%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v19.01     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                       04 - January - 2019                        %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is an entirely synthetic 10,000 bus case, geographically situated
%   in US portion of the WECC system. The case is designed with a 765, 500,
%   345, 230, 161, 138 and 115 kV transmission network to serve a load that
%   roughly mimics the actual population of its geographic footprint. The
%   synthetic transmission system was designed by algorithms described in
%   [1] to be statistically similar to actual transmission system models but
%   without modeling any actual lines.
%
%   When publishing results based on this data, please cite:
%
%   [1] A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye, T.J. Overbye,
%       "Grid Structural Characteristics as Validation Criteria for
%       Synthetic Networks," IEEE Transactions on Power Systems, 2017.
%
%   This is a synthetic power system model that does not represent the
%   actual grid. It was developed as part of the US ARPA-E GRID DATA
%   research project and contains no CEII.
%
%   One-line diagrams and other data formats available at:
%       https://electricgrids.engr.tamu.edu
%
%   October 27, 2017
%
%   Created from ACTIVSg10k.pwb, saved by
%   PowerWorld Simulator, version 20, build date October 19, 2017,
%   then by MATPOWER 6.
%
%   Copyright (c) 2017 by A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye,
%   and T.J. Overbye
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case10000_tamu
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	10001	 1	 9.64	 2.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10002	 1	 15.98	 6.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10003	 1	 14.39	 1.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10005	 1	 10.45	 2.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10006	 1	 13.44	 1.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10009	 1	 16.82	 2.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10010	 1	 33.49	 15.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10011	 1	 32.02	 8.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10013	 1	 57.79	 30.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10014	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10015	 1	 25.01	 11.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10016	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10017	 1	 25.89	 7.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10018	 1	 24.47	 6.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10019	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10020	 1	 53.35	 4.54	 0.0	 32.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10021	 1	 8.99	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10022	 1	 48.19	 15.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10024	 1	 43.96	 8.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10025	 1	 30.89	 12.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10026	 1	 18.65	 4.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10027	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10028	 1	 32.23	 12.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10029	 1	 32.23	 1.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10031	 1	 39.8	 7.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10032	 1	 41.5	 5.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10033	 1	 59.05	 6.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10035	 1	 59.05	 42.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10037	 1	 58.29	 11.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10038	 1	 36.59	 13.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10040	 1	 43.57	 13.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10041	 1	 20.08	 9.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10042	 1	 59.25	 11.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10043	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10044	 1	 37.54	 1.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10045	 1	 25.35	 12.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10047	 1	 45.76	 5.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10048	 1	 45.76	 10.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10050	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10052	 1	 17.51	 1.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10053	 1	 43.68	 4.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10054	 1	 43.32	 16.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10055	 1	 17.57	 5.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10058	 1	 43.93	 8.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10060	 1	 43.93	 27.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10061	 1	 51.07	 18.71	 0.0	 22.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10062	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10064	 1	 36.24	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10065	 1	 46.26	 6.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10069	 1	 58.86	 14.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10070	 1	 11.07	 0.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10071	 1	 38.37	 10.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10072	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10073	 1	 38.37	 20.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10075	 1	 14.72	 4.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10076	 1	 27.96	 2.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10077	 1	 28.46	 7.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10079	 1	 55.86	 12.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10081	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10083	 1	 22.32	 8.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10085	 1	 40.86	 5.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10086	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10087	 1	 10.87	 8.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10088	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10089	 1	 33.23	 4.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10090	 1	 33.23	 6.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10091	 1	 37.67	 4.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10092	 1	 31.46	 1.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10093	 1	 31.46	 11.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10094	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10095	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10096	 1	 18.02	 4.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10097	 1	 31.02	 5.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10098	 1	 19.84	 5.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10099	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10100	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10102	 1	 33.88	 8.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10104	 1	 57.74	 17.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10106	 1	 51.34	 13.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10107	 1	 26.95	 1.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10110	 1	 12.48	 4.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10111	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10112	 1	 11.2	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10113	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10114	 1	 31.06	 13.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10115	 1	 31.06	 11.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10116	 1	 47.94	 5.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10118	 1	 45.39	 21.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10120	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10122	 1	 35.43	 19.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10125	 1	 35.43	 7.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10128	 1	 44.89	 16.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10129	 1	 50.09	 14.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10130	 1	 50.09	 14.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10132	 1	 41.72	 12.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10134	 1	 71.03	 8.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10135	 1	 61.01	 13.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10137	 1	 20.07	 5.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10138	 1	 38.05	 7.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10139	 1	 35.0	 8.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10140	 1	 16.07	 5.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10141	 1	 41.11	 16.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10142	 1	 41.11	 1.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10144	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10145	 1	 37.97	 9.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10146	 1	 37.97	 9.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10148	 1	 52.25	 24.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10150	 1	 7.99	 4.67	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10151	 1	 11.73	 1.24	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10153	 1	 35.35	 3.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10154	 1	 33.06	 13.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10156	 1	 33.52	 4.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10157	 1	 32.33	 10.35	 0.0	 80.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10159	 1	 15.22	 4.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10160	 1	 55.26	 20.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10162	 1	 25.6	 5.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10164	 1	 26.64	 6.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10166	 1	 47.72	 5.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10167	 1	 32.36	 10.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10168	 1	 32.36	 10.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10169	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10170	 1	 14.51	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10171	 1	 51.86	 8.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10174	 1	 41.08	 5.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10175	 1	 41.08	 12.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10177	 1	 37.0	 12.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10178	 1	 37.0	 6.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10179	 1	 55.41	 4.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10180	 1	 1.46	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10182	 1	 55.41	 4.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10183	 1	 48.59	 5.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10185	 1	 68.06	 27.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10187	 1	 37.59	 7.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10188	 1	 51.74	 17.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10190	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10191	 1	 63.47	 6.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10193	 1	 63.47	 25.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10198	 1	 55.17	 29.09	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10199	 1	 25.51	 11.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10200	 1	 57.98	 19.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10201	 1	 45.34	 7.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10202	 1	 21.66	 3.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10203	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10204	 1	 12.67	 2.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10206	 1	 40.75	 8.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10207	 1	 40.75	 6.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10208	 1	 24.17	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10209	 1	 81.39	 49.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10210	 1	 49.48	 10.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10211	 1	 49.48	 11.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10214	 1	 12.52	 3.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10215	 1	 36.39	 3.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10217	 1	 36.39	 3.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10218	 1	 30.67	 6.45	 0.0	 90.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10219	 1	 38.5	 11.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10221	 1	 38.5	 7.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10222	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10223	 1	 9.41	 2.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10224	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10225	 1	 35.59	 23.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10226	 1	 35.59	 19.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10227	 1	 47.25	 13.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10228	 1	 53.38	 19.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10229	 1	 35.45	 4.71	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10230	 1	 51.81	 10.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10231	 1	 51.81	 15.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10232	 1	 48.36	 11.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10234	 1	 37.64	 3.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10236	 1	 37.64	 13.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10237	 1	 33.48	 6.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10238	 1	 33.48	 8.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10239	 1	 50.01	 9.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10241	 1	 50.75	 10.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10242	 1	 0.0	 0.0	 0.0	 60.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10243	 1	 45.67	 5.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10244	 1	 34.46	 5.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10245	 1	 34.46	 8.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10247	 1	 41.16	 3.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10248	 1	 43.93	 29.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10249	 1	 50.49	 5.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10250	 1	 57.01	 12.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10251	 1	 57.01	 22.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10252	 1	 31.11	 9.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10254	 1	 31.11	 19.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10256	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10257	 1	 24.34	 12.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10259	 1	 48.72	 8.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10260	 1	 30.31	 12.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10261	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10262	 1	 54.9	 12.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10263	 1	 35.69	 9.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10264	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10265	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10266	 1	 49.72	 2.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10267	 1	 23.27	 4.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10269	 1	 53.47	 13.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10271	 1	 53.47	 7.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10272	 1	 55.09	 7.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10273	 1	 55.09	 20.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10274	 1	 24.57	 5.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10275	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10276	 1	 43.11	 11.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10277	 1	 44.92	 20.45	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10279	 1	 28.63	 8.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10283	 1	 32.97	 7.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10284	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10285	 1	 24.02	 1.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10286	 1	 53.39	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10288	 1	 49.12	 9.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10289	 1	 32.24	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10290	 1	 32.24	 4.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10292	 1	 49.81	 3.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10293	 1	 52.98	 28.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10294	 1	 52.98	 12.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10296	 1	 56.71	 7.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10299	 1	 41.5	 28.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10301	 1	 50.57	 7.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10302	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10303	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10305	 1	 47.86	 19.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10306	 1	 60.83	 25.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10307	 1	 48.61	 20.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10309	 1	 39.33	 13.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10310	 1	 39.33	 5.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10312	 1	 40.48	 22.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10314	 1	 40.48	 8.05	 0.0	 93.5	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10315	 1	 44.5	 8.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10316	 1	 44.5	 7.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10318	 1	 37.74	 7.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10320	 1	 37.74	 9.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10321	 1	 32.26	 13.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10322	 1	 32.26	 6.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10323	 1	 50.58	 11.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10324	 1	 32.27	 4.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10325	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10326	 1	 32.27	 7.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10327	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10328	 1	 52.71	 7.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10329	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10331	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10332	 1	 52.71	 12.35	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10334	 1	 55.45	 10.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10335	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10337	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10338	 1	 55.45	 18.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10339	 1	 43.2	 7.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10341	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10342	 1	 43.2	 9.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10344	 1	 87.17	 16.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10346	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10348	 1	 55.47	 9.35	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10351	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10354	 1	 51.28	 15.06	 0.0	 100.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10355	 1	 51.28	 18.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10356	 1	 35.97	 3.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10358	 1	 35.97	 3.43	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10359	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10361	 1	 53.94	 6.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10362	 1	 38.29	 10.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10363	 1	 38.29	 29.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10364	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10366	 1	 44.83	 11.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10367	 1	 44.83	 13.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10368	 1	 47.26	 13.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10370	 1	 47.26	 2.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10372	 1	 40.62	 5.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10374	 1	 40.62	 8.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10376	 1	 49.01	 10.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10377	 1	 57.82	 24.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10379	 1	 50.93	 12.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10380	 1	 32.62	 5.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10381	 1	 32.62	 8.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10384	 1	 54.48	 37.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10385	 1	 41.22	 10.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10388	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10389	 1	 41.22	 19.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10390	 1	 25.11	 4.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10392	 1	 25.47	 2.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10393	 1	 37.98	 4.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10394	 1	 37.98	 9.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10395	 1	 48.49	 17.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10396	 1	 48.49	 9.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10397	 1	 35.5	 8.68	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10398	 1	 35.5	 11.17	 0.0	 60.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10400	 1	 32.07	 7.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10404	 1	 32.07	 11.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10406	 1	 33.54	 8.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10407	 1	 33.54	 15.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10408	 1	 35.05	 12.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10409	 1	 35.05	 11.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10410	 1	 52.57	 23.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10411	 1	 61.36	 11.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10412	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10413	 1	 61.36	 11.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10414	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10415	 1	 40.52	 24.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10416	 1	 40.52	 14.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10417	 1	 43.9	 2.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10418	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10419	 1	 43.9	 15.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10420	 1	 41.21	 22.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10421	 1	 41.21	 6.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10422	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10423	 1	 38.99	 8.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10424	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10425	 1	 38.99	 9.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10426	 1	 62.16	 9.98	 0.0	 56.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10429	 1	 62.16	 12.77	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10430	 1	 42.51	 5.9	 0.0	 48.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10432	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10433	 1	 54.76	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10434	 1	 53.17	 5.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10435	 1	 28.73	 8.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10436	 1	 43.64	 7.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10438	 1	 43.64	 10.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10439	 1	 29.48	 5.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10440	 1	 55.08	 4.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10441	 1	 55.08	 5.02	 0.0	 60.5	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10442	 1	 40.3	 12.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10445	 1	 59.73	 15.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10448	 1	 53.55	 15.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10449	 1	 47.78	 4.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10451	 1	 47.78	 18.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10452	 1	 50.33	 5.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10453	 1	 50.33	 14.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10456	 1	 58.98	 25.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10457	 1	 17.46	 1.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10458	 1	 70.13	 13.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10459	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10460	 1	 70.13	 15.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10461	 1	 52.41	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10463	 1	 64.47	 17.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10464	 1	 41.36	 15.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10465	 1	 42.13	 18.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10466	 1	 33.55	 5.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10467	 1	 33.55	 12.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10469	 1	 58.59	 7.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10470	 1	 36.63	 3.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10473	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10474	 1	 36.63	 6.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10475	 1	 37.47	 3.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10476	 1	 6.89	 1.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10477	 1	 32.6	 11.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10479	 1	 30.9	 10.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10482	 1	 30.9	 2.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10483	 1	 49.72	 16.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10484	 1	 45.08	 3.55	 0.0	 31.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10485	 1	 58.44	 6.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10486	 1	 31.37	 21.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10487	 1	 31.37	 16.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10488	 1	 39.26	 18.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10489	 1	 39.26	 13.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10491	 1	 45.25	 10.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10492	 1	 37.41	 10.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10494	 1	 9.47	 1.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10495	 1	 48.98	 14.87	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10497	 1	 48.98	 16.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10499	 1	 1.68	 0.56	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10500	 1	 50.37	 11.17	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10502	 1	 13.56	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10503	 1	 33.53	 1.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10504	 1	 33.53	 3.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10505	 1	 16.24	 3.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10507	 1	 25.74	 1.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10509	 1	 31.18	 5.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10513	 1	 15.83	 2.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10514	 1	 21.06	 8.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10515	 1	 35.95	 7.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10516	 1	 11.97	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10517	 1	 23.34	 17.01	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10518	 1	 5.11	 0.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10519	 1	 12.65	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10520	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10521	 1	 8.11	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10523	 1	 34.84	 16.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10524	 1	 23.34	 3.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10525	 1	 21.1	 16.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10526	 1	 17.1	 4.79	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10528	 1	 5.59	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10529	 1	 52.69	 12.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10530	 1	 42.29	 8.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10531	 1	 40.74	 11.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10533	 1	 55.59	 19.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10535	 1	 55.59	 16.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10536	 1	 36.42	 8.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10539	 1	 20.01	 7.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10540	 1	 36.29	 3.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10541	 1	 38.97	 6.45	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10542	 1	 36.2	 17.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10543	 1	 36.2	 6.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10545	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10546	 1	 0.57	 0.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10547	 1	 15.35	 7.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10549	 1	 49.17	 12.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10550	 1	 49.17	 17.55	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10552	 1	 5.68	 0.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10554	 1	 31.74	 3.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10555	 1	 7.28	 1.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10557	 1	 48.67	 18.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10558	 1	 38.11	 10.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10559	 1	 34.46	 8.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10561	 1	 8.85	 1.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10564	 1	 16.95	 2.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10566	 1	 10.06	 4.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10567	 1	 36.6	 16.45	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10568	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10570	 1	 28.08	 3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10571	 1	 11.76	 7.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10573	 1	 20.36	 2.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10574	 1	 31.66	 9.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10576	 1	 11.65	 6.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10577	 1	 52.83	 24.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10578	 1	 26.53	 6.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10580	 1	 13.0	 4.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10581	 1	 22.08	 6.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10582	 1	 13.67	 3.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10584	 1	 31.93	 1.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10585	 1	 47.67	 13.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10588	 1	 48.43	 13.27	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10589	 1	 51.22	 19.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10590	 1	 32.37	 19.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10592	 1	 33.21	 7.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10594	 1	 27.73	 18.76	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10595	 1	 2.59	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10596	 1	 22.07	 6.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10597	 1	 15.44	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10598	 1	 11.72	 2.14	 0.0	 -28.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10599	 1	 7.3	 0.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10600	 1	 40.36	 10.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10601	 1	 58.5	 8.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10602	 1	 58.5	 37.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10604	 1	 36.33	 6.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10605	 1	 35.81	 17.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10606	 1	 9.8	 4.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10607	 1	 81.83	 24.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10609	 1	 84.01	 4.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10610	 1	 19.08	 2.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10613	 1	 8.84	 3.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10614	 1	 14.83	 2.9	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10616	 1	 10.54	 1.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10617	 1	 25.71	 3.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10618	 1	 11.54	 4.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10620	 1	 18.18	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10622	 1	 16.75	 2.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10625	 1	 13.52	 3.74	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10626	 1	 12.06	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10627	 1	 33.56	 6.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10628	 1	 44.13	 15.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10629	 1	 21.97	 4.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10630	 1	 44.49	 7.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10631	 1	 4.79	 0.93	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10632	 1	 21.7	 1.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10633	 1	 43.89	 21.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10634	 1	 37.73	 8.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10635	 1	 59.03	 26.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10636	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10637	 1	 59.03	 31.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10638	 1	 50.56	 26.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10639	 1	 50.56	 11.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10640	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10641	 1	 32.02	 9.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10642	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10643	 1	 16.23	 4.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10644	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10645	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10646	 1	 12.43	 6.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10647	 1	 37.27	 5.15	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10648	 1	 48.46	 9.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10649	 1	 37.02	 10.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10650	 1	 37.02	 18.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10651	 1	 51.79	 4.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10652	 1	 20.58	 0.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10653	 1	 35.13	 16.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10654	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10655	 1	 42.81	 15.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10656	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10657	 1	 46.07	 12.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10658	 1	 11.64	 4.64	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10659	 1	 52.07	 9.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10660	 1	 41.82	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10661	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10662	 1	 41.76	 6.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10664	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10665	 1	 41.76	 7.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10666	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10667	 1	 9.47	 2.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10668	 1	 58.47	 16.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10669	 1	 37.68	 10.45	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10670	 1	 43.92	 41.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10671	 1	 31.14	 10.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10672	 1	 19.47	 0.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10673	 1	 22.02	 10.97	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10674	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10675	 1	 14.64	 2.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10676	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10677	 1	 33.11	 10.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10678	 1	 22.8	 5.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10679	 1	 12.56	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10683	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10684	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10685	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10686	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10687	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	10688	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10689	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10690	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10691	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10692	 1	 0.71	 0.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10693	 1	 6.94	 1.63	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10694	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	10695	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	10696	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10697	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10698	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10699	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10700	 1	 1.19	 0.45	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10701	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10702	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10703	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10704	 1	 2.16	 0.73	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10705	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10706	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10707	 1	 0.0	 0.0	 0.0	 -324.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10708	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10710	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10711	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10712	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10713	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10714	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10715	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10716	 1	 0.17	 0.02	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10717	 1	 0.0	 0.0	 0.0	 -1538.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10718	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10719	 1	 0.31	 0.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10720	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10721	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10722	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10723	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10724	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10725	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10726	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10727	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10728	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10729	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10730	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10731	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10732	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10734	 1	 0.0	 0.0	 0.0	 440.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10735	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10737	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10738	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10739	 1	 0.0	 0.0	 0.0	 -256.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10740	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10741	 1	 0.36	 0.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10742	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10743	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10745	 1	 0.42	 0.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10746	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10747	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10749	 1	 8.81	 1.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10750	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10751	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10752	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10753	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10754	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10755	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10756	 1	 0.0	 0.0	 0.0	 -109.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10757	 2	 10.95	 1.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10758	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10759	 1	 9.66	 2.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10761	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10765	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10766	 1	 0.0	 0.0	 0.0	 -105.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10767	 1	 5.4	 0.33	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10768	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10770	 1	 2.32	 0.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10771	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10772	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10773	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10774	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10775	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10776	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10777	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10778	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10779	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10780	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10781	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10782	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10783	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10784	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10785	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10788	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10789	 1	 0.0	 0.0	 0.0	 -90.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10790	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10791	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10792	 1	 13.86	 3.24	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10793	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10794	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10795	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10796	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10797	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10798	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10799	 1	 9.92	 1.97	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10800	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10801	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10802	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10803	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10804	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10805	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10806	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10807	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10808	 1	 0.0	 0.0	 0.0	 -254.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10810	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10811	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10812	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10813	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10815	 1	 2.44	 0.29	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10816	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10817	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10818	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10819	 1	 2.9	 0.43	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10821	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10822	 1	 0.52	 0.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10823	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10824	 1	 0.0	 0.0	 0.0	 -476.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10825	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10826	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10827	 1	 5.5	 1.37	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10828	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10829	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10830	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10831	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10832	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10833	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10834	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10836	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10838	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10841	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10842	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10843	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10844	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10845	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10846	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10847	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10848	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10849	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10850	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10851	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10852	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10853	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10854	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10855	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10856	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10858	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10859	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10860	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10864	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10865	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10866	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10867	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10868	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10869	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10870	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10871	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10872	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10873	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10875	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10876	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10879	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10880	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10881	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10882	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10883	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10884	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10885	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10886	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10887	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10889	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10890	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10891	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10892	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10893	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10894	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10895	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	10896	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10897	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10898	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10900	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10901	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10902	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10904	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10905	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10906	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10907	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10908	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10909	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10910	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	10912	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10913	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10914	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10916	 1	 0.0	 0.0	 0.0	 -666.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10917	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10919	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10920	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10921	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10922	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10923	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10924	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10925	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10926	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10929	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10930	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10931	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10932	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10933	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10934	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10935	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10936	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10937	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10938	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10939	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10940	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10941	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10942	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10943	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10944	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	10945	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10946	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10947	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10948	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10949	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10950	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10951	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10952	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10953	 1	 0.0	 0.0	 0.0	 46.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10954	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10955	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10956	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10957	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10958	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10959	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10960	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10961	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10963	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10964	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10965	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10966	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10969	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10970	 1	 0.0	 0.0	 0.0	 -202.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10972	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10973	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10975	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10976	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10977	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	10978	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10980	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10981	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10982	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10985	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10986	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	10987	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	10988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10989	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10990	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	10991	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	10992	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10993	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10994	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10995	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10996	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10997	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	10998	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	10999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11000	 1	 0.0	 0.0	 0.0	 -776.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	11001	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11002	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	11004	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	11005	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11006	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11007	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11008	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11009	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	11010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11011	 1	 0.0	 0.0	 0.0	 -1746.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	11012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11013	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11014	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11015	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11016	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11017	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11018	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11019	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11020	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	11021	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	11022	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11024	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11025	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11026	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11027	 1	 0.0	 0.0	 0.0	 -177.5	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11028	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11029	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11030	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	11031	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11032	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	11033	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	11034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11035	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11037	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11038	 1	 0.0	 0.0	 0.0	 -384.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	11039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11041	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11042	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11043	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11044	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11045	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	11046	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11047	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11048	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11049	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11050	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11051	 1	 0.0	 0.0	 0.0	 -29.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	11053	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11054	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11057	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11058	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11059	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	11060	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11061	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11062	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11063	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11065	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11066	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11067	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11068	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11069	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11072	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11073	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	11074	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	11075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	11076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	11077	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	11078	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11079	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11080	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11081	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	11082	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13000	 1	 18.95	 3.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13001	 1	 5.92	 0.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13002	 1	 0.0	 0.0	 0.0	 10.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13003	 1	 12.43	 3.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13004	 1	 35.23	 8.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13005	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13006	 1	 35.54	 17.22	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13007	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13008	 1	 16.34	 3.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13009	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13010	 1	 32.97	 11.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13011	 1	 0.0	 0.0	 0.0	 46.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13012	 1	 37.67	 13.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13013	 1	 39.69	 27.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13014	 1	 26.39	 5.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13015	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13016	 1	 13.32	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13017	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13018	 1	 31.38	 1.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13019	 1	 17.49	 4.98	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13020	 1	 16.52	 1.81	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13021	 1	 11.69	 2.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13022	 1	 19.17	 3.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13023	 1	 7.26	 2.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13024	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13025	 1	 16.54	 3.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13026	 1	 23.07	 7.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13027	 1	 31.54	 4.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13028	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13029	 1	 40.46	 9.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13030	 1	 24.05	 15.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13031	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13032	 1	 21.24	 4.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13033	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13034	 1	 12.08	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13035	 1	 5.71	 0.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13036	 1	 38.52	 13.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13037	 1	 36.63	 10.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13038	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13039	 1	 22.2	 3.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13040	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13041	 1	 20.89	 8.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13042	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13043	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13044	 1	 17.06	 5.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13045	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13046	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13047	 1	 21.32	 8.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13048	 1	 0.0	 0.0	 0.0	 -12.5	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13049	 1	 40.46	 9.81	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13050	 1	 42.22	 4.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13051	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13052	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13053	 1	 20.28	 13.09	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13054	 1	 13.68	 9.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13055	 1	 50.69	 5.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13056	 1	 29.33	 10.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13057	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13058	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13059	 1	 41.05	 8.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13060	 1	 41.05	 14.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13061	 1	 12.35	 4.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13062	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13063	 1	 51.3	 22.47	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13064	 1	 43.37	 9.43	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13065	 1	 52.47	 19.01	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13066	 1	 29.39	 8.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13067	 1	 14.6	 7.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13068	 1	 55.55	 24.43	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13069	 1	 53.79	 26.38	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13070	 1	 47.96	 2.1	 0.0	 48.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13071	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	13072	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	13073	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13074	 1	 8.78	 2.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13075	 1	 68.22	 13.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13076	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13077	 1	 60.41	 12.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13078	 1	 32.56	 12.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13079	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13080	 1	 32.26	 6.73	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13081	 1	 18.78	 7.13	 0.0	 18.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13082	 1	 54.5	 20.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13083	 1	 53.57	 11.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13084	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13085	 1	 57.85	 13.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13086	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13087	 1	 59.83	 15.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13088	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13089	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13090	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13091	 1	 16.6	 3.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13092	 1	 24.74	 8.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13093	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13094	 1	 38.71	 7.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13095	 1	 38.71	 7.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13096	 1	 14.31	 1.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13097	 1	 34.14	 8.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13098	 1	 34.14	 18.04	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13099	 1	 32.83	 0.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13100	 1	 32.83	 3.03	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13101	 1	 48.63	 5.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13102	 1	 48.63	 8.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13103	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13104	 1	 20.4	 7.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13105	 1	 44.56	 4.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13106	 1	 46.31	 8.03	 0.0	 56.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13107	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13108	 1	 11.04	 4.42	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13109	 1	 28.11	 6.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13110	 1	 21.89	 6.51	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13111	 1	 11.55	 2.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13112	 1	 27.89	 5.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13113	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13114	 1	 33.97	 19.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13115	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13116	 1	 23.32	 2.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13117	 1	 13.45	 4.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13118	 1	 46.4	 5.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13119	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13120	 1	 46.4	 6.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13121	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13122	 1	 9.6	 3.07	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13123	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13124	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13125	 1	 40.85	 7.65	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	13126	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	13127	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13128	 1	 40.85	 22.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13129	 1	 5.36	 1.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13130	 1	 44.45	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13131	 1	 44.25	 20.84	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13132	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13133	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13134	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13135	 1	 50.34	 7.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13136	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13137	 1	 64.22	 15.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13138	 1	 64.22	 15.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13139	 1	 51.44	 3.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13140	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13141	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13142	 1	 33.93	 14.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13143	 1	 16.06	 3.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13144	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13145	 1	 53.44	 10.93	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13146	 1	 53.44	 36.37	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13147	 1	 40.07	 8.54	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13148	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13149	 1	 12.29	 3.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13150	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13151	 1	 33.23	 4.12	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13152	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13153	 1	 33.23	 5.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13154	 1	 42.09	 9.86	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13155	 1	 58.02	 7.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13156	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13157	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13158	 1	 58.02	 33.67	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13159	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13160	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13161	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13162	 1	 12.99	 1.76	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13163	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13164	 1	 12.46	 1.69	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13165	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13166	 1	 48.21	 18.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13167	 1	 48.21	 17.03	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13168	 1	 25.27	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13169	 1	 58.45	 7.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13170	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13171	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13172	 1	 50.54	 9.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13173	 1	 50.54	 2.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13174	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13175	 1	 93.84	 39.6	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13176	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13177	 1	 80.34	 13.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13178	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13179	 1	 56.34	 6.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13180	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13181	 1	 75.64	 25.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13182	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13183	 1	 75.64	 25.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13184	 1	 15.87	 1.03	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13185	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13186	 1	 44.41	 2.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13187	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13188	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13189	 1	 47.27	 5.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13190	 1	 3.41	 0.89	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13191	 1	 5.6	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13192	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13193	 1	 34.56	 16.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13194	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13195	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13196	 1	 34.56	 15.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13197	 1	 34.34	 16.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13198	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13199	 1	 34.34	 9.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13200	 1	 19.03	 3.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13201	 1	 12.11	 3.27	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13202	 1	 0.0	 0.0	 0.0	 70.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13203	 1	 69.86	 22.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13204	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13205	 1	 69.86	 17.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13206	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13207	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13208	 1	 34.76	 15.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13209	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13210	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13211	 1	 34.76	 13.42	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13212	 1	 59.77	 3.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13213	 1	 53.33	 18.88	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13214	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13215	 1	 53.33	 14.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13216	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13217	 1	 37.35	 10.62	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13218	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13219	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13220	 1	 37.35	 8.86	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13221	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13222	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13223	 1	 13.85	 5.41	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13224	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13225	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13226	 1	 0.0	 0.0	 0.0	 60.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13227	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13228	 1	 12.53	 0.69	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13229	 1	 0.0	 0.0	 0.0	 110.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13230	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13231	 1	 56.04	 11.4	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13232	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13233	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13234	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13235	 1	 56.04	 6.96	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13236	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13237	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13238	 1	 50.3	 3.5	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13239	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13240	 1	 10.41	 4.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13241	 1	 58.02	 18.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13242	 1	 0.0	 0.0	 0.0	 59.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13243	 1	 32.92	 4.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13244	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13245	 1	 32.92	 17.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13246	 1	 37.25	 13.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13247	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13248	 1	 37.25	 12.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13249	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13250	 1	 27.91	 10.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13251	 1	 39.23	 13.48	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13252	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13253	 1	 44.58	 10.55	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13254	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13255	 1	 57.39	 3.29	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13256	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13257	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13258	 1	 43.46	 8.22	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13259	 1	 35.31	 17.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13260	 1	 37.73	 9.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13261	 1	 37.73	 19.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13262	 1	 46.45	 9.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13263	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13264	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13265	 1	 83.61	 24.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13266	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13267	 1	 33.96	 14.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13268	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13269	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13270	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13271	 1	 35.88	 11.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13272	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13273	 1	 45.37	 13.08	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13274	 1	 33.97	 3.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13275	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13276	 1	 33.97	 19.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13277	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13278	 1	 54.45	 10.57	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13279	 1	 36.28	 12.01	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13280	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13281	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13282	 1	 46.51	 14.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13283	 1	 46.51	 8.05	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13284	 1	 27.53	 6.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13285	 1	 67.14	 23.83	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13286	 1	 57.15	 10.33	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13287	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13288	 1	 37.5	 15.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13289	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13290	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13291	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13292	 1	 47.78	 20.64	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13293	 1	 41.97	 4.85	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13294	 1	 41.97	 8.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13295	 1	 37.01	 19.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13296	 1	 37.01	 12.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13297	 1	 0.0	 0.0	 0.0	 -92.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13298	 1	 34.95	 6.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13299	 1	 39.3	 10.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13300	 1	 35.06	 8.71	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13301	 1	 35.06	 12.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13302	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13303	 1	 57.12	 7.21	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13304	 1	 57.12	 7.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13305	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13306	 1	 29.11	 2.81	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13307	 1	 58.73	 11.01	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13308	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13309	 1	 34.19	 8.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13310	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13311	 1	 34.19	 10.61	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13312	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13313	 1	 36.27	 9.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13314	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13315	 1	 39.91	 17.75	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13316	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13317	 1	 39.96	 11.92	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13318	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13319	 1	 39.96	 6.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13320	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13321	 1	 46.85	 7.91	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13322	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13323	 1	 68.65	 28.61	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13324	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13325	 1	 61.63	 9.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13326	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13327	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13328	 1	 31.21	 14.89	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13329	 1	 31.21	 2.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13330	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13331	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13332	 1	 44.22	 7.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13333	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13334	 1	 44.22	 19.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13335	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13336	 1	 47.7	 22.86	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13337	 1	 47.7	 2.99	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13338	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13339	 1	 47.24	 21.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13340	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13341	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13342	 1	 47.24	 9.56	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13343	 1	 17.54	 7.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13344	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13345	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13346	 1	 28.77	 3.1	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13347	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13348	 1	 24.58	 2.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13349	 1	 44.03	 9.35	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13350	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13351	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13352	 1	 44.03	 6.8	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13353	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13354	 1	 14.64	 4.17	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13355	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13356	 1	 49.07	 4.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13357	 1	 58.0	 14.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13358	 1	 11.15	 1.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13359	 1	 54.03	 15.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13360	 1	 26.22	 6.19	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13361	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13362	 1	 23.6	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13363	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13364	 1	 48.17	 20.44	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13365	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13366	 1	 54.11	 6.56	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13367	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13368	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13369	 1	 15.54	 2.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13370	 1	 0.48	 0.18	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13371	 1	 35.43	 20.34	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13372	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13373	 1	 35.43	 8.27	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13374	 1	 11.04	 2.39	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13375	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13376	 1	 14.42	 0.87	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13377	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13378	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13379	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13380	 1	 44.1	 10.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13381	 1	 13.95	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13382	 1	 28.03	 7.72	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13383	 1	 6.78	 2.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13384	 1	 9.02	 1.65	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13385	 1	 12.16	 7.32	 0.0	 -30.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13386	 1	 48.7	 4.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13387	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13388	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13389	 1	 48.7	 17.06	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13390	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13391	 1	 16.22	 2.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13392	 1	 4.84	 0.79	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13393	 1	 40.26	 9.09	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13394	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13395	 1	 40.26	 13.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13396	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13397	 1	 70.79	 17.7	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13398	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13399	 1	 70.79	 29.81	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13400	 1	 53.21	 10.9	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13401	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13402	 1	 29.66	 6.13	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13403	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13404	 1	 45.08	 6.77	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13405	 1	 5.03	 0.75	 0.0	 -8.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13406	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13407	 1	 13.71	 1.07	 0.0	 -28.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13408	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13409	 1	 9.98	 1.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13410	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13411	 1	 9.13	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13412	 1	 0.0	 0.0	 0.0	 -10.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13413	 1	 4.76	 0.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13414	 1	 18.62	 7.78	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13415	 1	 33.02	 10.26	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13416	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13417	 1	 36.68	 7.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13418	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13419	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13420	 1	 18.38	 5.58	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13421	 1	 0.0	 0.0	 0.0	 -30.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13422	 1	 17.59	 4.67	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13423	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13424	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13425	 1	 5.43	 0.68	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13426	 1	 53.61	 21.63	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13427	 1	 34.15	 3.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13428	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13429	 1	 49.27	 11.52	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13430	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13431	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13432	 1	 49.27	 13.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13433	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13434	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13435	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13436	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13437	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13438	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13439	 1	 43.84	 4.03	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13440	 1	 6.31	 1.02	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13441	 1	 32.09	 9.28	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13442	 1	 9.92	 2.4	 0.0	 -14.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13443	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13444	 1	 13.49	 6.31	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13445	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13446	 1	 11.91	 3.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13447	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13448	 1	 47.75	 10.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13449	 1	 4.91	 0.97	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13450	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13451	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13452	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13453	 1	 0.0	 0.0	 0.0	 -85.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13454	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13455	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13456	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13457	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13458	 2	 1.55	 0.32	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13459	 1	 0.0	 0.0	 0.0	 -296.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13460	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13461	 1	 1.87	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13462	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13463	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13464	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13465	 1	 0.87	 0.11	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13466	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13467	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13468	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13469	 1	 2.04	 0.94	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13470	 1	 0.0	 0.0	 0.0	 -1424.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13471	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13472	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13473	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13474	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13475	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13476	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13477	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13478	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13479	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13480	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13481	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13482	 1	 3.98	 1.16	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13483	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	13484	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13485	 1	 1.62	 0.46	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13486	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	13487	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13488	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13489	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13490	 1	 2.98	 1.71	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13491	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13492	 2	 1.9	 0.53	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13493	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13494	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13495	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13496	 1	 0.0	 0.0	 0.0	 -1148.5	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13497	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13498	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13499	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13500	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13501	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	13502	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13503	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13504	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	13505	 1	 0.65	 0.23	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13506	 1	 0.0	 0.0	 0.0	 -290.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13507	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13508	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13509	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13510	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13511	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13512	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13513	 2	 1.43	 0.14	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13514	 1	 4.99	 1.74	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13515	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13516	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13517	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13518	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13519	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13520	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13521	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13522	 2	 0.51	 0.25	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13523	 1	 0.0	 0.0	 0.0	 -720.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13524	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13525	 1	 7.29	 2.59	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13526	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13527	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13528	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13529	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13530	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13531	 1	 1.96	 0.22	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13532	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13533	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13534	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13535	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13536	 1	 4.62	 1.49	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13537	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13538	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13539	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13540	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13541	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13542	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13543	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13544	 2	 2.37	 0.36	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13545	 1	 0.24	 0.02	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13546	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13547	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13548	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13549	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13550	 1	 1.14	 0.4	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13551	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13552	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13553	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13554	 1	 0.0	 0.0	 0.0	 -1200.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13555	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13556	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13557	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13558	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13559	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13560	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13561	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13562	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13563	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13564	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	13565	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13566	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13567	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13568	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13569	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13570	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	13571	 1	 0.0	 0.0	 0.0	 100.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13572	 2	 3.5	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13573	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13574	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13575	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13576	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13577	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13578	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13579	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13580	 1	 0.0	 0.0	 0.0	 -800.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13581	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13582	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13583	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13584	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13585	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13586	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13587	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	13588	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13589	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13590	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13591	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13592	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13593	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13594	 1	 0.0	 0.0	 0.0	 -420.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13595	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13596	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13597	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13598	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13599	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	13600	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13601	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13602	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13603	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13604	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13605	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13606	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13607	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13608	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13609	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13610	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13611	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13612	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13613	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13614	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13615	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13616	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13617	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13618	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13619	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13620	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13621	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13622	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13623	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13624	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13625	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	13626	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13627	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13628	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13629	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13630	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13631	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13632	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13633	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13634	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13635	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13636	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13637	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13638	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13639	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13640	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13641	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13642	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13643	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13644	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13645	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13646	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13647	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13648	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13649	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13650	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13651	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13652	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13653	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13654	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13655	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13656	 1	 0.0	 0.0	 0.0	 -71.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13657	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13658	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	13659	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13660	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13661	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13662	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13663	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13664	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13665	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13666	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13667	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13668	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13669	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13670	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13671	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	13672	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13673	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13674	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13675	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13676	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13677	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13678	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13679	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13680	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13681	 1	 0.0	 0.0	 0.0	 -408.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13682	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13683	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13684	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	13685	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13686	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13687	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13688	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13689	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13690	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13691	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13692	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	13693	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13694	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	13695	 1	 0.0	 0.0	 0.0	 -250.0	 2	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	13696	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	13697	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13698	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13699	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20000	 1	 43.99	 19.17	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20001	 1	 47.72	 14.7	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20002	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20003	 1	 43.97	 20.92	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20004	 1	 39.57	 6.1	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20005	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20006	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20007	 1	 51.47	 8.81	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20008	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20009	 1	 39.88	 9.38	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20010	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20011	 1	 16.7	 4.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20012	 1	 13.0	 7.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20013	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20014	 1	 27.14	 5.06	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20015	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20016	 1	 13.73	 3.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20017	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20018	 1	 10.58	 1.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20019	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20020	 1	 24.0	 2.73	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20021	 1	 10.86	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20022	 1	 0.0	 0.0	 0.0	 -90.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20023	 1	 31.74	 13.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20024	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20025	 1	 30.33	 17.09	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20026	 1	 7.73	 0.78	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20027	 1	 23.28	 4.16	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20028	 1	 12.83	 4.66	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20029	 1	 27.93	 14.68	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20030	 1	 11.11	 1.77	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20031	 1	 13.73	 2.67	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20032	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20033	 1	 20.18	 2.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20034	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20035	 1	 19.12	 7.7	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20036	 1	 35.22	 10.61	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20037	 1	 16.04	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20038	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20039	 1	 12.84	 1.88	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20040	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20041	 1	 30.48	 3.51	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20042	 1	 48.63	 17.35	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20043	 1	 30.19	 3.93	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20044	 1	 25.89	 12.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20045	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20046	 1	 25.89	 5.06	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20047	 1	 19.49	 4.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20048	 1	 1.44	 0.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20049	 1	 8.23	 0.72	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20050	 1	 29.97	 3.53	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20051	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20052	 1	 29.97	 7.86	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20053	 1	 10.88	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20054	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20055	 1	 41.11	 12.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20056	 1	 35.65	 9.91	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20057	 1	 17.52	 2.38	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20058	 1	 27.89	 9.42	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20059	 1	 40.01	 6.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20060	 1	 44.0	 9.14	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20061	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20062	 1	 9.34	 3.38	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20063	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20064	 1	 8.73	 1.99	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20065	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20066	 1	 11.75	 6.39	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20067	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20068	 1	 24.3	 2.58	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20069	 1	 11.78	 4.72	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20070	 1	 39.01	 11.97	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20071	 1	 34.15	 8.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20072	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20073	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20074	 1	 37.54	 6.32	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20075	 1	 32.86	 8.74	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20076	 1	 33.95	 9.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20077	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20078	 1	 35.53	 7.92	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20079	 1	 28.76	 7.03	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20080	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20081	 1	 28.76	 10.93	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20082	 1	 42.33	 12.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20083	 1	 42.33	 3.64	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20084	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20085	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20086	 1	 25.09	 5.91	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20087	 1	 34.51	 4.68	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20088	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20089	 1	 22.37	 12.17	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20090	 1	 39.42	 22.2	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20091	 1	 32.46	 5.76	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20092	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20093	 1	 32.46	 9.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20094	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20095	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20096	 1	 25.05	 16.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20097	 1	 24.79	 3.74	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20098	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20099	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20100	 1	 60.39	 11.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20101	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20102	 1	 39.48	 24.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20103	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20104	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20105	 1	 31.26	 7.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20106	 1	 31.26	 2.12	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20107	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20108	 1	 24.39	 4.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20109	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20110	 1	 36.69	 26.22	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20111	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20112	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20113	 1	 23.86	 3.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20114	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20115	 1	 25.52	 7.13	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20116	 1	 37.19	 8.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20117	 1	 37.19	 12.83	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20118	 1	 32.34	 14.33	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20119	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20120	 1	 32.34	 5.92	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20121	 1	 23.31	 6.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20122	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20123	 1	 51.42	 10.54	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20124	 1	 35.6	 5.5	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20125	 1	 35.66	 13.11	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20126	 1	 21.46	 10.8	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20127	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20128	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20129	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20130	 1	 28.18	 5.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20131	 1	 28.18	 4.13	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20132	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20133	 1	 61.42	 11.87	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20134	 1	 38.11	 16.26	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20135	 1	 41.71	 6.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20136	 1	 38.57	 4.95	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20137	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20138	 1	 24.36	 1.33	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20139	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20140	 1	 44.42	 7.14	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20141	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20142	 1	 33.09	 2.64	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20143	 1	 33.09	 10.84	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20144	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20145	 1	 54.39	 11.33	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20146	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20147	 1	 54.9	 15.32	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20148	 1	 31.03	 11.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20149	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20150	 1	 31.03	 7.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20151	 1	 68.35	 19.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20152	 1	 66.59	 26.28	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20153	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20154	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20155	 1	 27.2	 14.84	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20156	 1	 0.0	 0.0	 0.0	 -10.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20157	 1	 4.52	 0.41	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20158	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20159	 1	 30.85	 8.14	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20160	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20161	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20162	 1	 36.2	 10.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20163	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20164	 1	 36.2	 4.76	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20165	 1	 1.04	 0.18	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20166	 1	 27.58	 2.47	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20167	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20168	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20169	 1	 27.58	 3.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20170	 1	 27.98	 5.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20171	 1	 27.98	 10.2	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20172	 1	 52.08	 12.17	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20173	 1	 52.08	 7.82	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20174	 1	 30.2	 3.68	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20175	 1	 30.2	 2.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20176	 1	 27.64	 3.73	 0.0	 140.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20177	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20178	 1	 27.64	 2.17	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20179	 1	 32.97	 1.69	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20180	 1	 32.97	 6.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20181	 1	 40.4	 1.24	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20182	 1	 58.0	 5.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20183	 1	 50.96	 13.59	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20184	 1	 41.87	 18.35	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20185	 1	 69.17	 11.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20186	 1	 28.63	 6.27	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20187	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20188	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20189	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20190	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20191	 1	 35.01	 16.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20192	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20193	 1	 53.48	 11.48	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20194	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20195	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20196	 1	 53.48	 16.77	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20197	 1	 36.48	 13.47	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20198	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20199	 1	 44.56	 11.18	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20200	 1	 55.79	 14.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20201	 1	 63.56	 4.42	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20202	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20203	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20204	 1	 54.32	 14.42	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20205	 1	 44.83	 7.39	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20206	 1	 35.84	 7.38	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20207	 1	 35.84	 10.88	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20208	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20209	 1	 37.07	 5.02	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20210	 1	 37.07	 17.4	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20211	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20212	 1	 47.68	 16.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20213	 1	 49.36	 10.06	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20214	 1	 30.58	 3.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20215	 1	 30.58	 8.52	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20216	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20217	 1	 39.73	 3.65	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20218	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20219	 1	 39.73	 6.6	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20220	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20221	 1	 26.34	 11.86	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20222	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20223	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20224	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20225	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20226	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20227	 1	 26.34	 3.79	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20228	 1	 36.18	 9.37	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20229	 1	 64.58	 8.44	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20230	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20231	 1	 26.81	 6.06	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20232	 1	 26.81	 3.15	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20233	 1	 42.0	 12.8	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20234	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20235	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20236	 1	 28.4	 9.06	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20237	 1	 27.35	 5.39	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20238	 1	 20.44	 7.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20239	 1	 13.95	 5.07	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20240	 1	 38.63	 6.18	 0.0	 118.5	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20241	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20242	 1	 22.4	 7.13	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20243	 1	 0.0	 0.0	 0.0	 -78.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20244	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20245	 1	 64.96	 21.08	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	20246	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20247	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20248	 1	 64.96	 9.81	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20249	 1	 22.68	 4.98	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20250	 1	 35.53	 14.6	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20251	 1	 39.77	 9.24	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20252	 1	 52.17	 10.66	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20253	 1	 43.51	 15.43	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20254	 1	 34.92	 5.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20255	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20256	 1	 13.7	 5.66	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20257	 1	 22.68	 4.9	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20258	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20259	 1	 26.2	 11.28	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20260	 1	 26.2	 4.39	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20261	 1	 32.11	 14.85	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20262	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20263	 1	 12.73	 1.46	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20264	 1	 17.51	 1.49	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20265	 1	 10.94	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20266	 1	 49.19	 3.83	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20267	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20268	 1	 54.78	 2.72	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20269	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20270	 1	 43.16	 2.53	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20271	 1	 15.83	 2.79	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20272	 1	 17.9	 5.83	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20273	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20274	 1	 5.8	 0.94	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20275	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20276	 1	 19.41	 10.06	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20277	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20278	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20279	 1	 55.51	 12.63	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20280	 1	 26.81	 5.01	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20281	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20282	 1	 27.3	 3.76	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20283	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20284	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20285	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20286	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20287	 1	 7.56	 3.18	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20288	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20289	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20290	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20291	 1	 0.0	 0.0	 0.0	 -491.5	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20292	 1	 1.92	 0.26	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20293	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20294	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20295	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20296	 1	 0.0	 0.0	 0.0	 -346.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20297	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20298	 1	 2.73	 1.2	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20299	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	20300	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20301	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20302	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20303	 1	 1.07	 0.12	 0.0	 0.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20304	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20305	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20306	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20307	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20308	 1	 0.0	 0.0	 0.0	 -280.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20309	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20310	 1	 14.62	 1.87	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20311	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20312	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20313	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20314	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20315	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	20316	 1	 0.0	 0.0	 0.0	 -720.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20317	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20318	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20319	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	20320	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20321	 1	 0.39	 0.08	 0.0	 0.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20322	 1	 0.31	 0.14	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20323	 2	 13.5	 5.71	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20324	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20325	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20326	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20327	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20328	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20329	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20330	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20331	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20332	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20333	 1	 1.37	 0.3	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20334	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20335	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20336	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20337	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20338	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20339	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20340	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20341	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20342	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20343	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20344	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20345	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20346	 1	 2.48	 0.76	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20347	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20348	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20349	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20350	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20351	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20352	 1	 3.89	 0.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20353	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20354	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20355	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20356	 2	 27.2	 13.24	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20357	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20358	 1	 2.93	 0.27	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20359	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20360	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20361	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20362	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20363	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20364	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20365	 1	 0.0	 0.0	 0.0	 -122.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20366	 1	 1.13	 0.54	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20367	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20368	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20369	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20370	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20371	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20372	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20373	 1	 14.03	 2.77	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20374	 1	 0.0	 0.0	 0.0	 -448.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20375	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20376	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20377	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20378	 1	 0.08	 0.03	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20379	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20380	 1	 2.59	 0.35	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20381	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20382	 1	 5.38	 0.96	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20383	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20384	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20385	 2	 0.1	 0.05	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20386	 1	 0.22	 0.03	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20387	 1	 0.0	 0.0	 0.0	 -1322.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20388	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20389	 1	 2.83	 0.42	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20390	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20391	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20392	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	20393	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20394	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20395	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20396	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20397	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20398	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20399	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20400	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20401	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20402	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20403	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20404	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20405	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20406	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20407	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20408	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20409	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20410	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20411	 1	 1.19	 0.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20412	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20413	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	20414	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20415	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20416	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20417	 1	 4.07	 1.13	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20418	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20419	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20420	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20421	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20422	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20423	 1	 0.0	 0.0	 0.0	 -660.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20424	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20425	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20426	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20427	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20428	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20429	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20430	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20431	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20432	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20433	 1	 0.0	 0.0	 0.0	 27.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20434	 1	 1.77	 0.34	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20435	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20436	 1	 0.0	 0.0	 0.0	 -1054.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20437	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20438	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20439	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20440	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20441	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20442	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20443	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20444	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20445	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20446	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20447	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20448	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20449	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20450	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20451	 1	 9.07	 1.35	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20452	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20453	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20454	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20455	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20456	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20457	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20458	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20459	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20460	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20461	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20462	 2	 1.08	 0.19	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20463	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20464	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20465	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20466	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20467	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20468	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20469	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20470	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20471	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20472	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20473	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20474	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20475	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20476	 1	 0.0	 0.0	 0.0	 -306.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20477	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20478	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20479	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20480	 1	 0.0	 0.0	 0.0	 -196.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20481	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20482	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20483	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	20484	 1	 0.0	 0.0	 0.0	 -282.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20485	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20486	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20487	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20488	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20489	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20490	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20491	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20492	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20493	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20494	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20495	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20496	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20497	 1	 0.0	 0.0	 0.0	 63.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20498	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20499	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20500	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20501	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20502	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20503	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20504	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20505	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20506	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20507	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20508	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20509	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20510	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20511	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20512	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	20513	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20514	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20515	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20516	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20517	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	20518	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20519	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20520	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20521	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20522	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20523	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20524	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20525	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20526	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20527	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20528	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20529	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20530	 2	 0.0	 0.0	 0.0	 -350.0	 3	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	20531	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20532	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20533	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20534	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20535	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20536	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20537	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20538	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20539	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20540	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	20541	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20542	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	20543	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	20544	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	20545	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21000	 1	 17.92	 0.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21001	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21002	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21003	 1	 33.96	 5.74	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21004	 1	 30.04	 6.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21005	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21006	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21007	 1	 26.78	 5.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21008	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21009	 1	 25.68	 11.51	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21010	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21011	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21012	 1	 25.68	 3.03	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21013	 1	 45.19	 10.31	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21014	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21015	 1	 33.28	 13.01	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21016	 1	 1.51	 0.37	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21017	 1	 29.57	 11.26	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21018	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21019	 1	 52.24	 4.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21020	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21021	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21022	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21023	 1	 40.65	 4.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21024	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21025	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21026	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21027	 1	 40.65	 11.76	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21028	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21029	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21030	 1	 36.55	 21.51	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21031	 1	 35.42	 1.93	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21032	 1	 38.85	 4.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21033	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21034	 1	 42.96	 1.99	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21035	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21036	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21037	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21038	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21039	 1	 35.78	 7.66	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21040	 1	 35.78	 6.78	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21041	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21042	 1	 38.52	 17.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21043	 1	 48.72	 25.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21044	 1	 15.3	 3.64	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21045	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21046	 1	 12.69	 2.83	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21047	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21048	 1	 27.27	 11.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21049	 1	 24.47	 6.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21050	 1	 40.68	 5.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21051	 1	 29.84	 11.65	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21052	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21053	 1	 27.45	 4.71	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21054	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21055	 1	 24.54	 10.68	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21056	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21057	 1	 33.63	 15.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21058	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21059	 1	 33.63	 13.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21060	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21061	 1	 26.14	 12.19	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21062	 1	 35.31	 7.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21063	 1	 19.52	 13.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21064	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21065	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21066	 1	 30.9	 14.71	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21067	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21068	 1	 32.43	 3.38	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21069	 1	 16.66	 5.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21070	 1	 37.04	 14.42	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21071	 1	 41.76	 12.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21072	 1	 37.08	 12.44	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21073	 1	 37.08	 8.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21074	 1	 11.33	 3.06	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21075	 1	 24.45	 6.54	 0.0	 34.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21076	 1	 39.33	 21.23	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21077	 1	 39.33	 3.75	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21078	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21079	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21080	 1	 50.42	 8.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21081	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21082	 1	 50.42	 10.93	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21083	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21084	 1	 25.32	 13.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21085	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21086	 1	 25.32	 6.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21087	 1	 54.83	 7.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21088	 1	 54.83	 10.42	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21089	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21090	 1	 33.57	 15.96	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21091	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21092	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21093	 1	 38.81	 14.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21094	 1	 31.85	 6.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21095	 1	 31.85	 8.96	 0.0	 73.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21096	 1	 22.45	 4.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21097	 1	 54.03	 19.12	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21098	 1	 34.49	 5.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21099	 1	 34.72	 7.93	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21100	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21101	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21102	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21103	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21104	 1	 64.04	 37.24	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21105	 1	 35.25	 4.46	 0.0	 120.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21106	 1	 50.02	 26.07	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21107	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21108	 1	 79.03	 12.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21109	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21110	 1	 47.64	 22.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21111	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21112	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21113	 1	 47.64	 12.05	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21114	 1	 47.64	 12.71	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21115	 1	 25.42	 13.6	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21116	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21117	 1	 54.06	 12.6	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21118	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21119	 1	 29.72	 5.89	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21120	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21121	 1	 105.83	 27.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21122	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	21123	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21124	 1	 28.01	 10.21	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21125	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21126	 1	 37.02	 19.14	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21127	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21128	 1	 37.02	 8.46	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21129	 1	 85.13	 20.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21130	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21131	 1	 80.1	 16.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21132	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21133	 1	 57.58	 14.82	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21134	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21135	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21136	 1	 0.0	 0.0	 0.0	 107.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21137	 1	 57.58	 26.92	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21138	 1	 23.45	 6.95	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21139	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21140	 1	 86.85	 26.69	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21141	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21142	 1	 62.4	 16.12	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21143	 1	 36.72	 7.76	 0.0	 118.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21144	 1	 33.16	 0.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21145	 1	 23.61	 6.19	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21146	 1	 38.76	 4.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21147	 1	 23.94	 3.95	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21148	 1	 55.38	 10.69	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21149	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21150	 1	 26.46	 5.2	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21151	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21152	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21153	 1	 26.46	 18.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21154	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21155	 1	 36.66	 11.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21156	 1	 36.66	 4.76	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21157	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21158	 1	 5.47	 2.78	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21159	 1	 43.17	 8.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21160	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21161	 1	 59.92	 31.5	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21162	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21163	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21164	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21165	 1	 89.55	 32.59	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21166	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21167	 1	 53.87	 26.9	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21168	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21169	 1	 54.23	 7.39	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21170	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21171	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21172	 1	 24.57	 2.16	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21173	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21174	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21175	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21176	 1	 30.99	 3.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21177	 1	 24.47	 3.8	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21178	 1	 24.47	 3.57	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21179	 1	 66.05	 16.7	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21180	 1	 35.68	 9.23	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21181	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21182	 1	 79.42	 30.16	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21183	 1	 0.12	 0.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21184	 1	 23.39	 8.99	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21185	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21186	 1	 42.98	 14.51	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21187	 1	 23.29	 4.59	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21188	 1	 23.29	 7.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21189	 1	 35.31	 7.2	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21190	 1	 46.47	 13.05	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21191	 1	 28.76	 3.44	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21192	 1	 69.0	 14.87	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21193	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21194	 1	 48.55	 9.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21195	 1	 21.08	 6.37	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21196	 1	 54.19	 18.08	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21197	 1	 54.19	 23.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21198	 1	 35.72	 11.12	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21199	 1	 26.25	 8.45	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21200	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21201	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21202	 1	 26.25	 6.64	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21203	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21204	 1	 53.77	 8.68	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21205	 1	 35.43	 9.68	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21206	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21207	 1	 37.07	 4.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21208	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21209	 1	 43.37	 13.25	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21210	 1	 19.77	 5.69	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21211	 1	 37.51	 7.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21212	 1	 31.88	 1.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21213	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21214	 1	 32.21	 13.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21215	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21216	 1	 24.48	 4.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21217	 1	 33.0	 2.37	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21218	 1	 34.76	 20.9	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21219	 1	 26.36	 8.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21220	 1	 26.36	 7.81	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21221	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21222	 1	 60.15	 34.9	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21223	 1	 60.15	 6.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21224	 1	 22.97	 4.87	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21225	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21226	 1	 28.88	 1.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21227	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21228	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21229	 1	 32.62	 25.05	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21230	 1	 12.76	 3.39	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21231	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21232	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21233	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21234	 1	 63.61	 13.44	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21235	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21236	 1	 26.89	 4.15	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21237	 1	 28.22	 4.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21238	 1	 45.26	 9.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21239	 1	 45.26	 16.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21240	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21241	 1	 49.92	 6.47	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21242	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21243	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21244	 1	 25.5	 4.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21245	 1	 25.5	 11.23	 0.0	 142.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21246	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21247	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21248	 1	 32.91	 3.24	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21249	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21250	 1	 32.91	 5.12	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21251	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21252	 1	 47.74	 5.52	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21253	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21254	 1	 47.74	 13.2	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21255	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21256	 1	 27.85	 8.82	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21257	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21258	 1	 27.85	 7.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21259	 1	 31.81	 9.58	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21260	 1	 28.26	 5.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21261	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21262	 1	 55.15	 14.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21263	 1	 36.47	 12.56	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21264	 1	 36.47	 4.75	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21265	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21266	 1	 28.13	 9.28	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21267	 1	 41.0	 9.01	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21268	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21269	 1	 41.0	 9.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21270	 1	 37.03	 4.06	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21271	 1	 35.11	 20.07	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21272	 1	 33.74	 13.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21273	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21274	 1	 30.16	 4.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21275	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21276	 1	 57.12	 12.62	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21277	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21278	 1	 42.36	 8.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21279	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21280	 1	 42.36	 8.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21281	 1	 24.38	 5.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21282	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21283	 1	 24.38	 4.63	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21284	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21285	 1	 32.77	 11.08	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21286	 1	 32.77	 22.6	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21287	 1	 24.44	 2.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21288	 1	 24.44	 2.78	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21289	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21290	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21291	 1	 41.94	 13.89	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21292	 1	 30.35	 8.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21293	 1	 26.74	 5.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21294	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21295	 1	 26.74	 3.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21296	 1	 35.99	 6.45	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21297	 1	 34.7	 2.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21298	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21299	 1	 41.74	 1.32	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21300	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21301	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21302	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21303	 1	 43.24	 13.56	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21304	 1	 40.92	 9.21	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21305	 1	 40.92	 2.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21306	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21307	 1	 27.41	 6.64	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21308	 1	 24.18	 2.88	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21309	 1	 30.73	 8.25	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21310	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21311	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21312	 1	 30.73	 7.93	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21313	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21314	 1	 40.29	 14.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21315	 1	 29.7	 7.62	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21316	 1	 29.7	 0.04	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21317	 1	 55.47	 15.05	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21318	 1	 55.47	 13.2	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21319	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21320	 1	 54.65	 4.82	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21321	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21322	 1	 54.65	 8.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21323	 1	 16.48	 5.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21324	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21325	 1	 37.99	 14.65	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21326	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21327	 1	 73.1	 24.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21328	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21329	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21330	 1	 30.21	 11.59	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21331	 1	 30.21	 16.11	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21332	 1	 23.93	 7.11	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21333	 1	 36.5	 6.46	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21334	 1	 25.52	 2.94	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21335	 1	 25.52	 4.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21336	 1	 29.94	 5.38	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21337	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21338	 1	 13.2	 3.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21339	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21340	 1	 65.72	 20.45	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21341	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21342	 1	 65.72	 23.03	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21343	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21344	 1	 27.56	 3.94	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21345	 1	 27.56	 12.69	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21346	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21347	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21348	 1	 33.49	 5.38	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21349	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21350	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21351	 1	 33.49	 10.3	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21352	 1	 36.07	 10.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21353	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21354	 1	 22.89	 4.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21355	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21356	 1	 48.86	 6.16	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21357	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21358	 1	 48.86	 15.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21359	 1	 38.32	 3.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21360	 1	 38.32	 6.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21361	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21362	 1	 42.73	 13.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21363	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21364	 1	 41.13	 5.45	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21365	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21366	 1	 30.94	 1.15	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21367	 1	 30.94	 14.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21368	 1	 24.1	 12.22	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21369	 1	 24.1	 6.11	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21370	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21371	 1	 26.02	 14.87	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21372	 1	 26.8	 5.7	 0.0	 26.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21373	 1	 0.0	 0.0	 0.0	 70.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21374	 1	 62.56	 38.93	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21375	 1	 64.23	 4.82	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21376	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21377	 1	 38.24	 12.06	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21378	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21379	 1	 34.64	 7.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21380	 1	 0.0	 0.0	 0.0	 118.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21381	 1	 26.55	 6.76	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21382	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21383	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21384	 1	 56.45	 11.77	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21385	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21386	 1	 6.83	 3.15	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21387	 1	 62.35	 16.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21388	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21389	 1	 62.35	 0.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21390	 1	 38.82	 14.94	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21391	 1	 34.85	 13.56	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21392	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21393	 1	 23.24	 8.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21394	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21395	 1	 27.99	 8.89	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21396	 1	 27.99	 6.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21397	 1	 32.76	 3.53	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21398	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21399	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21400	 1	 46.38	 7.21	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21401	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21402	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21403	 1	 25.04	 4.4	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21404	 1	 29.45	 8.91	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21405	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21406	 1	 48.89	 1.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21407	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21408	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21409	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21410	 1	 48.89	 20.41	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21411	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21412	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21413	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21414	 1	 14.6	 5.31	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21415	 1	 23.02	 3.44	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21416	 1	 61.91	 3.71	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21417	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21418	 1	 61.91	 9.76	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21419	 1	 31.37	 8.92	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21420	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21421	 1	 31.37	 6.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21422	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21423	 1	 42.06	 5.54	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21424	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21425	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21426	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21427	 1	 55.03	 18.56	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21428	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21429	 1	 55.03	 17.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21430	 1	 27.06	 2.27	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21431	 1	 27.06	 3.74	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21432	 1	 37.12	 5.73	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21433	 1	 37.12	 15.35	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21434	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21435	 1	 40.73	 14.11	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21436	 1	 40.73	 19.37	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21437	 1	 16.45	 7.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21438	 1	 32.33	 7.75	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21439	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21440	 1	 32.33	 1.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21441	 1	 27.48	 8.93	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21442	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21443	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21444	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21445	 1	 31.35	 9.47	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21446	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21447	 1	 18.28	 5.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21448	 1	 25.44	 8.98	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21449	 1	 25.44	 8.99	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21450	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21451	 1	 22.58	 4.67	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21452	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21453	 1	 22.58	 2.18	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21454	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21455	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21456	 1	 42.37	 2.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21457	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21458	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21459	 1	 42.37	 21.63	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21460	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	21461	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21462	 1	 58.87	 2.78	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21463	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21464	 1	 58.59	 6.42	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21465	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21466	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21467	 1	 27.94	 4.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21468	 1	 27.94	 10.09	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21469	 1	 34.68	 2.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21470	 1	 34.68	 16.08	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21471	 1	 43.15	 23.01	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21472	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21473	 1	 41.41	 9.72	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21474	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21475	 1	 40.41	 4.79	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21476	 1	 45.03	 15.96	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21477	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21478	 1	 45.03	 9.9	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21479	 1	 33.71	 3.51	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21480	 1	 50.78	 6.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21481	 1	 50.78	 14.71	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21482	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21483	 1	 50.98	 4.29	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21484	 1	 25.71	 6.78	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21485	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21486	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21487	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21488	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21489	 1	 25.71	 7.92	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21490	 1	 46.75	 18.59	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21491	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21492	 1	 50.48	 6.12	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21493	 1	 51.6	 11.38	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21494	 1	 28.74	 8.51	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21495	 1	 50.33	 19.03	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21496	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21497	 1	 81.69	 19.72	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21498	 1	 43.15	 20.83	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21499	 1	 22.29	 4.64	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21500	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21501	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21502	 1	 60.25	 5.48	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21503	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21504	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21505	 1	 60.25	 3.21	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21506	 1	 22.86	 8.33	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21507	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	21508	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	21509	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21510	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21511	 1	 27.76	 8.67	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21512	 1	 46.35	 4.76	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21513	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21514	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21515	 1	 46.35	 18.95	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21516	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21517	 1	 38.69	 3.07	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21518	 1	 38.69	 3.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21519	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21520	 1	 36.8	 10.9	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21521	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21522	 1	 64.55	 16.27	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21523	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21524	 1	 33.71	 20.49	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21525	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21526	 1	 33.71	 10.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21527	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21528	 1	 50.89	 8.45	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21529	 1	 50.89	 7.37	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21530	 1	 56.15	 5.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21531	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21532	 1	 56.01	 12.69	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21533	 1	 52.62	 20.21	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21534	 1	 64.77	 12.96	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21535	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21536	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21537	 1	 56.2	 17.8	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21538	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21539	 1	 56.2	 7.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21540	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21541	 1	 33.72	 16.97	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21542	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21543	 1	 33.72	 3.1	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21544	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21545	 1	 55.19	 14.78	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21546	 1	 55.19	 17.42	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21547	 1	 17.95	 5.4	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21548	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21549	 1	 41.32	 11.19	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21550	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21551	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21552	 1	 40.98	 3.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21553	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21554	 1	 36.26	 10.58	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21555	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21556	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21557	 1	 37.0	 12.89	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21558	 1	 39.23	 25.66	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21559	 1	 33.18	 15.36	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21560	 1	 33.18	 3.08	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21561	 1	 36.27	 3.95	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21562	 1	 36.27	 2.72	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21563	 1	 34.0	 1.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21564	 1	 36.71	 11.77	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21565	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21566	 1	 32.86	 2.64	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21567	 1	 36.22	 10.64	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21568	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21569	 1	 24.55	 4.96	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21570	 1	 24.55	 4.95	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21571	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21572	 1	 49.14	 11.06	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21573	 1	 49.14	 19.65	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21574	 1	 20.37	 6.33	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21575	 1	 11.55	 3.34	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21576	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21577	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21578	 1	 41.02	 12.86	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21579	 1	 41.02	 7.17	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21580	 1	 24.13	 7.69	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21581	 1	 42.21	 22.26	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21582	 1	 42.21	 9.12	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21583	 1	 51.61	 3.14	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21584	 1	 51.61	 9.59	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21585	 1	 27.81	 10.02	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21586	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21587	 1	 27.81	 9.86	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21588	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21589	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21590	 1	 25.1	 2.45	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21591	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21592	 1	 25.1	 6.38	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21593	 1	 0.0	 0.0	 0.0	 -1260.0	 4	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21594	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21595	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21596	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21597	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21598	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21599	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	21600	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21601	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21602	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21603	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21604	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21605	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	21606	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21607	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21608	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21609	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21610	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21611	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21612	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21613	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21614	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21615	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21616	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21617	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21618	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21619	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21620	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21621	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21622	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21623	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21624	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21625	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21626	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21627	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21628	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21629	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21630	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21631	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21632	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21633	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21634	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21635	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21636	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21637	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21638	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21639	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21640	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21641	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21642	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21643	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21644	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21645	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21646	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21647	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21648	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21649	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21650	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21651	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21652	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21653	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	21654	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21655	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21656	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21657	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21658	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21659	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21660	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21661	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21662	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21663	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21664	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21665	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21666	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21667	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21668	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21669	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21670	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21671	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21672	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21673	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21674	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21675	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21676	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21677	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21678	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21679	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21680	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21681	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21682	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21683	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21684	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21685	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21686	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21687	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21688	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21689	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21690	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21691	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21692	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21693	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21694	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21695	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21696	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21697	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21698	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21699	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21700	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21701	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21702	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21703	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21704	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21705	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21706	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21707	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21708	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21709	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21710	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21711	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21712	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21713	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21714	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21715	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21716	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21717	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21718	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21719	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21720	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21721	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21722	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21723	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21724	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21725	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21726	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	21727	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	21728	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21729	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21730	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21731	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21732	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21733	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21734	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21735	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21736	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21737	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21738	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	21739	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21740	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21741	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21742	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21743	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21744	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21745	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21746	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	21747	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21748	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21749	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21750	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	21751	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21752	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21753	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	21754	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21755	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21756	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	21757	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	21758	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21759	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	21760	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23000	 1	 35.21	 15.52	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23001	 1	 27.64	 3.84	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23002	 1	 28.45	 18.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23003	 1	 58.48	 16.41	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23004	 1	 30.02	 15.78	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23005	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23006	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23007	 1	 40.33	 7.09	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23008	 1	 49.48	 13.83	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23009	 1	 49.48	 10.55	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23010	 1	 51.96	 8.7	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23011	 1	 62.58	 4.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23012	 1	 13.77	 4.25	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23013	 1	 60.57	 18.96	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23014	 1	 53.51	 7.11	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23015	 1	 24.18	 4.51	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23016	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23017	 1	 97.73	 17.88	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23018	 1	 56.19	 9.97	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23019	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23020	 1	 44.87	 9.68	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23021	 1	 44.87	 13.7	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23022	 1	 58.63	 6.52	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23023	 1	 58.5	 10.71	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23024	 1	 28.27	 6.54	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23025	 1	 31.58	 5.16	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23026	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23027	 1	 25.38	 7.07	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23028	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23029	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23030	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23031	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23032	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23033	 1	 58.39	 7.25	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23034	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23035	 1	 44.55	 17.78	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23036	 1	 51.24	 22.07	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23037	 1	 3.01	 1.51	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23038	 1	 24.37	 4.04	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23039	 1	 40.08	 10.83	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23040	 1	 28.25	 6.19	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23041	 1	 43.17	 15.93	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23042	 1	 43.17	 7.42	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23043	 1	 25.01	 5.96	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23044	 1	 2.78	 0.19	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23045	 1	 25.01	 7.04	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23046	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23047	 1	 32.14	 8.01	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23048	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23049	 1	 34.26	 1.12	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23050	 1	 35.11	 2.29	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23051	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23052	 1	 35.11	 10.88	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23053	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23054	 1	 28.4	 10.97	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23055	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23056	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23057	 1	 28.4	 3.47	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23058	 1	 26.02	 4.66	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23059	 1	 45.43	 8.6	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23060	 1	 24.63	 5.78	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23061	 1	 25.21	 4.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23062	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23063	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23064	 1	 38.41	 9.45	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23065	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23066	 1	 72.67	 20.56	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23067	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23068	 1	 21.08	 3.81	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23069	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23070	 1	 49.4	 25.59	 0.0	 102.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23071	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23072	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23073	 1	 42.45	 14.33	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23074	 1	 42.45	 12.65	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23075	 1	 29.84	 3.3	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23076	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23077	 1	 28.5	 3.4	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23078	 1	 28.5	 8.96	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23079	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23080	 1	 50.68	 8.64	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23081	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23082	 1	 29.1	 5.3	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23083	 1	 45.94	 15.35	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23084	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23085	 1	 70.45	 17.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23086	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23087	 1	 23.07	 8.16	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23088	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23089	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23090	 1	 41.81	 5.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23091	 1	 41.81	 9.58	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23092	 1	 22.28	 6.21	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23093	 1	 38.48	 8.53	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23094	 1	 45.67	 21.14	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23095	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23096	 1	 73.29	 18.63	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23097	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23098	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23099	 1	 75.33	 26.81	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23100	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23101	 1	 41.71	 20.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23102	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23103	 1	 13.18	 1.83	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23104	 1	 37.08	 6.62	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23105	 1	 20.39	 5.86	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23106	 1	 32.56	 11.83	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23107	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23108	 1	 32.56	 2.99	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23109	 1	 27.59	 3.24	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23110	 1	 34.9	 21.02	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23111	 1	 38.55	 9.57	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23112	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23113	 1	 23.43	 0.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23114	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23115	 1	 27.85	 8.46	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23116	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23117	 1	 60.33	 21.14	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23118	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23119	 1	 35.61	 15.48	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23120	 1	 28.31	 10.59	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23121	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23122	 1	 35.01	 13.65	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23123	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23124	 1	 33.37	 7.04	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23125	 1	 27.72	 1.99	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23126	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23127	 1	 16.8	 0.89	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23128	 1	 19.58	 8.58	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23129	 1	 25.66	 3.07	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23130	 1	 17.25	 5.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23131	 1	 29.67	 2.05	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23132	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23133	 1	 29.67	 11.47	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23134	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23135	 1	 27.72	 3.8	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23136	 1	 17.65	 6.43	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23137	 1	 21.38	 2.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23138	 1	 35.11	 1.4	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23139	 1	 30.54	 3.45	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23140	 1	 30.54	 11.69	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23141	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	23142	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	23143	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23144	 1	 11.61	 4.58	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23145	 1	 44.05	 10.74	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23146	 1	 41.76	 17.35	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23147	 1	 16.01	 3.2	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23148	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23149	 1	 42.9	 12.51	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23150	 1	 33.97	 11.01	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23151	 1	 33.97	 10.38	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23152	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23153	 1	 53.87	 5.67	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23154	 1	 27.95	 6.27	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23155	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23156	 1	 44.16	 6.25	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23157	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23158	 1	 44.16	 17.02	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23159	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23160	 1	 25.14	 4.44	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23161	 1	 27.1	 7.56	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23162	 1	 36.98	 12.11	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23163	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23164	 1	 36.98	 15.19	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23165	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23166	 1	 45.87	 3.67	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23167	 1	 45.87	 13.08	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23168	 1	 74.95	 20.83	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23169	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23170	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23171	 1	 21.43	 5.14	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23172	 1	 33.06	 19.62	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23173	 1	 66.09	 22.94	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23174	 1	 49.1	 15.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23175	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23176	 1	 33.67	 6.37	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23177	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23178	 1	 33.03	 13.68	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23179	 1	 24.44	 6.21	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23180	 1	 53.12	 7.91	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23181	 1	 36.63	 18.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23182	 1	 49.16	 23.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23183	 1	 40.67	 5.18	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23184	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23185	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23186	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	23187	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23188	 1	 63.22	 29.72	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23189	 1	 54.36	 19.55	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23190	 1	 17.89	 1.87	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23191	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23192	 1	 43.75	 8.02	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23193	 1	 43.75	 7.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23194	 1	 27.21	 5.62	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23195	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23196	 1	 55.11	 12.98	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23197	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23198	 1	 4.73	 1.12	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23199	 1	 31.82	 24.43	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23200	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23201	 1	 67.8	 27.24	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23202	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23203	 1	 64.64	 19.47	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23204	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23205	 1	 64.64	 19.38	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23206	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23207	 1	 41.05	 12.46	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23208	 1	 41.05	 9.79	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23209	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23210	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23211	 1	 27.21	 13.12	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23212	 1	 27.21	 9.5	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23213	 1	 18.49	 4.06	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23214	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23215	 1	 58.74	 19.46	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23216	 1	 58.74	 4.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23217	 1	 26.07	 4.1	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23218	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23219	 1	 36.03	 16.15	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23220	 1	 46.94	 9.02	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23221	 1	 28.69	 4.43	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23222	 1	 36.19	 6.9	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23223	 1	 31.5	 5.47	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23224	 1	 26.8	 10.99	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23225	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23226	 1	 26.8	 6.92	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23227	 1	 52.15	 20.24	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23228	 1	 45.55	 18.63	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23229	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23230	 1	 93.11	 24.78	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23231	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23232	 1	 58.44	 20.03	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23233	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23234	 1	 62.75	 10.04	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23235	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23236	 1	 62.75	 12.95	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23237	 1	 16.8	 4.23	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23238	 1	 20.25	 8.11	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23239	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23240	 1	 18.35	 5.63	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23241	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23242	 1	 35.13	 4.78	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23243	 1	 35.13	 4.09	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23244	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23245	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23246	 1	 19.09	 2.75	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23247	 1	 29.26	 9.54	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23248	 1	 26.75	 7.66	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23249	 1	 46.27	 10.72	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23250	 1	 31.0	 6.86	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23251	 1	 53.2	 10.21	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23252	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23253	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23254	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23255	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23256	 1	 51.66	 14.61	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23257	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23258	 1	 55.7	 24.68	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23259	 1	 19.17	 3.99	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23260	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23261	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23262	 1	 26.19	 9.68	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23263	 1	 19.21	 3.12	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23264	 1	 14.61	 4.39	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23265	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23266	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23267	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23268	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23269	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23270	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23271	 1	 35.54	 13.15	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23272	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23273	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23274	 1	 13.25	 2.78	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23275	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23276	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23277	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23278	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23279	 1	 12.61	 5.24	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23280	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23281	 2	 4.87	 1.86	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23282	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23283	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23284	 1	 0.0	 0.0	 0.0	 -966.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23285	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23286	 1	 1.15	 0.16	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23287	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23288	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	23289	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	23290	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23291	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23292	 1	 2.45	 0.77	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23293	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23294	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23295	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23296	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23297	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23298	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23299	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23300	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23301	 1	 2.43	 1.31	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23302	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23303	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23304	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23305	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23306	 2	 5.71	 0.93	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23307	 2	 0.84	 0.16	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23308	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23309	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23310	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23311	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23312	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23313	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23314	 1	 3.04	 0.52	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23315	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23316	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23317	 1	 10.66	 3.11	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23318	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23319	 2	 1.93	 0.85	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23320	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23321	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23322	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23323	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23324	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	23325	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23326	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	23327	 1	 1.43	 0.42	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23328	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23329	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23330	 1	 0.91	 0.11	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23331	 1	 0.0	 0.0	 0.0	 -80.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23332	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23333	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23334	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23335	 1	 8.83	 0.96	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23336	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23337	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	23338	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23339	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23340	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23341	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23342	 1	 27.83	 13.73	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23343	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23344	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23345	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23346	 2	 28.29	 2.37	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23347	 2	 7.7	 1.41	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23348	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23349	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23350	 1	 37.08	 17.77	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23351	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23352	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23353	 2	 1.21	 0.27	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23354	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23355	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23356	 1	 16.1	 8.17	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23357	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23358	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23359	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23360	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23361	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23362	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23363	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23364	 1	 3.17	 0.41	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23365	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23366	 2	 12.43	 8.82	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23367	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23368	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23369	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23370	 2	 7.48	 3.42	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23371	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23372	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23373	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23374	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23375	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23376	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23377	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23378	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23379	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23380	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	23381	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23382	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23383	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23384	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23385	 2	 0.12	 0.01	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23386	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23387	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23388	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23389	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23390	 2	 11.74	 2.76	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23391	 1	 0.0	 0.0	 0.0	 -153.5	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23392	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23393	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	23394	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23395	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23396	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23397	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23398	 1	 0.22	 0.04	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23399	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23400	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	23401	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23402	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23403	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23404	 1	 7.87	 0.86	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23405	 2	 1.07	 0.55	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23406	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23407	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23408	 1	 13.16	 4.44	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23409	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23410	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23411	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23412	 1	 0.0	 0.0	 0.0	 -908.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23413	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23414	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23415	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23416	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23417	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	23418	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	23419	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23420	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23421	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23422	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23423	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23424	 1	 0.0	 0.0	 0.0	 -52.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23425	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23426	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23427	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	23428	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23429	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23430	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23431	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23432	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23433	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23434	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23435	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23436	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23437	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23438	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23439	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23440	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23441	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23442	 1	 0.0	 0.0	 0.0	 -218.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23443	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23444	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23445	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23446	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23447	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23448	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23449	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23450	 1	 0.0	 0.0	 0.0	 -360.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23451	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23452	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23453	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23454	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23455	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23456	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23457	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23458	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23459	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23460	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23461	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23462	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23463	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23464	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23465	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23466	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23467	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23468	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23469	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23470	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23471	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23472	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23473	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23474	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23475	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23476	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23477	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23478	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23479	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23480	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23481	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23482	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23483	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23484	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	23485	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	23486	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23487	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23488	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23489	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23490	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23491	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23492	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23493	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23494	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23495	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23496	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23497	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23498	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23499	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23500	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23501	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23502	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23503	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23504	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23505	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23506	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	23507	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	23508	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23509	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	23510	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23511	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23512	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	23513	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	23514	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	23515	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25000	 1	 12.31	 3.88	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25001	 1	 31.12	 10.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25002	 1	 19.42	 2.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25003	 1	 16.48	 7.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25004	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25005	 1	 31.9	 4.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25006	 1	 31.9	 9.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25007	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25008	 1	 39.34	 6.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25009	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25010	 1	 39.34	 13.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25011	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25012	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25013	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25014	 1	 30.73	 6.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25015	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25016	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25017	 1	 28.24	 4.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25018	 1	 16.05	 2.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25019	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25020	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25021	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25022	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25023	 1	 23.69	 1.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25024	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25025	 1	 25.23	 2.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25026	 1	 25.23	 6.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25027	 1	 12.8	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25028	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25029	 1	 34.64	 0.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25030	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25031	 1	 49.89	 15.7	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25032	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25033	 1	 62.8	 23.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25034	 1	 30.79	 10.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25035	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25036	 1	 25.57	 6.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25037	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25038	 1	 43.8	 5.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25039	 1	 37.52	 10.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25040	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25041	 1	 48.62	 30.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25042	 1	 48.62	 4.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25043	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25044	 1	 32.8	 3.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25045	 1	 34.26	 5.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25046	 1	 9.91	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25047	 1	 26.93	 4.56	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25048	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25049	 1	 47.9	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25050	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	25051	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25052	 1	 47.9	 18.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25053	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25054	 1	 31.27	 8.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25055	 1	 47.42	 4.88	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25056	 1	 30.29	 14.7	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25057	 1	 28.51	 9.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25058	 1	 28.51	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25059	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25060	 1	 36.45	 12.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25061	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25062	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25063	 1	 21.61	 1.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25064	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25065	 1	 48.51	 8.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25066	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25067	 1	 24.44	 6.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25068	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25069	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25070	 1	 24.44	 18.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25071	 1	 31.23	 5.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25072	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25073	 1	 37.06	 6.93	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25074	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25075	 1	 10.99	 3.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25076	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25077	 1	 39.39	 6.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25078	 1	 40.6	 11.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25079	 1	 7.52	 3.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25080	 1	 24.96	 9.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25081	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25082	 1	 45.43	 16.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25083	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25084	 1	 45.43	 9.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25085	 1	 50.09	 9.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25086	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25087	 1	 50.09	 8.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25088	 1	 24.34	 1.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25089	 1	 37.52	 17.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25090	 1	 37.52	 17.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25091	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25092	 1	 36.75	 8.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25093	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25094	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25095	 1	 36.75	 7.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25096	 1	 78.39	 33.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25097	 1	 53.43	 11.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25098	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25099	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25100	 1	 26.23	 12.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25101	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25102	 1	 31.82	 8.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25103	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25104	 1	 49.64	 15.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25105	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25106	 1	 49.64	 12.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25107	 1	 49.64	 7.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25108	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25109	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25110	 1	 73.11	 26.53	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25111	 1	 51.07	 6.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25112	 1	 42.55	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25113	 1	 29.53	 9.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25114	 1	 29.53	 8.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25115	 1	 39.21	 13.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25116	 1	 38.61	 9.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25117	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25118	 1	 52.57	 9.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25119	 1	 52.57	 8.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25120	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25121	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25122	 1	 39.2	 14.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25123	 1	 39.2	 12.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25124	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25126	 1	 15.97	 3.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25127	 1	 43.86	 15.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25128	 1	 43.86	 5.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25129	 1	 31.16	 5.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25130	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25131	 1	 31.16	 10.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25132	 1	 33.84	 14.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25133	 1	 33.84	 13.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25134	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25135	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25136	 1	 39.85	 17.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25137	 1	 39.85	 12.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25138	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25139	 1	 49.59	 6.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25140	 1	 49.59	 15.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25141	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25142	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25143	 1	 49.59	 26.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25144	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25145	 1	 31.48	 9.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25146	 1	 32.78	 12.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25147	 1	 32.78	 11.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25148	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25149	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25150	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25151	 1	 31.2	 7.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25152	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25153	 1	 36.79	 9.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25154	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25155	 1	 38.16	 15.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25156	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25157	 1	 38.16	 16.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25158	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25159	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25160	 1	 32.61	 10.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25161	 1	 37.69	 21.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25162	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25163	 1	 32.44	 6.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25164	 1	 32.44	 8.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25165	 1	 47.2	 22.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25166	 1	 0.51	 0.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25167	 1	 47.2	 25.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25168	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25169	 1	 58.51	 31.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25170	 1	 58.13	 24.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25171	 1	 65.26	 11.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25172	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25173	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25174	 1	 65.26	 15.94	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25175	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25176	 1	 24.86	 4.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25177	 1	 22.94	 7.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25178	 1	 22.94	 3.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25179	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25180	 1	 26.87	 6.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25181	 1	 26.87	 7.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25182	 1	 3.66	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25183	 1	 48.93	 21.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25184	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25185	 1	 25.85	 6.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25186	 1	 48.93	 19.98	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25187	 1	 23.14	 11.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25188	 1	 23.21	 3.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25189	 1	 44.05	 11.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25190	 1	 36.28	 10.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25191	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25192	 1	 29.34	 5.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25193	 1	 29.34	 10.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25194	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25195	 1	 45.21	 8.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25196	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25197	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25198	 1	 69.38	 24.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25199	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25200	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25201	 1	 35.55	 5.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25202	 1	 35.55	 4.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25203	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25204	 1	 32.9	 8.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25205	 1	 32.9	 6.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25206	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25207	 1	 24.17	 4.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25208	 1	 23.27	 9.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25209	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25210	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25211	 1	 23.27	 0.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25212	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25213	 1	 40.55	 7.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25214	 1	 45.42	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25215	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25216	 1	 30.34	 9.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25217	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25218	 1	 30.34	 10.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25219	 1	 24.9	 2.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25220	 1	 26.51	 9.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25221	 1	 26.51	 8.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25222	 1	 41.37	 9.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25223	 1	 66.93	 25.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25224	 1	 0.0	 0.0	 0.0	 42.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25225	 1	 66.93	 15.92	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25226	 1	 11.46	 2.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25227	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25228	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25229	 1	 57.07	 17.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25230	 1	 46.05	 12.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25231	 1	 24.21	 1.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25232	 1	 24.21	 6.94	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25233	 1	 46.57	 8.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25234	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25235	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25236	 1	 72.42	 20.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25237	 1	 30.01	 4.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25238	 1	 30.01	 5.05	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25239	 1	 32.08	 1.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25240	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25241	 1	 31.17	 8.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25242	 1	 44.14	 11.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25243	 1	 31.93	 6.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25244	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25245	 1	 31.93	 11.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25246	 1	 46.4	 10.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25247	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25248	 1	 46.4	 3.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25249	 1	 31.39	 11.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25250	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25251	 1	 31.39	 11.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25252	 1	 54.23	 8.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25253	 1	 54.23	 8.99	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25254	 1	 38.45	 5.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25255	 1	 48.47	 15.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25256	 1	 9.84	 3.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25257	 1	 25.51	 5.56	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25258	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25259	 1	 25.51	 4.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25260	 1	 42.27	 9.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25261	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25262	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25263	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25264	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25265	 1	 44.33	 2.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25266	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25267	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25268	 1	 75.71	 20.61	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25269	 1	 25.62	 9.55	 0.0	 30.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25270	 1	 29.13	 2.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25271	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25272	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25273	 1	 29.13	 7.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25274	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25275	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25276	 1	 76.8	 16.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25277	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25278	 1	 46.03	 7.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25279	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25280	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25281	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25282	 1	 37.93	 5.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25283	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25284	 1	 88.7	 16.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25285	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25286	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25287	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25288	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25289	 1	 113.54	 32.45	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25290	 1	 30.77	 5.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25291	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25292	 1	 42.71	 15.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25293	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25294	 1	 71.3	 24.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25295	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25296	 1	 27.89	 7.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25297	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25298	 1	 35.36	 6.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25299	 1	 60.26	 4.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25300	 1	 12.1	 4.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25301	 1	 49.75	 18.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25302	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25303	 1	 112.63	 49.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25304	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25305	 1	 22.86	 1.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25306	 1	 25.13	 7.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25307	 1	 62.21	 19.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25308	 1	 62.21	 29.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25309	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25310	 1	 62.21	 15.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25311	 1	 35.61	 14.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25312	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25313	 1	 35.53	 4.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25314	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25315	 1	 35.53	 9.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25316	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25317	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25318	 1	 39.13	 6.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25319	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25320	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25321	 1	 31.62	 4.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25322	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25323	 1	 50.71	 9.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25324	 1	 25.13	 11.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25325	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25326	 1	 52.17	 15.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25327	 1	 52.17	 18.39	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25328	 1	 35.11	 9.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25329	 1	 28.59	 4.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25330	 1	 26.13	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25331	 1	 27.27	 5.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25332	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25333	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25334	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25335	 1	 73.76	 14.53	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25336	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25337	 1	 55.64	 12.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25338	 1	 31.76	 5.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25339	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25340	 1	 72.91	 10.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25341	 1	 55.04	 2.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25342	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25343	 1	 55.04	 16.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25344	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25345	 1	 55.04	 9.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25346	 1	 72.43	 25.49	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25347	 1	 33.47	 7.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25348	 1	 36.3	 7.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25349	 1	 36.3	 6.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25350	 1	 36.06	 12.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25351	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25352	 1	 36.06	 10.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25353	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25354	 1	 63.83	 22.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25355	 1	 63.83	 2.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25356	 1	 37.24	 12.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25357	 1	 69.39	 20.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25358	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25359	 1	 43.03	 4.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25360	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25361	 1	 69.85	 20.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25362	 1	 86.75	 44.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25363	 1	 54.75	 12.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25364	 1	 73.69	 2.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25365	 1	 26.47	 11.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25366	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25367	 1	 26.47	 7.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25368	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25369	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25370	 1	 42.84	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25371	 1	 0.97	 0.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25372	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25373	 1	 42.84	 9.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25374	 1	 39.94	 13.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25375	 1	 96.22	 28.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25376	 1	 60.53	 14.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25377	 1	 26.74	 3.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25378	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25379	 1	 31.43	 12.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25380	 1	 33.18	 18.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25381	 1	 33.18	 3.53	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25382	 1	 55.92	 14.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25383	 1	 55.92	 21.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25384	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25385	 1	 94.78	 21.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25386	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25387	 1	 33.01	 11.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25388	 1	 57.01	 13.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25389	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25390	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25391	 1	 27.7	 6.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25392	 1	 25.66	 10.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25393	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25394	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25395	 1	 27.7	 8.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25396	 1	 29.09	 10.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25397	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25398	 1	 34.04	 13.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25399	 1	 58.01	 15.94	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25400	 1	 91.47	 24.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25401	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25402	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25403	 1	 104.81	 29.79	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25404	 1	 57.14	 17.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25405	 1	 23.56	 3.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25406	 1	 40.11	 35.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25407	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25408	 1	 28.89	 3.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25409	 1	 28.89	 7.59	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25410	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25411	 1	 70.92	 17.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25412	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25413	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25414	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25415	 1	 51.87	 9.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25416	 1	 34.03	 5.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25417	 1	 44.38	 14.92	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25418	 1	 44.38	 12.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25419	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25420	 1	 38.86	 20.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25421	 1	 38.01	 5.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25422	 1	 55.96	 14.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25423	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25424	 1	 55.96	 9.14	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25425	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25426	 1	 77.33	 11.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25427	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25428	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25429	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25430	 1	 43.75	 9.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25431	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25432	 1	 43.75	 18.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25433	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25434	 1	 33.91	 1.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25435	 1	 22.91	 2.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25436	 1	 42.74	 9.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25437	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25438	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25439	 1	 139.4	 34.42	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25440	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25441	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25442	 1	 40.64	 4.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25443	 1	 65.32	 9.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25444	 1	 34.76	 3.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25445	 1	 39.12	 8.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25446	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25447	 1	 107.85	 34.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25448	 1	 53.27	 8.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25449	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25450	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25451	 1	 37.53	 6.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25452	 1	 53.87	 0.88	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25453	 1	 66.48	 12.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25454	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25455	 1	 83.41	 16.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25456	 1	 41.01	 9.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25457	 1	 56.05	 27.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25458	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25459	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25460	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25461	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25462	 1	 62.89	 12.92	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25463	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25464	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25465	 1	 31.62	 6.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25466	 1	 36.83	 1.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25467	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25468	 1	 64.82	 21.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25469	 1	 53.7	 22.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25470	 1	 53.7	 10.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25471	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25472	 1	 66.07	 29.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25473	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25474	 1	 105.61	 30.7	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25475	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25476	 1	 59.64	 13.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25477	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25478	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25479	 1	 41.09	 6.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25480	 1	 34.17	 5.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25481	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25482	 1	 63.58	 29.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25483	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25484	 1	 51.53	 14.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25485	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25486	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25487	 1	 51.53	 7.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25488	 1	 61.08	 7.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25489	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25490	 1	 79.99	 8.95	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25491	 1	 48.43	 8.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25492	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25493	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25494	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25495	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25496	 1	 48.43	 6.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25497	 1	 53.24	 12.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25498	 1	 25.66	 4.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25499	 1	 62.34	 25.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25500	 1	 62.34	 16.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25501	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25502	 1	 62.34	 15.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25503	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25504	 1	 23.39	 8.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25505	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25506	 1	 36.86	 13.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25507	 1	 51.4	 17.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25508	 1	 27.32	 14.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25509	 1	 69.49	 21.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25510	 1	 46.1	 10.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25511	 1	 34.03	 3.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25512	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25513	 1	 34.03	 5.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25514	 1	 45.72	 8.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25515	 1	 45.72	 15.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25516	 1	 55.28	 9.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25517	 1	 24.83	 10.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25518	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25519	 1	 24.83	 3.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25520	 1	 28.68	 4.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25521	 1	 44.4	 13.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25522	 1	 44.4	 6.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25523	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25524	 1	 56.12	 11.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25525	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25526	 1	 40.97	 12.52	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25527	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25528	 1	 22.69	 4.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25529	 1	 33.06	 17.43	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25530	 1	 55.75	 14.02	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25531	 1	 14.39	 1.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25532	 1	 45.04	 1.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25533	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25534	 1	 45.04	 13.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25535	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25536	 1	 50.84	 5.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25537	 1	 29.76	 2.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25538	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25539	 1	 30.04	 8.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25540	 1	 43.97	 15.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25541	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25542	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25543	 1	 43.97	 12.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25544	 1	 67.83	 19.28	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25545	 1	 35.41	 12.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25546	 1	 60.02	 11.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25547	 1	 35.38	 10.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25548	 1	 48.33	 18.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25549	 1	 48.33	 7.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25550	 1	 36.5	 14.2	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25551	 1	 62.77	 10.13	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25552	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25553	 1	 62.77	 11.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25554	 1	 78.17	 7.62	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25555	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25556	 1	 41.31	 7.63	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25557	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25558	 1	 37.62	 9.85	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25559	 1	 53.02	 13.03	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25560	 1	 53.02	 15.87	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25561	 1	 56.64	 5.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25562	 1	 56.64	 5.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25563	 1	 56.64	 22.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25564	 1	 56.19	 21.05	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25565	 1	 63.3	 18.61	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25566	 1	 38.16	 15.48	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25567	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25568	 1	 38.16	 17.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25569	 1	 24.63	 10.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25570	 1	 74.23	 33.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25571	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25572	 1	 50.18	 20.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25573	 1	 64.77	 26.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25574	 1	 70.45	 12.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25575	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25576	 1	 80.3	 14.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25577	 1	 56.11	 30.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25578	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25579	 1	 56.11	 11.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25580	 1	 28.33	 9.75	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25581	 1	 28.33	 10.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25582	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25583	 1	 60.77	 43.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25584	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25585	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25586	 1	 60.77	 29.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25587	 1	 85.51	 25.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25588	 1	 21.19	 12.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25589	 1	 48.69	 15.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25590	 1	 48.69	 12.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25591	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25592	 1	 24.73	 16.84	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25593	 1	 23.05	 4.16	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25594	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25595	 1	 93.54	 15.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25596	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25597	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25598	 1	 111.86	 20.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25599	 1	 35.41	 18.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25600	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25601	 1	 35.41	 13.19	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25602	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25603	 1	 36.28	 9.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25604	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25605	 1	 36.28	 7.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25606	 1	 28.56	 3.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25607	 1	 28.35	 1.78	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25608	 1	 27.29	 4.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25609	 1	 34.44	 8.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25610	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25611	 1	 29.47	 7.88	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25612	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25613	 1	 68.64	 21.44	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25614	 1	 67.14	 36.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25615	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25616	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25617	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25618	 1	 97.74	 23.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25619	 1	 32.51	 15.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25620	 1	 59.83	 13.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25621	 1	 28.83	 1.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25622	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25623	 1	 28.83	 3.47	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25624	 1	 43.61	 10.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25625	 1	 38.16	 6.4	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25626	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25627	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25628	 1	 38.16	 19.1	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25629	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25630	 1	 47.46	 21.36	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25631	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25632	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25633	 1	 72.14	 21.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25634	 1	 45.97	 17.08	 0.0	 204.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25635	 1	 45.97	 12.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25636	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25637	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25638	 1	 33.08	 11.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25639	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25640	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25641	 1	 67.44	 24.89	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25642	 1	 67.44	 17.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25643	 1	 23.29	 5.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25644	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25645	 1	 35.76	 1.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25646	 1	 35.76	 3.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25647	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25648	 1	 25.13	 4.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25649	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25650	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25651	 1	 34.41	 7.65	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25652	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25653	 1	 34.41	 13.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25654	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25655	 1	 56.29	 17.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25656	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25657	 1	 79.49	 42.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25658	 1	 34.63	 16.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25659	 1	 77.81	 21.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25660	 1	 56.64	 22.26	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25661	 1	 0.0	 0.0	 0.0	 88.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25662	 1	 56.64	 6.66	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25663	 1	 29.65	 8.93	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25664	 1	 29.65	 7.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25665	 1	 79.18	 16.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25666	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25667	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25668	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25669	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25670	 1	 55.89	 27.17	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25671	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25672	 1	 63.33	 12.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25673	 1	 63.33	 10.6	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25674	 1	 0.0	 0.0	 0.0	 176.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25675	 1	 162.97	 48.67	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25676	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25677	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25678	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25679	 1	 29.86	 7.33	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25680	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25681	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25682	 1	 36.7	 3.18	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25683	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25684	 1	 42.71	 7.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25685	 1	 64.39	 13.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25686	 1	 44.46	 11.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25687	 1	 29.16	 14.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25688	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25689	 1	 26.76	 9.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25690	 1	 30.9	 2.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25691	 1	 30.9	 3.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25692	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25693	 1	 39.51	 10.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25694	 1	 39.51	 14.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25695	 1	 30.69	 5.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25696	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25697	 1	 30.69	 8.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25698	 1	 26.63	 6.24	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25699	 1	 43.19	 8.45	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25700	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25701	 1	 43.19	 11.09	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25702	 1	 28.78	 4.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25703	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25704	 1	 28.78	 14.69	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25705	 1	 28.54	 5.22	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25706	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25707	 1	 28.54	 6.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25708	 1	 36.3	 6.04	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25709	 1	 36.3	 9.31	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25710	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25711	 1	 34.34	 16.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25712	 1	 34.34	 15.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25713	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25714	 1	 106.27	 28.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25715	 1	 55.25	 11.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25716	 1	 35.47	 7.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25717	 1	 35.47	 6.46	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25718	 1	 69.64	 12.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25719	 1	 36.54	 4.41	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25720	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25721	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25722	 1	 59.36	 28.8	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25723	 1	 36.11	 2.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25724	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25725	 1	 27.44	 5.29	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25726	 1	 27.44	 9.11	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25727	 1	 23.46	 2.71	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25728	 1	 48.61	 2.91	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25729	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25730	 1	 92.72	 16.55	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25731	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25732	 1	 69.51	 22.42	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25733	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25734	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25735	 1	 72.57	 24.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25736	 1	 45.94	 7.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25737	 1	 23.47	 14.51	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25738	 1	 23.47	 9.34	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25739	 1	 60.86	 8.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25740	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25741	 1	 60.86	 29.15	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25742	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25743	 1	 40.42	 1.5	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25744	 1	 40.42	 12.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25745	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25746	 1	 51.02	 14.76	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25747	 1	 51.02	 13.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25748	 1	 30.97	 5.73	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25749	 1	 30.97	 23.77	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25750	 1	 27.77	 5.08	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25751	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25752	 1	 27.77	 10.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25753	 1	 40.87	 4.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25754	 1	 40.87	 10.89	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25755	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25756	 1	 29.17	 9.12	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25757	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25758	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25759	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25760	 1	 29.17	 7.5	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25761	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25762	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25763	 1	 35.4	 14.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25764	 1	 30.8	 7.35	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25765	 1	 53.73	 10.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25766	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25767	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25768	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25769	 1	 77.23	 8.43	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25770	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25771	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25772	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25773	 1	 65.25	 52.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25774	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25775	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25776	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25777	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25778	 1	 64.84	 18.35	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25779	 1	 22.82	 5.03	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25780	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25781	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25782	 1	 38.77	 8.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25783	 1	 38.77	 10.3	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25784	 1	 23.57	 6.97	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25785	 1	 23.24	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25786	 1	 23.24	 4.58	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25787	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25788	 1	 41.81	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25789	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25790	 1	 41.81	 5.25	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25791	 1	 16.08	 2.32	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25792	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25793	 1	 29.81	 4.01	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25794	 1	 29.81	 6.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25795	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25796	 1	 31.08	 6.9	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25797	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25798	 1	 31.08	 2.23	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25799	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25800	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25801	 1	 30.78	 4.82	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25802	 1	 29.92	 8.57	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25803	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25804	 1	 64.44	 26.56	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25805	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25806	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25807	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25808	 1	 64.44	 7.64	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25809	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25810	 1	 43.26	 23.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25811	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25812	 1	 43.26	 16.96	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25813	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25814	 1	 32.13	 19.83	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25815	 1	 32.13	 3.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25816	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25817	 1	 29.3	 10.98	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25818	 1	 1.11	 0.38	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25819	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25820	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25821	 1	 29.74	 1.81	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25822	 1	 8.81	 1.68	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25823	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25824	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25825	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25826	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25827	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	25828	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25829	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25830	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25831	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25832	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25833	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25834	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25835	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25836	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25837	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25838	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25839	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25840	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25841	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25842	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25843	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25844	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25845	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25846	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25847	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25848	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25849	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25850	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25851	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25852	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25853	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25854	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25855	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25856	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25857	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25858	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25859	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25860	 1	 0.18	 0.06	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25861	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25862	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25863	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25864	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25865	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25866	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25867	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25868	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25869	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25870	 1	 4.14	 0.54	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25871	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25872	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25873	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25874	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25875	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25876	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25877	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25878	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25879	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25880	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25881	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	25882	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25883	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25884	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25885	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25886	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25887	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25888	 1	 20.26	 10.37	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25889	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25890	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25891	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25892	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25893	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25894	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25895	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25896	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25897	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25898	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25899	 2	 2.06	 0.72	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25900	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25901	 1	 0.0	 0.0	 0.0	 -700.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25902	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25903	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25904	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	25905	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25906	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25907	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25908	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25909	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25910	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25911	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25912	 1	 0.21	 0.07	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25913	 1	 8.34	 3.21	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25914	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25915	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25916	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25917	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25918	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25919	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25920	 1	 29.98	 2.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25921	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25922	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25923	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25924	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25925	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25926	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25927	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25928	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25929	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25930	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25931	 1	 25.13	 8.86	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25932	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	25933	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25934	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25935	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25936	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25937	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25938	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25939	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25940	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25941	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25942	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25943	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25944	 2	 5.28	 0.27	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25945	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25946	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25947	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	25948	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	25949	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25950	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25951	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25952	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25953	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25954	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	25955	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25956	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25957	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25958	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25959	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25960	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25961	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25962	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25963	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	25964	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	25965	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25966	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25967	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25968	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25969	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25970	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25971	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25972	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25973	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25974	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25975	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25976	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25977	 2	 9.84	 1.74	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25978	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25979	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25980	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	25981	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25982	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25983	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25984	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25985	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25986	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25987	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	25988	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25989	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25990	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	25991	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25992	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25993	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	25994	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25995	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	25996	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25997	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25998	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25999	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26000	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26001	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26002	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26003	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26004	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26005	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26006	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26007	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26008	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26009	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26010	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26011	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26012	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26013	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26014	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26015	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26016	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26017	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26018	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26019	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26020	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26021	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26022	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26023	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26024	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26025	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26026	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26027	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26028	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26029	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26030	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26031	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26032	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26033	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26034	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26035	 1	 0.0	 0.0	 0.0	 -494.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26036	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26037	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26038	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26039	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26040	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26041	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26042	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	26043	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26044	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26045	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26046	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26047	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26048	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26049	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26050	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26051	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26052	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26053	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26054	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26055	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26056	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26057	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26058	 1	 0.0	 0.0	 0.0	 840.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26059	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26060	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26061	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26062	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26063	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26064	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26065	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26066	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	26067	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	26068	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26069	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26070	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26071	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26072	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26073	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26074	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26076	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26077	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26078	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26079	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26080	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26081	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26082	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26083	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26084	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26085	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26086	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26087	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26088	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26089	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26090	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26091	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26092	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26093	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26094	 1	 0.0	 0.0	 0.0	 1780.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26095	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26096	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26097	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26098	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26099	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26100	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26101	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	26102	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26103	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26104	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26105	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26106	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26107	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26108	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26109	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26110	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26111	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26112	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26113	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26114	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26115	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26116	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26117	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26118	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26119	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26120	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26121	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26122	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26123	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26124	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26125	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26126	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26127	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26128	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26129	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26130	 1	 0.0	 0.0	 0.0	 -504.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26131	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26132	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26133	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	26134	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26135	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26136	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26137	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26138	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26139	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26140	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26141	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26142	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26143	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26144	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26145	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26146	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	26147	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26148	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26149	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26150	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26151	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26152	 1	 0.0	 0.0	 0.0	 483.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26153	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26154	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26155	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26156	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26157	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26158	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26159	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	26160	 1	 0.0	 0.0	 0.0	 -1842.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26161	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26162	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26163	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26164	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26165	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26166	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26167	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26168	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26169	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26170	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26171	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26172	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26173	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26174	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26175	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26176	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26177	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26178	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26179	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26180	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26181	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	26182	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26183	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26184	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26185	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26186	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26187	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26188	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26189	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26190	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26191	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26192	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26193	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26194	 1	 0.0	 0.0	 0.0	 -534.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26195	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26196	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26197	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26198	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26199	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26200	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26201	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26202	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26203	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	26204	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26205	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26206	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26207	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26208	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26209	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26210	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26211	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26212	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	26213	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26214	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26215	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26216	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26217	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26218	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26219	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26220	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26221	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26222	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26223	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26224	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26225	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26226	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	26227	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	26228	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26229	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26230	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26231	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	26232	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	26233	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26234	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	26235	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26236	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26237	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	26238	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28000	 1	 39.15	 6.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28001	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28002	 1	 70.18	 13.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28003	 1	 70.0	 10.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28004	 1	 40.6	 13.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28005	 1	 40.6	 10.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28006	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28007	 1	 51.52	 3.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28008	 1	 51.52	 7.07	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28009	 1	 26.95	 11.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28010	 1	 53.85	 18.94	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28011	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28012	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28013	 1	 80.8	 5.25	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28014	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28015	 1	 53.85	 5.67	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28016	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28017	 1	 63.28	 10.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28018	 1	 29.56	 7.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28019	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28020	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28021	 1	 29.56	 3.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28022	 1	 51.55	 16.88	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28023	 1	 0.0	 0.0	 0.0	 -1236.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28024	 1	 80.77	 6.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28025	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28026	 1	 51.55	 7.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28027	 1	 43.75	 7.34	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28028	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28029	 1	 49.7	 8.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28030	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28031	 1	 49.7	 14.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28032	 1	 46.59	 20.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28033	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28034	 1	 46.59	 1.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28035	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28036	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28037	 1	 55.86	 7.72	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28038	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28039	 1	 55.86	 31.6	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28040	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28041	 1	 50.4	 3.4	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28042	 1	 51.22	 17.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28043	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28044	 1	 38.97	 6.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28045	 1	 48.67	 6.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28046	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28047	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28048	 1	 79.99	 34.27	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28049	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28050	 1	 10.41	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28051	 1	 40.69	 8.53	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28052	 1	 40.69	 4.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28053	 1	 44.55	 6.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28054	 1	 38.44	 14.78	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28055	 1	 38.44	 14.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28056	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28057	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28058	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28059	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28060	 1	 86.27	 12.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28061	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28062	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28063	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28064	 1	 83.18	 16.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28065	 1	 66.08	 5.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28066	 1	 44.41	 7.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28067	 1	 44.41	 3.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28068	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28069	 1	 58.9	 6.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28070	 1	 58.9	 19.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28071	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28072	 1	 63.36	 10.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28073	 1	 63.36	 11.54	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28074	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28075	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28076	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28077	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28078	 1	 132.52	 25.89	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28079	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28080	 1	 52.87	 22.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28081	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28082	 1	 30.78	 12.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28083	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28084	 1	 31.98	 11.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28085	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28086	 1	 31.98	 1.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28087	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28088	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28089	 1	 32.81	 5.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28090	 1	 31.32	 8.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28091	 1	 33.46	 3.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28092	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28093	 1	 33.46	 2.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28094	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28095	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28096	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28097	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28098	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28099	 1	 96.53	 9.18	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28100	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28101	 1	 53.54	 18.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28102	 1	 15.01	 6.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28103	 1	 48.52	 5.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28104	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28105	 1	 48.52	 31.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28106	 1	 46.83	 23.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28107	 1	 46.83	 16.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28108	 1	 32.55	 6.67	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28109	 1	 35.47	 9.69	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28110	 1	 40.06	 6.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28111	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28112	 1	 40.06	 5.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28113	 1	 68.71	 11.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28114	 1	 24.77	 6.67	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28115	 1	 51.97	 12.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28116	 1	 51.97	 6.98	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28117	 1	 38.69	 8.07	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28118	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28119	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28120	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28121	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28122	 1	 110.61	 28.14	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28123	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28124	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28125	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28126	 1	 33.47	 13.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28127	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28128	 1	 103.83	 22.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28129	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28130	 1	 40.24	 21.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28131	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28132	 1	 32.55	 2.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28133	 1	 41.46	 18.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28134	 1	 59.51	 17.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28135	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28136	 1	 34.64	 23.57	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28137	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28138	 1	 34.64	 3.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28139	 1	 41.17	 11.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28140	 1	 36.07	 7.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28141	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28142	 1	 73.82	 17.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28143	 1	 73.38	 18.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28144	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28145	 1	 29.46	 2.2	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28146	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28147	 1	 28.82	 11.46	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28148	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28149	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28150	 1	 44.14	 11.33	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28151	 1	 22.46	 2.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28152	 1	 44.14	 7.44	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28153	 1	 69.48	 22.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28154	 1	 36.23	 14.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28155	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28156	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28157	 1	 56.97	 13.65	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28158	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28159	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28160	 1	 56.97	 20.5	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28161	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28162	 1	 32.74	 5.07	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28163	 1	 32.74	 4.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28164	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28165	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28166	 1	 26.36	 5.09	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28167	 1	 43.9	 13.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28168	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28169	 1	 53.26	 21.75	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28170	 1	 54.15	 33.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28171	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28172	 1	 48.21	 15.44	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28173	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28174	 1	 48.21	 21.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28175	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28176	 1	 48.21	 23.1	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28177	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28178	 1	 20.25	 4.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28179	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28180	 1	 50.27	 20.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28181	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28182	 1	 50.27	 11.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28183	 1	 0.0	 0.0	 0.0	 -30.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28184	 1	 42.82	 9.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28185	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28186	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28187	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28188	 1	 42.82	 5.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28189	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28190	 1	 46.05	 8.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28191	 1	 46.05	 7.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28192	 1	 23.34	 0.89	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28193	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28194	 1	 23.34	 4.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28195	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28196	 1	 42.5	 4.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28197	 1	 42.5	 7.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28198	 1	 39.5	 15.46	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28199	 1	 56.39	 8.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28200	 1	 52.89	 10.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28201	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28202	 1	 26.38	 9.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28203	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28204	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28205	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28206	 1	 39.41	 6.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28207	 1	 39.41	 12.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28208	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28209	 1	 31.26	 5.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28210	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28211	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28212	 1	 57.64	 13.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28213	 1	 31.02	 5.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28214	 1	 31.02	 6.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28215	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28216	 1	 48.68	 12.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28217	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28218	 1	 48.68	 24.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28219	 1	 29.35	 21.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28220	 1	 29.35	 5.3	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28221	 1	 61.13	 23.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28222	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28223	 1	 61.13	 4.1	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28224	 1	 35.08	 13.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28225	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28226	 1	 35.08	 22.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28227	 1	 51.22	 24.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28228	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28229	 1	 51.22	 13.4	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28230	 1	 60.23	 14.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28231	 1	 60.23	 7.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28232	 1	 44.53	 7.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28233	 1	 24.48	 11.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28234	 1	 41.37	 10.23	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28235	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28236	 1	 27.04	 4.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28237	 1	 27.04	 8.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28238	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28239	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28240	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28241	 1	 42.07	 3.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28242	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28243	 1	 42.07	 17.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28244	 1	 52.37	 18.93	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28245	 1	 27.89	 7.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28246	 1	 32.59	 12.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28247	 1	 31.31	 13.89	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28248	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28249	 1	 42.9	 15.64	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28250	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28251	 1	 42.9	 10.67	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28252	 1	 26.37	 3.84	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28253	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28254	 1	 26.37	 6.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28255	 1	 34.06	 5.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28256	 1	 34.06	 3.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28257	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28258	 1	 57.24	 19.75	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28259	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28260	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28261	 1	 57.24	 9.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28262	 1	 57.24	 21.34	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28263	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28264	 1	 53.05	 20.94	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28265	 1	 53.05	 22.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28266	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28267	 1	 53.05	 27.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28268	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28269	 1	 29.45	 7.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28270	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28271	 1	 29.45	 5.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28272	 1	 28.18	 17.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28273	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28274	 1	 50.71	 25.37	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28275	 1	 50.71	 17.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28276	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28277	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28278	 1	 50.71	 31.88	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28279	 1	 45.12	 9.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28280	 1	 45.12	 11.46	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28281	 1	 45.12	 10.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28282	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28283	 1	 49.37	 24.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28284	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28285	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28286	 1	 49.37	 9.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28287	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28288	 1	 35.98	 12.69	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28289	 1	 37.38	 11.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28290	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28291	 1	 48.4	 6.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28292	 1	 48.4	 17.53	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28293	 1	 27.75	 9.34	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28294	 1	 51.02	 33.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28295	 1	 51.02	 13.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28296	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28297	 1	 48.91	 3.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28298	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28299	 1	 48.91	 11.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28300	 1	 48.91	 14.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28301	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28302	 1	 85.38	 15.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28303	 1	 45.19	 10.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28304	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28305	 1	 45.19	 11.48	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28306	 1	 31.5	 13.44	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28307	 1	 39.6	 12.68	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28308	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28309	 1	 39.6	 6.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28310	 1	 36.34	 7.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28311	 1	 31.92	 9.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28312	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28313	 1	 29.91	 1.49	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28314	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28315	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28316	 1	 11.48	 0.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28317	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28318	 1	 55.87	 21.93	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28319	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28320	 1	 55.87	 15.2	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28321	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28322	 1	 31.5	 2.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28323	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28324	 1	 52.2	 23.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28325	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28326	 1	 52.2	 22.75	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28327	 1	 48.33	 16.17	 0.0	 54.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28328	 1	 48.33	 26.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28329	 1	 23.59	 8.94	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28330	 1	 46.58	 18.17	 0.0	 -17.5	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28331	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28332	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28333	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28334	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28335	 1	 24.88	 5.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28336	 1	 38.19	 20.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28337	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28338	 1	 38.19	 17.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28339	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28340	 1	 25.99	 12.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28341	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28342	 1	 47.23	 13.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28343	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28344	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28345	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28346	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28347	 1	 47.23	 17.9	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28348	 1	 49.49	 19.51	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28349	 1	 44.47	 16.44	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28350	 1	 44.47	 7.68	 0.0	 36.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28351	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28352	 1	 46.65	 14.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28353	 1	 46.65	 4.27	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28354	 1	 76.67	 33.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28355	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28356	 1	 38.16	 13.32	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28357	 1	 38.16	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28358	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28359	 1	 50.85	 24.54	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28360	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28361	 1	 78.6	 25.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28362	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28363	 1	 48.69	 7.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28364	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28365	 1	 107.85	 13.02	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28366	 1	 16.9	 6.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28367	 1	 28.05	 3.25	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28368	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28369	 1	 44.21	 16.3	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28370	 1	 46.1	 25.69	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28371	 1	 26.87	 7.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28372	 1	 33.45	 7.23	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28373	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28374	 1	 45.29	 14.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28375	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28376	 1	 45.29	 3.53	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28377	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28378	 1	 64.91	 7.63	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28379	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28380	 1	 42.1	 8.32	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28381	 1	 30.02	 7.67	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28382	 1	 23.68	 7.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28383	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28384	 1	 33.28	 7.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28385	 1	 66.35	 15.36	 0.0	 30.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28386	 1	 66.35	 17.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28387	 1	 55.44	 5.62	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28388	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28389	 1	 36.67	 14.41	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28390	 1	 24.66	 7.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28391	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28392	 1	 41.83	 4.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28393	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28394	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28395	 1	 34.79	 3.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28396	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28397	 1	 42.24	 9.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28398	 1	 47.39	 9.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28399	 1	 27.73	 11.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28400	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28401	 1	 91.25	 18.71	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28402	 1	 52.44	 28.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28403	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28404	 1	 7.52	 1.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28405	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28406	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28407	 1	 44.05	 16.92	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28408	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28409	 1	 44.05	 6.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28410	 1	 42.43	 7.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28411	 1	 41.62	 7.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28412	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28413	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28414	 1	 41.62	 5.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28415	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28416	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28417	 1	 75.0	 7.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28418	 1	 47.26	 7.8	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28419	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28420	 1	 42.89	 4.85	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28421	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28422	 1	 42.89	 13.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28423	 1	 71.98	 11.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28424	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28425	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28426	 1	 46.2	 7.45	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28427	 1	 19.06	 6.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28428	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28429	 1	 69.23	 29.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28430	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28431	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28432	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28433	 1	 49.43	 4.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28434	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28435	 1	 49.43	 8.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28436	 1	 38.62	 16.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28437	 1	 38.62	 9.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28438	 1	 39.06	 10.99	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28439	 1	 39.06	 4.88	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28440	 1	 46.08	 19.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28441	 1	 40.8	 2.63	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28442	 1	 36.24	 17.02	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28443	 1	 39.36	 6.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28444	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28445	 1	 39.36	 0.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28446	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28447	 1	 33.74	 12.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28448	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28449	 1	 62.89	 18.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28450	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28451	 1	 40.59	 5.78	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28452	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28453	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28454	 1	 40.59	 12.69	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28455	 1	 27.96	 6.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28456	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28457	 1	 27.96	 4.32	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28458	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28459	 1	 35.85	 5.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28460	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28461	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28462	 1	 35.85	 10.93	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28463	 1	 33.56	 9.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28464	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28465	 1	 30.08	 2.74	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28466	 1	 41.73	 8.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28467	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28468	 1	 41.73	 10.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28469	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28470	 1	 48.5	 4.78	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28471	 1	 48.5	 12.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28472	 1	 33.94	 6.63	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28473	 1	 66.01	 13.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28474	 1	 90.15	 15.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28475	 1	 24.14	 3.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28476	 1	 33.87	 9.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28477	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28478	 1	 33.87	 9.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28479	 1	 35.4	 13.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28480	 1	 35.4	 6.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28481	 1	 34.24	 11.37	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28482	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28483	 1	 39.97	 11.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28484	 1	 39.97	 16.88	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28485	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28486	 1	 46.38	 8.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28487	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28488	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28489	 1	 46.38	 11.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28490	 1	 28.51	 6.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28491	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28492	 1	 23.15	 5.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28493	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28494	 1	 50.46	 22.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28495	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28496	 1	 50.46	 10.91	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28497	 1	 38.94	 4.02	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28498	 1	 64.73	 11.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28499	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28500	 1	 44.03	 18.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28501	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28502	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28503	 1	 78.3	 18.02	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28504	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28505	 1	 35.17	 16.26	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28506	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28507	 1	 35.17	 10.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28508	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28509	 1	 34.44	 15.1	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28510	 1	 34.44	 6.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28511	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28512	 1	 54.29	 18.94	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28513	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28514	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28515	 1	 54.29	 12.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28516	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28517	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28518	 1	 63.84	 18.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28519	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28520	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28521	 1	 62.83	 21.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28522	 1	 51.08	 17.94	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28523	 1	 29.51	 6.1	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28524	 1	 53.52	 22.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28525	 1	 44.98	 6.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28526	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28527	 1	 80.1	 28.77	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28528	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28529	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28530	 1	 52.7	 21.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28531	 1	 24.07	 10.19	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28532	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28533	 1	 42.74	 7.65	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28534	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28535	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28536	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28537	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28538	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28539	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28540	 1	 42.74	 13.12	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28541	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28542	 1	 46.6	 13.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28543	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28544	 1	 68.29	 15.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28545	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28546	 1	 45.48	 14.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28547	 1	 58.89	 9.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28548	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28549	 1	 104.37	 14.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28550	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28551	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28552	 1	 49.8	 17.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28553	 1	 49.8	 7.37	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28554	 1	 49.8	 9.11	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28555	 1	 14.02	 1.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28556	 1	 41.71	 5.84	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28557	 1	 31.61	 15.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28558	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28559	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28560	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28561	 1	 31.61	 4.87	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28562	 1	 49.63	 15.82	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28563	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28564	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28565	 1	 65.24	 11.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28566	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28567	 1	 65.24	 16.53	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28568	 1	 52.54	 16.18	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28569	 1	 35.51	 7.42	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28570	 1	 0.0	 0.0	 0.0	 103.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28571	 1	 41.5	 6.85	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28572	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28573	 1	 34.26	 14.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28574	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28575	 1	 57.18	 16.95	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28576	 1	 28.17	 5.09	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28577	 1	 43.11	 9.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28578	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28579	 1	 72.62	 18.3	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28580	 1	 60.38	 12.21	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28581	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28582	 1	 58.11	 8.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28583	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28584	 1	 47.35	 11.72	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28585	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28586	 1	 48.12	 3.7	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28587	 1	 47.82	 6.47	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28588	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28589	 1	 47.82	 19.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28590	 1	 28.6	 8.76	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28591	 1	 52.53	 5.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28592	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28593	 1	 52.53	 2.14	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28594	 1	 48.08	 14.24	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28595	 1	 48.08	 13.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28596	 1	 39.24	 3.12	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28597	 1	 43.83	 13.12	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28598	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28599	 1	 63.36	 32.1	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28600	 1	 36.87	 12.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28601	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28602	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28603	 1	 48.49	 19.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28604	 1	 48.89	 29.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28605	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28606	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28607	 1	 51.99	 17.23	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28608	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28609	 1	 51.99	 12.61	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28610	 1	 61.03	 14.27	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28611	 1	 30.2	 8.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28612	 1	 30.2	 13.17	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28613	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28614	 1	 44.39	 8.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28615	 1	 27.81	 3.58	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28616	 1	 27.21	 2.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28617	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28618	 1	 27.21	 3.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28619	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28620	 1	 11.62	 2.46	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28621	 1	 39.76	 22.81	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28622	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28623	 1	 37.15	 17.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28624	 1	 47.12	 12.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28625	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28626	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28627	 1	 40.26	 9.94	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28628	 1	 54.35	 5.88	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28629	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28630	 1	 38.34	 9.88	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28631	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28632	 1	 58.56	 10.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28633	 1	 64.75	 8.4	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28634	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28635	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28636	 1	 31.87	 8.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28637	 1	 34.11	 13.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28638	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28639	 1	 32.56	 4.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28640	 1	 28.47	 12.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28641	 1	 23.99	 5.4	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28642	 1	 17.31	 6.12	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28643	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28644	 1	 35.31	 8.84	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28645	 1	 22.04	 11.09	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28646	 1	 12.03	 2.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28647	 1	 30.63	 8.36	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28648	 1	 25.79	 8.96	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28649	 1	 31.25	 9.49	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28650	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28651	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28652	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28653	 1	 37.71	 11.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28654	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28655	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28656	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28657	 1	 34.89	 23.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28658	 1	 46.04	 2.01	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28659	 1	 46.04	 9.08	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28660	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28661	 1	 22.59	 6.97	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28662	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28663	 1	 23.62	 8.53	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28664	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28665	 1	 33.99	 2.29	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28666	 1	 37.0	 5.39	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28667	 1	 28.58	 12.23	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28668	 1	 43.73	 34.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28669	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	28670	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	28671	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28672	 1	 29.5	 3.31	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28673	 1	 17.36	 6.15	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28674	 1	 33.54	 5.67	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28675	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28676	 1	 33.54	 7.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28677	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28678	 1	 23.04	 3.66	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28679	 1	 55.64	 16.43	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28680	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28681	 1	 55.64	 17.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28682	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28683	 1	 36.97	 17.59	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28684	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28685	 1	 60.02	 23.73	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28686	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28687	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28688	 1	 6.99	 2.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28689	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28690	 1	 35.64	 0.05	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28691	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28692	 1	 6.94	 0.86	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28693	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28694	 1	 22.98	 9.48	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28695	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28696	 1	 42.13	 8.52	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28697	 1	 43.07	 13.16	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28698	 1	 43.93	 12.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28699	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28700	 1	 43.23	 2.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28701	 1	 4.19	 0.42	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28702	 1	 14.58	 1.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28703	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28704	 1	 35.17	 5.83	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28705	 1	 35.17	 6.85	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28706	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28707	 1	 13.2	 5.28	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28708	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28709	 1	 23.61	 3.25	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28710	 1	 23.61	 5.9	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28711	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28712	 1	 20.68	 6.37	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	28713	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28714	 1	 46.78	 27.79	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28715	 1	 9.69	 4.35	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28716	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28717	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28718	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28719	 1	 3.05	 0.38	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28720	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28721	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28722	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28723	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28724	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28725	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28726	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28727	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28728	 1	 2.01	 0.75	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28729	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28730	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28731	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28732	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28733	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28734	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28735	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28736	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28737	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28738	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28739	 1	 0.4	 0.13	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28740	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28741	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28742	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28743	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28744	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28745	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28746	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28747	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28748	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28749	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28750	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28751	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28752	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28753	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28754	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28755	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28756	 1	 14.02	 2.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28757	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28758	 1	 0.0	 0.0	 0.0	 -670.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28759	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28760	 1	 0.16	 0.03	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28761	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28762	 1	 0.0	 0.0	 0.0	 -294.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28763	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28764	 1	 1.55	 0.56	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28765	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28766	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28767	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28768	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28769	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28770	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28771	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28772	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28773	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28774	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28775	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28776	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28777	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28778	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28779	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28780	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28781	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28782	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28783	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28784	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28785	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28786	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28787	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28788	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28789	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28790	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28791	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28792	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28793	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28794	 1	 0.0	 0.0	 0.0	 230.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28795	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28796	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28797	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28798	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28799	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28800	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28801	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28802	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28803	 1	 0.0	 0.0	 0.0	 5.5	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28804	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28805	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28806	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28807	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28808	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28809	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28810	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28811	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28812	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28813	 1	 7.41	 2.52	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28814	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28815	 2	 3.5	 0.22	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28816	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28817	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28818	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28819	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28820	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28821	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28822	 1	 24.77	 3.04	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28823	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28824	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28825	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28826	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28827	 1	 7.09	 1.98	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28828	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28829	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28830	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28831	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28832	 1	 23.59	 3.92	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28833	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28834	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28835	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28836	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28837	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28838	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28839	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28840	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28841	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28842	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28843	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28844	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28845	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28846	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28847	 1	 0.0	 0.0	 0.0	 -82.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28848	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28849	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28850	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	28851	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28852	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28853	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28854	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28855	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28856	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28857	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28858	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28859	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28860	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28861	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28862	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28863	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28864	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28865	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28866	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28867	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28868	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28869	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28870	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28871	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28872	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28873	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28874	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28875	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28876	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28877	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28878	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28879	 1	 0.0	 0.0	 0.0	 -520.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28880	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28881	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28882	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	28883	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28884	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28885	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	28886	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28887	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28888	 1	 0.42	 0.15	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28889	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28890	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28891	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28892	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28893	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28894	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28895	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28896	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28897	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28898	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28899	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28900	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28901	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28902	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28903	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28904	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28905	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28906	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28907	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28908	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28909	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28910	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28911	 1	 0.0	 0.0	 0.0	 -522.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28912	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28913	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	28914	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28915	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28916	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28917	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28918	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28919	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	28920	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28921	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28922	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28923	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28924	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28925	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28926	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28927	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28928	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28929	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28930	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28931	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28932	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28933	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28934	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28935	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28936	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28937	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28938	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28939	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28940	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28941	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28942	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28943	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28944	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28945	 1	 0.0	 0.0	 0.0	 99.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28946	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28947	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28948	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28949	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28950	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28951	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28952	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28953	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28954	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28955	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28956	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28957	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28958	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28959	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28960	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28961	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28962	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28963	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28964	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28965	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28966	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28967	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28968	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28969	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28970	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28971	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	28972	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28973	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28974	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28975	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28976	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28977	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28978	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28979	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28980	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28981	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28982	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28983	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28984	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28985	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28986	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28987	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28988	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28989	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28990	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	28991	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	28992	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	28993	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28994	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	28995	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	28996	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28997	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28998	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	28999	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29000	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29001	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29002	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29003	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29004	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29005	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29006	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29007	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29008	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29009	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29010	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	29011	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29012	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29013	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	29014	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29015	 1	 0.0	 0.0	 0.0	 -140.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	29016	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29017	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29018	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29019	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	29020	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29021	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29022	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29023	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29024	 1	 0.0	 0.0	 0.0	 32.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	29025	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29026	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29027	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29028	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29029	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29030	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	29031	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29032	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29033	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29034	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29035	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29036	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	29037	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29038	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29039	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	29040	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29041	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29042	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29043	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	29044	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29045	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29046	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29047	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29048	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29049	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29050	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29051	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29052	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29053	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29054	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29055	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29056	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	29057	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	29058	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	29059	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29060	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29061	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29062	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29063	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29064	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29065	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	29066	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29067	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	29068	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	29069	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	29070	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29071	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29072	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29073	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29074	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29075	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29076	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29077	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	29078	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	29079	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29080	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	29081	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	29082	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29083	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	29084	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	30000	 1	 27.05	 8.45	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30001	 1	 47.06	 16.85	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30002	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30003	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30004	 1	 47.06	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30005	 1	 34.99	 6.9	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30006	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30007	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30008	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30009	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30010	 1	 8.98	 2.2	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30011	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30012	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30013	 1	 37.52	 4.9	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30014	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30015	 1	 37.52	 8.45	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30016	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30017	 1	 16.87	 3.37	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30018	 1	 25.18	 5.29	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30019	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30020	 1	 41.84	 7.88	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30021	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30022	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30023	 1	 41.84	 11.02	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30024	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30025	 1	 29.14	 7.93	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30026	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30027	 1	 50.09	 11.82	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30028	 1	 50.09	 16.03	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30029	 1	 57.57	 23.03	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30030	 1	 57.57	 28.97	 0.0	 114.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30031	 1	 13.08	 2.79	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30032	 1	 38.36	 7.14	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30033	 1	 38.36	 7.84	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30034	 1	 42.5	 9.28	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30035	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30036	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30037	 1	 60.56	 15.65	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30038	 1	 36.48	 20.14	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30039	 1	 54.28	 18.42	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30040	 1	 54.28	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30041	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30042	 1	 12.76	 5.91	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30043	 1	 65.35	 8.22	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30044	 1	 65.35	 30.23	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30045	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30046	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30047	 1	 41.97	 14.36	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30048	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30049	 1	 41.44	 5.1	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30050	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30051	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30052	 1	 61.37	 33.71	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30053	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30054	 1	 38.57	 11.26	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30055	 1	 38.57	 8.79	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30056	 1	 55.3	 13.2	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30057	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30058	 1	 55.3	 25.32	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30059	 1	 34.63	 12.42	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30060	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30061	 1	 38.12	 2.11	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30062	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30063	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30064	 1	 38.12	 11.58	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30065	 1	 6.64	 1.18	 0.0	 -24.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30066	 1	 31.67	 8.82	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30067	 1	 42.47	 6.61	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30068	 1	 9.5	 3.55	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30069	 1	 22.88	 12.38	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30070	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30071	 1	 58.88	 19.28	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30072	 1	 23.79	 7.18	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30073	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30074	 1	 14.26	 4.49	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30075	 1	 0.0	 0.0	 0.0	 -124.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30076	 1	 74.32	 20.65	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30077	 1	 49.75	 5.01	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30078	 1	 16.61	 5.55	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30079	 1	 2.68	 0.64	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30080	 1	 16.07	 1.49	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30081	 1	 6.37	 1.8	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30082	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30083	 1	 4.27	 3.54	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30084	 1	 4.37	 2.38	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30085	 1	 0.47	 0.09	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30086	 1	 8.18	 1.41	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30087	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30088	 1	 0.0	 0.0	 0.0	 -10.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30089	 1	 7.54	 1.21	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30090	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30091	 1	 63.51	 24.84	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30092	 1	 4.22	 1.44	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30093	 1	 0.0	 0.0	 0.0	 -322.5	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30094	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30095	 1	 69.89	 12.4	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30096	 1	 41.44	 18.15	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30097	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30098	 1	 5.84	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30099	 1	 39.63	 8.7	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30100	 1	 4.2	 0.89	 0.0	 -14.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30101	 1	 72.43	 23.88	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30102	 1	 36.35	 5.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30103	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30104	 1	 56.14	 14.56	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30105	 1	 72.12	 12.88	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30106	 1	 59.57	 1.89	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30107	 1	 59.57	 10.6	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30108	 1	 38.36	 10.91	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30109	 1	 46.71	 32.13	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30110	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30111	 1	 46.71	 3.17	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30112	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30113	 1	 76.88	 32.8	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30114	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30115	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30116	 1	 76.88	 26.94	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30117	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30118	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30119	 1	 48.72	 12.2	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30120	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30121	 1	 41.38	 6.73	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30122	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30123	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30124	 1	 84.61	 25.44	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30125	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30126	 1	 83.12	 22.11	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30127	 1	 74.67	 17.34	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30128	 1	 74.67	 13.13	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30129	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30130	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30131	 1	 69.56	 2.93	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30132	 1	 53.5	 10.94	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30133	 1	 53.5	 10.31	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30134	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30135	 1	 71.4	 34.43	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30136	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30137	 1	 64.61	 20.47	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30138	 1	 64.61	 30.28	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30139	 1	 49.52	 10.88	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30140	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30141	 1	 49.52	 2.12	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30142	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30143	 1	 67.31	 19.5	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30144	 1	 105.18	 46.77	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30145	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30146	 1	 105.18	 14.43	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30147	 1	 57.95	 11.81	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30148	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30149	 1	 75.78	 20.1	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30150	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30151	 1	 75.78	 9.45	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30152	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30153	 1	 45.72	 13.7	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30154	 1	 45.72	 9.09	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30155	 1	 54.42	 28.17	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30156	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30157	 1	 54.42	 21.33	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30158	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30159	 1	 37.72	 6.03	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30160	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30161	 1	 38.17	 4.98	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30162	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30163	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30164	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30165	 1	 53.64	 7.33	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30166	 1	 53.64	 10.07	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30167	 1	 42.78	 10.02	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30168	 1	 65.51	 11.68	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30169	 1	 60.45	 28.51	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30170	 1	 60.45	 9.88	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30171	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30172	 1	 90.88	 22.01	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30173	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30174	 1	 90.88	 35.59	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30175	 1	 23.31	 3.45	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30176	 1	 38.64	 5.12	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30177	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30178	 1	 38.64	 4.93	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30179	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30180	 1	 54.01	 15.16	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30181	 1	 54.01	 6.67	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30182	 1	 84.45	 14.81	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30183	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30184	 1	 84.45	 26.04	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30185	 1	 74.17	 15.44	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30186	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30187	 1	 74.17	 10.33	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30188	 1	 69.91	 16.54	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30189	 1	 83.46	 15.25	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30190	 1	 80.89	 13.18	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30191	 1	 69.08	 20.97	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30192	 1	 69.08	 44.6	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30193	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30194	 1	 59.86	 7.79	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30195	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30196	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30197	 1	 59.86	 23.69	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30198	 1	 14.18	 4.78	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30199	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30200	 1	 44.66	 10.81	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30201	 1	 44.66	 17.7	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30202	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30203	 1	 69.93	 6.18	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30204	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30205	 1	 96.14	 39.17	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30206	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30207	 1	 96.14	 29.25	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30208	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30209	 1	 70.64	 17.23	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30210	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30211	 1	 70.64	 6.86	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30212	 1	 55.38	 20.19	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30213	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30214	 1	 55.38	 30.13	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30215	 1	 70.82	 36.18	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30216	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30217	 1	 70.82	 29.34	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30218	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30219	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30220	 1	 106.49	 32.47	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30221	 1	 106.49	 16.76	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30222	 1	 43.63	 8.98	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30223	 1	 43.63	 9.09	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30224	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30225	 1	 88.19	 9.53	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30226	 1	 88.19	 29.47	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30227	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30228	 1	 68.58	 23.12	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30229	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30230	 1	 68.58	 12.03	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30231	 1	 50.6	 1.66	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30232	 1	 50.6	 11.88	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30233	 1	 41.69	 12.01	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30234	 1	 41.69	 11.6	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30235	 1	 58.65	 6.15	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30236	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30237	 1	 47.82	 18.46	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30238	 1	 47.82	 15.44	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30239	 1	 58.49	 2.86	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30240	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30241	 1	 58.49	 6.99	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	30242	 1	 4.2	 0.8	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30243	 1	 7.1	 1.54	 0.0	 -14.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30244	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30245	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	30246	 1	 45.2	 15.56	 0.0	 20.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30247	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30248	 1	 0.0	 0.0	 0.0	 -17.5	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30249	 1	 3.81	 0.99	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30250	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30251	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30252	 1	 29.16	 10.53	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30253	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30254	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	30255	 1	 22.64	 11.06	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30256	 1	 11.16	 3.98	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30257	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30258	 1	 4.52	 0.77	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30259	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30260	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30261	 1	 5.72	 1.4	 0.0	 -30.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30262	 1	 10.81	 3.52	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30263	 1	 3.03	 0.86	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30264	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30265	 1	 13.46	 3.69	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30266	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30267	 1	 49.88	 20.7	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30268	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30269	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30270	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30271	 1	 0.0	 0.0	 0.0	 -298.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30272	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30273	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30274	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30275	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30276	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30277	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30278	 1	 0.85	 0.04	 0.0	 -42.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30279	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30280	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30281	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30282	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30283	 1	 3.35	 0.34	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30284	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30285	 2	 2.93	 0.46	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30286	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30287	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30288	 1	 1.02	 0.39	 0.0	 -72.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30289	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30290	 1	 0.61	 0.14	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30291	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30292	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30293	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	30294	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30295	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30296	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30297	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30298	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	30299	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30300	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30301	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30302	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30303	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30304	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30305	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30306	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30307	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30308	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30309	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30310	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30311	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30312	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30313	 1	 0.0	 0.0	 0.0	 -810.0	 8	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	30314	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30315	 1	 1.19	 0.53	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30316	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30317	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	30318	 1	 1.45	 0.33	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30319	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30320	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30321	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30322	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30323	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30324	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30325	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30326	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30327	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	30328	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30329	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30330	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30331	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30332	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30333	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30334	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30335	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30336	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30337	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30338	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30339	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30340	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30341	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30342	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30343	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30344	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30345	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30346	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30347	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	30348	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30349	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30350	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30351	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30352	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30353	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30354	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30355	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30356	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30357	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	30358	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	30359	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30360	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30361	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30362	 1	 0.0	 0.0	 0.0	 -166.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30363	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30364	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30365	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30366	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30367	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30368	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30369	 1	 0.0	 0.0	 0.0	 -611.0	 8	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	30370	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30371	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30372	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30373	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30374	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30375	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30376	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30377	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30378	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30379	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30380	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30381	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30382	 1	 0.0	 0.0	 0.0	 -280.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30383	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30384	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30385	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30386	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30387	 1	 0.0	 0.0	 0.0	 -910.0	 8	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	30388	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30389	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30390	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30391	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30392	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30393	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30394	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30395	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30396	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30397	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30398	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30399	 1	 0.0	 0.0	 0.0	 -98.0	 8	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	30400	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30401	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30402	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30403	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30404	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30405	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30406	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30407	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30408	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30409	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30410	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30411	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30412	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30413	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30414	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30415	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30416	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30417	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30418	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30419	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	30420	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30421	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30422	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30423	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30424	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30425	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30426	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30427	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30428	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30429	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30430	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30431	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30432	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30433	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30434	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30435	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30436	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30437	 1	 0.0	 0.0	 0.0	 -505.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30438	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30439	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30440	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30441	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30442	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30443	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30444	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30445	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30446	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30447	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	30448	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	30449	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30450	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30451	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30452	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	30453	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30454	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30455	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30456	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30457	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30458	 1	 0.0	 0.0	 0.0	 -137.5	 8	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	30459	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	30460	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	30461	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40000	 1	 38.28	 11.93	 0.0	 14.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40001	 1	 40.38	 9.47	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40002	 1	 63.64	 19.44	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40003	 1	 112.36	 26.37	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40004	 1	 112.36	 32.89	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40005	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40006	 1	 0.33	 0.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40007	 1	 41.59	 5.16	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40008	 1	 50.07	 22.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40009	 1	 50.07	 1.88	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40010	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40011	 1	 20.72	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40012	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40013	 1	 5.22	 1.69	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40014	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40015	 1	 21.49	 7.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40016	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40017	 1	 61.29	 18.16	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40018	 1	 6.31	 0.84	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40019	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40020	 1	 2.14	 0.39	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40021	 1	 6.67	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40022	 1	 47.41	 12.18	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40023	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40024	 1	 36.31	 1.34	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40025	 1	 48.73	 3.58	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40026	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40027	 1	 27.44	 4.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40028	 1	 17.15	 3.84	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40029	 1	 1.26	 0.32	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40030	 1	 13.27	 4.98	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40031	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40032	 1	 69.84	 17.61	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40033	 1	 0.0	 0.0	 0.0	 -250.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40034	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40035	 1	 69.84	 7.87	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40036	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40037	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40038	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40039	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40040	 1	 74.03	 17.8	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40041	 1	 4.1	 1.21	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40042	 1	 39.71	 12.5	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40043	 1	 39.71	 7.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40044	 1	 3.64	 1.39	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40045	 1	 8.36	 1.51	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40046	 1	 72.87	 9.2	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40047	 1	 5.37	 0.35	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40048	 1	 13.26	 3.88	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40049	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40050	 1	 5.87	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40051	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40052	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40053	 1	 8.65	 2.39	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40054	 1	 19.93	 1.82	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40055	 1	 3.8	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40056	 1	 18.25	 8.47	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40057	 1	 54.3	 3.76	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40058	 1	 6.44	 3.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40059	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40060	 1	 25.86	 5.99	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40061	 1	 6.63	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40062	 1	 8.38	 2.62	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40063	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40064	 1	 36.49	 4.32	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40065	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40066	 1	 13.42	 2.49	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40067	 1	 5.65	 1.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40068	 1	 4.91	 0.86	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40069	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40070	 1	 24.83	 6.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40071	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40072	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40073	 1	 77.56	 9.68	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40074	 1	 0.0	 0.0	 0.0	 -77.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40075	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40076	 1	 78.15	 19.77	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40077	 1	 14.96	 5.57	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40078	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40079	 1	 26.23	 1.95	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40080	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40081	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40082	 1	 28.72	 7.51	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40083	 1	 51.25	 31.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40084	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40085	 1	 70.47	 14.87	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40086	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40087	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40088	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40089	 1	 61.88	 15.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40090	 1	 0.77	 0.36	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40091	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40092	 1	 4.46	 1.16	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40093	 1	 39.39	 5.43	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40094	 1	 39.39	 22.28	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40095	 1	 61.67	 21.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40096	 1	 61.67	 4.56	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40097	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40098	 1	 47.47	 18.2	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40099	 1	 0.0	 0.0	 0.0	 22.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40100	 1	 38.88	 3.52	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40101	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40102	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40103	 1	 38.88	 5.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40104	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40105	 1	 70.72	 22.98	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40106	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40107	 1	 0.0	 0.0	 0.0	 80.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40108	 1	 70.72	 7.82	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40109	 1	 59.6	 15.63	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40110	 1	 59.6	 21.9	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40111	 1	 41.55	 7.12	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40112	 1	 41.55	 4.75	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40113	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40114	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40115	 1	 47.68	 12.9	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40116	 1	 47.68	 11.86	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40117	 1	 59.26	 20.65	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40118	 1	 59.26	 11.03	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40119	 1	 27.69	 15.77	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40120	 1	 52.96	 21.26	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40121	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40122	 1	 52.96	 9.94	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40123	 1	 51.6	 18.54	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40124	 1	 51.6	 3.24	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40125	 1	 18.47	 5.44	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40126	 1	 52.07	 15.28	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40127	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40128	 1	 41.68	 7.02	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40129	 1	 41.68	 5.23	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40130	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40131	 1	 46.52	 3.02	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40132	 1	 46.52	 13.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40133	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40134	 1	 21.7	 4.21	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40135	 1	 67.16	 25.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40136	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40137	 1	 67.16	 19.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40138	 1	 32.47	 10.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40139	 1	 60.68	 9.23	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40140	 1	 60.68	 14.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40141	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40142	 1	 55.77	 30.2	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40143	 1	 55.77	 12.56	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40144	 1	 84.31	 9.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40145	 1	 84.31	 29.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40146	 1	 72.75	 27.12	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40147	 1	 45.47	 4.96	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40148	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40149	 1	 45.47	 16.04	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40150	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40151	 1	 79.56	 6.26	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40152	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40153	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40154	 1	 79.56	 37.62	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40155	 1	 45.84	 7.52	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40156	 1	 45.84	 7.65	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40157	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40158	 1	 71.23	 8.52	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40159	 1	 71.23	 23.05	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40160	 1	 95.81	 44.06	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40161	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40162	 1	 95.81	 27.77	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40163	 1	 38.82	 7.56	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40164	 1	 38.82	 19.02	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40165	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40166	 1	 55.36	 14.14	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40167	 1	 55.36	 11.58	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40168	 1	 90.24	 18.24	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40169	 1	 90.24	 10.65	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40170	 1	 72.57	 42.76	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40171	 1	 45.74	 6.86	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40172	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40173	 1	 45.74	 22.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40174	 1	 53.38	 23.65	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40175	 1	 53.38	 11.85	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40176	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40177	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40178	 1	 57.02	 11.11	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40179	 1	 54.31	 9.76	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40180	 1	 53.94	 8.7	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40181	 1	 37.56	 13.67	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40182	 1	 37.56	 19.55	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40183	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40184	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40185	 1	 60.56	 21.37	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40186	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40187	 1	 60.56	 5.18	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40188	 1	 42.72	 6.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40189	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40190	 1	 42.72	 16.16	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40191	 1	 78.78	 27.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40192	 1	 78.78	 22.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40193	 1	 23.12	 4.61	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40194	 1	 1.15	 0.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40195	 1	 20.55	 8.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40196	 1	 75.05	 18.75	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40197	 1	 58.31	 11.72	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40198	 1	 13.93	 4.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40199	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40200	 1	 60.74	 31.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40201	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40202	 1	 60.74	 43.38	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40203	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40204	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40205	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40206	 1	 82.42	 10.27	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40207	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40208	 1	 82.42	 36.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40209	 1	 64.85	 9.6	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40210	 1	 64.85	 17.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40211	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40212	 1	 30.11	 7.03	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40213	 1	 21.71	 1.56	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40214	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40215	 1	 56.47	 5.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40216	 1	 56.47	 4.22	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40217	 1	 46.91	 6.22	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40218	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40219	 1	 46.91	 16.15	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40220	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40221	 1	 56.61	 17.84	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40222	 1	 56.61	 11.29	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40223	 1	 55.71	 14.22	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40224	 1	 55.71	 7.98	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40225	 1	 42.12	 30.69	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40226	 1	 52.55	 32.51	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40227	 1	 57.94	 9.79	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40228	 1	 17.73	 6.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40229	 1	 28.11	 10.32	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40230	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40231	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40232	 1	 14.89	 6.89	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40233	 1	 74.35	 20.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40234	 1	 50.17	 5.87	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40235	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40236	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40237	 1	 50.17	 10.26	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40238	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40239	 1	 49.27	 15.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40240	 1	 49.27	 15.54	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40241	 1	 38.61	 1.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40242	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40243	 1	 38.61	 9.19	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40244	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40245	 1	 69.59	 11.35	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40246	 1	 69.59	 8.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40247	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40248	 1	 0.0	 0.0	 0.0	 12.5	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40249	 1	 8.66	 3.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40250	 1	 61.44	 8.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40251	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40252	 1	 61.44	 34.72	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40253	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40254	 1	 0.0	 0.0	 0.0	 -228.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40255	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40256	 1	 68.69	 10.42	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40257	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40258	 1	 44.03	 10.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40259	 1	 63.2	 13.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40260	 1	 0.0	 0.0	 0.0	 -440.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40261	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40262	 1	 70.03	 8.26	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40263	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40264	 1	 0.08	 0.02	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40265	 1	 7.88	 4.68	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40266	 1	 50.84	 25.3	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40267	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40268	 1	 50.84	 10.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40269	 1	 56.99	 13.97	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40270	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40271	 1	 56.99	 17.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40272	 1	 56.06	 26.43	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40273	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40274	 1	 56.06	 6.87	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40275	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40276	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40277	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40278	 1	 57.47	 18.25	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40279	 1	 98.23	 36.88	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40280	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40281	 1	 98.23	 54.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40282	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40283	 1	 38.6	 11.43	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40284	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40285	 1	 38.6	 2.77	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40286	 1	 19.47	 3.13	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40287	 1	 4.1	 1.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40288	 1	 50.45	 6.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40289	 1	 50.45	 15.61	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40290	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40291	 1	 54.1	 12.35	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40292	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40293	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40294	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40295	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40296	 1	 54.1	 15.03	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40297	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40298	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40299	 1	 84.22	 14.71	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40300	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40301	 1	 84.22	 67.38	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40302	 1	 51.14	 13.7	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40303	 1	 68.7	 13.97	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40304	 1	 68.7	 30.27	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40305	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40306	 1	 16.15	 2.95	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40307	 1	 49.44	 13.8	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40308	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40309	 1	 86.02	 38.72	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40310	 1	 86.02	 32.19	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40311	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40312	 1	 73.01	 15.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40313	 1	 73.01	 22.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40314	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40315	 1	 67.22	 27.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40316	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40317	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40318	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40319	 1	 67.22	 17.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40320	 1	 51.59	 14.8	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40321	 1	 51.59	 12.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40322	 1	 34.22	 11.2	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40323	 1	 40.13	 16.18	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40324	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40325	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40326	 1	 40.13	 1.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40327	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40328	 1	 9.15	 0.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40329	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40330	 1	 40.44	 4.86	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40331	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40332	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40333	 1	 40.44	 3.08	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40334	 1	 15.46	 2.61	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40335	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40336	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40337	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40338	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40339	 1	 70.03	 10.38	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40340	 1	 54.08	 15.27	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40341	 1	 54.08	 25.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40342	 1	 47.72	 8.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40343	 1	 64.19	 19.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40344	 1	 64.19	 30.1	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40345	 1	 55.91	 9.7	 0.0	 150.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40346	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40347	 1	 55.91	 4.33	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40348	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40349	 1	 44.73	 7.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40350	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40351	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40352	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40353	 1	 44.73	 13.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40354	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40355	 1	 33.96	 1.6	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40356	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40357	 1	 69.14	 22.47	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40358	 1	 69.14	 12.8	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40359	 1	 14.92	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40360	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40361	 1	 54.7	 16.52	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40362	 1	 54.7	 22.33	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40363	 1	 64.93	 23.21	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40364	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40365	 1	 58.39	 15.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40366	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40367	 1	 104.72	 20.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40368	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40369	 1	 104.72	 46.27	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40370	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40371	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40372	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40373	 1	 55.91	 5.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40374	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40375	 1	 55.91	 13.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40376	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40377	 1	 14.72	 5.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40378	 1	 56.35	 18.75	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40379	 1	 56.35	 5.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40380	 1	 64.27	 5.87	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40381	 1	 33.83	 8.13	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40382	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40383	 1	 53.31	 14.66	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40384	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40385	 1	 53.31	 6.55	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40386	 1	 34.44	 7.97	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40387	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40388	 1	 55.36	 22.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40389	 1	 55.36	 20.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40390	 1	 91.33	 17.31	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40391	 1	 91.33	 17.24	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40392	 1	 21.05	 6.09	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40393	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40394	 1	 47.7	 10.81	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40395	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40396	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40397	 1	 47.7	 2.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40398	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40399	 1	 76.41	 29.45	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40400	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40401	 1	 76.41	 13.13	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40402	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40403	 1	 68.05	 7.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40404	 1	 57.5	 18.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40405	 1	 57.5	 29.02	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40406	 1	 55.2	 19.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40407	 1	 0.0	 0.0	 0.0	 60.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40408	 1	 55.2	 12.75	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40409	 1	 75.02	 25.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40410	 1	 75.02	 20.27	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40411	 1	 13.63	 3.32	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40412	 1	 40.47	 16.63	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40413	 1	 40.47	 11.14	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40414	 1	 64.44	 13.44	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40415	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40416	 1	 59.79	 18.42	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40417	 1	 59.79	 38.72	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40418	 1	 49.73	 23.96	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40419	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40420	 1	 49.73	 17.09	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40421	 1	 32.03	 7.04	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40422	 1	 2.11	 0.44	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40423	 1	 14.42	 0.21	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40424	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40425	 1	 19.39	 9.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40426	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40427	 1	 61.16	 5.33	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40428	 1	 0.0	 0.0	 0.0	 -49.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40429	 1	 61.16	 11.09	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40430	 1	 56.07	 11.69	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40431	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40432	 1	 56.07	 16.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40433	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40434	 1	 73.3	 28.69	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40435	 1	 73.3	 10.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40436	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40437	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40438	 1	 67.12	 24.15	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40439	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40440	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40441	 1	 67.12	 6.39	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40442	 1	 73.48	 56.88	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40443	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40444	 1	 20.16	 12.36	 0.0	 0.0	 9	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	40445	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	40446	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40447	 1	 52.14	 5.28	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40448	 1	 52.14	 5.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40449	 1	 47.89	 5.98	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40450	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40451	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40452	 1	 42.25	 12.97	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40453	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40454	 1	 42.25	 2.91	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40455	 1	 8.85	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40456	 1	 55.6	 6.54	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40457	 1	 55.07	 7.65	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40458	 1	 55.07	 8.51	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40459	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40460	 1	 44.47	 7.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40461	 1	 6.33	 1.53	 0.0	 10.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40462	 1	 52.52	 6.53	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40463	 1	 52.52	 8.45	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40464	 1	 63.66	 15.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40465	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40466	 1	 5.82	 1.21	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40467	 1	 32.01	 15.38	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40468	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40469	 1	 6.32	 1.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40470	 1	 45.25	 3.25	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40471	 1	 56.19	 9.15	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40472	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40473	 1	 56.01	 23.18	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40474	 1	 15.09	 2.65	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40475	 1	 33.75	 13.92	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40476	 1	 36.74	 7.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40477	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40478	 1	 65.63	 11.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40479	 1	 50.33	 12.8	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40480	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40481	 1	 50.33	 7.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40482	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40483	 1	 6.84	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40484	 1	 43.72	 41.39	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40485	 1	 43.72	 16.14	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40486	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40487	 1	 8.79	 3.12	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40488	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40489	 1	 23.37	 7.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40490	 1	 8.62	 1.49	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40491	 1	 50.96	 11.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40492	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40493	 1	 34.06	 4.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40494	 1	 55.51	 26.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40495	 1	 55.51	 11.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40496	 1	 18.98	 5.43	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40497	 1	 37.82	 7.49	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40498	 1	 37.82	 9.66	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40499	 1	 6.93	 1.42	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40500	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40501	 1	 64.59	 1.47	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40502	 1	 64.59	 28.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40503	 1	 49.5	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40504	 1	 49.79	 12.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40505	 1	 62.5	 6.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40506	 1	 6.99	 3.27	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40507	 1	 0.0	 0.0	 0.0	 -41.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40508	 1	 70.7	 26.13	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40509	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40510	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40511	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40512	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40513	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40514	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40515	 1	 75.23	 18.62	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40516	 1	 75.23	 6.17	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40517	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40518	 1	 86.28	 24.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40519	 1	 86.28	 24.18	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40520	 1	 53.54	 23.47	 0.0	 150.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40521	 1	 46.39	 16.11	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40522	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40523	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40524	 1	 46.39	 10.09	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40525	 1	 45.32	 2.84	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40526	 1	 14.95	 6.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40527	 1	 45.03	 5.8	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40528	 1	 65.98	 14.89	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40529	 1	 65.98	 38.15	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40530	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40531	 1	 62.18	 9.57	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40532	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40533	 1	 5.41	 1.12	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40534	 1	 82.81	 9.55	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40535	 1	 84.79	 20.41	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40536	 1	 49.28	 7.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40537	 1	 49.28	 22.59	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40538	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40539	 1	 69.49	 7.19	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40540	 1	 41.05	 12.89	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40541	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40542	 1	 41.05	 4.05	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40543	 1	 69.16	 23.26	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40544	 1	 53.55	 14.43	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40545	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40546	 1	 53.55	 10.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40547	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40548	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40549	 1	 13.56	 3.28	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40550	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40551	 1	 49.0	 2.91	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40552	 1	 49.0	 12.29	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40553	 1	 61.88	 6.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40554	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40555	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40556	 1	 61.88	 11.77	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40557	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40558	 1	 8.94	 1.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40559	 1	 53.11	 26.85	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40560	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40561	 1	 72.63	 29.87	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40562	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40563	 1	 81.66	 3.95	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40564	 1	 81.66	 15.75	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40565	 1	 12.75	 2.67	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40566	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40567	 1	 12.22	 5.98	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40568	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40569	 1	 69.17	 14.73	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40570	 1	 40.04	 16.99	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40571	 1	 54.26	 22.42	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40572	 1	 57.48	 12.71	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40573	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40574	 1	 57.48	 8.37	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40575	 1	 57.1	 36.6	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40576	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40577	 1	 4.12	 1.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40578	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40579	 1	 4.28	 1.13	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40580	 1	 8.25	 1.86	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40581	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40582	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40583	 1	 44.91	 5.02	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40584	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40585	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40586	 1	 65.26	 15.37	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40587	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40588	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40589	 1	 5.8	 1.84	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40590	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40591	 1	 16.06	 4.31	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40592	 1	 5.39	 2.58	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40593	 1	 4.4	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40594	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40595	 1	 14.89	 4.1	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40596	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40597	 1	 14.37	 0.71	 0.0	 24.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40598	 1	 28.39	 4.25	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40599	 1	 16.8	 1.7	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40600	 1	 5.4	 1.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40601	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40602	 1	 4.36	 0.61	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40603	 1	 19.59	 3.79	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40604	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40605	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40606	 1	 9.59	 4.44	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40607	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40608	 1	 4.53	 2.13	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40609	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40610	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40611	 1	 23.53	 4.51	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40612	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40613	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40614	 1	 16.07	 7.1	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40615	 1	 28.24	 10.07	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40616	 1	 45.84	 15.06	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40617	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40618	 1	 6.21	 1.39	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40619	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40620	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40621	 1	 11.36	 3.22	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40622	 1	 52.09	 30.91	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40623	 1	 0.0	 0.0	 0.0	 -300.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40624	 1	 52.09	 24.16	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40625	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40626	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40627	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40628	 1	 12.15	 3.44	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40629	 1	 18.13	 7.93	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40630	 1	 14.92	 2.35	 0.0	 -5.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40631	 1	 0.24	 0.03	 0.0	 -108.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40632	 1	 22.91	 7.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40633	 1	 0.53	 0.09	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40634	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40635	 1	 5.57	 0.82	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40636	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40637	 1	 5.92	 1.78	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40638	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40639	 1	 51.62	 31.78	 0.0	 36.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40640	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40641	 1	 12.69	 6.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40642	 1	 30.62	 7.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40643	 1	 31.22	 6.46	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40644	 1	 24.97	 4.4	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40645	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40646	 1	 5.38	 2.37	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40647	 1	 27.99	 5.77	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40648	 1	 17.46	 2.83	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40649	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40650	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40651	 1	 5.52	 1.58	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40652	 1	 21.8	 4.82	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40653	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40654	 1	 23.05	 9.5	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40655	 1	 0.0	 0.0	 0.0	 -390.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40656	 1	 32.14	 4.2	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40657	 1	 4.33	 1.38	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40658	 1	 8.05	 1.23	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40659	 1	 12.45	 3.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40660	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40661	 1	 8.46	 0.99	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40662	 1	 7.01	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40663	 1	 4.39	 1.74	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40664	 1	 8.95	 2.26	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40665	 1	 8.62	 0.36	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40666	 1	 0.0	 0.0	 0.0	 -156.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40667	 1	 56.77	 7.71	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40668	 1	 0.0	 0.0	 0.0	 -365.5	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40669	 1	 59.03	 4.58	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40670	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40671	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40672	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40673	 1	 7.1	 0.43	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40674	 1	 9.95	 1.73	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40675	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40676	 1	 17.69	 1.22	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40677	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40678	 1	 12.88	 5.01	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40679	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40680	 1	 7.02	 1.39	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40681	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40682	 1	 6.27	 2.64	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40683	 1	 7.32	 2.08	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40684	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40685	 1	 3.96	 0.77	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40686	 1	 13.34	 2.94	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40687	 1	 3.8	 0.9	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40688	 1	 7.76	 1.89	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40689	 1	 23.03	 7.99	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40690	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40691	 1	 8.0	 1.26	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40692	 1	 13.44	 4.79	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40693	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40694	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40695	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40696	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40697	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40698	 1	 0.0	 0.0	 0.0	 -170.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40699	 1	 2.37	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40700	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40701	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40702	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40703	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40704	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40705	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40706	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40707	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40708	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40709	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40710	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40711	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40712	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40713	 1	 1.75	 0.07	 0.0	 -28.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40714	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40715	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40716	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40717	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40718	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40719	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40720	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40721	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40722	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40723	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40724	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40725	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40726	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40727	 1	 9.98	 3.69	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40728	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40729	 1	 0.0	 0.0	 0.0	 -330.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40730	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40731	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40732	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40733	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40734	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40735	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40736	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40737	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40738	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40739	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40740	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40741	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40742	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40743	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40744	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40745	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40746	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40747	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40748	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40749	 1	 0.67	 0.18	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40750	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40751	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40752	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40753	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40754	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	40755	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40756	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40757	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40758	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40759	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40760	 1	 0.0	 0.0	 0.0	 -714.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40761	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40762	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40763	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40764	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40765	 1	 0.0	 0.0	 0.0	 -524.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40766	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40767	 1	 4.73	 0.85	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40768	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40769	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40770	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40771	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40772	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40773	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40774	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40775	 2	 3.75	 0.49	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40776	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40777	 1	 2.26	 0.57	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40778	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40779	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40780	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40781	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40782	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40783	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40784	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40785	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40786	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40787	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40788	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40789	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40790	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40791	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40792	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40793	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40794	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40795	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40796	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40797	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40798	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40799	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40800	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40801	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40802	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40803	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40804	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40805	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40806	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40807	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40808	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40809	 1	 0.0	 0.0	 0.0	 -70.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40810	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40811	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40812	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40813	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40814	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40815	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40816	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40817	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40818	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40819	 1	 0.0	 0.0	 0.0	 -420.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40820	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40821	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40822	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40823	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40824	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40825	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40826	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40827	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40828	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40829	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40830	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40831	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40832	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40833	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40834	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40835	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40836	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40837	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40838	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40839	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40840	 1	 0.0	 0.0	 0.0	 200.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40841	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40842	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40843	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40844	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40845	 3	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40846	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40847	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40848	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40849	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40850	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40851	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40852	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40853	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40854	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40855	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40856	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40857	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40858	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40859	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40860	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40861	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40862	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40863	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40864	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40865	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40866	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40867	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40868	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40869	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40870	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40871	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40872	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40873	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40874	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40875	 1	 0.0	 0.0	 0.0	 -404.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40876	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40877	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40878	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40879	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40880	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40881	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	40882	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40883	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40884	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40885	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40886	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40887	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40888	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40889	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40890	 1	 0.0	 0.0	 0.0	 -160.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40891	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40892	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40893	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40894	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40895	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40896	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40897	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40898	 1	 0.0	 0.0	 0.0	 -700.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40899	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40900	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40901	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40902	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40903	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40904	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40905	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40906	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40907	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40908	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	40909	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40910	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40911	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40912	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40913	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40914	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40915	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	40916	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40917	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40918	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40919	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40920	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40921	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40922	 1	 0.0	 0.0	 0.0	 -391.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40923	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40924	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40925	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40926	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40927	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40928	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40929	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40930	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40931	 1	 0.0	 0.0	 0.0	 -1022.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40932	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40933	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40934	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40935	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40936	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40937	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40938	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40939	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40940	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40941	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40942	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40943	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40944	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40945	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40946	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40947	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40948	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40949	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40950	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40951	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40952	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40953	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40954	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40955	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40956	 1	 0.0	 0.0	 0.0	 -60.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40957	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40958	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40959	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40960	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40961	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40962	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40963	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40964	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40965	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40966	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40967	 1	 0.0	 0.0	 0.0	 80.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40968	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40969	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40970	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40971	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40972	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40973	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40974	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40975	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40976	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40977	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40978	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40979	 1	 0.0	 0.0	 0.0	 -316.0	 9	    1.00000	    0.00000	 765.0	 1	    1.10000	    0.90000;
	40980	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40981	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40982	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40983	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	40984	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40985	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40986	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40987	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40988	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40989	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40990	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40991	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40992	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40993	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	40994	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	40995	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	40996	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40997	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	40998	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	40999	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	41000	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	41001	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	41002	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	41003	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	41004	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	41005	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	41006	 1	 0.0	 0.0	 0.0	 -310.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	41007	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	41008	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	41009	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	41010	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	41011	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	41012	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	41013	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	41014	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	41015	 1	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	41016	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	41017	 2	 0.0	 0.0	 0.0	 0.0	 9	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50000	 1	 7.34	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50001	 1	 20.47	 1.42	 0.0	 -30.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50002	 1	 15.97	 1.33	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50003	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50004	 1	 55.51	 26.13	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50005	 1	 50.87	 17.16	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50006	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50007	 1	 4.12	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50008	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50009	 1	 46.5	 19.84	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50010	 1	 46.5	 16.59	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50011	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50012	 1	 48.77	 18.05	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50013	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50014	 1	 5.3	 1.48	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50015	 1	 3.52	 0.83	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50016	 1	 13.56	 4.61	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50017	 1	 38.58	 5.24	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50018	 1	 51.91	 25.63	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50019	 1	 0.0	 0.0	 0.0	 -260.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50020	 1	 54.5	 10.95	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50021	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50022	 1	 7.77	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50023	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50024	 1	 7.46	 4.28	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50025	 1	 8.82	 0.29	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50026	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50027	 1	 24.63	 9.83	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50028	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50029	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50030	 1	 5.46	 3.61	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50031	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50032	 1	 9.86	 1.65	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50033	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50034	 1	 17.39	 7.13	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50035	 1	 4.43	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50036	 1	 4.1	 0.99	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50037	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50038	 1	 6.94	 1.68	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50039	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50040	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50041	 1	 9.21	 4.17	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50042	 1	 3.05	 0.15	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50043	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50044	 1	 31.72	 7.68	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50045	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50046	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50047	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50048	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50049	 1	 57.6	 22.06	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50050	 1	 3.05	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50051	 1	 57.6	 4.39	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50052	 1	 2.89	 0.49	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50053	 1	 14.45	 1.84	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50054	 1	 34.48	 7.52	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50055	 1	 34.48	 8.22	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50056	 1	 13.75	 5.18	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50057	 1	 7.07	 2.13	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50058	 1	 19.71	 5.3	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50059	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50060	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50061	 1	 73.27	 20.68	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50062	 1	 73.27	 23.89	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50063	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50064	 1	 11.3	 2.19	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50065	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50066	 1	 43.41	 12.1	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50067	 1	 45.56	 2.45	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50068	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50069	 1	 63.72	 20.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50070	 1	 4.06	 1.22	 0.0	 -8.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50071	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50072	 1	 7.93	 1.21	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50073	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50074	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50075	 1	 81.24	 36.41	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50076	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50077	 1	 81.24	 42.05	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50078	 1	 63.92	 28.06	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50079	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50080	 1	 48.68	 3.3	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50081	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50082	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50083	 1	 48.68	 2.65	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50084	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50085	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50086	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50087	 1	 36.38	 14.29	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50088	 1	 36.38	 6.38	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50089	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50090	 1	 52.95	 12.91	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50091	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50092	 1	 52.95	 36.42	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50093	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50094	 1	 8.76	 0.43	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50095	 1	 46.31	 10.26	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50096	 1	 46.31	 8.66	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50097	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50098	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50099	 1	 93.83	 21.34	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50100	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50101	 1	 88.78	 23.55	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50102	 1	 63.64	 21.19	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50103	 1	 63.64	 11.37	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50104	 1	 58.29	 20.55	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50105	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50106	 1	 8.61	 0.97	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50107	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50108	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50109	 1	 58.01	 8.08	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50110	 1	 58.01	 4.95	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50111	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50112	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50113	 1	 64.66	 20.62	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50114	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50115	 1	 65.74	 7.1	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50116	 1	 0.0	 0.0	 0.0	 720.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50117	 1	 65.74	 18.45	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50118	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50119	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50120	 1	 34.46	 4.82	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50121	 1	 34.46	 2.55	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50122	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50123	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50124	 1	 40.75	 5.21	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50125	 1	 40.75	 12.59	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50126	 1	 62.14	 16.85	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50127	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50128	 1	 48.42	 3.38	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50129	 1	 46.28	 15.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50130	 1	 46.28	 3.85	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50131	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50132	 1	 43.29	 6.7	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50133	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50134	 1	 43.29	 11.68	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50135	 1	 43.38	 14.5	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50136	 1	 43.38	 8.55	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50137	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50138	 1	 69.0	 29.71	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50139	 1	 69.0	 30.47	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50140	 1	 13.12	 2.03	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50141	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50142	 1	 49.62	 7.98	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50143	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50144	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50145	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50146	 1	 49.62	 13.07	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50147	 1	 36.99	 7.86	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50148	 1	 59.87	 24.51	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50149	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50150	 1	 7.2	 2.04	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50151	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50152	 1	 49.27	 19.26	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50153	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50154	 1	 49.27	 7.96	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50155	 1	 42.11	 8.66	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50156	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50157	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50158	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50159	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50160	 1	 43.87	 11.86	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50161	 1	 47.56	 42.35	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50162	 1	 47.56	 9.12	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50163	 1	 0.0	 0.0	 0.0	 147.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50164	 1	 47.46	 9.8	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50165	 1	 37.62	 7.9	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50166	 1	 37.62	 10.48	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50167	 1	 64.14	 20.02	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50168	 1	 64.64	 8.73	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50169	 1	 40.12	 13.93	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50170	 1	 40.12	 18.56	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50171	 1	 39.7	 13.52	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50172	 1	 27.93	 3.68	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50173	 1	 33.64	 10.28	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50174	 1	 63.74	 12.29	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50175	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50176	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50177	 1	 63.74	 24.27	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50178	 1	 51.69	 6.39	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50179	 1	 51.69	 13.55	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50180	 1	 58.27	 7.72	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50181	 1	 58.27	 1.78	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50182	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50183	 1	 15.02	 4.57	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50184	 1	 45.29	 2.88	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50185	 1	 36.49	 1.02	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50186	 1	 36.49	 11.21	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50187	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50188	 1	 57.56	 14.05	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50189	 1	 43.4	 12.48	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50190	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50191	 1	 43.4	 17.14	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50192	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50193	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50194	 1	 10.69	 1.86	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50195	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50196	 1	 5.82	 0.51	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50197	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50198	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50199	 1	 6.81	 3.24	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50200	 1	 54.82	 6.75	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50201	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50202	 1	 57.3	 18.08	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50203	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50204	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50205	 1	 57.3	 13.42	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50206	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50207	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50208	 1	 6.15	 2.79	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50209	 1	 0.0	 0.0	 0.0	 -17.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50210	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50211	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50212	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50213	 1	 63.19	 6.85	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50214	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50215	 1	 60.14	 26.74	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50216	 1	 5.52	 1.17	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50217	 1	 4.58	 2.84	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50218	 1	 15.59	 8.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50219	 1	 55.37	 12.73	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50220	 1	 18.77	 2.59	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50221	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50222	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50223	 1	 7.08	 2.16	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50224	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50225	 1	 10.49	 3.43	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50226	 1	 30.36	 4.37	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50227	 1	 52.28	 24.45	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50228	 1	 25.53	 4.39	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50229	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50230	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50231	 1	 53.92	 5.31	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50232	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50233	 1	 39.7	 12.71	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50234	 1	 39.7	 7.94	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50235	 1	 26.24	 5.09	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50236	 1	 63.71	 26.73	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50237	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50238	 1	 54.21	 14.75	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50239	 1	 0.0	 0.0	 0.0	 -28.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50240	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50241	 1	 54.21	 6.45	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50242	 1	 47.67	 9.66	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50243	 1	 47.67	 10.73	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50244	 1	 38.38	 18.82	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50245	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50246	 1	 38.38	 4.21	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50247	 1	 62.03	 11.37	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50248	 1	 25.58	 2.14	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50249	 1	 40.93	 12.91	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50250	 1	 40.93	 6.67	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50251	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50252	 1	 49.39	 15.06	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50253	 1	 49.39	 9.48	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50254	 1	 55.1	 30.77	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50255	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50256	 1	 55.1	 28.15	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50257	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50258	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50259	 1	 26.84	 1.37	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50260	 1	 55.44	 6.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50261	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50262	 1	 56.25	 9.72	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50263	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50264	 1	 56.25	 6.87	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50265	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50266	 1	 20.55	 3.87	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50267	 1	 20.66	 3.63	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50268	 1	 0.0	 0.0	 0.0	 -38.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50269	 1	 6.13	 0.54	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50270	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50271	 1	 6.99	 0.76	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50272	 1	 41.98	 9.47	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50273	 1	 41.98	 18.54	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50274	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50275	 1	 7.5	 1.25	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50276	 1	 10.6	 3.39	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50277	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50278	 1	 10.85	 0.78	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50279	 1	 4.39	 2.47	 0.0	 -21.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50280	 1	 63.89	 9.59	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50281	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50282	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50283	 1	 63.89	 29.86	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50284	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50285	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50286	 1	 20.89	 2.72	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50287	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50288	 1	 21.02	 2.88	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50289	 1	 44.93	 7.9	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50290	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50291	 1	 13.3	 3.37	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50292	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50293	 1	 19.75	 5.24	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50294	 1	 38.97	 7.62	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50295	 1	 38.97	 14.33	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50296	 1	 6.58	 1.83	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50297	 1	 4.84	 0.41	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50298	 1	 10.45	 3.07	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50299	 1	 44.85	 17.19	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50300	 1	 9.41	 1.3	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50301	 1	 3.91	 1.4	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50302	 1	 4.67	 1.56	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50303	 1	 5.26	 0.66	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50304	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50305	 1	 7.13	 1.36	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50306	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50307	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50308	 1	 16.39	 3.44	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50309	 1	 5.28	 0.75	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50310	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50311	 1	 10.75	 4.33	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50312	 1	 35.86	 10.83	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50313	 1	 8.7	 1.04	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50314	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50315	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50316	 1	 38.0	 2.51	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50317	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50318	 1	 9.81	 2.76	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50319	 1	 4.37	 0.47	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50320	 1	 5.18	 1.31	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50321	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50322	 1	 0.12	 0.07	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50323	 1	 3.08	 0.39	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50324	 1	 31.26	 8.61	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50325	 1	 4.28	 0.92	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50326	 1	 4.52	 1.6	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50327	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50328	 1	 4.34	 3.33	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50329	 1	 3.88	 1.07	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50330	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50331	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50332	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50333	 1	 3.54	 0.68	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50334	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50335	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50336	 1	 6.76	 1.98	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50337	 1	 0.0	 0.0	 0.0	 -207.5	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50338	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50339	 1	 26.64	 4.43	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50340	 1	 0.0	 0.0	 0.0	 -220.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50341	 1	 35.67	 12.88	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50342	 1	 0.69	 0.14	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50343	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50344	 1	 33.61	 2.57	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50345	 1	 0.0	 0.0	 0.0	 -10.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50346	 1	 12.15	 2.16	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50347	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50348	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50349	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50350	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50351	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50352	 1	 0.0	 0.0	 0.0	 -44.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50353	 1	 6.9	 1.18	 0.0	 0.0	 10	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	50354	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50355	 1	 1.94	 0.59	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50356	 1	 0.0	 0.0	 0.0	 -460.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50357	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50358	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50359	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50360	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50361	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	50362	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50363	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	50364	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50365	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	50366	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50367	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50368	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50369	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50370	 1	 0.0	 0.0	 0.0	 -148.5	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50371	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50372	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50373	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50374	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50375	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50376	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	50377	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50378	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50379	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50380	 1	 0.0	 0.0	 0.0	 -46.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50381	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50382	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50383	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50384	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50385	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	50386	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	50387	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50388	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50389	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50390	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50391	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50392	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50393	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50394	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50395	 1	 0.0	 0.0	 0.0	 -614.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50396	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50397	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50398	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50399	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50400	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50401	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50402	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50403	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50404	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50405	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50406	 1	 0.0	 0.0	 0.0	 -628.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50407	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50408	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50409	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50410	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50411	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50412	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50413	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50414	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50415	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50416	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50417	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50418	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50419	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50420	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50421	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50422	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50423	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50424	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50425	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50426	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50427	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50428	 1	 0.0	 0.0	 0.0	 -250.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50429	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50430	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50431	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50432	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	50433	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50434	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50435	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50436	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	50437	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50438	 1	 0.0	 0.0	 0.0	 -146.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50439	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50440	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	50441	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50442	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50443	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50444	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50445	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50446	 1	 0.0	 0.0	 0.0	 -158.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50447	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50448	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50449	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50450	 1	 0.0	 0.0	 0.0	 -64.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50451	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50452	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50453	 1	 0.0	 0.0	 0.0	 -160.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50454	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50455	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50456	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	50457	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	50458	 2	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	50459	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	50460	 1	 0.0	 0.0	 0.0	 0.0	 10	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53000	 1	 29.54	 1.26	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53001	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53002	 1	 6.2	 0.68	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53003	 1	 3.71	 0.38	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53004	 1	 6.27	 0.56	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53005	 1	 16.39	 7.38	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53006	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53007	 1	 6.15	 1.28	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53008	 1	 5.1	 0.23	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53009	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53010	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53011	 1	 5.82	 2.94	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53012	 1	 8.76	 1.06	 0.0	 -7.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53013	 1	 5.66	 0.32	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53014	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53015	 1	 9.53	 2.39	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53016	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53017	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53018	 1	 4.41	 1.54	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53019	 1	 12.4	 7.53	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53020	 1	 11.64	 1.51	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53021	 1	 2.59	 0.18	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53022	 1	 9.13	 1.36	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53023	 1	 21.21	 4.08	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53024	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53025	 1	 24.29	 7.74	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53026	 1	 21.97	 7.55	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53027	 1	 4.86	 0.61	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53028	 1	 6.55	 3.28	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53029	 1	 14.17	 6.14	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53030	 1	 10.23	 3.27	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53031	 1	 26.75	 10.14	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53032	 1	 20.47	 3.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53033	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53034	 1	 7.26	 2.28	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53035	 1	 25.04	 6.24	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53036	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53037	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53038	 1	 28.08	 5.33	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53039	 1	 4.28	 0.28	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53040	 1	 0.0	 0.0	 0.0	 38.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53041	 1	 29.91	 8.74	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53042	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53043	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53044	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53045	 1	 32.12	 8.5	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53046	 1	 1.59	 0.38	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53047	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53048	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53049	 1	 32.12	 11.03	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53050	 1	 18.35	 5.93	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53051	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53052	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53053	 1	 22.06	 3.56	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53054	 1	 3.07	 1.5	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53055	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53056	 1	 27.16	 9.57	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53057	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53058	 1	 6.85	 1.07	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53059	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53060	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53061	 1	 13.45	 2.97	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53062	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53063	 1	 10.54	 1.99	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53064	 1	 6.2	 2.63	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53065	 1	 7.07	 0.17	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53066	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53067	 1	 41.45	 2.26	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53068	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53069	 1	 29.03	 9.48	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53070	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53071	 1	 39.54	 9.92	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53072	 1	 39.54	 12.63	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53073	 1	 0.0	 0.0	 0.0	 20.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53074	 1	 25.17	 10.68	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53075	 1	 34.08	 2.51	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53076	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53077	 1	 30.51	 4.39	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53078	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53079	 1	 28.3	 12.38	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53080	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53081	 1	 28.3	 3.26	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53082	 1	 27.01	 14.94	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53083	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53084	 1	 27.01	 8.09	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53085	 1	 27.05	 8.2	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53086	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53087	 1	 27.05	 5.29	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53088	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53089	 1	 20.27	 10.06	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53090	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53091	 1	 14.19	 4.61	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53092	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53093	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53094	 1	 18.61	 4.86	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53095	 1	 40.38	 10.27	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53096	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53097	 1	 40.38	 11.84	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53098	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53099	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53100	 1	 3.5	 1.02	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53101	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53102	 1	 18.91	 2.93	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53103	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53104	 1	 18.91	 9.33	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53105	 1	 12.15	 0.3	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53106	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53107	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53108	 1	 21.83	 3.51	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53109	 1	 21.83	 1.76	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53110	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53111	 1	 29.69	 3.36	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53112	 1	 21.71	 3.73	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53113	 1	 19.39	 8.27	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53114	 1	 4.08	 0.55	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53115	 1	 32.97	 5.01	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53116	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53117	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53118	 1	 5.41	 1.1	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53119	 1	 17.41	 8.28	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53120	 1	 8.05	 1.89	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53121	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53122	 1	 43.14	 27.25	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53123	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53124	 1	 43.14	 20.47	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53125	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53126	 1	 6.37	 1.08	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53127	 1	 26.4	 10.17	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53128	 1	 26.4	 10.94	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53129	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53130	 1	 6.77	 2.69	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53131	 1	 27.21	 1.34	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53132	 1	 26.24	 13.67	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53133	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53134	 1	 40.62	 7.86	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53135	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53136	 1	 40.62	 11.43	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53137	 1	 18.17	 1.6	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53138	 1	 18.55	 2.01	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53139	 1	 35.98	 10.25	 0.0	 58.5	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53140	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53141	 1	 35.98	 7.9	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53142	 1	 8.54	 0.26	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53143	 1	 18.98	 7.5	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53144	 1	 1.25	 0.06	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53145	 1	 18.98	 5.73	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53146	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53147	 1	 16.99	 3.02	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53148	 1	 35.8	 11.26	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53149	 1	 35.8	 8.68	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53150	 1	 35.8	 11.74	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53151	 1	 35.87	 15.88	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53152	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53153	 1	 7.53	 4.31	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53154	 1	 25.79	 2.79	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53155	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53156	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53157	 1	 30.85	 7.1	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53158	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53159	 1	 30.85	 10.4	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53160	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53161	 1	 12.65	 4.28	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53162	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53163	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53164	 1	 6.33	 1.27	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53165	 1	 8.76	 3.36	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53166	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53167	 1	 9.39	 2.68	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53168	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53169	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53170	 1	 4.52	 0.53	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53171	 1	 3.48	 0.5	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53172	 1	 5.46	 0.65	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53173	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53174	 1	 4.14	 0.52	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53175	 1	 32.51	 15.24	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53176	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53177	 1	 9.61	 5.43	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53178	 1	 26.13	 7.34	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53179	 1	 15.89	 4.74	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53180	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53181	 1	 24.14	 7.48	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53182	 1	 7.93	 0.64	 0.0	 6.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53183	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53184	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53185	 1	 13.07	 1.16	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53186	 1	 17.96	 1.65	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53187	 1	 32.41	 3.09	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53188	 1	 32.41	 12.65	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53189	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53190	 1	 8.64	 2.07	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53191	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53192	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53193	 1	 26.02	 3.27	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53194	 1	 9.67	 3.39	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53195	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53196	 1	 4.17	 0.64	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53197	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53198	 1	 10.25	 1.25	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53199	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53200	 1	 6.7	 1.81	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53201	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53202	 1	 10.09	 2.04	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53203	 1	 35.71	 17.84	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53204	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53205	 1	 2.55	 0.8	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53206	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53207	 1	 9.94	 2.31	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53208	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53209	 1	 12.33	 3.29	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53210	 1	 7.05	 1.75	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53211	 1	 16.75	 0.57	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53212	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53213	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53214	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53215	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53216	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53217	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53218	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53219	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53220	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53221	 1	 2.0	 0.52	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53222	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53223	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53224	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	53225	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53226	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53227	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53228	 1	 0.0	 0.0	 0.0	 -280.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53229	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53230	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53231	 1	 2.45	 0.37	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53232	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53233	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53234	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53235	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53236	 2	 2.1	 0.45	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53237	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53238	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53239	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53240	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53241	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53242	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53243	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53244	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53245	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53246	 2	 5.45	 1.79	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53247	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53248	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53249	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53250	 1	 0.0	 0.0	 0.0	 -438.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53251	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53252	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53253	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53254	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53255	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53256	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53257	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53258	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53259	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53260	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53261	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53262	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53263	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53264	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53265	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53266	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53267	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53268	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53269	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53270	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53271	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53272	 1	 0.0	 0.0	 0.0	 -92.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53273	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53274	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53275	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53276	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53277	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	53278	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53279	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53280	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53281	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53282	 1	 0.0	 0.0	 0.0	 -66.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53283	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53284	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53285	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53286	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	53287	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53288	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53289	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53290	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53291	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53292	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53293	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	53294	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53295	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53296	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53297	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	53298	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	53299	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53300	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53301	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53302	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53303	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53304	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	53305	 2	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	53306	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	53307	 1	 0.0	 0.0	 0.0	 0.0	 11	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60000	 1	 5.85	 0.67	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60001	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60002	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60003	 1	 42.02	 9.83	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60004	 1	 10.79	 3.01	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60005	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60006	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	60007	 1	 43.48	 6.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60008	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	60009	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60010	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	60011	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60012	 1	 8.51	 3.11	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60013	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60014	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60015	 1	 39.21	 12.67	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60016	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60017	 1	 61.01	 16.91	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60018	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60019	 1	 25.43	 4.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60020	 1	 28.5	 3.3	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60021	 1	 37.03	 3.06	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60022	 1	 37.03	 2.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60023	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60024	 1	 5.75	 0.88	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60025	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60026	 1	 39.65	 4.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60027	 1	 34.96	 8.56	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60028	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60029	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60030	 1	 10.99	 4.79	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60031	 1	 13.83	 5.36	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60032	 1	 10.65	 2.25	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60033	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60034	 1	 14.1	 3.74	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60035	 1	 5.7	 2.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60036	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60037	 1	 36.07	 8.94	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60038	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60039	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60040	 1	 0.73	 0.4	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60041	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60042	 1	 11.46	 0.98	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60043	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60044	 1	 33.82	 13.61	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60045	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60046	 1	 15.49	 4.42	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60047	 1	 4.3	 0.6	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60048	 1	 4.46	 2.42	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60049	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60050	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60051	 1	 27.39	 1.41	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60052	 1	 16.17	 1.69	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60053	 1	 20.13	 11.18	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60054	 1	 15.27	 3.07	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60055	 1	 36.8	 26.2	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60056	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60057	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	60058	 1	 36.8	 14.3	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60059	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60060	 1	 62.53	 16.06	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60061	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60062	 1	 14.06	 6.7	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60063	 1	 10.26	 4.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60064	 1	 14.09	 2.67	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60065	 1	 0.65	 0.15	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60066	 1	 33.59	 4.62	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60067	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60068	 1	 12.75	 7.34	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60069	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60070	 1	 14.29	 1.28	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60071	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60072	 1	 10.03	 3.23	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60073	 1	 18.47	 2.21	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60074	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60075	 1	 21.39	 10.12	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60076	 1	 40.15	 5.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60077	 1	 0.08	 0.01	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60078	 1	 6.4	 1.78	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60079	 1	 43.23	 11.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60080	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60081	 1	 20.34	 3.36	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60082	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60083	 1	 31.5	 5.98	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60084	 1	 25.9	 7.92	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60085	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60086	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60087	 1	 12.36	 2.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60088	 1	 7.43	 0.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60089	 1	 16.01	 7.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60090	 1	 44.35	 8.97	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60091	 1	 8.66	 3.09	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60092	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60093	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60094	 1	 21.36	 2.52	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60095	 1	 25.95	 10.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60096	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60097	 1	 29.63	 4.14	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60098	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60099	 1	 27.17	 21.74	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60100	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60101	 1	 6.37	 1.34	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60102	 1	 11.39	 3.79	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60103	 1	 23.24	 9.95	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60104	 1	 5.33	 1.42	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60105	 1	 7.39	 2.53	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60106	 1	 18.43	 6.42	 0.0	 -30.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60107	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60108	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60109	 1	 15.12	 2.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60110	 1	 18.21	 1.8	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60111	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60112	 1	 10.28	 0.78	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60113	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60114	 1	 19.09	 3.37	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60115	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60116	 1	 7.14	 1.69	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60117	 1	 14.48	 3.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60118	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60119	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60120	 1	 26.97	 3.12	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60121	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60122	 1	 27.46	 10.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60123	 1	 9.8	 1.27	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60124	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60125	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60126	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60127	 1	 15.79	 9.6	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60128	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60129	 1	 22.8	 3.08	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60130	 1	 11.26	 1.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60131	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60132	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60133	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60134	 1	 38.16	 13.79	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60135	 1	 7.39	 1.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60136	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60137	 1	 6.33	 1.16	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60138	 1	 9.82	 0.66	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60139	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60140	 1	 7.14	 2.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60141	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60142	 1	 24.84	 5.4	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60143	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60144	 1	 5.68	 1.24	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60145	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60146	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60147	 1	 14.85	 6.81	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60148	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60149	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60150	 1	 24.6	 7.5	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60151	 1	 65.01	 11.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60152	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60153	 1	 9.96	 5.23	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60154	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60155	 1	 6.56	 0.47	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60156	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60157	 1	 38.66	 8.82	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60158	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60159	 1	 40.76	 8.05	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60160	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60161	 1	 35.02	 7.17	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60162	 1	 46.54	 4.06	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60163	 1	 7.05	 1.34	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60164	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60165	 1	 2.63	 0.46	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60166	 1	 11.6	 6.99	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60167	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60168	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60169	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60170	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60171	 1	 8.55	 2.91	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60172	 1	 13.47	 2.38	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60173	 1	 0.66	 0.08	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60174	 1	 47.35	 6.22	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60175	 1	 33.31	 4.52	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60176	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60177	 1	 33.31	 3.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60178	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60179	 1	 17.1	 1.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60180	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60181	 1	 22.2	 2.59	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60182	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60183	 1	 43.87	 16.58	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60184	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60185	 1	 51.19	 7.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60186	 1	 51.19	 22.57	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60187	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60188	 1	 40.38	 11.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60189	 1	 40.38	 5.22	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60190	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60191	 1	 58.14	 41.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60192	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60193	 1	 39.89	 6.15	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60194	 1	 98.99	 17.16	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60195	 1	 18.88	 0.32	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60196	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60197	 1	 10.46	 3.41	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60198	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60199	 1	 6.85	 0.95	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60200	 1	 50.47	 12.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60201	 1	 50.47	 10.44	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60202	 1	 39.18	 13.95	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60203	 1	 39.18	 6.84	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60204	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60205	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60206	 1	 55.38	 6.87	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60207	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60208	 1	 55.38	 9.57	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60209	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60210	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60211	 1	 40.34	 6.38	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60212	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60213	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60214	 1	 9.97	 1.71	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60215	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60216	 1	 5.34	 0.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60217	 1	 57.44	 17.87	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60218	 1	 57.44	 9.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60219	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60220	 1	 26.48	 8.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60221	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60222	 1	 33.22	 7.48	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60223	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60224	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60225	 1	 33.22	 10.33	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60226	 1	 43.43	 10.98	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60227	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60228	 1	 43.43	 16.01	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60229	 1	 46.66	 0.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60230	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60231	 1	 46.66	 7.19	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60232	 1	 46.39	 24.55	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60233	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60234	 1	 39.07	 10.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60235	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60236	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60237	 1	 39.07	 8.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60238	 1	 32.95	 6.98	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60239	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60240	 1	 7.06	 1.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60241	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60242	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60243	 1	 46.85	 4.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60244	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60245	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60246	 1	 26.77	 10.85	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60247	 1	 0.29	 0.05	 0.0	 26.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60248	 1	 51.38	 7.91	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60249	 1	 51.38	 16.54	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60250	 1	 62.32	 4.67	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60251	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60252	 1	 34.29	 2.16	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60253	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60254	 1	 34.29	 10.98	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60255	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60256	 1	 40.21	 19.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60257	 1	 40.21	 10.19	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60258	 1	 55.67	 8.88	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60259	 1	 43.77	 5.33	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60260	 1	 45.36	 10.08	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60261	 1	 19.68	 0.57	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60262	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60263	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60264	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60265	 1	 46.12	 6.35	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60266	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60267	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60268	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60269	 1	 45.48	 11.59	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60270	 1	 60.93	 8.09	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60271	 1	 60.93	 22.88	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60272	 1	 58.23	 14.68	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60273	 1	 58.23	 15.01	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60274	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60275	 1	 64.53	 6.24	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60276	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60277	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60278	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60279	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60280	 1	 46.0	 9.31	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60281	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60282	 1	 46.0	 12.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60283	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60284	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60285	 1	 26.49	 5.22	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60286	 1	 57.11	 20.3	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60287	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60288	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60289	 1	 57.11	 7.78	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60290	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60291	 1	 23.59	 11.18	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60292	 1	 46.93	 18.5	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60293	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60294	 1	 41.92	 7.41	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60295	 1	 44.11	 12.95	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60296	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60297	 1	 44.11	 5.43	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60298	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60299	 1	 39.86	 7.55	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60300	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60301	 1	 64.95	 9.93	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60302	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60303	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60304	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60305	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60306	 1	 62.94	 30.6	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60307	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60308	 1	 79.68	 8.07	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60309	 1	 79.68	 34.07	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60310	 1	 11.24	 5.06	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60311	 1	 60.94	 11.91	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60312	 1	 60.94	 17.83	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60313	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60314	 1	 41.17	 6.58	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60315	 1	 41.17	 10.05	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60316	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60317	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60318	 1	 62.51	 15.21	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60319	 1	 40.94	 8.31	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60320	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60321	 1	 40.94	 12.8	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60322	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60323	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60324	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60325	 1	 41.06	 17.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60326	 1	 41.06	 9.57	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60327	 1	 36.97	 17.84	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60328	 1	 36.97	 1.78	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60329	 1	 54.25	 3.67	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60330	 1	 49.11	 9.48	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60331	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60332	 1	 49.11	 11.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60333	 1	 35.11	 10.67	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60334	 1	 35.11	 14.71	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60335	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60336	 1	 40.08	 3.33	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60337	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60338	 1	 40.84	 20.2	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60339	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60340	 1	 40.84	 13.06	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60341	 1	 46.66	 17.22	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60342	 1	 46.77	 2.8	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60343	 1	 33.72	 3.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60344	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60345	 1	 33.72	 3.56	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60346	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60347	 1	 26.38	 5.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60348	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60349	 1	 48.98	 6.45	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60350	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60351	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60352	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60353	 1	 46.61	 1.48	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60354	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60355	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60356	 1	 55.97	 5.53	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60357	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60358	 1	 53.46	 18.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60359	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60360	 1	 37.99	 3.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60361	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60362	 1	 44.13	 13.42	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60363	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60364	 1	 44.13	 2.81	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60365	 1	 51.61	 24.14	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60366	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60367	 1	 51.61	 21.45	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60368	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60369	 1	 28.4	 4.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60370	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60371	 1	 64.48	 19.1	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60372	 1	 64.48	 11.65	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60373	 1	 10.68	 1.59	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60374	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60375	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60376	 1	 38.72	 8.73	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60377	 1	 38.72	 13.32	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60378	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60379	 1	 41.27	 12.89	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60380	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60381	 1	 41.27	 20.09	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60382	 1	 46.42	 6.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60383	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60384	 1	 55.95	 8.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60385	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60386	 1	 59.0	 6.1	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60387	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60388	 1	 59.0	 28.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60389	 1	 38.82	 3.87	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60390	 1	 33.47	 9.47	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60391	 1	 52.19	 19.88	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60392	 1	 35.17	 11.92	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60393	 1	 35.17	 10.18	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60394	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60395	 1	 55.16	 11.66	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60396	 1	 43.59	 3.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60397	 1	 43.59	 3.43	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60398	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60399	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60400	 1	 35.96	 6.55	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60401	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60402	 1	 39.86	 15.15	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60403	 1	 82.85	 33.74	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60404	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60405	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60406	 1	 49.4	 17.24	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60407	 1	 19.11	 4.2	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60408	 1	 4.91	 1.52	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60409	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60410	 1	 45.68	 9.52	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60411	 1	 44.77	 27.72	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60412	 1	 57.48	 16.03	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60413	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60414	 1	 46.85	 22.28	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60415	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60416	 1	 19.65	 3.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60417	 1	 41.77	 10.59	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60418	 1	 41.77	 9.94	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60419	 1	 28.74	 7.5	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60420	 1	 26.15	 1.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60421	 1	 33.08	 8.07	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60422	 1	 33.08	 5.62	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60423	 1	 54.23	 22.05	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60424	 1	 52.98	 13.95	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60425	 1	 37.63	 10.94	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60426	 1	 37.63	 17.4	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60427	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60428	 1	 51.65	 13.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60429	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60430	 1	 51.65	 4.69	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60431	 1	 52.24	 13.89	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60432	 1	 29.16	 10.7	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60433	 1	 37.98	 9.33	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60434	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60435	 1	 37.98	 17.02	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60436	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60437	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60438	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60439	 1	 0.0	 0.0	 0.0	 73.5	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60440	 1	 58.79	 7.38	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60441	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60442	 1	 35.62	 15.6	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60443	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60444	 1	 35.62	 1.57	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60445	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60446	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60447	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60448	 1	 17.98	 4.37	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60449	 1	 51.06	 21.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60450	 1	 52.67	 2.08	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60451	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60452	 1	 52.67	 16.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60453	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60454	 1	 42.26	 9.19	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60455	 1	 48.44	 25.74	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60456	 1	 47.72	 31.48	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60457	 1	 60.66	 12.72	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60458	 1	 60.66	 19.71	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60459	 1	 35.86	 15.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60460	 1	 35.86	 5.21	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60461	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60462	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60463	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60464	 1	 34.79	 8.56	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60465	 1	 34.79	 14.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60466	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60467	 1	 39.15	 6.64	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60468	 1	 38.97	 4.36	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60469	 1	 42.18	 13.5	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60470	 1	 10.86	 4.36	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60471	 1	 31.95	 6.44	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60472	 1	 43.98	 11.4	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60473	 1	 43.98	 5.92	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60474	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60475	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60476	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60477	 1	 31.41	 4.65	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60478	 1	 59.9	 9.52	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60479	 1	 55.51	 15.06	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60480	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60481	 1	 68.72	 11.27	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60482	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60483	 1	 68.72	 7.51	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60484	 1	 44.55	 5.46	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60485	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60486	 1	 44.55	 3.47	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60487	 1	 61.7	 19.21	 0.0	 50.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60488	 1	 61.7	 10.71	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60489	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60490	 1	 59.11	 9.28	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60491	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60492	 1	 59.11	 23.43	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60493	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60494	 1	 81.16	 34.98	 0.0	 84.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60495	 1	 81.16	 4.95	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60496	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60497	 1	 71.6	 9.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60498	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60499	 1	 71.6	 18.58	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60500	 1	 46.46	 17.56	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60501	 1	 46.46	 5.44	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60502	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60503	 1	 38.44	 13.57	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60504	 1	 37.43	 13.21	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60505	 1	 38.62	 2.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60506	 1	 38.62	 12.13	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60507	 1	 50.14	 42.32	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60508	 1	 64.38	 13.62	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60509	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60510	 1	 0.0	 0.0	 0.0	 -34.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60511	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60512	 1	 90.46	 32.95	 0.0	 35.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60513	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60514	 1	 90.46	 12.15	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60515	 1	 48.98	 23.26	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60516	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60517	 1	 38.05	 15.19	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60518	 1	 14.79	 0.7	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60519	 1	 31.13	 7.85	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60520	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60521	 1	 39.77	 4.84	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60522	 1	 39.77	 11.82	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60523	 1	 46.22	 33.68	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60524	 1	 50.75	 15.73	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60525	 1	 33.94	 9.92	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60526	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60527	 1	 35.55	 13.48	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60528	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60529	 1	 37.6	 16.78	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60530	 1	 4.06	 1.53	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60531	 1	 33.2	 10.29	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60532	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60533	 1	 10.25	 1.64	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60534	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60535	 1	 45.03	 4.74	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60536	 1	 45.03	 20.25	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60537	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60538	 1	 53.58	 16.03	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60539	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60540	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60541	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60542	 1	 53.58	 24.94	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60543	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60544	 1	 34.51	 3.18	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60545	 1	 34.51	 5.83	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60546	 1	 60.85	 7.18	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60547	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60548	 1	 35.95	 16.3	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60549	 1	 23.94	 5.04	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60550	 1	 43.27	 13.91	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60551	 1	 35.5	 4.89	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60552	 1	 63.18	 15.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60553	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60554	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60555	 1	 63.18	 4.07	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60556	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60557	 1	 38.72	 4.08	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60558	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60559	 1	 38.72	 9.46	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60560	 1	 12.61	 3.6	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60561	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60562	 1	 19.08	 5.97	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60563	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60564	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60565	 1	 19.45	 2.56	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60566	 1	 38.84	 11.19	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60567	 1	 25.07	 2.15	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60568	 1	 11.2	 4.62	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60569	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60570	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60571	 1	 12.27	 1.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60572	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60573	 1	 31.31	 3.46	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60574	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60575	 1	 39.65	 14.63	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60576	 1	 39.65	 16.38	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60577	 1	 32.95	 1.78	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60578	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60579	 1	 11.0	 0.16	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60580	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60581	 1	 32.72	 5.38	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60582	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60583	 1	 57.18	 0.86	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60584	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60585	 1	 7.83	 2.47	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60586	 1	 7.77	 0.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60587	 1	 17.78	 5.02	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60588	 1	 7.75	 0.97	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60589	 1	 21.04	 3.55	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60590	 1	 12.57	 4.52	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60591	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60592	 1	 5.41	 1.25	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60593	 1	 9.44	 2.99	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60594	 1	 6.52	 1.43	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60595	 1	 10.46	 7.24	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60596	 1	 9.32	 2.5	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60597	 1	 45.08	 8.2	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60598	 1	 16.63	 10.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60599	 1	 8.74	 3.55	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60600	 1	 2.37	 0.66	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60601	 1	 8.69	 2.11	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60602	 1	 20.7	 11.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60603	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60604	 1	 26.48	 5.74	 0.0	 10.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60605	 1	 52.79	 11.01	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60606	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60607	 1	 6.65	 1.34	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60608	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60609	 1	 14.84	 4.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60610	 1	 5.82	 1.54	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60611	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60612	 1	 6.11	 0.94	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60613	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60614	 1	 15.68	 3.61	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60615	 1	 28.12	 7.91	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60616	 1	 6.17	 1.66	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60617	 1	 4.73	 0.9	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60618	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60619	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60620	 1	 7.92	 3.7	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60621	 1	 13.79	 2.63	 0.0	 -38.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60622	 1	 3.78	 0.96	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60623	 1	 12.45	 2.62	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60624	 1	 5.74	 1.55	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60625	 1	 5.08	 1.19	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60626	 1	 0.0	 0.0	 0.0	 -58.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60627	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60628	 1	 1.61	 0.32	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60629	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60630	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60631	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60632	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60633	 1	 3.56	 0.76	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60634	 1	 0.0	 0.0	 0.0	 490.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60635	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60636	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60637	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60638	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60639	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60640	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60641	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60642	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60643	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60644	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60645	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60646	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60647	 1	 1.99	 0.56	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60648	 1	 0.0	 0.0	 0.0	 -450.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60649	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60650	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60651	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	60652	 1	 0.28	 0.06	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60653	 1	 0.0	 0.0	 0.0	 -225.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60654	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60655	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60656	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60657	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60658	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60659	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60660	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60661	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60662	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60663	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60664	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60665	 1	 0.0	 0.0	 0.0	 79.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60666	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60667	 1	 3.73	 0.65	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60668	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60669	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60670	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60671	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60672	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60673	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60674	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60675	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60676	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60677	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60678	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60679	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60680	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60681	 1	 4.72	 3.73	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60682	 1	 0.0	 0.0	 0.0	 30.5	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60683	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60684	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60685	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60686	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60687	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60688	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60689	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	60690	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60691	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	60692	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60693	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60694	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60695	 2	 3.47	 1.77	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60696	 2	 4.48	 1.79	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60697	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60698	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60699	 1	 0.58	 0.29	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60700	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60701	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60702	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60703	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60704	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60705	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60706	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60707	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60708	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60709	 1	 0.0	 0.0	 0.0	 -260.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60710	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60711	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60712	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	60713	 1	 0.0	 0.0	 0.0	 93.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60714	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60715	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60716	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60717	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60718	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60719	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60720	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60721	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60722	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60723	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60724	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60725	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60726	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60727	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60728	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60729	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60730	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60731	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60732	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60733	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60734	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60735	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60736	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	60737	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60738	 1	 0.0	 0.0	 0.0	 -27.5	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60739	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60740	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60741	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60742	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60743	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60744	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60745	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60746	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60747	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60748	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60749	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60750	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60751	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	60752	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60753	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60754	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60755	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60756	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60757	 1	 0.0	 0.0	 0.0	 -452.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60758	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60759	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60760	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60761	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60762	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60763	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	60764	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60765	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60766	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60767	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60768	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60769	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60770	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60771	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60772	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60773	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60774	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60775	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60776	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60777	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60778	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60779	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60780	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	60781	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60782	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60783	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60784	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60785	 1	 0.0	 0.0	 0.0	 -644.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60786	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60787	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60788	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	60789	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	60790	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60791	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60792	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60793	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60794	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	60795	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60796	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60797	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60798	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60799	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60800	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60801	 2	 0.0	 0.0	 0.0	 -840.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60802	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60803	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60804	 1	 0.0	 0.0	 0.0	 -518.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60805	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60806	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60807	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60808	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60809	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60810	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60811	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60812	 1	 0.0	 0.0	 0.0	 -44.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60813	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60814	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60815	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60816	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60817	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60818	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60819	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60820	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60821	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60822	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60823	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60824	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60825	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60826	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60827	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60828	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60829	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60830	 1	 0.0	 0.0	 0.0	 -137.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60831	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60832	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60833	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60834	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	60835	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60836	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60837	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60838	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60839	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60840	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	60841	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	60842	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60843	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60844	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60845	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60846	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60847	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60848	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60849	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60850	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60851	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60852	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60853	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60854	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60855	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60856	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60857	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60858	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60859	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60860	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60861	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	60862	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60863	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60864	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60865	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60866	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60867	 1	 0.0	 0.0	 0.0	 -530.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60868	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60869	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60870	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60871	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60872	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60873	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60874	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60875	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60876	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60877	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60878	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60879	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60880	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60881	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60882	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60883	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60884	 1	 0.0	 0.0	 0.0	 -378.0	 12	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	60885	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	60886	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	60887	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60888	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	60889	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60890	 1	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	60891	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60892	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	60893	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60894	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60895	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	60896	 2	 0.0	 0.0	 0.0	 0.0	 12	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70000	 1	 12.27	 3.07	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70001	 1	 10.87	 4.15	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70002	 1	 15.53	 2.99	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70003	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70004	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70005	 1	 6.32	 2.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70006	 1	 43.53	 6.24	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70007	 1	 10.26	 1.95	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70008	 1	 10.22	 3.8	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70009	 1	 10.37	 2.47	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70010	 1	 14.52	 10.37	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70011	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70012	 1	 6.22	 1.36	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70013	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70014	 1	 36.64	 11.05	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70015	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70016	 1	 42.5	 9.15	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70017	 1	 37.14	 16.8	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70018	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70019	 1	 36.36	 15.68	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70020	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70021	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70022	 1	 5.57	 1.09	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70023	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70024	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70025	 1	 34.29	 5.64	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70026	 1	 36.35	 12.41	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70027	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70028	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70029	 1	 14.47	 1.61	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70030	 1	 54.72	 35.76	 0.0	 45.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70031	 1	 11.27	 4.35	 0.0	 -14.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70032	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70033	 1	 20.71	 5.61	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70034	 1	 7.8	 2.52	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70035	 1	 7.89	 0.71	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70036	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70037	 1	 28.36	 15.95	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70038	 1	 6.58	 0.78	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70039	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70040	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70041	 1	 5.38	 1.19	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70042	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70043	 1	 8.96	 1.48	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70044	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70045	 1	 33.65	 3.63	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70046	 1	 33.91	 17.28	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70047	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70048	 1	 23.72	 7.16	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70049	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70050	 1	 37.45	 12.86	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70051	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70052	 1	 39.47	 7.68	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70053	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70054	 1	 40.9	 14.56	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70055	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70056	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	70057	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70058	 1	 10.35	 3.77	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70059	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70060	 1	 10.75	 5.1	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70061	 1	 52.17	 14.58	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70062	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70063	 1	 49.84	 4.04	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70064	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70065	 1	 59.81	 26.72	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70066	 1	 5.6	 0.59	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70067	 1	 40.73	 16.17	 0.0	 25.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70068	 1	 25.19	 11.04	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70069	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70070	 1	 17.85	 2.05	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70071	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70072	 1	 46.13	 11.5	 0.0	 0.0	 13	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	70073	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70074	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	70075	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70076	 1	 46.48	 7.01	 0.0	 0.0	 13	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	70077	 1	 10.73	 6.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70078	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70079	 1	 41.21	 22.56	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70080	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70081	 1	 0.1	 0.04	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70082	 1	 43.02	 12.18	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70083	 1	 7.66	 1.46	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70084	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70085	 1	 50.73	 12.38	 0.0	 0.0	 13	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	70086	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70087	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70088	 1	 4.79	 0.39	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70089	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70090	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70091	 1	 7.46	 1.06	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70092	 1	 8.36	 2.17	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70093	 1	 6.38	 1.4	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70094	 1	 29.97	 17.72	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70095	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70096	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70097	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70098	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70099	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	70100	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70101	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70102	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70103	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70104	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70105	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70106	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70107	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70108	 1	 0.06	 0.02	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70109	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70110	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70111	 2	 2.96	 0.23	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70112	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70113	 1	 0.97	 0.53	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70114	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70115	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70116	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70117	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70118	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70119	 1	 0.35	 0.1	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70120	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	70121	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70122	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70123	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	70124	 1	 1.89	 0.46	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70125	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70126	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70127	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70128	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70129	 1	 0.75	 0.29	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70130	 1	 7.37	 2.89	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70131	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70132	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70133	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70134	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70135	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70136	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	70137	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70138	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	70139	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70140	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	70141	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70142	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70143	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	70144	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70145	 1	 1.07	 0.17	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70146	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70147	 2	 0.66	 0.32	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70148	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70149	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70150	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70151	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70152	 1	 2.53	 0.58	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70153	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70154	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70155	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70156	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70157	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70158	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70159	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70160	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70161	 1	 0.0	 0.0	 0.0	 -88.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70162	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70163	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70164	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70165	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70166	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70167	 2	 4.78	 0.32	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70168	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70169	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70170	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	70171	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70172	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70173	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	70174	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70175	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70176	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70177	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70178	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70179	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70180	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70181	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70182	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70183	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70184	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70185	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70186	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70187	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70188	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	70189	 2	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	70190	 1	 0.0	 0.0	 0.0	 0.0	 13	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74000	 1	 13.58	 1.04	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74001	 1	 16.78	 1.7	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74002	 1	 40.97	 11.41	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74003	 1	 40.97	 8.05	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74004	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74005	 1	 20.28	 8.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74006	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74007	 1	 30.04	 3.25	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74008	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74009	 1	 34.78	 9.28	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74010	 1	 31.52	 12.45	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74011	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74012	 1	 12.96	 2.98	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74013	 1	 37.65	 8.57	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74014	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74015	 1	 44.32	 5.08	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74016	 1	 6.89	 1.58	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74017	 1	 25.52	 6.8	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74018	 1	 18.36	 8.77	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74019	 1	 12.19	 4.75	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74020	 1	 12.66	 1.77	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74021	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74022	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74023	 1	 6.8	 1.09	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74024	 1	 34.12	 13.23	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74025	 1	 34.12	 1.94	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74026	 1	 49.09	 21.69	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74027	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74028	 1	 12.9	 4.54	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74029	 1	 22.07	 6.09	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74030	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74031	 1	 13.53	 2.53	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74032	 1	 2.55	 0.23	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74033	 1	 43.98	 25.25	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74034	 1	 43.61	 14.3	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74035	 1	 43.61	 5.98	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74036	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74037	 1	 54.36	 8.67	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74038	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74039	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74040	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74041	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74042	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74043	 1	 31.47	 9.85	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74044	 1	 31.47	 11.96	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74045	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74046	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74047	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74048	 1	 50.85	 11.88	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74049	 1	 50.85	 7.45	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74050	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74051	 1	 21.95	 5.36	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74052	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74053	 1	 24.44	 4.12	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74054	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74055	 1	 19.01	 1.4	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74056	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74057	 1	 16.4	 6.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74058	 1	 32.67	 4.23	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74059	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74060	 1	 32.67	 5.15	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74061	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74062	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74063	 1	 40.31	 5.07	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74064	 1	 33.93	 7.74	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74065	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74066	 1	 16.2	 1.76	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74067	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74068	 1	 51.81	 8.37	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74069	 1	 51.81	 8.29	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74070	 1	 40.71	 8.69	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74071	 1	 40.71	 16.36	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74072	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74073	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74074	 1	 50.12	 9.66	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74075	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74076	 1	 30.91	 7.75	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74077	 1	 30.91	 14.46	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74078	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74079	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74080	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74081	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74082	 1	 53.89	 6.13	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74083	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74084	 1	 55.04	 2.75	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74085	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74086	 1	 55.04	 15.99	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74087	 1	 44.64	 8.61	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74088	 1	 43.59	 8.82	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74089	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74090	 1	 43.59	 14.51	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74091	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74092	 1	 36.44	 7.28	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74093	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74094	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74095	 1	 29.29	 8.33	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74096	 1	 29.29	 8.63	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74097	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74098	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74099	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74100	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74101	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74102	 1	 32.71	 5.52	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74103	 1	 32.71	 9.59	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74104	 1	 2.87	 0.66	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74105	 1	 49.04	 16.54	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74106	 1	 14.84	 3.07	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74107	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74108	 1	 12.31	 3.88	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74109	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74110	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74111	 1	 27.48	 3.91	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74112	 1	 17.93	 3.82	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74113	 1	 21.14	 5.91	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74114	 1	 4.21	 1.05	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74115	 1	 13.7	 4.38	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74116	 1	 19.24	 2.64	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74117	 1	 31.95	 12.17	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74118	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74119	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74120	 1	 45.74	 14.43	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74121	 1	 5.47	 2.63	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74122	 1	 5.23	 3.51	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74123	 1	 21.18	 5.16	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74124	 1	 11.89	 5.75	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74125	 1	 16.59	 6.76	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74126	 1	 12.98	 6.76	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74127	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74128	 1	 13.4	 2.04	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74129	 1	 57.21	 18.63	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74130	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74131	 1	 57.21	 8.92	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74132	 1	 12.45	 4.24	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74133	 1	 47.27	 15.97	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74134	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74135	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74136	 1	 9.66	 1.74	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74137	 1	 18.81	 3.21	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74138	 1	 6.81	 2.93	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74139	 1	 30.64	 1.67	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74140	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74141	 1	 8.27	 1.48	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74142	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74143	 1	 6.53	 2.32	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74144	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74145	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74146	 1	 17.14	 5.93	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74147	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74148	 1	 10.89	 3.09	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74149	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74150	 1	 41.07	 6.38	 0.0	 -30.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74151	 1	 7.17	 2.76	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74152	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74153	 1	 26.99	 2.66	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74154	 1	 8.91	 3.84	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74155	 1	 7.13	 2.67	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74156	 1	 1.17	 0.06	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74157	 1	 14.02	 2.84	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74158	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74159	 1	 7.59	 3.71	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74160	 1	 42.24	 2.89	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74161	 1	 29.72	 2.83	 0.0	 16.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74162	 1	 33.02	 21.81	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74163	 1	 9.62	 1.41	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74164	 1	 41.6	 1.97	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74165	 1	 40.92	 3.64	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74166	 1	 11.9	 3.33	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74167	 1	 0.0	 0.0	 0.0	 -150.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74168	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	74169	 1	 47.54	 16.68	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74170	 1	 36.86	 9.37	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74171	 1	 28.68	 5.57	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74172	 1	 20.34	 3.25	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74173	 1	 47.53	 33.3	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74174	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74175	 1	 42.35	 9.66	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74176	 1	 46.71	 12.13	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74177	 1	 42.93	 4.9	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74178	 1	 5.75	 0.97	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74179	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74180	 1	 41.7	 15.19	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74181	 1	 41.9	 10.38	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74182	 1	 34.98	 21.26	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74183	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74184	 1	 23.68	 13.94	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74185	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74186	 1	 9.38	 2.89	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74187	 1	 26.28	 15.06	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74188	 1	 11.41	 2.2	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74189	 1	 13.67	 2.59	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74190	 1	 9.92	 2.49	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74191	 1	 20.83	 4.1	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74192	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74193	 1	 2.79	 0.86	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74194	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74195	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74196	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74197	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74198	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74199	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74200	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74201	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74202	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74203	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74204	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74205	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74206	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74207	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74208	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74209	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74210	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74211	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74212	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74213	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74214	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74215	 1	 2.18	 0.43	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74216	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74217	 1	 0.0	 0.0	 0.0	 -92.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74218	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74219	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74220	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74221	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74222	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74223	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74224	 1	 9.75	 2.99	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74225	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74226	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74227	 1	 5.19	 0.79	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74228	 2	 8.78	 3.72	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74229	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74230	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74231	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74232	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74233	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74234	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74235	 1	 5.38	 0.82	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74236	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	74237	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	74238	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74239	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74240	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74241	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74242	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74243	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74244	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74245	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74246	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74247	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74248	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74249	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74250	 1	 0.0	 0.0	 0.0	 -342.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74251	 1	 6.32	 2.52	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74252	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74253	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74254	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74255	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74256	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74257	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74258	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74259	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	74260	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74261	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74262	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74263	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74264	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74265	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74266	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74267	 1	 0.1	 0.01	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74268	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74269	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74270	 2	 2.94	 1.34	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74271	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74272	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74273	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74274	 1	 6.1	 1.85	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74275	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74276	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74277	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74278	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74279	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74280	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74281	 1	 4.7	 1.14	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74282	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74283	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74284	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74285	 1	 3.7	 0.34	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74286	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74287	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74288	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74289	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74290	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74291	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	74292	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74293	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74294	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74295	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74296	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74297	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74298	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74299	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74300	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74301	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74302	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	74303	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74304	 1	 0.0	 0.0	 0.0	 -5.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74305	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74306	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74307	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74308	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74309	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74310	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74311	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74312	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74313	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74314	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74315	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	74316	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74317	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74318	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	74319	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74320	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 161.0	 1	    1.10000	    0.90000;
	74321	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74322	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74323	 1	 0.0	 0.0	 0.0	 -480.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74324	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74325	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74326	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74327	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74328	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74329	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74330	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	74331	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74332	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	74333	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	74334	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74335	 2	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	74336	 1	 0.0	 0.0	 0.0	 0.0	 14	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77000	 1	 6.4	 0.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77001	 1	 8.14	 0.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77002	 1	 49.23	 6.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77003	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77004	 1	 10.73	 4.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77005	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77006	 1	 6.75	 2.15	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77007	 1	 4.36	 0.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77008	 1	 10.95	 1.76	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77009	 1	 7.99	 1.8	 0.0	 10.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77010	 1	 6.01	 2.34	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77011	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77012	 1	 6.96	 2.27	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77013	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77014	 1	 42.91	 7.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77015	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77016	 1	 39.56	 20.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77017	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77018	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77019	 1	 29.95	 13.18	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77020	 1	 29.62	 9.94	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77021	 1	 10.22	 1.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77022	 1	 46.56	 15.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77023	 1	 46.56	 2.33	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77024	 1	 25.9	 11.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77025	 1	 5.77	 2.46	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77026	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77027	 1	 23.34	 7.77	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77028	 1	 3.68	 0.42	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77029	 1	 5.18	 1.32	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77030	 1	 5.94	 1.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77031	 1	 6.64	 1.26	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77032	 1	 7.94	 2.59	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77033	 1	 4.65	 0.51	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77034	 1	 22.3	 6.78	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77035	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77036	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77037	 1	 8.14	 3.21	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77038	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77039	 1	 5.08	 1.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77040	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77041	 1	 26.82	 6.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77042	 1	 9.01	 2.74	 0.0	 -4.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77043	 1	 7.24	 0.39	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77044	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77045	 1	 6.92	 1.41	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77046	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77047	 1	 2.7	 0.62	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77048	 1	 24.43	 4.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77049	 1	 5.66	 1.71	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77050	 1	 7.41	 3.52	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77051	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77052	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77053	 1	 34.22	 3.13	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77054	 1	 31.57	 20.85	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77055	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77056	 1	 5.79	 1.68	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77057	 1	 3.37	 0.76	 0.0	 -42.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77058	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77059	 1	 27.37	 5.6	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77060	 1	 0.0	 0.0	 0.0	 -5.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77061	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77062	 1	 27.37	 4.31	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77063	 1	 36.49	 11.48	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77064	 1	 5.25	 0.64	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77065	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77066	 1	 4.6	 1.04	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77067	 1	 1.31	 0.18	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77068	 1	 27.55	 7.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77069	 1	 32.2	 7.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77070	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77071	 1	 31.44	 16.02	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77072	 1	 0.35	 0.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77073	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77074	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77075	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77076	 1	 26.87	 3.38	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77077	 1	 30.09	 9.16	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77078	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77079	 1	 10.09	 4.93	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77080	 1	 8.74	 2.85	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77081	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77082	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77083	 1	 7.74	 1.89	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77084	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77085	 1	 4.66	 1.46	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77086	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77087	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77088	 1	 9.56	 2.37	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77089	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77090	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77091	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77092	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77093	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77094	 1	 8.52	 0.75	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77095	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77096	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77097	 1	 5.99	 3.53	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77098	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77099	 1	 14.56	 4.07	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77100	 1	 8.18	 2.29	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77101	 1	 48.57	 16.75	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77102	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77103	 1	 14.75	 1.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77104	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77105	 1	 5.78	 0.99	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77106	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77107	 1	 8.95	 3.22	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77108	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77109	 1	 30.99	 12.45	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77110	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77111	 1	 29.31	 6.87	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77112	 1	 4.87	 0.72	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77113	 1	 5.48	 1.28	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77114	 1	 33.74	 18.66	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77115	 1	 33.15	 8.46	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77116	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77117	 1	 9.51	 3.54	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77118	 1	 4.9	 2.3	 0.0	 -4.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77119	 1	 12.85	 1.73	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77120	 1	 16.62	 6.15	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77121	 1	 17.28	 0.75	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77122	 1	 18.91	 1.49	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77123	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77124	 1	 3.08	 1.69	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77125	 1	 4.11	 1.04	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77126	 1	 7.17	 2.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77127	 1	 17.03	 5.63	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77128	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77129	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77130	 1	 39.94	 1.74	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77131	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77132	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77133	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77134	 1	 32.75	 10.27	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77135	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77136	 1	 11.52	 4.03	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77137	 1	 0.0	 0.0	 0.0	 -7.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77138	 1	 6.37	 1.02	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77139	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77140	 1	 30.94	 11.57	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77141	 1	 30.94	 10.45	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77142	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77143	 1	 10.9	 2.97	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77144	 1	 19.23	 2.53	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77145	 1	 4.75	 2.86	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77146	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77147	 1	 35.81	 0.82	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77148	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77149	 1	 20.2	 4.38	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77150	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77151	 1	 27.0	 15.67	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77152	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77153	 1	 19.83	 8.15	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77154	 1	 9.57	 4.65	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77155	 1	 0.0	 0.0	 0.0	 -78.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77156	 1	 27.94	 10.38	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77157	 1	 5.39	 1.1	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77158	 1	 15.07	 9.16	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77159	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77160	 1	 5.96	 0.85	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77161	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77162	 1	 7.07	 2.51	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77163	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77164	 1	 49.69	 20.51	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77165	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77166	 1	 49.69	 25.31	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77167	 1	 6.65	 1.52	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77168	 1	 26.17	 5.44	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77169	 1	 6.7	 0.83	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77170	 1	 0.0	 0.0	 0.0	 -52.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77171	 1	 11.01	 1.05	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77172	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77173	 1	 12.42	 2.95	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77174	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77175	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77176	 1	 4.62	 0.96	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77177	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77178	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77179	 1	 6.7	 3.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77180	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77181	 1	 19.71	 2.81	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77182	 1	 6.01	 1.59	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77183	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77184	 1	 7.15	 1.08	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77185	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77186	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77187	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	77188	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	77189	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77190	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	77191	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77192	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77193	 1	 0.0	 0.0	 0.0	 -125.5	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77194	 1	 1.99	 0.77	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77195	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77196	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77197	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77198	 1	 4.79	 1.29	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77199	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77200	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77201	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77202	 1	 0.0	 0.0	 0.0	 -150.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77203	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77204	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77205	 1	 2.01	 0.33	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77206	 1	 0.88	 0.11	 0.0	 -84.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77207	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77208	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77209	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77210	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77211	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77212	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77213	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77214	 1	 0.0	 0.0	 0.0	 -135.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77215	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77216	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77217	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77218	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77219	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77220	 1	 1.03	 0.29	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77221	 1	 0.0	 0.0	 0.0	 -194.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77222	 1	 3.37	 0.65	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77223	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77224	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77225	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77226	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77227	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77228	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77229	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77230	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77231	 2	 6.07	 2.84	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77232	 1	 0.0	 0.0	 0.0	 -177.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77233	 1	 1.18	 0.41	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77234	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77235	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77236	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77237	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	77238	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77239	 1	 0.0	 0.0	 0.0	 -80.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77240	 1	 1.62	 0.09	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77241	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77242	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77243	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77244	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77245	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77246	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77247	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77248	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	77249	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77250	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77251	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77252	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77253	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77254	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77255	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77256	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77257	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77258	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77259	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77260	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77261	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77262	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77263	 1	 0.0	 0.0	 0.0	 -126.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77264	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77265	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77266	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77267	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77268	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77269	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77270	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77271	 1	 0.0	 0.0	 0.0	 -36.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77272	 1	 0.0	 0.0	 0.0	 -332.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77273	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77274	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77275	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77276	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77277	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77278	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77279	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77280	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77281	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77282	 1	 0.0	 0.0	 0.0	 -100.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77283	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77284	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	77285	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	77286	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 13.2	 1	    1.10000	    0.90000;
	77287	 1	 0.0	 0.0	 0.0	 -61.0	 15	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	77288	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77289	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	77290	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77291	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77292	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77293	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77294	 2	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77295	 1	 0.0	 0.0	 0.0	 0.0	 15	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80000	 1	 57.47	 19.22	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80001	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80002	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80003	 1	 16.43	 2.62	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80004	 1	 32.79	 6.8	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80005	 1	 20.55	 7.07	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80006	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80007	 1	 59.16	 16.82	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80008	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80009	 1	 59.16	 9.94	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80010	 1	 59.16	 16.84	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80011	 1	 48.84	 12.42	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80012	 1	 32.67	 1.79	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80013	 1	 32.67	 15.66	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80014	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80015	 1	 26.05	 4.57	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80016	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80017	 1	 40.32	 3.78	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80018	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80019	 1	 40.32	 7.95	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80020	 1	 42.44	 19.4	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80021	 1	 44.1	 17.09	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80022	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80023	 1	 29.94	 3.61	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80024	 1	 29.94	 4.97	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80025	 1	 6.89	 1.36	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80026	 1	 33.96	 6.51	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80027	 1	 34.31	 15.24	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80028	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80029	 1	 67.92	 8.86	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80030	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80031	 1	 10.06	 1.59	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80032	 1	 8.45	 1.39	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80033	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80034	 1	 46.07	 23.83	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80035	 1	 46.07	 13.57	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80036	 1	 46.74	 14.69	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80037	 1	 46.74	 14.29	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80038	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80039	 1	 41.5	 3.99	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80040	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80041	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80042	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80043	 1	 63.4	 23.34	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80044	 1	 63.4	 23.67	 0.0	 46.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80045	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80046	 1	 85.17	 21.98	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80047	 1	 85.17	 27.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80048	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	80049	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80050	 1	 85.17	 12.29	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80051	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80052	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	80053	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80054	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80055	 1	 44.87	 4.9	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80056	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	80057	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80058	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80059	 1	 44.87	 15.38	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80060	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80061	 1	 30.38	 8.3	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80062	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80063	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80064	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80065	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80066	 1	 13.28	 13.52	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80067	 1	 20.01	 4.11	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80068	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80069	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80070	 1	 56.98	 13.52	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80071	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80072	 1	 56.98	 34.31	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80073	 1	 8.58	 5.36	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80074	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80075	 1	 61.55	 10.84	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80076	 1	 0.0	 0.0	 0.0	 62.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80077	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80078	 1	 61.55	 13.16	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80079	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	80080	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80081	 1	 4.46	 2.83	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80082	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80083	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80084	 1	 1.47	 0.63	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80085	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80086	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	80087	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	80088	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	80089	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80090	 1	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 1.0	 1	    1.10000	    0.90000;
	80091	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 22.0	 1	    1.10000	    0.90000;
	80092	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80093	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80094	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80095	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80096	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	80097	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80098	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80099	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	80100	 2	 0.0	 0.0	 0.0	 0.0	 16	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin	Pc1	Pc2	Qc1min	Qc1max	Qc2min	Qc2max	ramp_agc	ramp_10	ramp_30	ramp_q	apf
mpc.gen = [
	10683	 105.64	 26.68	 61.16	 -7.8	 1.0	 207.74	 0	 159.27	 52.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.27;
	10684	 85.29	 26.68	 61.16	 -7.8	 1.0	 201.13	 1	 85.29	 85.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.2667;
	10685	 138.65	 26.68	 61.16	 -7.8	 1.0	 217.36	 1	 138.65	 138.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.2667;
	10686	 107.655	 26.68	 61.16	 -7.8	 1.0	 214.15	 0	 159.27	 56.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.2667;
	10687	 120.63	 26.68	 61.16	 -7.8	 1.0	 188.08	 1	 120.63	 120.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.2667;
	10688	 109.93	 26.68	 61.16	 -7.8	 1.0	 201.28	 1	 109.93	 109.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.2667;
	10689	 9.02	 2.16	 4.95	 -0.63	 1.0	 12.9	 1	 9.02	 9.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.9;
	10691	 59.72	 3.415	 21.07	 -14.24	 1.0	 98.92	 1	 59.72	 59.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.9;
	10694	 23.02	 5.865	 13.44	 -1.71	 1.0	 35.08	 1	 23.02	 23.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	10695	 25.55	 5.865	 13.44	 -1.71	 1.0	 41.36	 1	 25.55	 25.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	10699	 79.42	 3.475	 21.45	 -14.5	 1.0	 120.64	 1	 79.42	 79.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.7;
	10703	 136.3	 4.7	 29.03	 -19.63	 1.0	 174.64	 1	 136.3	 136.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.3;
	10710	 171.16	 36.28	 83.17	 -10.61	 1.0	 238.48	 1	 171.16	 171.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6;
	10711	 189.67	 36.28	 83.17	 -10.61	 1.0	 219.83	 1	 189.67	 189.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6;
	10712	 135.95	 36.28	 83.17	 -10.61	 1.0	 219.92	 1	 135.95	 135.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6;
	10713	 189.37	 36.28	 83.17	 -10.61	 1.0	 259.93	 1	 189.37	 189.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6;
	10714	 129.665	 36.28	 83.17	 -10.61	 1.0	 235.85	 0	 216.6	 42.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6;
	10715	 172.43	 36.28	 83.17	 -10.61	 1.0	 279.75	 1	 172.43	 172.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6;
	10722	 68.84	 17.57	 40.28	 -5.14	 1.0	 131.4	 0	 104.9	 32.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.9;
	10723	 82.25	 17.57	 40.28	 -5.14	 1.0	 152.84	 1	 82.25	 82.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.9;
	10724	 104.9	 17.57	 40.28	 -5.14	 1.0	 115.76	 1	 104.9	 104.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.9;
	10725	 71.29	 17.57	 40.28	 -5.14	 1.0	 116.27	 1	 71.29	 71.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.9;
	10726	 71.08	 17.57	 40.28	 -5.14	 1.0	 106.56	 1	 71.08	 71.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.9;
	10727	 66.575	 17.57	 40.28	 -5.14	 1.0	 122.59	 0	 104.9	 28.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.9;
	10728	 23.81	 4.68	 10.73	 -1.37	 1.0	 32.27	 1	 23.81	 23.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.95;
	10728	 17.465	 4.68	 10.73	 -1.37	 1.0	 35.8	 0	 27.95	 6.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.95;
	10729	 16.99	 4.68	 10.73	 -1.37	 1.0	 27.95	 0	 27.95	 6.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.95;
	10729	 20.46	 4.68	 10.73	 -1.37	 1.0	 32.33	 1	 20.46	 20.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.95;
	10731	 11.28	 2.835	 6.5	 -0.83	 1.0	 18.62	 0	 16.92	 5.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.92;
	10731	 11.89	 2.835	 6.5	 -0.83	 1.0	 21.25	 0	 16.92	 6.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.92;
	10731	 9.98	 2.835	 6.5	 -0.83	 1.0	 16.92	 0	 16.92	 3.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.92;
	10731	 9.83	 2.835	 6.5	 -0.83	 1.0	 19.89	 1	 9.83	 9.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.92;
	10731	 10.54	 2.835	 6.5	 -0.83	 1.0	 20.51	 0	 16.92	 4.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.92;
	10737	 115.85	 31.67	 81.01	 -17.67	 1.0	 193.29	 1	 159.15	 72.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.15;
	10738	 108.845	 31.67	 81.01	 -17.67	 1.0	 195.43	 1	 159.15	 58.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.15;
	10742	 80.0	 13.4	 30.72	 -3.92	 1.0	 96.14	 1	 80.0	 80.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	10743	 55.985	 13.4	 30.72	 -3.92	 1.0	 93.18	 0	 80.0	 31.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	10744	 64.23	 13.4	 30.72	 -3.92	 1.0	 106.35	 1	 64.23	 64.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	10746	 66.35	 3.105	 19.17	 -12.96	 1.0	 98.26	 1	 66.35	 66.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	10750	 409.37	 68.57	 157.2	 -20.06	 1.0	 498.65	 1	 409.37	 409.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.37;
	10751	 228.385	 68.57	 157.2	 -20.06	 1.0	 454.46	 0	 409.37	 47.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.3667;
	10752	 293.05	 68.57	 157.2	 -20.06	 1.0	 417.45	 1	 293.05	 293.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.3667;
	10753	 229.495	 68.57	 157.2	 -20.06	 1.0	 459.34	 0	 409.37	 49.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.3667;
	10754	 323.1	 68.57	 157.2	 -20.06	 1.0	 487.04	 1	 323.1	 323.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.3667;
	10755	 333.93	 68.57	 157.2	 -20.06	 1.0	 548.59	 1	 333.93	 333.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.37;
	10757	 40.5	 6.785	 15.55	 -1.98	 1.0	 45.68	 1	 40.5	 40.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	10757	 40.5	 6.785	 15.55	 -1.98	 1.0	 47.33	 1	 40.5	 40.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	10757	 28.94	 6.785	 15.55	 -1.98	 1.0	 57.72	 1	 28.94	 28.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	10757	 25.04	 6.785	 15.55	 -1.98	 1.0	 56.8	 0	 40.5	 9.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.5;
	10758	 37.51	 9.315	 21.35	 -2.72	 1.0	 64.74	 0	 55.6	 19.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.6;
	10758	 55.6	 9.315	 21.35	 -2.72	 1.0	 63.99	 1	 55.6	 55.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.6;
	10760	 37.28	 0.0	 0.0	 0.0	 1.0	 69.12	 0	 61.5	 13.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	10768	 212.51	 9.205	 56.83	 -38.42	 1.0	 301.55	 1	 212.51	 212.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 266.8;
	10771	 51.82	 8.68	 19.9	 -2.54	 1.0	 72.35	 1	 51.82	 51.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.825;
	10772	 41.62	 8.68	 19.9	 -2.54	 1.0	 52.68	 1	 41.62	 41.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.825;
	10773	 36.35	 8.68	 19.9	 -2.54	 1.0	 66.71	 0	 51.82	 20.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.83;
	10774	 41.38	 8.68	 19.9	 -2.54	 1.0	 57.61	 1	 41.38	 41.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.825;
	10776	 15.885	 0.0	 0.0	 0.0	 1.0	 32.07	 0	 28.0	 3.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	10776	 14.32	 0.0	 0.0	 0.0	 1.0	 23.98	 1	 14.32	 14.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	10778	 8.03	 1.675	 3.84	 -0.49	 1.0	 11.56	 1	 8.03	 8.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	10778	 14.8	 2.475	 5.68	 -0.73	 1.0	 14.94	 1	 14.8	 14.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	10782	 13.43	 0.0	 0.0	 0.0	 1.0	 27.32	 1	 13.43	 13.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3333;
	10782	 14.65	 0.0	 0.0	 0.0	 1.0	 18.63	 1	 14.65	 14.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3333;
	10783	 13.24	 0.0	 0.0	 0.0	 1.0	 22.11	 1	 13.24	 13.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3333;
	10784	 17.21	 0.0	 0.0	 0.0	 1.0	 43.83	 1	 17.21	 17.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4;
	10784	 42.83	 0.0	 0.0	 0.0	 1.0	 64.64	 1	 42.83	 42.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.2;
	10785	 39.4	 0.0	 0.0	 0.0	 1.0	 44.46	 1	 39.4	 39.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4;
	10785	 31.08	 0.0	 0.0	 0.0	 1.0	 49.64	 1	 31.08	 31.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.4;
	10791	 58.2	 3.635	 22.43	 -15.16	 1.0	 136.19	 1	 58.2	 58.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3;
	10796	 24.56	 8.3	 21.23	 -4.63	 1.0	 55.57	 0	 41.7	 7.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.7;
	10797	 25.265	 8.3	 21.23	 -4.63	 1.0	 62.55	 1	 41.7	 8.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.7;
	10797	 29.17	 8.3	 21.23	 -4.63	 1.0	 41.7	 1	 41.7	 16.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.7;
	10798	 27.755	 8.3	 21.23	 -4.63	 1.0	 41.7	 1	 41.7	 13.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.7;
	10800	 82.34	 3.375	 20.83	 -14.08	 1.0	 129.15	 1	 82.34	 82.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.8;
	10802	 10.22	 2.01	 4.61	 -0.59	 1.0	 14.15	 1	 10.22	 10.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	10803	 12.0	 2.01	 4.61	 -0.59	 1.0	 12.12	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	10806	 34.74	 7.64	 17.51	 -2.23	 1.0	 52.42	 1	 34.74	 34.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.6;
	10806	 42.97	 7.64	 17.51	 -2.23	 1.0	 61.48	 1	 42.97	 42.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.6;
	10807	 33.305	 7.64	 17.51	 -2.23	 1.0	 68.4	 0	 45.6	 21.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.6;
	10807	 30.26	 7.64	 17.51	 -2.23	 1.0	 51.24	 1	 30.26	 30.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.6;
	10811	 834.565	 171.6	 441.6	 -98.4	 1.0	 1400.38	 1	 1200.0	 469.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1200.0;
	10813	 56.32	 11.225	 25.73	 -3.28	 1.0	 74.5	 1	 56.32	 56.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	10813	 48.685	 11.225	 25.73	 -3.28	 1.0	 91.7	 0	 67.0	 30.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.0;
	10817	 50.7	 0.0	 0.0	 0.0	 1.0	 68.96	 1	 50.7	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.7;
	10818	 4.765	 0.0	 0.0	 0.0	 1.0	 7.2	 0	 7.2	 2.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.2;
	10821	 107.525	 5.22	 32.21	 -21.77	 1.0	 208.02	 0	 151.2	 63.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 151.2;
	10829	 75.24	 22.61	 51.84	 -6.62	 1.0	 168.3	 1	 75.24	 75.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10830	 135.0	 22.61	 51.84	 -6.62	 1.0	 159.7	 1	 135.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10831	 106.15	 22.61	 51.84	 -6.62	 1.0	 152.07	 1	 106.15	 106.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10832	 135.0	 22.61	 51.84	 -6.62	 1.0	 143.54	 1	 135.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10833	 88.14	 22.61	 51.84	 -6.62	 1.0	 177.11	 1	 88.14	 88.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10834	 75.59	 22.61	 51.84	 -6.62	 1.0	 175.15	 1	 75.59	 75.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10836	 54.735	 17.69	 45.25	 -9.87	 1.0	 116.35	 1	 88.9	 20.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.9;
	10836	 51.91	 17.69	 45.25	 -9.87	 1.0	 90.43	 1	 88.9	 14.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.9;
	10838	 45.58	 0.0	 0.0	 0.0	 1.0	 91.58	 1	 45.58	 45.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.0;
	10842	 10.5	 2.145	 4.92	 -0.63	 1.0	 12.8	 1	 10.5	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	10842	 8.22	 2.145	 4.92	 -0.63	 1.0	 16.02	 1	 8.22	 8.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	10843	 11.05	 2.145	 4.92	 -0.63	 1.0	 13.06	 1	 11.05	 11.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	10843	 8.18	 2.145	 4.92	 -0.63	 1.0	 14.28	 0	 12.8	 3.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	10843	 8.89	 2.145	 4.92	 -0.63	 1.0	 12.8	 1	 8.89	 8.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	10847	 100.5	 16.835	 38.59	 -4.92	 1.0	 118.86	 1	 100.5	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	10848	 78.52	 16.835	 38.59	 -4.92	 1.0	 140.04	 1	 78.52	 78.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	10849	 83.39	 16.835	 38.59	 -4.92	 1.0	 128.45	 1	 83.39	 83.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	10850	 87.3	 16.835	 38.59	 -4.92	 1.0	 120.81	 1	 87.3	 87.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	10851	 80.36	 16.835	 38.59	 -4.92	 1.0	 108.12	 1	 80.36	 80.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	10852	 99.06	 16.835	 38.59	 -4.92	 1.0	 100.5	 1	 99.06	 99.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	10853	 6.715	 1.675	 3.84	 -0.49	 1.0	 13.29	 0	 10.0	 3.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	10859	 543.575	 125.54	 340.13	 -89.05	 1.0	 844.8	 0	 729.9	 357.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 729.9;
	10860	 521.045	 125.54	 340.13	 -89.05	 1.0	 887.05	 1	 729.9	 312.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 729.9;
	10864	 103.61	 25.125	 57.6	 -7.35	 1.0	 187.87	 1	 103.61	 103.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	10865	 110.96	 25.125	 57.6	 -7.35	 1.0	 209.0	 1	 110.96	 110.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	10867	 11.12	 2.51	 5.76	 -0.74	 1.0	 15.21	 1	 11.12	 11.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	10867	 11.39	 2.51	 5.76	 -0.74	 1.0	 20.37	 1	 11.39	 11.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	10869	 6.555	 1.675	 3.84	 -0.49	 1.0	 10.0	 0	 10.0	 3.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	10869	 10.0	 1.675	 3.84	 -0.49	 1.0	 11.12	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	10872	 44.945	 12.3	 31.46	 -6.86	 1.0	 90.38	 1	 61.8	 28.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.8;
	10873	 21.91	 4.96	 11.37	 -1.45	 1.0	 33.07	 1	 21.91	 21.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.6;
	10873	 17.095	 4.96	 11.37	 -1.45	 1.0	 38.51	 0	 29.6	 4.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.6;
	10879	 70.43	 22.61	 51.84	 -6.62	 1.0	 149.8	 1	 70.43	 70.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10880	 109.22	 22.61	 51.84	 -6.62	 1.0	 177.0	 1	 109.22	 109.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10881	 73.16	 22.61	 51.84	 -6.62	 1.0	 178.0	 1	 73.16	 73.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10882	 80.925	 22.61	 51.84	 -6.62	 1.0	 183.66	 0	 135.0	 26.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10883	 96.27	 22.61	 51.84	 -6.62	 1.0	 146.95	 0	 135.0	 57.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10884	 118.13	 22.61	 51.84	 -6.62	 1.0	 153.95	 1	 118.13	 118.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10889	 65.715	 17.47	 44.69	 -9.75	 1.0	 110.05	 1	 87.8	 43.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.8;
	10890	 26.4	 7.505	 19.19	 -4.18	 1.0	 38.42	 0	 37.7	 15.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.7;
	10895	 66.475	 18.71	 47.85	 -10.43	 1.0	 115.42	 1	 94.0	 38.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	10896	 52.805	 18.71	 47.85	 -10.43	 1.0	 108.98	 1	 94.0	 11.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	10897	 61.335	 18.71	 47.85	 -10.43	 1.0	 118.83	 1	 94.0	 28.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	10898	 66.86	 18.71	 47.85	 -10.43	 1.0	 138.07	 1	 94.0	 39.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.0;
	10901	 36.21	 7.705	 17.66	 -2.25	 1.0	 61.88	 1	 36.21	 36.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	10902	 28.065	 7.705	 17.66	 -2.25	 1.0	 46.65	 0	 46.0	 10.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	10904	 37.13	 1.725	 10.65	 -7.2	 1.0	 64.29	 1	 37.13	 37.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	10908	 115.41	 28.62	 65.61	 -8.37	 1.0	 202.81	 1	 115.41	 115.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.8667;
	10909	 104.05	 28.62	 65.61	 -8.37	 1.0	 171.05	 0	 170.87	 37.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.8667;
	10910	 99.62	 28.62	 65.61	 -8.37	 1.0	 185.54	 1	 99.62	 99.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.8667;
	10911	 111.375	 28.62	 65.61	 -8.37	 1.0	 205.0	 0	 170.87	 51.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.8667;
	10912	 116.3	 28.62	 65.61	 -8.37	 1.0	 246.02	 1	 116.3	 116.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.87;
	10913	 94.215	 28.62	 65.61	 -8.37	 1.0	 188.36	 0	 170.87	 17.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.8667;
	10914	 7.23	 1.575	 3.61	 -0.46	 1.0	 9.4	 1	 7.23	 7.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.4;
	10919	 112.5	 18.845	 43.2	 -5.51	 1.0	 148.42	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	10920	 80.83	 18.845	 43.2	 -5.51	 1.0	 112.95	 0	 112.5	 49.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	10921	 93.79	 18.845	 43.2	 -5.51	 1.0	 131.63	 1	 93.79	 93.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	10922	 77.5	 18.845	 43.2	 -5.51	 1.0	 153.59	 0	 112.5	 42.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	10923	 52.245	 16.835	 43.06	 -9.39	 1.0	 107.98	 1	 84.6	 19.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.6;
	10923	 59.8	 16.835	 43.06	 -9.39	 1.0	 85.56	 1	 84.6	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.6;
	10925	 16.8	 2.815	 6.45	 -0.82	 1.0	 16.87	 1	 16.8	 16.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.8;
	10925	 6.52	 1.255	 2.88	 -0.37	 1.0	 8.37	 1	 6.52	 6.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	10930	 158.415	 46.3	 118.43	 -25.83	 1.0	 310.59	 1	 232.67	 84.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 232.6667;
	10931	 135.32	 46.3	 118.43	 -25.83	 1.0	 290.05	 1	 232.67	 37.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 232.6667;
	10932	 161.72	 46.3	 118.43	 -25.83	 1.0	 261.17	 1	 232.67	 90.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 232.6667;
	10933	 50.0	 1.725	 10.65	 -7.2	 1.0	 50.0	 1	 50.0	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	10934	 36.0	 6.03	 13.82	 -1.76	 1.0	 39.66	 1	 36.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	10934	 36.0	 6.03	 13.82	 -1.76	 1.0	 53.42	 1	 36.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	10938	 14.84	 0.0	 0.0	 0.0	 1.0	 20.22	 1	 14.84	 14.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	10939	 7.5	 0.0	 0.0	 0.0	 1.0	 8.1	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	10940	 7.5	 0.0	 0.0	 0.0	 1.0	 8.27	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	10944	 123.26	 22.61	 51.84	 -6.62	 1.0	 147.93	 1	 123.26	 123.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10945	 118.78	 22.61	 51.84	 -6.62	 1.0	 194.09	 1	 118.78	 118.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10946	 135.0	 22.61	 51.84	 -6.62	 1.0	 154.67	 1	 135.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10947	 109.12	 22.61	 51.84	 -6.62	 1.0	 200.23	 1	 109.12	 109.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10948	 89.95	 22.61	 51.84	 -6.62	 1.0	 185.19	 0	 135.0	 44.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10949	 90.42	 22.61	 51.84	 -6.62	 1.0	 172.19	 1	 90.42	 90.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	10951	 12.05	 3.24	 7.43	 -0.95	 1.0	 19.99	 0	 19.35	 4.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.35;
	10951	 13.865	 3.24	 7.43	 -0.95	 1.0	 21.18	 0	 19.35	 8.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.35;
	10955	 32.11	 5.695	 13.06	 -1.67	 1.0	 34.02	 1	 32.11	 32.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	10955	 17.04	 5.695	 13.06	 -1.67	 1.0	 41.9	 1	 17.04	 17.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	10956	 19.355	 5.695	 13.06	 -1.67	 1.0	 44.38	 0	 34.0	 4.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	10956	 25.415	 5.695	 13.06	 -1.67	 1.0	 45.23	 0	 34.0	 16.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	10959	 221.29	 9.045	 55.85	 -37.76	 1.0	 336.76	 1	 221.29	 221.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.2;
	10965	 245.83	 11.825	 73.0	 -49.35	 1.0	 382.51	 0	 342.7	 148.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 342.7;
	10966	 4.875	 1.155	 2.65	 -0.34	 1.0	 6.96	 0	 6.9	 2.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9;
	10966	 5.28	 1.155	 2.65	 -0.34	 1.0	 9.31	 1	 5.28	 5.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9;
	10966	 20.12	 4.605	 10.56	 -1.35	 1.0	 36.0	 1	 20.12	 20.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	10969	 18.465	 5.17	 13.23	 -2.89	 1.0	 32.28	 0	 26.0	 10.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0;
	10972	 13.16	 2.93	 6.72	 -0.86	 1.0	 18.98	 1	 13.16	 13.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	10972	 17.5	 2.93	 6.72	 -0.86	 1.0	 21.37	 1	 17.5	 17.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	10973	 12.96	 2.93	 6.72	 -0.86	 1.0	 21.11	 0	 17.5	 8.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	10973	 17.5	 2.93	 6.72	 -0.86	 1.0	 19.51	 1	 17.5	 17.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	10978	 95.9	 3.31	 20.43	 -13.81	 1.0	 103.8	 1	 95.9	 95.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.9;
	10981	 97.59	 4.7	 29.03	 -19.63	 1.0	 168.9	 1	 97.59	 97.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.3;
	10982	 92.02	 4.7	 29.03	 -19.63	 1.0	 154.45	 1	 92.02	 92.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 136.3;
	10985	 199.0	 6.865	 42.39	 -28.66	 1.0	 199.13	 1	 199.0	 199.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0;
	10989	 140.28	 43.115	 110.28	 -24.05	 1.0	 295.91	 1	 216.67	 63.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.67;
	10990	 136.815	 43.115	 110.28	 -24.05	 1.0	 242.35	 1	 216.67	 56.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6667;
	10991	 119.68	 43.115	 110.28	 -24.05	 1.0	 322.3	 1	 216.67	 22.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.67;
	10993	 15.145	 3.455	 7.92	 -1.01	 1.0	 24.82	 0	 20.62	 9.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.625;
	10993	 14.155	 3.455	 7.92	 -1.01	 1.0	 21.05	 0	 20.62	 7.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.63;
	10994	 12.39	 3.455	 7.92	 -1.01	 1.0	 30.93	 0	 20.62	 4.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.63;
	10995	 20.62	 3.455	 7.92	 -1.01	 1.0	 25.07	 1	 20.62	 20.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.625;
	10998	 16.51	 4.19	 9.6	 -1.22	 1.0	 34.25	 1	 16.51	 16.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	10998	 25.0	 4.19	 9.6	 -1.22	 1.0	 28.91	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	11005	 93.475	 28.285	 72.35	 -15.78	 1.0	 171.01	 1	 142.15	 44.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.15;
	11006	 79.055	 28.285	 72.35	 -15.78	 1.0	 185.88	 1	 142.15	 15.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.15;
	11008	 21.6	 3.615	 8.29	 -1.06	 1.0	 27.1	 1	 21.6	 21.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	11009	 16.3	 3.615	 8.29	 -1.06	 1.0	 22.46	 1	 16.3	 16.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	11009	 5.97	 2.145	 4.92	 -0.63	 1.0	 19.2	 1	 5.97	 5.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	11014	 812.69	 181.32	 415.68	 -53.04	 1.0	 1169.43	 1	 812.69	 812.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1082.5;
	11015	 680.16	 181.32	 415.68	 -53.04	 1.0	 1277.21	 0	 1082.5	 277.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1082.5;
	11016	 1082.5	 181.32	 415.68	 -53.04	 1.0	 1357.65	 1	 1082.5	 1082.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1082.5;
	11017	 648.375	 181.32	 415.68	 -53.04	 1.0	 1214.02	 0	 1082.5	 214.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1082.5;
	11018	 885.08	 181.32	 415.68	 -53.04	 1.0	 1082.5	 1	 885.08	 885.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1082.5;
	11019	 754.61	 181.32	 415.68	 -53.04	 1.0	 1299.87	 1	 754.61	 754.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1082.5;
	11020	 52.33	 8.77	 20.1	 -2.56	 1.0	 59.07	 1	 52.33	 52.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.3333;
	11021	 26.5	 8.77	 20.1	 -2.56	 1.0	 56.77	 1	 26.5	 26.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.3333;
	11022	 30.27	 8.77	 20.1	 -2.56	 1.0	 61.87	 0	 52.33	 8.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.3333;
	11023	 40.81	 8.77	 20.1	 -2.56	 1.0	 66.3	 1	 40.81	 40.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.3333;
	11024	 37.81	 8.77	 20.1	 -2.56	 1.0	 75.12	 0	 52.33	 23.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.3333;
	11025	 40.92	 8.77	 20.1	 -2.56	 1.0	 61.62	 1	 40.92	 40.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.3333;
	11031	 55.65	 18.94	 48.44	 -10.56	 1.0	 125.95	 1	 95.17	 16.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.17;
	11032	 58.985	 18.94	 48.44	 -10.56	 1.0	 114.43	 1	 95.17	 22.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.1667;
	11033	 58.305	 18.94	 48.44	 -10.56	 1.0	 118.26	 1	 95.17	 21.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.1667;
	11035	 14.85	 0.0	 0.0	 0.0	 1.0	 17.51	 1	 14.85	 14.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	11035	 7.71	 0.0	 0.0	 0.0	 1.0	 15.95	 1	 7.71	 7.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	11035	 10.195	 0.0	 0.0	 0.0	 1.0	 16.37	 0	 14.85	 5.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	11035	 10.88	 0.0	 0.0	 0.0	 1.0	 14.85	 0	 14.85	 6.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.85;
	11037	 9.69	 2.01	 4.61	 -0.59	 1.0	 12.0	 1	 9.69	 9.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	11037	 37.76	 8.775	 20.12	 -2.57	 1.0	 71.38	 1	 37.76	 37.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.4;
	11037	 29.325	 8.775	 20.12	 -2.57	 1.0	 72.34	 0	 52.4	 6.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.4;
	11041	 125.16	 29.03	 66.55	 -8.49	 1.0	 233.04	 0	 173.3	 77.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	11042	 126.245	 29.03	 66.55	 -8.49	 1.0	 173.3	 0	 173.3	 79.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	11043	 127.075	 29.03	 66.55	 -8.49	 1.0	 173.89	 0	 173.3	 80.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	11044	 108.155	 29.03	 66.55	 -8.49	 1.0	 198.62	 0	 173.3	 43.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	11045	 131.96	 29.03	 66.55	 -8.49	 1.0	 213.54	 1	 131.96	 131.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	11046	 129.26	 29.03	 66.55	 -8.49	 1.0	 205.09	 1	 129.26	 129.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	11047	 22.81	 4.49	 10.29	 -1.31	 1.0	 31.77	 1	 22.81	 22.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.8;
	11050	 181.895	 49.35	 126.23	 -27.53	 1.0	 301.43	 1	 248.0	 115.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.0;
	11052	 44.37	 2.7	 16.68	 -11.28	 1.0	 84.32	 1	 44.37	 44.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.3;
	11053	 51.88	 2.7	 16.68	 -11.28	 1.0	 87.82	 1	 51.88	 51.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.3;
	11054	 6.59	 1.34	 3.07	 -0.39	 1.0	 12.0	 1	 6.59	 6.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	11054	 5.96	 1.34	 3.07	 -0.39	 1.0	 12.0	 1	 5.96	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	11054	 6.19	 1.34	 3.07	 -0.39	 1.0	 8.98	 1	 6.19	 6.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	11054	 4.46	 1.34	 3.07	 -0.39	 1.0	 9.73	 0	 8.0	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	11060	 105.3	 3.635	 22.43	 -15.16	 1.0	 131.75	 1	 105.3	 105.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3;
	11061	 105.3	 3.635	 22.43	 -15.16	 1.0	 119.42	 1	 105.3	 105.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.3;
	11062	 7.395	 2.265	 5.8	 -1.27	 1.0	 14.44	 0	 11.4	 3.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	11062	 6.81	 2.265	 5.8	 -1.27	 1.0	 12.63	 0	 11.4	 2.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	11062	 6.57	 2.265	 5.8	 -1.27	 1.0	 13.52	 0	 11.4	 1.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	11062	 7.08	 2.265	 5.8	 -1.27	 1.0	 12.63	 1	 11.4	 2.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	11065	 130.66	 6.105	 37.68	 -25.47	 1.0	 186.09	 1	 130.66	 130.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.9;
	11069	 204.0	 7.035	 43.45	 -29.38	 1.0	 219.02	 1	 204.0	 204.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	11072	 96.825	 31.745	 81.19	 -17.7	 1.0	 217.04	 1	 159.5	 34.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5;
	11073	 93.905	 31.745	 81.19	 -17.7	 1.0	 217.26	 1	 159.5	 28.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5;
	11077	 100.99	 21.61	 49.54	 -6.32	 1.0	 148.12	 1	 100.99	 100.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	11078	 76.435	 21.61	 49.54	 -6.32	 1.0	 129.99	 0	 129.0	 23.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	11079	 84.92	 21.61	 49.54	 -6.32	 1.0	 146.73	 1	 84.92	 84.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	11080	 106.47	 21.61	 49.54	 -6.32	 1.0	 154.9	 1	 106.47	 106.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	11081	 77.205	 21.61	 49.54	 -6.32	 1.0	 178.44	 0	 129.0	 25.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	11082	 98.22	 21.61	 49.54	 -6.32	 1.0	 164.44	 1	 98.22	 98.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 129.0;
	13454	 38.1	 6.38	 14.63	 -1.87	 1.0	 54.77	 1	 38.1	 38.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.1;
	13454	 38.1	 6.38	 14.63	 -1.87	 1.0	 38.54	 1	 38.1	 38.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.1;
	13454	 26.18	 6.38	 14.63	 -1.87	 1.0	 46.66	 1	 26.18	 26.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.1;
	13458	 98.7	 3.405	 21.02	 -14.21	 1.0	 123.85	 1	 98.7	 98.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.7;
	13460	 13.81	 2.88	 6.6	 -0.84	 1.0	 25.8	 1	 13.81	 13.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	13460	 31.36	 8.265	 18.95	 -2.42	 1.0	 49.98	 1	 31.36	 31.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.35;
	13460	 49.35	 8.265	 18.95	 -2.42	 1.0	 67.15	 1	 49.35	 49.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.35;
	13462	 19.7	 6.855	 17.54	 -3.83	 1.0	 48.12	 1	 34.47	 4.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.47;
	13462	 20.52	 6.855	 17.54	 -3.83	 1.0	 40.73	 0	 34.47	 6.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.4667;
	13462	 22.865	 6.855	 17.54	 -3.83	 1.0	 38.66	 0	 34.47	 11.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.4667;
	13462	 22.795	 6.855	 17.54	 -3.83	 1.0	 41.38	 1	 34.47	 11.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.4667;
	13462	 20.09	 6.855	 17.54	 -3.83	 1.0	 43.77	 1	 34.47	 5.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.4667;
	13462	 20.9	 6.855	 17.54	 -3.83	 1.0	 45.16	 1	 34.47	 7.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.47;
	13466	 86.5	 4.24	 26.16	 -17.68	 1.0	 122.8	 1	 86.5	 86.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.8;
	13468	 100.5	 3.47	 21.41	 -14.47	 1.0	 112.55	 1	 100.5	 100.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.5;
	13475	 165.08	 27.65	 63.39	 -8.09	 1.0	 174.09	 1	 165.08	 165.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0833;
	13476	 139.14	 27.65	 63.39	 -8.09	 1.0	 196.06	 1	 139.14	 139.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0833;
	13477	 165.08	 27.65	 63.39	 -8.09	 1.0	 177.07	 1	 165.08	 165.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.08;
	13478	 91.995	 27.65	 63.39	 -8.09	 1.0	 222.63	 0	 165.08	 18.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0833;
	13479	 131.28	 27.65	 63.39	 -8.09	 1.0	 216.38	 1	 131.28	 131.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0833;
	13480	 96.69	 27.65	 63.39	 -8.09	 1.0	 216.22	 1	 96.69	 96.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.0833;
	13483	 69.42	 3.475	 21.45	 -14.5	 1.0	 108.22	 0	 100.7	 38.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.7;
	13486	 148.75	 5.13	 31.68	 -21.42	 1.0	 199.93	 1	 148.75	 148.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.75;
	13487	 148.75	 5.13	 31.68	 -21.42	 1.0	 183.91	 1	 148.75	 148.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.75;
	13488	 34.82	 8.375	 19.2	 -2.45	 1.0	 61.01	 0	 50.0	 19.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	13488	 37.31	 8.375	 19.2	 -2.45	 1.0	 65.05	 1	 37.31	 37.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	13489	 12.29	 3.015	 6.91	 -0.88	 1.0	 27.0	 0	 18.0	 6.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	13492	 27.65	 0.0	 0.0	 0.0	 1.0	 30.51	 1	 27.65	 27.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.65;
	13493	 16.25	 0.0	 0.0	 0.0	 1.0	 21.01	 1	 16.25	 16.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	13494	 19.955	 0.0	 0.0	 0.0	 1.0	 36.15	 0	 27.65	 12.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.65;
	13499	 229.4	 60.3	 138.24	 -17.64	 1.0	 500.74	 1	 229.4	 229.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0;
	13500	 209.125	 60.3	 138.24	 -17.64	 1.0	 365.65	 0	 360.0	 58.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0;
	13501	 290.08	 60.3	 138.24	 -17.64	 1.0	 442.29	 1	 290.08	 290.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0;
	13502	 304.83	 60.3	 138.24	 -17.64	 1.0	 363.69	 1	 304.83	 304.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0;
	13503	 231.15	 60.3	 138.24	 -17.64	 1.0	 413.28	 1	 231.15	 231.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0;
	13504	 316.7	 60.3	 138.24	 -17.64	 1.0	 370.08	 1	 316.7	 316.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 360.0;
	13509	 168.175	 45.73	 116.97	 -25.51	 1.0	 309.23	 1	 229.8	 106.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.8;
	13510	 170.16	 45.73	 116.97	 -25.51	 1.0	 271.04	 1	 229.8	 110.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.8;
	13511	 171.59	 45.73	 116.97	 -25.51	 1.0	 247.19	 1	 229.8	 113.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.8;
	13512	 29.35	 0.0	 0.0	 0.0	 1.0	 44.14	 1	 29.35	 29.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	13513	 10.46	 2.51	 5.76	 -0.74	 1.0	 17.2	 1	 10.46	 10.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	13513	 8.65	 2.51	 5.76	 -0.74	 1.0	 15.0	 1	 8.65	 8.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	13515	 21.57	 0.855	 5.3	 -3.59	 1.0	 25.35	 1	 21.57	 21.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	13515	 22.57	 0.855	 5.3	 -3.59	 1.0	 25.59	 1	 22.57	 22.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	13518	 119.83	 5.17	 31.93	 -21.59	 1.0	 206.81	 1	 119.83	 119.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.9;
	13519	 132.39	 5.17	 31.93	 -21.59	 1.0	 212.76	 1	 132.39	 132.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.9;
	13520	 149.9	 5.17	 31.93	 -21.59	 1.0	 166.65	 1	 149.9	 149.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 149.9;
	13521	 7.46	 0.31	 1.92	 -1.3	 1.0	 9.0	 1	 7.46	 7.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	13522	 18.055	 5.85	 14.96	 -3.26	 1.0	 31.88	 1	 29.4	 6.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	13522	 20.545	 5.85	 14.96	 -3.26	 1.0	 43.2	 0	 29.4	 11.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	13522	 17.125	 5.85	 14.96	 -3.26	 1.0	 32.48	 1	 29.4	 4.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	13522	 18.485	 5.85	 14.96	 -3.26	 1.0	 32.71	 0	 29.4	 7.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	13526	 124.17	 20.8	 47.68	 -6.08	 1.0	 125.79	 1	 124.17	 124.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.1667;
	13527	 68.07	 20.8	 47.68	 -6.08	 1.0	 148.86	 1	 68.07	 68.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.1667;
	13528	 84.575	 20.8	 47.68	 -6.08	 1.0	 124.71	 0	 124.17	 44.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.17;
	13530	 60.82	 3.725	 23.0	 -15.55	 1.0	 113.89	 1	 60.82	 60.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	13533	 9.9	 2.175	 4.99	 -0.64	 1.0	 16.27	 1	 9.9	 9.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	13534	 13.0	 2.175	 4.99	 -0.64	 1.0	 13.21	 1	 13.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	13539	 115.495	 30.905	 79.05	 -17.24	 1.0	 196.02	 1	 155.3	 75.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.3;
	13540	 111.725	 30.905	 79.05	 -17.24	 1.0	 214.48	 1	 155.3	 68.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.3;
	13541	 114.44	 30.905	 79.05	 -17.24	 1.0	 196.91	 1	 155.3	 73.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.3;
	13542	 86.73	 30.905	 79.05	 -17.24	 1.0	 202.2	 1	 155.3	 18.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.3;
	13543	 39.78	 7.955	 18.24	 -2.33	 1.0	 47.79	 1	 39.78	 39.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	13543	 33.67	 7.955	 18.24	 -2.33	 1.0	 58.03	 0	 47.5	 19.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	13544	 33.48	 7.955	 18.24	 -2.33	 1.0	 60.15	 0	 47.5	 19.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	13544	 40.73	 7.955	 18.24	 -2.33	 1.0	 63.94	 1	 40.73	 40.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	13548	 5.225	 0.0	 0.0	 0.0	 1.0	 8.84	 0	 8.58	 1.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	13548	 6.29	 0.0	 0.0	 0.0	 1.0	 9.92	 1	 6.29	 6.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5833;
	13549	 7.5	 0.0	 0.0	 0.0	 1.0	 7.67	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	13549	 5.78	 0.0	 0.0	 0.0	 1.0	 8.58	 1	 5.78	 5.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5833;
	13549	 5.245	 0.0	 0.0	 0.0	 1.0	 9.62	 0	 8.58	 1.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5833;
	13549	 7.18	 0.0	 0.0	 0.0	 1.0	 9.48	 1	 7.18	 7.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.58;
	13549	 5.17	 0.0	 0.0	 0.0	 1.0	 10.12	 1	 5.17	 5.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5833;
	13551	 94.71	 26.495	 67.77	 -14.78	 1.0	 156.72	 1	 133.15	 56.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.15;
	13552	 77.565	 26.495	 67.77	 -14.78	 1.0	 190.64	 1	 133.15	 21.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.15;
	13559	 114.62	 33.265	 85.09	 -18.56	 1.0	 207.93	 0	 167.17	 62.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.1667;
	13560	 99.12	 33.265	 85.09	 -18.56	 1.0	 195.32	 1	 167.17	 31.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.1667;
	13561	 104.165	 33.265	 85.09	 -18.56	 1.0	 187.13	 1	 167.17	 41.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 167.17;
	13563	 12.97	 0.0	 0.0	 0.0	 1.0	 20.7	 1	 12.97	 12.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	13563	 11.865	 0.0	 0.0	 0.0	 1.0	 18.67	 0	 16.25	 7.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	13563	 14.28	 0.0	 0.0	 0.0	 1.0	 21.29	 0	 19.8	 8.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8;
	13566	 11.73	 0.0	 0.0	 0.0	 1.0	 16.25	 1	 11.73	 11.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	13567	 12.59	 0.0	 0.0	 0.0	 1.0	 17.06	 1	 12.59	 12.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.25;
	13570	 69.48	 3.345	 20.66	 -13.97	 1.0	 97.0	 1	 69.48	 69.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.0;
	13572	 12.04	 0.0	 0.0	 0.0	 1.0	 19.0	 0	 18.65	 5.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.65;
	13572	 18.65	 0.0	 0.0	 0.0	 1.0	 23.45	 1	 18.65	 18.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.65;
	13573	 18.44	 0.86	 5.32	 -3.6	 1.0	 29.98	 1	 18.44	 18.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	13574	 5.465	 0.34	 2.11	 -1.43	 1.0	 9.95	 0	 9.9	 1.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	13574	 72.0	 2.485	 15.34	 -10.37	 1.0	 85.37	 1	 72.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	13577	 23.33	 4.27	 9.79	 -1.25	 1.0	 29.78	 1	 23.33	 23.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	13578	 24.18	 4.27	 9.79	 -1.25	 1.0	 26.42	 1	 24.18	 24.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	13578	 8.08	 2.01	 4.61	 -0.59	 1.0	 13.46	 1	 8.08	 8.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	13583	 25.655	 6.7	 15.36	 -1.96	 1.0	 44.16	 0	 40.0	 11.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	13583	 23.97	 6.7	 15.36	 -1.96	 1.0	 40.0	 1	 23.97	 23.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	13584	 33.81	 6.7	 15.36	 -1.96	 1.0	 48.79	 1	 33.81	 33.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	13585	 14.06	 2.51	 5.76	 -0.74	 1.0	 21.72	 1	 14.06	 14.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	13586	 6.0	 1.34	 3.07	 -0.39	 1.0	 10.12	 1	 6.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	13586	 5.7	 1.33	 3.05	 -0.39	 1.0	 9.84	 1	 5.7	 5.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.95;
	13587	 6.96	 1.33	 3.05	 -0.39	 1.0	 8.63	 1	 6.96	 6.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.95;
	13590	 103.0	 3.555	 21.94	 -14.83	 1.0	 130.63	 1	 103.0	 103.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0;
	13593	 14.62	 3.415	 7.83	 -1.0	 1.0	 20.46	 1	 14.62	 14.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4;
	13593	 13.515	 3.415	 7.83	 -1.0	 1.0	 25.96	 0	 20.4	 6.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.4;
	13597	 91.685	 21.86	 50.11	 -6.39	 1.0	 162.57	 0	 130.5	 52.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	13598	 88.03	 21.86	 50.11	 -6.39	 1.0	 155.76	 1	 88.03	 88.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	13599	 115.67	 21.86	 50.11	 -6.39	 1.0	 179.31	 1	 115.67	 115.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	13600	 9.2	 1.84	 4.22	 -0.54	 1.0	 11.43	 1	 9.2	 9.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	13600	 14.66	 3.015	 6.91	 -0.88	 1.0	 26.54	 1	 14.66	 14.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	13602	 12.17	 2.51	 5.76	 -0.74	 1.0	 16.77	 1	 12.17	 12.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	13603	 19.235	 4.355	 9.98	 -1.27	 1.0	 30.16	 0	 26.0	 12.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0;
	13606	 65.41	 3.415	 21.07	 -14.24	 1.0	 141.2	 1	 65.41	 65.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.9;
	13612	 10.23	 2.68	 6.14	 -0.78	 1.0	 16.24	 0	 16.0	 4.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	13612	 16.0	 2.68	 6.14	 -0.78	 1.0	 20.68	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	13613	 5.26	 1.205	 2.76	 -0.35	 1.0	 7.99	 1	 5.26	 5.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.2;
	13614	 5.995	 0.34	 2.11	 -1.43	 1.0	 10.66	 0	 9.9	 2.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	13614	 6.835	 0.34	 2.11	 -1.43	 1.0	 10.95	 0	 9.9	 3.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	13614	 6.87	 0.345	 2.13	 -1.44	 1.0	 11.22	 0	 10.0	 3.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	13614	 7.52	 0.345	 2.13	 -1.44	 1.0	 12.13	 1	 7.52	 7.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	13618	 171.49	 6.935	 42.81	 -28.94	 1.0	 216.74	 1	 171.49	 171.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.0;
	13625	 196.725	 50.8	 116.46	 -14.86	 1.0	 348.95	 0	 303.28	 90.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 303.28;
	13626	 246.09	 50.8	 116.46	 -14.86	 1.0	 310.7	 1	 246.09	 246.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 303.2833;
	13627	 230.23	 50.8	 116.46	 -14.86	 1.0	 367.35	 1	 230.23	 230.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 303.2833;
	13628	 208.865	 50.8	 116.46	 -14.86	 1.0	 421.35	 0	 303.28	 114.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 303.28;
	13629	 303.28	 50.8	 116.46	 -14.86	 1.0	 341.63	 1	 303.28	 303.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 303.28;
	13630	 190.025	 50.8	 116.46	 -14.86	 1.0	 389.95	 0	 303.28	 76.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 303.2833;
	13632	 9.37	 0.0	 0.0	 0.0	 1.0	 18.53	 0	 13.33	 5.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3333;
	13632	 10.53	 0.0	 0.0	 0.0	 1.0	 16.36	 1	 10.53	 10.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3333;
	13632	 9.8	 0.0	 0.0	 0.0	 1.0	 15.24	 1	 9.8	 9.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3333;
	13633	 32.0	 5.36	 12.29	 -1.57	 1.0	 37.85	 1	 32.0	 32.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	13634	 94.34	 3.405	 21.02	 -14.21	 1.0	 99.78	 1	 94.34	 94.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.7;
	13641	 49.23	 2.175	 13.42	 -9.07	 1.0	 85.99	 1	 49.23	 49.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	13642	 34.87	 1.415	 8.73	 -5.9	 1.0	 51.88	 1	 34.87	 34.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	13645	 56.86	 19.445	 49.73	 -10.84	 1.0	 103.74	 1	 97.7	 16.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	13645	 67.095	 19.445	 49.73	 -10.84	 1.0	 143.03	 0	 97.7	 36.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	13645	 67.65	 19.445	 49.73	 -10.84	 1.0	 113.77	 1	 97.7	 37.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	13645	 58.995	 19.445	 49.73	 -10.84	 1.0	 100.11	 1	 97.7	 20.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	13645	 65.845	 19.445	 49.73	 -10.84	 1.0	 97.7	 1	 97.7	 33.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	13645	 58.665	 19.445	 49.73	 -10.84	 1.0	 108.33	 1	 97.7	 19.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	13646	 6.685	 2.17	 5.55	 -1.21	 1.0	 12.02	 1	 10.9	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	13646	 8.465	 2.61	 6.67	 -1.45	 1.0	 19.2	 1	 13.1	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.1;
	13646	 14.495	 4.875	 12.47	 -2.72	 1.0	 34.27	 1	 24.5	 4.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	13650	 33.31	 6.7	 15.36	 -1.96	 1.0	 48.53	 1	 33.31	 33.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	13650	 40.0	 6.7	 15.36	 -1.96	 1.0	 41.66	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	13652	 5.95	 1.675	 3.84	 -0.49	 1.0	 11.03	 1	 5.95	 5.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	13653	 6.99	 1.675	 3.84	 -0.49	 1.0	 10.0	 1	 6.99	 6.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	13655	 24.5	 4.105	 9.41	 -1.2	 1.0	 24.51	 1	 24.5	 24.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	13655	 19.26	 4.105	 9.41	 -1.2	 1.0	 24.5	 1	 19.26	 19.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	13658	 10.22	 2.375	 5.45	 -0.7	 1.0	 16.36	 1	 10.22	 10.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2;
	13658	 10.58	 2.375	 5.45	 -0.7	 1.0	 14.2	 0	 14.2	 6.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2;
	13659	 13.4	 2.375	 5.45	 -0.7	 1.0	 15.85	 1	 13.4	 13.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.2;
	13659	 7.6	 1.84	 4.22	 -0.54	 1.0	 11.0	 1	 7.6	 7.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	13661	 56.64	 2.585	 15.97	 -10.8	 1.0	 105.42	 1	 56.64	 56.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	13662	 15.0	 0.845	 5.22	 -3.53	 1.0	 26.45	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	13663	 12.23	 3.285	 7.53	 -0.96	 1.0	 21.34	 0	 19.6	 4.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	13663	 29.33	 6.13	 14.05	 -1.79	 1.0	 40.87	 1	 29.33	 29.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.6;
	13663	 25.68	 6.13	 14.05	 -1.79	 1.0	 50.03	 0	 36.6	 14.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.6;
	13663	 28.42	 6.13	 14.05	 -1.79	 1.0	 36.6	 1	 28.42	 28.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.6;
	13665	 13.79	 3.97	 9.1	 -1.16	 1.0	 26.61	 1	 13.79	 13.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.7;
	13665	 8.43	 1.975	 4.53	 -0.58	 1.0	 12.53	 0	 11.8	 5.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	13669	 137.28	 32.44	 74.37	 -9.49	 1.0	 244.12	 0	 193.67	 80.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.6667;
	13670	 193.67	 32.44	 74.37	 -9.49	 1.0	 200.55	 1	 193.67	 193.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.67;
	13671	 126.43	 32.44	 74.37	 -9.49	 1.0	 232.79	 1	 126.43	 126.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.6667;
	13672	 125.545	 32.44	 74.37	 -9.49	 1.0	 249.11	 0	 193.67	 57.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.67;
	13673	 138.84	 32.44	 74.37	 -9.49	 1.0	 245.86	 0	 193.67	 84.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.67;
	13674	 193.67	 32.44	 74.37	 -9.49	 1.0	 217.28	 1	 193.67	 193.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.6667;
	13677	 89.355	 28.555	 73.04	 -15.93	 1.0	 168.89	 0	 143.5	 35.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.5;
	13678	 104.365	 28.555	 73.04	 -15.93	 1.0	 183.38	 1	 143.5	 65.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.5;
	13680	 38.5	 6.445	 14.78	 -1.89	 1.0	 39.7	 1	 38.5	 38.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	13684	 267.92	 10.005	 61.77	 -41.76	 1.0	 314.1	 1	 267.92	 267.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 290.0;
	13685	 191.32	 10.005	 61.77	 -41.76	 1.0	 397.51	 1	 191.32	 191.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 290.0;
	13686	 197.955	 9.145	 56.45	 -38.16	 1.0	 274.05	 0	 265.0	 130.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.0;
	13687	 6.41	 0.0	 0.0	 0.0	 1.0	 9.47	 1	 6.41	 6.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	13687	 8.91	 0.0	 0.0	 0.0	 1.0	 11.62	 1	 8.91	 8.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	13687	 9.58	 0.0	 0.0	 0.0	 1.0	 11.13	 1	 9.58	 9.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	13687	 8.82	 0.0	 0.0	 0.0	 1.0	 13.77	 1	 8.82	 8.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	13693	 170.575	 48.055	 122.92	 -26.81	 1.0	 338.22	 1	 241.5	 99.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.5;
	13694	 137.46	 48.055	 122.92	 -26.81	 1.0	 244.41	 1	 241.5	 33.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.5;
	13698	 415.205	 110.46	 299.27	 -78.35	 1.0	 692.83	 1	 642.2	 188.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 642.2;
	20283	 60.36	 12.41	 28.45	 -3.63	 1.0	 93.63	 1	 60.36	 60.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.1;
	20284	 12.34	 2.565	 5.88	 -0.75	 1.0	 15.54	 1	 12.34	 12.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.3;
	20288	 50.45	 15.32	 39.19	 -8.55	 1.0	 98.01	 1	 77.0	 23.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.0;
	20293	 42.41	 3.495	 21.56	 -14.57	 1.0	 111.73	 1	 42.41	 42.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.2;
	20295	 85.3	 19.745	 45.27	 -5.78	 1.0	 153.99	 1	 85.3	 85.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.9;
	20299	 147.12	 47.255	 120.87	 -26.36	 1.0	 314.16	 1	 237.47	 56.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.4667;
	20300	 144.25	 47.255	 120.87	 -26.36	 1.0	 327.37	 1	 237.47	 51.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.47;
	20301	 161.75	 47.255	 120.87	 -26.36	 1.0	 298.78	 1	 237.47	 86.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.47;
	20302	 16.5	 5.695	 14.56	 -3.17	 1.0	 31.98	 1	 28.6	 4.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.6;
	20304	 33.01	 0.0	 0.0	 0.0	 1.0	 61.66	 0	 55.0	 11.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20304	 39.715	 0.0	 0.0	 0.0	 1.0	 55.92	 0	 55.0	 24.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20306	 44.08	 0.0	 0.0	 0.0	 1.0	 61.51	 1	 44.08	 44.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20307	 8.82	 0.0	 0.0	 0.0	 1.0	 12.5	 1	 8.82	 8.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	20307	 10.64	 0.0	 0.0	 0.0	 1.0	 12.63	 1	 10.64	 10.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	20313	 97.575	 22.275	 51.07	 -6.52	 1.0	 184.58	 0	 133.0	 62.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0;
	20314	 119.27	 22.275	 51.07	 -6.52	 1.0	 157.74	 1	 119.27	 119.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0;
	20315	 5.48	 1.175	 2.69	 -0.34	 1.0	 7.0	 1	 5.48	 5.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	20319	 51.54	 14.12	 32.37	 -4.13	 1.0	 114.4	 1	 51.54	 51.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.3;
	20320	 73.19	 14.12	 32.37	 -4.13	 1.0	 113.47	 1	 73.19	 73.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.3;
	20323	 14.67	 4.47	 10.25	 -1.31	 1.0	 37.86	 1	 14.67	 14.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20323	 19.035	 4.47	 10.25	 -1.31	 1.0	 29.75	 0	 26.7	 11.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20323	 19.2	 4.47	 10.25	 -1.31	 1.0	 32.03	 1	 19.2	 19.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.7;
	20328	 62.65	 10.495	 24.06	 -3.07	 1.0	 62.65	 1	 62.65	 62.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.65;
	20329	 62.65	 10.495	 24.06	 -3.07	 1.0	 71.78	 1	 62.65	 62.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.65;
	20330	 10.355	 2.43	 5.57	 -0.71	 1.0	 14.78	 0	 14.5	 6.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5;
	20330	 10.11	 3.085	 7.07	 -0.9	 1.0	 18.4	 1	 10.11	 10.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.4;
	20330	 23.1	 6.18	 14.17	 -1.81	 1.0	 41.21	 1	 23.1	 23.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.9;
	20330	 35.59	 6.18	 14.17	 -1.81	 1.0	 40.51	 1	 35.59	 35.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.9;
	20332	 24.32	 6.57	 16.8	 -3.66	 1.0	 48.76	 1	 33.0	 15.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	20332	 19.86	 6.57	 16.8	 -3.66	 1.0	 42.16	 1	 33.0	 6.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	20335	 78.1	 13.215	 30.3	 -3.87	 1.0	 78.9	 1	 78.1	 78.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.9;
	20335	 61.12	 13.215	 30.3	 -3.87	 1.0	 113.9	 1	 61.12	 61.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.9;
	20336	 10.0	 1.675	 3.84	 -0.49	 1.0	 12.52	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20336	 10.0	 1.675	 3.84	 -0.49	 1.0	 10.8	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20339	 30.7	 10.88	 27.83	 -6.07	 1.0	 64.63	 1	 54.67	 6.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.6667;
	20339	 40.335	 10.88	 27.83	 -6.07	 1.0	 68.79	 1	 54.67	 26.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.67;
	20339	 33.485	 10.88	 27.83	 -6.07	 1.0	 59.25	 1	 54.67	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.6667;
	20344	 13.6	 2.275	 5.22	 -0.67	 1.0	 15.25	 1	 13.6	 13.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	20344	 9.62	 2.13	 4.88	 -0.62	 1.0	 12.7	 1	 9.62	 9.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	20345	 5.5	 1.375	 3.15	 -0.4	 1.0	 8.2	 0	 8.2	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2;
	20345	 4.665	 1.375	 3.15	 -0.4	 1.0	 8.21	 0	 8.2	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2;
	20347	 32.69	 6.465	 14.82	 -1.89	 1.0	 51.07	 1	 32.69	 32.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.6;
	20349	 15.81	 0.0	 0.0	 0.0	 1.0	 25.35	 1	 15.81	 15.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	20349	 14.03	 0.0	 0.0	 0.0	 1.0	 23.19	 1	 14.03	 14.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	20350	 18.3	 0.0	 0.0	 0.0	 1.0	 21.91	 1	 18.3	 18.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	20351	 64.43	 11.725	 26.88	 -3.43	 1.0	 70.36	 1	 64.43	 64.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	20351	 48.14	 11.725	 26.88	 -3.43	 1.0	 80.45	 0	 70.0	 26.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	20353	 39.89	 8.66	 19.85	 -2.53	 1.0	 76.17	 1	 39.89	 39.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	20353	 39.98	 8.66	 19.85	 -2.53	 1.0	 74.72	 1	 39.98	 39.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	20355	 22.295	 7.115	 18.2	 -3.97	 1.0	 39.67	 1	 35.75	 8.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.75;
	20355	 33.02	 10.75	 27.49	 -5.99	 1.0	 61.37	 1	 54.0	 12.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	20356	 24.18	 7.115	 18.2	 -3.97	 1.0	 47.25	 1	 35.75	 12.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.75;
	20357	 15.22	 3.685	 8.45	 -1.08	 1.0	 32.92	 1	 15.22	 15.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	20357	 32.46	 5.525	 12.67	 -1.62	 1.0	 33.81	 1	 32.46	 32.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	20357	 24.92	 5.525	 12.67	 -1.62	 1.0	 45.65	 1	 24.92	 24.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.0;
	20359	 23.775	 0.0	 0.0	 0.0	 1.0	 37.79	 0	 36.2	 11.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.2;
	20363	 85.15	 5.175	 31.95	 -21.6	 1.0	 160.28	 0	 150.0	 20.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	20367	 44.41	 9.195	 21.08	 -2.69	 1.0	 63.25	 1	 44.41	 44.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.9;
	20368	 42.08	 9.195	 21.08	 -2.69	 1.0	 54.9	 1	 42.08	 42.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.9;
	20369	 9.29	 2.03	 4.65	 -0.59	 1.0	 14.68	 1	 9.29	 9.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1;
	20369	 8.5	 1.42	 3.26	 -0.42	 1.0	 9.54	 1	 8.5	 8.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5;
	20370	 4.98	 1.275	 2.92	 -0.37	 1.0	 7.6	 1	 4.98	 4.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6;
	20371	 3.98	 1.14	 2.61	 -0.33	 1.0	 6.94	 1	 3.98	 3.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8;
	20371	 4.755	 1.12	 2.57	 -0.33	 1.0	 7.46	 0	 6.7	 2.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	20372	 6.31	 1.205	 2.76	 -0.35	 1.0	 9.45	 1	 6.31	 6.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.2;
	20372	 8.33	 1.71	 3.92	 -0.5	 1.0	 12.17	 1	 8.33	 8.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	20372	 35.98	 7.82	 17.93	 -2.29	 1.0	 67.13	 1	 35.98	 35.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.7;
	20376	 33.19	 9.875	 22.64	 -2.89	 1.0	 75.96	 0	 58.95	 7.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.95;
	20377	 58.95	 9.875	 22.64	 -2.89	 1.0	 68.44	 1	 58.95	 58.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.95;
	20379	 62.28	 11.96	 27.42	 -3.5	 1.0	 100.17	 1	 62.28	 62.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.4;
	20379	 53.56	 11.96	 27.42	 -3.5	 1.0	 107.1	 1	 53.56	 53.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.4;
	20383	 59.0	 9.885	 22.66	 -2.89	 1.0	 85.67	 1	 59.0	 59.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	20384	 4.8	 2.03	 4.65	 -0.59	 1.0	 12.1	 1	 4.8	 4.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1;
	20385	 19.64	 4.12	 9.45	 -1.21	 1.0	 36.35	 1	 19.64	 19.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	20385	 20.11	 4.12	 9.45	 -1.21	 1.0	 27.1	 1	 20.11	 20.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	20385	 18.03	 4.12	 9.45	 -1.21	 1.0	 31.56	 0	 24.6	 11.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	20390	 70.36	 19.935	 45.7	 -5.83	 1.0	 137.34	 1	 70.36	 70.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0;
	20391	 88.31	 19.935	 45.7	 -5.83	 1.0	 157.85	 1	 88.31	 88.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0;
	20392	 74.94	 19.935	 45.7	 -5.83	 1.0	 157.73	 1	 74.94	 74.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0;
	20393	 119.0	 19.935	 45.7	 -5.83	 1.0	 155.33	 1	 119.0	 119.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0;
	20394	 68.35	 19.935	 45.7	 -5.83	 1.0	 156.07	 0	 119.0	 17.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0;
	20395	 81.9	 19.935	 45.7	 -5.83	 1.0	 119.0	 0	 119.0	 44.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.0;
	20396	 48.83	 11.09	 25.42	 -3.24	 1.0	 73.97	 1	 48.83	 48.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2;
	20396	 50.61	 11.09	 25.42	 -3.24	 1.0	 67.07	 1	 50.61	 50.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2;
	20396	 66.2	 11.09	 25.42	 -3.24	 1.0	 88.13	 1	 66.2	 66.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.2;
	20397	 4.62	 1.12	 2.57	 -0.33	 1.0	 8.22	 1	 4.62	 4.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	20397	 5.31	 1.12	 2.57	 -0.33	 1.0	 8.3	 1	 5.31	 5.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	20401	 12.1	 0.0	 0.0	 0.0	 1.0	 17.0	 0	 17.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.0;
	20401	 18.095	 0.0	 0.0	 0.0	 1.0	 37.65	 0	 28.0	 8.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	20406	 8.79	 1.675	 3.84	 -0.49	 1.0	 11.79	 1	 8.79	 8.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20407	 21.65	 4.27	 9.79	 -1.25	 1.0	 25.5	 1	 21.65	 21.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.5;
	20410	 29.73	 8.895	 20.39	 -2.6	 1.0	 68.12	 0	 53.1	 6.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	20412	 5.78	 1.105	 2.53	 -0.32	 1.0	 9.54	 1	 5.78	 5.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	20413	 7.0	 1.175	 2.69	 -0.34	 1.0	 7.0	 1	 7.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	20415	 6.84	 1.675	 3.84	 -0.49	 1.0	 11.22	 1	 6.84	 6.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20416	 10.0	 1.675	 3.84	 -0.49	 1.0	 10.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20416	 11.32	 2.26	 5.18	 -0.66	 1.0	 14.91	 1	 11.32	 11.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	20416	 10.66	 2.26	 5.18	 -0.66	 1.0	 16.81	 1	 10.66	 10.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	20416	 14.08	 3.015	 6.91	 -0.88	 1.0	 22.77	 1	 14.08	 14.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	20418	 47.45	 9.725	 22.29	 -2.84	 1.0	 82.8	 1	 47.45	 47.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.05;
	20418	 58.05	 9.725	 22.29	 -2.84	 1.0	 63.9	 1	 58.05	 58.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.05;
	20428	 155.19	 42.19	 107.91	 -23.53	 1.0	 249.37	 0	 212.0	 98.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	20429	 126.1	 42.19	 107.91	 -23.53	 1.0	 236.35	 1	 212.0	 40.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	20430	 151.58	 42.19	 107.91	 -23.53	 1.0	 273.32	 1	 212.0	 91.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.0;
	20432	 8.83	 0.0	 0.0	 0.0	 1.0	 13.06	 1	 8.83	 8.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.83;
	20432	 9.05	 0.0	 0.0	 0.0	 1.0	 10.83	 1	 9.05	 9.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.83;
	20432	 10.83	 0.0	 0.0	 0.0	 1.0	 10.83	 1	 10.83	 10.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8333;
	20432	 13.8	 0.0	 0.0	 0.0	 1.0	 13.99	 1	 13.8	 13.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.8;
	20432	 16.13	 0.0	 0.0	 0.0	 1.0	 18.8	 1	 16.13	 16.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.8;
	20432	 12.575	 0.0	 0.0	 0.0	 1.0	 24.16	 0	 20.0	 5.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20435	 16.085	 4.57	 10.48	 -1.34	 1.0	 27.48	 0	 27.3	 4.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.3;
	20435	 12.95	 3.685	 8.45	 -1.08	 1.0	 24.51	 1	 12.95	 12.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	20439	 95.83	 19.6	 44.93	 -5.73	 1.0	 148.41	 1	 95.83	 95.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	20440	 83.78	 19.6	 44.93	 -5.73	 1.0	 126.97	 0	 117.0	 50.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	20441	 78.525	 19.6	 44.93	 -5.73	 1.0	 150.41	 0	 117.0	 40.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.0;
	20442	 97.7	 16.365	 37.52	 -4.79	 1.0	 107.61	 1	 97.7	 97.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	20443	 97.7	 16.365	 37.52	 -4.79	 1.0	 109.15	 1	 97.7	 97.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	20444	 66.535	 16.365	 37.52	 -4.79	 1.0	 99.52	 0	 97.7	 35.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 97.7;
	20445	 7.62	 1.675	 3.84	 -0.49	 1.0	 10.0	 1	 7.62	 7.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20447	 55.0	 0.0	 0.0	 0.0	 1.0	 79.25	 1	 55.0	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20448	 41.98	 0.0	 0.0	 0.0	 1.0	 68.28	 1	 41.98	 41.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	20449	 9.07	 0.0	 0.0	 0.0	 1.0	 13.31	 1	 9.07	 9.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2;
	20449	 8.07	 0.0	 0.0	 0.0	 1.0	 12.2	 0	 12.2	 3.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.2;
	20450	 11.65	 0.0	 0.0	 0.0	 1.0	 21.27	 0	 19.0	 4.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	20450	 10.605	 0.0	 0.0	 0.0	 1.0	 19.0	 0	 19.0	 2.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	20453	 33.605	 9.855	 25.2	 -5.49	 1.0	 49.5	 1	 49.5	 17.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	20454	 53.93	 13.265	 30.41	 -3.88	 1.0	 89.58	 1	 53.93	 53.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.2;
	20456	 28.2	 9.35	 23.92	 -5.22	 1.0	 47.37	 1	 47.0	 9.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	20460	 33.645	 9.415	 24.08	 -5.25	 1.0	 47.3	 1	 47.3	 19.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.3;
	20462	 32.58	 6.535	 14.98	 -1.91	 1.0	 43.01	 1	 32.58	 32.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	20462	 26.81	 6.535	 14.98	 -1.91	 1.0	 43.63	 1	 26.81	 26.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	20462	 28.82	 6.535	 14.98	 -1.91	 1.0	 47.52	 0	 39.0	 18.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.0;
	20463	 51.08	 0.0	 0.0	 0.0	 1.0	 98.0	 1	 51.08	 51.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	20463	 65.43	 0.0	 0.0	 0.0	 1.0	 88.2	 1	 65.43	 65.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	20468	 124.285	 35.155	 89.92	 -19.61	 1.0	 249.5	 1	 176.67	 71.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.67;
	20469	 118.825	 35.155	 89.92	 -19.61	 1.0	 205.0	 1	 176.67	 60.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6667;
	20470	 115.14	 35.155	 89.92	 -19.61	 1.0	 233.82	 1	 176.67	 53.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.6667;
	20471	 29.52	 9.75	 24.94	 -5.44	 1.0	 53.97	 1	 49.0	 10.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	20472	 40.0	 6.7	 15.36	 -1.96	 1.0	 45.43	 1	 40.0	 40.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	20474	 78.0	 0.0	 0.0	 0.0	 1.0	 113.68	 1	 78.0	 78.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	20475	 5.605	 0.0	 0.0	 0.0	 1.0	 9.3	 0	 9.3	 1.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	20475	 8.41	 0.0	 0.0	 0.0	 1.0	 11.4	 1	 8.41	 8.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	20475	 8.645	 0.0	 0.0	 0.0	 1.0	 13.54	 0	 13.4	 3.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.4;
	20475	 14.58	 0.0	 0.0	 0.0	 1.0	 22.55	 1	 14.58	 14.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	20475	 31.0	 0.0	 0.0	 0.0	 1.0	 41.94	 1	 31.0	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	20478	 67.33	 15.075	 34.56	 -4.41	 1.0	 117.55	 0	 90.0	 44.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	20479	 53.69	 15.075	 34.56	 -4.41	 1.0	 95.35	 1	 53.69	 53.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	20482	 61.31	 12.93	 29.64	 -3.78	 1.0	 92.07	 1	 61.31	 61.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.2;
	20483	 69.11	 12.93	 29.64	 -3.78	 1.0	 105.27	 1	 69.11	 69.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.2;
	20487	 157.455	 0.0	 0.0	 0.0	 1.0	 244.59	 0	 212.17	 102.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.1667;
	20488	 182.08	 0.0	 0.0	 0.0	 1.0	 269.69	 1	 182.08	 182.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.1667;
	20489	 134.015	 0.0	 0.0	 0.0	 1.0	 299.15	 0	 212.17	 55.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.1667;
	20490	 212.17	 0.0	 0.0	 0.0	 1.0	 212.17	 1	 212.17	 212.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.1667;
	20491	 127.29	 0.0	 0.0	 0.0	 1.0	 265.56	 1	 127.29	 127.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.17;
	20492	 212.17	 0.0	 0.0	 0.0	 1.0	 273.53	 1	 212.17	 212.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 212.1667;
	20494	 39.6	 6.635	 15.21	 -1.94	 1.0	 40.0	 1	 39.6	 39.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6;
	20494	 36.69	 6.635	 15.21	 -1.94	 1.0	 46.88	 1	 36.69	 36.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6;
	20496	 7.48	 0.0	 0.0	 0.0	 1.0	 11.81	 1	 7.48	 7.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	20496	 9.15	 0.0	 0.0	 0.0	 1.0	 12.07	 1	 9.15	 9.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	20496	 13.75	 0.0	 0.0	 0.0	 1.0	 16.43	 1	 13.75	 13.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75;
	20496	 8.06	 0.0	 0.0	 0.0	 1.0	 14.75	 1	 8.06	 8.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.75;
	20499	 14.73	 4.895	 12.52	 -2.73	 1.0	 24.6	 1	 24.6	 4.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	20500	 13.595	 4.895	 12.52	 -2.73	 1.0	 27.36	 0	 24.6	 2.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	20502	 24.05	 7.25	 18.54	 -4.04	 1.0	 45.34	 1	 36.43	 11.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.4333;
	20502	 22.63	 7.25	 18.54	 -4.04	 1.0	 41.82	 1	 36.43	 8.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.43;
	20503	 25.825	 7.25	 18.54	 -4.04	 1.0	 36.76	 0	 36.43	 15.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.4333;
	20503	 16.99	 4.895	 12.52	 -2.73	 1.0	 25.8	 1	 24.6	 9.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.6;
	20505	 7.1	 2.03	 4.65	 -0.59	 1.0	 12.4	 1	 7.1	 7.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.1;
	20506	 40.29	 7.37	 16.9	 -2.16	 1.0	 48.68	 1	 40.29	 40.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	20509	 27.64	 8.76	 22.4	 -4.88	 1.0	 58.99	 0	 44.0	 11.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	20509	 30.375	 9.91	 25.35	 -5.53	 1.0	 59.49	 1	 49.8	 10.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	20509	 30.285	 9.91	 25.35	 -5.53	 1.0	 55.82	 1	 49.8	 10.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	20509	 33.83	 9.91	 25.35	 -5.53	 1.0	 56.13	 0	 49.8	 17.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	20515	 20.11	 0.0	 0.0	 0.0	 1.0	 28.6	 1	 20.11	 20.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9;
	20516	 16.77	 0.0	 0.0	 0.0	 1.0	 19.39	 1	 16.77	 16.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.2;
	20516	 8.39	 0.0	 0.0	 0.0	 1.0	 9.16	 1	 8.39	 8.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	20517	 6.64	 0.0	 0.0	 0.0	 1.0	 12.11	 1	 6.64	 6.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	20519	 16.29	 4.605	 10.56	 -1.35	 1.0	 27.5	 0	 27.5	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	20519	 27.5	 4.605	 10.56	 -1.35	 1.0	 30.57	 1	 27.5	 27.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	20519	 20.41	 4.605	 10.56	 -1.35	 1.0	 27.5	 1	 20.41	 20.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5;
	20519	 22.76	 5.46	 12.52	 -1.6	 1.0	 43.81	 0	 32.6	 12.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.6;
	20521	 23.85	 7.02	 16.09	 -2.05	 1.0	 43.22	 0	 41.9	 5.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.9;
	20523	 55.56	 17.305	 44.26	 -9.65	 1.0	 126.81	 1	 86.95	 24.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.95;
	20523	 62.345	 17.305	 44.26	 -9.65	 1.0	 99.91	 1	 86.95	 37.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.95;
	20525	 28.11	 5.795	 13.29	 -1.7	 1.0	 41.69	 1	 28.11	 28.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.6;
	20526	 8.56	 1.675	 3.84	 -0.49	 1.0	 10.25	 1	 8.56	 8.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20526	 7.2	 1.675	 3.84	 -0.49	 1.0	 10.0	 1	 7.2	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	20526	 18.44	 5.005	 11.48	 -1.47	 1.0	 34.56	 0	 29.9	 6.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9;
	20526	 21.01	 5.795	 13.29	 -1.7	 1.0	 44.09	 1	 21.01	 21.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.6;
	20528	 4.395	 1.54	 3.94	 -0.86	 1.0	 9.1	 0	 7.73	 1.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.7333;
	20528	 5.37	 1.54	 3.94	 -0.86	 1.0	 7.9	 0	 7.73	 3.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.73;
	20528	 5.65	 1.54	 3.94	 -0.86	 1.0	 11.6	 1	 7.73	 3.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.73;
	20528	 4.31	 1.54	 3.94	 -0.86	 1.0	 11.17	 0	 7.73	 0.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.73;
	20528	 4.975	 1.54	 3.94	 -0.86	 1.0	 8.18	 1	 7.73	 2.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.7333;
	20528	 5.34	 1.54	 3.94	 -0.86	 1.0	 9.01	 1	 7.73	 2.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.73;
	20530	 17.405	 5.54	 14.17	 -3.09	 1.0	 41.74	 1	 27.83	 6.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.8333;
	20530	 17.82	 5.54	 14.17	 -3.09	 1.0	 27.83	 0	 27.83	 7.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.8333;
	20531	 19.005	 5.54	 14.17	 -3.09	 1.0	 37.18	 1	 27.83	 10.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.83;
	20531	 16.885	 5.54	 14.17	 -3.09	 1.0	 29.93	 1	 27.83	 5.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.8333;
	20531	 19.825	 5.54	 14.17	 -3.09	 1.0	 29.22	 1	 27.83	 11.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.83;
	20531	 20.695	 5.54	 14.17	 -3.09	 1.0	 28.27	 1	 27.83	 13.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.83;
	20534	 10.34	 2.06	 4.72	 -0.6	 1.0	 15.59	 1	 10.34	 10.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	20534	 8.495	 2.06	 4.72	 -0.6	 1.0	 15.68	 0	 12.3	 4.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	20534	 12.3	 2.06	 4.72	 -0.6	 1.0	 12.3	 1	 12.3	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	20534	 9.0	 2.06	 4.72	 -0.6	 1.0	 15.39	 0	 12.3	 5.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.3;
	20536	 23.08	 5.93	 13.59	 -1.73	 1.0	 36.18	 1	 23.08	 23.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.4;
	20536	 15.96	 5.93	 13.59	 -1.73	 1.0	 36.34	 1	 15.96	 15.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.4;
	20537	 27.4	 5.93	 13.59	 -1.73	 1.0	 35.4	 1	 27.4	 27.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.4;
	20538	 35.4	 5.93	 13.59	 -1.73	 1.0	 35.5	 1	 35.4	 35.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.4;
	20540	 61.74	 13.535	 31.03	 -3.96	 1.0	 103.36	 1	 61.74	 61.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.8;
	20541	 60.2	 13.535	 31.03	 -3.96	 1.0	 93.14	 1	 60.2	 60.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.8;
	20544	 124.18	 26.38	 60.48	 -7.72	 1.0	 177.26	 1	 124.18	 124.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.5;
	20545	 100.1	 26.38	 60.48	 -7.72	 1.0	 205.83	 0	 157.5	 42.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 157.5;
	21596	 116.55	 41.19	 105.36	 -22.98	 1.0	 249.51	 1	 207.0	 26.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.0;
	21597	 120.58	 41.19	 105.36	 -22.98	 1.0	 212.06	 1	 207.0	 34.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.0;
	21598	 145.435	 41.19	 105.36	 -22.98	 1.0	 267.73	 1	 207.0	 83.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.0;
	21599	 114.92	 41.19	 105.36	 -22.98	 1.0	 310.5	 1	 207.0	 22.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.0;
	21602	 57.05	 1.965	 12.15	 -8.22	 1.0	 66.04	 1	 57.05	 57.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.05;
	21603	 36.47	 1.965	 12.15	 -8.22	 1.0	 65.7	 1	 36.47	 36.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.05;
	21604	 38.97	 1.965	 12.15	 -8.22	 1.0	 57.05	 1	 38.97	 38.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.05;
	21605	 36.12	 1.965	 12.15	 -8.22	 1.0	 80.49	 1	 36.12	 36.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.05;
	21611	 130.865	 46.94	 120.06	 -26.18	 1.0	 244.29	 1	 235.88	 25.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.88;
	21612	 166.605	 46.94	 120.06	 -26.18	 1.0	 266.29	 1	 235.88	 97.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.875;
	21613	 134.26	 46.94	 120.06	 -26.18	 1.0	 298.35	 1	 235.88	 32.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.875;
	21614	 146.88	 46.94	 120.06	 -26.18	 1.0	 311.14	 0	 235.88	 57.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.88;
	21617	 283.17	 11.47	 70.82	 -47.88	 1.0	 395.46	 1	 283.17	 283.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 332.5;
	21618	 16.22	 0.825	 5.11	 -3.46	 1.0	 24.0	 1	 16.22	 16.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	21619	 18.0	 0.62	 3.83	 -2.59	 1.0	 19.08	 1	 18.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	21619	 10.235	 0.62	 3.83	 -2.59	 1.0	 22.7	 0	 18.0	 2.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	21620	 10.9	 0.375	 2.32	 -1.57	 1.0	 10.9	 1	 10.9	 10.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	21620	 10.5	 0.365	 2.24	 -1.51	 1.0	 13.44	 1	 10.5	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	21623	 120.24	 41.105	 105.14	 -22.93	 1.0	 221.17	 1	 206.57	 33.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.57;
	21624	 138.875	 41.105	 105.14	 -22.93	 1.0	 267.92	 1	 206.57	 71.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.57;
	21625	 139.835	 41.105	 105.14	 -22.93	 1.0	 258.09	 1	 206.57	 73.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.5667;
	21627	 29.865	 10.215	 26.13	 -5.7	 1.0	 67.08	 1	 51.33	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3333;
	21627	 35.215	 10.215	 26.13	 -5.7	 1.0	 55.9	 1	 51.33	 19.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3333;
	21627	 30.795	 10.215	 26.13	 -5.7	 1.0	 75.37	 1	 51.33	 10.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3333;
	21628	 8.145	 2.685	 6.87	 -1.5	 1.0	 13.5	 1	 13.5	 2.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	21628	 8.05	 2.685	 6.87	 -1.5	 1.0	 13.5	 0	 13.5	 2.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	21631	 32.54	 9.51	 25.77	 -6.75	 1.0	 68.11	 1	 55.3	 9.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.3;
	21636	 15.31	 5.255	 13.44	 -2.93	 1.0	 30.82	 1	 26.4	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.4;
	21637	 18.55	 5.255	 13.44	 -2.93	 1.0	 29.65	 1	 26.4	 10.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.4;
	21639	 44.845	 12.94	 33.09	 -7.21	 1.0	 87.12	 1	 65.0	 24.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0;
	21639	 47.355	 12.94	 33.09	 -7.21	 1.0	 86.4	 0	 65.0	 29.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.0;
	21646	 329.61	 93.13	 238.2	 -51.94	 1.0	 472.89	 1	 467.97	 191.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 467.9667;
	21647	 270.99	 93.13	 238.2	 -51.94	 1.0	 568.58	 1	 467.97	 74.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 467.9667;
	21648	 335.485	 93.13	 238.2	 -51.94	 1.0	 506.07	 0	 467.97	 203.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 467.9667;
	21651	 154.61	 44.99	 115.08	 -25.1	 1.0	 339.11	 1	 226.1	 83.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 226.1;
	21652	 144.955	 44.99	 115.08	 -25.1	 1.0	 273.13	 1	 226.1	 63.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 226.1;
	21653	 167.36	 44.99	 115.08	 -25.1	 1.0	 336.56	 1	 226.1	 108.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 226.1;
	21654	 15.885	 0.0	 0.0	 0.0	 1.0	 23.11	 0	 23.0	 8.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	21654	 17.87	 0.0	 0.0	 0.0	 1.0	 29.86	 0	 27.3	 8.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.3;
	21656	 33.895	 9.35	 23.92	 -5.22	 1.0	 48.14	 1	 47.0	 20.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	21656	 26.96	 9.35	 23.92	 -5.22	 1.0	 49.13	 1	 47.0	 6.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	21656	 31.9	 9.35	 23.92	 -5.22	 1.0	 60.99	 1	 47.0	 16.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	21662	 36.35	 9.93	 25.4	 -5.54	 1.0	 55.49	 0	 49.9	 22.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	21662	 31.145	 9.93	 25.4	 -5.54	 1.0	 71.93	 1	 49.9	 12.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	21663	 33.895	 9.93	 25.4	 -5.54	 1.0	 49.9	 1	 49.9	 17.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	21663	 36.375	 9.93	 25.4	 -5.54	 1.0	 63.58	 1	 49.9	 22.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	21668	 47.885	 12.815	 34.72	 -9.09	 1.0	 85.89	 1	 74.5	 21.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5;
	21669	 48.59	 12.815	 34.72	 -9.09	 1.0	 98.73	 1	 74.5	 22.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5;
	21670	 44.44	 12.815	 34.72	 -9.09	 1.0	 82.85	 0	 74.5	 14.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.5;
	21673	 43.435	 12.035	 30.79	 -6.72	 1.0	 78.21	 1	 60.5	 26.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	21675	 33.145	 9.35	 23.92	 -5.22	 1.0	 54.9	 1	 47.0	 19.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	21676	 32.64	 1.27	 7.84	 -5.3	 1.0	 47.91	 1	 32.64	 32.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.8;
	21676	 81.0	 2.795	 17.25	 -11.66	 1.0	 81.0	 1	 81.0	 81.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0;
	21676	 71.8	 2.795	 17.25	 -11.66	 1.0	 96.85	 1	 71.8	 71.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0;
	21681	 110.83	 5.175	 31.95	 -21.6	 1.0	 196.42	 1	 110.83	 110.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	21689	 117.025	 42.12	 107.74	 -23.5	 1.0	 224.67	 1	 211.67	 22.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 211.6667;
	21690	 146.15	 42.12	 107.74	 -23.5	 1.0	 255.57	 1	 211.67	 80.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 211.6667;
	21691	 153.575	 42.12	 107.74	 -23.5	 1.0	 261.55	 1	 211.67	 95.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 211.6667;
	21693	 75.975	 3.535	 21.83	 -14.76	 1.0	 140.77	 0	 102.5	 49.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.5;
	21694	 34.52	 9.35	 23.92	 -5.22	 1.0	 62.31	 1	 47.0	 22.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	21694	 36.78	 10.15	 25.96	 -5.66	 1.0	 58.3	 1	 51.0	 22.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0;
	21699	 25.19	 7.53	 19.26	 -4.2	 1.0	 50.71	 1	 37.83	 12.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.83;
	21699	 23.235	 7.53	 19.26	 -4.2	 1.0	 42.54	 1	 37.83	 8.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.83;
	21699	 23.175	 7.53	 19.26	 -4.2	 1.0	 38.56	 1	 37.83	 8.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.83;
	21702	 64.04	 22.29	 57.02	 -12.44	 1.0	 123.94	 1	 112.03	 16.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0333;
	21703	 66.62	 22.29	 57.02	 -12.44	 1.0	 128.07	 1	 112.03	 21.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.0333;
	21704	 67.34	 22.29	 57.02	 -12.44	 1.0	 124.97	 1	 112.03	 22.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.03;
	21706	 8.095	 2.835	 7.25	 -1.58	 1.0	 17.23	 0	 14.25	 1.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.25;
	21707	 9.805	 2.835	 7.25	 -1.58	 1.0	 14.32	 0	 14.25	 5.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.25;
	21709	 18.87	 5.455	 13.95	 -3.04	 1.0	 35.78	 1	 27.4	 10.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	21710	 18.145	 5.455	 13.95	 -3.04	 1.0	 30.49	 1	 27.4	 8.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	21716	 9.585	 0.56	 3.45	 -2.33	 1.0	 19.59	 0	 16.2	 2.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.2;
	21716	 52.68	 2.7	 16.66	 -11.26	 1.0	 101.24	 1	 52.68	 52.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.2;
	21718	 22.68	 6.635	 16.97	 -3.7	 1.0	 39.57	 1	 33.33	 12.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	21718	 21.47	 6.635	 16.97	 -3.7	 1.0	 36.86	 1	 33.33	 9.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.33;
	21719	 21.075	 6.635	 16.97	 -3.7	 1.0	 47.9	 1	 33.33	 8.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.33;
	21720	 5.3	 1.535	 4.16	 -1.09	 1.0	 8.93	 1	 8.93	 1.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.93;
	21720	 6.06	 1.535	 4.16	 -1.09	 1.0	 8.93	 1	 8.93	 3.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.9333;
	21720	 5.64	 1.535	 4.16	 -1.09	 1.0	 9.97	 0	 8.93	 2.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.93;
	21720	 5.2	 1.535	 4.16	 -1.09	 1.0	 11.23	 0	 8.93	 1.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.93;
	21720	 5.625	 1.535	 4.16	 -1.09	 1.0	 9.83	 1	 8.93	 2.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.9333;
	21720	 5.06	 1.535	 4.16	 -1.09	 1.0	 9.87	 1	 8.93	 1.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.93;
	21726	 148.375	 49.235	 125.93	 -27.46	 1.0	 322.43	 1	 247.4	 49.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.4;
	21730	 154.955	 43.45	 111.13	 -24.23	 1.0	 223.08	 1	 218.33	 91.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.33;
	21731	 162.32	 43.45	 111.13	 -24.23	 1.0	 244.43	 1	 218.33	 106.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.3333;
	21732	 136.72	 43.45	 111.13	 -24.23	 1.0	 233.08	 1	 218.33	 55.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.3333;
	21735	 41.765	 12.18	 31.16	 -6.8	 1.0	 68.02	 1	 61.22	 22.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.22;
	21736	 34.44	 12.18	 31.16	 -6.8	 1.0	 73.05	 0	 61.22	 7.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.22;
	21737	 41.215	 12.18	 31.16	 -6.8	 1.0	 82.32	 1	 61.22	 21.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.22;
	21738	 39.385	 12.18	 31.16	 -6.8	 1.0	 65.63	 0	 61.22	 17.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.22;
	21739	 36.215	 12.18	 31.16	 -6.8	 1.0	 65.47	 1	 61.22	 11.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.22;
	21740	 10.105	 3.18	 8.14	 -1.78	 1.0	 17.86	 0	 16.0	 4.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	21740	 10.99	 3.18	 8.14	 -1.78	 1.0	 17.66	 0	 16.0	 5.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	21742	 68.89	 2.7	 16.66	 -11.26	 1.0	 113.29	 1	 68.89	 68.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.2;
	21743	 38.0	 1.31	 8.09	 -5.47	 1.0	 42.0	 1	 38.0	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	21744	 24.94	 8.955	 22.9	 -4.99	 1.0	 55.77	 1	 45.0	 4.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	21748	 31.76	 8.955	 22.9	 -4.99	 1.0	 45.16	 1	 45.0	 18.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	21749	 33.16	 8.955	 22.9	 -4.99	 1.0	 50.97	 1	 45.0	 21.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	21753	 37.38	 12.455	 31.86	 -6.95	 1.0	 72.39	 1	 62.6	 12.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.6;
	21753	 42.815	 12.455	 31.86	 -6.95	 1.0	 92.14	 1	 62.6	 23.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.6;
	21754	 21.675	 6.05	 15.47	 -3.37	 1.0	 36.78	 1	 30.4	 12.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	21756	 12.2	 3.64	 9.31	 -2.03	 1.0	 21.8	 0	 18.3	 6.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	21756	 12.105	 3.64	 9.31	 -2.03	 1.0	 20.44	 0	 18.3	 5.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	21757	 10.69	 3.64	 9.31	 -2.03	 1.0	 19.47	 1	 18.3	 3.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3;
	21758	 20.585	 6.425	 16.44	 -3.59	 1.0	 48.1	 1	 32.3	 8.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.3;
	21758	 19.295	 6.425	 16.44	 -3.59	 1.0	 46.41	 1	 32.3	 6.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.3;
	21760	 70.01	 3.495	 21.58	 -14.59	 1.0	 101.3	 1	 70.01	 70.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.3;
	23267	 30.665	 9.75	 24.94	 -5.44	 1.0	 64.12	 1	 49.0	 12.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	23268	 30.085	 9.75	 24.94	 -5.44	 1.0	 62.28	 1	 49.0	 11.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	23270	 20.12	 5.455	 13.95	 -3.04	 1.0	 31.11	 1	 27.4	 12.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	23270	 28.055	 9.95	 25.45	 -5.55	 1.0	 58.6	 1	 50.0	 6.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	23272	 6.4	 1.675	 3.84	 -0.49	 1.0	 11.52	 1	 6.4	 6.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	23272	 13.54	 2.715	 6.22	 -0.79	 1.0	 17.87	 1	 13.54	 13.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.2;
	23272	 57.7	 12.06	 27.65	 -3.53	 1.0	 83.27	 1	 57.7	 57.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	23277	 25.055	 5.725	 13.12	 -1.67	 1.0	 37.12	 0	 34.17	 15.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1667;
	23278	 4.965	 1.315	 3.02	 -0.39	 1.0	 9.84	 0	 7.87	 2.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8667;
	23278	 7.04	 1.315	 3.02	 -0.39	 1.0	 10.03	 1	 7.04	 7.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8667;
	23278	 7.87	 1.315	 3.02	 -0.39	 1.0	 9.73	 1	 7.87	 7.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8667;
	23278	 20.975	 5.725	 13.12	 -1.67	 1.0	 41.59	 0	 34.17	 7.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.1667;
	23278	 23.545	 5.725	 13.12	 -1.67	 1.0	 40.33	 0	 34.17	 12.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.17;
	23281	 42.09	 8.375	 19.2	 -2.45	 1.0	 58.43	 1	 42.09	 42.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	23281	 32.47	 8.375	 19.2	 -2.45	 1.0	 60.48	 0	 50.0	 14.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	23282	 20.0	 0.0	 0.0	 0.0	 1.0	 24.43	 1	 20.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23282	 12.92	 0.0	 0.0	 0.0	 1.0	 20.1	 1	 12.92	 12.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23282	 13.98	 0.0	 0.0	 0.0	 1.0	 23.0	 0	 20.0	 7.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23282	 17.33	 0.0	 0.0	 0.0	 1.0	 33.14	 1	 17.33	 17.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	23287	 79.605	 21.49	 54.97	 -11.99	 1.0	 131.81	 1	 108.0	 51.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	23288	 65.08	 21.49	 54.97	 -11.99	 1.0	 136.92	 1	 108.0	 22.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	23289	 62.47	 21.49	 54.97	 -11.99	 1.0	 128.62	 1	 108.0	 16.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	23290	 66.6	 21.49	 54.97	 -11.99	 1.0	 155.58	 1	 108.0	 25.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	23293	 113.37	 23.365	 53.57	 -6.84	 1.0	 167.68	 1	 113.37	 113.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 139.5;
	23294	 6.675	 1.895	 4.34	 -0.55	 1.0	 13.53	 0	 11.3	 2.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	23295	 11.3	 1.895	 4.34	 -0.55	 1.0	 11.52	 1	 11.3	 11.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	23295	 7.94	 1.71	 3.92	 -0.5	 1.0	 13.49	 1	 7.94	 7.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	23296	 5.07	 1.71	 3.92	 -0.5	 1.0	 10.31	 1	 5.07	 5.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	23297	 10.2	 1.71	 3.92	 -0.5	 1.0	 10.33	 1	 10.2	 10.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	23298	 28.11	 0.0	 0.0	 0.0	 1.0	 30.0	 1	 28.11	 28.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	23298	 27.55	 0.0	 0.0	 0.0	 1.0	 35.33	 1	 27.55	 27.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	23298	 22.76	 0.0	 0.0	 0.0	 1.0	 36.45	 1	 22.76	 22.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	23302	 47.51	 0.0	 0.0	 0.0	 1.0	 56.2	 1	 47.51	 47.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	23303	 20.2	 0.0	 0.0	 0.0	 1.0	 20.59	 1	 20.2	 20.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2;
	23303	 14.2	 0.0	 0.0	 0.0	 1.0	 22.41	 1	 14.2	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23304	 20.0	 0.0	 0.0	 0.0	 1.0	 20.0	 1	 20.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23305	 11.5	 0.0	 0.0	 0.0	 1.0	 25.78	 0	 19.8	 3.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8;
	23306	 36.36	 8.375	 19.2	 -2.45	 1.0	 50.59	 1	 36.36	 36.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	23306	 33.66	 8.375	 19.2	 -2.45	 1.0	 67.91	 1	 33.66	 33.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	23307	 15.37	 3.37	 7.72	 -0.98	 1.0	 20.1	 1	 15.37	 15.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.1;
	23307	 27.58	 8.14	 18.66	 -2.38	 1.0	 63.31	 0	 48.6	 6.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.6;
	23309	 30.92	 11.12	 28.44	 -6.2	 1.0	 75.82	 1	 55.87	 5.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.88;
	23309	 35.835	 11.12	 28.44	 -6.2	 1.0	 67.38	 1	 55.87	 15.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.875;
	23309	 38.27	 11.12	 28.44	 -6.2	 1.0	 75.93	 1	 55.87	 20.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.875;
	23309	 41.79	 11.12	 28.44	 -6.2	 1.0	 59.84	 1	 55.87	 27.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.88;
	23311	 33.82	 5.84	 13.39	 -1.71	 1.0	 52.32	 1	 33.82	 33.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.88;
	23311	 34.88	 5.84	 13.39	 -1.71	 1.0	 44.03	 1	 34.88	 34.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.88;
	23311	 21.275	 5.84	 13.39	 -1.71	 1.0	 44.05	 0	 34.88	 7.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.88;
	23311	 24.68	 5.84	 13.39	 -1.71	 1.0	 46.99	 1	 24.68	 24.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.88;
	23311	 20.875	 5.84	 13.39	 -1.71	 1.0	 44.12	 0	 34.88	 6.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.88;
	23313	 11.37	 0.0	 0.0	 0.0	 1.0	 20.48	 1	 11.37	 11.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23313	 14.51	 0.0	 0.0	 0.0	 1.0	 23.88	 1	 14.51	 14.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	23315	 27.2	 7.6	 19.44	 -4.24	 1.0	 46.6	 1	 38.2	 16.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	23318	 17.365	 5.455	 13.95	 -3.04	 1.0	 30.62	 1	 27.4	 7.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	23318	 17.4	 5.455	 13.95	 -3.04	 1.0	 30.74	 1	 27.4	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.4;
	23319	 67.5	 11.305	 25.92	 -3.31	 1.0	 75.37	 1	 67.5	 67.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	23319	 41.965	 11.305	 25.92	 -3.31	 1.0	 74.26	 0	 67.5	 16.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	23321	 10.8	 1.81	 4.15	 -0.53	 1.0	 11.95	 1	 10.8	 10.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8;
	23322	 18.22	 3.7	 8.48	 -1.08	 1.0	 22.08	 1	 18.22	 18.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.08;
	23324	 20.0	 3.7	 8.48	 -1.08	 1.0	 22.08	 1	 20.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.075;
	23325	 13.96	 3.7	 8.48	 -1.08	 1.0	 24.5	 1	 13.96	 13.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.075;
	23326	 22.08	 3.7	 8.48	 -1.08	 1.0	 23.66	 1	 22.08	 22.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.08;
	23329	 39.855	 13.255	 33.9	 -7.39	 1.0	 74.99	 1	 66.6	 13.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.6;
	23329	 37.715	 13.255	 33.9	 -7.39	 1.0	 76.28	 1	 66.6	 8.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.6;
	23333	 16.995	 0.0	 0.0	 0.0	 1.0	 35.04	 0	 30.73	 3.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.73;
	23333	 24.87	 0.0	 0.0	 0.0	 1.0	 33.88	 1	 24.87	 24.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.7333;
	23334	 22.685	 0.0	 0.0	 0.0	 1.0	 31.26	 0	 30.73	 14.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.73;
	23337	 27.45	 6.28	 14.4	 -1.84	 1.0	 43.6	 1	 27.45	 27.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	23338	 50.285	 13.135	 30.11	 -3.84	 1.0	 115.54	 0	 78.4	 22.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.4;
	23338	 60.59	 13.135	 30.11	 -3.84	 1.0	 90.82	 1	 60.59	 60.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.4;
	23340	 35.03	 12.035	 30.79	 -6.72	 1.0	 69.73	 0	 60.5	 9.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	23340	 41.1	 12.035	 30.79	 -6.72	 1.0	 77.57	 1	 60.5	 21.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	23345	 9.355	 2.485	 6.36	 -1.39	 1.0	 12.5	 0	 12.5	 6.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	23346	 10.685	 3.6	 9.21	 -2.01	 1.0	 18.32	 1	 18.1	 3.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.1;
	23346	 10.135	 3.6	 9.21	 -2.01	 1.0	 26.62	 1	 18.1	 2.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.1;
	23346	 34.64	 9.75	 24.94	 -5.44	 1.0	 50.07	 1	 49.0	 20.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	23347	 8.045	 1.895	 4.34	 -0.55	 1.0	 11.51	 0	 11.3	 4.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	23347	 38.5	 6.445	 14.78	 -1.89	 1.0	 43.79	 1	 38.5	 38.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	23347	 27.83	 6.445	 14.78	 -1.89	 1.0	 42.9	 1	 27.83	 27.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	23347	 31.94	 6.445	 14.78	 -1.89	 1.0	 43.97	 1	 31.94	 31.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.5;
	23348	 44.88	 12.245	 33.18	 -8.69	 1.0	 95.2	 1	 71.2	 18.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2;
	23348	 42.48	 12.245	 33.18	 -8.69	 1.0	 74.07	 1	 71.2	 13.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.2;
	23351	 18.28	 4.955	 12.67	 -2.76	 1.0	 27.54	 1	 24.9	 11.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	23351	 17.67	 4.955	 12.67	 -2.76	 1.0	 24.9	 1	 24.9	 10.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	23352	 13.825	 4.78	 12.22	 -2.66	 1.0	 35.37	 1	 24.0	 3.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	23353	 20.87	 6.28	 14.4	 -1.84	 1.0	 52.39	 0	 37.5	 4.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	23353	 33.78	 6.28	 14.4	 -1.84	 1.0	 37.5	 1	 33.78	 33.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	23354	 42.875	 11.84	 27.14	 -3.46	 1.0	 91.44	 0	 70.67	 15.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6667;
	23354	 70.67	 11.84	 27.14	 -3.46	 1.0	 105.22	 1	 70.67	 70.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6667;
	23354	 42.155	 11.84	 27.14	 -3.46	 1.0	 80.17	 0	 70.67	 13.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6667;
	23354	 41.335	 11.84	 27.14	 -3.46	 1.0	 89.48	 0	 70.67	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6667;
	23354	 41.785	 11.84	 27.14	 -3.46	 1.0	 76.67	 0	 70.67	 12.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.67;
	23354	 45.25	 11.84	 27.14	 -3.46	 1.0	 100.34	 0	 70.67	 19.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.6667;
	23360	 16.74	 0.0	 0.0	 0.0	 1.0	 21.95	 1	 16.74	 16.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23361	 12.92	 0.0	 0.0	 0.0	 1.0	 20.0	 1	 12.92	 12.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23363	 28.55	 6.28	 14.4	 -1.84	 1.0	 41.82	 1	 28.55	 28.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	23366	 12.92	 0.0	 0.0	 0.0	 1.0	 20.0	 0	 20.0	 5.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23366	 17.74	 0.0	 0.0	 0.0	 1.0	 26.35	 1	 17.74	 17.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23367	 7.37	 0.0	 0.0	 0.0	 1.0	 12.74	 0	 10.0	 4.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	23368	 15.05	 0.0	 0.0	 0.0	 1.0	 24.45	 1	 15.05	 15.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	23370	 10.16	 2.275	 5.22	 -0.67	 1.0	 16.57	 0	 13.6	 6.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	23370	 16.465	 4.37	 10.02	 -1.28	 1.0	 29.34	 0	 26.1	 6.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1;
	23370	 15.445	 4.37	 10.02	 -1.28	 1.0	 27.57	 0	 26.1	 4.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1;
	23372	 49.45	 9.215	 21.12	 -2.69	 1.0	 55.0	 1	 49.45	 49.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	23372	 43.41	 9.215	 21.12	 -2.69	 1.0	 56.73	 1	 43.41	 43.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	23377	 515.015	 139.7	 357.32	 -77.92	 1.0	 822.68	 1	 702.0	 328.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 702.0;
	23378	 498.08	 139.7	 357.32	 -77.92	 1.0	 802.26	 0	 702.0	 294.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 702.0;
	23379	 163.915	 46.37	 118.6	 -25.86	 1.0	 251.6	 1	 233.0	 94.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	23380	 156.71	 46.37	 118.6	 -25.86	 1.0	 255.96	 1	 233.0	 80.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	23381	 151.85	 46.37	 118.6	 -25.86	 1.0	 233.0	 1	 233.0	 70.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	23382	 170.565	 46.37	 118.6	 -25.86	 1.0	 318.21	 1	 233.0	 108.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	23383	 138.595	 46.37	 118.6	 -25.86	 1.0	 252.6	 1	 233.0	 44.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	23384	 166.595	 46.37	 118.6	 -25.86	 1.0	 233.0	 1	 233.0	 100.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 233.0;
	23385	 21.97	 0.0	 0.0	 0.0	 1.0	 41.35	 1	 21.97	 21.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	23385	 30.0	 0.0	 0.0	 0.0	 1.0	 32.67	 1	 30.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	23385	 26.4	 0.0	 0.0	 0.0	 1.0	 40.95	 1	 26.4	 26.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	23386	 30.67	 9.93	 25.4	 -5.54	 1.0	 68.1	 1	 49.9	 11.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	23389	 38.56	 0.0	 0.0	 0.0	 1.0	 72.65	 0	 54.0	 23.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	23390	 4.94	 0.0	 0.0	 0.0	 1.0	 8.68	 0	 7.5	 2.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	23390	 14.03	 0.0	 0.0	 0.0	 1.0	 33.23	 1	 14.03	 14.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	23390	 25.0	 0.0	 0.0	 0.0	 1.0	 25.1	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	23390	 7.56	 0.0	 0.0	 0.0	 1.0	 30.6	 1	 7.56	 7.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	23393	 32.64	 6.28	 14.4	 -1.84	 1.0	 41.6	 1	 32.64	 32.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	23396	 35.36	 0.0	 0.0	 0.0	 1.0	 76.9	 0	 52.0	 18.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.0;
	23399	 17.385	 5.475	 14.01	 -3.06	 1.0	 35.86	 1	 27.53	 7.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.53;
	23400	 18.03	 5.475	 14.01	 -3.06	 1.0	 28.0	 1	 27.53	 8.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.53;
	23401	 18.51	 5.475	 14.01	 -3.06	 1.0	 35.86	 1	 27.53	 9.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.5333;
	23403	 26.295	 9.15	 23.41	 -5.11	 1.0	 60.66	 1	 46.0	 6.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	23405	 34.46	 9.415	 24.08	 -5.25	 1.0	 70.73	 1	 47.3	 21.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.3;
	23406	 44.445	 12.035	 30.79	 -6.72	 1.0	 78.08	 1	 60.5	 28.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	23406	 36.505	 12.035	 30.79	 -6.72	 1.0	 76.86	 1	 60.5	 12.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	23411	 150.67	 33.465	 76.72	 -9.79	 1.0	 252.22	 1	 150.67	 150.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.8;
	23417	 291.98	 58.79	 134.78	 -17.2	 1.0	 414.27	 1	 291.98	 291.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0;
	23418	 351.0	 58.79	 134.78	 -17.2	 1.0	 371.75	 1	 351.0	 351.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0;
	23419	 346.13	 58.79	 134.78	 -17.2	 1.0	 426.99	 1	 346.13	 346.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.0;
	23421	 32.97	 9.855	 25.2	 -5.49	 1.0	 54.55	 1	 49.5	 16.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	23422	 27.11	 7.645	 19.55	 -4.26	 1.0	 42.86	 1	 38.4	 15.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.4;
	23423	 81.9	 13.72	 31.45	 -4.01	 1.0	 94.15	 1	 81.9	 81.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.9;
	23425	 32.815	 9.17	 23.46	 -5.12	 1.0	 51.09	 1	 46.1	 19.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1;
	23426	 29.635	 9.17	 23.46	 -5.12	 1.0	 46.78	 1	 46.1	 13.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1;
	23434	 121.715	 36.815	 94.16	 -20.53	 1.0	 257.24	 1	 185.0	 58.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 185.0;
	23435	 58.01	 20.68	 52.89	 -11.53	 1.0	 120.78	 1	 103.9	 12.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.9;
	23436	 37.825	 9.215	 21.12	 -2.69	 1.0	 74.89	 0	 55.0	 20.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	23436	 51.3	 9.215	 21.12	 -2.69	 1.0	 59.39	 1	 51.3	 51.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	23436	 33.47	 9.215	 21.12	 -2.69	 1.0	 73.82	 1	 33.47	 33.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	23438	 8.02	 0.0	 0.0	 0.0	 1.0	 12.01	 1	 8.02	 8.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	23438	 14.77	 0.0	 0.0	 0.0	 1.0	 19.37	 1	 14.77	 14.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.4;
	23438	 12.75	 0.0	 0.0	 0.0	 1.0	 25.0	 1	 12.75	 12.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	23438	 14.1	 0.0	 0.0	 0.0	 1.0	 25.05	 1	 14.1	 14.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23438	 12.58	 0.0	 0.0	 0.0	 1.0	 20.3	 1	 12.58	 12.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	23441	 8.53	 0.0	 0.0	 0.0	 1.0	 12.66	 0	 12.5	 4.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	23441	 8.83	 0.0	 0.0	 0.0	 1.0	 14.47	 1	 8.83	 8.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	23441	 19.735	 0.0	 0.0	 0.0	 1.0	 35.45	 0	 28.0	 11.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	23445	 59.03	 19.94	 51.0	 -11.12	 1.0	 135.93	 1	 100.2	 17.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.2;
	23446	 71.27	 19.94	 51.0	 -11.12	 1.0	 118.89	 1	 100.2	 42.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.2;
	23447	 58.37	 19.94	 51.0	 -11.12	 1.0	 115.69	 1	 100.2	 16.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.2;
	23449	 40.895	 12.035	 30.79	 -6.72	 1.0	 86.85	 1	 60.5	 21.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	23453	 91.83	 25.125	 57.6	 -7.35	 1.0	 182.17	 1	 91.83	 91.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	23454	 132.32	 25.125	 57.6	 -7.35	 1.0	 172.7	 1	 132.32	 132.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	23455	 5.79	 1.35	 3.1	 -0.4	 1.0	 8.07	 1	 5.79	 5.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.07;
	23456	 5.85	 1.35	 3.1	 -0.4	 1.0	 8.98	 1	 5.85	 5.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.07;
	23456	 5.83	 1.35	 3.1	 -0.4	 1.0	 8.07	 1	 5.83	 5.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0667;
	23459	 14.45	 2.78	 6.37	 -0.81	 1.0	 16.68	 1	 14.45	 14.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	23460	 9.5	 2.78	 6.37	 -0.81	 1.0	 20.12	 0	 16.6	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	23462	 11.65	 2.78	 6.37	 -0.81	 1.0	 16.6	 1	 11.65	 11.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	23463	 11.03	 2.78	 6.37	 -0.81	 1.0	 19.34	 1	 11.03	 11.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	23469	 6.08	 1.51	 3.46	 -0.44	 1.0	 12.5	 0	 9.0	 3.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	23469	 65.08	 15.83	 36.29	 -4.63	 1.0	 133.0	 0	 94.5	 35.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.5;
	23471	 23.615	 7.74	 19.8	 -4.32	 1.0	 56.88	 1	 38.9	 8.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.9;
	23477	 27.96	 25.65	 25.65	 25.65	 1.0	 59.42	 1	 50.4	 5.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	23478	 29.985	 9.77	 24.99	 -5.45	 1.0	 58.65	 1	 49.1	 10.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.1;
	23478	 27.945	 9.77	 24.99	 -5.45	 1.0	 60.27	 1	 49.1	 6.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.1;
	23479	 6.25	 1.675	 4.28	 -0.93	 1.0	 10.7	 1	 8.4	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	23479	 5.42	 1.675	 4.28	 -0.93	 1.0	 10.67	 0	 8.4	 2.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	23480	 5.8	 1.675	 4.28	 -0.93	 1.0	 10.29	 0	 8.4	 3.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	23480	 6.02	 1.675	 4.28	 -0.93	 1.0	 12.47	 0	 8.4	 3.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	23481	 5.05	 1.675	 4.28	 -0.93	 1.0	 10.57	 0	 8.4	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	23481	 5.645	 1.675	 4.28	 -0.93	 1.0	 10.66	 0	 8.4	 2.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	23484	 31.0	 5.19	 11.9	 -1.52	 1.0	 34.14	 1	 31.0	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	23485	 40.94	 8.14	 18.66	 -2.38	 1.0	 48.6	 1	 40.94	 40.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.6;
	23487	 33.45	 8.14	 18.66	 -2.38	 1.0	 49.09	 1	 33.45	 33.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.6;
	23490	 12.81	 3.515	 8.06	 -1.03	 1.0	 23.85	 1	 12.81	 12.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	23491	 21.0	 3.515	 8.06	 -1.03	 1.0	 21.32	 1	 21.0	 21.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	23493	 95.0	 15.915	 36.48	 -4.65	 1.0	 111.02	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	23493	 95.0	 15.915	 36.48	 -4.65	 1.0	 127.23	 1	 95.0	 95.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	23495	 5.03	 1.645	 4.21	 -0.92	 1.0	 8.92	 0	 8.27	 1.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2667;
	23495	 5.41	 1.645	 4.21	 -0.92	 1.0	 11.78	 0	 8.27	 2.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2667;
	23495	 5.945	 1.645	 4.21	 -0.92	 1.0	 9.24	 1	 8.27	 3.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2667;
	23495	 5.03	 1.645	 4.21	 -0.92	 1.0	 9.11	 0	 8.27	 1.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.27;
	23495	 5.16	 1.645	 4.21	 -0.92	 1.0	 11.41	 0	 8.27	 2.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2667;
	23495	 4.95	 1.645	 4.21	 -0.92	 1.0	 8.27	 0	 8.27	 1.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2667;
	23499	 48.035	 13.91	 35.58	 -7.76	 1.0	 77.96	 1	 69.9	 26.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9;
	23499	 48.69	 13.91	 35.58	 -7.76	 1.0	 79.04	 1	 69.9	 27.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.9;
	23501	 27.85	 7.155	 16.4	 -2.09	 1.0	 58.08	 1	 27.85	 27.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7;
	23501	 36.51	 7.155	 16.4	 -2.09	 1.0	 58.99	 1	 36.51	 36.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7;
	23502	 31.545	 7.155	 16.4	 -2.09	 1.0	 43.13	 0	 42.7	 20.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7;
	23503	 27.91	 7.155	 16.4	 -2.09	 1.0	 43.89	 1	 27.91	 27.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.7;
	23510	 157.48	 45.665	 116.8	 -25.47	 1.0	 320.01	 1	 229.47	 85.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.47;
	23511	 157.265	 45.665	 116.8	 -25.47	 1.0	 289.27	 1	 229.47	 85.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.4667;
	23512	 171.32	 45.665	 116.8	 -25.47	 1.0	 239.81	 1	 229.47	 113.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.4667;
	23513	 5.41	 1.495	 3.82	 -0.83	 1.0	 7.57	 0	 7.5	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	25829	 477.79	 160.39	 410.25	 -89.47	 1.0	 941.78	 0	 806.0	 149.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 806.0;
	25830	 563.23	 160.39	 410.25	 -89.47	 1.0	 951.99	 1	 806.0	 320.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 806.0;
	25831	 16.43	 5.77	 14.76	 -3.22	 1.0	 29.0	 1	 29.0	 3.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	25834	 136.12	 6.52	 40.26	 -27.22	 1.0	 233.3	 1	 136.12	 136.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.0;
	25835	 60.0	 2.07	 12.78	 -8.64	 1.0	 71.55	 1	 60.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	25837	 16.505	 5.55	 14.2	 -3.1	 1.0	 31.3	 0	 27.9	 5.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9;
	25837	 18.46	 5.55	 14.2	 -3.1	 1.0	 41.63	 1	 27.9	 9.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.9;
	25839	 38.105	 0.0	 0.0	 0.0	 1.0	 62.04	 0	 60.0	 16.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	25840	 21.705	 6.835	 17.48	 -3.81	 1.0	 45.78	 1	 34.35	 9.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.35;
	25840	 21.03	 6.835	 17.48	 -3.81	 1.0	 41.4	 1	 34.35	 7.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.35;
	25843	 49.96	 0.0	 0.0	 0.0	 1.0	 55.7	 1	 49.96	 49.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.96;
	25844	 40.07	 0.0	 0.0	 0.0	 1.0	 58.48	 1	 40.07	 40.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.96;
	25844	 35.475	 0.0	 0.0	 0.0	 1.0	 56.01	 0	 49.96	 20.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.96;
	25845	 36.115	 0.0	 0.0	 0.0	 1.0	 50.59	 0	 49.96	 22.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.96;
	25846	 39.48	 0.0	 0.0	 0.0	 1.0	 67.7	 1	 39.48	 39.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.96;
	25852	 103.16	 5.235	 32.31	 -21.84	 1.0	 189.83	 1	 103.16	 103.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 151.7;
	25854	 31.9	 0.0	 0.0	 0.0	 1.0	 41.82	 1	 31.9	 31.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.9;
	25855	 23.095	 0.0	 0.0	 0.0	 1.0	 34.0	 0	 34.0	 12.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	25857	 40.3	 11.425	 29.22	 -6.37	 1.0	 74.18	 1	 57.4	 23.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	25863	 89.055	 4.66	 28.76	 -19.44	 1.0	 194.1	 0	 135.0	 43.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	25867	 111.8	 5.175	 31.95	 -21.6	 1.0	 205.84	 1	 111.8	 111.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	25868	 119.0	 5.175	 31.95	 -21.6	 1.0	 176.74	 1	 119.0	 119.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	25869	 25.25	 0.0	 0.0	 0.0	 1.0	 45.32	 1	 25.25	 25.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2;
	25871	 20.64	 0.0	 0.0	 0.0	 1.0	 41.55	 1	 20.64	 20.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2;
	25872	 26.08	 0.0	 0.0	 0.0	 1.0	 43.35	 1	 26.08	 26.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.2;
	25874	 39.935	 13.435	 34.36	 -7.49	 1.0	 67.61	 0	 67.5	 12.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	25874	 48.59	 13.435	 34.36	 -7.49	 1.0	 94.26	 1	 67.5	 29.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	25874	 49.78	 13.435	 34.36	 -7.49	 1.0	 78.6	 1	 67.5	 32.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	25874	 41.79	 13.435	 34.36	 -7.49	 1.0	 96.97	 1	 67.5	 16.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	25874	 49.34	 13.435	 34.36	 -7.49	 1.0	 93.2	 1	 67.5	 31.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	25874	 40.925	 13.435	 34.36	 -7.49	 1.0	 89.06	 1	 67.5	 14.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.5;
	25875	 8.155	 2.39	 6.11	 -1.33	 1.0	 12.14	 0	 12.0	 4.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	25876	 69.065	 19.9	 50.9	 -11.1	 1.0	 129.97	 1	 100.0	 38.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	25876	 61.21	 19.9	 50.9	 -11.1	 1.0	 101.23	 1	 100.0	 22.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	25876	 59.46	 19.9	 50.9	 -11.1	 1.0	 137.24	 1	 100.0	 18.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	25876	 70.755	 19.9	 50.9	 -11.1	 1.0	 141.9	 1	 100.0	 41.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	25876	 65.72	 19.9	 50.9	 -11.1	 1.0	 143.84	 1	 100.0	 31.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	25881	 41.825	 11.54	 29.52	 -6.44	 1.0	 82.78	 1	 58.0	 25.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.0;
	25887	 155.07	 0.0	 0.0	 0.0	 1.0	 276.13	 0	 253.0	 57.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 253.0;
	25889	 47.275	 14.92	 38.17	 -8.33	 1.0	 83.12	 1	 75.0	 19.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	25890	 30.83	 0.0	 0.0	 0.0	 1.0	 68.51	 1	 30.83	 30.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.0;
	25892	 30.075	 9.91	 25.35	 -5.53	 1.0	 50.2	 1	 49.8	 10.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	25896	 70.32	 0.0	 0.0	 0.0	 1.0	 161.5	 0	 110.0	 30.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.0;
	25899	 15.56	 0.76	 4.69	 -3.17	 1.0	 22.41	 1	 15.56	 15.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	25899	 58.87	 2.655	 16.38	 -11.07	 1.0	 76.9	 1	 58.87	 58.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 76.9;
	25900	 14.335	 0.0	 0.0	 0.0	 1.0	 25.13	 0	 20.0	 8.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25900	 15.99	 0.0	 0.0	 0.0	 1.0	 20.08	 1	 15.99	 15.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25904	 113.41	 31.005	 79.3	 -17.29	 1.0	 201.62	 1	 155.8	 71.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.8;
	25905	 106.555	 31.005	 79.3	 -17.29	 1.0	 225.23	 1	 155.8	 57.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.8;
	25906	 110.99	 31.005	 79.3	 -17.29	 1.0	 157.81	 1	 155.8	 66.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.8;
	25907	 86.92	 31.005	 79.3	 -17.29	 1.0	 198.68	 1	 155.8	 18.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.8;
	25908	 114.62	 31.005	 79.3	 -17.29	 1.0	 215.18	 1	 155.8	 73.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 155.8;
	25911	 27.49	 6.57	 17.8	 -4.66	 1.0	 45.38	 0	 38.2	 16.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	25914	 12.995	 4.635	 11.86	 -2.59	 1.0	 28.96	 1	 23.3	 2.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.3;
	25914	 14.995	 4.635	 11.86	 -2.59	 1.0	 23.73	 1	 23.3	 6.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.3;
	25915	 7.55	 2.045	 5.23	 -1.14	 1.0	 11.54	 1	 10.27	 4.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2667;
	25915	 7.17	 2.045	 5.23	 -1.14	 1.0	 11.75	 1	 10.27	 4.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.27;
	25915	 6.92	 2.045	 5.23	 -1.14	 1.0	 10.37	 0	 10.27	 3.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2667;
	25915	 15.195	 4.855	 12.42	 -2.71	 1.0	 33.14	 1	 24.4	 5.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.4;
	25915	 15.485	 4.855	 12.42	 -2.71	 1.0	 24.6	 1	 24.4	 6.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.4;
	25916	 34.935	 12.035	 30.79	 -6.72	 1.0	 60.7	 1	 60.5	 9.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	25917	 23.84	 1.0	 6.18	 -4.18	 1.0	 39.99	 1	 23.84	 23.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	25917	 26.385	 1.615	 9.97	 -6.74	 1.0	 69.54	 0	 46.8	 5.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.8;
	25918	 7.56	 0.0	 0.0	 0.0	 1.0	 10.31	 1	 7.56	 7.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	25918	 8.87	 0.0	 0.0	 0.0	 1.0	 12.0	 0	 12.0	 5.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	25918	 13.45	 0.0	 0.0	 0.0	 1.0	 25.74	 0	 20.0	 6.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25918	 14.31	 0.0	 0.0	 0.0	 1.0	 22.05	 1	 14.31	 14.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25923	 91.735	 26.735	 68.38	 -14.91	 1.0	 196.78	 1	 134.35	 49.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.35;
	25924	 83.88	 26.735	 68.38	 -14.91	 1.0	 165.35	 1	 134.35	 33.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.35;
	25925	 96.615	 26.735	 68.38	 -14.91	 1.0	 134.82	 1	 134.35	 58.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.35;
	25926	 98.9	 26.735	 68.38	 -14.91	 1.0	 168.22	 1	 134.35	 63.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 134.35;
	25927	 23.605	 7.085	 18.12	 -3.95	 1.0	 51.02	 1	 35.6	 11.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.6;
	25932	 29.92	 9.91	 25.35	 -5.53	 1.0	 59.15	 1	 49.8	 10.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	25932	 11.045	 3.055	 7.81	 -1.7	 1.0	 17.09	 0	 15.35	 6.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.35;
	25933	 9.65	 3.055	 7.81	 -1.7	 1.0	 16.91	 0	 15.35	 3.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.35;
	25933	 4.79	 1.335	 3.41	 -0.74	 1.0	 9.06	 0	 6.7	 2.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.7;
	25934	 40.06	 0.0	 0.0	 0.0	 1.0	 63.87	 1	 40.06	 40.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.1;
	25934	 28.735	 0.0	 0.0	 0.0	 1.0	 51.9	 0	 47.1	 10.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.1;
	25934	 47.1	 0.0	 0.0	 0.0	 1.0	 54.68	 1	 47.1	 47.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.1;
	25935	 47.1	 0.0	 0.0	 0.0	 1.0	 54.0	 1	 47.1	 47.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.1;
	25935	 28.23	 0.0	 0.0	 0.0	 1.0	 67.5	 1	 28.23	 28.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.1;
	25938	 227.875	 68.06	 174.08	 -37.96	 1.0	 434.91	 1	 342.0	 113.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 342.0;
	25940	 36.05	 0.0	 0.0	 0.0	 1.0	 46.12	 1	 36.05	 36.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	25940	 10.64	 0.0	 0.0	 0.0	 1.0	 16.28	 1	 10.64	 10.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	25941	 5.1	 0.0	 0.0	 0.0	 1.0	 9.02	 0	 8.5	 1.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5;
	25943	 32.925	 9.655	 24.69	 -5.38	 1.0	 67.32	 1	 48.5	 17.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.5;
	25944	 12.29	 2.9	 6.65	 -0.85	 1.0	 21.74	 1	 12.29	 12.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.33;
	25944	 17.33	 2.9	 6.65	 -0.85	 1.0	 23.69	 1	 17.33	 17.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.325;
	25944	 13.8	 2.9	 6.65	 -0.85	 1.0	 17.33	 1	 13.8	 13.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.325;
	25944	 10.25	 2.9	 6.65	 -0.85	 1.0	 22.57	 0	 17.33	 3.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.33;
	25947	 5.97	 0.3	 1.84	 -1.24	 1.0	 11.2	 1	 5.97	 5.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.625;
	25948	 8.62	 0.3	 1.84	 -1.24	 1.0	 10.07	 1	 8.62	 8.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.625;
	25950	 30.0	 1.035	 6.39	 -4.32	 1.0	 33.21	 1	 30.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	25950	 27.18	 1.035	 6.39	 -4.32	 1.0	 41.69	 1	 27.18	 27.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	25951	 24.36	 1.0	 6.18	 -4.18	 1.0	 40.55	 1	 24.36	 24.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	25951	 22.85	 0.99	 6.11	 -4.13	 1.0	 42.42	 1	 22.85	 22.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.7;
	25952	 14.32	 0.86	 5.32	 -3.6	 1.0	 29.1	 0	 25.0	 3.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	25953	 20.34	 0.815	 5.01	 -3.38	 1.0	 26.28	 1	 20.34	 20.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5;
	25954	 20.43	 0.775	 4.79	 -3.24	 1.0	 33.75	 1	 20.43	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	25954	 6.92	 0.3	 1.84	 -1.24	 1.0	 8.79	 1	 6.92	 6.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.625;
	25955	 6.385	 0.3	 1.84	 -1.24	 1.0	 11.51	 0	 8.62	 4.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.625;
	25957	 7.4	 0.255	 1.58	 -1.07	 1.0	 7.51	 1	 7.4	 7.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4;
	25957	 5.83	 0.375	 2.33	 -1.58	 1.0	 12.27	 1	 5.83	 5.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.95;
	25957	 9.43	 0.375	 2.33	 -1.58	 1.0	 10.95	 1	 9.43	 9.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.95;
	25957	 8.25	 0.485	 3.0	 -2.03	 1.0	 17.81	 0	 14.1	 2.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.1;
	25957	 11.455	 0.635	 3.92	 -2.65	 1.0	 23.36	 0	 18.4	 4.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.4;
	25957	 13.345	 0.735	 4.52	 -3.05	 1.0	 21.44	 0	 21.2	 5.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.2;
	25960	 18.625	 4.955	 12.67	 -2.76	 1.0	 29.56	 1	 24.9	 12.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	25961	 17.565	 4.955	 12.67	 -2.76	 1.0	 24.9	 1	 24.9	 10.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	25963	 15.115	 4.955	 12.67	 -2.76	 1.0	 27.8	 1	 24.9	 5.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	25964	 15.825	 4.955	 12.67	 -2.76	 1.0	 30.4	 1	 24.9	 6.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	25968	 109.85	 4.14	 25.56	 -17.28	 1.0	 132.89	 1	 109.85	 109.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	25969	 10.165	 0.555	 3.41	 -2.3	 1.0	 24.0	 0	 16.0	 4.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	25969	 5.27	 0.26	 1.6	 -1.08	 1.0	 7.5	 1	 5.27	 5.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	25970	 4.64	 0.24	 1.47	 -0.99	 1.0	 8.18	 1	 4.64	 4.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9;
	25972	 46.42	 12.54	 32.07	 -6.99	 1.0	 69.11	 1	 63.0	 29.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	25972	 44.335	 12.54	 32.07	 -6.99	 1.0	 83.01	 1	 63.0	 25.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	25972	 39.59	 12.54	 32.07	 -6.99	 1.0	 75.1	 1	 63.0	 16.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	25972	 40.57	 12.54	 32.07	 -6.99	 1.0	 70.74	 1	 63.0	 18.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	25975	 132.0	 4.555	 28.12	 -19.01	 1.0	 146.32	 1	 132.0	 132.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.0;
	25977	 15.0	 0.52	 3.2	 -2.16	 1.0	 15.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	25977	 27.1	 0.935	 5.77	 -3.9	 1.0	 30.07	 1	 27.1	 27.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.1;
	25978	 22.175	 0.0	 0.0	 0.0	 1.0	 46.84	 0	 35.0	 9.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	25980	 14.24	 4.955	 12.67	 -2.76	 1.0	 34.32	 1	 24.9	 3.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	25980	 16.06	 4.955	 12.67	 -2.76	 1.0	 27.88	 1	 24.9	 7.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	25982	 18.03	 4.905	 12.55	 -2.74	 1.0	 25.06	 1	 24.65	 11.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.65;
	25982	 15.105	 4.905	 12.55	 -2.74	 1.0	 24.65	 1	 24.65	 5.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.65;
	25984	 32.76	 8.885	 22.73	 -4.96	 1.0	 47.89	 1	 44.65	 20.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.65;
	25984	 29.38	 8.885	 22.73	 -4.96	 1.0	 49.54	 1	 44.65	 14.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.65;
	25985	 26.805	 8.885	 22.73	 -4.96	 1.0	 56.83	 1	 44.65	 8.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.65;
	25985	 30.17	 8.885	 22.73	 -4.96	 1.0	 66.97	 1	 44.65	 15.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.65;
	25987	 37.855	 12.035	 30.79	 -6.72	 1.0	 79.55	 1	 60.5	 15.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	25987	 33.53	 12.035	 30.79	 -6.72	 1.0	 71.34	 1	 60.5	 6.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	25987	 42.54	 12.035	 30.79	 -6.72	 1.0	 79.23	 1	 60.5	 24.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	25987	 39.28	 12.035	 30.79	 -6.72	 1.0	 80.24	 1	 60.5	 18.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	25987	 38.1	 12.035	 30.79	 -6.72	 1.0	 82.04	 1	 60.5	 15.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	25987	 59.63	 16.29	 41.67	 -9.09	 1.0	 91.38	 1	 81.87	 37.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.8667;
	25987	 48.89	 16.29	 41.67	 -9.09	 1.0	 112.32	 1	 81.87	 15.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.87;
	25987	 55.815	 16.29	 41.67	 -9.09	 1.0	 90.43	 1	 81.87	 29.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.8667;
	25991	 5.56	 0.0	 0.0	 0.0	 1.0	 7.5	 1	 5.56	 5.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	25991	 12.52	 0.0	 0.0	 0.0	 1.0	 24.24	 0	 20.0	 5.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25991	 15.72	 0.0	 0.0	 0.0	 1.0	 24.93	 1	 15.72	 15.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25991	 12.76	 0.0	 0.0	 0.0	 1.0	 20.0	 1	 12.76	 12.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	25995	 129.41	 5.175	 31.95	 -21.6	 1.0	 196.39	 1	 129.41	 129.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	25996	 40.055	 2.055	 12.69	 -8.58	 1.0	 63.31	 0	 59.6	 20.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.6;
	25998	 29.155	 9.15	 23.41	 -5.11	 1.0	 51.51	 1	 46.0	 12.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	25999	 6.84	 2.39	 6.11	 -1.33	 1.0	 12.12	 0	 12.0	 1.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	25999	 33.04	 10.53	 26.94	 -5.88	 1.0	 77.17	 1	 52.93	 13.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.93;
	25999	 39.18	 10.53	 26.94	 -5.88	 1.0	 71.93	 1	 52.93	 25.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9333;
	25999	 38.27	 10.53	 26.94	 -5.88	 1.0	 52.93	 1	 52.93	 23.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.9333;
	26000	 7.505	 2.465	 6.31	 -1.38	 1.0	 12.53	 1	 12.4	 2.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.4;
	26000	 13.46	 4.4	 11.25	 -2.45	 1.0	 33.15	 1	 22.1	 4.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.1;
	26004	 135.75	 5.175	 31.95	 -21.6	 1.0	 163.11	 1	 135.75	 135.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	26006	 8.695	 3.09	 7.91	 -1.73	 1.0	 15.89	 0	 15.55	 1.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.55;
	26006	 9.46	 3.09	 7.91	 -1.73	 1.0	 15.55	 1	 15.55	 3.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.55;
	26006	 34.045	 9.655	 24.69	 -5.38	 1.0	 62.81	 1	 48.5	 19.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.5;
	26009	 10.31	 3.58	 9.16	 -2.0	 1.0	 20.11	 0	 18.0	 2.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	26009	 11.21	 3.58	 9.16	 -2.0	 1.0	 19.53	 1	 18.0	 4.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	26012	 90.81	 5.795	 35.78	 -24.19	 1.0	 222.87	 1	 90.81	 90.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 168.0;
	26013	 32.755	 9.15	 23.41	 -5.11	 1.0	 60.99	 0	 46.0	 19.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	26017	 206.33	 65.49	 167.51	 -36.53	 1.0	 369.63	 1	 329.1	 83.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.1;
	26018	 246.02	 65.49	 167.51	 -36.53	 1.0	 354.5	 1	 329.1	 162.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.1;
	26019	 220.855	 65.49	 167.51	 -36.53	 1.0	 393.87	 1	 329.1	 112.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.1;
	26020	 212.385	 65.49	 167.51	 -36.53	 1.0	 457.85	 1	 329.1	 95.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 329.1;
	26023	 6.19	 2.11	 5.4	 -1.18	 1.0	 13.77	 0	 10.6	 1.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6;
	26023	 28.03	 9.15	 23.41	 -5.11	 1.0	 53.51	 1	 46.0	 10.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	26026	 9.925	 2.855	 7.3	 -1.59	 1.0	 15.91	 1	 14.33	 5.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.3333;
	26026	 9.705	 2.855	 7.3	 -1.59	 1.0	 18.05	 0	 14.33	 5.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.33;
	26026	 10.165	 2.855	 7.3	 -1.59	 1.0	 14.33	 0	 14.33	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.33;
	26029	 21.96	 5.975	 15.28	 -3.33	 1.0	 41.67	 0	 30.02	 13.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.02;
	26029	 17.83	 5.975	 15.28	 -3.33	 1.0	 39.91	 1	 30.02	 5.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.02;
	26029	 17.2	 5.975	 15.28	 -3.33	 1.0	 45.03	 1	 30.02	 4.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.02;
	26029	 19.78	 5.975	 15.28	 -3.33	 1.0	 45.03	 1	 30.02	 9.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0167;
	26030	 21.43	 5.975	 15.28	 -3.33	 1.0	 33.65	 1	 30.02	 12.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0167;
	26031	 19.68	 5.975	 15.28	 -3.33	 1.0	 34.94	 1	 30.02	 9.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0167;
	26034	 31.825	 9.15	 23.41	 -5.11	 1.0	 66.43	 1	 46.0	 17.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	26038	 135.935	 43.38	 110.96	 -24.2	 1.0	 283.35	 1	 218.0	 53.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	26039	 161.92	 43.38	 110.96	 -24.2	 1.0	 218.0	 1	 218.0	 105.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	26040	 89.05	 27.46	 70.24	 -15.32	 1.0	 156.4	 1	 138.0	 40.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.0;
	26042	 42.485	 11.645	 29.78	 -6.49	 1.0	 78.26	 1	 58.5	 26.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.5;
	26043	 5.64	 1.99	 5.09	 -1.11	 1.0	 10.06	 0	 10.0	 1.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	26044	 31.715	 10.915	 27.92	 -6.09	 1.0	 71.31	 1	 54.85	 8.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.85;
	26044	 33.155	 10.915	 27.92	 -6.09	 1.0	 59.12	 1	 54.85	 11.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.85;
	26047	 108.59	 5.175	 31.95	 -21.6	 1.0	 206.77	 1	 108.59	 108.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	26051	 118.645	 40.16	 102.72	 -22.4	 1.0	 253.71	 0	 201.8	 35.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.8;
	26052	 119.33	 40.16	 102.72	 -22.4	 1.0	 263.45	 1	 201.8	 36.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.8;
	26053	 120.515	 40.16	 102.72	 -22.4	 1.0	 256.47	 1	 201.8	 39.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.8;
	26056	 28.995	 9.15	 23.41	 -5.11	 1.0	 67.98	 1	 46.0	 11.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	26061	 120.59	 41.79	 106.89	 -23.31	 1.0	 210.0	 1	 210.0	 31.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0;
	26062	 116.535	 41.79	 106.89	 -23.31	 1.0	 271.5	 0	 210.0	 23.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0;
	26063	 149.28	 41.79	 106.89	 -23.31	 1.0	 315.0	 1	 210.0	 88.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 210.0;
	26064	 43.465	 12.035	 30.79	 -6.72	 1.0	 69.59	 1	 60.5	 26.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	26066	 5.35	 1.91	 4.89	 -1.07	 1.0	 12.23	 0	 9.6	 1.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	26067	 7.15	 1.91	 4.89	 -1.07	 1.0	 9.71	 0	 9.6	 4.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	26069	 5.67	 1.91	 4.89	 -1.07	 1.0	 12.63	 1	 9.6	 1.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	26069	 6.46	 1.91	 4.89	 -1.07	 1.0	 9.6	 0	 9.6	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	26073	 21.93	 7.7	 19.7	 -4.3	 1.0	 46.02	 1	 38.7	 5.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.7;
	26074	 5.81	 1.75	 4.48	 -0.98	 1.0	 9.77	 1	 8.8	 2.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.8;
	26074	 5.005	 1.75	 4.48	 -0.98	 1.0	 8.8	 0	 8.8	 1.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.8;
	26076	 11.15	 2.98	 7.62	 -1.66	 1.0	 14.97	 1	 14.97	 7.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.98;
	26076	 10.665	 2.98	 7.62	 -1.66	 1.0	 14.97	 1	 14.97	 6.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.975;
	26077	 11.025	 2.98	 7.62	 -1.66	 1.0	 14.97	 1	 14.97	 7.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.98;
	26078	 10.825	 2.98	 7.62	 -1.66	 1.0	 18.74	 0	 14.97	 6.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.975;
	26080	 10.1	 3.085	 7.89	 -1.72	 1.0	 15.96	 1	 15.5	 4.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.5;
	26080	 10.305	 3.085	 7.89	 -1.72	 1.0	 15.85	 0	 15.5	 5.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.5;
	26080	 17.15	 5.505	 14.08	 -3.07	 1.0	 40.12	 1	 27.67	 6.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6667;
	26080	 16.54	 5.505	 14.08	 -3.07	 1.0	 31.68	 1	 27.67	 5.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6667;
	26080	 19.44	 5.505	 14.08	 -3.07	 1.0	 33.62	 1	 27.67	 11.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6667;
	26085	 25.185	 6.215	 14.25	 -1.82	 1.0	 37.1	 0	 37.1	 13.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.1;
	26085	 23.87	 6.215	 14.25	 -1.82	 1.0	 48.6	 0	 37.1	 10.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.1;
	26086	 14.26	 3.285	 7.53	 -0.96	 1.0	 19.87	 1	 14.26	 14.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	26089	 120.31	 5.59	 34.51	 -23.33	 1.0	 180.55	 1	 120.31	 120.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 162.0;
	26091	 16.405	 0.0	 0.0	 0.0	 1.0	 40.95	 0	 28.5	 4.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.5;
	26091	 24.88	 0.0	 0.0	 0.0	 1.0	 36.32	 1	 24.88	 24.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.5;
	26093	 22.08	 0.0	 0.0	 0.0	 1.0	 51.46	 1	 22.08	 22.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	26093	 8.15	 0.0	 0.0	 0.0	 1.0	 11.36	 1	 8.15	 8.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.1;
	26097	 188.66	 63.745	 163.05	 -35.56	 1.0	 383.27	 1	 320.33	 56.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.3333;
	26098	 189.52	 63.745	 163.05	 -35.56	 1.0	 389.51	 1	 320.33	 58.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.33;
	26099	 224.085	 63.745	 163.05	 -35.56	 1.0	 444.98	 1	 320.33	 127.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.33;
	26100	 230.315	 63.745	 163.05	 -35.56	 1.0	 446.37	 1	 320.33	 140.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.3333;
	26101	 193.965	 63.745	 163.05	 -35.56	 1.0	 320.33	 1	 320.33	 67.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.33;
	26102	 218.195	 63.745	 163.05	 -35.56	 1.0	 402.11	 0	 320.33	 116.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 320.33;
	26105	 29.7	 8.955	 22.9	 -4.99	 1.0	 53.58	 1	 45.0	 14.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	26105	 27.985	 8.955	 22.9	 -4.99	 1.0	 65.1	 1	 45.0	 10.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	26106	 10.48	 2.815	 7.2	 -1.57	 1.0	 20.56	 0	 14.15	 6.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.15;
	26107	 8.78	 2.815	 7.2	 -1.57	 1.0	 14.48	 0	 14.15	 3.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.15;
	26110	 29.035	 9.59	 24.53	 -5.35	 1.0	 53.37	 1	 48.2	 9.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.2;
	26116	 168.0	 5.795	 35.78	 -24.19	 1.0	 187.18	 1	 168.0	 168.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 168.0;
	26117	 81.91	 3.52	 21.73	 -14.69	 1.0	 137.77	 1	 81.91	 81.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.0;
	26120	 56.36	 3.105	 19.17	 -12.96	 1.0	 90.35	 0	 90.0	 22.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	26121	 8.45	 0.395	 2.42	 -1.63	 1.0	 17.02	 1	 8.45	 8.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.35;
	26122	 9.76	 0.395	 2.42	 -1.63	 1.0	 15.34	 1	 9.76	 9.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.35;
	26122	 8.7	 0.3	 1.85	 -1.25	 1.0	 12.02	 1	 8.7	 8.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.7;
	26128	 123.795	 38.565	 98.64	 -21.51	 1.0	 250.69	 0	 193.8	 53.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.8;
	26129	 118.36	 38.565	 98.64	 -21.51	 1.0	 233.55	 1	 193.8	 42.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.8;
	26133	 663.665	 166.095	 427.43	 -95.24	 1.0	 1398.26	 1	 1161.5	 165.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1161.5;
	26134	 645.875	 166.095	 427.43	 -95.24	 1.0	 1384.26	 1	 1161.5	 130.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1161.5;
	26138	 7.43	 2.665	 6.82	 -1.49	 1.0	 13.4	 0	 13.4	 1.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.4;
	26139	 9.83	 2.665	 6.82	 -1.49	 1.0	 15.79	 0	 13.4	 6.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.4;
	26141	 14.04	 4.475	 11.45	 -2.5	 1.0	 23.42	 1	 22.5	 5.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	26145	 68.96	 0.0	 0.0	 0.0	 1.0	 175.64	 0	 117.18	 20.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.18;
	26146	 117.18	 0.0	 0.0	 0.0	 1.0	 138.09	 1	 117.18	 117.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.18;
	26147	 114.33	 0.0	 0.0	 0.0	 1.0	 133.03	 1	 114.33	 114.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.18;
	26148	 95.92	 0.0	 0.0	 0.0	 1.0	 125.4	 1	 95.92	 95.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.18;
	26149	 76.525	 0.0	 0.0	 0.0	 1.0	 149.89	 0	 117.18	 35.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.18;
	26150	 66.0	 0.0	 0.0	 0.0	 1.0	 80.72	 1	 66.0	 66.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0;
	26157	 131.94	 0.0	 0.0	 0.0	 1.0	 289.78	 1	 131.94	 131.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.0;
	26158	 114.12	 0.0	 0.0	 0.0	 1.0	 250.77	 1	 114.12	 114.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0;
	26159	 132.86	 0.0	 0.0	 0.0	 1.0	 259.03	 0	 199.0	 66.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.0;
	26163	 397.005	 119.4	 305.4	 -66.6	 1.0	 716.41	 1	 600.0	 194.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 600.0;
	26164	 194.055	 60.715	 155.3	 -33.87	 1.0	 407.08	 1	 305.1	 83.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 305.1049;
	26165	 184.305	 59.7	 152.7	 -33.3	 1.0	 390.91	 1	 300.0	 68.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	26166	 214.62	 59.7	 152.7	 -33.3	 1.0	 342.41	 1	 300.0	 129.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.0;
	26167	 51.96	 15.52	 39.7	 -8.66	 1.0	 78.0	 1	 78.0	 25.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	26167	 52.89	 15.52	 39.7	 -8.66	 1.0	 107.05	 1	 78.0	 27.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	26167	 54.995	 15.52	 39.7	 -8.66	 1.0	 78.0	 1	 78.0	 31.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 78.0;
	26173	 144.41	 45.77	 117.07	 -25.53	 1.0	 310.86	 0	 230.0	 58.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0;
	26174	 127.165	 45.77	 117.07	 -25.53	 1.0	 249.38	 1	 230.0	 24.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0;
	26175	 155.935	 41.78	 106.87	 -23.31	 1.0	 290.79	 0	 209.97	 101.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.97;
	26176	 123.45	 41.78	 106.87	 -23.31	 1.0	 242.11	 1	 209.97	 36.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.97;
	26177	 130.88	 41.78	 106.87	 -23.31	 1.0	 220.97	 1	 209.97	 51.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.9667;
	26178	 61.07	 21.53	 55.07	 -12.01	 1.0	 122.45	 1	 108.2	 13.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.2;
	26179	 75.84	 21.53	 55.07	 -12.01	 1.0	 122.66	 1	 108.2	 43.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.2;
	26180	 79.02	 21.53	 55.07	 -12.01	 1.0	 114.24	 1	 108.2	 49.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.2;
	26181	 69.275	 21.53	 55.07	 -12.01	 1.0	 129.53	 1	 108.2	 30.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.2;
	26182	 69.78	 21.53	 55.07	 -12.01	 1.0	 136.21	 1	 108.2	 31.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.2;
	26183	 65.215	 21.53	 55.07	 -12.01	 1.0	 153.97	 1	 108.2	 22.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.2;
	26185	 28.665	 7.78	 19.9	 -4.34	 1.0	 48.44	 1	 39.1	 18.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.1;
	26190	 26.025	 7.125	 18.22	 -3.97	 1.0	 40.01	 1	 35.8	 16.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	26190	 24.025	 7.125	 18.22	 -3.97	 1.0	 35.8	 1	 35.8	 12.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	26191	 23.09	 7.125	 18.22	 -3.97	 1.0	 43.35	 1	 35.8	 10.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	26197	 178.6	 45.39	 104.06	 -13.28	 1.0	 306.43	 1	 178.6	 178.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	26198	 196.9	 45.39	 104.06	 -13.28	 1.0	 274.41	 1	 196.9	 196.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	26199	 180.95	 45.39	 104.06	 -13.28	 1.0	 344.7	 1	 180.95	 180.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	26200	 237.95	 45.39	 104.06	 -13.28	 1.0	 345.59	 1	 237.95	 237.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	26201	 257.84	 45.39	 104.06	 -13.28	 1.0	 307.04	 1	 257.84	 257.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	26202	 194.09	 45.39	 104.06	 -13.28	 1.0	 284.06	 1	 194.09	 194.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 271.0;
	26203	 37.65	 9.38	 21.5	 -2.74	 1.0	 62.78	 0	 56.0	 19.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.0;
	26205	 13.29	 3.36	 7.7	 -0.98	 1.0	 20.05	 0	 20.05	 6.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.05;
	26206	 4.32	 1.105	 2.53	 -0.32	 1.0	 6.67	 1	 4.32	 4.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6;
	26206	 7.0	 1.175	 2.69	 -0.34	 1.0	 7.0	 1	 7.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	26206	 4.48	 1.175	 2.69	 -0.34	 1.0	 7.8	 0	 7.0	 1.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	26206	 7.48	 1.59	 3.65	 -0.47	 1.0	 9.75	 1	 7.48	 7.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.5;
	26206	 15.29	 3.36	 7.7	 -0.98	 1.0	 29.65	 1	 15.29	 15.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.05;
	26208	 15.555	 4.255	 10.89	 -2.38	 1.0	 23.6	 1	 21.4	 9.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.4;
	26208	 15.7	 4.255	 10.89	 -2.38	 1.0	 32.1	 1	 21.4	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.4;
	26210	 83.11	 3.52	 21.73	 -14.69	 1.0	 130.23	 1	 83.11	 83.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.0;
	26215	 199.285	 54.605	 139.67	 -30.46	 1.0	 274.4	 1	 274.4	 124.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 274.4;
	26216	 175.165	 54.605	 139.67	 -30.46	 1.0	 276.92	 1	 274.4	 75.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 274.4;
	26217	 173.05	 54.605	 139.67	 -30.46	 1.0	 325.12	 1	 274.4	 71.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 274.4;
	26219	 28.62	 9.15	 23.41	 -5.11	 1.0	 46.0	 1	 46.0	 11.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.0;
	26222	 7.39	 1.42	 3.26	 -0.42	 1.0	 8.78	 1	 7.39	 7.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5;
	26223	 7.215	 1.655	 3.8	 -0.49	 1.0	 9.9	 0	 9.9	 4.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	26225	 10.59	 2.345	 5.38	 -0.69	 1.0	 14.13	 1	 10.59	 10.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	26226	 6.93	 2.345	 5.38	 -0.69	 1.0	 20.5	 1	 6.93	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	26226	 14.0	 2.345	 5.38	 -0.69	 1.0	 14.24	 1	 14.0	 14.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	26227	 7.88	 1.84	 4.22	 -0.54	 1.0	 13.8	 1	 7.88	 7.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	26227	 7.8	 1.695	 3.88	 -0.49	 1.0	 11.76	 1	 7.8	 7.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.1;
	26229	 22.44	 6.245	 15.98	 -3.49	 1.0	 41.62	 1	 31.4	 13.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	26230	 19.51	 6.245	 15.98	 -3.49	 1.0	 38.22	 1	 31.4	 7.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	26230	 22.745	 6.245	 15.98	 -3.49	 1.0	 31.91	 1	 31.4	 14.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.4;
	26234	 110.94	 4.76	 29.39	 -19.87	 1.0	 183.52	 1	 110.94	 110.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 138.0;
	26236	 32.51	 0.0	 0.0	 0.0	 1.0	 54.38	 1	 32.51	 32.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.25;
	26236	 44.25	 0.0	 0.0	 0.0	 1.0	 44.25	 1	 44.25	 44.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.25;
	26236	 35.46	 0.0	 0.0	 0.0	 1.0	 61.76	 1	 35.46	 35.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.25;
	26236	 28.33	 0.0	 0.0	 0.0	 1.0	 54.79	 1	 28.33	 28.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.25;
	26237	 37.85	 11.425	 29.22	 -6.37	 1.0	 60.31	 0	 57.4	 18.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	26238	 19.03	 5.995	 15.33	 -3.34	 1.0	 30.58	 1	 30.13	 7.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.125;
	26238	 17.6	 5.995	 15.33	 -3.34	 1.0	 30.81	 1	 30.13	 5.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.125;
	26238	 18.7	 5.995	 15.33	 -3.34	 1.0	 34.83	 1	 30.13	 7.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.13;
	26238	 19.47	 5.995	 15.33	 -3.34	 1.0	 38.3	 1	 30.13	 8.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.13;
	26238	 25.58	 8.16	 20.87	 -4.55	 1.0	 55.34	 1	 41.0	 10.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	26238	 27.64	 8.16	 20.87	 -4.55	 1.0	 48.01	 1	 41.0	 14.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	26238	 24.92	 8.16	 20.87	 -4.55	 1.0	 41.0	 1	 41.0	 8.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.0;
	28720	 103.47	 0.0	 0.0	 0.0	 1.0	 174.4	 1	 103.47	 103.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.0;
	28721	 79.565	 0.0	 0.0	 0.0	 1.0	 195.83	 0	 140.0	 19.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.0;
	28722	 16.45	 0.0	 0.0	 0.0	 1.0	 22.48	 1	 16.45	 16.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	28723	 10.0	 0.0	 0.0	 0.0	 1.0	 10.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28725	 39.635	 11.72	 29.98	 -6.54	 1.0	 61.04	 1	 58.9	 20.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.9;
	28727	 39.87	 1.705	 10.54	 -7.13	 1.0	 49.72	 1	 39.87	 39.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.5;
	28729	 42.94	 12.035	 30.79	 -6.72	 1.0	 86.7	 1	 60.5	 25.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	28732	 7.16	 0.0	 0.0	 0.0	 1.0	 13.99	 1	 7.16	 7.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	28733	 10.6	 0.0	 0.0	 0.0	 1.0	 14.15	 1	 10.6	 10.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	28735	 15.82	 0.0	 0.0	 0.0	 1.0	 32.4	 0	 21.6	 10.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.6;
	28736	 12.85	 0.0	 0.0	 0.0	 1.0	 16.82	 1	 12.85	 12.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	28736	 9.915	 0.0	 0.0	 0.0	 1.0	 16.67	 0	 14.8	 5.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	28740	 52.28	 0.0	 0.0	 0.0	 1.0	 75.46	 1	 52.28	 52.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.28;
	28741	 35.035	 0.0	 0.0	 0.0	 1.0	 52.6	 0	 52.28	 17.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2833;
	28742	 44.47	 0.0	 0.0	 0.0	 1.0	 75.56	 1	 44.47	 44.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2833;
	28743	 38.89	 0.0	 0.0	 0.0	 1.0	 70.78	 1	 38.89	 38.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.28;
	28744	 25.36	 0.0	 0.0	 0.0	 1.0	 54.29	 1	 25.36	 25.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.28;
	28744	 38.36	 0.0	 0.0	 0.0	 1.0	 59.41	 1	 38.36	 38.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.28;
	28746	 26.15	 0.0	 0.0	 0.0	 1.0	 60.0	 1	 26.15	 26.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.62;
	28746	 25.895	 0.0	 0.0	 0.0	 1.0	 41.62	 0	 41.62	 10.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.62;
	28747	 31.57	 0.0	 0.0	 0.0	 1.0	 48.33	 1	 31.57	 31.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.6167;
	28747	 35.98	 0.0	 0.0	 0.0	 1.0	 46.22	 1	 35.98	 35.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.6167;
	28748	 22.995	 0.0	 0.0	 0.0	 1.0	 42.61	 0	 41.62	 4.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.6167;
	28748	 28.27	 0.0	 0.0	 0.0	 1.0	 43.76	 1	 28.27	 28.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.6167;
	28751	 23.52	 0.0	 0.0	 0.0	 1.0	 29.13	 1	 23.52	 23.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.1333;
	28751	 25.12	 0.0	 0.0	 0.0	 1.0	 41.58	 1	 25.12	 25.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.13;
	28752	 21.58	 0.0	 0.0	 0.0	 1.0	 29.13	 1	 21.58	 21.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.1333;
	28753	 29.13	 0.0	 0.0	 0.0	 1.0	 36.93	 1	 29.13	 29.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.1333;
	28753	 20.69	 0.0	 0.0	 0.0	 1.0	 37.6	 1	 20.69	 20.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.1333;
	28754	 22.2	 0.0	 0.0	 0.0	 1.0	 31.85	 1	 22.2	 22.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.13;
	28755	 6.66	 0.0	 0.0	 0.0	 1.0	 22.4	 1	 6.66	 6.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	28755	 15.36	 0.0	 0.0	 0.0	 1.0	 20.12	 1	 15.36	 15.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	28755	 13.52	 0.0	 0.0	 0.0	 1.0	 19.38	 1	 13.52	 13.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	28755	 11.27	 0.0	 0.0	 0.0	 1.0	 16.06	 0	 16.0	 6.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	28757	 40.21	 1.725	 10.65	 -7.2	 1.0	 56.83	 1	 40.21	 40.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	28761	 91.62	 0.0	 0.0	 0.0	 1.0	 187.71	 0	 133.4	 49.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.4;
	28765	 81.37	 26.535	 67.87	 -14.8	 1.0	 143.31	 1	 133.33	 29.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	28766	 75.305	 26.535	 67.87	 -14.8	 1.0	 179.85	 1	 133.33	 17.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	28767	 92.31	 26.535	 67.87	 -14.8	 1.0	 189.54	 0	 133.33	 51.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	28768	 96.72	 26.535	 67.87	 -14.8	 1.0	 164.9	 1	 133.33	 60.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	28769	 86.63	 26.535	 67.87	 -14.8	 1.0	 190.56	 1	 133.33	 39.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.33;
	28770	 75.83	 26.535	 67.87	 -14.8	 1.0	 150.59	 1	 133.33	 18.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	28771	 4.755	 1.43	 3.66	 -0.8	 1.0	 7.2	 1	 7.2	 2.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.2;
	28778	 31.885	 10.55	 26.98	 -5.88	 1.0	 60.27	 1	 53.0	 10.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	28779	 32.965	 10.55	 26.98	 -5.88	 1.0	 60.21	 1	 53.0	 12.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.0;
	28784	 95.28	 34.39	 87.96	 -19.18	 1.0	 220.62	 1	 172.8	 17.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	28785	 100.755	 34.39	 87.96	 -19.18	 1.0	 202.44	 1	 172.8	 28.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	28786	 115.715	 34.39	 87.96	 -19.18	 1.0	 203.64	 1	 172.8	 58.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	28787	 123.135	 34.39	 87.96	 -19.18	 1.0	 200.77	 1	 172.8	 73.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	28788	 95.295	 34.39	 87.96	 -19.18	 1.0	 179.89	 1	 172.8	 17.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	28789	 105.965	 34.39	 87.96	 -19.18	 1.0	 227.33	 1	 172.8	 39.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	28791	 16.355	 5.115	 13.08	 -2.85	 1.0	 30.9	 1	 25.7	 7.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.7;
	28792	 16.435	 5.115	 13.08	 -2.85	 1.0	 34.85	 1	 25.7	 7.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.7;
	28797	 238.145	 66.27	 169.5	 -36.96	 1.0	 376.57	 1	 333.0	 143.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 333.0;
	28798	 184.61	 66.27	 169.5	 -36.96	 1.0	 366.05	 1	 333.0	 36.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 333.0;
	28799	 4.86	 1.455	 3.72	 -0.81	 1.0	 7.46	 0	 7.3	 2.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3;
	28799	 31.2	 9.91	 25.35	 -5.53	 1.0	 71.1	 1	 49.8	 12.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	28800	 17.115	 4.675	 11.96	 -2.61	 1.0	 24.65	 1	 23.5	 10.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5;
	28804	 15.42	 0.0	 0.0	 0.0	 1.0	 25.32	 1	 15.42	 15.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.8333;
	28804	 13.965	 0.0	 0.0	 0.0	 1.0	 26.78	 0	 20.83	 7.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.8333;
	28804	 12.4	 0.0	 0.0	 0.0	 1.0	 21.35	 0	 20.83	 3.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.8333;
	28805	 36.03	 9.69	 24.79	 -5.41	 1.0	 57.84	 1	 48.7	 23.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.7;
	28811	 41.355	 11.74	 30.03	 -6.55	 1.0	 67.52	 1	 59.0	 23.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	28812	 43.09	 11.74	 30.03	 -6.55	 1.0	 75.18	 1	 59.0	 27.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	28815	 13.25	 3.585	 9.71	 -2.54	 1.0	 22.97	 1	 20.83	 5.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.83;
	28815	 11.76	 3.585	 9.71	 -2.54	 1.0	 25.39	 1	 20.83	 2.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.8333;
	28815	 14.645	 3.585	 9.71	 -2.54	 1.0	 31.25	 1	 20.83	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.8333;
	28816	 10.0	 2.58	 6.99	 -1.83	 1.0	 19.48	 0	 15.0	 5.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	28817	 9.92	 2.58	 6.99	 -1.83	 1.0	 15.25	 0	 15.0	 4.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	28820	 11.77	 3.98	 10.18	 -2.22	 1.0	 22.39	 1	 20.0	 3.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	28821	 6.995	 1.895	 4.84	 -1.05	 1.0	 10.6	 1	 9.5	 4.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.5;
	28821	 5.845	 1.895	 4.84	 -1.05	 1.0	 11.41	 1	 9.5	 2.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.5;
	28823	 24.07	 0.0	 0.0	 0.0	 1.0	 42.54	 1	 24.07	 24.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	28824	 35.75	 1.55	 9.58	 -6.48	 1.0	 57.49	 1	 35.75	 35.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.0;
	28828	 53.9	 0.0	 0.0	 0.0	 1.0	 74.29	 1	 53.9	 53.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.9;
	28829	 7.86	 0.0	 0.0	 0.0	 1.0	 10.0	 1	 7.86	 7.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28829	 5.01	 0.0	 0.0	 0.0	 1.0	 8.71	 1	 5.01	 5.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.6667;
	28830	 6.67	 0.0	 0.0	 0.0	 1.0	 9.21	 1	 6.67	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.67;
	28830	 6.67	 0.0	 0.0	 0.0	 1.0	 7.35	 1	 6.67	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.67;
	28831	 43.315	 12.035	 30.79	 -6.72	 1.0	 88.27	 1	 60.5	 26.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	28833	 55.5	 0.0	 0.0	 0.0	 1.0	 61.6	 1	 55.5	 55.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.5;
	28834	 19.47	 0.0	 0.0	 0.0	 1.0	 28.97	 0	 26.0	 12.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.0;
	28835	 5.895	 1.77	 4.53	 -0.99	 1.0	 9.38	 0	 8.9	 2.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.9;
	28835	 17.92	 4.955	 12.67	 -2.76	 1.0	 27.5	 1	 24.9	 10.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	28835	 14.185	 4.955	 12.67	 -2.76	 1.0	 28.13	 1	 24.9	 3.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.9;
	28837	 6.875	 2.19	 5.6	 -1.22	 1.0	 13.82	 0	 11.0	 2.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	28837	 6.68	 2.19	 5.6	 -1.22	 1.0	 13.05	 1	 11.0	 2.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	28838	 7.6	 2.19	 5.6	 -1.22	 1.0	 11.29	 1	 11.0	 4.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	28839	 62.02	 0.0	 0.0	 0.0	 1.0	 118.54	 1	 62.02	 62.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.0;
	28844	 107.34	 37.08	 94.84	 -20.68	 1.0	 188.02	 1	 186.33	 28.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.33;
	28845	 138.385	 37.08	 94.84	 -20.68	 1.0	 214.41	 1	 186.33	 90.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.3333;
	28846	 128.365	 37.08	 94.84	 -20.68	 1.0	 235.43	 1	 186.33	 70.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.3333;
	28850	 128.185	 42.39	 108.42	 -23.64	 1.0	 237.49	 1	 213.0	 43.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	28851	 146.205	 42.39	 108.42	 -23.64	 1.0	 317.5	 1	 213.0	 79.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	28852	 153.325	 42.39	 108.42	 -23.64	 1.0	 265.12	 1	 213.0	 93.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	28853	 154.2	 42.39	 108.42	 -23.64	 1.0	 223.79	 0	 213.0	 95.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	28854	 11.57	 3.98	 10.18	 -2.22	 1.0	 20.0	 1	 20.0	 3.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	28855	 10.005	 3.58	 9.16	 -2.0	 1.0	 18.0	 1	 18.0	 2.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	28856	 27.47	 9.93	 25.4	 -5.54	 1.0	 58.45	 1	 49.9	 5.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	28858	 6.15	 0.0	 0.0	 0.0	 1.0	 13.71	 1	 6.15	 6.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	28858	 31.53	 0.0	 0.0	 0.0	 1.0	 51.27	 1	 31.53	 31.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	28859	 5.015	 0.275	 1.7	 -1.15	 1.0	 11.96	 0	 8.0	 2.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	28859	 11.55	 0.69	 4.26	 -2.88	 1.0	 20.0	 0	 20.0	 3.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	28859	 32.375	 1.69	 10.44	 -7.06	 1.0	 49.0	 0	 49.0	 15.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	28862	 6.33	 1.32	 3.03	 -0.39	 1.0	 8.13	 1	 6.33	 6.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.9;
	28863	 18.72	 4.005	 9.18	 -1.17	 1.0	 33.13	 1	 18.72	 18.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.9;
	28865	 54.93	 11.57	 26.52	 -3.38	 1.0	 86.73	 1	 54.93	 54.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.05;
	28866	 40.335	 11.57	 26.52	 -3.38	 1.0	 69.51	 0	 69.05	 11.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.05;
	28867	 48.47	 11.57	 26.52	 -3.38	 1.0	 82.87	 1	 48.47	 48.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.05;
	28868	 47.61	 11.57	 26.52	 -3.38	 1.0	 86.6	 1	 47.61	 47.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.05;
	28869	 69.0	 0.0	 0.0	 0.0	 1.0	 117.32	 1	 69.0	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.0;
	28871	 14.515	 4.875	 12.47	 -2.72	 1.0	 29.03	 1	 24.5	 4.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	28872	 17.215	 4.875	 12.47	 -2.72	 1.0	 24.5	 1	 24.5	 9.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.5;
	28874	 30.545	 9.79	 25.04	 -5.46	 1.0	 72.83	 1	 49.2	 11.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.2;
	28877	 45.83	 0.0	 0.0	 0.0	 1.0	 60.75	 1	 45.83	 45.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	28877	 43.32	 0.0	 0.0	 0.0	 1.0	 56.09	 1	 43.32	 43.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	28877	 48.14	 0.0	 0.0	 0.0	 1.0	 66.07	 1	 48.14	 48.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.7;
	28885	 128.415	 39.2	 100.27	 -21.87	 1.0	 227.64	 1	 197.0	 59.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	28886	 134.145	 39.2	 100.27	 -21.87	 1.0	 280.33	 1	 197.0	 71.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	28887	 135.71	 39.2	 100.27	 -21.87	 1.0	 269.12	 1	 197.0	 74.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	28890	 133.0	 0.0	 0.0	 0.0	 1.0	 166.66	 1	 133.0	 133.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.0;
	28893	 14.49	 0.0	 0.0	 0.0	 1.0	 25.5	 1	 14.49	 14.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	28893	 12.7	 0.0	 0.0	 0.0	 1.0	 26.11	 1	 12.7	 12.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.1;
	28896	 10.9	 1.83	 4.19	 -0.53	 1.0	 11.66	 1	 10.9	 10.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	28897	 6.415	 1.83	 4.19	 -0.53	 1.0	 12.19	 0	 10.9	 1.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	28898	 10.9	 1.83	 4.19	 -0.53	 1.0	 10.93	 1	 10.9	 10.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	28901	 34.46	 9.75	 24.94	 -5.44	 1.0	 68.1	 1	 49.0	 19.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	28902	 34.32	 0.0	 0.0	 0.0	 1.0	 58.12	 0	 47.5	 21.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.5;
	28906	 265.4	 9.155	 56.53	 -38.22	 1.0	 265.65	 1	 265.4	 265.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 265.4;
	28907	 7.955	 2.55	 6.52	 -1.42	 1.0	 12.97	 1	 12.8	 3.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	28908	 7.51	 2.55	 6.52	 -1.42	 1.0	 12.8	 0	 12.8	 2.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.8;
	28908	 12.47	 4.01	 10.26	 -2.24	 1.0	 20.19	 0	 20.15	 4.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.15;
	28908	 11.205	 4.01	 10.26	 -2.24	 1.0	 20.6	 1	 20.15	 2.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.15;
	28913	 106.785	 0.0	 0.0	 0.0	 1.0	 183.09	 0	 147.4	 66.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.4;
	28915	 7.81	 1.64	 3.76	 -0.48	 1.0	 12.62	 1	 7.81	 7.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.8;
	28915	 9.8	 1.64	 3.76	 -0.48	 1.0	 10.08	 1	 9.8	 9.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.8;
	28915	 10.855	 2.765	 6.34	 -0.81	 1.0	 16.51	 0	 16.5	 5.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	28915	 7.8	 2.765	 6.34	 -0.81	 1.0	 18.18	 1	 7.8	 7.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	28918	 25.4	 0.875	 5.41	 -3.66	 1.0	 35.78	 1	 25.4	 25.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.4;
	28918	 12.485	 0.655	 4.05	 -2.74	 1.0	 20.82	 0	 19.0	 5.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	28919	 34.675	 11.015	 28.17	 -6.14	 1.0	 70.47	 1	 55.34	 14.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.34;
	28919	 34.335	 11.015	 28.17	 -6.14	 1.0	 83.01	 1	 55.34	 13.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.34;
	28919	 36.54	 11.015	 28.17	 -6.14	 1.0	 74.69	 1	 55.34	 17.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.34;
	28919	 38.125	 11.015	 28.17	 -6.14	 1.0	 76.1	 1	 55.34	 20.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.34;
	28919	 37.2	 11.015	 28.17	 -6.14	 1.0	 55.34	 1	 55.34	 19.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.34;
	28919	 51.205	 16.235	 41.53	 -9.06	 1.0	 110.95	 1	 81.6	 20.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6;
	28926	 37.405	 9.93	 25.4	 -5.54	 1.0	 61.53	 0	 49.9	 24.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	28926	 36.955	 9.93	 25.4	 -5.54	 1.0	 54.32	 1	 49.9	 24.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	28927	 30.46	 9.93	 25.4	 -5.54	 1.0	 49.9	 1	 49.9	 11.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	28928	 5.7	 1.855	 4.75	 -1.04	 1.0	 10.47	 1	 9.33	 2.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3333;
	28928	 10.565	 3.655	 9.35	 -2.04	 1.0	 18.6	 1	 18.37	 2.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.37;
	28928	 12.035	 3.655	 9.35	 -2.04	 1.0	 23.13	 1	 18.37	 5.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.37;
	28928	 10.625	 3.655	 9.35	 -2.04	 1.0	 20.15	 1	 18.37	 2.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.3667;
	28929	 6.49	 1.855	 4.75	 -1.04	 1.0	 9.33	 1	 9.33	 3.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3333;
	28930	 5.615	 1.855	 4.75	 -1.04	 1.0	 13.26	 1	 9.33	 1.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3333;
	28934	 22.445	 6.77	 17.31	 -3.77	 1.0	 45.82	 1	 34.0	 10.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.0;
	28935	 49.74	 0.0	 0.0	 0.0	 1.0	 93.13	 1	 49.74	 49.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.6333;
	28935	 66.63	 0.0	 0.0	 0.0	 1.0	 89.69	 1	 66.63	 66.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.6333;
	28935	 43.725	 0.0	 0.0	 0.0	 1.0	 89.51	 0	 66.63	 20.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.6333;
	28938	 8.38	 2.23	 5.7	 -1.24	 1.0	 14.09	 0	 11.2	 5.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	28939	 7.79	 2.23	 5.7	 -1.24	 1.0	 11.2	 1	 11.2	 4.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	28941	 7.12	 2.23	 5.7	 -1.24	 1.0	 14.29	 0	 11.2	 3.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	28942	 6.32	 2.23	 5.7	 -1.24	 1.0	 15.62	 1	 11.2	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	28946	 30.155	 9.91	 25.35	 -5.53	 1.0	 49.8	 1	 49.8	 10.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	28948	 11.97	 0.0	 0.0	 0.0	 1.0	 21.83	 0	 19.8	 4.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8;
	28948	 17.7	 0.0	 0.0	 0.0	 1.0	 20.09	 1	 17.7	 17.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8;
	28951	 74.5	 0.0	 0.0	 0.0	 1.0	 161.81	 1	 74.5	 74.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	28952	 80.66	 0.0	 0.0	 0.0	 1.0	 150.51	 0	 125.0	 36.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 125.0;
	28953	 12.415	 0.0	 0.0	 0.0	 1.0	 31.03	 0	 21.0	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	28957	 5.97	 1.99	 5.09	 -1.11	 1.0	 13.41	 0	 10.0	 1.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28957	 6.815	 1.99	 5.09	 -1.11	 1.0	 11.21	 0	 10.0	 3.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28957	 5.855	 1.99	 5.09	 -1.11	 1.0	 12.52	 0	 10.0	 1.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28957	 6.63	 1.99	 5.09	 -1.11	 1.0	 10.42	 0	 10.0	 3.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28961	 15.24	 0.0	 0.0	 0.0	 1.0	 30.0	 1	 15.24	 15.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	28962	 14.84	 0.0	 0.0	 0.0	 1.0	 20.27	 1	 14.84	 14.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	28963	 10.1	 0.0	 0.0	 0.0	 1.0	 17.44	 1	 10.1	 10.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.8;
	28963	 6.93	 0.0	 0.0	 0.0	 1.0	 11.64	 1	 6.93	 6.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	28969	 10.9	 0.0	 0.0	 0.0	 1.0	 12.71	 1	 10.9	 10.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.9;
	28970	 8.75	 0.0	 0.0	 0.0	 1.0	 13.77	 1	 8.75	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3333;
	28972	 12.68	 0.0	 0.0	 0.0	 1.0	 20.0	 1	 12.68	 12.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	28972	 13.33	 0.0	 0.0	 0.0	 1.0	 16.76	 1	 13.33	 13.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.33;
	28973	 13.33	 0.0	 0.0	 0.0	 1.0	 18.4	 1	 13.33	 13.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.33;
	28973	 12.3	 0.0	 0.0	 0.0	 1.0	 13.55	 1	 12.3	 12.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3333;
	28974	 7.565	 0.0	 0.0	 0.0	 1.0	 18.55	 0	 13.33	 1.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.3333;
	28975	 10.35	 0.0	 0.0	 0.0	 1.0	 13.53	 1	 10.35	 10.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.33;
	28978	 47.335	 14.33	 36.65	 -7.99	 1.0	 89.43	 1	 72.0	 22.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	28978	 46.71	 14.33	 36.65	 -7.99	 1.0	 99.21	 0	 72.0	 21.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	28980	 14.13	 3.515	 8.06	 -1.03	 1.0	 21.49	 1	 14.13	 14.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	28980	 16.88	 3.515	 8.06	 -1.03	 1.0	 26.28	 1	 16.88	 16.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	28982	 26.0	 0.0	 0.0	 0.0	 1.0	 46.39	 0	 35.8	 16.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.8;
	28984	 37.23	 9.91	 25.35	 -5.53	 1.0	 60.07	 1	 49.8	 24.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.8;
	28987	 33.7	 0.0	 0.0	 0.0	 1.0	 75.73	 1	 33.7	 33.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.3;
	28991	 28.74	 5.025	 11.52	 -1.47	 1.0	 33.39	 1	 28.74	 28.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	28991	 23.98	 5.025	 11.52	 -1.47	 1.0	 30.0	 1	 23.98	 23.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	28992	 24.48	 5.025	 11.52	 -1.47	 1.0	 34.6	 1	 24.48	 24.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	28992	 30.0	 5.025	 11.52	 -1.47	 1.0	 44.58	 1	 30.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	28994	 16.835	 4.6	 11.76	 -2.56	 1.0	 34.01	 1	 23.1	 10.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	28994	 12.96	 4.6	 11.76	 -2.56	 1.0	 25.81	 1	 23.1	 2.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	28995	 14.335	 4.6	 11.76	 -2.56	 1.0	 31.59	 1	 23.1	 5.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	28995	 16.195	 4.6	 11.76	 -2.56	 1.0	 23.15	 1	 23.1	 9.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.1;
	29000	 34.67	 9.75	 24.94	 -5.44	 1.0	 57.52	 1	 49.0	 20.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	29001	 34.08	 9.75	 24.94	 -5.44	 1.0	 52.32	 1	 49.0	 19.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	29001	 32.03	 9.75	 24.94	 -5.44	 1.0	 61.17	 1	 49.0	 15.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	29002	 36.115	 9.75	 24.94	 -5.44	 1.0	 50.02	 1	 49.0	 23.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.0;
	29004	 35.215	 9.93	 25.4	 -5.54	 1.0	 51.1	 1	 49.9	 20.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	29006	 6.495	 2.23	 5.7	 -1.24	 1.0	 15.14	 1	 11.2	 1.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	29006	 7.665	 2.23	 5.7	 -1.24	 1.0	 11.39	 1	 11.2	 4.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	29007	 6.62	 2.23	 5.7	 -1.24	 1.0	 11.9	 1	 11.2	 2.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	29007	 6.865	 2.23	 5.7	 -1.24	 1.0	 12.51	 1	 11.2	 2.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.2;
	29010	 37.445	 12.035	 30.79	 -6.72	 1.0	 75.24	 0	 60.5	 14.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	29011	 42.34	 12.035	 30.79	 -6.72	 1.0	 67.87	 1	 60.5	 24.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	29013	 27.435	 9.35	 23.92	 -5.22	 1.0	 52.03	 0	 47.0	 7.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	29018	 152.16	 45.675	 116.82	 -25.47	 1.0	 243.17	 1	 229.5	 74.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.5;
	29019	 165.75	 45.675	 116.82	 -25.47	 1.0	 233.61	 1	 229.5	 102.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.5;
	29020	 134.62	 45.675	 116.82	 -25.47	 1.0	 296.81	 1	 229.5	 39.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 229.5;
	29022	 108.98	 0.0	 0.0	 0.0	 1.0	 134.12	 1	 108.98	 108.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 128.9;
	29027	 133.355	 39.07	 99.93	 -21.79	 1.0	 215.65	 1	 196.32	 70.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.32;
	29028	 109.4	 39.07	 99.93	 -21.79	 1.0	 207.36	 1	 196.32	 22.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.32;
	29029	 131.62	 39.07	 99.93	 -21.79	 1.0	 274.03	 1	 196.32	 66.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.32;
	29030	 117.09	 39.07	 99.93	 -21.79	 1.0	 198.92	 1	 196.32	 37.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.32;
	29031	 128.715	 39.07	 99.93	 -21.79	 1.0	 218.61	 1	 196.32	 61.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.32;
	29032	 11.875	 3.58	 9.16	 -2.0	 1.0	 18.0	 1	 18.0	 5.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	29033	 10.07	 0.43	 2.67	 -1.81	 1.0	 18.64	 1	 10.07	 10.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.55;
	29033	 16.0	 0.555	 3.41	 -2.3	 1.0	 17.6	 1	 16.0	 16.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	29034	 7.3	 0.25	 1.55	 -1.05	 1.0	 7.35	 1	 7.3	 7.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.3;
	29035	 10.54	 0.43	 2.67	 -1.81	 1.0	 12.69	 1	 10.54	 10.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.55;
	29038	 16.66	 0.77	 4.77	 -3.23	 1.0	 25.37	 1	 16.66	 16.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.4;
	29038	 34.09	 1.495	 9.24	 -6.25	 1.0	 60.75	 1	 34.09	 34.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	29042	 146.065	 43.38	 110.96	 -24.2	 1.0	 235.14	 0	 218.0	 74.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	29043	 122.4	 43.38	 110.96	 -24.2	 1.0	 302.93	 1	 218.0	 26.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	29044	 4.37	 1.48	 3.79	 -0.83	 1.0	 9.04	 1	 7.44	 1.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.44;
	29044	 4.62	 1.48	 3.79	 -0.83	 1.0	 9.59	 0	 7.44	 1.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.44;
	29044	 4.72	 1.48	 3.79	 -0.83	 1.0	 7.44	 1	 7.44	 2.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.44;
	29044	 4.405	 1.48	 3.79	 -0.83	 1.0	 9.41	 1	 7.44	 1.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.44;
	29044	 4.54	 1.48	 3.79	 -0.83	 1.0	 11.16	 0	 7.44	 1.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.44;
	29046	 6.83	 0.32	 1.99	 -1.35	 1.0	 11.43	 0	 9.35	 4.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.35;
	29046	 5.63	 0.32	 1.99	 -1.35	 1.0	 9.35	 1	 5.63	 5.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.35;
	29047	 22.41	 1.145	 7.09	 -4.8	 1.0	 47.67	 1	 22.41	 22.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3;
	29047	 19.32	 1.145	 7.09	 -4.8	 1.0	 36.64	 1	 19.32	 19.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3;
	29048	 6.98	 0.405	 2.49	 -1.68	 1.0	 12.17	 0	 11.7	 2.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.7;
	29048	 7.375	 0.405	 2.49	 -1.68	 1.0	 13.81	 0	 11.7	 3.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.7;
	29051	 39.25	 0.0	 0.0	 0.0	 1.0	 63.66	 1	 39.25	 39.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 55.0;
	29052	 13.49	 0.0	 0.0	 0.0	 1.0	 26.03	 0	 23.0	 3.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	29054	 16.2	 0.0	 0.0	 0.0	 1.0	 19.28	 1	 16.2	 16.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.5;
	29056	 5.17	 0.0	 0.0	 0.0	 1.0	 9.0	 1	 5.17	 5.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	29057	 10.43	 0.0	 0.0	 0.0	 1.0	 12.0	 1	 10.43	 10.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	29059	 29.64	 9.93	 25.4	 -5.54	 1.0	 59.9	 1	 49.9	 9.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	29059	 31.53	 9.93	 25.4	 -5.54	 1.0	 73.86	 1	 49.9	 13.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 49.9;
	29060	 25.405	 8.76	 22.4	 -4.88	 1.0	 48.66	 1	 44.0	 6.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	29062	 23.31	 1.37	 8.46	 -5.72	 1.0	 43.65	 1	 23.31	 23.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.7;
	29063	 9.505	 0.565	 3.51	 -2.38	 1.0	 18.49	 0	 16.5	 2.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.5;
	29064	 21.56	 1.03	 6.37	 -4.31	 1.0	 36.98	 1	 21.56	 21.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.9;
	29070	 46.37	 2.12	 13.1	 -8.86	 1.0	 77.15	 1	 46.37	 46.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	29071	 31.0	 1.07	 6.6	 -4.46	 1.0	 35.91	 1	 31.0	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.0;
	29073	 82.75	 0.0	 0.0	 0.0	 1.0	 159.29	 1	 82.75	 82.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.4;
	29075	 28.895	 9.95	 25.45	 -5.55	 1.0	 55.67	 1	 50.0	 7.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	29075	 34.03	 9.95	 25.45	 -5.55	 1.0	 68.11	 1	 50.0	 18.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	29075	 34.345	 9.95	 25.45	 -5.55	 1.0	 66.95	 1	 50.0	 18.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	29075	 29.74	 9.95	 25.45	 -5.55	 1.0	 58.82	 1	 50.0	 9.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	29076	 7.825	 2.085	 5.34	 -1.17	 1.0	 11.87	 0	 10.5	 5.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	29076	 6.105	 2.085	 5.34	 -1.17	 1.0	 11.74	 0	 10.5	 1.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	29083	 265.13	 81.495	 208.44	 -45.45	 1.0	 452.28	 1	 409.5	 120.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.5;
	29084	 258.58	 81.495	 208.44	 -45.45	 1.0	 463.51	 0	 409.5	 107.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 409.5;
	30269	 7.69	 0.0	 0.0	 0.0	 1.0	 18.95	 1	 7.69	 7.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	30269	 8.84	 0.0	 0.0	 0.0	 1.0	 16.0	 1	 8.84	 8.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	30272	 13.74	 0.0	 0.0	 0.0	 1.0	 21.47	 0	 21.3	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	30272	 14.0	 0.0	 0.0	 0.0	 1.0	 28.59	 0	 21.3	 6.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	30272	 14.62	 0.0	 0.0	 0.0	 1.0	 28.57	 1	 14.62	 14.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.3;
	30274	 11.49	 0.0	 0.0	 0.0	 1.0	 13.5	 1	 11.49	 11.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	30277	 10.0	 0.0	 0.0	 0.0	 1.0	 10.44	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	30279	 6.69	 0.0	 0.0	 0.0	 1.0	 17.7	 0	 11.8	 1.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30280	 7.91	 0.0	 0.0	 0.0	 1.0	 13.96	 1	 7.91	 7.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30281	 14.105	 3.9	 9.98	 -2.18	 1.0	 26.28	 0	 19.6	 8.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	30281	 12.25	 3.9	 9.98	 -2.18	 1.0	 19.63	 0	 19.6	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	30281	 11.905	 3.9	 9.98	 -2.18	 1.0	 21.73	 1	 19.6	 4.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	30281	 13.49	 3.9	 9.98	 -2.18	 1.0	 19.6	 0	 19.6	 7.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	30281	 13.12	 3.9	 9.98	 -2.18	 1.0	 24.96	 0	 19.6	 6.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	30281	 11.905	 3.9	 9.98	 -2.18	 1.0	 19.6	 0	 19.6	 4.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	30285	 11.63	 0.0	 0.0	 0.0	 1.0	 17.5	 0	 17.5	 5.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	30287	 6.84	 0.0	 0.0	 0.0	 1.0	 8.22	 1	 6.84	 6.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.225;
	30287	 8.08	 0.0	 0.0	 0.0	 1.0	 10.31	 1	 8.08	 8.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.23;
	30287	 7.15	 0.0	 0.0	 0.0	 1.0	 8.76	 1	 7.15	 7.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.225;
	30287	 8.22	 0.0	 0.0	 0.0	 1.0	 8.22	 1	 8.22	 8.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.23;
	30291	 9.88	 0.0	 0.0	 0.0	 1.0	 17.16	 1	 9.88	 9.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	30291	 8.42	 0.0	 0.0	 0.0	 1.0	 12.0	 1	 8.42	 8.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	30293	 26.49	 0.0	 0.0	 0.0	 1.0	 34.65	 1	 26.49	 26.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	30297	 111.275	 37.05	 94.76	 -20.66	 1.0	 279.26	 0	 186.17	 36.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.17;
	30298	 112.605	 37.05	 94.76	 -20.66	 1.0	 186.32	 1	 186.17	 39.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.17;
	30299	 103.3	 37.05	 94.76	 -20.66	 1.0	 224.41	 1	 186.17	 20.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.17;
	30300	 51.49	 18.555	 47.46	 -10.35	 1.0	 118.87	 1	 93.25	 9.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.25;
	30301	 67.52	 18.555	 47.46	 -10.35	 1.0	 136.49	 1	 93.25	 41.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.25;
	30306	 147.035	 41.625	 112.77	 -29.52	 1.0	 299.84	 1	 242.0	 52.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 242.0;
	30307	 60.5	 0.0	 0.0	 0.0	 1.0	 82.26	 1	 60.5	 60.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	30309	 9.46	 0.0	 0.0	 0.0	 1.0	 16.59	 1	 9.46	 9.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	30309	 13.0	 0.0	 0.0	 0.0	 1.0	 16.8	 1	 13.0	 13.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	30310	 15.0	 0.0	 0.0	 0.0	 1.0	 19.3	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	30310	 9.55	 0.0	 0.0	 0.0	 1.0	 18.6	 1	 9.55	 9.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	30316	 198.925	 48.76	 132.11	 -34.59	 1.0	 392.74	 1	 283.5	 114.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 283.5;
	30317	 200.09	 48.76	 132.11	 -34.59	 1.0	 284.95	 1	 283.5	 116.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 283.5;
	30319	 8.34	 0.0	 0.0	 0.0	 1.0	 11.8	 1	 8.34	 8.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3;
	30320	 7.075	 0.0	 0.0	 0.0	 1.0	 10.51	 0	 10.3	 3.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.3;
	30323	 25.295	 8.435	 21.58	 -4.71	 1.0	 48.25	 1	 42.4	 8.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	30323	 29.92	 8.435	 21.58	 -4.71	 1.0	 42.4	 1	 42.4	 17.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	30323	 24.095	 8.435	 21.58	 -4.71	 1.0	 58.5	 1	 42.4	 5.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.4;
	30326	 8.01	 0.0	 0.0	 0.0	 1.0	 9.68	 1	 8.01	 8.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	30326	 7.09	 0.0	 0.0	 0.0	 1.0	 11.57	 1	 7.09	 7.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	30327	 5.89	 0.0	 0.0	 0.0	 1.0	 9.6	 1	 5.89	 5.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	30327	 8.57	 0.0	 0.0	 0.0	 1.0	 9.6	 1	 8.57	 8.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	30327	 7.27	 0.0	 0.0	 0.0	 1.0	 13.05	 1	 7.27	 7.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	30332	 14.31	 4.79	 12.25	 -2.67	 1.0	 28.67	 0	 24.07	 4.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30332	 13.71	 4.79	 12.25	 -2.67	 1.0	 24.23	 0	 24.07	 3.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.08;
	30332	 14.685	 4.79	 12.25	 -2.67	 1.0	 24.07	 0	 24.07	 5.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30332	 13.63	 4.79	 12.25	 -2.67	 1.0	 24.07	 1	 24.07	 3.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30335	 17.83	 0.0	 0.0	 0.0	 1.0	 22.0	 1	 17.83	 17.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	30335	 11.8	 0.0	 0.0	 0.0	 1.0	 16.78	 1	 11.8	 11.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30336	 8.86	 0.0	 0.0	 0.0	 1.0	 14.75	 1	 8.86	 8.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30336	 8.46	 0.0	 0.0	 0.0	 1.0	 15.22	 0	 11.8	 5.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30337	 8.38	 0.0	 0.0	 0.0	 1.0	 14.84	 1	 8.38	 8.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30342	 100.75	 35.555	 90.94	 -19.83	 1.0	 223.07	 1	 178.67	 22.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.6667;
	30343	 123.99	 35.555	 90.94	 -19.83	 1.0	 207.17	 1	 178.67	 69.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.67;
	30344	 119.355	 35.555	 90.94	 -19.83	 1.0	 212.53	 1	 178.67	 60.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.67;
	30347	 213.425	 50.705	 137.38	 -35.97	 1.0	 393.78	 1	 294.8	 132.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 294.8;
	30349	 13.355	 4.79	 12.25	 -2.67	 1.0	 27.29	 1	 24.07	 2.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30349	 17.55	 4.79	 12.25	 -2.67	 1.0	 36.1	 1	 24.07	 11.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30350	 13.7	 4.79	 12.25	 -2.67	 1.0	 24.07	 0	 24.07	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30350	 15.89	 4.79	 12.25	 -2.67	 1.0	 24.6	 1	 24.07	 7.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.075;
	30351	 30.66	 0.0	 0.0	 0.0	 1.0	 35.79	 1	 30.66	 30.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	30352	 27.74	 0.0	 0.0	 0.0	 1.0	 52.5	 1	 27.74	 27.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	30352	 25.705	 0.0	 0.0	 0.0	 1.0	 48.86	 0	 35.0	 16.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	30352	 18.82	 0.0	 0.0	 0.0	 1.0	 35.0	 1	 18.82	 18.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	30352	 35.0	 0.0	 0.0	 0.0	 1.0	 40.92	 1	 35.0	 35.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	30352	 23.95	 0.0	 0.0	 0.0	 1.0	 39.26	 0	 35.0	 12.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	30357	 8.515	 0.0	 0.0	 0.0	 1.0	 12.89	 0	 11.75	 5.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.75;
	30358	 11.46	 0.0	 0.0	 0.0	 1.0	 13.03	 1	 11.46	 11.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.75;
	30363	 10.58	 0.0	 0.0	 0.0	 1.0	 17.33	 0	 17.33	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.33;
	30364	 14.2	 0.0	 0.0	 0.0	 1.0	 17.33	 1	 14.2	 14.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.33;
	30365	 9.0	 0.0	 0.0	 0.0	 1.0	 21.53	 1	 9.0	 9.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.3333;
	30368	 48.765	 0.0	 0.0	 0.0	 1.0	 109.43	 0	 75.7	 21.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.7;
	30372	 137.125	 48.61	 124.33	 -27.11	 1.0	 312.23	 0	 244.27	 29.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.2667;
	30373	 140.285	 48.61	 124.33	 -27.11	 1.0	 318.59	 0	 244.27	 36.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.27;
	30374	 166.365	 48.61	 124.33	 -27.11	 1.0	 244.27	 1	 244.27	 88.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.27;
	30375	 166.365	 48.61	 124.33	 -27.11	 1.0	 317.94	 1	 244.27	 88.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.2667;
	30376	 155.555	 48.61	 124.33	 -27.11	 1.0	 245.81	 1	 244.27	 66.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.2667;
	30377	 159.695	 48.61	 124.33	 -27.11	 1.0	 285.52	 1	 244.27	 75.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 244.2667;
	30379	 50.125	 14.73	 37.67	 -8.21	 1.0	 76.31	 1	 74.0	 26.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0;
	30379	 47.49	 14.73	 37.67	 -8.21	 1.0	 74.88	 1	 74.0	 20.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0;
	30379	 46.435	 14.73	 37.67	 -8.21	 1.0	 111.0	 1	 74.0	 18.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.0;
	30381	 14.665	 0.0	 0.0	 0.0	 1.0	 24.03	 0	 20.0	 9.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	30386	 150.0	 5.175	 31.95	 -21.6	 1.0	 206.59	 1	 150.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	30390	 81.83	 29.575	 75.65	 -16.5	 1.0	 148.62	 1	 148.62	 15.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.62;
	30391	 87.555	 29.575	 75.65	 -16.5	 1.0	 203.33	 1	 148.62	 26.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.62;
	30392	 105.71	 29.575	 75.65	 -16.5	 1.0	 165.8	 1	 148.62	 62.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.62;
	30393	 86.575	 29.575	 75.65	 -16.5	 1.0	 152.4	 1	 148.62	 24.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.62;
	30394	 89.165	 29.575	 75.65	 -16.5	 1.0	 170.48	 1	 148.62	 29.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 148.62;
	30395	 72.495	 23.84	 60.98	 -13.3	 1.0	 130.4	 1	 119.8	 25.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.8;
	30396	 62.585	 16.91	 43.26	 -9.44	 1.0	 93.26	 1	 85.0	 40.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	30397	 47.365	 16.91	 43.26	 -9.44	 1.0	 89.74	 0	 85.0	 9.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	30398	 10.05	 0.0	 0.0	 0.0	 1.0	 10.05	 1	 10.05	 10.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.05;
	30398	 7.46	 0.0	 0.0	 0.0	 1.0	 10.27	 1	 7.46	 7.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.05;
	30404	 97.225	 26.43	 67.6	 -14.74	 1.0	 156.17	 1	 132.8	 61.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	30405	 97.59	 26.43	 67.6	 -14.74	 1.0	 174.79	 1	 132.8	 62.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	30406	 91.77	 26.43	 67.6	 -14.74	 1.0	 150.07	 1	 132.8	 50.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	30407	 95.315	 26.43	 67.6	 -14.74	 1.0	 140.35	 1	 132.8	 57.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	30408	 90.795	 26.43	 67.6	 -14.74	 1.0	 167.31	 1	 132.8	 48.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	30409	 73.77	 26.43	 67.6	 -14.74	 1.0	 173.37	 1	 132.8	 14.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 132.8;
	30410	 56.46	 19.195	 49.1	 -10.71	 1.0	 136.78	 1	 96.47	 16.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.4667;
	30411	 59.635	 19.195	 49.1	 -10.71	 1.0	 104.92	 1	 96.47	 22.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.4667;
	30412	 70.84	 19.195	 49.1	 -10.71	 1.0	 98.05	 1	 96.47	 45.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.4667;
	30413	 64.14	 19.195	 49.1	 -10.71	 1.0	 100.36	 1	 96.47	 31.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.4667;
	30414	 67.38	 19.195	 49.1	 -10.71	 1.0	 113.78	 1	 96.47	 38.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.47;
	30415	 55.17	 19.195	 49.1	 -10.71	 1.0	 135.36	 1	 96.47	 13.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.4667;
	30421	 148.705	 44.095	 112.78	 -24.59	 1.0	 225.11	 0	 221.57	 75.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.5667;
	30422	 147.935	 44.095	 112.78	 -24.59	 1.0	 296.5	 1	 221.57	 74.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.5667;
	30423	 127.335	 44.095	 112.78	 -24.59	 1.0	 273.35	 1	 221.57	 33.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.57;
	30425	 16.89	 0.0	 0.0	 0.0	 1.0	 20.88	 1	 16.89	 16.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	30426	 13.06	 0.0	 0.0	 0.0	 1.0	 21.55	 1	 13.06	 13.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	30426	 12.86	 0.0	 0.0	 0.0	 1.0	 17.41	 1	 12.86	 12.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	30426	 9.11	 0.0	 0.0	 0.0	 1.0	 16.0	 0	 16.0	 2.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	30427	 17.88	 0.0	 0.0	 0.0	 1.0	 20.0	 1	 17.88	 17.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	30428	 35.48	 12.54	 32.07	 -6.99	 1.0	 77.66	 1	 63.0	 7.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	30428	 41.795	 12.54	 32.07	 -6.99	 1.0	 87.61	 1	 63.0	 20.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	30428	 42.49	 12.54	 32.07	 -6.99	 1.0	 66.16	 1	 63.0	 21.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	30428	 37.49	 12.54	 32.07	 -6.99	 1.0	 86.18	 1	 63.0	 11.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	30429	 33.9	 11.905	 30.45	 -6.64	 1.0	 73.98	 1	 59.82	 7.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.82;
	30429	 37.35	 11.905	 30.45	 -6.64	 1.0	 60.93	 1	 59.82	 14.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.8167;
	30429	 40.085	 11.905	 30.45	 -6.64	 1.0	 69.44	 1	 59.82	 20.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.8167;
	30429	 40.085	 11.905	 30.45	 -6.64	 1.0	 80.14	 1	 59.82	 20.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.8167;
	30429	 42.445	 11.905	 30.45	 -6.64	 1.0	 79.54	 1	 59.82	 25.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.82;
	30429	 44.385	 11.905	 30.45	 -6.64	 1.0	 81.18	 1	 59.82	 28.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.8167;
	30434	 22.235	 0.0	 0.0	 0.0	 1.0	 36.48	 0	 31.33	 13.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3333;
	30434	 21.81	 0.0	 0.0	 0.0	 1.0	 34.84	 1	 21.81	 21.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.33;
	30434	 21.02	 0.0	 0.0	 0.0	 1.0	 45.46	 1	 21.02	 21.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3333;
	30435	 6.54	 0.0	 0.0	 0.0	 1.0	 11.85	 1	 6.54	 6.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.8;
	30441	 118.235	 39.84	 101.9	 -22.22	 1.0	 268.78	 1	 200.2	 36.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.2;
	30442	 127.92	 39.84	 101.9	 -22.22	 1.0	 221.73	 1	 200.2	 55.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.2;
	30443	 113.65	 39.84	 101.9	 -22.22	 1.0	 297.22	 1	 200.2	 27.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.2;
	30445	 6.22	 0.0	 0.0	 0.0	 1.0	 10.74	 0	 9.1	 3.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.1;
	30445	 7.93	 0.0	 0.0	 0.0	 1.0	 9.2	 1	 7.93	 7.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.1;
	30446	 9.1	 0.0	 0.0	 0.0	 1.0	 10.09	 1	 9.1	 9.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.1;
	30447	 6.05	 0.0	 0.0	 0.0	 1.0	 10.23	 1	 6.05	 6.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.1;
	30451	 115.565	 29.015	 66.52	 -8.49	 1.0	 239.0	 0	 173.23	 57.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	30452	 173.23	 29.015	 66.52	 -8.49	 1.0	 255.26	 1	 173.23	 173.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	30453	 173.23	 29.015	 66.52	 -8.49	 1.0	 185.71	 1	 173.23	 173.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	30454	 137.19	 29.015	 66.52	 -8.49	 1.0	 217.04	 1	 137.19	 137.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	30455	 115.71	 29.015	 66.52	 -8.49	 1.0	 208.55	 1	 115.71	 115.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	30456	 173.23	 29.015	 66.52	 -8.49	 1.0	 226.56	 1	 173.23	 173.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	30460	 79.205	 22.885	 58.53	 -12.76	 1.0	 115.0	 1	 115.0	 43.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	30461	 69.805	 22.885	 58.53	 -12.76	 1.0	 145.02	 1	 115.0	 24.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	40695	 45.44	 12.235	 31.3	 -6.83	 1.0	 79.84	 1	 61.5	 29.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	40696	 36.91	 12.235	 31.3	 -6.83	 1.0	 66.87	 0	 61.5	 12.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	40697	 41.24	 12.235	 31.3	 -6.83	 1.0	 62.0	 1	 61.5	 20.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.5;
	40700	 95.91	 0.0	 0.0	 0.0	 1.0	 135.25	 1	 95.91	 95.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.9;
	40701	 90.97	 0.0	 0.0	 0.0	 1.0	 141.0	 1	 90.97	 90.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.9;
	40702	 115.9	 0.0	 0.0	 0.0	 1.0	 148.44	 1	 115.9	 115.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.9;
	40703	 37.805	 12.035	 30.79	 -6.72	 1.0	 68.22	 1	 60.5	 15.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	40703	 38.76	 12.035	 30.79	 -6.72	 1.0	 82.85	 1	 60.5	 17.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	40706	 17.02	 5.37	 13.74	 -3.0	 1.0	 32.48	 0	 27.0	 7.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	40706	 16.11	 5.37	 13.74	 -3.0	 1.0	 31.35	 1	 27.0	 5.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	40707	 19.225	 5.37	 13.74	 -3.0	 1.0	 34.33	 1	 27.0	 11.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	40707	 15.34	 5.37	 13.74	 -3.0	 1.0	 29.72	 1	 27.0	 3.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	40708	 5.03	 1.495	 3.82	 -0.83	 1.0	 8.4	 1	 7.5	 2.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	40708	 4.26	 1.495	 3.82	 -0.83	 1.0	 8.43	 0	 7.5	 1.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	40709	 4.735	 1.495	 3.82	 -0.83	 1.0	 7.66	 1	 7.5	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	40710	 4.315	 1.495	 3.82	 -0.83	 1.0	 10.72	 1	 7.5	 1.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	40712	 23.96	 6.03	 13.82	 -1.76	 1.0	 36.89	 1	 23.96	 23.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	40715	 63.42	 3.425	 21.13	 -14.28	 1.0	 99.37	 1	 63.42	 63.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.2;
	40719	 10.0	 1.675	 3.84	 -0.49	 1.0	 10.0	 1	 10.0	 10.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	40719	 8.16	 1.675	 3.84	 -0.49	 1.0	 13.4	 1	 8.16	 8.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	40719	 5.555	 1.675	 3.84	 -0.49	 1.0	 15.0	 0	 10.0	 1.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	40719	 7.035	 1.675	 3.84	 -0.49	 1.0	 14.76	 0	 10.0	 4.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	40721	 9.99	 0.0	 0.0	 0.0	 1.0	 16.49	 1	 9.99	 9.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	40722	 35.255	 9.575	 24.49	 -5.34	 1.0	 56.14	 1	 48.12	 22.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.12;
	40722	 62.35	 17.255	 44.13	 -9.62	 1.0	 117.3	 1	 86.7	 38.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.7;
	40723	 32.26	 9.575	 24.49	 -5.34	 1.0	 65.86	 0	 48.12	 16.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.12;
	40723	 32.245	 9.575	 24.49	 -5.34	 1.0	 52.94	 1	 48.12	 16.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.12;
	40723	 27.775	 9.575	 24.49	 -5.34	 1.0	 56.85	 0	 48.12	 7.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.12;
	40723	 27.265	 9.575	 24.49	 -5.34	 1.0	 55.97	 1	 48.12	 6.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.12;
	40723	 30.885	 9.72	 24.86	 -5.42	 1.0	 55.17	 0	 48.85	 12.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.85;
	40723	 26.9	 9.72	 24.86	 -5.42	 1.0	 54.88	 1	 48.85	 4.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.85;
	40728	 16.95	 4.49	 12.16	 -3.18	 1.0	 35.19	 0	 26.1	 7.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.1;
	40732	 41.0	 8.535	 19.57	 -2.5	 1.0	 60.63	 1	 41.0	 41.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.96;
	40733	 45.25	 8.535	 19.57	 -2.5	 1.0	 68.97	 1	 45.25	 45.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.96;
	40734	 32.335	 8.535	 19.57	 -2.5	 1.0	 61.29	 0	 50.96	 13.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.96;
	40735	 44.51	 8.535	 19.57	 -2.5	 1.0	 50.96	 1	 44.51	 44.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.96;
	40736	 50.96	 8.535	 19.57	 -2.5	 1.0	 61.28	 1	 50.96	 50.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.96;
	40739	 91.67	 29.05	 74.31	 -16.21	 1.0	 181.78	 0	 146.0	 37.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.0;
	40740	 80.72	 29.05	 74.31	 -16.21	 1.0	 186.13	 1	 146.0	 15.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 146.0;
	40741	 43.0	 11.52	 29.47	 -6.43	 1.0	 78.43	 0	 57.9	 28.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.9;
	40742	 34.04	 11.52	 29.47	 -6.43	 1.0	 68.93	 1	 57.9	 10.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.9;
	40743	 36.09	 11.52	 29.47	 -6.43	 1.0	 80.35	 1	 57.9	 14.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.9;
	40744	 30.48	 10.75	 27.49	 -5.99	 1.0	 71.42	 1	 54.0	 6.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	40745	 37.85	 10.75	 27.49	 -5.99	 1.0	 56.02	 1	 54.0	 21.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.0;
	40747	 13.6	 0.0	 0.0	 0.0	 1.0	 17.25	 1	 13.6	 13.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.6;
	40750	 10.59	 0.0	 0.0	 0.0	 1.0	 16.89	 0	 15.0	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	40756	 167.32	 46.96	 120.12	 -26.2	 1.0	 236.0	 1	 236.0	 98.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0;
	40757	 153.19	 46.96	 120.12	 -26.2	 1.0	 267.07	 0	 236.0	 70.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0;
	40758	 172.565	 46.96	 120.12	 -26.2	 1.0	 270.87	 1	 236.0	 109.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 236.0;
	40763	 298.42	 70.675	 191.48	 -50.13	 1.0	 471.85	 1	 410.9	 185.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.9;
	40764	 262.305	 70.675	 191.48	 -50.13	 1.0	 521.05	 1	 410.9	 113.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.9;
	40768	 117.715	 35.085	 95.06	 -24.89	 1.0	 235.87	 1	 204.0	 31.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	40769	 124.99	 35.085	 95.06	 -24.89	 1.0	 250.05	 1	 204.0	 45.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 204.0;
	40770	 57.39	 14.035	 38.03	 -9.96	 1.0	 106.3	 1	 81.6	 33.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.6;
	40771	 24.09	 7.355	 19.93	 -5.22	 1.0	 49.84	 0	 42.77	 5.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.775;
	40772	 29.89	 7.355	 19.93	 -5.22	 1.0	 62.46	 1	 42.77	 17.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.78;
	40772	 31.455	 7.355	 19.93	 -5.22	 1.0	 43.42	 1	 42.77	 20.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.78;
	40773	 24.965	 7.355	 19.93	 -5.22	 1.0	 52.34	 0	 42.77	 7.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.775;
	40774	 15.35	 0.0	 0.0	 0.0	 1.0	 25.47	 1	 15.35	 15.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	40775	 8.86	 1.54	 3.53	 -0.45	 1.0	 10.66	 1	 8.86	 8.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.2;
	40775	 31.38	 9.095	 20.85	 -2.66	 1.0	 59.51	 0	 54.3	 8.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.3;
	40778	 21.12	 0.0	 0.0	 0.0	 1.0	 38.11	 1	 21.12	 21.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8;
	40778	 18.7	 0.0	 0.0	 0.0	 1.0	 28.58	 1	 18.7	 18.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8;
	40779	 25.8	 0.0	 0.0	 0.0	 1.0	 30.21	 1	 25.8	 25.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8;
	40779	 25.02	 0.0	 0.0	 0.0	 1.0	 37.41	 1	 25.02	 25.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8;
	40780	 20.34	 0.0	 0.0	 0.0	 1.0	 28.54	 1	 20.34	 20.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.8;
	40782	 55.28	 2.175	 13.42	 -9.07	 1.0	 79.91	 1	 55.28	 55.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	40786	 483.145	 138.13	 374.24	 -97.98	 1.0	 968.04	 1	 803.1	 163.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 803.1;
	40787	 571.125	 138.13	 374.24	 -97.98	 1.0	 856.08	 1	 803.1	 339.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 803.1;
	40788	 549.715	 138.13	 374.24	 -97.98	 1.0	 945.0	 1	 803.1	 296.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 803.1;
	40790	 12.48	 0.0	 0.0	 0.0	 1.0	 23.93	 1	 12.48	 12.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.6;
	40793	 22.35	 0.0	 0.0	 0.0	 1.0	 38.94	 1	 22.35	 22.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3333;
	40793	 19.0	 0.0	 0.0	 0.0	 1.0	 33.81	 1	 19.0	 19.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.33;
	40793	 15.795	 0.0	 0.0	 0.0	 1.0	 31.88	 0	 28.33	 3.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3333;
	40793	 19.12	 0.0	 0.0	 0.0	 1.0	 39.17	 1	 19.12	 19.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.33;
	40793	 14.42	 0.0	 0.0	 0.0	 1.0	 28.33	 1	 14.42	 14.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3333;
	40793	 19.2	 0.0	 0.0	 0.0	 1.0	 31.44	 0	 28.33	 10.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3333;
	40797	 121.98	 36.525	 93.42	 -20.37	 1.0	 198.43	 1	 183.53	 60.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.5333;
	40798	 133.795	 36.525	 93.42	 -20.37	 1.0	 233.71	 1	 183.53	 84.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.53;
	40799	 127.205	 36.525	 93.42	 -20.37	 1.0	 209.51	 0	 183.53	 70.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.53;
	40800	 126.225	 36.525	 93.42	 -20.37	 1.0	 190.68	 0	 183.53	 68.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.5333;
	40801	 134.405	 36.525	 93.42	 -20.37	 1.0	 206.81	 1	 183.53	 85.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.5333;
	40802	 122.975	 36.525	 93.42	 -20.37	 1.0	 214.19	 1	 183.53	 62.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.5333;
	40803	 32.635	 10.57	 27.03	 -5.89	 1.0	 54.54	 1	 53.1	 12.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	40804	 29.33	 10.57	 27.03	 -5.89	 1.0	 67.83	 1	 53.1	 5.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	40806	 16.905	 5.365	 13.72	 -2.99	 1.0	 31.73	 1	 26.95	 6.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.95;
	40806	 16.525	 5.365	 13.72	 -2.99	 1.0	 26.95	 0	 26.95	 6.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.95;
	40806	 18.93	 5.365	 13.72	 -2.99	 1.0	 31.33	 1	 26.95	 10.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.95;
	40806	 16.47	 5.365	 13.72	 -2.99	 1.0	 32.17	 0	 26.95	 5.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.95;
	40808	 15.31	 0.0	 0.0	 0.0	 1.0	 19.67	 1	 15.31	 15.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	40813	 94.535	 25.9	 66.24	 -14.44	 1.0	 162.14	 1	 130.13	 58.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.1333;
	40814	 80.775	 25.9	 66.24	 -14.44	 1.0	 163.65	 1	 130.13	 31.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.1333;
	40815	 84.82	 25.9	 66.24	 -14.44	 1.0	 183.06	 1	 130.13	 39.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.1333;
	40816	 49.955	 14.785	 37.82	 -8.25	 1.0	 74.52	 1	 74.3	 25.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.3;
	40817	 42.455	 14.785	 37.82	 -8.25	 1.0	 101.6	 1	 74.3	 10.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.3;
	40818	 44.79	 14.785	 37.82	 -8.25	 1.0	 76.41	 1	 74.3	 15.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.3;
	40824	 67.415	 24.08	 61.59	 -13.43	 1.0	 151.68	 1	 121.0	 13.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	40825	 87.35	 24.08	 61.59	 -13.43	 1.0	 142.34	 1	 121.0	 53.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	40826	 71.205	 24.08	 61.59	 -13.43	 1.0	 155.42	 1	 121.0	 21.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	40827	 84.235	 24.08	 61.59	 -13.43	 1.0	 155.19	 1	 121.0	 47.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	40828	 73.31	 24.08	 61.59	 -13.43	 1.0	 139.62	 1	 121.0	 25.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	40829	 71.84	 24.08	 61.59	 -13.43	 1.0	 154.18	 1	 121.0	 22.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	40833	 5.43	 0.0	 0.0	 0.0	 1.0	 10.12	 1	 5.43	 5.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	40834	 10.31	 0.0	 0.0	 0.0	 1.0	 13.55	 1	 10.31	 10.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8;
	40836	 165.89	 45.875	 117.34	 -25.59	 1.0	 230.53	 0	 230.53	 101.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.5333;
	40837	 145.835	 45.875	 117.34	 -25.59	 1.0	 264.3	 1	 230.53	 61.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.5333;
	40838	 148.365	 45.875	 117.34	 -25.59	 1.0	 309.24	 1	 230.53	 66.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.5333;
	40843	 854.15	 200.66	 516.38	 -115.06	 1.0	 1663.53	 1	 1403.2	 305.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1403.2;
	40844	 849.41	 200.66	 516.38	 -115.06	 1.0	 1764.36	 1	 1403.2	 295.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1403.2;
	40845	 924.69	 200.66	 516.38	 -115.06	 1.0	 1608.37	 1	 1403.2	 446.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1403.2;
	40849	 119.09	 0.0	 0.0	 0.0	 1.0	 165.81	 1	 119.09	 119.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.0;
	40850	 87.775	 0.0	 0.0	 0.0	 1.0	 176.74	 0	 140.0	 35.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.0;
	40854	 122.995	 29.81	 80.76	 -21.14	 1.0	 235.04	 1	 173.3	 72.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.3;
	40855	 82.08	 18.99	 51.45	 -13.47	 1.0	 136.58	 1	 110.4	 53.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.4;
	40856	 69.135	 18.99	 51.45	 -13.47	 1.0	 124.23	 1	 110.4	 27.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.4;
	40857	 64.965	 18.99	 51.45	 -13.47	 1.0	 156.31	 1	 110.4	 19.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.4;
	40858	 15.66	 4.645	 12.58	 -3.29	 1.0	 35.97	 1	 27.0	 4.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	40859	 18.97	 4.645	 12.58	 -3.29	 1.0	 27.07	 1	 27.0	 10.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	40861	 22.23	 6.23	 15.93	 -3.47	 1.0	 35.9	 0	 31.3	 13.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3;
	40861	 17.83	 6.23	 15.93	 -3.47	 1.0	 44.51	 1	 31.3	 4.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3;
	40863	 6.16	 1.83	 4.68	 -1.02	 1.0	 11.35	 1	 9.2	 3.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.2;
	40865	 50.56	 16.91	 43.26	 -9.44	 1.0	 85.0	 1	 85.0	 16.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.0;
	40868	 135.82	 42.855	 109.62	 -23.91	 1.0	 323.05	 1	 215.37	 56.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.37;
	40869	 122.58	 42.855	 109.62	 -23.91	 1.0	 267.93	 1	 215.37	 29.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.3667;
	40870	 146.68	 42.855	 109.62	 -23.91	 1.0	 290.33	 1	 215.37	 77.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 215.3667;
	40871	 6.25	 1.79	 4.58	 -1.0	 1.0	 9.08	 1	 9.0	 3.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	40873	 20.0	 0.0	 0.0	 0.0	 1.0	 20.0	 1	 20.0	 20.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	40878	 276.97	 75.93	 205.72	 -53.86	 1.0	 565.19	 1	 441.45	 112.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 441.45;
	40879	 295.785	 75.93	 205.72	 -53.86	 1.0	 454.51	 0	 441.45	 150.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 441.45;
	40880	 247.86	 75.93	 205.72	 -53.86	 1.0	 532.28	 1	 441.45	 54.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 441.45;
	40881	 254.75	 75.93	 205.72	 -53.86	 1.0	 514.02	 1	 441.45	 68.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 441.45;
	40884	 134.935	 41.06	 105.02	 -22.9	 1.0	 257.9	 1	 206.33	 63.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40885	 144.49	 41.06	 105.02	 -22.9	 1.0	 258.59	 1	 206.33	 82.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.33;
	40886	 117.05	 41.06	 105.02	 -22.9	 1.0	 266.68	 1	 206.33	 27.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40887	 146.535	 41.06	 105.02	 -22.9	 1.0	 267.58	 1	 206.33	 86.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.33;
	40888	 147.64	 41.06	 105.02	 -22.9	 1.0	 249.52	 1	 206.33	 88.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.33;
	40889	 151.475	 41.06	 105.02	 -22.9	 1.0	 214.43	 1	 206.33	 96.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40892	 72.535	 20.065	 51.32	 -11.19	 1.0	 117.3	 1	 100.83	 44.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.8333;
	40893	 61.925	 20.065	 51.32	 -11.19	 1.0	 116.17	 1	 100.83	 23.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.8333;
	40894	 68.93	 20.065	 51.32	 -11.19	 1.0	 111.95	 1	 100.83	 37.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.83;
	40895	 57.485	 20.065	 51.32	 -11.19	 1.0	 111.77	 1	 100.83	 14.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.83;
	40896	 68.03	 20.065	 51.32	 -11.19	 1.0	 131.26	 1	 100.83	 35.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.83;
	40897	 66.63	 20.065	 51.32	 -11.19	 1.0	 119.05	 1	 100.83	 32.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.8333;
	40903	 122.63	 43.98	 112.49	 -24.53	 1.0	 261.62	 1	 221.0	 24.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	40904	 150.73	 43.98	 112.49	 -24.53	 1.0	 227.38	 1	 221.0	 80.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	40905	 147.54	 43.98	 112.49	 -24.53	 1.0	 247.26	 1	 221.0	 74.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	40906	 144.21	 43.98	 112.49	 -24.53	 1.0	 262.15	 1	 221.0	 67.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	40907	 126.265	 43.98	 112.49	 -24.53	 1.0	 237.67	 1	 221.0	 31.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	40908	 161.18	 43.98	 112.49	 -24.53	 1.0	 221.0	 1	 221.0	 101.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 221.0;
	40912	 130.365	 43.95	 112.41	 -24.51	 1.0	 256.67	 1	 220.85	 39.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.85;
	40913	 123.645	 43.95	 112.41	 -24.51	 1.0	 272.96	 1	 220.85	 26.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.85;
	40914	 156.135	 43.95	 112.41	 -24.51	 1.0	 302.8	 0	 220.85	 91.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.85;
	40915	 141.2	 43.95	 112.41	 -24.51	 1.0	 292.79	 1	 220.85	 61.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.85;
	40916	 145.795	 43.95	 112.41	 -24.51	 1.0	 228.01	 1	 220.85	 70.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.85;
	40917	 161.945	 43.95	 112.41	 -24.51	 1.0	 238.78	 1	 220.85	 103.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 220.85;
	40918	 19.18	 0.0	 0.0	 0.0	 1.0	 29.74	 0	 27.2	 11.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.2;
	40919	 9.4	 0.0	 0.0	 0.0	 1.0	 18.63	 1	 9.4	 9.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	40921	 6.67	 0.0	 0.0	 0.0	 1.0	 11.11	 1	 6.67	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	40924	 178.48	 36.63	 83.97	 -10.71	 1.0	 314.46	 1	 178.48	 178.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.6667;
	40925	 218.67	 36.63	 83.97	 -10.71	 1.0	 275.31	 1	 218.67	 218.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.67;
	40926	 131.56	 36.63	 83.97	 -10.71	 1.0	 265.1	 0	 218.67	 44.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.67;
	40927	 179.81	 36.63	 83.97	 -10.71	 1.0	 260.63	 1	 179.81	 179.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.67;
	40928	 142.315	 36.63	 83.97	 -10.71	 1.0	 218.67	 0	 218.67	 65.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.6667;
	40929	 147.145	 36.63	 83.97	 -10.71	 1.0	 267.8	 0	 218.67	 75.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.6667;
	40934	 161.61	 48.54	 131.51	 -34.43	 1.0	 417.06	 1	 282.2	 41.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.2;
	40935	 211.33	 48.54	 131.51	 -34.43	 1.0	 302.0	 1	 282.2	 140.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.2;
	40936	 183.95	 48.54	 131.51	 -34.43	 1.0	 337.03	 1	 282.2	 85.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.2;
	40937	 204.05	 48.54	 131.51	 -34.43	 1.0	 327.44	 1	 282.2	 125.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 282.2;
	40943	 78.025	 22.605	 57.82	 -12.61	 1.0	 119.84	 1	 113.6	 42.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	40944	 82.755	 22.605	 57.82	 -12.61	 1.0	 133.28	 0	 113.6	 51.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 113.6;
	40945	 30.405	 10.57	 27.03	 -5.89	 1.0	 54.17	 1	 53.1	 7.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	40946	 36.07	 10.57	 27.03	 -5.89	 1.0	 70.43	 1	 53.1	 19.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 53.1;
	40947	 49.23	 2.25	 13.87	 -9.37	 1.0	 65.1	 1	 49.23	 49.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 65.1;
	40949	 10.36	 2.175	 4.99	 -0.64	 1.0	 18.17	 1	 10.36	 10.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	40950	 11.77	 0.0	 0.0	 0.0	 1.0	 20.5	 0	 17.5	 6.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	40950	 12.575	 0.0	 0.0	 0.0	 1.0	 17.64	 0	 17.5	 7.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.5;
	40953	 63.17	 16.715	 38.32	 -4.89	 1.0	 123.1	 0	 99.8	 26.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.8;
	40954	 7.96	 1.655	 3.8	 -0.49	 1.0	 14.53	 1	 7.96	 7.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	40954	 6.36	 1.655	 3.8	 -0.49	 1.0	 12.58	 1	 6.36	 6.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	40954	 5.925	 1.655	 3.8	 -0.49	 1.0	 9.9	 0	 9.9	 1.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	40959	 135.28	 41.06	 105.02	 -22.9	 1.0	 265.59	 1	 206.33	 64.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40960	 140.2	 41.06	 105.02	 -22.9	 1.0	 226.92	 1	 206.33	 74.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40961	 128.05	 41.06	 105.02	 -22.9	 1.0	 217.56	 1	 206.33	 49.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40962	 147.08	 41.06	 105.02	 -22.9	 1.0	 239.42	 0	 206.33	 87.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40963	 126.7	 41.06	 105.02	 -22.9	 1.0	 209.77	 1	 206.33	 47.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.33;
	40964	 151.4	 41.06	 105.02	 -22.9	 1.0	 254.34	 0	 206.33	 96.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.3333;
	40966	 7.63	 0.0	 0.0	 0.0	 1.0	 12.6	 1	 7.63	 7.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.6;
	40969	 140.365	 37.82	 96.74	 -21.1	 1.0	 199.26	 1	 190.05	 90.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.05;
	40970	 125.69	 37.82	 96.74	 -21.1	 1.0	 231.88	 1	 190.05	 61.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.05;
	40971	 127.69	 37.82	 96.74	 -21.1	 1.0	 246.85	 1	 190.05	 65.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.05;
	40972	 134.275	 37.82	 96.74	 -21.1	 1.0	 275.33	 1	 190.05	 78.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.05;
	40973	 107.215	 37.82	 96.74	 -21.1	 1.0	 243.59	 1	 190.05	 24.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.05;
	40974	 128.46	 37.82	 96.74	 -21.1	 1.0	 220.57	 1	 190.05	 66.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 190.05;
	40976	 11.0	 0.0	 0.0	 0.0	 1.0	 11.05	 1	 11.0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	40977	 7.8	 0.0	 0.0	 0.0	 1.0	 11.27	 1	 7.8	 7.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	40984	 173.23	 29.015	 66.52	 -8.49	 1.0	 251.98	 1	 173.23	 173.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	40985	 90.55	 29.015	 66.52	 -8.49	 1.0	 259.85	 1	 90.55	 90.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	40986	 142.76	 29.015	 66.52	 -8.49	 1.0	 195.26	 1	 142.76	 142.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.2333;
	40987	 131.55	 29.015	 66.52	 -8.49	 1.0	 234.88	 1	 131.55	 131.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.23;
	40988	 100.525	 29.015	 66.52	 -8.49	 1.0	 191.18	 0	 173.23	 27.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.23;
	40989	 111.445	 29.015	 66.52	 -8.49	 1.0	 234.62	 0	 173.23	 49.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 173.23;
	40990	 19.56	 0.0	 0.0	 0.0	 1.0	 37.93	 0	 32.0	 7.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 32.0;
	40993	 132.44	 47.295	 120.97	 -26.38	 1.0	 250.7	 0	 237.67	 27.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.67;
	40994	 159.345	 47.295	 120.97	 -26.38	 1.0	 298.53	 1	 237.67	 81.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.6667;
	40995	 141.75	 47.295	 120.97	 -26.38	 1.0	 240.2	 0	 237.67	 45.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 237.6667;
	40996	 9.97	 0.0	 0.0	 0.0	 1.0	 21.24	 1	 9.97	 9.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.8;
	40997	 15.61	 0.0	 0.0	 0.0	 1.0	 27.38	 1	 15.61	 15.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.5;
	41000	 130.55	 45.875	 117.34	 -25.59	 1.0	 263.85	 1	 230.53	 30.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.53;
	41001	 139.19	 45.875	 117.34	 -25.59	 1.0	 260.16	 0	 230.53	 47.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.53;
	41002	 172.495	 45.875	 117.34	 -25.59	 1.0	 296.19	 0	 230.53	 114.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.5333;
	41005	 11.6	 0.0	 0.0	 0.0	 1.0	 17.08	 1	 11.6	 11.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	41009	 130.755	 43.41	 111.03	 -24.21	 1.0	 237.86	 1	 218.13	 43.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.13;
	41010	 144.055	 43.41	 111.03	 -24.21	 1.0	 281.77	 1	 218.13	 69.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.1333;
	41011	 161.055	 43.41	 111.03	 -24.21	 1.0	 261.25	 1	 218.13	 103.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.1333;
	41014	 11.715	 0.0	 0.0	 0.0	 1.0	 23.19	 0	 19.0	 4.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	41016	 11.82	 0.0	 0.0	 0.0	 1.0	 18.07	 1	 11.82	 11.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.0;
	41017	 7.28	 0.345	 2.13	 -1.44	 1.0	 13.94	 1	 7.28	 7.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	50360	 139.995	 45.935	 117.49	 -25.62	 1.0	 272.47	 1	 230.83	 49.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.8333;
	50361	 157.465	 45.935	 117.49	 -25.62	 1.0	 288.13	 0	 230.83	 84.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.8333;
	50362	 137.2	 45.935	 117.49	 -25.62	 1.0	 250.65	 1	 230.83	 43.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.8333;
	50363	 145.24	 45.935	 117.49	 -25.62	 1.0	 319.0	 1	 230.83	 59.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.8333;
	50364	 150.08	 45.935	 117.49	 -25.62	 1.0	 236.59	 0	 230.83	 69.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.83;
	50365	 145.985	 45.935	 117.49	 -25.62	 1.0	 307.38	 1	 230.83	 61.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.8333;
	50366	 5.385	 1.495	 3.82	 -0.83	 1.0	 8.38	 1	 7.5	 3.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	50367	 32.22	 9.99	 27.07	 -7.09	 1.0	 67.92	 1	 58.1	 6.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.1;
	50369	 4.98	 1.475	 3.77	 -0.82	 1.0	 8.16	 0	 7.4	 2.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.4;
	50369	 8.345	 2.485	 6.36	 -1.39	 1.0	 13.79	 0	 12.5	 4.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	50369	 9.025	 2.485	 6.36	 -1.39	 1.0	 13.84	 1	 12.5	 5.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	50374	 25.63	 8.635	 22.09	 -4.82	 1.0	 63.81	 1	 43.4	 7.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	50374	 26.37	 8.635	 22.09	 -4.82	 1.0	 47.29	 1	 43.4	 9.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	50375	 27.475	 8.635	 22.09	 -4.82	 1.0	 61.25	 1	 43.4	 11.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	50375	 30.63	 8.635	 22.09	 -4.82	 1.0	 64.31	 1	 43.4	 17.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	50376	 28.505	 8.635	 22.09	 -4.82	 1.0	 62.05	 1	 43.4	 13.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.4;
	50379	 11.93	 2.51	 5.76	 -0.74	 1.0	 19.04	 1	 11.93	 11.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	50379	 15.0	 2.51	 5.76	 -0.74	 1.0	 15.0	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	50382	 345.55	 85.915	 232.77	 -60.94	 1.0	 528.2	 1	 499.5	 191.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 499.5;
	50385	 467.135	 141.04	 382.12	 -100.04	 1.0	 936.79	 1	 820.0	 114.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 820.0;
	50386	 460.33	 141.04	 382.12	 -100.04	 1.0	 866.59	 1	 820.0	 100.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 820.0;
	50387	 5.0	 1.205	 3.26	 -0.85	 1.0	 8.81	 0	 7.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	50387	 5.07	 1.205	 3.26	 -0.85	 1.0	 9.59	 1	 7.0	 3.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	50390	 16.05	 0.0	 0.0	 0.0	 1.0	 26.66	 1	 16.05	 16.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.4;
	50390	 17.46	 0.0	 0.0	 0.0	 1.0	 29.58	 1	 17.46	 17.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.4;
	50391	 9.49	 0.0	 0.0	 0.0	 1.0	 21.0	 1	 9.49	 9.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	50393	 7.565	 0.0	 0.0	 0.0	 1.0	 13.9	 0	 12.5	 2.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	50393	 10.08	 0.0	 0.0	 0.0	 1.0	 12.66	 1	 10.08	 10.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	50397	 297.4	 90.425	 244.99	 -64.14	 1.0	 592.39	 1	 525.73	 69.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 525.73;
	50398	 348.595	 90.425	 244.99	 -64.14	 1.0	 587.41	 1	 525.73	 171.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 525.7333;
	50399	 290.775	 90.425	 244.99	 -64.14	 1.0	 585.95	 1	 525.73	 55.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 525.7333;
	50402	 157.22	 43.05	 110.11	 -24.01	 1.0	 221.08	 1	 216.33	 98.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.33;
	50403	 151.42	 43.05	 110.11	 -24.01	 1.0	 244.92	 1	 216.33	 86.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.33;
	50404	 119.905	 43.05	 110.11	 -24.01	 1.0	 270.36	 1	 216.33	 23.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.3333;
	50409	 160.85	 7.025	 43.35	 -29.3	 1.0	 257.91	 1	 160.85	 160.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.5;
	50412	 5.785	 2.02	 5.16	 -1.12	 1.0	 10.13	 0	 10.13	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.1333;
	50412	 7.03	 2.02	 5.16	 -1.12	 1.0	 10.13	 1	 10.13	 3.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.1333;
	50413	 6.83	 2.02	 5.16	 -1.12	 1.0	 11.26	 1	 10.13	 3.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.1333;
	50418	 71.31	 17.94	 48.6	 -12.72	 1.0	 104.39	 1	 104.3	 38.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.3;
	50419	 57.94	 17.94	 48.6	 -12.72	 1.0	 142.9	 1	 104.3	 11.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.3;
	50421	 91.74	 3.52	 21.73	 -14.69	 1.0	 114.57	 1	 91.74	 91.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.0;
	50424	 42.265	 13.93	 35.63	 -7.77	 1.0	 78.26	 1	 70.0	 14.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	50424	 49.27	 13.93	 35.63	 -7.77	 1.0	 71.69	 1	 70.0	 28.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	50433	 127.66	 4.965	 30.67	 -20.74	 1.0	 171.0	 1	 127.66	 127.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0;
	50434	 12.075	 0.655	 4.03	 -2.72	 1.0	 21.1	 0	 18.9	 5.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.9;
	50437	 10.205	 2.79	 7.13	 -1.55	 1.0	 14.26	 0	 14.0	 6.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	50437	 8.63	 2.79	 7.13	 -1.55	 1.0	 14.03	 0	 14.0	 3.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	50437	 9.545	 2.79	 7.13	 -1.55	 1.0	 17.81	 1	 14.0	 5.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	50440	 26.255	 7.825	 21.2	 -5.55	 1.0	 48.33	 1	 45.5	 7.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	50440	 25.83	 7.825	 21.2	 -5.55	 1.0	 50.9	 1	 45.5	 6.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	50441	 27.28	 7.825	 21.2	 -5.55	 1.0	 67.5	 1	 45.5	 9.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	50441	 26.135	 7.825	 21.2	 -5.55	 1.0	 46.46	 1	 45.5	 6.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	50442	 21.9	 5.47	 14.82	 -3.88	 1.0	 39.85	 1	 31.8	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.8;
	50443	 40.48	 14.13	 36.14	 -7.88	 1.0	 83.0	 1	 71.0	 9.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0;
	50443	 39.205	 14.13	 36.14	 -7.88	 1.0	 99.97	 1	 71.0	 7.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0;
	50443	 42.7	 14.13	 36.14	 -7.88	 1.0	 97.4	 1	 71.0	 14.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.0;
	50443	 66.445	 18.51	 47.35	 -10.33	 1.0	 97.48	 1	 93.03	 39.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.0333;
	50443	 64.225	 18.51	 47.35	 -10.33	 1.0	 97.78	 1	 93.03	 35.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.03;
	50443	 58.77	 18.51	 47.35	 -10.33	 1.0	 101.45	 1	 93.03	 24.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 93.03;
	50448	 382.18	 89.205	 241.69	 -63.28	 1.0	 609.96	 1	 518.65	 245.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 518.65;
	50449	 327.725	 89.205	 241.69	 -63.28	 1.0	 582.83	 0	 518.65	 136.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 518.65;
	50451	 11.69	 3.18	 8.14	 -1.78	 1.0	 20.34	 1	 16.0	 7.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	50451	 9.835	 3.18	 8.14	 -1.78	 1.0	 20.83	 1	 16.0	 3.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	50451	 11.01	 3.18	 8.14	 -1.78	 1.0	 16.4	 1	 16.0	 6.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.0;
	50457	 27.24	 7.96	 20.36	 -4.44	 1.0	 54.24	 0	 40.0	 14.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	50457	 22.99	 7.96	 20.36	 -4.44	 1.0	 45.15	 1	 40.0	 5.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	50458	 30.16	 -2.48	 -2.48	 -2.48	 1.0	 60.52	 1	 30.16	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	50458	 39.06	 -2.48	 -2.48	 -2.48	 1.0	 63.42	 1	 39.06	 39.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	50458	 43.01	 -2.48	 -2.48	 -2.48	 1.0	 56.83	 1	 43.01	 43.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.6;
	53215	 287.21	 79.465	 215.29	 -56.36	 1.0	 519.26	 0	 462.0	 112.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 462.0;
	53216	 268.245	 79.465	 215.29	 -56.36	 1.0	 571.3	 1	 462.0	 74.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 462.0;
	53217	 299.82	 79.465	 215.29	 -56.36	 1.0	 527.57	 1	 462.0	 137.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 462.0;
	53218	 259.15	 79.465	 215.29	 -56.36	 1.0	 533.99	 1	 462.0	 56.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 462.0;
	53222	 15.0	 2.51	 5.76	 -0.74	 1.0	 15.01	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	53222	 13.03	 2.51	 5.76	 -0.74	 1.0	 18.98	 1	 13.03	 13.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	53223	 8.14	 1.555	 3.57	 -0.46	 1.0	 9.34	 1	 8.14	 8.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	53223	 7.44	 1.555	 3.57	 -0.46	 1.0	 10.61	 1	 7.44	 7.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	53224	 4.59	 1.555	 3.57	 -0.46	 1.0	 10.88	 1	 4.59	 4.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.3;
	53224	 6.42	 1.34	 3.07	 -0.39	 1.0	 8.0	 1	 6.42	 6.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	53226	 35.915	 1.74	 10.74	 -7.26	 1.0	 65.04	 0	 50.4	 21.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	53233	 155.125	 44.205	 119.76	 -31.35	 1.0	 328.25	 1	 257.0	 53.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 257.0;
	53236	 4.995	 1.305	 3.53	 -0.92	 1.0	 7.57	 1	 7.57	 2.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5667;
	53236	 5.24	 1.305	 3.53	 -0.92	 1.0	 8.81	 1	 7.57	 2.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5667;
	53236	 5.45	 1.305	 3.53	 -0.92	 1.0	 7.57	 0	 7.57	 3.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5667;
	53236	 4.94	 1.305	 3.53	 -0.92	 1.0	 11.35	 0	 7.57	 2.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5667;
	53236	 4.865	 1.305	 3.53	 -0.92	 1.0	 7.69	 0	 7.57	 2.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5667;
	53236	 4.38	 1.305	 3.53	 -0.92	 1.0	 10.47	 0	 7.57	 1.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.57;
	53241	 63.055	 21.09	 53.95	 -11.77	 1.0	 126.63	 1	 106.0	 20.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.0;
	53242	 58.79	 17.68	 45.22	 -9.86	 1.0	 112.21	 1	 88.83	 28.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.8333;
	53243	 50.25	 17.68	 45.22	 -9.86	 1.0	 116.81	 1	 88.83	 11.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.8333;
	53244	 58.9	 17.68	 45.22	 -9.86	 1.0	 89.53	 1	 88.83	 28.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.8333;
	53246	 29.315	 8.76	 22.4	 -4.88	 1.0	 51.43	 1	 44.0	 14.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	53246	 24.87	 8.76	 22.4	 -4.88	 1.0	 50.83	 1	 44.0	 5.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	53248	 9.65	 2.985	 7.64	 -1.67	 1.0	 20.75	 0	 15.0	 4.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	53248	 9.645	 2.985	 7.64	 -1.67	 1.0	 16.83	 1	 15.0	 4.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	53248	 9.735	 2.985	 7.64	 -1.67	 1.0	 20.84	 1	 15.0	 4.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	53253	 135.43	 43.115	 110.28	 -24.05	 1.0	 234.66	 1	 216.67	 54.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6667;
	53254	 158.305	 43.115	 110.28	 -24.05	 1.0	 233.41	 0	 216.67	 99.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.6667;
	53255	 161.62	 43.115	 110.28	 -24.05	 1.0	 266.29	 1	 216.67	 106.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.67;
	53261	 116.89	 31.745	 81.19	 -17.7	 1.0	 207.41	 1	 159.5	 74.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.5;
	53263	 11.155	 0.0	 0.0	 0.0	 1.0	 20.65	 0	 20.2	 2.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.2;
	53263	 12.0	 0.0	 0.0	 0.0	 1.0	 13.28	 1	 12.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	53264	 7.55	 0.0	 0.0	 0.0	 1.0	 12.68	 1	 7.55	 7.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	53264	 7.5	 0.0	 0.0	 0.0	 1.0	 7.5	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	53268	 103.88	 29.85	 76.35	 -16.65	 1.0	 170.78	 1	 150.0	 57.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	53269	 5.1	 1.365	 3.49	 -0.76	 1.0	 8.65	 1	 6.85	 3.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.85;
	53269	 4.935	 1.365	 3.49	 -0.76	 1.0	 6.99	 1	 6.85	 3.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.85;
	53270	 100.0	 3.45	 21.3	 -14.4	 1.0	 123.72	 1	 100.0	 100.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	53277	 92.38	 3.53	 21.81	 -14.75	 1.0	 110.95	 1	 92.38	 92.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.4;
	53279	 18.505	 6.05	 15.47	 -3.37	 1.0	 44.22	 1	 30.4	 6.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	53279	 21.155	 6.05	 15.47	 -3.37	 1.0	 30.78	 1	 30.4	 11.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	53279	 17.225	 6.05	 15.47	 -3.37	 1.0	 35.27	 1	 30.4	 4.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	53279	 22.295	 6.05	 15.47	 -3.37	 1.0	 37.6	 0	 30.4	 14.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.4;
	53284	 17.14	 5.37	 13.74	 -3.0	 1.0	 30.8	 1	 27.0	 7.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	53285	 17.39	 5.37	 13.74	 -3.0	 1.0	 30.26	 1	 27.0	 7.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	53288	 32.91	 9.255	 23.67	 -5.16	 1.0	 50.61	 0	 46.5	 19.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	53289	 27.275	 9.255	 23.67	 -5.16	 1.0	 54.21	 1	 46.5	 8.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	53289	 34.725	 9.255	 23.67	 -5.16	 1.0	 68.5	 1	 46.5	 22.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	53289	 27.625	 9.255	 23.67	 -5.16	 1.0	 53.54	 1	 46.5	 8.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.5;
	53292	 107.51	 28.555	 73.04	 -15.93	 1.0	 170.23	 1	 143.5	 71.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.5;
	53293	 86.07	 28.555	 73.04	 -15.93	 1.0	 206.52	 1	 143.5	 28.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 143.5;
	53297	 512.18	 140.71	 381.23	 -99.81	 1.0	 931.25	 1	 818.1	 206.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 818.1;
	53298	 547.295	 140.71	 381.23	 -99.81	 1.0	 972.38	 1	 818.1	 276.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 818.1;
	53300	 43.36	 0.0	 0.0	 0.0	 1.0	 62.82	 1	 43.36	 43.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 52.2;
	53301	 4.59	 0.0	 0.0	 0.0	 1.0	 8.8	 1	 4.59	 4.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	53301	 23.18	 0.0	 0.0	 0.0	 1.0	 43.93	 1	 23.18	 23.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.6;
	53303	 6.015	 1.63	 4.17	 -0.91	 1.0	 9.42	 1	 8.2	 3.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2;
	53303	 5.57	 1.63	 4.17	 -0.91	 1.0	 9.21	 1	 8.2	 2.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2;
	53303	 5.085	 1.63	 4.17	 -0.91	 1.0	 8.2	 1	 8.2	 1.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.2;
	53303	 20.055	 6.665	 17.05	 -3.72	 1.0	 35.98	 1	 33.5	 6.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.5;
	53303	 18.92	 6.665	 17.05	 -3.72	 1.0	 39.34	 1	 33.5	 4.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.5;
	53305	 29.62	 10.215	 26.13	 -5.7	 1.0	 69.47	 1	 51.33	 7.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.33;
	53305	 32.58	 10.215	 26.13	 -5.7	 1.0	 77.0	 1	 51.33	 13.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.33;
	53305	 36.88	 10.215	 26.13	 -5.7	 1.0	 70.12	 1	 51.33	 22.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3333;
	60629	 125.25	 6.935	 42.81	 -28.94	 1.0	 301.5	 0	 201.0	 49.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.0;
	60631	 71.04	 3.005	 18.56	 -12.55	 1.0	 87.15	 1	 71.04	 71.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.15;
	60631	 63.78	 3.005	 18.56	 -12.55	 1.0	 97.38	 1	 63.78	 63.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.15;
	60635	 25.165	 7.56	 19.34	 -4.22	 1.0	 38.0	 1	 38.0	 12.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	60635	 23.68	 7.56	 19.34	 -4.22	 1.0	 43.48	 1	 38.0	 9.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	60635	 21.47	 7.56	 19.34	 -4.22	 1.0	 51.15	 1	 38.0	 4.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	60635	 25.915	 7.56	 19.34	 -4.22	 1.0	 55.32	 1	 38.0	 13.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	60635	 21.98	 7.56	 19.34	 -4.22	 1.0	 44.87	 1	 38.0	 5.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	60635	 22.225	 7.56	 19.34	 -4.22	 1.0	 50.57	 1	 38.0	 6.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.0;
	60646	 180.88	 10.37	 64.01	 -43.27	 1.0	 351.65	 1	 180.88	 180.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 300.5;
	60651	 167.95	 8.695	 53.68	 -36.29	 1.0	 347.48	 1	 167.95	 167.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 252.0;
	60656	 167.96	 6.88	 42.49	 -28.73	 1.0	 244.73	 1	 167.96	 167.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.5;
	60662	 390.01	 93.76	 254.02	 -66.5	 1.0	 598.49	 1	 545.1	 234.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 545.1;
	60663	 344.21	 93.76	 254.02	 -66.5	 1.0	 593.17	 1	 545.1	 143.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 545.1;
	60664	 389.33	 93.76	 254.02	 -66.5	 1.0	 688.1	 1	 545.1	 233.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 545.1;
	60668	 200.0	 6.9	 42.6	 -28.8	 1.0	 255.79	 1	 200.0	 200.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	60670	 44.375	 13.165	 33.67	 -7.34	 1.0	 72.58	 1	 66.15	 22.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.15;
	60670	 45.695	 13.165	 33.67	 -7.34	 1.0	 80.9	 1	 66.15	 25.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.15;
	60670	 39.155	 13.165	 33.67	 -7.34	 1.0	 85.16	 1	 66.15	 12.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.15;
	60670	 41.895	 13.165	 33.67	 -7.34	 1.0	 86.81	 1	 66.15	 17.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.15;
	60670	 36.47	 13.165	 33.67	 -7.34	 1.0	 66.87	 1	 66.15	 6.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.15;
	60670	 36.98	 13.165	 33.67	 -7.34	 1.0	 94.42	 1	 66.15	 7.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.15;
	60677	 111.245	 32.97	 89.33	 -23.39	 1.0	 275.73	 1	 191.7	 30.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.7;
	60678	 42.045	 10.2	 27.63	 -7.23	 1.0	 71.21	 1	 59.3	 24.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.3;
	60679	 41.895	 11.13	 30.15	 -7.89	 1.0	 87.13	 1	 64.7	 19.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.7;
	60679	 46.4	 11.13	 30.15	 -7.89	 1.0	 87.23	 1	 64.7	 28.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.7;
	60686	 135.41	 43.18	 110.44	 -24.08	 1.0	 269.88	 1	 216.97	 53.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.975;
	60687	 158.355	 43.18	 110.44	 -24.08	 1.0	 221.08	 0	 216.97	 99.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.98;
	60688	 158.155	 43.18	 110.44	 -24.08	 1.0	 248.61	 1	 216.97	 99.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.98;
	60689	 158.61	 43.18	 110.44	 -24.08	 1.0	 261.76	 0	 216.97	 100.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 216.975;
	60690	 98.375	 27.92	 71.41	 -15.57	 1.0	 152.84	 1	 140.3	 56.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.3;
	60691	 97.015	 27.92	 71.41	 -15.57	 1.0	 163.35	 0	 140.3	 53.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 140.3;
	60692	 27.405	 7.36	 18.83	 -4.11	 1.0	 51.31	 1	 37.0	 17.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.0;
	60695	 18.62	 5.295	 13.54	 -2.95	 1.0	 27.87	 1	 26.6	 10.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6;
	60695	 16.235	 5.295	 13.54	 -2.95	 1.0	 36.89	 1	 26.6	 5.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6;
	60696	 14.69	 3.745	 10.14	 -2.65	 1.0	 24.36	 1	 21.75	 7.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.75;
	60696	 16.005	 3.745	 10.14	 -2.65	 1.0	 22.2	 1	 21.75	 10.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.75;
	60701	 69.05	 2.585	 15.97	 -10.8	 1.0	 86.53	 1	 69.05	 69.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	60702	 29.0	 1.0	 6.18	 -4.18	 1.0	 39.33	 1	 29.0	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.0;
	60707	 138.385	 40.025	 108.44	 -28.39	 1.0	 258.03	 1	 232.7	 44.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 232.7;
	60708	 141.965	 40.025	 108.44	 -28.39	 1.0	 303.4	 1	 232.7	 51.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 232.7;
	60712	 250.8	 8.65	 53.42	 -36.12	 1.0	 337.51	 1	 250.8	 250.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 250.8;
	60716	 131.175	 39.58	 101.24	 -22.08	 1.0	 271.24	 1	 198.9	 63.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	60717	 141.525	 39.58	 101.24	 -22.08	 1.0	 253.18	 1	 198.9	 84.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.9;
	60721	 139.82	 6.92	 42.73	 -28.89	 1.0	 222.35	 1	 139.82	 139.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.6;
	60722	 38.2	 6.4	 14.67	 -1.87	 1.0	 38.2	 1	 38.2	 38.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.2;
	60727	 159.87	 47.41	 128.45	 -33.63	 1.0	 412.33	 1	 275.65	 44.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 275.65;
	60728	 193.1	 47.41	 128.45	 -33.63	 1.0	 354.46	 1	 275.65	 110.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 275.65;
	60729	 8.62	 2.01	 5.44	 -1.42	 1.0	 17.5	 1	 11.67	 5.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.67;
	60730	 6.785	 2.01	 5.44	 -1.42	 1.0	 11.67	 1	 11.67	 1.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.67;
	60730	 6.815	 2.01	 5.44	 -1.42	 1.0	 13.67	 1	 11.67	 1.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.6667;
	60731	 16.395	 4.735	 12.11	 -2.64	 1.0	 29.87	 1	 23.8	 8.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.8;
	60731	 25.97	 9.065	 23.19	 -5.06	 1.0	 55.07	 1	 45.57	 6.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5667;
	60732	 32.19	 9.065	 23.19	 -5.06	 1.0	 65.08	 1	 45.57	 18.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5667;
	60732	 27.89	 9.065	 23.19	 -5.06	 1.0	 60.25	 1	 45.57	 10.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.57;
	60732	 27.205	 9.065	 23.19	 -5.06	 1.0	 59.31	 1	 45.57	 8.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5667;
	60732	 26.08	 9.065	 23.19	 -5.06	 1.0	 58.85	 0	 45.57	 6.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.57;
	60732	 33.775	 9.065	 23.19	 -5.06	 1.0	 54.49	 1	 45.57	 21.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5667;
	60734	 16.905	 4.895	 13.26	 -3.47	 1.0	 28.45	 1	 28.45	 5.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	60735	 16.0	 4.895	 13.26	 -3.47	 1.0	 42.67	 1	 28.45	 3.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	60735	 18.45	 4.895	 13.26	 -3.47	 1.0	 34.11	 1	 28.45	 8.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	60735	 19.915	 4.895	 13.26	 -3.47	 1.0	 41.17	 1	 28.45	 11.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.45;
	60743	 5.56	 1.31	 3.0	 -0.38	 1.0	 8.37	 0	 7.8	 3.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.8;
	60744	 21.54	 4.625	 10.6	 -1.35	 1.0	 28.27	 1	 21.54	 21.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	60746	 124.58	 25.125	 57.6	 -7.35	 1.0	 175.05	 1	 124.58	 124.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	60747	 94.45	 25.125	 57.6	 -7.35	 1.0	 184.86	 1	 94.45	 94.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	60751	 315.545	 94.995	 257.37	 -67.38	 1.0	 598.59	 1	 552.3	 78.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 552.3;
	60752	 46.785	 15.34	 39.24	 -8.56	 1.0	 107.94	 1	 77.1	 16.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	60752	 44.94	 15.34	 39.24	 -8.56	 1.0	 87.15	 1	 77.1	 12.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	60760	 142.31	 5.59	 34.51	 -23.33	 1.0	 211.28	 1	 142.31	 142.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 162.0;
	60763	 14.255	 3.95	 10.11	 -2.21	 1.0	 21.17	 0	 19.87	 8.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8667;
	60763	 13.5	 3.95	 10.11	 -2.21	 1.0	 24.95	 0	 19.87	 7.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.87;
	60764	 11.14	 3.95	 10.11	 -2.21	 1.0	 19.87	 0	 19.87	 2.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8667;
	60765	 9.9	 1.655	 3.8	 -0.49	 1.0	 12.71	 1	 9.9	 9.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.9;
	60765	 17.84	 4.69	 10.75	 -1.37	 1.0	 28.68	 1	 17.84	 17.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	60766	 50.535	 15.34	 39.24	 -8.56	 1.0	 78.12	 1	 77.1	 23.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	60766	 45.095	 15.34	 39.24	 -8.56	 1.0	 104.44	 1	 77.1	 13.09	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 77.1;
	60773	 13.77	 3.78	 9.67	 -2.11	 1.0	 22.28	 1	 19.0	 8.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	60773	 11.61	 3.78	 9.67	 -2.11	 1.0	 21.08	 1	 19.0	 4.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	60773	 13.555	 3.78	 9.67	 -2.11	 1.0	 21.48	 1	 19.0	 8.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	60773	 14.2	 3.78	 9.67	 -2.11	 1.0	 26.24	 1	 19.0	 9.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	60773	 10.855	 3.78	 9.67	 -2.11	 1.0	 23.88	 0	 19.0	 2.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	60773	 13.895	 3.78	 9.67	 -2.11	 1.0	 19.46	 0	 19.0	 8.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	60775	 136.665	 35.605	 96.46	 -25.25	 1.0	 282.59	 1	 207.0	 66.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 207.0;
	60776	 27.49	 6.5	 17.61	 -4.61	 1.0	 56.7	 1	 37.8	 17.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.8;
	60776	 26.795	 6.5	 17.61	 -4.61	 1.0	 38.49	 1	 37.8	 15.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.8;
	60780	 175.68	 6.9	 42.6	 -28.8	 1.0	 252.84	 1	 175.68	 175.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	60783	 30.75	 7.2	 16.51	 -2.11	 1.0	 54.98	 1	 30.75	 30.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0;
	60784	 6.5	 1.42	 3.26	 -0.42	 1.0	 11.38	 1	 6.5	 6.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.5;
	60784	 29.14	 7.2	 16.51	 -2.11	 1.0	 52.3	 1	 29.14	 29.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.0;
	60788	 24.94	 6.635	 16.97	 -3.7	 1.0	 40.27	 1	 33.33	 16.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	60789	 21.37	 6.635	 16.97	 -3.7	 1.0	 39.09	 1	 33.33	 9.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	60791	 59.865	 19.9	 50.9	 -11.1	 1.0	 120.78	 1	 100.0	 19.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	60792	 68.41	 19.9	 50.9	 -11.1	 1.0	 124.31	 1	 100.0	 36.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	60793	 24.455	 6.635	 16.97	 -3.7	 1.0	 45.98	 0	 33.33	 15.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	60794	 22.375	 6.635	 16.97	 -3.7	 1.0	 33.33	 1	 33.33	 11.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	60794	 23.195	 6.635	 16.97	 -3.7	 1.0	 33.33	 1	 33.33	 13.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.33;
	60795	 20.785	 6.635	 16.97	 -3.7	 1.0	 37.33	 1	 33.33	 8.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.33;
	60798	 9.34	 2.175	 4.99	 -0.64	 1.0	 14.12	 1	 9.34	 9.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	60798	 8.99	 2.175	 4.99	 -0.64	 1.0	 13.28	 1	 8.99	 8.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.0;
	60799	 6.32	 1.205	 2.76	 -0.35	 1.0	 7.2	 1	 6.32	 6.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.2;
	60799	 6.05	 1.205	 2.76	 -0.35	 1.0	 7.65	 1	 6.05	 6.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.2;
	60801	 8.81	 0.0	 0.0	 0.0	 1.0	 11.33	 1	 8.81	 8.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.3;
	60802	 7.74	 0.0	 0.0	 0.0	 1.0	 10.62	 1	 7.74	 7.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.5;
	60802	 21.83	 0.0	 0.0	 0.0	 1.0	 31.87	 1	 21.83	 21.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	60802	 25.785	 0.0	 0.0	 0.0	 1.0	 51.64	 0	 35.0	 16.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	60803	 7.54	 0.0	 0.0	 0.0	 1.0	 9.5	 1	 7.54	 7.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.5;
	60807	 75.19	 14.505	 33.25	 -4.24	 1.0	 103.02	 1	 75.19	 75.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.6;
	60808	 55.88	 14.505	 33.25	 -4.24	 1.0	 113.06	 0	 86.6	 25.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 86.6;
	60809	 6.31	 1.91	 4.38	 -0.56	 1.0	 11.6	 1	 6.31	 6.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.4;
	60810	 44.785	 14.92	 38.17	 -8.33	 1.0	 83.46	 1	 75.0	 14.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	60811	 26.08	 7.235	 16.59	 -2.12	 1.0	 48.58	 1	 26.08	 26.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2;
	60811	 24.175	 7.235	 16.59	 -2.12	 1.0	 50.3	 0	 43.2	 5.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 43.2;
	60814	 89.48	 29.85	 76.35	 -16.65	 1.0	 174.95	 0	 150.0	 28.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	60815	 97.905	 29.85	 76.35	 -16.65	 1.0	 199.63	 0	 150.0	 45.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	60820	 41.04	 1.57	 9.69	 -6.55	 1.0	 57.21	 1	 41.04	 41.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	60820	 35.21	 1.57	 9.69	 -6.55	 1.0	 63.39	 1	 35.21	 35.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 45.5;
	60822	 39.82	 1.76	 10.86	 -7.34	 1.0	 51.66	 1	 39.82	 39.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0;
	60825	 7.43	 2.19	 5.6	 -1.22	 1.0	 14.49	 0	 11.0	 3.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	60825	 7.46	 2.19	 5.6	 -1.22	 1.0	 11.21	 1	 11.0	 3.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	60825	 7.065	 2.19	 5.6	 -1.22	 1.0	 11.33	 1	 11.0	 3.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	60825	 53.085	 14.15	 36.19	 -7.89	 1.0	 93.11	 0	 71.1	 35.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1;
	60825	 42.245	 14.15	 36.19	 -7.89	 1.0	 94.19	 1	 71.1	 13.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 71.1;
	60827	 62.775	 16.75	 38.4	 -4.9	 1.0	 117.65	 0	 100.0	 25.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	60827	 78.85	 16.75	 38.4	 -4.9	 1.0	 130.22	 1	 78.85	 78.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.0;
	60833	 161.74	 45.445	 116.24	 -25.35	 1.0	 294.77	 1	 228.37	 95.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.3667;
	60834	 158.87	 45.445	 116.24	 -25.35	 1.0	 296.39	 1	 228.37	 89.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.37;
	60835	 145.33	 45.445	 116.24	 -25.35	 1.0	 266.31	 1	 228.37	 62.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.3667;
	60839	 43.33	 12.87	 32.92	 -7.18	 1.0	 82.12	 0	 64.67	 21.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.6667;
	60840	 36.31	 12.87	 32.92	 -7.18	 1.0	 83.38	 1	 64.67	 7.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.6667;
	60841	 37.32	 12.87	 32.92	 -7.18	 1.0	 73.01	 1	 64.67	 9.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.67;
	60844	 36.18	 10.03	 25.65	 -5.59	 1.0	 62.58	 1	 50.4	 21.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	60844	 28.51	 10.03	 25.65	 -5.59	 1.0	 56.33	 1	 50.4	 6.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.4;
	60847	 15.615	 4.18	 10.69	 -2.33	 1.0	 24.01	 0	 21.0	 10.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	60847	 12.76	 4.18	 10.69	 -2.33	 1.0	 21.0	 0	 21.0	 4.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	60847	 12.975	 4.18	 10.69	 -2.33	 1.0	 28.96	 1	 21.0	 4.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	60848	 11.71	 4.18	 10.69	 -2.33	 1.0	 31.38	 1	 21.0	 2.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	60848	 18.735	 5.295	 13.54	 -2.95	 1.0	 29.97	 1	 26.6	 10.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.6;
	60850	 10.93	 3.9	 9.98	 -2.18	 1.0	 19.67	 1	 19.6	 2.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	60850	 12.52	 3.9	 9.98	 -2.18	 1.0	 26.22	 1	 19.6	 5.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	60850	 14.415	 3.9	 9.98	 -2.18	 1.0	 25.65	 0	 19.6	 9.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	60851	 14.325	 3.9	 9.98	 -2.18	 1.0	 23.23	 0	 19.6	 9.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	60851	 12.445	 3.9	 9.98	 -2.18	 1.0	 19.65	 0	 19.6	 5.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	60851	 14.555	 3.9	 9.98	 -2.18	 1.0	 19.6	 1	 19.6	 9.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.6;
	60852	 58.595	 14.735	 39.92	 -10.45	 1.0	 127.09	 1	 85.67	 31.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.6667;
	60852	 58.135	 14.735	 39.92	 -10.45	 1.0	 128.03	 1	 85.67	 30.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.6667;
	60852	 51.62	 14.735	 39.92	 -10.45	 1.0	 86.63	 1	 85.67	 17.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 85.6667;
	60856	 9.63	 2.51	 5.76	 -0.74	 1.0	 15.0	 1	 9.63	 9.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	60856	 10.87	 2.51	 5.76	 -0.74	 1.0	 21.52	 1	 10.87	 10.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	60857	 13.52	 2.51	 5.76	 -0.74	 1.0	 15.89	 1	 13.52	 13.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	60857	 5.195	 1.355	 3.11	 -0.4	 1.0	 9.07	 0	 8.1	 2.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.1;
	60861	 121.14	 39.2	 100.27	 -21.87	 1.0	 224.32	 1	 197.0	 45.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	60862	 144.105	 39.2	 100.27	 -21.87	 1.0	 242.2	 0	 197.0	 91.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	60865	 42.25	 2.07	 12.78	 -8.64	 1.0	 60.37	 0	 60.0	 24.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	60872	 268.455	 81.845	 221.75	 -58.06	 1.0	 593.45	 1	 475.87	 61.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 475.87;
	60873	 321.65	 81.845	 221.75	 -58.06	 1.0	 565.2	 1	 475.87	 167.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 475.87;
	60874	 354.27	 81.845	 221.75	 -58.06	 1.0	 480.85	 1	 475.87	 232.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 475.8667;
	60875	 20.86	 1.025	 6.33	 -4.28	 1.0	 43.94	 1	 20.86	 20.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	60875	 22.13	 1.08	 6.67	 -4.51	 1.0	 35.18	 1	 22.13	 22.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3;
	60875	 22.36	 1.08	 6.67	 -4.51	 1.0	 31.3	 1	 22.36	 22.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.3;
	60881	 111.815	 35.885	 91.79	 -20.02	 1.0	 183.08	 0	 180.33	 43.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.33;
	60882	 109.47	 35.885	 91.79	 -20.02	 1.0	 225.53	 1	 180.33	 38.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.3333;
	60883	 106.17	 35.885	 91.79	 -20.02	 1.0	 259.49	 1	 180.33	 32.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.33;
	60891	 190.58	 50.5	 136.82	 -35.82	 1.0	 293.6	 1	 293.6	 87.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 293.6;
	60892	 74.115	 17.43	 47.23	 -12.37	 1.0	 113.18	 1	 101.36	 46.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.36;
	60893	 56.245	 17.43	 47.23	 -12.37	 1.0	 137.93	 1	 101.36	 11.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.36;
	60894	 69.13	 17.43	 47.23	 -12.37	 1.0	 118.18	 1	 101.36	 36.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.36;
	60895	 67.67	 17.43	 47.23	 -12.37	 1.0	 125.59	 1	 101.36	 33.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.36;
	60896	 66.14	 17.43	 47.23	 -12.37	 1.0	 101.36	 1	 101.36	 30.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.36;
	70097	 167.445	 39.655	 107.44	 -28.13	 1.0	 267.51	 0	 230.55	 104.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.55;
	70098	 127.155	 39.655	 107.44	 -28.13	 1.0	 285.37	 1	 230.55	 23.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.55;
	70099	 172.885	 39.655	 107.44	 -28.13	 1.0	 274.81	 0	 230.55	 115.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.55;
	70100	 131.665	 39.655	 107.44	 -28.13	 1.0	 303.98	 0	 230.55	 32.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.55;
	70104	 185.19	 6.9	 42.6	 -28.8	 1.0	 256.4	 1	 185.19	 185.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	70105	 61.98	 15.135	 41.01	 -10.74	 1.0	 117.0	 1	 88.0	 35.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.0;
	70107	 23.13	 1.015	 6.26	 -4.23	 1.0	 36.72	 1	 23.13	 23.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.4;
	70107	 30.77	 1.45	 8.95	 -6.05	 1.0	 52.97	 1	 30.77	 30.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.0;
	70110	 23.225	 6.88	 18.64	 -4.88	 1.0	 46.69	 1	 40.0	 6.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	70110	 47.98	 13.76	 37.28	 -9.76	 1.0	 117.04	 1	 80.0	 15.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	70111	 29.77	 5.595	 12.83	 -1.64	 1.0	 48.77	 1	 29.77	 29.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4;
	70111	 33.4	 5.595	 12.83	 -1.64	 1.0	 44.67	 1	 33.4	 33.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.4;
	70114	 86.23	 3.56	 22.0	 -14.88	 1.0	 112.35	 1	 86.23	 86.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.3;
	70115	 24.86	 1.025	 6.33	 -4.28	 1.0	 29.7	 1	 24.86	 24.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 29.7;
	70121	 295.04	 83.195	 225.4	 -59.01	 1.0	 603.17	 1	 483.7	 106.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 483.7;
	70125	 181.9	 47.705	 129.24	 -33.83	 1.0	 277.33	 1	 277.33	 86.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 277.33;
	70126	 188.965	 47.705	 129.24	 -33.83	 1.0	 300.24	 1	 277.33	 100.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 277.3333;
	70127	 197.185	 47.705	 129.24	 -33.83	 1.0	 309.88	 1	 277.33	 117.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 277.3333;
	70128	 11.5	 0.395	 2.45	 -1.66	 1.0	 14.58	 1	 11.5	 11.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.5;
	70128	 10.92	 0.58	 3.58	 -2.42	 1.0	 16.8	 1	 10.92	 10.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.8;
	70128	 17.32	 0.855	 5.28	 -3.57	 1.0	 25.31	 0	 24.8	 9.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.8;
	70128	 28.33	 1.43	 8.82	 -5.96	 1.0	 51.09	 1	 28.33	 28.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.4;
	70128	 32.04	 1.725	 10.65	 -7.2	 1.0	 62.5	 1	 32.04	 32.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 50.0;
	70131	 48.17	 2.105	 12.99	 -8.78	 1.0	 87.54	 1	 48.17	 48.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	70134	 246.245	 69.195	 187.47	 -49.08	 1.0	 438.06	 1	 402.3	 90.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 402.3;
	70141	 20.095	 6.635	 16.97	 -3.7	 1.0	 44.88	 1	 33.33	 6.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	70142	 23.355	 6.635	 16.97	 -3.7	 1.0	 39.24	 1	 33.33	 13.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	70144	 23.46	 7.96	 20.36	 -4.44	 1.0	 50.91	 1	 40.0	 6.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	70144	 19.825	 6.635	 16.97	 -3.7	 1.0	 42.46	 1	 33.33	 6.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.3333;
	70146	 75.68	 3.995	 24.67	 -16.68	 1.0	 137.7	 1	 75.68	 75.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.8;
	70147	 4.48	 1.175	 3.18	 -0.83	 1.0	 6.83	 0	 6.83	 2.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	70147	 4.22	 1.175	 3.18	 -0.83	 1.0	 8.28	 1	 6.83	 1.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.83;
	70147	 4.67	 1.175	 3.18	 -0.83	 1.0	 7.65	 1	 6.83	 2.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	70147	 4.13	 1.175	 3.18	 -0.83	 1.0	 8.26	 1	 6.83	 1.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	70147	 3.875	 1.175	 3.18	 -0.83	 1.0	 6.83	 1	 6.83	 0.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	70147	 4.645	 1.175	 3.18	 -0.83	 1.0	 7.6	 0	 6.83	 2.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8333;
	70147	 10.645	 2.58	 6.99	 -1.83	 1.0	 18.61	 0	 15.0	 6.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	70147	 10.595	 2.58	 6.99	 -1.83	 1.0	 19.52	 0	 15.0	 6.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	70149	 71.29	 3.415	 21.09	 -14.26	 1.0	 110.78	 0	 99.0	 43.58	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.0;
	70150	 11.75	 0.585	 3.62	 -2.45	 1.0	 19.46	 0	 17.0	 6.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.0;
	70153	 377.415	 105.0	 284.48	 -74.48	 1.0	 797.76	 1	 610.48	 144.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.475;
	70154	 393.14	 105.0	 284.48	 -74.48	 1.0	 717.31	 1	 610.48	 175.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.47;
	70155	 413.095	 105.0	 284.48	 -74.48	 1.0	 717.63	 1	 610.48	 215.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.475;
	70156	 401.955	 105.0	 284.48	 -74.48	 1.0	 686.24	 1	 610.48	 193.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 610.475;
	70160	 87.22	 3.56	 22.0	 -14.88	 1.0	 123.54	 1	 87.22	 87.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.3;
	70163	 12.4	 3.47	 7.95	 -1.01	 1.0	 23.24	 0	 20.7	 4.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	70164	 16.26	 3.47	 7.95	 -1.01	 1.0	 21.16	 1	 16.26	 16.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.7;
	70164	 11.53	 3.185	 7.3	 -0.93	 1.0	 24.13	 0	 19.0	 4.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	70165	 13.57	 3.185	 7.3	 -0.93	 1.0	 21.84	 1	 13.57	 13.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.0;
	70165	 9.06	 1.675	 3.84	 -0.49	 1.0	 10.18	 1	 9.06	 9.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	70166	 5.15	 1.255	 2.88	 -0.37	 1.0	 9.04	 0	 7.5	 2.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70166	 6.66	 1.255	 2.88	 -0.37	 1.0	 9.39	 1	 6.66	 6.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 5.18	 1.495	 3.82	 -0.83	 1.0	 7.5	 1	 7.5	 2.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 25.85	 7.96	 20.36	 -4.44	 1.0	 44.49	 1	 40.0	 11.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	70167	 5.375	 1.495	 3.82	 -0.83	 1.0	 8.33	 1	 7.5	 3.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 5.56	 1.495	 3.82	 -0.83	 1.0	 7.53	 1	 7.5	 3.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 4.675	 1.495	 3.82	 -0.83	 1.0	 10.83	 1	 7.5	 1.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 4.39	 1.495	 3.82	 -0.83	 1.0	 10.15	 1	 7.5	 1.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 4.925	 1.495	 3.82	 -0.83	 1.0	 8.2	 1	 7.5	 2.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 4.565	 1.495	 3.82	 -0.83	 1.0	 7.63	 1	 7.5	 1.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 4.165	 1.495	 3.82	 -0.83	 1.0	 7.5	 1	 7.5	 0.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70167	 5.335	 1.495	 3.82	 -0.83	 1.0	 9.63	 1	 7.5	 3.17	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	70168	 54.41	 2.76	 17.04	 -11.52	 1.0	 103.44	 0	 80.0	 28.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	70172	 380.43	 98.04	 265.62	 -69.54	 1.0	 648.33	 1	 570.0	 190.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.0;
	70173	 349.445	 98.04	 265.62	 -69.54	 1.0	 662.9	 1	 570.0	 128.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.0;
	70174	 332.28	 98.04	 265.62	 -69.54	 1.0	 604.83	 1	 570.0	 94.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 570.0;
	70176	 76.55	 19.985	 54.15	 -14.18	 1.0	 118.72	 1	 116.2	 36.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 116.2;
	70177	 42.55	 2.13	 13.16	 -8.9	 1.0	 64.31	 1	 42.55	 42.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.8;
	70177	 55.22	 2.13	 13.16	 -8.9	 1.0	 61.8	 1	 55.22	 55.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.8;
	70180	 72.0	 2.485	 15.34	 -10.37	 1.0	 100.08	 1	 72.0	 72.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	70181	 45.235	 2.485	 15.34	 -10.37	 1.0	 72.78	 0	 72.0	 18.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	70182	 7.28	 2.01	 4.61	 -0.59	 1.0	 17.32	 1	 7.28	 7.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	70182	 10.86	 2.01	 4.61	 -0.59	 1.0	 14.93	 1	 10.86	 10.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	70182	 9.26	 2.01	 4.61	 -0.59	 1.0	 15.27	 1	 9.26	 9.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	70182	 12.64	 2.88	 6.6	 -0.84	 1.0	 21.82	 1	 12.64	 12.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	70182	 11.08	 2.88	 6.6	 -0.84	 1.0	 17.51	 1	 11.08	 11.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	70182	 11.79	 2.88	 6.6	 -0.84	 1.0	 17.46	 1	 11.79	 11.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 17.2;
	70184	 64.345	 16.34	 44.27	 -11.59	 1.0	 95.0	 0	 95.0	 33.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	70188	 25.59	 7.16	 18.32	 -4.0	 1.0	 42.01	 1	 36.0	 15.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	70188	 25.83	 7.16	 18.32	 -4.0	 1.0	 39.71	 1	 36.0	 15.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	70189	 24.93	 7.16	 18.32	 -4.0	 1.0	 44.09	 1	 36.0	 13.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	74196	 26.315	 7.385	 16.93	 -2.16	 1.0	 61.92	 0	 44.1	 8.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	74196	 29.24	 7.385	 16.93	 -2.16	 1.0	 50.83	 0	 44.1	 14.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	74197	 44.1	 7.385	 16.93	 -2.16	 1.0	 62.89	 1	 44.1	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	74197	 37.11	 7.385	 16.93	 -2.16	 1.0	 55.65	 1	 37.11	 37.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.1;
	74199	 15.0	 2.51	 5.76	 -0.74	 1.0	 15.03	 1	 15.0	 15.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	74199	 8.04	 2.51	 5.76	 -0.74	 1.0	 21.78	 1	 8.04	 8.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	74199	 12.94	 2.51	 5.76	 -0.74	 1.0	 15.0	 1	 12.94	 12.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	74199	 12.99	 2.51	 5.76	 -0.74	 1.0	 19.1	 1	 12.99	 12.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	74200	 6.045	 1.39	 3.19	 -0.41	 1.0	 8.3	 0	 8.3	 3.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.3;
	74201	 10.18	 2.26	 5.18	 -0.66	 1.0	 13.56	 1	 10.18	 10.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	74204	 118.01	 34.39	 87.96	 -19.18	 1.0	 193.75	 1	 172.8	 63.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	74205	 6.965	 2.07	 5.29	 -1.15	 1.0	 11.44	 0	 10.4	 3.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4;
	74205	 6.42	 2.07	 5.29	 -1.15	 1.0	 10.4	 1	 10.4	 2.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4;
	74211	 89.675	 30.0	 76.73	 -16.73	 1.0	 189.7	 1	 150.75	 28.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.75;
	74212	 99.765	 30.0	 76.73	 -16.73	 1.0	 166.34	 1	 150.75	 48.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.75;
	74213	 38.28	 0.0	 0.0	 0.0	 1.0	 46.9	 1	 38.28	 38.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.9;
	74214	 9.35	 0.0	 0.0	 0.0	 1.0	 11.09	 1	 9.35	 9.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	74214	 7.46	 0.0	 0.0	 0.0	 1.0	 15.0	 1	 7.46	 7.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	74214	 33.93	 0.0	 0.0	 0.0	 1.0	 61.68	 1	 33.93	 33.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.9;
	74220	 28.36	 5.65	 12.95	 -1.65	 1.0	 39.57	 1	 28.36	 28.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.73;
	74220	 27.57	 5.65	 12.95	 -1.65	 1.0	 33.73	 1	 27.57	 27.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.73;
	74221	 33.73	 5.65	 12.95	 -1.65	 1.0	 33.73	 1	 33.73	 33.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.7333;
	74221	 4.745	 1.255	 2.88	 -0.37	 1.0	 9.55	 0	 7.5	 1.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	74222	 5.26	 1.255	 2.88	 -0.37	 1.0	 11.25	 1	 5.26	 5.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	74223	 57.02	 17.97	 45.96	 -10.02	 1.0	 124.96	 0	 90.3	 23.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.3;
	74223	 62.02	 17.97	 45.96	 -10.02	 1.0	 105.01	 1	 90.3	 33.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.3;
	74223	 55.975	 17.97	 45.96	 -10.02	 1.0	 123.18	 1	 90.3	 21.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.3;
	74225	 50.07	 2.225	 13.74	 -9.29	 1.0	 64.98	 1	 50.07	 50.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 64.5;
	74226	 16.8	 0.58	 3.58	 -2.42	 1.0	 18.48	 1	 16.8	 16.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.8;
	74226	 6.55	 0.655	 4.03	 -2.72	 1.0	 20.92	 1	 6.55	 6.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.9;
	74228	 5.65	 1.175	 2.69	 -0.34	 1.0	 7.02	 1	 5.65	 5.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.0;
	74228	 8.06	 2.095	 4.8	 -0.61	 1.0	 12.81	 1	 8.06	 8.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	74228	 12.36	 2.095	 4.8	 -0.61	 1.0	 15.16	 1	 12.36	 12.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.5;
	74230	 9.89	 0.365	 2.24	 -1.51	 1.0	 13.38	 1	 9.89	 9.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	74231	 16.1	 0.725	 4.47	 -3.02	 1.0	 21.37	 1	 16.1	 16.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	74233	 14.015	 0.725	 4.47	 -3.02	 1.0	 25.61	 0	 21.0	 7.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	74236	 36.59	 11.105	 25.46	 -3.25	 1.0	 74.23	 1	 36.59	 36.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.3;
	74237	 45.59	 11.105	 25.46	 -3.25	 1.0	 74.0	 1	 45.59	 45.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.3;
	74238	 44.9	 11.105	 25.46	 -3.25	 1.0	 84.3	 1	 44.9	 44.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.3;
	74239	 47.54	 11.105	 25.46	 -3.25	 1.0	 91.92	 1	 47.54	 47.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.3;
	74240	 53.835	 16.555	 42.35	 -9.24	 1.0	 97.63	 1	 83.2	 24.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.2;
	74240	 53.36	 16.555	 42.35	 -9.24	 1.0	 83.2	 1	 83.2	 23.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.2;
	74245	 5.43	 1.16	 2.66	 -0.34	 1.0	 6.93	 1	 5.43	 5.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.93;
	74246	 3.885	 1.16	 2.66	 -0.34	 1.0	 7.76	 0	 6.93	 0.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.93;
	74248	 3.4	 1.16	 2.66	 -0.34	 1.0	 6.93	 1	 3.4	 3.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.925;
	74248	 4.495	 1.16	 2.66	 -0.34	 1.0	 6.96	 0	 6.93	 2.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.925;
	74252	 89.21	 19.61	 44.96	 -5.74	 1.0	 117.23	 1	 89.21	 89.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.08;
	74253	 84.005	 19.61	 44.96	 -5.74	 1.0	 158.76	 0	 117.08	 50.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.08;
	74254	 83.06	 19.61	 44.96	 -5.74	 1.0	 125.59	 1	 83.06	 83.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.08;
	74255	 80.11	 19.61	 44.96	 -5.74	 1.0	 154.54	 1	 80.11	 80.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.08;
	74256	 105.82	 19.61	 44.96	 -5.74	 1.0	 137.85	 1	 105.82	 105.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 117.08;
	74259	 22.5	 0.775	 4.79	 -3.24	 1.0	 22.5	 1	 22.5	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	74259	 16.46	 0.725	 4.47	 -3.02	 1.0	 26.26	 1	 16.46	 16.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	74260	 6.475	 0.365	 2.24	 -1.51	 1.0	 13.79	 0	 10.5	 2.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	74261	 25.0	 4.19	 9.6	 -1.22	 1.0	 32.61	 1	 25.0	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	74261	 20.31	 4.19	 9.6	 -1.22	 1.0	 37.5	 1	 20.31	 20.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	74261	 16.155	 4.19	 9.6	 -1.22	 1.0	 25.53	 0	 25.0	 7.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.0;
	74263	 43.945	 2.735	 16.87	 -11.4	 1.0	 84.88	 0	 79.2	 8.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.2;
	74265	 7.49	 2.13	 4.88	 -0.62	 1.0	 12.7	 1	 7.49	 7.49	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	74266	 12.7	 2.13	 4.88	 -0.62	 1.0	 16.98	 1	 12.7	 12.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	74266	 9.44	 2.13	 4.88	 -0.62	 1.0	 18.38	 0	 12.7	 6.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.7;
	74268	 5.03	 1.34	 3.07	 -0.39	 1.0	 8.0	 1	 5.03	 5.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	74268	 4.595	 1.34	 3.07	 -0.39	 1.0	 8.0	 0	 8.0	 1.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	74268	 8.0	 1.34	 3.07	 -0.39	 1.0	 8.45	 1	 8.0	 8.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	74268	 13.14	 3.92	 8.99	 -1.15	 1.0	 34.7	 0	 23.4	 2.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.4;
	74270	 18.07	 0.77	 4.77	 -3.23	 1.0	 22.74	 1	 18.07	 18.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.4;
	74270	 16.56	 0.795	 4.9	 -3.31	 1.0	 23.0	 1	 16.56	 16.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	74270	 23.0	 0.795	 4.9	 -3.31	 1.0	 24.33	 1	 23.0	 23.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	74271	 48.32	 1.99	 12.27	 -8.29	 1.0	 81.01	 1	 48.32	 48.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.6;
	74276	 90.64	 22.335	 51.2	 -6.53	 1.0	 194.54	 1	 90.64	 90.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	74277	 85.23	 22.335	 51.2	 -6.53	 1.0	 165.95	 0	 133.33	 37.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	74278	 117.94	 22.335	 51.2	 -6.53	 1.0	 151.3	 1	 117.94	 117.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 133.3333;
	74280	 100.14	 4.13	 25.5	 -17.24	 1.0	 175.27	 1	 100.14	 100.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 119.7;
	74282	 13.91	 0.795	 4.9	 -3.31	 1.0	 25.7	 0	 23.0	 4.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	74283	 13.95	 0.795	 4.9	 -3.31	 1.0	 23.0	 0	 23.0	 4.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	74284	 6.33	 1.675	 3.84	 -0.49	 1.0	 10.53	 1	 6.33	 6.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	74284	 6.27	 1.675	 3.84	 -0.49	 1.0	 14.34	 1	 6.27	 6.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	74284	 6.87	 1.675	 3.84	 -0.49	 1.0	 10.0	 0	 10.0	 3.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	74288	 7.52	 0.365	 2.24	 -1.51	 1.0	 11.53	 0	 10.5	 4.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	74289	 10.5	 0.365	 2.24	 -1.51	 1.0	 10.52	 1	 10.5	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
	74291	 9.36	 0.47	 2.88	 -1.94	 1.0	 15.12	 0	 13.5	 5.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	74292	 9.23	 0.415	 2.56	 -1.73	 1.0	 12.0	 1	 9.23	 9.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	74295	 17.56	 0.725	 4.47	 -3.02	 1.0	 25.5	 1	 17.56	 17.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	74296	 14.85	 0.725	 4.47	 -3.02	 1.0	 21.0	 1	 14.85	 14.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 21.0;
	74296	 15.01	 0.795	 4.9	 -3.31	 1.0	 29.73	 1	 15.01	 15.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	74296	 16.42	 0.795	 4.9	 -3.31	 1.0	 33.26	 0	 23.0	 9.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.0;
	74298	 12.64	 3.35	 7.68	 -0.98	 1.0	 20.95	 0	 20.0	 5.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	74298	 16.3	 3.35	 7.68	 -0.98	 1.0	 24.1	 1	 16.3	 16.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	74301	 9.94	 2.345	 5.38	 -0.69	 1.0	 14.0	 1	 9.94	 9.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	74302	 11.55	 2.345	 5.38	 -0.69	 1.0	 15.67	 1	 11.55	 11.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	74302	 8.855	 2.345	 5.38	 -0.69	 1.0	 14.0	 0	 14.0	 3.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.0;
	74303	 18.18	 0.775	 4.79	 -3.24	 1.0	 22.5	 1	 18.18	 18.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	74303	 17.29	 0.775	 4.79	 -3.24	 1.0	 26.35	 1	 17.29	 17.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.5;
	74305	 14.89	 0.0	 0.0	 0.0	 1.0	 19.82	 1	 14.89	 14.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	74305	 11.56	 0.0	 0.0	 0.0	 1.0	 15.9	 1	 11.56	 11.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.9;
	74307	 25.47	 4.625	 10.6	 -1.35	 1.0	 33.83	 1	 25.47	 25.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	74307	 19.015	 4.625	 10.6	 -1.35	 1.0	 38.12	 0	 27.6	 10.43	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	74307	 24.9	 4.625	 10.6	 -1.35	 1.0	 33.03	 1	 24.9	 24.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.6;
	74310	 88.0	 4.295	 26.52	 -17.93	 1.0	 157.4	 1	 88.0	 88.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.5;
	74313	 27.14	 5.16	 11.83	 -1.51	 1.0	 30.8	 1	 27.14	 27.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	74314	 15.21	 5.16	 11.83	 -1.51	 1.0	 36.86	 1	 15.21	 15.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	74316	 17.14	 5.16	 11.83	 -1.51	 1.0	 36.32	 1	 17.14	 17.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.8;
	74317	 6.64	 1.84	 4.22	 -0.54	 1.0	 11.2	 1	 6.64	 6.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	74317	 7.71	 1.84	 4.22	 -0.54	 1.0	 11.4	 0	 11.0	 4.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	74318	 5.41	 1.21	 2.78	 -0.36	 1.0	 8.74	 1	 5.41	 5.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.25;
	74318	 8.065	 1.84	 4.22	 -0.54	 1.0	 12.0	 0	 11.0	 5.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.0;
	74319	 5.28	 1.21	 2.78	 -0.36	 1.0	 10.48	 0	 7.25	 3.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.25;
	74322	 21.04	 4.415	 10.12	 -1.29	 1.0	 27.54	 1	 21.04	 21.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.35;
	74322	 22.05	 4.415	 10.12	 -1.29	 1.0	 27.61	 1	 22.05	 22.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 26.35;
	74324	 12.885	 3.325	 7.62	 -0.97	 1.0	 24.77	 0	 19.83	 5.94	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.8333;
	74324	 18.29	 3.325	 7.62	 -0.97	 1.0	 23.95	 1	 18.29	 18.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.83;
	74324	 19.83	 3.325	 7.62	 -0.97	 1.0	 21.17	 1	 19.83	 19.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.83;
	74328	 99.54	 31.69	 81.06	 -17.68	 1.0	 172.32	 1	 159.25	 39.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.25;
	74329	 116.35	 31.69	 81.06	 -17.68	 1.0	 230.37	 1	 159.25	 73.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 159.25;
	74332	 5.73	 1.51	 3.46	 -0.44	 1.0	 10.7	 1	 5.73	 5.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	74332	 6.36	 1.51	 3.46	 -0.44	 1.0	 9.0	 1	 6.36	 6.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	74333	 6.8	 1.385	 3.17	 -0.4	 1.0	 8.35	 1	 6.8	 6.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.25;
	74333	 4.14	 1.385	 3.17	 -0.4	 1.0	 8.35	 1	 4.14	 4.14	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.25;
	74334	 26.93	 1.38	 8.52	 -5.76	 1.0	 46.3	 1	 26.93	 26.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	74335	 8.155	 0.415	 2.56	 -1.73	 1.0	 13.05	 0	 12.0	 4.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	74335	 8.69	 0.47	 2.88	 -1.94	 1.0	 16.24	 1	 8.69	 8.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.5;
	74335	 11.06	 0.67	 4.15	 -2.81	 1.0	 19.5	 1	 11.06	 11.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 19.5;
	77187	 82.0	 17.59	 40.32	 -5.14	 1.0	 127.54	 1	 82.0	 82.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	77188	 65.45	 17.59	 40.32	 -5.14	 1.0	 131.59	 1	 65.45	 65.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	77189	 77.22	 17.59	 40.32	 -5.14	 1.0	 112.68	 1	 77.22	 77.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	77190	 89.78	 17.59	 40.32	 -5.14	 1.0	 152.33	 1	 89.78	 89.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	77191	 90.22	 17.59	 40.32	 -5.14	 1.0	 106.16	 1	 90.22	 90.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	77195	 47.27	 13.475	 34.46	 -7.51	 1.0	 74.66	 1	 67.7	 26.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.7;
	77196	 46.885	 13.475	 34.46	 -7.51	 1.0	 99.62	 1	 67.7	 26.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.7;
	77197	 45.855	 13.475	 34.46	 -7.51	 1.0	 71.03	 0	 67.7	 24.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.7;
	77199	 27.555	 7.93	 21.48	 -5.62	 1.0	 50.8	 0	 46.1	 9.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 46.1;
	77200	 4.35	 1.34	 3.07	 -0.39	 1.0	 8.0	 1	 4.35	 4.35	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	77200	 4.915	 1.34	 3.07	 -0.39	 1.0	 10.77	 0	 8.0	 1.83	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	77200	 5.32	 1.34	 3.07	 -0.39	 1.0	 8.09	 1	 5.32	 5.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.0;
	77204	 78.05	 3.67	 22.68	 -15.34	 1.0	 152.53	 0	 106.5	 49.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.5;
	77207	 5.79	 0.335	 2.07	 -1.4	 1.0	 10.43	 1	 5.79	 5.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.7;
	77207	 5.32	 0.33	 2.04	 -1.38	 1.0	 9.81	 0	 9.6	 1.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	77213	 104.855	 29.72	 80.52	 -21.08	 1.0	 210.11	 1	 172.8	 36.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.8;
	77216	 42.68	 10.47	 24.0	 -3.06	 1.0	 63.73	 0	 62.5	 22.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	77217	 43.2	 10.47	 24.0	 -3.06	 1.0	 89.36	 1	 43.2	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	77218	 35.53	 10.47	 24.0	 -3.06	 1.0	 86.66	 1	 35.53	 35.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	77219	 40.32	 10.47	 24.0	 -3.06	 1.0	 80.3	 1	 40.32	 40.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 62.5;
	77223	 83.19	 17.925	 41.09	 -5.24	 1.0	 133.57	 1	 83.19	 83.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	77224	 90.98	 17.925	 41.09	 -5.24	 1.0	 129.99	 1	 90.98	 90.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	77225	 107.0	 17.925	 41.09	 -5.24	 1.0	 138.51	 1	 107.0	 107.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	77226	 77.82	 17.925	 41.09	 -5.24	 1.0	 134.26	 0	 107.0	 48.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.0;
	77228	 8.42	 1.62	 3.72	 -0.48	 1.0	 11.12	 1	 8.42	 8.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.7;
	77229	 12.97	 2.78	 6.37	 -0.81	 1.0	 20.99	 1	 12.97	 12.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	77229	 12.38	 2.78	 6.37	 -0.81	 1.0	 16.83	 0	 16.6	 8.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	77229	 9.01	 2.78	 6.37	 -0.81	 1.0	 18.63	 1	 9.01	 9.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.6;
	77231	 5.015	 0.31	 1.92	 -1.3	 1.0	 9.0	 0	 9.0	 1.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	77231	 7.23	 0.345	 2.13	 -1.44	 1.0	 15.0	 1	 7.23	 7.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	77236	 57.44	 11.59	 26.57	 -3.39	 1.0	 100.27	 1	 57.44	 57.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.2;
	77237	 47.12	 11.59	 26.57	 -3.39	 1.0	 69.2	 1	 47.12	 47.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.2;
	77238	 54.18	 11.59	 26.57	 -3.39	 1.0	 79.62	 1	 54.18	 54.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 69.2;
	77243	 29.2	 6.205	 14.23	 -1.82	 1.0	 40.94	 1	 29.2	 29.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.06;
	77243	 37.06	 6.205	 14.23	 -1.82	 1.0	 42.19	 1	 37.06	 37.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.06;
	77244	 28.91	 6.205	 14.23	 -1.82	 1.0	 46.0	 1	 28.91	 28.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.06;
	77244	 27.91	 6.205	 14.23	 -1.82	 1.0	 43.13	 1	 27.91	 27.91	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.06;
	77245	 18.64	 6.205	 14.23	 -1.82	 1.0	 42.87	 1	 18.64	 18.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.06;
	77248	 41.13	 11.695	 31.69	 -8.3	 1.0	 73.76	 1	 68.0	 14.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 68.0;
	77250	 7.0	 0.345	 2.13	 -1.44	 1.0	 10.0	 1	 7.0	 7.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	77251	 7.22	 0.345	 2.13	 -1.44	 1.0	 12.65	 1	 7.22	 7.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	77252	 10.66	 2.43	 5.57	 -0.71	 1.0	 14.8	 1	 10.66	 10.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5167;
	77253	 14.52	 2.43	 5.57	 -0.71	 1.0	 18.5	 1	 14.52	 14.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5167;
	77253	 12.39	 2.43	 5.57	 -0.71	 1.0	 18.05	 1	 12.39	 12.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.52;
	77253	 8.81	 2.43	 5.57	 -0.71	 1.0	 16.3	 1	 8.81	 8.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5167;
	77253	 10.57	 2.43	 5.57	 -0.71	 1.0	 15.48	 1	 10.57	 10.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.5167;
	77253	 10.56	 2.43	 5.57	 -0.71	 1.0	 14.52	 1	 10.56	 10.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 14.52;
	77258	 368.17	 97.695	 264.69	 -69.3	 1.0	 634.74	 1	 568.0	 168.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 568.0;
	77259	 419.055	 97.695	 264.69	 -69.3	 1.0	 618.21	 1	 568.0	 270.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 568.0;
	77260	 332.125	 97.695	 264.69	 -69.3	 1.0	 690.12	 1	 568.0	 96.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 568.0;
	77261	 337.36	 97.695	 264.69	 -69.3	 1.0	 696.61	 1	 568.0	 106.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 568.0;
	77264	 5.785	 1.82	 4.66	 -1.02	 1.0	 9.21	 1	 9.15	 2.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.15;
	77264	 5.88	 1.82	 4.66	 -1.02	 1.0	 11.15	 1	 9.15	 2.61	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.15;
	77264	 5.965	 1.82	 4.66	 -1.02	 1.0	 11.3	 1	 9.15	 2.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.15;
	77264	 5.46	 1.82	 4.66	 -1.02	 1.0	 9.87	 0	 9.15	 1.77	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.15;
	77264	 5.97	 1.82	 4.66	 -1.02	 1.0	 10.44	 1	 9.15	 2.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.15;
	77264	 5.71	 1.82	 4.66	 -1.02	 1.0	 11.71	 1	 9.15	 2.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.15;
	77267	 57.69	 9.885	 22.66	 -2.89	 1.0	 64.27	 1	 57.69	 57.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	77268	 22.98	 5.06	 11.6	 -1.48	 1.0	 30.61	 1	 22.98	 22.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.2;
	77269	 21.98	 5.06	 11.6	 -1.48	 1.0	 40.42	 1	 21.98	 21.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.2;
	77270	 9.27	 1.61	 3.69	 -0.47	 1.0	 10.2	 1	 9.27	 9.27	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	77270	 6.63	 1.61	 3.69	 -0.47	 1.0	 10.69	 1	 6.63	 6.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	77270	 9.6	 1.61	 3.69	 -0.47	 1.0	 9.8	 1	 9.6	 9.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	77270	 7.33	 1.61	 3.69	 -0.47	 1.0	 10.79	 1	 7.33	 7.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	77274	 78.26	 17.835	 40.89	 -5.22	 1.0	 141.75	 1	 78.26	 78.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.48;
	77275	 75.25	 17.835	 40.89	 -5.22	 1.0	 106.48	 1	 75.25	 75.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.48;
	77276	 68.38	 17.835	 40.89	 -5.22	 1.0	 118.88	 1	 68.38	 68.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.48;
	77277	 70.01	 17.835	 40.89	 -5.22	 1.0	 119.04	 0	 106.48	 33.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.48;
	77278	 77.795	 17.835	 40.89	 -5.22	 1.0	 111.47	 0	 106.48	 49.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 106.48;
	77280	 78.36	 3.575	 22.05	 -14.9	 1.0	 124.52	 1	 78.36	 78.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.5;
	77286	 76.11	 19.9	 53.92	 -14.12	 1.0	 132.93	 1	 115.7	 36.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.7;
	77289	 180.65	 6.52	 40.26	 -27.22	 1.0	 259.11	 1	 180.65	 180.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 189.0;
	77290	 24.6	 8.475	 21.68	 -4.73	 1.0	 47.55	 1	 42.6	 6.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 42.6;
	77291	 5.48	 1.41	 3.23	 -0.41	 1.0	 8.4	 1	 5.48	 5.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	77291	 8.4	 1.41	 3.23	 -0.41	 1.0	 10.53	 1	 8.4	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	77291	 8.4	 1.41	 3.23	 -0.41	 1.0	 8.66	 1	 8.4	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	77291	 5.54	 1.41	 3.23	 -0.41	 1.0	 8.82	 0	 8.4	 2.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	77291	 6.76	 1.41	 3.23	 -0.41	 1.0	 9.87	 1	 6.76	 6.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	77291	 8.2	 1.41	 3.23	 -0.41	 1.0	 8.59	 1	 8.2	 8.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	77294	 4.265	 1.255	 2.88	 -0.37	 1.0	 8.48	 0	 7.5	 1.03	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	77294	 15.27	 4.525	 10.37	 -1.32	 1.0	 30.17	 0	 27.0	 3.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	77294	 22.54	 4.525	 10.37	 -1.32	 1.0	 29.92	 1	 22.54	 22.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 27.0;
	80085	 55.75	 16.015	 40.97	 -8.94	 1.0	 93.04	 0	 80.5	 31.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.5;
	80091	 70.425	 20.83	 53.28	 -11.62	 1.0	 141.5	 1	 104.67	 36.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.6667;
	80092	 71.535	 20.83	 53.28	 -11.62	 1.0	 135.58	 1	 104.67	 38.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.67;
	80093	 65.545	 20.83	 53.28	 -11.62	 1.0	 120.75	 1	 104.67	 26.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.67;
	80094	 58.895	 20.83	 53.28	 -11.62	 1.0	 153.12	 1	 104.67	 13.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.67;
	80095	 78.375	 20.83	 53.28	 -11.62	 1.0	 120.22	 1	 104.67	 52.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.6667;
	80096	 64.215	 20.83	 53.28	 -11.62	 1.0	 111.0	 1	 104.67	 23.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 104.67;
	80097	 67.99	 18.91	 48.36	 -10.54	 1.0	 132.54	 0	 95.0	 40.98	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	80098	 68.18	 18.91	 48.36	 -10.54	 1.0	 125.63	 1	 95.0	 41.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	80099	 67.41	 18.91	 48.36	 -10.54	 1.0	 97.01	 1	 95.0	 39.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.0;
	80100	 6.67	 0.0	 0.0	 0.0	 1.0	 12.76	 1	 6.67	 6.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.5;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  13.233000	 838.720000;
	2	 0.0	 0.0	 3	   0.001000	  17.183000	 838.720000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.617000	 662.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.261000	 662.550000;
	2	 0.0	 0.0	 3	   0.001000	  15.711000	 662.550000;
	2	 0.0	 0.0	 3	   0.001000	  15.154000	 662.550000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   8.000000	 1000.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.734000	 733.350000;
	2	 0.0	 0.0	 3	   0.001000	  14.977000	 733.350000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.550000	 1403.470000;
	2	 0.0	 0.0	 3	   0.002000	  20.062000	 1403.470000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.396000	 692.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.226000	 731.700000;
	2	 0.0	 0.0	 3	   0.001000	  15.513000	 656.550000;
	2	 0.0	 0.0	 3	   0.001000	  15.163000	 741.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.937000	 741.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.249000	 741.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.063000	 741.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  13.771000	 726.900000;
	2	 0.0	 0.0	 3	   0.001000	  14.554000	 726.900000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.673000	 949.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.435000	 949.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.186000	 949.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.235000	 639.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.640000	 925.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.958000	 925.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.316000	 925.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.179000	 813.220000;
	2	 0.0	 0.0	 3	   0.001000	  13.515000	 813.220000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.643000	 742.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.370000	 742.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.653000	 742.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.262000	 972.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.426000	 617.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.532000	 617.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.149000	 617.100000;
	2	 0.0	 0.0	 3	   0.001000	  13.793000	 617.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.308000	 839.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.285000	 839.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.998000	 651.700000;
	2	 0.0	 0.0	 3	   0.001000	  17.414000	 651.700000;
	2	 0.0	 0.0	 3	   0.002000	  18.809000	 651.700000;
	2	 0.0	 0.0	 3	   0.001000	  15.898000	 651.700000;
	2	 0.0	 0.0	 3	   0.001000	  15.559000	 651.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.002000	 651.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.012000	 944.700000;
	2	 0.0	 0.0	 3	   0.001000	  17.959000	 944.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.438000	 944.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.059000	 644.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.332000	 644.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.019000	 644.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.063000	 644.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.325000	 832.950000;
	2	 0.0	 0.0	 3	   0.001000	  16.139000	 832.950000;
	2	 0.0	 0.0	 3	   0.001000	  16.886000	 832.950000;
	2	 0.0	 0.0	 3	   0.001000	  17.238000	 832.950000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.460000	 799.720000;
	2	 0.0	 0.0	 3	   0.001000	  16.410000	 799.720000;
	2	 0.0	 0.0	 3	   0.002000	  19.195000	 850.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.491000	 850.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.212000	 850.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.441000	 746.550000;
	2	 0.0	 0.0	 3	   0.002000	  17.869000	 746.550000;
	2	 0.0	 0.0	 3	   0.001000	  15.200000	 746.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.116000	 746.550000;
	2	 0.0	 0.0	 3	   0.001000	  14.545000	 746.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.145000	 746.550000;
	2	 0.0	 0.0	 3	   0.001000	  15.733000	 616.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.003000	 619.650000;
	2	 0.0	 0.0	 3	   0.001000	  15.930000	 636.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.706000	 815.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.893000	 815.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.248000	 962.250000;
	2	 0.0	 0.0	 3	   0.001000	  18.197000	 962.250000;
	2	 0.0	 0.0	 3	   0.002000	  16.200000	 1359.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.803000	 715.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.993000	 956.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.150000	 956.200000;
	2	 0.0	 0.0	 3	   0.001000	  18.417000	 956.200000;
	2	 0.0	 0.0	 3	   0.001000	  16.800000	 642.900000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.692000	 649.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.790000	 649.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.813000	 682.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.867000	 682.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.343000	 682.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.240000	 653.630000;
	2	 0.0	 0.0	 3	   0.001000	  17.140000	 681.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.609000	 653.630000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.557000	 918.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.053000	 918.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.717000	 918.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.231000	 674.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.959000	 670.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.500000	 670.950000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.627000	 865.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.817000	 865.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.267000	 865.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.371000	 673.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.209000	 636.900000;
	2	 0.0	 0.0	 3	   0.001000	  17.403000	 636.900000;
	2	 0.0	 0.0	 3	   0.001000	  16.786000	 654.650000;
	2	 0.0	 0.0	 3	   0.002000	  18.778000	 654.650000;
	2	 0.0	 0.0	 3	   0.002000	  20.947000	 654.650000;
	2	 0.0	 0.0	 3	   0.001000	  16.274000	 636.900000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.046000	 666.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.756000	 674.700000;
	2	 0.0	 0.0	 3	   0.002000	  18.402000	 674.700000;
	2	 0.0	 0.0	 3	   0.002000	  18.890000	 674.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.146000	 730.420000;
	2	 0.0	 0.0	 3	   0.001000	  15.896000	 730.420000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.154000	 611.600000;
	2	 0.0	 0.0	 3	   0.002000	  18.498000	 611.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.598000	 611.600000;
	2	 0.0	 0.0	 3	   0.001000	  17.135000	 611.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.341000	 611.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.086000	 611.600000;
	2	 0.0	 0.0	 3	   0.002000	  17.623000	 641.750000;
	2	 0.0	 0.0	 3	   0.002000	  19.301000	 641.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.874000	 641.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.545000	 641.750000;
	2	 0.0	 0.0	 3	   0.001000	  17.458000	 641.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.266000	 641.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.678000	 910.500000;
	2	 0.0	 0.0	 3	   0.001000	  14.354000	 910.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.801000	 910.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.151000	 910.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.629000	 953.810000;
	2	 0.0	 0.0	 3	   0.002000	  19.686000	 953.810000;
	2	 0.0	 0.0	 3	   0.002000	  19.635000	 953.810000;
	2	 0.0	 0.0	 3	   0.002000	  20.658000	 953.810000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.858000	 909.850000;
	2	 0.0	 0.0	 3	   0.002000	  18.632000	 909.850000;
	2	 0.0	 0.0	 3	   0.001000	  16.334000	 909.850000;
	2	 0.0	 0.0	 3	   0.002000	  17.624000	 677.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.369000	 677.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.947000	 677.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.067000	 620.250000;
	2	 0.0	 0.0	 3	   0.002000	  18.763000	 620.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.562000	 237.470000;
	2	 0.0	 0.0	 3	   0.001000	  15.065000	 639.600000;
	2	 0.0	 0.0	 3	   0.002000	  17.540000	 639.600000;
	2	 0.0	 0.0	 3	   0.002000	  19.424000	 697.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.043000	 697.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.404000	 1707.520000;
	2	 0.0	 0.0	 3	   0.001000	  18.655000	 1707.520000;
	2	 0.0	 0.0	 3	   0.002000	  22.808000	 1707.520000;
	2	 0.0	 0.0	 3	   0.001000	  18.183000	 939.150000;
	2	 0.0	 0.0	 3	   0.001000	  17.676000	 939.150000;
	2	 0.0	 0.0	 3	   0.001000	  17.124000	 939.150000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.081000	 670.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.670000	 670.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.941000	 670.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.035000	 674.850000;
	2	 0.0	 0.0	 3	   0.002000	  17.640000	 674.850000;
	2	 0.0	 0.0	 3	   0.002000	  17.887000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  17.376000	 674.850000;
	2	 0.0	 0.0	 3	   0.002000	  18.232000	 237.990000;
	2	 0.0	 0.0	 3	   0.002000	  14.632000	 237.990000;
	2	 0.0	 0.0	 3	   0.002000	  22.637000	 237.990000;
	2	 0.0	 0.0	 3	   0.001000	  17.556000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  19.127000	 670.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.616000	 917.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.844000	 917.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.983000	 917.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.506000	 670.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.290000	 676.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.674000	 656.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.487000	 656.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.769000	 656.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.136000	 768.050000;
	2	 0.0	 0.0	 3	   0.001000	  14.819000	 768.050000;
	2	 0.0	 0.0	 3	   0.002000	  18.445000	 768.050000;
	2	 0.0	 0.0	 3	   0.002000	  18.449000	 621.380000;
	2	 0.0	 0.0	 3	   0.002000	  18.976000	 621.380000;
	2	 0.0	 0.0	 3	   0.001000	  16.919000	 641.100000;
	2	 0.0	 0.0	 3	   0.002000	  17.840000	 641.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.698000	 650.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.365000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.675000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  16.282000	 236.240000;
	2	 0.0	 0.0	 3	   0.002000	  16.606000	 236.240000;
	2	 0.0	 0.0	 3	   0.002000	  20.407000	 236.240000;
	2	 0.0	 0.0	 3	   0.002000	  19.504000	 236.240000;
	2	 0.0	 0.0	 3	   0.002000	  17.067000	 236.240000;
	2	 0.0	 0.0	 3	   0.002000	  14.757000	 236.240000;
	2	 0.0	 0.0	 3	   0.001000	  17.912000	 971.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.275000	 927.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.028000	 927.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.136000	 927.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.648000	 691.830000;
	2	 0.0	 0.0	 3	   0.002000	  20.091000	 691.830000;
	2	 0.0	 0.0	 3	   0.001000	  14.927000	 691.830000;
	2	 0.0	 0.0	 3	   0.002000	  20.285000	 691.830000;
	2	 0.0	 0.0	 3	   0.001000	  16.331000	 691.830000;
	2	 0.0	 0.0	 3	   0.002000	  19.930000	 624.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.661000	 624.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.127000	 667.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.845000	 667.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.754000	 667.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.779000	 693.900000;
	2	 0.0	 0.0	 3	   0.001000	  17.624000	 693.900000;
	2	 0.0	 0.0	 3	   0.001000	  16.739000	 645.600000;
	2	 0.0	 0.0	 3	   0.002000	  19.226000	 627.450000;
	2	 0.0	 0.0	 3	   0.002000	  17.650000	 627.450000;
	2	 0.0	 0.0	 3	   0.001000	  15.300000	 627.450000;
	2	 0.0	 0.0	 3	   0.002000	  17.976000	 648.450000;
	2	 0.0	 0.0	 3	   0.001000	  16.580000	 648.450000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.443000	 673.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.720000	 673.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.110000	 641.100000;
	2	 0.0	 0.0	 3	   0.002000	  17.674000	 675.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.955000	 762.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.720000	 762.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.337000	 762.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.617000	 762.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.399000	 683.810000;
	2	 0.0	 0.0	 3	   0.002000	  18.692000	 683.810000;
	2	 0.0	 0.0	 3	   0.002000	  18.361000	 683.810000;
	2	 0.0	 0.0	 3	   0.002000	  19.691000	 683.810000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.683000	 657.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.424000	 641.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.083000	 641.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.177000	 699.900000;
	2	 0.0	 0.0	 3	   0.002000	  18.784000	 699.900000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.561000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.949000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.961000	 618.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.999000	 627.150000;
	2	 0.0	 0.0	 3	   0.001000	  15.624000	 627.150000;
	2	 0.0	 0.0	 3	   0.002000	  18.798000	 673.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.608000	 237.900000;
	2	 0.0	 0.0	 3	   0.002000	  17.739000	 237.900000;
	2	 0.0	 0.0	 3	   0.001000	  16.310000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  15.408000	 637.350000;
	2	 0.0	 0.0	 3	   0.002000	  18.081000	 636.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.293000	 3859.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.750000	 3859.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.920000	 949.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.112000	 949.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.553000	 949.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.676000	 949.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.158000	 949.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.814000	 949.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.485000	 674.850000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.726000	 641.300000;
	2	 0.0	 0.0	 3	   0.001000	  16.694000	 641.300000;
	2	 0.0	 0.0	 3	   0.002000	  17.710000	 641.300000;
	2	 0.0	 0.0	 3	   0.002000	  17.796000	 669.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.476000	 670.950000;
	2	 0.0	 0.0	 3	   0.001000	  15.159000	 690.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.889000	 690.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.589000	 674.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.344000	 657.600000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.963000	 669.150000;
	2	 0.0	 0.0	 3	   0.001000	  17.187000	 669.150000;
	2	 0.0	 0.0	 3	   0.001000	  17.160000	 877.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.605000	 755.850000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.896000	 750.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.737000	 750.300000;
	2	 0.0	 0.0	 3	   0.001000	  17.669000	 750.300000;
	2	 0.0	 0.0	 3	   0.001000	  17.430000	 690.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.859000	 658.350000;
	2	 0.0	 0.0	 3	   0.001000	  15.784000	 675.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.458000	 673.650000;
	2	 0.0	 0.0	 3	   0.002000	  18.630000	 673.650000;
	2	 0.0	 0.0	 3	   0.001000	  16.124000	 612.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.488000	 612.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.197000	 612.600000;
	2	 0.0	 0.0	 3	   0.002000	  20.106000	 612.600000;
	2	 0.0	 0.0	 3	   0.002000	  18.616000	 612.600000;
	2	 0.0	 0.0	 3	   0.002000	  17.556000	 612.600000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.421000	 612.400000;
	2	 0.0	 0.0	 3	   0.002000	  17.635000	 612.400000;
	2	 0.0	 0.0	 3	   0.001000	  14.863000	 612.400000;
	2	 0.0	 0.0	 3	   0.001000	  16.725000	 612.400000;
	2	 0.0	 0.0	 3	   0.001000	  16.958000	 612.400000;
	2	 0.0	 0.0	 3	   0.002000	  18.816000	 612.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.516000	 704.850000;
	2	 0.0	 0.0	 3	   0.001000	  17.387000	 704.850000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.971000	 944.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.054000	 944.200000;
	2	 0.0	 0.0	 3	   0.002000	  21.192000	 944.200000;
	2	 0.0	 0.0	 3	   0.002000	  17.593000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  21.470000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.557000	 3859.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.766000	 643.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.940000	 641.850000;
	2	 0.0	 0.0	 3	   0.001000	  16.990000	 641.850000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.028000	 651.530000;
	2	 0.0	 0.0	 3	   0.001000	  15.569000	 651.530000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.011000	 686.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.674000	 701.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.519000	 701.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.464000	 701.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.006000	 701.250000;
	2	 0.0	 0.0	 3	   0.002000	  17.994000	 701.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.788000	 701.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.821000	 618.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.913000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.591000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.084000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.957000	 750.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.565000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.435000	 687.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.764000	 712.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.315000	 674.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.324000	 833.700000;
	2	 0.0	 0.0	 3	   0.002000	  19.270000	 833.700000;
	2	 0.0	 0.0	 3	   0.001000	  17.843000	 833.700000;
	2	 0.0	 0.0	 3	   0.002000	  19.727000	 833.700000;
	2	 0.0	 0.0	 3	   0.002000	  19.921000	 833.700000;
	2	 0.0	 0.0	 3	   0.003000	  24.346000	 237.020000;
	2	 0.0	 0.0	 3	   0.001000	  17.213000	 634.950000;
	2	 0.0	 0.0	 3	   0.001000	  16.415000	 634.950000;
	2	 0.0	 0.0	 3	   0.001000	  14.645000	 615.400000;
	2	 0.0	 0.0	 3	   0.001000	  14.624000	 615.400000;
	2	 0.0	 0.0	 3	   0.002000	  18.134000	 615.400000;
	2	 0.0	 0.0	 3	   0.001000	  17.364000	 636.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.965000	 636.600000;
	2	 0.0	 0.0	 3	   0.002000	  18.147000	 690.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.470000	 801.530000;
	2	 0.0	 0.0	 3	   0.002000	  19.021000	 801.530000;
	2	 0.0	 0.0	 3	   0.001000	  15.819000	 801.530000;
	2	 0.0	 0.0	 3	   0.002000	  18.507000	 801.530000;
	2	 0.0	 0.0	 3	   0.001000	  16.864000	 653.400000;
	2	 0.0	 0.0	 3	   0.001000	  16.951000	 674.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.854000	 623.030000;
	2	 0.0	 0.0	 3	   0.001000	  16.726000	 623.030000;
	2	 0.0	 0.0	 3	   0.002000	  18.400000	 610.050000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.852000	 1113.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.775000	 672.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.633000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  16.107000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  16.733000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  14.971000	 637.350000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.333000	 694.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.046000	 694.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.538000	 694.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.597000	 694.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.524000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  13.992000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.383000	 636.970000;
	2	 0.0	 0.0	 3	   0.001000	  15.916000	 636.970000;
	2	 0.0	 0.0	 3	   0.001000	  15.916000	 666.970000;
	2	 0.0	 0.0	 3	   0.002000	  19.079000	 666.970000;
	2	 0.0	 0.0	 3	   0.002000	  17.758000	 666.970000;
	2	 0.0	 0.0	 3	   0.001000	  16.740000	 666.970000;
	2	 0.0	 0.0	 3	   0.001000	  16.392000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.264000	 690.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.941000	 690.750000;
	2	 0.0	 0.0	 3	   0.001000	  17.565000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  19.572000	 690.750000;
	2	 0.0	 0.0	 3	   0.001000	  17.325000	 722.800000;
	2	 0.0	 0.0	 3	   0.002000	  19.897000	 722.800000;
	2	 0.0	 0.0	 3	   0.002000	  18.114000	 722.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.235000	 669.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.406000	 618.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.861000	 679.400000;
	2	 0.0	 0.0	 3	   0.001000	  16.734000	 679.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.182000	 679.400000;
	2	 0.0	 0.0	 3	   0.001000	  16.100000	 618.600000;
	2	 0.0	 0.0	 3	   0.002000	  18.361000	 633.150000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.774000	 623.330000;
	2	 0.0	 0.0	 3	   0.001000	  15.176000	 623.330000;
	2	 0.0	 0.0	 3	   0.001000	  16.486000	 672.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.540000	 627.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.167000	 627.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.127000	 669.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.700000	 1093.650000;
	2	 0.0	 0.0	 3	   0.001000	  17.738000	 1093.650000;
	2	 0.0	 0.0	 3	   0.001000	  18.773000	 1093.650000;
	2	 0.0	 0.0	 3	   0.002000	  20.064000	 1093.650000;
	2	 0.0	 0.0	 3	   0.001000	  17.189000	 615.900000;
	2	 0.0	 0.0	 3	   0.002000	  18.430000	 669.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.121000	 621.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.086000	 621.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.704000	 621.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.254000	 645.030000;
	2	 0.0	 0.0	 3	   0.002000	  18.747000	 645.030000;
	2	 0.0	 0.0	 3	   0.001000	  15.776000	 645.030000;
	2	 0.0	 0.0	 3	   0.001000	  16.908000	 645.030000;
	2	 0.0	 0.0	 3	   0.002000	  17.581000	 645.030000;
	2	 0.0	 0.0	 3	   0.001000	  14.521000	 645.030000;
	2	 0.0	 0.0	 3	   0.002000	  19.490000	 669.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.693000	 927.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.325000	 927.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.756000	 807.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.525000	 687.750000;
	2	 0.0	 0.0	 3	   0.001000	  17.194000	 615.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.202000	 682.280000;
	2	 0.0	 0.0	 3	   0.001000	  17.560000	 682.280000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.487000	 902.700000;
	2	 0.0	 0.0	 3	   0.001000	  15.593000	 902.700000;
	2	 0.0	 0.0	 3	   0.001000	  17.648000	 902.700000;
	2	 0.0	 0.0	 3	   0.002000	  17.817000	 669.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.116000	 915.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.387000	 915.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.595000	 915.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.097000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.222000	 614.400000;
	2	 0.0	 0.0	 3	   0.002000	  18.327000	 614.400000;
	2	 0.0	 0.0	 3	   0.001000	  15.892000	 614.400000;
	2	 0.0	 0.0	 3	   0.002000	  17.803000	 614.400000;
	2	 0.0	 0.0	 3	   0.001000	  16.482000	 658.050000;
	2	 0.0	 0.0	 3	   0.001000	  16.581000	 613.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.160000	 613.200000;
	2	 0.0	 0.0	 3	   0.001000	  15.880000	 622.460000;
	2	 0.0	 0.0	 3	   0.001000	  15.246000	 622.460000;
	2	 0.0	 0.0	 3	   0.001000	  14.720000	 622.460000;
	2	 0.0	 0.0	 3	   0.002000	  18.702000	 622.460000;
	2	 0.0	 0.0	 3	   0.001000	  14.653000	 623.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.569000	 623.250000;
	2	 0.0	 0.0	 3	   0.001000	  15.961000	 641.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.751000	 641.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.513000	 641.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.077000	 1080.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.962000	 1080.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.179000	 1080.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.288000	 1080.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.150000	 1080.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.527000	 1080.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.782000	 667.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.523000	 667.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.602000	 621.220000;
	2	 0.0	 0.0	 3	   0.001000	  16.778000	 621.220000;
	2	 0.0	 0.0	 3	   0.002000	  19.184000	 672.300000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.060000	 890.700000;
	2	 0.0	 0.0	 3	   0.002000	  19.183000	 890.700000;
	2	 0.0	 0.0	 3	   0.000000	   8.000000	 1000.000000;
	2	 0.0	 0.0	 3	   0.000000	   8.000000	 1000.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.528000	 620.100000;
	2	 0.0	 0.0	 3	   0.002000	  18.883000	 620.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.029000	 633.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.709000	 3859.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.156000	 1057.660000;
	2	 0.0	 0.0	 3	   0.002000	  20.258000	 1050.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.233000	 1050.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.697000	 717.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.768000	 717.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.130000	 717.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.311000	 945.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.735000	 945.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.360000	 914.950000;
	2	 0.0	 0.0	 3	   0.001000	  18.401000	 914.950000;
	2	 0.0	 0.0	 3	   0.002000	  19.487000	 914.950000;
	2	 0.0	 0.0	 3	   0.001000	  17.740000	 762.300000;
	2	 0.0	 0.0	 3	   0.001000	  17.403000	 762.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.447000	 762.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.324000	 762.300000;
	2	 0.0	 0.0	 3	   0.002000	  20.281000	 762.300000;
	2	 0.0	 0.0	 3	   0.001000	  17.323000	 762.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.189000	 658.650000;
	2	 0.0	 0.0	 3	   0.001000	  16.694000	 653.700000;
	2	 0.0	 0.0	 3	   0.002000	  18.572000	 653.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.566000	 653.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.768000	 632.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.663000	 632.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.018000	 1011.600000;
	2	 0.0	 0.0	 3	   0.002000	  19.863000	 1011.600000;
	2	 0.0	 0.0	 3	   0.001000	  18.455000	 1011.600000;
	2	 0.0	 0.0	 3	   0.002000	  19.012000	 669.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.044000	 647.100000;
	2	 0.0	 0.0	 3	   0.002000	  17.636000	 647.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.198000	 647.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.037000	 686.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.867000	 645.190000;
	2	 0.0	 0.0	 3	   0.001000	  15.306000	 645.190000;
	2	 0.0	 0.0	 3	   0.001000	  16.511000	 645.190000;
	2	 0.0	 0.0	 3	   0.002000	  17.658000	 645.190000;
	2	 0.0	 0.0	 3	   0.001000	  15.556000	 661.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.618000	 661.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.661000	 661.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.266000	 688.350000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.829000	 690.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.750000	 800.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.752000	 800.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.071000	 800.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.020000	 800.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.259000	 800.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.069000	 800.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.968000	 610.800000;
	2	 0.0	 0.0	 3	   0.001000	  16.057000	 679.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.477000	 679.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.570000	 859.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.503000	 859.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.333000	 859.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.133000	 859.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.381000	 859.200000;
	2	 0.0	 0.0	 3	   0.001000	  15.753000	 859.200000;
	2	 0.0	 0.0	 3	   0.002000	  17.823000	 638.550000;
	2	 0.0	 0.0	 3	   0.002000	  18.017000	 638.550000;
	2	 0.0	 0.0	 3	   0.001000	  18.676000	 1099.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.727000	 1099.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.349000	 610.950000;
	2	 0.0	 0.0	 3	   0.001000	  14.765000	 674.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.211000	 635.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.670000	 673.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.160000	 688.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.190000	 688.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.073000	 236.560000;
	2	 0.0	 0.0	 3	   0.002000	  18.859000	 236.560000;
	2	 0.0	 0.0	 3	   0.002000	  17.970000	 236.560000;
	2	 0.0	 0.0	 3	   0.002000	  22.315000	 236.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.566000	 236.400000;
	2	 0.0	 0.0	 3	   0.001000	  17.327000	 630.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.679000	 614.250000;
	2	 0.0	 0.0	 3	   0.001000	  15.160000	 614.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.149000	 690.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.797000	 613.350000;
	2	 0.0	 0.0	 3	   0.002000	  17.568000	 637.350000;
	2	 0.0	 0.0	 3	   0.001000	  16.664000	 637.350000;
	2	 0.0	 0.0	 3	   0.002000	  18.805000	 616.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.810000	 616.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.101000	 616.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.548000	 879.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.760000	 879.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.365000	 879.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.171000	 919.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.195000	 919.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.503000	 919.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.742000	 919.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.786000	 630.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.202000	 627.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.359000	 674.850000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.553000	 636.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.530000	 636.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.986000	 673.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.052000	 895.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.078000	 895.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.125000	 895.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.317000	 673.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.673000	 619.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.224000	 619.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.404000	 630.220000;
	2	 0.0	 0.0	 3	   0.001000	  17.076000	 630.220000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.856000	 683.010000;
	2	 0.0	 0.0	 3	   0.001000	  17.363000	 683.010000;
	2	 0.0	 0.0	 3	   0.001000	  16.887000	 683.010000;
	2	 0.0	 0.0	 3	   0.002000	  18.498000	 683.010000;
	2	 0.0	 0.0	 3	   0.001000	  17.591000	 683.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.503000	 722.400000;
	2	 0.0	 0.0	 3	   0.002000	  21.078000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  16.365000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  16.532000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  16.535000	 614.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.188000	 627.550000;
	2	 0.0	 0.0	 3	   0.001000	  14.618000	 627.550000;
	2	 0.0	 0.0	 3	   0.001000	  17.172000	 627.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.279000	 614.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.190000	 614.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.703000	 651.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.315000	 616.800000;
	2	 0.0	 0.0	 3	   0.001000	  14.952000	 616.800000;
	2	 0.0	 0.0	 3	   0.002000	  18.409000	 616.800000;
	2	 0.0	 0.0	 3	   0.001000	  17.251000	 616.800000;
	2	 0.0	 0.0	 3	   0.001000	  16.834000	 674.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.487000	 615.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.741000	 615.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.668000	 615.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.739000	 615.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.455000	 708.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.788000	 708.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.414000	 674.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.900000	 634.650000;
	2	 0.0	 0.0	 3	   0.001000	  17.113000	 634.650000;
	2	 0.0	 0.0	 3	   0.002000	  18.068000	 634.650000;
	2	 0.0	 0.0	 3	   0.002000	  18.322000	 634.650000;
	2	 0.0	 0.0	 3	   0.002000	  18.382000	 673.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.497000	 673.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.659000	 673.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.465000	 673.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.279000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  17.389000	 616.800000;
	2	 0.0	 0.0	 3	   0.001000	  16.180000	 616.800000;
	2	 0.0	 0.0	 3	   0.001000	  16.866000	 616.800000;
	2	 0.0	 0.0	 3	   0.001000	  16.574000	 616.800000;
	2	 0.0	 0.0	 3	   0.002000	  20.449000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.335000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  19.509000	 670.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.111000	 944.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.910000	 944.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.607000	 944.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.643000	 894.480000;
	2	 0.0	 0.0	 3	   0.002000	  19.712000	 894.480000;
	2	 0.0	 0.0	 3	   0.002000	  19.413000	 894.480000;
	2	 0.0	 0.0	 3	   0.002000	  19.989000	 894.480000;
	2	 0.0	 0.0	 3	   0.001000	  15.222000	 894.480000;
	2	 0.0	 0.0	 3	   0.001000	  16.247000	 627.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.373000	 927.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.417000	 927.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.817000	 611.160000;
	2	 0.0	 0.0	 3	   0.002000	  17.426000	 611.160000;
	2	 0.0	 0.0	 3	   0.001000	  15.309000	 611.160000;
	2	 0.0	 0.0	 3	   0.001000	  15.235000	 611.160000;
	2	 0.0	 0.0	 3	   0.002000	  17.699000	 611.160000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.337000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  17.105000	 674.850000;
	2	 0.0	 0.0	 3	   0.001000	  17.261000	 666.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.252000	 675.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.990000	 675.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.667000	 675.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.155000	 675.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.747000	 615.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.879000	 615.750000;
	2	 0.0	 0.0	 3	   0.001000	  17.671000	 754.800000;
	2	 0.0	 0.0	 3	   0.002000	  22.218000	 754.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.788000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  21.243000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  18.241000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.629000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.806000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  20.353000	 629.400000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.361000	 879.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.793000	 879.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.574000	 879.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.702000	 739.880000;
	2	 0.0	 0.0	 3	   0.002000	  20.545000	 739.880000;
	2	 0.0	 0.0	 3	   0.002000	  20.907000	 960.280000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.094000	 1057.390000;
	2	 0.0	 0.0	 3	   0.002000	  21.577000	 1057.390000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.126000	 663.600000;
	2	 0.0	 0.0	 3	   0.002000	  20.774000	 663.600000;
	2	 0.0	 0.0	 3	   0.002000	  20.024000	 663.600000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.570000	 636.110000;
	2	 0.0	 0.0	 3	   0.002000	  20.837000	 636.110000;
	2	 0.0	 0.0	 3	   0.002000	  19.499000	 636.110000;
	2	 0.0	 0.0	 3	   0.002000	  18.626000	 636.110000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.210000	 868.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.270000	 868.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.448000	 868.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.718000	 1083.830000;
	2	 0.0	 0.0	 3	   0.002000	  18.057000	 636.110000;
	2	 0.0	 0.0	 3	   0.002000	  19.094000	 636.110000;
	2	 0.0	 0.0	 3	   0.002000	  20.889000	 636.110000;
	2	 0.0	 0.0	 3	   0.002000	  19.119000	 636.110000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.597000	 966.400000;
	2	 0.0	 0.0	 3	   0.002000	  23.143000	 966.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.235000	 966.400000;
	2	 0.0	 0.0	 3	   0.002000	  21.149000	 966.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.225000	 966.400000;
	2	 0.0	 0.0	 3	   0.002000	  21.389000	 966.400000;
	2	 0.0	 0.0	 3	   0.002000	  21.508000	 711.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.135000	 711.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.692000	 711.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.550000	 822.930000;
	2	 0.0	 0.0	 3	   0.002000	  20.623000	 822.930000;
	2	 0.0	 0.0	 3	   0.002000	  18.435000	 822.930000;
	2	 0.0	 0.0	 3	   0.002000	  20.393000	 822.930000;
	2	 0.0	 0.0	 3	   0.002000	  19.938000	 822.930000;
	2	 0.0	 0.0	 3	   0.002000	  21.320000	 779.700000;
	2	 0.0	 0.0	 3	   0.002000	  19.667000	 727.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.326000	 727.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.229000	 799.200000;
	2	 0.0	 0.0	 3	   0.002000	  21.180000	 799.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.016000	 799.200000;
	2	 0.0	 0.0	 3	   0.002000	  20.199000	 799.200000;
	2	 0.0	 0.0	 3	   0.002000	  22.477000	 799.200000;
	2	 0.0	 0.0	 3	   0.002000	  20.992000	 799.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.399000	 744.700000;
	2	 0.0	 0.0	 3	   0.002000	  20.385000	 744.700000;
	2	 0.0	 0.0	 3	   0.002000	  20.524000	 744.700000;
	2	 0.0	 0.0	 3	   0.002000	  21.637000	 744.700000;
	2	 0.0	 0.0	 3	   0.002000	  22.461000	 744.700000;
	2	 0.0	 0.0	 3	   0.002000	  20.371000	 744.700000;
	2	 0.0	 0.0	 3	   0.002000	  24.477000	 932.350000;
	2	 0.0	 0.0	 3	   0.002000	  22.988000	 932.350000;
	2	 0.0	 0.0	 3	   0.002000	  20.899000	 932.350000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.954000	 694.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.016000	 694.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.214000	 694.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.813000	 694.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.580000	 689.720000;
	2	 0.0	 0.0	 3	   0.002000	  21.040000	 689.720000;
	2	 0.0	 0.0	 3	   0.002000	  19.392000	 689.720000;
	2	 0.0	 0.0	 3	   0.002000	  21.211000	 689.720000;
	2	 0.0	 0.0	 3	   0.002000	  21.918000	 689.720000;
	2	 0.0	 0.0	 3	   0.002000	  18.148000	 689.720000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.397000	 900.300000;
	2	 0.0	 0.0	 3	   0.002000	  21.078000	 900.300000;
	2	 0.0	 0.0	 3	   0.002000	  19.456000	 900.300000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.807000	 772.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.989000	 772.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.373000	 692.250000;
	2	 0.0	 0.0	 3	   0.002000	  22.141000	 692.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.993000	 692.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.385000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.306000	 690.750000;
	2	 0.0	 0.0	 3	   0.002000	  19.608000	 640.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.534000	 640.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.518000	 640.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.428000	 640.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.770000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.171000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  18.507000	 611.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.766000	 611.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.064000	 672.180000;
	2	 0.0	 0.0	 3	   0.002000	  20.422000	 730.050000;
	2	 0.0	 0.0	 3	   0.002000	  20.014000	 672.180000;
	2	 0.0	 0.0	 3	   0.002000	  19.297000	 672.180000;
	2	 0.0	 0.0	 3	   0.002000	  21.992000	 672.180000;
	2	 0.0	 0.0	 3	   0.002000	  20.295000	 672.180000;
	2	 0.0	 0.0	 3	   0.002000	  21.255000	 673.280000;
	2	 0.0	 0.0	 3	   0.002000	  21.172000	 673.280000;
	2	 0.0	 0.0	 3	   0.002000	  19.797000	 236.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.797000	 819.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.257000	 819.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.411000	 686.850000;
	2	 0.0	 0.0	 3	   0.002000	  19.534000	 686.850000;
	2	 0.0	 0.0	 3	   0.002000	  20.575000	 686.850000;
	2	 0.0	 0.0	 3	   0.002000	  19.370000	 681.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.039000	 681.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.007000	 954.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.096000	 954.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.155000	 954.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.309000	 1243.530000;
	2	 0.0	 0.0	 3	   0.002000	  20.057000	 1243.530000;
	2	 0.0	 0.0	 3	   0.002000	  21.225000	 871.360000;
	2	 0.0	 0.0	 3	   0.002000	  19.415000	 871.360000;
	2	 0.0	 0.0	 3	   0.002000	  17.755000	 282.620000;
	2	 0.0	 0.0	 3	   0.002000	  19.728000	 237.140000;
	2	 0.0	 0.0	 3	   0.001000	  14.140000	 237.140000;
	2	 0.0	 0.0	 3	   0.002000	  18.624000	 237.140000;
	2	 0.0	 0.0	 3	   0.002000	  21.565000	 237.140000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.185000	 1440.170000;
	2	 0.0	 0.0	 3	   0.002000	  15.942000	 1440.170000;
	2	 0.0	 0.0	 3	   0.002000	  19.411000	 1440.170000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.808000	 875.300000;
	2	 0.0	 0.0	 3	   0.002000	  21.498000	 875.300000;
	2	 0.0	 0.0	 3	   0.002000	  22.302000	 875.300000;
	2	 0.0	 0.0	 3	   0.002000	  22.128000	 875.300000;
	2	 0.0	 0.0	 3	   0.002000	  20.963000	 875.300000;
	2	 0.0	 0.0	 3	   0.002000	  19.553000	 875.300000;
	2	 0.0	 0.0	 3	   0.001000	  16.557000	 679.650000;
	2	 0.0	 0.0	 3	   0.002000	  20.548000	 679.650000;
	2	 0.0	 0.0	 3	   0.002000	  17.990000	 640.420000;
	2	 0.0	 0.0	 3	   0.002000	  20.377000	 640.420000;
	2	 0.0	 0.0	 3	   0.002000	  17.898000	 640.420000;
	2	 0.0	 0.0	 3	   0.002000	  21.283000	 640.420000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.166000	 795.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.141000	 795.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.731000	 795.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.771000	 711.450000;
	2	 0.0	 0.0	 3	   0.002000	  20.724000	 711.450000;
	2	 0.0	 0.0	 3	   0.002000	  18.152000	 711.450000;
	2	 0.0	 0.0	 3	   0.002000	  21.410000	 781.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.778000	 781.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.574000	 781.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.561000	 781.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.658000	 781.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.445000	 781.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.653000	 945.800000;
	2	 0.0	 0.0	 3	   0.002000	  20.363000	 945.800000;
	2	 0.0	 0.0	 3	   0.002000	  19.407000	 945.800000;
	2	 0.0	 0.0	 3	   0.000000	   8.000000	 1254.000000;
	2	 0.0	 0.0	 3	   0.000000	   8.000000	 1254.000000;
	2	 0.0	 0.0	 3	   0.000000	   8.000000	 1254.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  14.641000	 799.520000;
	2	 0.0	 0.0	 3	   0.002000	  17.529000	 477.300000;
	2	 0.0	 0.0	 3	   0.002000	  17.709000	 477.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.600000	 477.300000;
	2	 0.0	 0.0	 3	   0.001000	  14.033000	 236.720000;
	2	 0.0	 0.0	 3	   0.002000	  18.340000	 236.720000;
	2	 0.0	 0.0	 3	   0.002000	  19.761000	 646.950000;
	2	 0.0	 0.0	 3	   0.002000	  19.569000	 646.950000;
	2	 0.0	 0.0	 3	   0.002000	  19.241000	 613.800000;
	2	 0.0	 0.0	 3	   0.002000	  19.249000	 727.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.152000	 923.050000;
	2	 0.0	 0.0	 3	   0.002000	  20.681000	 923.050000;
	2	 0.0	 0.0	 3	   0.002000	  18.742000	 923.050000;
	2	 0.0	 0.0	 3	   0.001000	  16.200000	 613.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.067000	 1258.850000;
	2	 0.0	 0.0	 3	   0.003000	  24.696000	 1258.850000;
	2	 0.0	 0.0	 3	   0.002000	  19.822000	 1258.850000;
	2	 0.0	 0.0	 3	   0.002000	  16.377000	 1258.850000;
	2	 0.0	 0.0	 3	   0.002000	  21.478000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.391000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.576000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.155000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.155000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.850000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.447000	 751.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.541000	 751.250000;
	2	 0.0	 0.0	 3	   0.002000	  18.951000	 751.250000;
	2	 0.0	 0.0	 3	   0.002000	  18.506000	 751.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.811000	 751.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.549000	 751.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.830000	 931.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.968000	 931.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.208000	 931.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.142000	 931.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.153000	 931.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.495000	 931.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.058000	 931.280000;
	2	 0.0	 0.0	 3	   0.002000	  18.544000	 931.280000;
	2	 0.0	 0.0	 3	   0.002000	  21.728000	 931.280000;
	2	 0.0	 0.0	 3	   0.002000	  18.609000	 931.280000;
	2	 0.0	 0.0	 3	   0.002000	  19.604000	 931.280000;
	2	 0.0	 0.0	 3	   0.002000	  19.691000	 931.280000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  16.672000	 1054.350000;
	2	 0.0	 0.0	 3	   0.002000	  17.660000	 1054.350000;
	2	 0.0	 0.0	 3	   0.002000	  20.350000	 1054.350000;
	2	 0.0	 0.0	 3	   0.002000	  21.131000	 1054.350000;
	2	 0.0	 0.0	 3	   0.002000	  20.338000	 770.400000;
	2	 0.0	 0.0	 3	   0.002000	  22.340000	 770.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.352000	 679.650000;
	2	 0.0	 0.0	 3	   0.002000	  19.806000	 679.650000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.252000	 909.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.972000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.707000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.175000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.334000	 909.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.934000	 909.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.232000	 885.080000;
	2	 0.0	 0.0	 3	   0.002000	  20.512000	 885.080000;
	2	 0.0	 0.0	 3	   0.002000	  20.179000	 885.080000;
	2	 0.0	 0.0	 3	   0.002000	  20.053000	 885.080000;
	2	 0.0	 0.0	 3	   0.002000	  19.310000	 885.080000;
	2	 0.0	 0.0	 3	   0.002000	  20.198000	 885.080000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.942000	 956.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.641000	 956.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.223000	 956.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.670000	 945.800000;
	2	 0.0	 0.0	 3	   0.002000	  22.266000	 945.800000;
	2	 0.0	 0.0	 3	   0.002000	  22.169000	 945.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.718000	 927.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.947000	 927.200000;
	2	 0.0	 0.0	 3	   0.002000	  20.414000	 927.200000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.727000	 946.250000;
	2	 0.0	 0.0	 3	   0.002000	  20.058000	 946.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.559000	 946.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.071000	 946.250000;
	2	 0.0	 0.0	 3	   0.002000	  19.854000	 946.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.445000	 946.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.049000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  15.173000	 237.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.941000	 611.100000;
	2	 0.0	 0.0	 3	   0.002000	  18.759000	 618.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.234000	 618.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.723000	 665.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.489000	 665.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.565000	 665.100000;
	2	 0.0	 0.0	 3	   0.002000	  17.876000	 665.100000;
	2	 0.0	 0.0	 3	   0.001000	  14.710000	 665.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  12.180000	 1287.950000;
	2	 0.0	 0.0	 3	   0.001000	  13.209000	 1448.640000;
	2	 0.0	 0.0	 3	   0.002000	  15.200000	 1448.640000;
	2	 0.0	 0.0	 3	   0.002000	  17.190000	 236.190000;
	2	 0.0	 0.0	 3	   0.002000	  14.870000	 236.190000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.930000	 1301.110000;
	2	 0.0	 0.0	 3	   0.002000	  15.721000	 1301.110000;
	2	 0.0	 0.0	 3	   0.002000	  14.687000	 1301.110000;
	2	 0.0	 0.0	 3	   0.002000	  18.523000	 924.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.004000	 924.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.529000	 924.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.809000	 615.200000;
	2	 0.0	 0.0	 3	   0.001000	  15.880000	 615.200000;
	2	 0.0	 0.0	 3	   0.001000	  16.009000	 615.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.702000	 436.070000;
	2	 0.0	 0.0	 3	   0.002000	  16.195000	 436.070000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.299000	 705.000000;
	2	 0.0	 0.0	 3	   0.001000	  12.401000	 705.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.546000	 621.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.401000	 621.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.948000	 621.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.146000	 237.210000;
	2	 0.0	 0.0	 3	   0.001000	  12.990000	 237.210000;
	2	 0.0	 0.0	 3	   0.002000	  17.655000	 237.210000;
	2	 0.0	 0.0	 3	   0.002000	  14.342000	 237.210000;
	2	 0.0	 0.0	 3	   0.002000	  14.364000	 236.850000;
	2	 0.0	 0.0	 3	   0.001000	  15.362000	 706.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.901000	 706.500000;
	2	 0.0	 0.0	 3	   0.001000	  13.609000	 706.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.822000	 739.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.688000	 739.550000;
	2	 0.0	 0.0	 3	   0.001000	  14.184000	 739.550000;
	2	 0.0	 0.0	 3	   0.002000	  14.942000	 1297.560000;
	2	 0.0	 0.0	 3	   0.002000	  20.801000	 1297.560000;
	2	 0.0	 0.0	 3	   0.001000	  14.579000	 624.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.267000	 624.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.164000	 624.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.557000	 660.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.386000	 660.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.487000	 1269.150000;
	2	 0.0	 0.0	 3	   0.002000	  22.558000	 1269.150000;
	2	 0.0	 0.0	 3	   0.002000	  20.821000	 1269.150000;
	2	 0.0	 0.0	 3	   0.002000	  21.215000	 1269.150000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  15.478000	 995.380000;
	2	 0.0	 0.0	 3	   0.002000	  18.572000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.335000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  20.522000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.868000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.435000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  22.733000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  18.293000	 759.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.685000	 733.250000;
	2	 0.0	 0.0	 3	   0.002000	  18.791000	 733.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.499000	 733.250000;
	2	 0.0	 0.0	 3	   0.001000	  15.005000	 666.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.393000	 666.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.510000	 622.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.274000	 622.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.370000	 622.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.662000	 925.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.543000	 925.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.786000	 925.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.383000	 839.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.411000	 825.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.742000	 610.280000;
	2	 0.0	 0.0	 3	   0.002000	  17.394000	 610.280000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.128000	 645.600000;
	2	 0.0	 0.0	 3	   0.002000	  18.462000	 645.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.302000	 645.600000;
	2	 0.0	 0.0	 3	   0.002000	  19.031000	 645.600000;
	2	 0.0	 0.0	 3	   0.002000	  17.879000	 640.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.193000	 640.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.970000	 669.750000;
	2	 0.0	 0.0	 3	   0.002000	  18.112000	 669.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.293000	 669.750000;
	2	 0.0	 0.0	 3	   0.001000	  14.682000	 669.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.721000	 815.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.676000	 815.250000;
	2	 0.0	 0.0	 3	   0.002000	  16.894000	 1447.690000;
	2	 0.0	 0.0	 3	   0.002000	  21.868000	 1447.690000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.708000	 612.300000;
	2	 0.0	 0.0	 3	   0.001000	  13.659000	 612.300000;
	2	 0.0	 0.0	 3	   0.001000	  16.401000	 612.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.119000	 650.250000;
	2	 0.0	 0.0	 3	   0.002000	  17.716000	 650.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.021000	 677.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.439000	 677.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.536000	 677.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.492000	 657.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.419000	 657.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.927000	 657.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.738000	 657.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.355000	 657.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.548000	 657.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  16.305000	 1310.820000;
	2	 0.0	 0.0	 3	   0.001000	  12.665000	 1310.820000;
	2	 0.0	 0.0	 3	   0.002000	  15.593000	 1310.820000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.572000	 699.220000;
	2	 0.0	 0.0	 3	   0.002000	  20.205000	 699.220000;
	2	 0.0	 0.0	 3	   0.002000	  20.218000	 699.220000;
	2	 0.0	 0.0	 3	   0.002000	  20.490000	 699.220000;
	2	 0.0	 0.0	 3	   0.002000	  19.131000	 699.220000;
	2	 0.0	 0.0	 3	   0.001000	  17.369000	 699.220000;
	2	 0.0	 0.0	 3	   0.001000	  12.394000	 842.580000;
	2	 0.0	 0.0	 3	   0.002000	  14.736000	 237.580000;
	2	 0.0	 0.0	 3	   0.002000	  16.523000	 237.730000;
	2	 0.0	 0.0	 3	   0.002000	  14.594000	 237.730000;
	2	 0.0	 0.0	 3	   0.002000	  21.165000	 925.460000;
	2	 0.0	 0.0	 3	   0.002000	  22.976000	 925.460000;
	2	 0.0	 0.0	 3	   0.002000	  20.889000	 925.460000;
	2	 0.0	 0.0	 3	   0.002000	  23.103000	 925.460000;
	2	 0.0	 0.0	 3	   0.002000	  21.140000	 810.450000;
	2	 0.0	 0.0	 3	   0.002000	  22.221000	 810.450000;
	2	 0.0	 0.0	 3	   0.002000	  19.254000	 655.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.740000	 639.900000;
	2	 0.0	 0.0	 3	   0.002000	  20.332000	 639.900000;
	2	 0.0	 0.0	 3	   0.002000	  16.684000	 236.580000;
	2	 0.0	 0.0	 3	   0.002000	  16.357000	 236.580000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  15.455000	 938.520000;
	2	 0.0	 0.0	 3	   0.001000	  12.925000	 938.520000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.935000	 898.350000;
	2	 0.0	 0.0	 3	   0.002000	  21.187000	 898.350000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	   9.784000	 1039.020000;
	2	 0.0	 0.0	 3	   0.002000	  14.413000	 1039.020000;
	2	 0.0	 0.0	 3	   0.001000	  12.228000	 236.310000;
	2	 0.0	 0.0	 3	   0.001000	  12.434000	 236.310000;
	2	 0.0	 0.0	 3	   0.001000	  10.255000	 236.310000;
	2	 0.0	 0.0	 3	   0.002000	  20.412000	 635.700000;
	2	 0.0	 0.0	 3	   0.002000	  19.697000	 668.350000;
	2	 0.0	 0.0	 3	   0.002000	  20.486000	 668.350000;
	2	 0.0	 0.0	 3	   0.002000	  21.766000	 668.350000;
	2	 0.0	 0.0	 3	   0.002000	  20.225000	 668.350000;
	2	 0.0	 0.0	 3	   0.002000	  23.740000	 668.350000;
	2	 0.0	 0.0	 3	   0.002000	  17.826000	 668.350000;
	2	 0.0	 0.0	 3	   0.001000	  13.020000	 236.760000;
	2	 0.0	 0.0	 3	   0.001000	  11.460000	 236.760000;
	2	 0.0	 0.0	 3	   0.002000	  14.480000	 236.760000;
	2	 0.0	 0.0	 3	   0.002000	  16.377000	 236.760000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  13.473000	 1314.430000;
	2	 0.0	 0.0	 3	   0.002000	  18.674000	 715.650000;
	2	 0.0	 0.0	 3	   0.002000	  19.179000	 715.650000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.866000	 629.800000;
	2	 0.0	 0.0	 3	   0.002000	  20.586000	 629.800000;
	2	 0.0	 0.0	 3	   0.002000	  22.341000	 629.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.133000	 715.650000;
	2	 0.0	 0.0	 3	   0.002000	  20.528000	 715.650000;
	2	 0.0	 0.0	 3	   0.002000	  19.344000	 628.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.121000	 628.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.265000	 628.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.268000	 628.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.111000	 628.500000;
	2	 0.0	 0.0	 3	   0.002000	  20.647000	 628.500000;
	2	 0.0	 0.0	 3	   0.001000	  12.693000	 878.380000;
	2	 0.0	 0.0	 3	   0.002000	  14.402000	 237.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.915000	 237.010000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.145000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.278000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.574000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.068000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.531000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.807000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.524000	 650.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.433000	 650.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.405000	 712.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.781000	 825.000000;
	2	 0.0	 0.0	 3	   0.002000	  22.762000	 825.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.501000	 616.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.889000	 616.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.136000	 616.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.631000	 706.650000;
	2	 0.0	 0.0	 3	   0.002000	  19.846000	 706.650000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.802000	 942.550000;
	2	 0.0	 0.0	 3	   0.002000	  18.583000	 942.550000;
	2	 0.0	 0.0	 3	   0.002000	  21.556000	 942.550000;
	2	 0.0	 0.0	 3	   0.002000	  23.990000	 697.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.158000	 697.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.157000	 697.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.519000	 675.600000;
	2	 0.0	 0.0	 3	   0.002000	  21.675000	 675.600000;
	2	 0.0	 0.0	 3	   0.002000	  20.636000	 631.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.672000	 631.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.214000	 631.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.050000	 631.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.380000	 639.900000;
	2	 0.0	 0.0	 3	   0.002000	  18.749000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  18.602000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  21.008000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  20.112000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  20.131000	 629.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.839000	 629.400000;
	2	 0.0	 0.0	 3	   0.001000	  13.918000	 310.110000;
	2	 0.0	 0.0	 3	   0.002000	  17.318000	 310.110000;
	2	 0.0	 0.0	 3	   0.001000	  11.741000	 310.110000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  20.837000	 895.500000;
	2	 0.0	 0.0	 3	   0.002000	  22.577000	 895.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  12.357000	 1276.110000;
	2	 0.0	 0.0	 3	   0.001000	  13.833000	 1276.110000;
	2	 0.0	 0.0	 3	   0.002000	  14.269000	 1276.110000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.048000	 870.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.156000	 870.500000;
	2	 0.0	 0.0	 3	   0.002000	  21.144000	 870.500000;
	2	 0.0	 0.0	 3	   0.002000	  16.524000	 1081.020000;
	2	 0.0	 0.0	 3	   0.002000	  14.980000	 416.190000;
	2	 0.0	 0.0	 3	   0.001000	  12.940000	 416.190000;
	2	 0.0	 0.0	 3	   0.001000	  13.168000	 416.190000;
	2	 0.0	 0.0	 3	   0.001000	  10.268000	 416.190000;
	2	 0.0	 0.0	 3	   0.001000	  13.455000	 416.190000;
	2	 0.0	 0.0	 3	   0.003000	  30.722000	 933.490000;
	2	 0.0	 0.0	 3	   0.003000	  24.605000	 933.490000;
	2	 0.0	 0.0	 3	   0.003000	  31.546000	 933.490000;
	2	 0.0	 0.0	 3	   0.003000	  31.945000	 933.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  29.062000	 325.880000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  29.302000	 237.070000;
	2	 0.0	 0.0	 3	   0.003000	  26.885000	 271.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  27.121000	 1280.030000;
	2	 0.0	 0.0	 3	   0.003000	  26.980000	 1042.960000;
	2	 0.0	 0.0	 3	   0.003000	  25.558000	 1042.960000;
	2	 0.0	 0.0	 3	   0.003000	  29.015000	 1042.960000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  29.738000	 1239.220000;
	2	 0.0	 0.0	 3	   0.002000	  23.567000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  25.785000	 650.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.682000	 660.000000;
	2	 0.0	 0.0	 3	   0.002000	  25.808000	 650.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  32.222000	 236.180000;
	2	 0.0	 0.0	 3	   0.003000	  23.939000	 236.180000;
	2	 0.0	 0.0	 3	   0.003000	  27.502000	 236.180000;
	2	 0.0	 0.0	 3	   0.003000	  29.560000	 236.180000;
	2	 0.0	 0.0	 3	   0.003000	  28.837000	 236.180000;
	2	 0.0	 0.0	 3	   0.003000	  31.068000	 236.180000;
	2	 0.0	 0.0	 3	   0.003000	  30.011000	 236.400000;
	2	 0.0	 0.0	 3	   0.003000	  29.888000	 236.400000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  30.401000	 1343.590000;
	2	 0.0	 0.0	 3	   0.003000	  30.134000	 1343.590000;
	2	 0.0	 0.0	 3	   0.003000	  28.333000	 1343.590000;
	2	 0.0	 0.0	 3	   0.003000	  24.120000	 1343.590000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.523000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  22.892000	 660.000000;
	2	 0.0	 0.0	 3	   0.002000	  27.431000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  23.176000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  25.221000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  25.249000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  24.081000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  25.652000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  26.370000	 611.250000;
	2	 0.0	 0.0	 3	   0.002000	  24.874000	 611.250000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  26.092000	 1323.300000;
	2	 0.0	 0.0	 3	   0.003000	  27.662000	 1323.300000;
	2	 0.0	 0.0	 3	   0.003000	  31.354000	 1323.300000;
	2	 0.0	 0.0	 3	   0.003000	  23.904000	 516.510000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.003000	  30.649000	 373.200000;
	2	 0.0	 0.0	 3	   0.002000	  26.074000	 654.000000;
	2	 0.0	 0.0	 3	   0.002000	  27.163000	 654.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.785000	 654.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.926000	 859.200000;
	2	 0.0	 0.0	 3	   0.001000	  14.975000	 615.600000;
	2	 0.0	 0.0	 3	   0.001000	  14.867000	 615.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.378000	 826.130000;
	2	 0.0	 0.0	 3	   0.001000	  14.833000	 826.130000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.735000	 735.450000;
	2	 0.0	 0.0	 3	   0.001000	  15.416000	 735.450000;
	2	 0.0	 0.0	 3	   0.001000	  14.179000	 735.450000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  13.572000	 724.800000;
	2	 0.0	 0.0	 3	   0.001000	  17.127000	 724.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.229000	 838.880000;
	2	 0.0	 0.0	 3	   0.001000	  16.096000	 838.880000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.375000	 701.550000;
	2	 0.0	 0.0	 3	   0.001000	  16.265000	 701.550000;
	2	 0.0	 0.0	 3	   0.002000	  18.941000	 701.550000;
	2	 0.0	 0.0	 3	   0.002000	  20.091000	 237.230000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  15.374000	 798.350000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  15.820000	 237.810000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.356000	 1322.300000;
	2	 0.0	 0.0	 3	   0.002000	  14.300000	 1322.300000;
	2	 0.0	 0.0	 3	   0.002000	  16.930000	 1322.300000;
	2	 0.0	 0.0	 3	   0.002000	  14.996000	 1322.300000;
	2	 0.0	 0.0	 3	   0.002000	  18.269000	 613.720000;
	2	 0.0	 0.0	 3	   0.001000	  16.565000	 613.720000;
	2	 0.0	 0.0	 3	   0.001000	  14.507000	 613.720000;
	2	 0.0	 0.0	 3	   0.002000	  19.084000	 613.720000;
	2	 0.0	 0.0	 3	   0.002000	  19.066000	 613.720000;
	2	 0.0	 0.0	 3	   0.001000	  17.157000	 613.720000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  15.278000	 513.130000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.650000	 663.900000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.091000	 720.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.800000	 757.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.152000	 757.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.255000	 757.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.032000	 757.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.744000	 757.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.160000	 757.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.284000	 742.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.392000	 742.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.233000	 742.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	10002	 10001	 0.057474	 0.297874	 0.04557	 185.33	 185.33	 185.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10011	 10001	 0.027895	 0.200986	 0.06271	 167.88	 167.88	 167.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 10002	 0.028286	 0.132954	 0.07205	 207.43	 207.43	 207.43	 0.0	 0.0	 1	 -30.0	 30.0;
	10004	 10003	 0.012099	 0.073288	 0.01171	 170.67	 170.67	 170.67	 0.0	 0.0	 1	 -30.0	 30.0;
	10003	 10010	 0.012423	 0.079127	 0.01766	 201.54	 201.54	 201.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10937	 10003	 0.009516	 0.050189	 0.02744	 211.8	 211.8	 211.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10004	 10005	 0.000201	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10004	 10937	 0.019482	 0.100643	 0.02121	 195.1	 195.1	 195.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10006	 10007	 0.000272	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10008	 10007	 0.00871	 0.065557	 0.0156	 212.34	 212.34	 212.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10007	 13019	 0.005848	 0.038664	 0.02062	 218.55	 218.55	 218.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10007	 13028	 0.018994	 0.103855	 0.1879	 231.63	 231.63	 231.63	 0.0	 0.0	 1	 -30.0	 30.0;
	10008	 10009	 0.000236	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10016	 10008	 0.013033	 0.083799	 0.0301	 229.92	 229.92	 229.92	 0.0	 0.0	 1	 -30.0	 30.0;
	13019	 10008	 0.01355	 0.065214	 0.032	 184.78	 184.78	 184.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 10010	 0.007781	 0.030841	 0.02241	 197.37	 197.37	 197.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10011	 10020	 0.022817	 0.11103	 0.02458	 214.06	 214.06	 214.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10013	 10012	 0.000261	 0.019344	 0.0	 473.63	 473.63	 473.63	 1.0	 0.0	 1	 -30.0	 30.0;
	10012	 10023	 0.001396	 0.016565	 0.31452	 1105.1	 1105.1	 1105.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10012	 10987	 0.000883	 0.009393	 0.17078	 1237.08	 1237.08	 1237.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 10013	 0.002093	 0.00845	 0.00407	 236.46	 236.46	 236.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10013	 10076	 0.015367	 0.101403	 0.11511	 239.71	 239.71	 239.71	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 10015	 0.00027	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10016	 10017	 0.00025	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10016	 13463	 0.008946	 0.046857	 0.19885	 245.26	 245.26	 245.26	 0.0	 0.0	 1	 -30.0	 30.0;
	10018	 10032	 0.002241	 0.0146	 0.03367	 250.62	 250.62	 250.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10018	 10988	 0.006284	 0.038361	 0.02021	 263.59	 263.59	 263.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10020	 10019	 0.000533	 0.033552	 0.0	 445.05	 445.05	 445.05	 0.975	 0.0	 1	 -30.0	 30.0;
	10730	 10019	 0.002142	 0.026863	 0.58195	 1150.4	 1150.4	 1150.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10020	 10029	 0.005708	 0.039706	 0.02239	 233.76	 233.76	 233.76	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 13074	 0.006464	 0.035113	 0.12496	 251.36	 251.36	 251.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 13512	 0.002495	 0.018	 0.01137	 201.56	 201.56	 201.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13690	 10021	 0.005193	 0.037293	 0.01323	 247.31	 247.31	 247.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10022	 10024	 0.001583	 0.010843	 0.00579	 204.48	 204.48	 204.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10022	 10030	 0.007083	 0.036561	 0.01221	 210.69	 210.69	 210.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10024	 10023	 0.000558	 0.024885	 0.0	 465.77	 465.77	 465.77	 1.03125	 0.0	 1	 -30.0	 30.0;
	10730	 10023	 0.000587	 0.00738	 0.21892	 1205.73	 1205.73	 1205.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10987	 10023	 0.001084	 0.012681	 0.23685	 1271.34	 1271.34	 1271.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10024	 10039	 0.003249	 0.013727	 0.00413	 261.21	 261.21	 261.21	 0.0	 0.0	 1	 -30.0	 30.0;
	10025	 10858	 0.006298	 0.039083	 0.03135	 188.02	 188.02	 188.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10025	 10929	 0.012125	 0.068124	 0.01755	 219.05	 219.05	 219.05	 0.0	 0.0	 1	 -30.0	 30.0;
	10051	 10026	 0.004528	 0.02582	 0.01123	 220.77	 220.77	 220.77	 0.0	 0.0	 1	 -30.0	 30.0;
	10027	 10028	 0.000249	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10027	 10029	 0.006288	 0.036606	 0.01108	 209.69	 209.69	 209.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10054	 10027	 0.005908	 0.03552	 0.03718	 199.0	 199.0	 199.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10030	 10031	 0.000244	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10030	 10988	 0.011232	 0.05541	 0.03885	 237.68	 237.68	 237.68	 0.0	 0.0	 1	 -30.0	 30.0;
	10032	 10040	 0.005932	 0.033216	 0.0405	 226.1	 226.1	 226.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10036	 10033	 0.001438	 0.006275	 0.00353	 216.72	 216.72	 216.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 10045	 0.010951	 0.047533	 0.03427	 216.4	 216.4	 216.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 11071	 0.001422	 0.007398	 0.00283	 237.01	 237.01	 237.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 13147	 0.007909	 0.052892	 0.05837	 246.79	 246.79	 246.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10034	 10035	 0.000201	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10034	 10036	 0.000248	 0.001185	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11071	 10036	 0.0005	 0.002496	 0.00233	 254.33	 254.33	 254.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10037	 10041	 0.003468	 0.018993	 0.08954	 230.13	 230.13	 230.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10037	 10053	 0.006057	 0.029228	 0.21482	 255.03	 255.03	 255.03	 0.0	 0.0	 1	 -30.0	 30.0;
	10929	 10037	 0.004393	 0.017586	 0.00677	 255.57	 255.57	 255.57	 0.0	 0.0	 1	 -30.0	 30.0;
	10038	 10039	 0.000276	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10040	 10039	 0.002872	 0.01782	 0.01246	 243.11	 243.11	 243.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10040	 10061	 0.004531	 0.021432	 0.02901	 245.08	 245.08	 245.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10045	 10041	 0.005713	 0.03731	 0.01199	 236.56	 236.56	 236.56	 0.0	 0.0	 1	 -30.0	 30.0;
	10041	 10757	 0.003754	 0.019648	 0.08439	 270.97	 270.97	 270.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10112	 10042	 0.006696	 0.033297	 0.02397	 241.87	 241.87	 241.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10042	 10858	 0.001268	 0.003825	 0.00121	 265.85	 265.85	 265.85	 0.0	 0.0	 1	 -30.0	 30.0;
	10043	 10044	 0.000235	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10065	 10043	 0.004192	 0.027014	 0.0131	 234.78	 234.78	 234.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10043	 10731	 0.008235	 0.049341	 0.02223	 254.45	 254.45	 254.45	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 10047	 0.000221	 0.001009	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10049	 10046	 0.001366	 0.006447	 0.0035	 199.81	 199.81	 199.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 10053	 0.004165	 0.027215	 0.0075	 230.09	 230.09	 230.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 10060	 0.003004	 0.017196	 0.00465	 209.43	 209.43	 209.43	 0.0	 0.0	 1	 -30.0	 30.0;
	10048	 10049	 0.000233	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10048	 10050	 0.000219	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10049	 10858	 0.008744	 0.048084	 0.03521	 236.41	 236.41	 236.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10051	 10052	 0.000267	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10051	 10106	 0.011558	 0.052554	 0.06616	 232.86	 232.86	 232.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10054	 10087	 0.009807	 0.051866	 0.06321	 227.67	 227.67	 227.67	 0.0	 0.0	 1	 -30.0	 30.0;
	10055	 10056	 0.000299	 0.001016	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10071	 10056	 0.001756	 0.013175	 0.01312	 213.54	 213.54	 213.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10056	 10111	 0.005763	 0.031111	 0.07264	 227.01	 227.01	 227.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10058	 10057	 0.000543	 0.025187	 0.0	 466.21	 466.21	 466.21	 1.0	 0.0	 1	 -30.0	 30.0;
	10057	 10059	 0.000237	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10060	 10058	 0.001632	 0.010946	 0.00846	 201.84	 201.84	 201.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10058	 10072	 0.001803	 0.013354	 0.00342	 235.48	 235.48	 235.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10058	 10099	 0.003268	 0.021191	 0.03671	 230.02	 230.02	 230.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 10462	 0.001137	 0.014419	 0.70236	 1228.28	 1228.28	 1228.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 10059	 0.000837	 0.00946	 0.19427	 1358.91	 1358.91	 1358.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10061	 10133	 0.002583	 0.013741	 0.01254	 211.25	 211.25	 211.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10062	 10063	 0.000252	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10062	 10064	 0.000263	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10065	 10063	 0.003065	 0.018143	 0.00658	 196.02	 196.02	 196.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10063	 10149	 0.003675	 0.024161	 0.01534	 206.38	 206.38	 206.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10065	 10068	 0.000841	 0.025733	 0.0	 108.63	 108.63	 108.63	 1.0	 0.0	 1	 -30.0	 30.0;
	10066	 10068	 0.008435	 0.258035	 0.0	 54.31	 54.31	 54.31	 1.0	 0.0	 1	 -30.0	 30.0;
	10067	 10068	 0.008435	 0.258035	 0.0	 54.31	 54.31	 54.31	 1.0	 0.0	 1	 -30.0	 30.0;
	10069	 10074	 0.005928	 0.033632	 0.01174	 203.82	 203.82	 203.82	 0.0	 0.0	 1	 -30.0	 30.0;
	10781	 10069	 0.002921	 0.013747	 0.0102	 244.58	 244.58	 244.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10070	 10090	 0.002734	 0.018279	 0.01645	 221.92	 221.92	 221.92	 0.0	 0.0	 1	 -30.0	 30.0;
	10095	 10070	 0.003473	 0.022438	 0.00952	 229.14	 229.14	 229.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10112	 10071	 0.003379	 0.016953	 0.02423	 236.16	 236.16	 236.16	 0.0	 0.0	 1	 -30.0	 30.0;
	10071	 10153	 0.002966	 0.015795	 0.10033	 232.27	 232.27	 232.27	 0.0	 0.0	 1	 -30.0	 30.0;
	10072	 10073	 0.000299	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10072	 10155	 0.005629	 0.029688	 0.00699	 205.7	 205.7	 205.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10074	 10075	 0.000228	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13154	 10074	 0.007954	 0.050685	 0.01611	 181.22	 181.22	 181.22	 0.0	 0.0	 1	 -30.0	 30.0;
	10076	 10133	 0.001323	 0.006403	 0.02926	 218.87	 218.87	 218.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10077	 10092	 0.002248	 0.011411	 0.00481	 205.12	 205.12	 205.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10077	 10097	 0.007262	 0.029947	 0.08604	 216.78	 216.78	 216.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10077	 10137	 0.005965	 0.022809	 0.03097	 236.35	 236.35	 236.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10077	 13292	 0.002442	 0.014841	 0.00883	 229.46	 229.46	 229.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10078	 10081	 0.001569	 0.086936	 0.0	 616.81	 616.81	 616.81	 1.0	 0.0	 1	 -30.0	 30.0;
	10078	 10838	 0.000957	 0.012068	 0.68187	 1170.64	 1170.64	 1170.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10079	 10081	 -0.000917	 -0.05082	 0.0	 466.81	 466.81	 466.81	 1.0	 0.0	 1	 -30.0	 30.0;
	10079	 10124	 0.003042	 0.017445	 0.006	 219.64	 219.64	 219.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 10079	 0.003	 0.01806	 0.03375	 246.83	 246.83	 246.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10080	 10081	 0.004152	 0.230086	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10082	 10083	 0.00028	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10113	 10082	 0.002023	 0.016404	 0.00465	 182.93	 182.93	 182.93	 0.0	 0.0	 1	 -30.0	 30.0;
	10082	 10121	 0.00212	 0.010107	 0.00756	 198.55	 198.55	 198.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10084	 10085	 0.000226	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10084	 10086	 0.000207	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10086	 10136	 0.002643	 0.017986	 0.0103	 216.7	 216.7	 216.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10086	 10216	 0.010323	 0.054805	 0.04341	 176.23	 176.23	 176.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 10121	 0.007479	 0.034982	 0.01936	 206.89	 206.89	 206.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 10087	 0.004732	 0.032055	 0.02713	 214.83	 214.83	 214.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10088	 10089	 0.000254	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10088	 10128	 0.001619	 0.009116	 0.0026	 258.98	 258.98	 258.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10088	 10149	 0.002097	 0.01208	 0.00604	 223.8	 223.8	 223.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10088	 10227	 0.005323	 0.028924	 0.0371	 212.33	 212.33	 212.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10090	 10138	 0.00331	 0.017372	 0.00479	 189.9	 189.9	 189.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10090	 10149	 0.007326	 0.033046	 0.01205	 172.91	 172.91	 172.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10137	 10091	 0.001153	 0.00794	 0.00434	 248.05	 248.05	 248.05	 0.0	 0.0	 1	 -30.0	 30.0;
	10091	 10176	 0.00345	 0.019599	 0.02875	 214.01	 214.01	 214.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10091	 10954	 0.003029	 0.013701	 0.0419	 249.45	 249.45	 249.45	 0.0	 0.0	 1	 -30.0	 30.0;
	10092	 10148	 0.002731	 0.0163	 0.00861	 229.01	 229.01	 229.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10092	 10173	 0.005409	 0.027737	 0.02911	 235.88	 235.88	 235.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 13144	 0.009419	 0.072795	 0.02979	 218.69	 218.69	 218.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 13147	 0.003349	 0.016415	 0.06083	 258.14	 258.14	 258.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 13182	 0.004096	 0.021643	 0.00554	 234.34	 234.34	 234.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 13204	 0.00351	 0.017155	 0.01854	 217.58	 217.58	 217.58	 0.0	 0.0	 1	 -30.0	 30.0;
	13292	 10093	 0.002609	 0.012396	 0.00539	 233.12	 233.12	 233.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10094	 10095	 0.000229	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10094	 10096	 0.000203	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10133	 10095	 0.002794	 0.018339	 0.0116	 168.25	 168.25	 168.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10095	 11010	 0.009226	 0.049923	 0.08677	 241.84	 241.84	 241.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10097	 10954	 0.005361	 0.031109	 0.01035	 240.32	 240.32	 240.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10098	 10099	 0.000291	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10155	 10099	 0.001709	 0.009509	 0.01513	 214.82	 214.82	 214.82	 0.0	 0.0	 1	 -30.0	 30.0;
	10100	 10101	 0.000217	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10100	 10102	 0.000274	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 10101	 0.001371	 0.006628	 0.0094	 194.26	 194.26	 194.26	 0.0	 0.0	 1	 -30.0	 30.0;
	13301	 10101	 0.001586	 0.00633	 0.00271	 212.88	 212.88	 212.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13314	 10101	 0.000606	 0.003748	 0.00188	 194.85	 194.85	 194.85	 0.0	 0.0	 1	 -30.0	 30.0;
	10103	 10104	 0.000294	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10103	 10105	 0.000252	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10131	 10105	 0.000329	 0.00205	 0.00161	 209.77	 209.77	 209.77	 0.0	 0.0	 1	 -30.0	 30.0;
	10148	 10105	 0.001119	 0.007126	 0.00294	 143.75	 143.75	 143.75	 0.0	 0.0	 1	 -30.0	 30.0;
	13285	 10105	 0.00187	 0.009753	 0.01147	 211.98	 211.98	 211.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10106	 10215	 0.006435	 0.048933	 0.01513	 212.58	 212.58	 212.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10107	 10108	 0.000211	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10107	 10109	 0.000292	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10108	 10186	 0.004715	 0.024296	 0.01313	 249.27	 249.27	 249.27	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 10108	 0.004364	 0.027955	 0.02179	 235.31	 235.31	 235.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10110	 10111	 0.000221	 0.001092	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10111	 10213	 0.007996	 0.059293	 0.03775	 236.86	 236.86	 236.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10113	 10114	 0.000224	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10113	 10128	 0.003764	 0.017243	 0.0787	 216.3	 216.3	 216.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10128	 10115	 0.003638	 0.016403	 0.00482	 234.53	 234.53	 234.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 10115	 0.001712	 0.01123	 0.00312	 212.47	 212.47	 212.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10118	 10116	 0.003108	 0.019022	 0.00851	 188.83	 188.83	 188.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10116	 10397	 0.007777	 0.036727	 0.07404	 221.58	 221.58	 221.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10116	 10795	 0.009396	 0.055383	 0.02548	 245.76	 245.76	 245.76	 0.0	 0.0	 1	 -30.0	 30.0;
	10117	 10120	 0.000915	 0.037256	 0.0	 577.61	 577.61	 577.61	 1.0	 0.0	 1	 -30.0	 30.0;
	10275	 10117	 0.001233	 0.013303	 0.39851	 1345.52	 1345.52	 1345.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10799	 10117	 0.000771	 0.009847	 0.22998	 1180.81	 1180.81	 1180.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10893	 10117	 0.000749	 0.008125	 0.20696	 1332.36	 1332.36	 1332.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10118	 10120	 -7.8e-05	 -0.003161	 0.0	 452.61	 452.61	 452.61	 1.0	 0.0	 1	 -30.0	 30.0;
	10118	 10186	 0.003228	 0.01551	 0.00786	 266.6	 266.6	 266.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10118	 10244	 0.003101	 0.020077	 0.05484	 246.49	 246.49	 246.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10118	 10300	 0.004389	 0.02992	 0.0165	 238.95	 238.95	 238.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10119	 10120	 0.00512	 0.20846	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10121	 10122	 0.000227	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10121	 10124	 0.002546	 0.014044	 0.00758	 179.57	 179.57	 179.57	 0.0	 0.0	 1	 -30.0	 30.0;
	10121	 10325	 0.004612	 0.028803	 0.06098	 208.42	 208.42	 208.42	 0.0	 0.0	 1	 -30.0	 30.0;
	10123	 10124	 0.000205	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10123	 10125	 0.000224	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10123	 10126	 0.000252	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10128	 10127	 0.000312	 0.020028	 0.0	 562.17	 562.17	 562.17	 1.05625	 0.0	 1	 -30.0	 30.0;
	10127	 10730	 0.001135	 0.014705	 0.31386	 1116.83	 1116.83	 1116.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10838	 10127	 0.000935	 0.011435	 0.21946	 1195.62	 1195.62	 1195.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10128	 10138	 0.004035	 0.026283	 0.01205	 239.6	 239.6	 239.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10129	 13285	 0.00062	 0.00434	 0.00183	 221.18	 221.18	 221.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10129	 13310	 0.001977	 0.012466	 0.00452	 239.02	 239.02	 239.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13314	 10129	 0.00057	 0.004133	 0.00873	 231.06	 231.06	 231.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10130	 10147	 0.000599	 0.003657	 0.01431	 223.05	 223.05	 223.05	 0.0	 0.0	 1	 -30.0	 30.0;
	13312	 10130	 0.001639	 0.011365	 0.0026	 182.98	 182.98	 182.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10131	 10132	 0.000247	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10178	 10131	 0.002141	 0.01383	 0.00585	 203.57	 203.57	 203.57	 0.0	 0.0	 1	 -30.0	 30.0;
	10131	 13300	 0.000979	 0.006112	 0.00719	 225.61	 225.61	 225.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10133	 10134	 0.00028	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10135	 10136	 0.000249	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10136	 10210	 0.004395	 0.022764	 0.03393	 202.01	 202.01	 202.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10136	 11028	 0.003014	 0.017477	 0.01016	 264.49	 264.49	 264.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10138	 10199	 0.005131	 0.026697	 0.01759	 220.87	 220.87	 220.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10139	 10154	 0.00043	 0.00294	 0.00101	 278.91	 278.91	 278.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10139	 10154	 0.00043	 0.00294	 0.00101	 278.91	 278.91	 278.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10197	 10139	 0.001172	 0.006691	 0.00432	 280.99	 280.99	 280.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10197	 10139	 0.001172	 0.006691	 0.00432	 280.99	 280.99	 280.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 10141	 0.000258	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 10143	 0.002479	 0.013455	 0.00531	 232.49	 232.49	 232.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10142	 10143	 0.000256	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10142	 10144	 0.00026	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 10143	 0.004505	 0.023167	 0.01358	 198.54	 198.54	 198.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10145	 10190	 0.000687	 0.005321	 0.00936	 242.1	 242.1	 242.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10145	 10193	 0.001727	 0.009053	 0.00257	 214.7	 214.7	 214.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10146	 10147	 0.00024	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10193	 10147	 0.001217	 0.007082	 0.00458	 246.47	 246.47	 246.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10149	 10152	 0.000504	 0.013842	 0.0	 203.15	 203.15	 203.15	 1.0	 0.0	 1	 -30.0	 30.0;
	10150	 10152	 0.005691	 0.156199	 0.0	 101.57	 101.57	 101.57	 1.0	 0.0	 1	 -30.0	 30.0;
	10151	 10152	 0.005691	 0.156199	 0.0	 101.57	 101.57	 101.57	 1.0	 0.0	 1	 -30.0	 30.0;
	10153	 10164	 0.001133	 0.007421	 0.00528	 204.81	 204.81	 204.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10154	 10184	 0.003441	 0.022662	 0.00837	 274.37	 274.37	 274.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10155	 10156	 0.000264	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10155	 10164	 0.002267	 0.00963	 0.00454	 205.94	 205.94	 205.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10157	 10158	 0.000214	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10158	 10159	 0.00291	 0.015591	 0.0087	 155.28	 155.28	 155.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10158	 10184	 0.001409	 0.006545	 0.01143	 249.59	 249.59	 249.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 10158	 0.001143	 0.008345	 0.00494	 232.9	 232.9	 232.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10208	 10159	 0.00044	 0.003278	 0.01862	 198.66	 198.66	 198.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 10272	 0.004091	 0.019171	 0.00733	 218.11	 218.11	 218.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10161	 10162	 0.000297	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10161	 10163	 0.000269	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10235	 10163	 0.003809	 0.018915	 0.0052	 209.35	 209.35	 209.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10164	 10169	 0.001734	 0.009014	 0.02286	 200.65	 200.65	 200.65	 0.0	 0.0	 1	 -30.0	 30.0;
	10165	 10166	 0.000262	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10199	 10165	 0.002041	 0.013192	 0.0112	 198.41	 198.41	 198.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10165	 10250	 0.005517	 0.025982	 0.0112	 212.61	 212.61	 212.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10167	 11049	 0.002993	 0.014863	 0.03428	 192.01	 192.01	 192.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10167	 13301	 0.001863	 0.010288	 0.00697	 233.51	 233.51	 233.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10167	 13303	 0.00158	 0.007495	 0.00243	 317.46	 317.46	 317.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10167	 13304	 0.001924	 0.01111	 0.02006	 328.09	 328.09	 328.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10168	 10761	 0.002779	 0.015298	 0.02764	 216.0	 216.0	 216.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10168	 13337	 0.000377	 0.002213	 0.00284	 183.11	 183.11	 183.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10168	 13347	 0.002193	 0.012485	 0.0082	 190.92	 190.92	 190.92	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 10170	 0.000264	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 10837	 0.003488	 0.027737	 0.01137	 175.4	 175.4	 175.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10250	 10171	 0.001125	 0.007793	 0.00196	 250.33	 250.33	 250.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10258	 10171	 0.001766	 0.012529	 0.00371	 196.79	 196.79	 196.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10171	 10298	 0.002505	 0.016053	 0.01321	 208.89	 208.89	 208.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10171	 10839	 0.000854	 0.006025	 0.00242	 267.61	 267.61	 267.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10172	 10173	 0.000243	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10172	 10174	 0.000254	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10190	 10173	 0.002664	 0.016864	 0.00839	 217.23	 217.23	 217.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10173	 10935	 0.00509	 0.031168	 0.0903	 271.37	 271.37	 271.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10175	 10176	 0.000266	 0.001178	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10176	 10741	 0.007971	 0.054666	 0.04874	 243.05	 243.05	 243.05	 0.0	 0.0	 1	 -30.0	 30.0;
	10177	 13289	 0.000349	 0.002227	 0.00095	 214.87	 214.87	 214.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10177	 13300	 0.001862	 0.008332	 0.01421	 246.31	 246.31	 246.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 10177	 0.000962	 0.005702	 0.00129	 272.58	 272.58	 272.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10193	 10178	 0.002649	 0.015833	 0.00536	 233.36	 233.36	 233.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10210	 10179	 0.002952	 0.01773	 0.00841	 189.73	 189.73	 189.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10923	 10179	 0.006201	 0.035107	 0.01011	 237.41	 237.41	 237.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10180	 10181	 0.000217	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10180	 10182	 0.000205	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10181	 10785	 0.005573	 0.030927	 0.01195	 204.3	 204.3	 204.3	 0.0	 0.0	 1	 -30.0	 30.0;
	11028	 10181	 0.008697	 0.049171	 0.01517	 215.84	 215.84	 215.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10251	 10183	 0.002001	 0.00868	 0.00304	 192.21	 192.21	 192.21	 0.0	 0.0	 1	 -30.0	 30.0;
	10183	 10839	 0.001831	 0.011766	 0.0033	 235.12	 235.12	 235.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10184	 10185	 0.000292	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10186	 10187	 0.000283	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10188	 10189	 0.00026	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10189	 10213	 0.017595	 0.048944	 0.08708	 226.53	 226.53	 226.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10189	 10843	 0.003381	 0.024568	 0.01481	 174.23	 174.23	 174.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10190	 10191	 0.000296	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10190	 10476	 0.004142	 0.029465	 0.11664	 256.51	 256.51	 256.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10192	 10195	 0.000631	 0.029418	 0.0	 556.65	 556.65	 556.65	 1.0	 0.0	 1	 -30.0	 30.0;
	10192	 10813	 0.000777	 0.010797	 0.23745	 1215.9	 1215.9	 1215.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10192	 11001	 0.002347	 0.029145	 1.41418	 1396.92	 1396.92	 1396.92	 0.0	 0.0	 1	 -30.0	 30.0;
	10192	 13180	 0.000613	 0.007345	 0.18007	 1182.41	 1182.41	 1182.41	 0.0	 0.0	 1	 -30.0	 30.0;
	13302	 10192	 0.000462	 0.005278	 0.18198	 1341.36	 1341.36	 1341.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10193	 10195	 0.0	 1e-05	 0.0	 456.65	 456.65	 456.65	 1.0	 0.0	 1	 -30.0	 30.0;
	10194	 10195	 0.004034	 0.188062	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10197	 10196	 0.000476	 0.029957	 0.0	 499.64	 499.64	 499.64	 1.05625	 0.0	 1	 -30.0	 30.0;
	10196	 10198	 0.000278	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10196	 10735	 0.000402	 0.005207	 0.14362	 1224.4	 1224.4	 1224.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10838	 10196	 0.000493	 0.006123	 0.13508	 1215.99	 1215.99	 1215.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10196	 10857	 0.001289	 0.014839	 0.36138	 1224.13	 1224.13	 1224.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10200	 10207	 0.001122	 0.007379	 0.00552	 207.09	 207.09	 207.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10200	 10251	 0.001448	 0.005571	 0.00164	 243.71	 243.71	 243.71	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 10201	 0.006314	 0.035258	 0.02068	 194.09	 194.09	 194.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 10201	 0.006716	 0.037916	 0.01972	 233.17	 233.17	 233.17	 0.0	 0.0	 1	 -30.0	 30.0;
	10238	 10202	 0.00153	 0.006888	 0.00547	 221.12	 221.12	 221.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10202	 10761	 0.002349	 0.01484	 0.02497	 236.99	 236.99	 236.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 10204	 0.000246	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10218	 10203	 0.006251	 0.040334	 0.01163	 225.99	 225.99	 225.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10248	 10203	 0.006491	 0.030404	 0.02235	 230.26	 230.26	 230.26	 0.0	 0.0	 1	 -30.0	 30.0;
	10205	 10206	 0.000241	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10205	 10226	 0.000582	 0.003469	 0.00439	 203.06	 203.06	 203.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10205	 10365	 0.00431	 0.024771	 0.01415	 235.4	 235.4	 235.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10207	 10220	 0.001493	 0.008324	 0.00262	 201.79	 201.79	 201.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10208	 10839	 0.002891	 0.018516	 0.01536	 220.1	 220.1	 220.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10224	 10209	 0.003674	 0.023088	 0.01365	 236.08	 236.08	 236.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 10290	 0.00175	 0.008738	 0.00853	 203.02	 203.02	 203.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10212	 10210	 0.002836	 0.01732	 0.00789	 203.4	 203.4	 203.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10211	 10212	 0.000242	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10785	 10212	 0.002455	 0.014491	 0.00361	 240.36	 240.36	 240.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10213	 10214	 0.000255	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10693	 10213	 0.007363	 0.049299	 0.01762	 223.19	 223.19	 223.19	 0.0	 0.0	 1	 -30.0	 30.0;
	10213	 10863	 0.004285	 0.026363	 0.00884	 249.12	 249.12	 249.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 10216	 0.002404	 0.015904	 0.00726	 254.06	 254.06	 254.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10894	 10215	 0.010901	 0.071606	 0.13852	 250.76	 250.76	 250.76	 0.0	 0.0	 1	 -30.0	 30.0;
	10216	 10217	 0.000234	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10216	 10222	 0.004233	 0.03042	 0.01366	 214.35	 214.35	 214.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10785	 10216	 0.001679	 0.008888	 0.01101	 275.02	 275.02	 275.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10218	 10235	 0.004549	 0.021451	 0.02972	 211.45	 211.45	 211.45	 0.0	 0.0	 1	 -30.0	 30.0;
	10248	 10218	 0.002857	 0.017775	 0.00486	 194.39	 194.39	 194.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10219	 10220	 0.000222	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10221	 0.001234	 0.006972	 0.00118	 224.79	 224.79	 224.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10221	 10295	 0.002375	 0.013094	 0.03006	 252.74	 252.74	 252.74	 0.0	 0.0	 1	 -30.0	 30.0;
	10365	 10221	 0.001678	 0.009885	 0.00517	 298.73	 298.73	 298.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10222	 10223	 0.000252	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10222	 10888	 0.018711	 0.068728	 0.06246	 221.33	 221.33	 221.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10224	 10225	 0.000273	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10224	 10837	 0.002218	 0.012897	 0.0091	 254.38	 254.38	 254.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 10247	 0.001465	 0.010269	 0.00279	 197.96	 197.96	 197.96	 0.0	 0.0	 1	 -30.0	 30.0;
	10235	 10227	 0.005575	 0.034615	 0.01362	 201.11	 201.11	 201.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10319	 10228	 0.001219	 0.007302	 0.0043	 222.9	 222.9	 222.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10228	 10383	 0.00147	 0.010532	 0.00588	 255.14	 255.14	 255.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10229	 10284	 0.001346	 0.008154	 0.00417	 234.23	 234.23	 234.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10229	 10374	 0.002253	 0.011956	 0.00238	 208.28	 208.28	 208.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10365	 10230	 0.000728	 0.004818	 0.00802	 178.77	 178.77	 178.77	 0.0	 0.0	 1	 -30.0	 30.0;
	10230	 10736	 0.002032	 0.013105	 0.00341	 231.05	 231.05	 231.05	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 10251	 0.004429	 0.023752	 0.05605	 269.59	 269.59	 269.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 10736	 0.002692	 0.018651	 0.01127	 278.29	 278.29	 278.29	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 10736	 0.002692	 0.018651	 0.01127	 278.29	 278.29	 278.29	 0.0	 0.0	 1	 -30.0	 30.0;
	10298	 10232	 0.001213	 0.007133	 0.00392	 237.87	 237.87	 237.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10364	 10232	 0.001166	 0.008291	 0.01139	 264.24	 264.24	 264.24	 0.0	 0.0	 1	 -30.0	 30.0;
	10233	 10234	 0.000278	 0.001135	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10233	 10242	 0.001867	 0.01245	 0.0096	 188.65	 188.65	 188.65	 0.0	 0.0	 1	 -30.0	 30.0;
	10233	 10309	 0.00144	 0.006753	 0.00127	 226.47	 226.47	 226.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10315	 10233	 0.000753	 0.005339	 0.00167	 205.35	 205.35	 205.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10235	 10236	 0.000207	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10238	 10237	 0.001997	 0.01234	 0.00387	 187.93	 187.93	 187.93	 0.0	 0.0	 1	 -30.0	 30.0;
	10237	 13350	 0.002474	 0.014621	 0.00957	 209.4	 209.4	 209.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10239	 10240	 0.000255	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10284	 10240	 0.000904	 0.006701	 0.00114	 184.59	 184.59	 184.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10240	 10306	 0.002741	 0.014709	 0.00591	 222.27	 222.27	 222.27	 0.0	 0.0	 1	 -30.0	 30.0;
	10260	 10241	 0.000554	 0.003937	 0.00243	 190.4	 190.4	 190.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10241	 10322	 0.001255	 0.004389	 0.00924	 216.88	 216.88	 216.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10242	 10243	 0.000216	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10270	 10242	 0.001988	 0.009772	 0.00398	 229.88	 229.88	 229.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10244	 10246	 0.000575	 0.003168	 0.00131	 213.28	 213.28	 213.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10777	 10244	 0.003414	 0.014429	 0.00996	 246.44	 246.44	 246.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10245	 10246	 0.0002	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10246	 10894	 0.003598	 0.01966	 0.01086	 238.67	 238.67	 238.67	 0.0	 0.0	 1	 -30.0	 30.0;
	10247	 10367	 0.001692	 0.009244	 0.00275	 247.88	 247.88	 247.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10247	 10843	 0.008165	 0.04604	 0.08725	 271.29	 271.29	 271.29	 0.0	 0.0	 1	 -30.0	 30.0;
	10249	 10291	 0.00068	 0.004226	 0.0019	 192.75	 192.75	 192.75	 0.0	 0.0	 1	 -30.0	 30.0;
	10315	 10249	 0.000658	 0.00401	 0.00397	 222.2	 222.2	 222.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10321	 10249	 0.001938	 0.00738	 0.00587	 175.98	 175.98	 175.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10251	 10258	 0.003329	 0.017747	 0.01288	 188.91	 188.91	 188.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10252	 10253	 0.000223	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10253	 10314	 0.002686	 0.014793	 0.00403	 213.67	 213.67	 213.67	 0.0	 0.0	 1	 -30.0	 30.0;
	10253	 10415	 0.001082	 0.005732	 0.02302	 237.0	 237.0	 237.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10254	 10255	 0.000202	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10313	 10255	 0.001492	 0.010013	 0.00369	 197.88	 197.88	 197.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10255	 10374	 0.00202	 0.013155	 0.00367	 198.63	 198.63	 198.63	 0.0	 0.0	 1	 -30.0	 30.0;
	10256	 10257	 0.000242	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10256	 10258	 0.000286	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10373	 10259	 0.001711	 0.00894	 0.00681	 205.47	 205.47	 205.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10259	 10839	 0.006141	 0.034326	 0.01579	 209.97	 209.97	 209.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10318	 10260	 0.001107	 0.007975	 0.00163	 221.51	 221.51	 221.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10261	 10262	 0.000292	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10261	 10270	 0.003206	 0.021712	 0.01099	 234.19	 234.19	 234.19	 0.0	 0.0	 1	 -30.0	 30.0;
	10261	 10272	 0.000756	 0.00459	 0.00138	 179.66	 179.66	 179.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10777	 10263	 0.000618	 0.003662	 0.00189	 195.36	 195.36	 195.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10263	 10795	 0.005975	 0.028792	 0.01129	 225.99	 225.99	 225.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10264	 10265	 0.000233	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10264	 10266	 0.000223	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10319	 10265	 0.001316	 0.007006	 0.00246	 180.99	 180.99	 180.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10265	 10323	 0.00075	 0.003747	 0.00218	 223.06	 223.06	 223.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10378	 10267	 0.004547	 0.025796	 0.03237	 248.14	 248.14	 248.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10267	 10814	 0.006959	 0.030752	 0.02785	 258.79	 258.79	 258.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10268	 10269	 0.000216	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10326	 10268	 0.000975	 0.004065	 0.0018	 212.27	 212.27	 212.27	 0.0	 0.0	 1	 -30.0	 30.0;
	10268	 10341	 0.001818	 0.00898	 0.00419	 219.74	 219.74	 219.74	 0.0	 0.0	 1	 -30.0	 30.0;
	10268	 10368	 0.002215	 0.010662	 0.00573	 224.03	 224.03	 224.03	 0.0	 0.0	 1	 -30.0	 30.0;
	10401	 10268	 0.000833	 0.005362	 0.00261	 165.81	 165.81	 165.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10270	 10271	 0.000225	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10270	 10409	 0.003091	 0.018784	 0.01849	 275.36	 275.36	 275.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10270	 10409	 0.003091	 0.018784	 0.01849	 275.36	 275.36	 275.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10272	 10334	 0.002273	 0.011255	 0.03843	 249.79	 249.79	 249.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10273	 10291	 0.001051	 0.005311	 0.00366	 235.4	 235.4	 235.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10334	 10273	 0.000304	 0.002269	 0.00112	 264.84	 264.84	 264.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10329	 10274	 0.001749	 0.009569	 0.0022	 231.76	 231.76	 231.76	 0.0	 0.0	 1	 -30.0	 30.0;
	10274	 10408	 0.002263	 0.013012	 0.00632	 246.0	 246.0	 246.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10276	 10275	 0.000351	 0.019585	 0.0	 614.72	 614.72	 614.72	 1.0	 0.0	 1	 -30.0	 30.0;
	10276	 10275	 0.000351	 0.019585	 0.0	 614.72	 614.72	 614.72	 1.0	 0.0	 1	 -30.0	 30.0;
	10276	 10275	 0.000351	 0.019585	 0.0	 614.72	 614.72	 614.72	 1.0	 0.0	 1	 -30.0	 30.0;
	10275	 10330	 0.000699	 0.008558	 0.18453	 1189.39	 1189.39	 1189.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10369	 10275	 0.000511	 0.0058	 0.09927	 1199.54	 1199.54	 1199.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10427	 10275	 0.000276	 0.003171	 0.07881	 1106.35	 1106.35	 1106.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10275	 10758	 0.002116	 0.027225	 0.61943	 1303.32	 1303.32	 1303.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10276	 10308	 0.001329	 0.007995	 0.00409	 250.53	 250.53	 250.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10276	 0.000567	 0.003855	 0.00315	 286.52	 286.52	 286.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10276	 0.000567	 0.003855	 0.00315	 286.52	 286.52	 286.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10276	 0.000567	 0.003855	 0.00315	 286.52	 286.52	 286.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10276	 10386	 0.000669	 0.003201	 0.00127	 258.9	 258.9	 258.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10403	 10276	 0.000989	 0.005715	 0.00209	 269.72	 269.72	 269.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10276	 10489	 0.003431	 0.019644	 0.01807	 242.43	 242.43	 242.43	 0.0	 0.0	 1	 -30.0	 30.0;
	10325	 10277	 0.002311	 0.011739	 0.00505	 231.69	 231.69	 231.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10386	 10277	 0.003124	 0.017773	 0.00522	 239.04	 239.04	 239.04	 0.0	 0.0	 1	 -30.0	 30.0;
	10388	 10277	 0.002171	 0.010365	 0.00456	 214.02	 214.02	 214.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 10279	 0.000265	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 10280	 0.000217	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 10281	 0.000205	 0.001127	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 10282	 0.000277	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 10280	 0.012616	 0.069271	 0.01419	 196.81	 196.81	 196.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 10785	 0.008011	 0.047757	 0.02329	 159.86	 159.86	 159.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10283	 10284	 0.000235	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10284	 10331	 0.00323	 0.02051	 0.01716	 256.9	 256.9	 256.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10422	 10285	 0.001125	 0.005896	 0.00384	 180.38	 180.38	 180.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10285	 10424	 0.003837	 0.016027	 0.01883	 235.43	 235.43	 235.43	 0.0	 0.0	 1	 -30.0	 30.0;
	10454	 10285	 0.00067	 0.004286	 0.00725	 223.7	 223.7	 223.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10287	 0.004472	 0.030129	 0.02275	 250.61	 250.61	 250.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10361	 10286	 0.000615	 0.002332	 0.00078	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10736	 0.001544	 0.010334	 0.02174	 293.02	 293.02	 293.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10736	 0.001544	 0.010334	 0.02174	 293.02	 293.02	 293.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 10736	 0.001544	 0.010334	 0.02174	 293.02	 293.02	 293.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10287	 10288	 0.000258	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10287	 10297	 0.00371	 0.017765	 0.00941	 219.89	 219.89	 219.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 10345	 0.001876	 0.014329	 0.00428	 210.64	 210.64	 210.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 10837	 0.004696	 0.024226	 0.01339	 233.49	 233.49	 233.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10361	 10290	 0.003007	 0.01412	 0.0038	 228.59	 228.59	 228.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10291	 10292	 0.000263	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10293	 10416	 0.001501	 0.010215	 0.0064	 196.42	 196.42	 196.42	 0.0	 0.0	 1	 -30.0	 30.0;
	10293	 10475	 0.004926	 0.035724	 0.02762	 219.06	 219.06	 219.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10294	 10295	 0.00024	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10364	 10295	 0.001842	 0.007364	 0.00125	 219.16	 219.16	 219.16	 0.0	 0.0	 1	 -30.0	 30.0;
	10296	 10297	 0.000288	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10297	 10373	 0.001314	 0.005736	 0.0043	 213.39	 213.39	 213.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10297	 10417	 0.001365	 0.007984	 0.00499	 226.81	 226.81	 226.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10298	 10299	 0.000299	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10300	 10301	 0.000226	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10380	 10300	 0.002654	 0.01404	 0.01102	 205.95	 205.95	 205.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10397	 10300	 0.00718	 0.041375	 0.01937	 183.06	 183.06	 183.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10302	 10303	 0.00028	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10302	 10304	 0.000296	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10302	 10305	 0.000253	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 10356	 0.001139	 0.004829	 0.00151	 260.0	 260.0	 260.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 10403	 0.001278	 0.00648	 0.0107	 257.81	 257.81	 257.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 10467	 0.001361	 0.007827	 0.01462	 256.77	 256.77	 256.77	 0.0	 0.0	 1	 -30.0	 30.0;
	10306	 10317	 0.002169	 0.01068	 0.00906	 257.55	 257.55	 257.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10307	 10308	 0.000265	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10308	 10356	 0.002315	 0.013071	 0.01106	 221.36	 221.36	 221.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10318	 10309	 0.001169	 0.007183	 0.00287	 280.86	 280.86	 280.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10318	 10309	 0.001169	 0.007183	 0.00287	 280.86	 280.86	 280.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10309	 10323	 0.000725	 0.003904	 0.01442	 266.32	 266.32	 266.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10310	 10326	 0.002105	 0.014649	 0.00692	 166.03	 166.03	 166.03	 0.0	 0.0	 1	 -30.0	 30.0;
	10375	 10310	 0.002275	 0.007627	 0.00298	 218.27	 218.27	 218.27	 0.0	 0.0	 1	 -30.0	 30.0;
	10311	 10312	 0.000289	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10311	 10313	 0.000224	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10313	 10362	 0.001994	 0.013953	 0.01461	 231.94	 231.94	 231.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10314	 10418	 0.002483	 0.015582	 0.01367	 183.16	 183.16	 183.16	 0.0	 0.0	 1	 -30.0	 30.0;
	10315	 10467	 0.003167	 0.019659	 0.02766	 237.1	 237.1	 237.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10316	 10317	 0.000201	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 10317	 0.000478	 0.002412	 0.00099	 274.18	 274.18	 274.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10409	 10318	 0.001906	 0.01154	 0.00354	 287.44	 287.44	 287.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10409	 10318	 0.001906	 0.01154	 0.00354	 287.44	 287.44	 287.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10409	 10318	 0.001906	 0.01154	 0.00354	 287.44	 287.44	 287.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10319	 10320	 0.00024	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10323	 10321	 0.001029	 0.005662	 0.00292	 211.07	 211.07	 211.07	 0.0	 0.0	 1	 -30.0	 30.0;
	10322	 10331	 0.001886	 0.008248	 0.00196	 265.31	 265.31	 265.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10324	 10325	 0.000268	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10327	 10328	 0.0002	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10327	 10329	 0.000214	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10329	 10338	 0.003404	 0.0106	 0.00345	 176.01	 176.01	 176.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 10330	 0.00037	 0.024663	 0.0	 594.3	 594.3	 594.3	 1.1	 0.0	 1	 -30.0	 30.0;
	10331	 10330	 0.00037	 0.024663	 0.0	 594.3	 594.3	 594.3	 1.1	 0.0	 1	 -30.0	 30.0;
	10331	 10330	 0.00037	 0.024663	 0.0	 594.3	 594.3	 594.3	 1.01875	 0.0	 1	 -30.0	 30.0;
	10330	 10332	 0.000256	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10353	 10330	 0.000308	 0.003491	 0.11293	 1192.38	 1192.38	 1192.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 10330	 0.00056	 0.006153	 0.11822	 1204.83	 1204.83	 1204.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 10331	 0.001106	 0.004951	 0.00226	 285.46	 285.46	 285.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 10331	 0.001106	 0.004951	 0.00226	 285.46	 285.46	 285.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 10331	 0.001106	 0.004951	 0.00226	 285.46	 285.46	 285.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10334	 10333	 0.000363	 0.028297	 0.0	 509.39	 509.39	 509.39	 1.0	 0.0	 1	 -30.0	 30.0;
	10333	 10427	 0.000406	 0.00496	 0.12515	 1137.85	 1137.85	 1137.85	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 10333	 0.000272	 0.003764	 0.11459	 1110.9	 1110.9	 1110.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10334	 10337	 0.0001	 0.000451	 0.0	 108.33	 108.33	 108.33	 1.0	 0.0	 1	 -30.0	 30.0;
	10334	 10339	 0.003366	 0.020012	 0.01672	 207.73	 207.73	 207.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 10337	 0.005516	 0.162499	 0.0	 54.16	 54.16	 54.16	 1.0	 0.0	 1	 -30.0	 30.0;
	10336	 10337	 0.005516	 0.162499	 0.0	 54.16	 54.16	 54.16	 1.0	 0.0	 1	 -30.0	 30.0;
	10338	 10431	 0.001902	 0.009167	 0.00247	 242.22	 242.22	 242.22	 0.0	 0.0	 1	 -30.0	 30.0;
	10446	 10338	 0.002548	 0.013336	 0.00925	 266.69	 266.69	 266.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10339	 10401	 0.002479	 0.013244	 0.01036	 238.41	 238.41	 238.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10340	 10341	 0.000237	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10340	 10342	 0.000244	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10341	 0.001506	 0.011627	 0.00948	 247.72	 247.72	 247.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10343	 10344	 0.000204	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10343	 10345	 0.000217	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10345	 10435	 0.009151	 0.051507	 0.01613	 235.04	 235.04	 235.04	 0.0	 0.0	 1	 -30.0	 30.0;
	10346	 10349	 0.000605	 0.041908	 0.0	 589.75	 589.75	 589.75	 1.0	 0.0	 1	 -30.0	 30.0;
	10346	 10353	 0.000263	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10347	 10349	 -6.8e-05	 -0.004743	 0.0	 467.64	 467.64	 467.64	 1.0	 0.0	 1	 -30.0	 30.0;
	10347	 10352	 0.0001	 -0.001949	 0.0	 108.26	 108.26	 108.26	 1.0	 0.0	 1	 -30.0	 30.0;
	10347	 10422	 0.002898	 0.014102	 0.01129	 223.13	 223.13	 223.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10347	 10436	 0.000343	 0.002169	 0.00108	 245.79	 245.79	 245.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10348	 10349	 0.003166	 0.21941	 0.0	 122.11	 122.11	 122.11	 1.0	 0.0	 1	 -30.0	 30.0;
	10350	 10352	 0.009235	 0.196555	 0.0	 54.13	 54.13	 54.13	 1.0	 0.0	 1	 -30.0	 30.0;
	10351	 10352	 0.009235	 0.196555	 0.0	 54.13	 54.13	 54.13	 1.0	 0.0	 1	 -30.0	 30.0;
	10414	 10353	 0.000511	 0.005664	 0.15077	 1237.11	 1237.11	 1237.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10353	 10468	 0.000417	 0.005958	 0.09723	 1118.63	 1118.63	 1118.63	 0.0	 0.0	 1	 -30.0	 30.0;
	10354	 10452	 0.001223	 0.008129	 0.01918	 210.0	 210.0	 210.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10354	 10461	 0.001325	 0.009078	 0.00476	 219.79	 219.79	 219.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10391	 10355	 0.000607	 0.004156	 0.00821	 201.85	 201.85	 201.85	 0.0	 0.0	 1	 -30.0	 30.0;
	10355	 10454	 0.00137	 0.006126	 0.00171	 213.37	 213.37	 213.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10411	 10356	 0.000999	 0.006638	 0.00846	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10360	 0.000526	 0.014084	 0.0	 231.62	 231.62	 231.62	 1.0	 0.0	 1	 -30.0	 30.0;
	10357	 10368	 0.001206	 0.009107	 0.00505	 253.22	 253.22	 253.22	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10401	 0.002245	 0.013761	 0.00843	 255.16	 255.16	 255.16	 0.0	 0.0	 1	 -30.0	 30.0;
	10357	 10473	 0.001508	 0.010036	 0.05926	 226.1	 226.1	 226.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10358	 10360	 0.005236	 0.140206	 0.0	 115.81	 115.81	 115.81	 1.0	 0.0	 1	 -30.0	 30.0;
	10359	 10360	 0.005236	 0.140206	 0.0	 115.81	 115.81	 115.81	 1.0	 0.0	 1	 -30.0	 30.0;
	10361	 10364	 0.003315	 0.019972	 0.02286	 241.83	 241.83	 241.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10415	 10362	 0.000804	 0.004024	 0.00139	 251.79	 251.79	 251.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10363	 10364	 0.000296	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 10364	 0.000693	 0.004218	 0.00816	 220.13	 220.13	 220.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10365	 10366	 0.000277	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 10365	 0.001643	 0.007885	 0.00369	 277.36	 277.36	 277.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 10365	 0.001643	 0.007885	 0.00369	 277.36	 277.36	 277.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10370	 10369	 0.000216	 0.014471	 0.0	 552.87	 552.87	 552.87	 1.0	 0.0	 1	 -30.0	 30.0;
	10728	 10369	 0.000817	 0.008139	 0.23813	 1145.78	 1145.78	 1145.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10369	 10893	 0.001669	 0.020408	 0.42951	 1319.14	 1319.14	 1319.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10398	 10370	 0.001653	 0.009698	 0.00719	 261.64	 261.64	 261.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10370	 10439	 0.001524	 0.008917	 0.00327	 234.09	 234.09	 234.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10473	 10370	 0.002806	 0.016514	 0.00974	 248.06	 248.06	 248.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10371	 10372	 0.000254	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10371	 10373	 0.000287	 0.001135	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10373	 10415	 0.001163	 0.006534	 0.00177	 211.47	 211.47	 211.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10374	 10407	 0.003179	 0.016469	 0.01733	 212.97	 212.97	 212.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10375	 10376	 0.000219	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10409	 10375	 0.001718	 0.008422	 0.00883	 213.52	 213.52	 213.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10375	 10447	 0.001693	 0.00971	 0.04065	 240.0	 240.0	 240.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10377	 10406	 0.001448	 0.009554	 0.00503	 159.62	 159.62	 159.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10377	 10464	 0.000463	 0.002677	 0.0054	 233.6	 233.6	 233.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10378	 10379	 0.000211	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13359	 10378	 0.00829	 0.026659	 0.02109	 213.38	 213.38	 213.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10380	 10471	 0.006361	 0.027058	 0.05504	 189.03	 189.03	 189.03	 0.0	 0.0	 1	 -30.0	 30.0;
	10381	 10382	 0.000263	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10439	 10382	 0.001145	 0.006265	 0.00253	 212.28	 212.28	 212.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10441	 10382	 0.000933	 0.006088	 0.01283	 174.7	 174.7	 174.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 10384	 0.000248	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 10436	 0.002025	 0.012223	 0.04751	 288.47	 288.47	 288.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10385	 10386	 0.000246	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10387	 10388	 0.000268	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10387	 10389	 0.000292	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10398	 10388	 0.003303	 0.02221	 0.01072	 243.35	 243.35	 243.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10390	 10449	 0.002016	 0.011094	 0.02679	 188.23	 188.23	 188.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10390	 10463	 0.006427	 0.032125	 0.01454	 214.33	 214.33	 214.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10391	 10392	 0.000296	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10410	 10391	 0.00202	 0.007773	 0.00413	 199.13	 199.13	 199.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10391	 10465	 0.003729	 0.024671	 0.02977	 210.8	 210.8	 210.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10415	 10393	 0.000269	 0.001878	 0.00336	 270.32	 270.32	 270.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10416	 10393	 0.001116	 0.006381	 0.00207	 240.0	 240.0	 240.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10449	 10394	 0.001086	 0.005888	 0.0095	 267.11	 267.11	 267.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10394	 10461	 0.002719	 0.020387	 0.0314	 251.44	 251.44	 251.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10395	 10420	 0.002181	 0.010935	 0.02783	 229.47	 229.47	 229.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10395	 10428	 0.001237	 0.00608	 0.00124	 270.74	 270.74	 270.74	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 10409	 0.000673	 0.003959	 0.00601	 293.55	 293.55	 293.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 10409	 0.000673	 0.003959	 0.00601	 293.55	 293.55	 293.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 10409	 0.000673	 0.003959	 0.00601	 293.55	 293.55	 293.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 10409	 0.000673	 0.003959	 0.00601	 293.55	 293.55	 293.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 10396	 0.001254	 0.008606	 0.00519	 303.18	 303.18	 303.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 10396	 0.001254	 0.008606	 0.00519	 303.18	 303.18	 303.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 10396	 0.001254	 0.008606	 0.00519	 303.18	 303.18	 303.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 10396	 0.001254	 0.008606	 0.00519	 303.18	 303.18	 303.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10399	 10400	 0.000227	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10399	 10401	 0.000246	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10402	 10403	 0.000228	 0.001178	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10402	 10404	 0.000288	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10402	 10405	 0.000214	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10406	 10431	 0.000652	 0.003828	 0.00227	 213.5	 213.5	 213.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10407	 10437	 0.000362	 0.002	 0.01358	 237.17	 237.17	 237.17	 0.0	 0.0	 1	 -30.0	 30.0;
	10408	 10409	 0.001022	 0.005988	 0.00244	 290.78	 290.78	 290.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10410	 10452	 0.001039	 0.00607	 0.00424	 239.94	 239.94	 239.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10411	 10428	 0.001126	 0.00489	 0.0029	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10412	 10413	 0.000213	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10466	 10412	 0.00458	 0.019806	 0.00686	 219.92	 219.92	 219.92	 0.0	 0.0	 1	 -30.0	 30.0;
	10412	 10729	 0.005551	 0.033239	 0.06044	 257.34	 257.34	 257.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10415	 10414	 0.000783	 0.03203	 0.0	 537.76	 537.76	 537.76	 1.0	 0.0	 1	 -30.0	 30.0;
	10735	 10414	 0.001028	 0.011157	 0.23075	 1312.55	 1312.55	 1312.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10414	 10838	 0.000651	 0.007215	 0.16126	 1170.38	 1170.38	 1170.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10416	 10475	 0.004547	 0.027115	 0.02771	 224.59	 224.59	 224.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10417	 10463	 0.005311	 0.036203	 0.01453	 253.18	 253.18	 253.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10418	 10419	 0.000294	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10418	 10490	 0.007262	 0.030455	 0.03023	 226.92	 226.92	 226.92	 0.0	 0.0	 1	 -30.0	 30.0;
	10421	 10420	 0.002995	 0.016351	 0.00432	 243.2	 243.2	 243.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10420	 10460	 0.000944	 0.005131	 0.00257	 413.86	 413.86	 413.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10477	 10421	 0.002559	 0.016063	 0.0076	 215.31	 215.31	 215.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10422	 10423	 0.000247	 0.001092	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10424	 10425	 0.000239	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 10424	 0.003922	 0.025794	 0.01319	 280.44	 280.44	 280.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 10424	 0.003922	 0.025794	 0.01319	 280.44	 280.44	 280.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10424	 10452	 0.000985	 0.007714	 0.00558	 257.24	 257.24	 257.24	 0.0	 0.0	 1	 -30.0	 30.0;
	10488	 10426	 0.002843	 0.020172	 0.01125	 210.89	 210.89	 210.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10426	 10489	 0.00217	 0.012023	 0.00595	 215.36	 215.36	 215.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10428	 10427	 0.000547	 0.024233	 0.0	 483.76	 483.76	 483.76	 1.05625	 0.0	 1	 -30.0	 30.0;
	10427	 10429	 0.000277	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10427	 10728	 0.000673	 0.008765	 0.28884	 1263.14	 1263.14	 1263.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10428	 10447	 0.00041	 0.00331	 0.00094	 316.94	 316.94	 316.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10430	 10431	 0.00028	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10433	 10432	 0.000265	 0.019062	 0.0	 509.57	 509.57	 509.57	 1.0125	 0.0	 1	 -30.0	 30.0;
	10432	 10462	 0.000596	 0.007225	 0.20622	 1372.69	 1372.69	 1372.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10432	 10701	 0.002754	 0.036539	 0.6771	 1337.31	 1337.31	 1337.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10432	 10735	 0.00055	 0.006436	 0.19102	 1263.59	 1263.59	 1263.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10434	 10433	 0.002516	 0.01212	 0.00302	 276.83	 276.83	 276.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10498	 10433	 0.004535	 0.033548	 0.02311	 188.28	 188.28	 188.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10434	 10475	 0.006214	 0.025813	 0.0251	 265.37	 265.37	 265.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 10435	 0.005199	 0.028418	 0.03445	 249.99	 249.99	 249.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10436	 10437	 0.000511	 0.002363	 0.0014	 301.41	 301.41	 301.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10437	 10438	 0.000216	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10437	 10454	 0.001121	 0.007962	 0.00172	 219.74	 219.74	 219.74	 0.0	 0.0	 1	 -30.0	 30.0;
	10441	 10440	 0.002631	 0.014219	 0.00704	 216.15	 216.15	 216.15	 0.0	 0.0	 1	 -30.0	 30.0;
	10471	 10440	 0.001882	 0.014423	 0.02237	 252.43	 252.43	 252.43	 0.0	 0.0	 1	 -30.0	 30.0;
	10441	 10495	 0.007687	 0.048842	 0.03824	 203.9	 203.9	 203.9	 0.0	 0.0	 1	 -30.0	 30.0;
	10442	 10443	 0.000233	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10442	 10444	 0.000238	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10456	 10443	 0.00875	 0.057484	 0.0173	 208.97	 208.97	 208.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10443	 10471	 0.006951	 0.033748	 0.09017	 226.18	 226.18	 226.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10495	 10443	 0.006587	 0.035772	 0.01744	 239.91	 239.91	 239.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10443	 10759	 0.008909	 0.056395	 0.05916	 269.11	 269.11	 269.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10445	 10446	 0.000202	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10446	 10458	 0.001497	 0.009459	 0.00313	 336.64	 336.64	 336.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10447	 10448	 0.000246	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10449	 10463	 0.001167	 0.007063	 0.00586	 275.82	 275.82	 275.82	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 10451	 0.000296	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 10450	 0.000951	 0.006289	 0.00759	 292.48	 292.48	 292.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 10450	 0.000951	 0.006289	 0.00759	 292.48	 292.48	 292.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 10450	 0.000951	 0.006289	 0.00759	 292.48	 292.48	 292.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10490	 10450	 0.003576	 0.023457	 0.01129	 254.2	 254.2	 254.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10452	 10483	 0.002111	 0.009696	 0.00779	 212.55	 212.55	 212.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10453	 10454	 0.000246	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10453	 10455	 0.000288	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10456	 11037	 0.01053	 0.073254	 0.03267	 247.61	 247.61	 247.61	 0.0	 0.0	 1	 -30.0	 30.0;
	11037	 10457	 0.009955	 0.077225	 0.04506	 213.66	 213.66	 213.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 10460	 0.002205	 0.011595	 0.00673	 283.12	 283.12	 283.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 10460	 0.002205	 0.011595	 0.00673	 283.12	 283.12	 283.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 10460	 0.002205	 0.011595	 0.00673	 283.12	 283.12	 283.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 10459	 0.000165	 0.010577	 0.0	 650.11	 650.11	 650.11	 1.025	 0.0	 1	 -30.0	 30.0;
	10460	 10459	 0.000165	 0.010577	 0.0	 650.11	 650.11	 650.11	 1.025	 0.0	 1	 -30.0	 30.0;
	10460	 10459	 0.000165	 0.010577	 0.0	 800.0	 800.0	 800.0	 1.1	 0.0	 1	 -30.0	 30.0;
	10460	 10459	 0.000165	 0.010577	 0.0	 650.11	 650.11	 650.11	 1.025	 0.0	 1	 -30.0	 30.0;
	10468	 10459	 0.000589	 0.007062	 0.11102	 1031.53	 1031.53	 1031.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 10728	 0.000884	 0.011376	 0.23272	 1226.5	 1226.5	 1226.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 10893	 0.001652	 0.023343	 0.74282	 1337.32	 1337.32	 1337.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 11075	 0.00344	 0.04602	 1.64956	 1472.07	 1472.07	 1472.07	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 10462	 0.000287	 0.014033	 0.0	 641.96	 641.96	 641.96	 1.0	 0.0	 1	 -30.0	 30.0;
	10463	 10462	 0.000287	 0.014033	 0.0	 641.96	 641.96	 641.96	 1.0	 0.0	 1	 -30.0	 30.0;
	10463	 10462	 0.000287	 0.014033	 0.0	 641.96	 641.96	 641.96	 1.0	 0.0	 1	 -30.0	 30.0;
	10462	 10468	 0.000602	 0.006787	 0.23886	 1062.79	 1062.79	 1062.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 10486	 0.005133	 0.022939	 0.01145	 250.94	 250.94	 250.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10464	 10469	 0.001855	 0.008111	 0.00284	 255.34	 255.34	 255.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10469	 10465	 0.000999	 0.007294	 0.00917	 240.18	 240.18	 240.18	 0.0	 0.0	 1	 -30.0	 30.0;
	10466	 10502	 0.007696	 0.04657	 0.03128	 185.2	 185.2	 185.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10469	 10468	 0.000622	 0.033417	 0.0	 501.69	 501.69	 501.69	 1.0375	 0.0	 1	 -30.0	 30.0;
	10468	 10708	 0.002939	 0.032966	 1.42932	 1533.44	 1533.44	 1533.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10470	 10471	 0.000229	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10470	 10472	 0.000294	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10496	 10471	 0.004128	 0.027136	 0.01848	 250.2	 250.2	 250.2	 0.0	 0.0	 1	 -30.0	 30.0;
	10473	 10474	 0.000257	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13668	 10476	 0.006195	 0.036348	 0.01995	 257.31	 257.31	 257.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10484	 10477	 0.001384	 0.007965	 0.00467	 207.63	 207.63	 207.63	 0.0	 0.0	 1	 -30.0	 30.0;
	10505	 10477	 0.004095	 0.020723	 0.01663	 204.89	 204.89	 204.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10478	 10479	 0.000215	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10478	 10480	 0.000203	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10480	 10481	 0.001002	 0.00416	 0.00214	 227.98	 227.98	 227.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10480	 10952	 0.006224	 0.032637	 0.03354	 246.69	 246.69	 246.69	 0.0	 0.0	 1	 -30.0	 30.0;
	10481	 10482	 0.000285	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10484	 10481	 0.003017	 0.01271	 0.00771	 204.16	 204.16	 204.16	 0.0	 0.0	 1	 -30.0	 30.0;
	10483	 10485	 0.003442	 0.012485	 0.00853	 193.95	 193.95	 193.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10483	 10866	 0.008139	 0.044779	 0.0344	 239.25	 239.25	 239.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10486	 10485	 0.004141	 0.024561	 0.0106	 235.51	 235.51	 235.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10485	 10492	 0.000622	 0.003542	 0.00094	 189.37	 189.37	 189.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10487	 10492	 0.001345	 0.009265	 0.00689	 225.53	 225.53	 225.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10487	 10502	 0.005577	 0.037364	 0.01987	 181.39	 181.39	 181.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10487	 10801	 0.006783	 0.045105	 0.05282	 248.32	 248.32	 248.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10504	 10488	 0.003788	 0.02544	 0.0269	 238.95	 238.95	 238.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10490	 10491	 0.000233	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10493	 10494	 0.000285	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10493	 13368	 0.053727	 0.339944	 0.11106	 189.6	 189.6	 189.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10493	 13376	 0.008817	 0.052775	 0.04436	 231.36	 231.36	 231.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13664	 10493	 0.006106	 0.040239	 0.01917	 216.25	 216.25	 216.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10496	 10497	 0.000274	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10496	 10805	 0.022202	 0.097159	 0.16158	 268.95	 268.95	 268.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10498	 10501	 0.000108	 0.00376	 0.0	 275.23	 275.23	 275.23	 1.0	 0.0	 1	 -30.0	 30.0;
	10967	 10498	 0.042251	 0.19018	 0.05793	 222.53	 222.53	 222.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10499	 10501	 0.002186	 0.07624	 0.0	 137.62	 137.62	 137.62	 1.0	 0.0	 1	 -30.0	 30.0;
	10500	 10501	 0.002186	 0.07624	 0.0	 137.62	 137.62	 137.62	 1.0	 0.0	 1	 -30.0	 30.0;
	10503	 10510	 0.003652	 0.01361	 0.07819	 180.63	 180.63	 180.63	 0.0	 0.0	 1	 -30.0	 30.0;
	10503	 10512	 0.002017	 0.014182	 0.00685	 218.71	 218.71	 218.71	 0.0	 0.0	 1	 -30.0	 30.0;
	10512	 10504	 0.005869	 0.03542	 0.00591	 186.12	 186.12	 186.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10504	 10729	 0.001381	 0.009165	 0.00354	 259.97	 259.97	 259.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10926	 10505	 0.003913	 0.031022	 0.01026	 218.02	 218.02	 218.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 10507	 0.000299	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 10525	 0.018822	 0.101135	 0.09322	 237.64	 237.64	 237.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10926	 10506	 0.001718	 0.009285	 0.00252	 220.32	 220.32	 220.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10508	 10509	 0.000294	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10508	 10510	 0.000258	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10508	 10511	 0.00024	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10510	 10926	 0.003364	 0.018338	 0.00735	 209.48	 209.48	 209.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10512	 10513	 0.000233	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10516	 10512	 0.003013	 0.017911	 0.01096	 225.3	 225.3	 225.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10516	 10514	 0.009785	 0.058311	 0.01689	 233.73	 233.73	 233.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10514	 10518	 0.012161	 0.078136	 0.02706	 245.73	 245.73	 245.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10515	 10538	 0.01203	 0.087579	 0.18527	 271.66	 271.66	 271.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10515	 10801	 0.003452	 0.0187	 0.00899	 260.02	 260.02	 260.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10517	 13380	 0.009537	 0.047967	 0.01919	 188.17	 188.17	 188.17	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 10517	 0.020902	 0.126936	 0.02524	 192.03	 192.03	 192.03	 0.0	 0.0	 1	 -30.0	 30.0;
	10518	 10556	 0.016417	 0.115579	 0.10895	 248.7	 248.7	 248.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10531	 10519	 0.014087	 0.089439	 0.04168	 197.19	 197.19	 197.19	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 10967	 0.021384	 0.125796	 0.0173	 171.91	 171.91	 171.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10520	 10521	 0.000299	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10520	 10522	 0.00024	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 10522	 0.002299	 0.013898	 0.00486	 256.77	 256.77	 256.77	 0.0	 0.0	 1	 -30.0	 30.0;
	10522	 13517	 0.013508	 0.061315	 0.08029	 261.54	 261.54	 261.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10523	 10527	 0.016634	 0.0751	 0.03777	 226.46	 226.46	 226.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10523	 10967	 0.014742	 0.125682	 0.03298	 198.54	 198.54	 198.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10698	 10524	 0.014089	 0.056644	 0.01662	 257.98	 257.98	 257.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10524	 10952	 0.016597	 0.123028	 0.12925	 248.53	 248.53	 248.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10525	 10538	 0.015697	 0.098026	 0.04878	 249.68	 249.68	 249.68	 0.0	 0.0	 1	 -30.0	 30.0;
	10526	 10705	 0.003608	 0.022023	 0.01166	 191.67	 191.67	 191.67	 0.0	 0.0	 1	 -30.0	 30.0;
	13498	 10526	 0.00605	 0.032238	 0.03855	 179.1	 179.1	 179.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10527	 10528	 0.000201	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10527	 10566	 0.013124	 0.068178	 0.11441	 230.66	 230.66	 230.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10529	 10535	 0.006377	 0.033972	 0.02236	 202.44	 202.44	 202.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10529	 10745	 0.020381	 0.116457	 0.04706	 241.67	 241.67	 241.67	 0.0	 0.0	 1	 -30.0	 30.0;
	10531	 10530	 0.008669	 0.046154	 0.01669	 230.97	 230.97	 230.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10535	 10530	 0.00464	 0.028753	 0.03393	 249.58	 249.58	 249.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10530	 10542	 0.005705	 0.032625	 0.03681	 193.11	 193.11	 193.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10532	 10533	 0.000242	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10535	 10532	 0.003492	 0.023358	 0.01297	 228.47	 228.47	 228.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10536	 10532	 0.003602	 0.024563	 0.00993	 180.15	 180.15	 180.15	 0.0	 0.0	 1	 -30.0	 30.0;
	10535	 10534	 0.00078	 0.040684	 0.0	 462.35	 462.35	 462.35	 1.03125	 0.0	 1	 -30.0	 30.0;
	10534	 10681	 0.001145	 0.013347	 0.3985	 1167.28	 1167.28	 1167.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10536	 10557	 0.008326	 0.054528	 0.04191	 221.46	 221.46	 221.46	 0.0	 0.0	 1	 -30.0	 30.0;
	10537	 10538	 0.000209	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10537	 10539	 0.000276	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10709	 10538	 0.006305	 0.03159	 0.0187	 281.93	 281.93	 281.93	 0.0	 0.0	 1	 -30.0	 30.0;
	10709	 10538	 0.006305	 0.03159	 0.0187	 281.93	 281.93	 281.93	 0.0	 0.0	 1	 -30.0	 30.0;
	10709	 10538	 0.006305	 0.03159	 0.0187	 281.93	 281.93	 281.93	 0.0	 0.0	 1	 -30.0	 30.0;
	10541	 10540	 0.004196	 0.024454	 0.00907	 228.74	 228.74	 228.74	 0.0	 0.0	 1	 -30.0	 30.0;
	10540	 10544	 0.008263	 0.042611	 0.04381	 197.75	 197.75	 197.75	 0.0	 0.0	 1	 -30.0	 30.0;
	10980	 10541	 0.00825	 0.039767	 0.01962	 250.19	 250.19	 250.19	 0.0	 0.0	 1	 -30.0	 30.0;
	10542	 10544	 0.004036	 0.024641	 0.0061	 225.99	 225.99	 225.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10543	 10544	 0.00022	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10543	 10545	 0.000267	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10544	 10569	 0.011765	 0.065112	 0.13422	 239.53	 239.53	 239.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10546	 10547	 0.000276	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10556	 10546	 0.005103	 0.031837	 0.09914	 236.62	 236.62	 236.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10546	 10873	 0.008262	 0.061276	 0.04542	 245.52	 245.52	 245.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10548	 10549	 0.000226	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10550	 10548	 0.003464	 0.022281	 0.01282	 179.67	 179.67	 179.67	 0.0	 0.0	 1	 -30.0	 30.0;
	10548	 10562	 0.004988	 0.030116	 0.01965	 223.84	 223.84	 223.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10550	 10980	 0.008478	 0.03769	 0.10636	 229.01	 229.01	 229.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10551	 10552	 0.000299	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10551	 10553	 0.000288	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10553	 10556	 0.01141	 0.072861	 0.02569	 212.23	 212.23	 212.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10579	 10553	 0.022087	 0.139647	 0.06918	 215.42	 215.42	 215.42	 0.0	 0.0	 1	 -30.0	 30.0;
	10554	 10566	 0.005618	 0.039305	 0.0239	 199.59	 199.59	 199.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10554	 11068	 0.019227	 0.081778	 0.06353	 225.23	 225.23	 225.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10555	 10556	 0.000254	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10557	 10682	 0.011135	 0.057738	 0.03603	 249.72	 249.72	 249.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10559	 10558	 0.001648	 0.011102	 0.00356	 199.61	 199.61	 199.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10719	 10558	 0.005195	 0.036673	 0.02069	 205.66	 205.66	 205.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10559	 10578	 0.014072	 0.073692	 0.0623	 227.41	 227.41	 227.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10560	 10561	 0.000291	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10560	 10562	 0.000251	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10562	 10719	 0.010124	 0.044343	 0.01518	 228.91	 228.91	 228.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 10564	 0.00022	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 10565	 0.000217	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10873	 10565	 0.005264	 0.028506	 0.00793	 232.48	 232.48	 232.48	 0.0	 0.0	 1	 -30.0	 30.0;
	11076	 10565	 0.001498	 0.010813	 0.07189	 242.6	 242.6	 242.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10566	 13410	 0.013099	 0.086129	 0.03181	 226.99	 226.99	 226.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10567	 10568	 0.000232	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10575	 10568	 0.007064	 0.042377	 0.03597	 215.41	 215.41	 215.41	 0.0	 0.0	 1	 -30.0	 30.0;
	13410	 10568	 0.015855	 0.091236	 0.05736	 148.07	 148.07	 148.07	 0.0	 0.0	 1	 -30.0	 30.0;
	10569	 10570	 0.000266	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10576	 10569	 0.014687	 0.073079	 0.0369	 207.04	 207.04	 207.04	 0.0	 0.0	 1	 -30.0	 30.0;
	10569	 10587	 0.011168	 0.052906	 0.06792	 242.02	 242.02	 242.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10571	 10579	 0.008347	 0.039526	 0.04541	 225.44	 225.44	 225.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10749	 10571	 0.003426	 0.020609	 0.01134	 234.44	 234.44	 234.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10572	 10573	 0.00025	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10572	 10577	 0.005384	 0.028164	 0.0431	 179.11	 179.11	 179.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10572	 10907	 0.015032	 0.069778	 0.0308	 199.07	 199.07	 199.07	 0.0	 0.0	 1	 -30.0	 30.0;
	10574	 10575	 0.000251	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10575	 10581	 0.007123	 0.044567	 0.02544	 188.88	 188.88	 188.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10575	 13676	 0.006085	 0.032187	 0.12194	 243.34	 243.34	 243.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10576	 10682	 0.006119	 0.031179	 0.06028	 214.87	 214.87	 214.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 10577	 0.007314	 0.031726	 0.0293	 231.53	 231.53	 231.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10578	 10582	 0.00502	 0.021621	 0.00804	 213.48	 213.48	 213.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10578	 11047	 0.00736	 0.039544	 0.05684	 223.29	 223.29	 223.29	 0.0	 0.0	 1	 -30.0	 30.0;
	10579	 10580	 0.00027	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10589	 10581	 0.00779	 0.050868	 0.01939	 195.21	 195.21	 195.21	 0.0	 0.0	 1	 -30.0	 30.0;
	10900	 10582	 0.008284	 0.039506	 0.01996	 225.0	 225.0	 225.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10583	 10584	 0.000263	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10583	 10589	 0.002975	 0.016424	 0.0053	 202.33	 202.33	 202.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10583	 10810	 0.00406	 0.020922	 0.04617	 227.1	 227.1	 227.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 10585	 0.003082	 0.01819	 0.01097	 224.48	 224.48	 224.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10585	 10606	 0.005501	 0.035872	 0.07431	 168.26	 168.26	 168.26	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 10586	 0.000611	 0.026059	 0.0	 424.51	 424.51	 424.51	 1.0125	 0.0	 1	 -30.0	 30.0;
	10586	 10588	 0.000266	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10586	 10899	 0.001233	 0.01483	 0.19006	 1161.1	 1161.1	 1161.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10590	 10589	 0.00153	 0.00843	 0.00386	 182.62	 182.62	 182.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10589	 11062	 0.003861	 0.027009	 0.02491	 159.54	 159.54	 159.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10589	 13472	 0.006919	 0.03928	 0.11398	 227.71	 227.71	 227.71	 0.0	 0.0	 1	 -30.0	 30.0;
	10590	 10810	 0.008986	 0.054586	 0.01848	 209.51	 209.51	 209.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 10592	 0.000292	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 10593	 0.000256	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10593	 10605	 0.006212	 0.024771	 0.07035	 155.0	 155.0	 155.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13414	 10593	 0.005756	 0.032428	 0.06653	 194.15	 194.15	 194.15	 0.0	 0.0	 1	 -30.0	 30.0;
	10593	 13418	 0.012625	 0.070427	 0.06215	 201.51	 201.51	 201.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10594	 10601	 0.000931	 0.005571	 0.01137	 219.42	 219.42	 219.42	 0.0	 0.0	 1	 -30.0	 30.0;
	10594	 10975	 0.005914	 0.025828	 0.01455	 237.63	 237.63	 237.63	 0.0	 0.0	 1	 -30.0	 30.0;
	10595	 10596	 0.000254	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10595	 10597	 0.01547	 0.103227	 0.03637	 195.22	 195.22	 195.22	 0.0	 0.0	 1	 -30.0	 30.0;
	10611	 10595	 0.019451	 0.086799	 0.05458	 211.85	 211.85	 211.85	 0.0	 0.0	 1	 -30.0	 30.0;
	10595	 10900	 0.011325	 0.069728	 0.2784	 187.16	 187.16	 187.16	 0.0	 0.0	 1	 -30.0	 30.0;
	10597	 10598	 0.015172	 0.075511	 0.04634	 168.35	 168.35	 168.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10615	 10598	 0.016481	 0.091322	 0.09355	 196.65	 196.65	 196.65	 0.0	 0.0	 1	 -30.0	 30.0;
	10599	 10600	 0.01656	 0.080478	 0.02672	 208.57	 208.57	 208.57	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 10599	 0.005385	 0.027744	 0.03996	 212.97	 212.97	 212.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10600	 10606	 0.005831	 0.031725	 0.01192	 193.31	 193.31	 193.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10614	 10600	 0.019429	 0.10756	 0.03674	 210.89	 210.89	 210.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10601	 10846	 0.004191	 0.018969	 0.05784	 201.86	 201.86	 201.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10602	 10603	 0.000211	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10603	 10613	 0.005237	 0.028186	 0.02146	 225.51	 225.51	 225.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10603	 11062	 0.008154	 0.041599	 0.01242	 189.83	 189.83	 189.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10604	 10605	 0.001999	 0.013274	 0.00231	 215.72	 215.72	 215.72	 0.0	 0.0	 1	 -30.0	 30.0;
	11064	 10604	 0.007009	 0.041199	 0.01142	 241.75	 241.75	 241.75	 0.0	 0.0	 1	 -30.0	 30.0;
	10607	 10608	 0.000274	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10846	 10608	 0.002212	 0.014231	 0.00798	 222.06	 222.06	 222.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10608	 10943	 0.009494	 0.062198	 0.06243	 220.77	 220.77	 220.77	 0.0	 0.0	 1	 -30.0	 30.0;
	10609	 10810	 0.005478	 0.028494	 0.04006	 225.27	 225.27	 225.27	 0.0	 0.0	 1	 -30.0	 30.0;
	10609	 10846	 0.008416	 0.059363	 0.02849	 216.54	 216.54	 216.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10610	 10611	 0.000274	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10610	 10612	 0.000266	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 10611	 0.006457	 0.034447	 0.01567	 226.12	 226.12	 226.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10846	 10613	 0.004612	 0.022186	 0.00765	 231.8	 231.8	 231.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10614	 10943	 0.009742	 0.062971	 0.01634	 222.23	 222.23	 222.23	 0.0	 0.0	 1	 -30.0	 30.0;
	10615	 10616	 0.000245	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10615	 11013	 0.028711	 0.168555	 0.05464	 208.64	 208.64	 208.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10617	 13439	 0.042951	 0.182489	 0.0929	 200.58	 200.58	 200.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10617	 13573	 0.007448	 0.035694	 0.02893	 222.13	 222.13	 222.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 10876	 0.046418	 0.146949	 0.081	 213.56	 213.56	 213.56	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 10968	 0.00991	 0.067115	 0.24944	 208.44	 208.44	 208.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10619	 10620	 0.000225	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 10619	 0.012003	 0.080314	 0.11587	 183.06	 183.06	 183.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10619	 11055	 0.026587	 0.128178	 0.02261	 192.41	 192.41	 192.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10621	 10622	 0.000247	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10621	 10623	 0.000275	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10627	 10623	 0.005551	 0.030838	 0.04306	 229.78	 229.78	 229.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10623	 10818	 0.002738	 0.016467	 0.00463	 241.53	 241.53	 241.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10624	 10625	 0.000201	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10624	 10659	 0.011008	 0.07025	 0.051	 218.06	 218.06	 218.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10624	 11057	 0.00581	 0.035842	 0.01909	 228.84	 228.84	 228.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10626	 10868	 0.004096	 0.024731	 0.17656	 215.11	 215.11	 215.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10626	 11055	 0.010197	 0.06565	 0.02094	 225.19	 225.19	 225.19	 0.0	 0.0	 1	 -30.0	 30.0;
	10627	 10629	 0.010047	 0.064515	 0.04481	 203.44	 203.44	 203.44	 0.0	 0.0	 1	 -30.0	 30.0;
	10628	 10630	 0.003949	 0.015158	 0.03061	 161.72	 161.72	 161.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10633	 10628	 0.003474	 0.022256	 0.05056	 154.34	 154.34	 154.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10628	 10676	 0.005872	 0.030269	 0.23696	 224.09	 224.09	 224.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10629	 10634	 0.021476	 0.093415	 0.02833	 161.58	 161.58	 161.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10630	 10790	 0.026647	 0.122151	 0.02497	 222.08	 222.08	 222.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10631	 10632	 0.000299	 0.001158	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10632	 10636	 0.004425	 0.030228	 0.0226	 234.7	 234.7	 234.7	 0.0	 0.0	 1	 -30.0	 30.0;
	10971	 10632	 0.00898	 0.058692	 0.01599	 249.65	 249.65	 249.65	 0.0	 0.0	 1	 -30.0	 30.0;
	10633	 10868	 0.004303	 0.019735	 0.00795	 222.8	 222.8	 222.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10971	 10634	 0.010663	 0.064662	 0.04336	 219.13	 219.13	 219.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10636	 10635	 0.003271	 0.016019	 0.00471	 219.58	 219.58	 219.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10635	 10647	 0.003116	 0.018564	 0.00375	 202.37	 202.37	 202.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10636	 10637	 0.000214	 0.001084	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10650	 10636	 0.002043	 0.009748	 0.0042	 218.25	 218.25	 218.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10644	 10638	 0.001256	 0.008261	 0.00589	 186.01	 186.01	 186.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10638	 10648	 0.002356	 0.016718	 0.00717	 221.81	 221.81	 221.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10779	 10638	 0.002321	 0.017425	 0.00649	 166.25	 166.25	 166.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10639	 10640	 0.00023	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10640	 10641	 0.002885	 0.019295	 0.01372	 224.01	 224.01	 224.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10640	 10665	 0.001586	 0.009149	 0.05736	 181.15	 181.15	 181.15	 0.0	 0.0	 1	 -30.0	 30.0;
	10641	 10665	 0.00203	 0.015949	 0.00614	 228.3	 228.3	 228.3	 0.0	 0.0	 1	 -30.0	 30.0;
	10871	 10641	 0.000458	 0.003171	 0.00075	 266.99	 266.99	 266.99	 0.0	 0.0	 1	 -30.0	 30.0;
	10642	 10643	 0.000277	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10642	 10644	 0.000295	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10968	 10644	 0.002502	 0.010965	 0.00648	 207.62	 207.62	 207.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10645	 10646	 0.000248	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10645	 10826	 0.005523	 0.031798	 0.04817	 209.27	 209.27	 209.27	 0.0	 0.0	 1	 -30.0	 30.0;
	74011	 10645	 0.02131	 0.092641	 0.03059	 197.52	 197.52	 197.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10652	 10647	 0.004	 0.025853	 0.00927	 232.33	 232.33	 232.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10656	 10648	 0.004519	 0.027647	 0.01002	 180.89	 180.89	 180.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10648	 10662	 0.001535	 0.008238	 0.00414	 253.87	 253.87	 253.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10651	 10649	 0.001161	 0.006972	 0.00335	 212.48	 212.48	 212.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10649	 10662	 0.002957	 0.022182	 0.02718	 239.14	 239.14	 239.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10871	 10650	 0.002432	 0.01368	 0.00321	 243.49	 243.49	 243.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10651	 10779	 0.002627	 0.013239	 0.00402	 203.6	 203.6	 203.6	 0.0	 0.0	 1	 -30.0	 30.0;
	10652	 10658	 0.005567	 0.030457	 0.02765	 222.38	 222.38	 222.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10652	 74021	 0.007806	 0.04646	 0.05279	 214.61	 214.61	 214.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10653	 10654	 0.000293	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10662	 10654	 0.001365	 0.006645	 0.00459	 275.94	 275.94	 275.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10654	 10671	 0.002588	 0.018569	 0.00856	 217.98	 217.98	 217.98	 0.0	 0.0	 1	 -30.0	 30.0;
	10654	 74002	 0.004987	 0.031731	 0.06839	 238.21	 238.21	 238.21	 0.0	 0.0	 1	 -30.0	 30.0;
	10655	 10656	 0.000257	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10656	 10662	 0.004963	 0.024426	 0.01534	 216.62	 216.62	 216.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10657	 10665	 0.001854	 0.008302	 0.00297	 171.41	 171.41	 171.41	 0.0	 0.0	 1	 -30.0	 30.0;
	10657	 10671	 0.00593	 0.02937	 0.01088	 222.5	 222.5	 222.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10666	 10658	 0.004518	 0.021858	 0.01456	 229.88	 229.88	 229.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10659	 74014	 0.017866	 0.08424	 0.03763	 195.82	 195.82	 195.82	 0.0	 0.0	 1	 -30.0	 30.0;
	10660	 10679	 0.005883	 0.033285	 0.01356	 202.59	 202.59	 202.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10660	 10871	 0.003943	 0.020559	 0.00817	 205.79	 205.79	 205.79	 0.0	 0.0	 1	 -30.0	 30.0;
	10662	 10661	 0.000381	 0.026172	 0.0	 521.12	 521.12	 521.12	 1.08125	 0.0	 1	 -30.0	 30.0;
	10661	 10663	 0.000242	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10661	 10664	 0.000217	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10970	 10661	 0.0011	 0.012	 0.26	 1100.0	 1100.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 10663	 0.003047	 0.033367	 0.51462	 1038.29	 1038.29	 1038.29	 0.0	 0.0	 1	 -30.0	 30.0;
	10663	 74234	 0.002796	 0.038534	 0.7293	 1220.24	 1220.24	 1220.24	 0.0	 0.0	 1	 -30.0	 30.0;
	10666	 10667	 0.000243	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10666	 74300	 0.007549	 0.039474	 0.03806	 236.89	 236.89	 236.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10674	 10668	 0.002261	 0.013906	 0.00394	 179.21	 179.21	 179.21	 0.0	 0.0	 1	 -30.0	 30.0;
	10668	 10678	 0.00356	 0.024168	 0.0234	 236.5	 236.5	 236.5	 0.0	 0.0	 1	 -30.0	 30.0;
	10669	 10826	 0.00513	 0.03299	 0.00807	 223.36	 223.36	 223.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74011	 10669	 0.013783	 0.080363	 0.02222	 182.95	 182.95	 182.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10670	 10826	 0.007706	 0.042427	 0.02163	 229.65	 229.65	 229.65	 0.0	 0.0	 1	 -30.0	 30.0;
	10670	 74027	 0.011216	 0.0511	 0.05149	 189.01	 189.01	 189.01	 0.0	 0.0	 1	 -30.0	 30.0;
	10671	 74025	 0.009336	 0.056124	 0.02219	 216.0	 216.0	 216.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10672	 74300	 0.008226	 0.034292	 0.01216	 212.82	 212.82	 212.82	 0.0	 0.0	 1	 -30.0	 30.0;
	10672	 77184	 0.021758	 0.147352	 0.25922	 229.49	 229.49	 229.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 10673	 0.003747	 0.024317	 0.03706	 196.17	 196.17	 196.17	 0.0	 0.0	 1	 -30.0	 30.0;
	74006	 10673	 0.004238	 0.022904	 0.0137	 226.13	 226.13	 226.13	 0.0	 0.0	 1	 -30.0	 30.0;
	10674	 10675	 0.000217	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10674	 10679	 0.002996	 0.018932	 0.00909	 189.78	 189.78	 189.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10676	 10677	 0.000266	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10676	 10790	 0.012219	 0.062825	 0.08326	 234.74	 234.74	 234.74	 0.0	 0.0	 1	 -30.0	 30.0;
	10676	 74003	 0.003951	 0.022327	 0.05018	 201.11	 201.11	 201.11	 0.0	 0.0	 1	 -30.0	 30.0;
	10678	 74241	 0.004623	 0.030748	 0.03838	 248.71	 248.71	 248.71	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 74024	 0.008352	 0.050569	 0.04425	 211.06	 211.06	 211.06	 0.0	 0.0	 1	 -30.0	 30.0;
	10681	 10680	 0.000117	 0.008837	 0.0	 1409.3	 1409.3	 1409.3	 1.0	 0.0	 1	 -30.0	 30.0;
	10680	 10683	 9.7e-05	 0.008845	 0.0	 1374.96	 1374.96	 1374.96	 1.0	 0.0	 1	 -30.0	 30.0;
	10680	 10684	 0.00011	 0.009473	 0.0	 1371.62	 1371.62	 1371.62	 1.03125	 0.0	 1	 -30.0	 30.0;
	10680	 10685	 0.000114	 0.009549	 0.0	 1369.65	 1369.65	 1369.65	 1.03125	 0.0	 1	 -30.0	 30.0;
	10680	 10686	 7.5e-05	 0.006805	 0.0	 1369.55	 1369.55	 1369.55	 1.0	 0.0	 1	 -30.0	 30.0;
	10680	 10687	 9.4e-05	 0.007209	 0.0	 1369.41	 1369.41	 1369.41	 1.03125	 0.0	 1	 -30.0	 30.0;
	10680	 10688	 0.000144	 0.010392	 0.0	 1368.2	 1368.2	 1368.2	 1.03125	 0.0	 1	 -30.0	 30.0;
	10680	 10812	 0.000109	 0.003064	 1.70908	 4069.09	 4069.09	 4069.09	 0.0	 0.0	 1	 -30.0	 30.0;
	10680	 10905	 6.3e-05	 0.001807	 0.77514	 3916.79	 3916.79	 3916.79	 0.0	 0.0	 1	 -30.0	 30.0;
	11000	 10680	 0.000267	 0.008217	 3.72116	 4131.05	 4131.05	 4131.05	 0.0	 0.0	 1	 -30.0	 30.0;
	10682	 10681	 0.000377	 0.024336	 0.0	 427.61	 427.61	 427.61	 1.00625	 0.0	 1	 -30.0	 30.0;
	10681	 10689	 0.000751	 0.047881	 0.0	 246.76	 246.76	 246.76	 1.04375	 0.0	 1	 -30.0	 30.0;
	10681	 10915	 0.000744	 0.008155	 0.2455	 1037.07	 1037.07	 1037.07	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 10691	 0.003387	 0.09989	 0.0	 128.57	 128.57	 128.57	 1.0625	 0.0	 1	 -30.0	 30.0;
	10690	 10692	 0.000271	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 10984	 0.00298	 0.020982	 0.01492	 207.33	 207.33	 207.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10690	 11068	 0.000499	 0.00316	 0.00055	 215.94	 215.94	 215.94	 0.0	 0.0	 1	 -30.0	 30.0;
	10693	 10696	 0.0001	 -0.002474	 0.0	 305.93	 305.93	 305.93	 1.0	 0.0	 1	 -30.0	 30.0;
	10693	 10863	 0.013117	 0.069516	 0.02325	 167.02	 167.02	 167.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10694	 10696	 0.003524	 0.0978	 0.0	 152.97	 152.97	 152.97	 1.0	 0.0	 1	 -30.0	 30.0;
	10695	 10696	 0.003524	 0.0978	 0.0	 152.97	 152.97	 152.97	 1.0	 0.0	 1	 -30.0	 30.0;
	10698	 10697	 0.000671	 0.041763	 0.0	 411.67	 411.67	 411.67	 1.0	 0.0	 1	 -30.0	 30.0;
	10697	 10699	 0.000728	 0.041443	 0.0	 420.33	 420.33	 420.33	 1.03125	 0.0	 1	 -30.0	 30.0;
	10697	 10700	 0.000238	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10697	 10701	 0.000208	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10701	 10718	 0.001483	 0.018455	 0.35262	 1199.55	 1199.55	 1199.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10701	 10979	 0.001496	 0.017808	 0.20963	 1197.59	 1197.59	 1197.59	 0.0	 0.0	 1	 -30.0	 30.0;
	10702	 10703	 0.002458	 0.078799	 0.0	 177.19	 177.19	 177.19	 1.0	 0.0	 1	 -30.0	 30.0;
	10702	 10704	 0.000288	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10702	 10705	 0.000251	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10702	 10706	 0.000265	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10705	 11002	 0.003464	 0.020038	 0.01269	 138.48	 138.48	 138.48	 0.0	 0.0	 1	 -30.0	 30.0;
	10705	 13380	 0.012476	 0.083937	 0.09402	 266.68	 266.68	 266.68	 0.0	 0.0	 1	 -30.0	 30.0;
	10708	 10707	 0.000122	 0.00891	 0.0	 1500.23	 1500.23	 1500.23	 1.0125	 0.0	 1	 -30.0	 30.0;
	10707	 10710	 0.000128	 0.01077	 0.0	 1518.59	 1518.59	 1518.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	10707	 10711	 9.8e-05	 0.007513	 0.0	 1517.03	 1517.03	 1517.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	10707	 10712	 0.000131	 0.009968	 0.0	 1515.27	 1515.27	 1515.27	 1.01875	 0.0	 1	 -30.0	 30.0;
	10707	 10713	 8.4e-05	 0.006774	 0.0	 1513.23	 1513.23	 1513.23	 1.01875	 0.0	 1	 -30.0	 30.0;
	10707	 10714	 9.1e-05	 0.007524	 0.0	 1509.97	 1509.97	 1509.97	 1.0	 0.0	 1	 -30.0	 30.0;
	10707	 10715	 5e-05	 0.003603	 0.0	 1505.34	 1505.34	 1505.34	 1.0125	 0.0	 1	 -30.0	 30.0;
	10707	 10716	 0.00028	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10709	 10708	 0.000443	 0.02894	 0.0	 522.31	 522.31	 522.31	 1.00625	 0.0	 1	 -30.0	 30.0;
	10718	 10708	 0.000684	 0.007909	 0.17775	 1094.29	 1094.29	 1094.29	 0.0	 0.0	 1	 -30.0	 30.0;
	11075	 10708	 0.001688	 0.019496	 0.41561	 1258.58	 1258.58	 1258.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10716	 10717	 7.1e-05	 0.001952	 0.82174	 4009.72	 4009.72	 4009.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10716	 10734	 0.000421	 0.011339	 5.17633	 4230.58	 4230.58	 4230.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10716	 11011	 0.000242	 0.006647	 4.30227	 4243.33	 4243.33	 4243.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10718	 10717	 8.3e-05	 0.007694	 0.0	 1453.13	 1453.13	 1453.13	 1.0	 0.0	 1	 -30.0	 30.0;
	10717	 10722	 0.000119	 0.01019	 0.0	 1223.71	 1223.71	 1223.71	 1.0	 0.0	 1	 -30.0	 30.0;
	10717	 10723	 0.000115	 0.009029	 0.0	 1223.22	 1223.22	 1223.22	 1.0375	 0.0	 1	 -30.0	 30.0;
	10717	 10724	 0.000153	 0.011674	 0.0	 1221.95	 1221.95	 1221.95	 1.0375	 0.0	 1	 -30.0	 30.0;
	10717	 10725	 0.000201	 0.013611	 0.0	 1216.91	 1216.91	 1216.91	 1.0375	 0.0	 1	 -30.0	 30.0;
	10717	 10726	 0.00019	 0.014406	 0.0	 1216.82	 1216.82	 1216.82	 1.0375	 0.0	 1	 -30.0	 30.0;
	10717	 10727	 0.000114	 0.010215	 0.0	 1216.07	 1216.07	 1216.07	 1.0	 0.0	 1	 -30.0	 30.0;
	10717	 10861	 0.000506	 0.013992	 7.90759	 4141.28	 4141.28	 4141.28	 0.0	 0.0	 1	 -30.0	 30.0;
	10717	 10892	 0.000506	 0.015145	 8.23779	 4081.31	 4081.31	 4081.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10905	 10717	 0.000121	 0.003353	 2.15736	 3936.47	 3936.47	 3936.47	 0.0	 0.0	 1	 -30.0	 30.0;
	10717	 11074	 0.000211	 0.005142	 2.28746	 4192.26	 4192.26	 4192.26	 0.0	 0.0	 1	 -30.0	 30.0;
	10718	 10721	 0.000981	 0.064124	 0.0	 468.05	 468.05	 468.05	 1.0	 0.0	 1	 -30.0	 30.0;
	10719	 10721	 -0.000479	 -0.031287	 0.0	 393.05	 393.05	 393.05	 1.0	 0.0	 1	 -30.0	 30.0;
	10720	 10721	 0.0025	 0.163386	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10729	 10728	 0.000587	 0.030543	 0.0	 472.2	 472.2	 472.2	 1.05	 0.0	 1	 -30.0	 30.0;
	10728	 10748	 0.004455	 0.052705	 1.37519	 1373.72	 1373.72	 1373.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10769	 10728	 0.002188	 0.026147	 0.83143	 1335.66	 1335.66	 1335.66	 0.0	 0.0	 1	 -30.0	 30.0;
	10730	 10733	 0.000309	 0.017989	 0.0	 547.05	 547.05	 547.05	 1.0	 0.0	 1	 -30.0	 30.0;
	10731	 10733	 0.000184	 0.010729	 0.0	 422.05	 422.05	 422.05	 1.0	 0.0	 1	 -30.0	 30.0;
	11010	 10731	 0.005798	 0.023621	 0.00689	 210.97	 210.97	 210.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10732	 10733	 0.003194	 0.185771	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10735	 10734	 7.1e-05	 0.006325	 0.0	 1777.25	 1777.25	 1777.25	 1.1	 0.0	 1	 -30.0	 30.0;
	10735	 10734	 7.1e-05	 0.006325	 0.0	 1777.25	 1777.25	 1777.25	 1.0125	 0.0	 1	 -30.0	 30.0;
	10735	 10734	 7.1e-05	 0.006325	 0.0	 1777.25	 1777.25	 1777.25	 1.0125	 0.0	 1	 -30.0	 30.0;
	10734	 10737	 0.000103	 0.0079	 0.0	 1367.63	 1367.63	 1367.63	 1.0	 0.0	 1	 -30.0	 30.0;
	10734	 10738	 9.4e-05	 0.008084	 0.0	 1366.92	 1366.92	 1366.92	 1.0	 0.0	 1	 -30.0	 30.0;
	10734	 10861	 0.000139	 0.003895	 1.53156	 4058.84	 4058.84	 4058.84	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 10735	 0.00047	 0.032143	 0.0	 635.96	 635.96	 635.96	 1.03125	 0.0	 1	 -30.0	 30.0;
	10736	 10735	 0.00047	 0.032143	 0.0	 635.96	 635.96	 635.96	 1.03125	 0.0	 1	 -30.0	 30.0;
	10736	 10735	 0.00047	 0.032143	 0.0	 635.96	 635.96	 635.96	 1.03125	 0.0	 1	 -30.0	 30.0;
	10735	 10838	 0.000459	 0.005262	 0.18851	 1391.4	 1391.4	 1391.4	 0.0	 0.0	 1	 -30.0	 30.0;
	10837	 10736	 0.000527	 0.002626	 0.00124	 313.07	 313.07	 313.07	 0.0	 0.0	 1	 -30.0	 30.0;
	10740	 10739	 0.000142	 0.009907	 0.0	 1461.79	 1461.79	 1461.79	 1.0	 0.0	 1	 -30.0	 30.0;
	10739	 10742	 0.0001	 0.006783	 0.0	 1100.75	 1100.75	 1100.75	 1.0	 0.0	 1	 -30.0	 30.0;
	10739	 10743	 0.000148	 0.009913	 0.0	 1092.82	 1092.82	 1092.82	 1.0	 0.0	 1	 -30.0	 30.0;
	10739	 10744	 0.00014	 0.010367	 0.0	 1088.73	 1088.73	 1088.73	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 10739	 0.000112	 0.00334	 1.84027	 3975.91	 3975.91	 3975.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10741	 10740	 0.000438	 0.023334	 0.0	 443.91	 443.91	 443.91	 1.0	 0.0	 1	 -30.0	 30.0;
	10813	 10740	 0.00054	 0.006387	 0.09147	 1330.97	 1330.97	 1330.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10862	 10740	 0.001157	 0.011576	 0.68304	 1129.14	 1129.14	 1129.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10741	 10935	 0.003023	 0.014204	 0.00604	 239.1	 239.1	 239.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10745	 10746	 0.003229	 0.108939	 0.0	 117.0	 117.0	 117.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10907	 10745	 0.006184	 0.032203	 0.02173	 182.56	 182.56	 182.56	 0.0	 0.0	 1	 -30.0	 30.0;
	10748	 10747	 3.8e-05	 0.003145	 0.0	 1568.88	 1568.88	 1568.88	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10750	 8.5e-05	 0.00725	 0.0	 1751.97	 1751.97	 1751.97	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10751	 3.2e-05	 0.00247	 0.0	 1746.69	 1746.69	 1746.69	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10752	 7.7e-05	 0.006647	 0.0	 1744.98	 1744.98	 1744.98	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10753	 6.6e-05	 0.005051	 0.0	 1744.39	 1744.39	 1744.39	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10754	 9.7e-05	 0.008412	 0.0	 1741.07	 1741.07	 1741.07	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10755	 0.000143	 0.01035	 0.0	 1741.0	 1741.0	 1741.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10747	 10916	 0.000325	 0.009305	 5.77305	 4211.49	 4211.49	 4211.49	 0.0	 0.0	 1	 -30.0	 30.0;
	11011	 10747	 0.000134	 0.00365	 1.80593	 4182.56	 4182.56	 4182.56	 0.0	 0.0	 1	 -30.0	 30.0;
	10747	 11074	 4.8e-05	 0.001296	 0.64688	 3989.97	 3989.97	 3989.97	 0.0	 0.0	 1	 -30.0	 30.0;
	10749	 10748	 0.000546	 0.032224	 0.0	 383.66	 383.66	 383.66	 1.0	 0.0	 1	 -30.0	 30.0;
	10748	 11075	 0.000474	 0.00517	 0.14721	 1221.53	 1221.53	 1221.53	 0.0	 0.0	 1	 -30.0	 30.0;
	10757	 10756	 0.000497	 0.025725	 0.0	 342.9	 342.9	 342.9	 1.0	 0.0	 1	 -30.0	 30.0;
	10862	 10756	 0.00045	 0.005221	 0.10018	 1149.78	 1149.78	 1149.78	 0.0	 0.0	 1	 -30.0	 30.0;
	10928	 10756	 0.000548	 0.007139	 0.2422	 1177.14	 1177.14	 1177.14	 0.0	 0.0	 1	 -30.0	 30.0;
	10759	 10758	 0.000296	 0.017731	 0.0	 445.0	 445.0	 445.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10769	 10758	 0.00126	 0.016442	 0.29828	 1170.86	 1170.86	 1170.86	 0.0	 0.0	 1	 -30.0	 30.0;
	10758	 10917	 0.001661	 0.01972	 0.42495	 1235.83	 1235.83	 1235.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10761	 10760	 0.0004	 0.024124	 0.0	 492.83	 492.83	 492.83	 1.01875	 0.0	 1	 -30.0	 30.0;
	10760	 10762	 0.000275	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10760	 10763	 0.000203	 0.001111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10760	 10764	 0.000222	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10760	 10765	 0.000206	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10761	 13335	 0.004876	 0.026285	 0.01686	 222.55	 222.55	 222.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10761	 13350	 0.002037	 0.013212	 0.00343	 242.12	 242.12	 242.12	 0.0	 0.0	 1	 -30.0	 30.0;
	13302	 10762	 0.00036	 0.004639	 0.12628	 1369.2	 1369.2	 1369.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13340	 10762	 0.000408	 0.004971	 0.10258	 1198.32	 1198.32	 1198.32	 0.0	 0.0	 1	 -30.0	 30.0;
	10762	 13621	 0.002097	 0.023568	 1.1807	 1390.95	 1390.95	 1390.95	 0.0	 0.0	 1	 -30.0	 30.0;
	10762	 13667	 0.001131	 0.012195	 0.28031	 1305.33	 1305.33	 1305.33	 0.0	 0.0	 1	 -30.0	 30.0;
	10767	 10766	 0.000768	 0.03855	 0.0	 349.08	 349.08	 349.08	 1.00625	 0.0	 1	 -30.0	 30.0;
	10766	 10768	 0.000302	 0.021447	 0.0	 582.49	 582.49	 582.49	 1.01875	 0.0	 1	 -30.0	 30.0;
	10766	 11056	 0.000572	 0.007684	 0.16824	 1103.19	 1103.19	 1103.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13438	 10766	 0.00093	 0.013019	 0.3065	 1221.54	 1221.54	 1221.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13432	 10767	 0.016488	 0.106146	 0.0317	 216.62	 216.62	 216.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 10769	 0.000291	 0.018045	 0.0	 387.62	 387.62	 387.62	 1.0	 0.0	 1	 -30.0	 30.0;
	10769	 10771	 0.000542	 0.034268	 0.0	 338.29	 338.29	 338.29	 1.0	 0.0	 1	 -30.0	 30.0;
	10769	 10772	 0.000739	 0.039135	 0.0	 336.68	 336.68	 336.68	 1.0	 0.0	 1	 -30.0	 30.0;
	10769	 10773	 0.000615	 0.040206	 0.0	 335.58	 335.58	 335.58	 1.0	 0.0	 1	 -30.0	 30.0;
	10769	 10774	 0.000524	 0.02833	 0.0	 332.79	 332.79	 332.79	 1.0	 0.0	 1	 -30.0	 30.0;
	10917	 10769	 0.000381	 0.004718	 0.08604	 1376.23	 1376.23	 1376.23	 0.0	 0.0	 1	 -30.0	 30.0;
	11037	 10770	 0.009152	 0.062067	 0.05034	 239.88	 239.88	 239.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10775	 10776	 0.005603	 0.149224	 0.0	 84.98	 84.98	 84.98	 1.025	 0.0	 1	 -30.0	 30.0;
	10775	 10777	 0.000272	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10777	 10894	 0.000661	 0.003824	 0.00088	 231.68	 231.68	 231.68	 0.0	 0.0	 1	 -30.0	 30.0;
	10778	 10779	 0.000244	 0.001186	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10778	 10780	 0.000203	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10781	 10782	 0.005502	 0.170771	 0.0	 70.82	 70.82	 70.82	 1.0	 0.0	 1	 -30.0	 30.0;
	10781	 10783	 0.015615	 0.529781	 0.0	 29.87	 29.87	 29.87	 1.0	 0.0	 1	 -30.0	 30.0;
	11036	 10781	 0.00144	 0.007815	 0.01165	 217.96	 217.96	 217.96	 0.0	 0.0	 1	 -30.0	 30.0;
	10785	 10784	 0.000456	 0.025571	 0.0	 469.32	 469.32	 469.32	 1.0	 0.0	 1	 -30.0	 30.0;
	10784	 10786	 0.000211	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10784	 10787	 0.000216	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10784	 10788	 0.000249	 0.001108	 0.0	 0.0	 0.0	 0.0	 1.0	 -12.0	 1	 -30.0	 30.0;
	10786	 11034	 0.000469	 0.005554	 0.12076	 1127.73	 1127.73	 1127.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10893	 10788	 0.001586	 0.014718	 0.39744	 995.83	 995.83	 995.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10790	 10789	 0.000372	 0.023115	 0.0	 409.3	 409.3	 409.3	 1.0	 0.0	 1	 -30.0	 30.0;
	10789	 10791	 0.000588	 0.036587	 0.0	 432.39	 432.39	 432.39	 1.025	 0.0	 1	 -30.0	 30.0;
	10789	 10792	 0.00022	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10789	 10793	 0.000286	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10825	 10793	 0.002061	 0.023539	 0.33709	 1030.17	 1030.17	 1030.17	 0.0	 0.0	 1	 -30.0	 30.0;
	10795	 10794	 0.000561	 0.036276	 0.0	 400.14	 400.14	 400.14	 1.00625	 0.0	 1	 -30.0	 30.0;
	10794	 10796	 0.000551	 0.033932	 0.0	 325.83	 325.83	 325.83	 1.0	 0.0	 1	 -30.0	 30.0;
	10794	 10797	 0.00064	 0.039291	 0.0	 403.19	 403.19	 403.19	 1.00625	 0.0	 1	 -30.0	 30.0;
	10794	 10799	 0.000288	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10795	 10798	 0.006997	 0.22473	 0.0	 75.8	 75.8	 75.8	 1.0125	 0.0	 1	 -30.0	 30.0;
	10893	 10799	 0.000331	 0.00393	 0.06746	 1295.51	 1295.51	 1295.51	 0.0	 0.0	 1	 -30.0	 30.0;
	10800	 10933	 0.006672	 0.027877	 0.03849	 241.12	 241.12	 241.12	 0.0	 0.0	 1	 -30.0	 30.0;
	10800	 13458	 0.009831	 0.060827	 0.04201	 219.01	 219.01	 219.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 10800	 0.006477	 0.041131	 0.01798	 227.08	 227.08	 227.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10801	 10804	 -0.000207	 -0.00651	 0.0	 166.94	 166.94	 166.94	 0.98125	 0.0	 1	 -30.0	 30.0;
	10801	 10866	 0.007035	 0.029674	 0.0067	 224.39	 224.39	 224.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10802	 10804	 0.004336	 0.136489	 0.0	 83.47	 83.47	 83.47	 1.0	 0.0	 1	 -30.0	 30.0;
	10803	 10804	 0.004336	 0.136489	 0.0	 83.47	 83.47	 83.47	 1.0	 0.0	 1	 -30.0	 30.0;
	10805	 10806	 0.00411	 0.112871	 0.0	 118.56	 118.56	 118.56	 1.0	 0.0	 1	 -30.0	 30.0;
	10805	 10807	 0.005022	 0.151362	 0.0	 118.56	 118.56	 118.56	 1.0	 0.0	 1	 -30.0	 30.0;
	10918	 10805	 0.004162	 0.018477	 0.00433	 212.05	 212.05	 212.05	 0.0	 0.0	 1	 -30.0	 30.0;
	10809	 10808	 0.000159	 0.012261	 0.0	 1314.67	 1314.67	 1314.67	 1.0	 0.0	 1	 -30.0	 30.0;
	10808	 10811	 0.000111	 0.010156	 0.0	 1955.01	 1955.01	 1955.01	 1.0	 0.0	 1	 -30.0	 30.0;
	10808	 10812	 0.000228	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 10809	 0.000385	 0.02395	 0.0	 470.0	 470.0	 470.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10809	 10974	 0.000843	 0.011989	 0.40394	 1061.96	 1061.96	 1061.96	 0.0	 0.0	 1	 -30.0	 30.0;
	10810	 10943	 0.009114	 0.042743	 0.25285	 236.49	 236.49	 236.49	 0.0	 0.0	 1	 -30.0	 30.0;
	10812	 13470	 0.000147	 0.004287	 1.76737	 4021.34	 4021.34	 4021.34	 0.0	 0.0	 1	 -30.0	 30.0;
	10813	 10816	 0.001412	 0.085371	 0.0	 568.17	 568.17	 568.17	 1.0	 0.0	 1	 -30.0	 30.0;
	10813	 10953	 0.000434	 0.005372	 0.14244	 1108.81	 1108.81	 1108.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10814	 10816	 -0.000919	 -0.055529	 0.0	 415.0	 415.0	 415.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10815	 10816	 0.003091	 0.186841	 0.0	 153.17	 153.17	 153.17	 1.0	 0.0	 1	 -30.0	 30.0;
	10818	 10817	 0.000355	 0.026402	 0.0	 387.51	 387.51	 387.51	 1.0	 0.0	 1	 -30.0	 30.0;
	10817	 10819	 0.000285	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10819	 11026	 0.003338	 0.040382	 0.61256	 1092.86	 1092.86	 1092.86	 0.0	 0.0	 1	 -30.0	 30.0;
	11039	 10819	 0.002398	 0.029072	 0.43724	 1108.55	 1108.55	 1108.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 10821	 0.001925	 0.061021	 0.0	 196.56	 196.56	 196.56	 1.0	 0.0	 1	 -30.0	 30.0;
	10820	 10822	 0.000252	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 10823	 0.000289	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13410	 10823	 0.010064	 0.045184	 0.02694	 194.47	 194.47	 194.47	 0.0	 0.0	 1	 -30.0	 30.0;
	13591	 10823	 0.004927	 0.031697	 0.04237	 194.39	 194.39	 194.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10824	 10828	 0.000272	 0.020027	 0.0	 1306.5	 1306.5	 1306.5	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10829	 0.000137	 0.013184	 0.0	 1343.94	 1343.94	 1343.94	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10830	 0.00011	 0.008714	 0.0	 1343.06	 1343.06	 1343.06	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10831	 0.000135	 0.010918	 0.0	 1342.71	 1342.71	 1342.71	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10832	 7.5e-05	 0.006331	 0.0	 1342.43	 1342.43	 1342.43	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10833	 0.000139	 0.010426	 0.0	 1340.6	 1340.6	 1340.6	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10834	 0.000103	 0.008988	 0.0	 1339.14	 1339.14	 1339.14	 1.0	 0.0	 1	 -30.0	 30.0;
	10824	 10835	 0.000225	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10826	 10825	 0.000349	 0.019525	 0.0	 426.83	 426.83	 426.83	 1.0	 0.0	 1	 -30.0	 30.0;
	10825	 10828	 -0.000142	 -0.010477	 0.0	 1274.35	 1274.35	 1274.35	 1.0	 0.0	 1	 -30.0	 30.0;
	10961	 10825	 0.001152	 0.01309	 0.20732	 1037.31	 1037.31	 1037.31	 0.0	 0.0	 1	 -30.0	 30.0;
	10825	 74217	 0.001206	 0.016046	 0.2917	 1077.54	 1077.54	 1077.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10827	 10828	 0.000663	 0.048745	 0.0	 32.15	 32.15	 32.15	 1.0	 0.0	 1	 -30.0	 30.0;
	10885	 10835	 0.000121	 0.003218	 1.5037	 3955.79	 3955.79	 3955.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13594	 10835	 0.000403	 0.012278	 5.13549	 4016.61	 4016.61	 4016.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10836	 10837	 0.000294	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10838	 10841	 0.000225	 0.018738	 0.0	 574.02	 574.02	 574.02	 1.0	 0.0	 1	 -30.0	 30.0;
	10839	 10841	 0.00022	 0.018368	 0.0	 524.02	 524.02	 524.02	 1.0	 0.0	 1	 -30.0	 30.0;
	10840	 10841	 0.002475	 0.206179	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10843	 10842	 0.000451	 0.026805	 0.0	 455.96	 455.96	 455.96	 1.00625	 0.0	 1	 -30.0	 30.0;
	10842	 10862	 0.001006	 0.011998	 0.22097	 1150.68	 1150.68	 1150.68	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 10843	 0.001753	 0.008361	 0.00645	 225.37	 225.37	 225.37	 0.0	 0.0	 1	 -30.0	 30.0;
	10845	 10844	 0.000113	 0.008986	 0.0	 1315.28	 1315.28	 1315.28	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10847	 0.000161	 0.01206	 0.0	 1213.67	 1213.67	 1213.67	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10848	 0.000156	 0.011912	 0.0	 1213.15	 1213.15	 1213.15	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10849	 0.000137	 0.011527	 0.0	 1212.68	 1212.68	 1212.68	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10850	 0.000204	 0.016043	 0.0	 1207.77	 1207.77	 1207.77	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10851	 0.000162	 0.011583	 0.0	 1207.05	 1207.05	 1207.05	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10852	 0.000153	 0.010857	 0.0	 1206.24	 1206.24	 1206.24	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10853	 0.000273	 0.020119	 0.0	 830.92	 830.92	 830.92	 1.0	 0.0	 1	 -30.0	 30.0;
	10844	 10855	 0.000227	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10846	 10845	 0.000677	 0.037678	 0.0	 415.43	 415.43	 415.43	 1.00625	 0.0	 1	 -30.0	 30.0;
	10845	 10854	 0.000221	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13465	 10846	 0.012596	 0.070536	 0.02737	 219.1	 219.1	 219.1	 0.0	 0.0	 1	 -30.0	 30.0;
	10942	 10854	 0.001275	 0.015666	 0.26621	 1113.29	 1113.29	 1113.29	 0.0	 0.0	 1	 -30.0	 30.0;
	10854	 10974	 0.000804	 0.009217	 0.1589	 1107.82	 1107.82	 1107.82	 0.0	 0.0	 1	 -30.0	 30.0;
	10855	 10941	 0.000135	 0.003586	 1.59146	 4116.08	 4116.08	 4116.08	 0.0	 0.0	 1	 -30.0	 30.0;
	13470	 10855	 0.00012	 0.00305	 2.08467	 4200.91	 4200.91	 4200.91	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 10856	 0.000104	 0.008197	 0.0	 1492.63	 1492.63	 1492.63	 1.0	 0.0	 1	 -30.0	 30.0;
	10856	 10859	 5e-05	 0.003934	 0.0	 1823.06	 1823.06	 1823.06	 1.0	 0.0	 1	 -30.0	 30.0;
	10856	 10860	 8e-05	 0.006397	 0.0	 1808.93	 1808.93	 1808.93	 1.0	 0.0	 1	 -30.0	 30.0;
	10856	 10861	 0.000272	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10858	 10857	 0.00035	 0.02919	 0.0	 470.04	 470.04	 470.04	 1.00625	 0.0	 1	 -30.0	 30.0;
	10857	 10928	 0.000395	 0.005133	 0.12574	 1312.36	 1312.36	 1312.36	 0.0	 0.0	 1	 -30.0	 30.0;
	10986	 10861	 0.000123	 0.003136	 2.4857	 3963.52	 3963.52	 3963.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10863	 10862	 0.000296	 0.014439	 0.0	 400.2	 400.2	 400.2	 1.0	 0.0	 1	 -30.0	 30.0;
	10862	 10864	 0.000354	 0.024793	 0.0	 487.52	 487.52	 487.52	 1.05	 0.0	 1	 -30.0	 30.0;
	10862	 10865	 0.000583	 0.035968	 0.0	 486.71	 486.71	 486.71	 1.05625	 0.0	 1	 -30.0	 30.0;
	10866	 10867	 0.008956	 0.200146	 0.0	 65.04	 65.04	 65.04	 1.0375	 0.0	 1	 -30.0	 30.0;
	10868	 10869	 0.006477	 0.24028	 0.0	 37.34	 37.34	 37.34	 1.0125	 0.0	 1	 -30.0	 30.0;
	10871	 10870	 0.000731	 0.036055	 0.0	 500.55	 500.55	 500.55	 1.0	 0.0	 1	 -30.0	 30.0;
	10870	 10872	 0.000428	 0.023662	 0.0	 372.8	 372.8	 372.8	 1.0	 0.0	 1	 -30.0	 30.0;
	10970	 10870	 0.001097	 0.011796	 0.26047	 1109.68	 1109.68	 1109.68	 0.0	 0.0	 1	 -30.0	 30.0;
	10870	 74207	 0.001246	 0.014249	 0.19186	 1074.88	 1074.88	 1074.88	 0.0	 0.0	 1	 -30.0	 30.0;
	10874	 10878	 0.00027	 0.018918	 0.0	 1382.94	 1382.94	 1382.94	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10879	 0.0001	 0.008392	 0.0	 1338.48	 1338.48	 1338.48	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10880	 7.5e-05	 0.005659	 0.0	 1336.22	 1336.22	 1336.22	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10881	 0.000125	 0.009844	 0.0	 1335.83	 1335.83	 1335.83	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10882	 9e-05	 0.007575	 0.0	 1333.57	 1333.57	 1333.57	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10883	 8.5e-05	 0.006855	 0.0	 1332.77	 1332.77	 1332.77	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10884	 0.000114	 0.009812	 0.0	 1332.61	 1332.61	 1332.61	 1.0	 0.0	 1	 -30.0	 30.0;
	10874	 10885	 0.00021	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10874	 10886	 0.000261	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10876	 10875	 0.000509	 0.027642	 0.0	 296.78	 296.78	 296.78	 1.0	 0.0	 1	 -30.0	 30.0;
	10875	 10878	 -0.000133	 -0.009335	 0.0	 1357.94	 1357.94	 1357.94	 1.0	 0.0	 1	 -30.0	 30.0;
	10942	 10875	 0.001435	 0.016131	 0.28509	 1123.87	 1123.87	 1123.87	 0.0	 0.0	 1	 -30.0	 30.0;
	10876	 10962	 0.005503	 0.03644	 0.01725	 206.72	 206.72	 206.72	 0.0	 0.0	 1	 -30.0	 30.0;
	10877	 10878	 0.000753	 0.052732	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10885	 10941	 0.000105	 0.002957	 1.51343	 3996.81	 3996.81	 3996.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 10887	 0.000448	 0.027229	 0.0	 407.69	 407.69	 407.69	 1.00625	 0.0	 1	 -30.0	 30.0;
	10887	 10889	 0.000501	 0.029795	 0.0	 403.35	 403.35	 403.35	 1.00625	 0.0	 1	 -30.0	 30.0;
	10887	 10890	 0.000937	 0.05412	 0.0	 320.01	 320.01	 320.01	 1.0	 0.0	 1	 -30.0	 30.0;
	10887	 10891	 0.00021	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11034	 10891	 0.001109	 0.012886	 0.3083	 993.89	 993.89	 993.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10893	 10892	 0.000109	 0.0089	 0.0	 1618.31	 1618.31	 1618.31	 1.00625	 0.0	 1	 -30.0	 30.0;
	10893	 10892	 0.000109	 0.0089	 0.0	 1618.31	 1618.31	 1618.31	 1.1	 0.0	 1	 -30.0	 30.0;
	10893	 10892	 0.000109	 0.0089	 0.0	 1618.31	 1618.31	 1618.31	 1.00625	 0.0	 1	 -30.0	 30.0;
	10892	 10895	 0.000152	 0.011481	 0.0	 1150.24	 1150.24	 1150.24	 1.0	 0.0	 1	 -30.0	 30.0;
	10892	 10896	 0.000162	 0.012266	 0.0	 1147.62	 1147.62	 1147.62	 1.0	 0.0	 1	 -30.0	 30.0;
	10892	 10897	 0.0001	 0.007965	 0.0	 1144.94	 1144.94	 1144.94	 1.0	 0.0	 1	 -30.0	 30.0;
	10892	 10898	 0.000142	 0.009568	 0.0	 1143.44	 1143.44	 1143.44	 1.0	 0.0	 1	 -30.0	 30.0;
	10892	 10916	 0.000267	 0.007225	 4.75886	 4073.52	 4073.52	 4073.52	 0.0	 0.0	 1	 -30.0	 30.0;
	10894	 10893	 0.000483	 0.028961	 0.0	 483.05	 483.05	 483.05	 1.05625	 0.0	 1	 -30.0	 30.0;
	10900	 10899	 0.000451	 0.030048	 0.0	 346.8	 346.8	 346.8	 1.0	 0.0	 1	 -30.0	 30.0;
	10899	 10902	 0.000528	 0.030927	 0.0	 325.84	 325.84	 325.84	 1.0	 0.0	 1	 -30.0	 30.0;
	11026	 10899	 0.0018	 0.021962	 0.35155	 1193.39	 1193.39	 1193.39	 0.0	 0.0	 1	 -30.0	 30.0;
	10900	 10901	 0.006046	 0.172592	 0.0	 80.12	 80.12	 80.12	 1.0	 0.0	 1	 -30.0	 30.0;
	10900	 11047	 0.007167	 0.03896	 0.01687	 204.75	 204.75	 204.75	 0.0	 0.0	 1	 -30.0	 30.0;
	10903	 10904	 0.003579	 0.111028	 0.0	 91.9	 91.9	 91.9	 0.99375	 0.0	 1	 -30.0	 30.0;
	10903	 10933	 0.013447	 0.07711	 0.05418	 228.35	 228.35	 228.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10903	 10984	 0.002054	 0.010477	 0.0046	 195.96	 195.96	 195.96	 0.0	 0.0	 1	 -30.0	 30.0;
	10906	 10905	 0.000109	 0.008192	 0.0	 1400.45	 1400.45	 1400.45	 1.0	 0.0	 1	 -30.0	 30.0;
	10905	 10908	 0.000118	 0.009119	 0.0	 1393.06	 1393.06	 1393.06	 1.00625	 0.0	 1	 -30.0	 30.0;
	10905	 10909	 0.000118	 0.009298	 0.0	 1390.94	 1390.94	 1390.94	 1.0	 0.0	 1	 -30.0	 30.0;
	10905	 10910	 7.4e-05	 0.005974	 0.0	 1389.36	 1389.36	 1389.36	 1.0125	 0.0	 1	 -30.0	 30.0;
	10905	 10911	 0.000134	 0.008634	 0.0	 1388.65	 1388.65	 1388.65	 1.0	 0.0	 1	 -30.0	 30.0;
	10905	 10912	 9.6e-05	 0.007331	 0.0	 1385.24	 1385.24	 1385.24	 1.0125	 0.0	 1	 -30.0	 30.0;
	10905	 10913	 9.9e-05	 0.008615	 0.0	 1384.0	 1384.0	 1384.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10905	 10914	 0.000211	 0.017805	 0.0	 826.69	 826.69	 826.69	 1.0125	 0.0	 1	 -30.0	 30.0;
	10907	 10906	 0.000372	 0.025607	 0.0	 322.59	 322.59	 322.59	 1.0	 0.0	 1	 -30.0	 30.0;
	10906	 10915	 0.00028	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10915	 10979	 0.000595	 0.006829	 0.26311	 1161.73	 1161.73	 1161.73	 0.0	 0.0	 1	 -30.0	 30.0;
	10917	 10916	 5.4e-05	 0.004417	 0.0	 1569.35	 1569.35	 1569.35	 1.0	 0.0	 1	 -30.0	 30.0;
	10916	 10919	 0.000234	 0.016125	 0.0	 1241.69	 1241.69	 1241.69	 0.99375	 0.0	 1	 -30.0	 30.0;
	10916	 10920	 0.000161	 0.013347	 0.0	 1238.06	 1238.06	 1238.06	 1.0	 0.0	 1	 -30.0	 30.0;
	10916	 10921	 0.000153	 0.011364	 0.0	 1237.33	 1237.33	 1237.33	 0.99375	 0.0	 1	 -30.0	 30.0;
	10916	 10922	 0.000161	 0.013338	 0.0	 1236.84	 1236.84	 1236.84	 1.0	 0.0	 1	 -30.0	 30.0;
	10918	 10917	 0.000416	 0.026911	 0.0	 338.72	 338.72	 338.72	 1.0	 0.0	 1	 -30.0	 30.0;
	11028	 10923	 0.000138	 0.000773	 0.00033	 203.83	 203.83	 203.83	 0.0	 0.0	 1	 -30.0	 30.0;
	10924	 10925	 0.009416	 0.261948	 0.0	 58.96	 58.96	 58.96	 1.0	 0.0	 1	 -30.0	 30.0;
	10924	 10926	 0.000241	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10924	 10927	 0.000232	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10929	 10928	 0.000561	 0.030717	 0.0	 439.89	 439.89	 439.89	 1.00625	 0.0	 1	 -30.0	 30.0;
	10928	 10930	 0.000466	 0.032611	 0.0	 552.45	 552.45	 552.45	 1.0	 0.0	 1	 -30.0	 30.0;
	10928	 10931	 0.000193	 0.014048	 0.0	 549.1	 549.1	 549.1	 1.0	 0.0	 1	 -30.0	 30.0;
	10928	 10932	 0.000464	 0.028889	 0.0	 548.58	 548.58	 548.58	 1.0	 0.0	 1	 -30.0	 30.0;
	10958	 10933	 0.002169	 0.012465	 0.00539	 336.31	 336.31	 336.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13498	 10933	 0.003804	 0.018927	 0.01222	 207.26	 207.26	 207.26	 0.0	 0.0	 1	 -30.0	 30.0;
	10934	 10935	 0.000216	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10934	 10936	 0.000275	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10937	 10938	 0.012033	 0.353978	 0.0	 27.49	 27.49	 27.49	 1.0	 0.0	 1	 -30.0	 30.0;
	10937	 10939	 0.035941	 1.145095	 0.0	 9.75	 9.75	 9.75	 1.0	 0.0	 1	 -30.0	 30.0;
	10937	 10940	 0.050383	 1.490127	 0.0	 9.75	 9.75	 9.75	 1.0	 0.0	 1	 -30.0	 30.0;
	10937	 10988	 0.006127	 0.037825	 0.03162	 195.02	 195.02	 195.02	 0.0	 0.0	 1	 -30.0	 30.0;
	10942	 10941	 0.000162	 0.014331	 0.0	 1347.89	 1347.89	 1347.89	 1.0	 0.0	 1	 -30.0	 30.0;
	10941	 10944	 0.000139	 0.011658	 0.0	 1330.72	 1330.72	 1330.72	 1.0	 0.0	 1	 -30.0	 30.0;
	10941	 10945	 0.000154	 0.013104	 0.0	 1327.92	 1327.92	 1327.92	 1.0	 0.0	 1	 -30.0	 30.0;
	10941	 10946	 0.000102	 0.007822	 0.0	 1324.1	 1324.1	 1324.1	 1.0	 0.0	 1	 -30.0	 30.0;
	10941	 10947	 0.000132	 0.009974	 0.0	 1322.94	 1322.94	 1322.94	 1.0	 0.0	 1	 -30.0	 30.0;
	10941	 10948	 0.000124	 0.010305	 0.0	 1322.62	 1322.62	 1322.62	 1.0	 0.0	 1	 -30.0	 30.0;
	10941	 10949	 0.000112	 0.008687	 0.0	 1322.61	 1322.61	 1322.61	 1.0	 0.0	 1	 -30.0	 30.0;
	10943	 10942	 0.000483	 0.030763	 0.0	 432.54	 432.54	 432.54	 1.0	 0.0	 1	 -30.0	 30.0;
	13430	 10943	 0.015901	 0.094727	 0.05148	 194.64	 194.64	 194.64	 0.0	 0.0	 1	 -30.0	 30.0;
	10950	 10951	 0.008545	 0.251087	 0.0	 72.95	 72.95	 72.95	 1.0	 0.0	 1	 -30.0	 30.0;
	10950	 10952	 0.000213	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10954	 10953	 0.000368	 0.024141	 0.0	 450.63	 450.63	 450.63	 1.00625	 0.0	 1	 -30.0	 30.0;
	10953	 10955	 0.00037	 0.021985	 0.0	 390.0	 390.0	 390.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10953	 10956	 0.000436	 0.027417	 0.0	 388.47	 388.47	 388.47	 1.0	 0.0	 1	 -30.0	 30.0;
	10953	 11048	 0.000985	 0.011783	 0.27365	 1221.08	 1221.08	 1221.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10953	 11070	 0.001112	 0.013443	 0.3357	 1225.38	 1225.38	 1225.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 10957	 0.000458	 0.027813	 0.0	 437.61	 437.61	 437.61	 1.0	 0.0	 1	 -30.0	 30.0;
	10957	 10959	 0.000354	 0.018907	 0.0	 577.8	 577.8	 577.8	 1.04375	 0.0	 1	 -30.0	 30.0;
	10957	 10960	 0.000205	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13401	 0.0063	 0.035856	 0.05543	 300.89	 300.89	 300.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13401	 0.0063	 0.035856	 0.05543	 300.89	 300.89	 300.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13401	 0.0063	 0.035856	 0.05543	 300.89	 300.89	 300.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13401	 0.0063	 0.035856	 0.05543	 300.89	 300.89	 300.89	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13485	 0.00248	 0.018903	 0.14022	 291.38	 291.38	 291.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13485	 0.00248	 0.018903	 0.14022	 291.38	 291.38	 291.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10958	 13485	 0.00248	 0.018903	 0.14022	 291.38	 291.38	 291.38	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 11067	 0.001057	 0.01213	 0.36659	 1194.55	 1194.55	 1194.55	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 13516	 0.000466	 0.005757	 0.15366	 1235.08	 1235.08	 1235.08	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 13667	 0.001671	 0.021507	 0.82649	 1433.54	 1433.54	 1433.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10961	 10964	 0.000875	 0.065211	 0.0	 496.51	 496.51	 496.51	 1.0	 0.0	 1	 -30.0	 30.0;
	10961	 10965	 0.000257	 0.016645	 0.0	 597.63	 597.63	 597.63	 1.0	 0.0	 1	 -30.0	 30.0;
	10961	 11056	 0.000589	 0.006921	 0.11254	 1094.35	 1094.35	 1094.35	 0.0	 0.0	 1	 -30.0	 30.0;
	10962	 10964	 -0.000375	 -0.027993	 0.0	 346.51	 346.51	 346.51	 1.0	 0.0	 1	 -30.0	 30.0;
	11051	 10962	 0.007183	 0.04201	 0.00944	 200.58	 200.58	 200.58	 0.0	 0.0	 1	 -30.0	 30.0;
	10963	 10964	 0.002695	 0.200905	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10966	 10967	 0.000201	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10968	 10969	 0.006646	 0.198183	 0.0	 60.49	 60.49	 60.49	 1.0	 0.0	 1	 -30.0	 30.0;
	10971	 10970	 0.000496	 0.033215	 0.0	 421.32	 421.32	 421.32	 1.0	 0.0	 1	 -30.0	 30.0;
	11012	 10970	 0.0022	 0.024	 0.52	 1100.0	 1100.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10970	 74234	 0.003637	 0.035988	 1.16051	 1201.43	 1201.43	 1201.43	 0.0	 0.0	 1	 -30.0	 30.0;
	10971	 10972	 0.006126	 0.172754	 0.0	 68.55	 68.55	 68.55	 1.0	 0.0	 1	 -30.0	 30.0;
	10971	 10973	 0.00465	 0.137515	 0.0	 68.52	 68.52	 68.52	 1.0	 0.0	 1	 -30.0	 30.0;
	11055	 10971	 0.002779	 0.014501	 0.01022	 218.62	 218.62	 218.62	 0.0	 0.0	 1	 -30.0	 30.0;
	10974	 10977	 0.000509	 0.036259	 0.0	 483.1	 483.1	 483.1	 1.0	 0.0	 1	 -30.0	 30.0;
	10974	 10978	 0.000317	 0.01747	 0.0	 412.78	 412.78	 412.78	 1.0	 0.0	 1	 -30.0	 30.0;
	11066	 10974	 0.00043	 0.004805	 0.13177	 1128.81	 1128.81	 1128.81	 0.0	 0.0	 1	 -30.0	 30.0;
	10974	 13507	 0.000682	 0.008519	 0.4002	 1178.54	 1178.54	 1178.54	 0.0	 0.0	 1	 -30.0	 30.0;
	10975	 10977	 -0.000136	 -0.009661	 0.0	 383.1	 383.1	 383.1	 1.0	 0.0	 1	 -30.0	 30.0;
	10976	 10977	 0.001844	 0.131338	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10980	 10979	 0.000401	 0.026695	 0.0	 444.75	 444.75	 444.75	 1.00625	 0.0	 1	 -30.0	 30.0;
	10979	 10981	 0.000361	 0.023046	 0.0	 471.1	 471.1	 471.1	 1.0	 0.0	 1	 -30.0	 30.0;
	10979	 10982	 0.000246	 0.015028	 0.0	 470.55	 470.55	 470.55	 1.0	 0.0	 1	 -30.0	 30.0;
	10984	 10983	 0.000424	 0.029214	 0.0	 281.19	 281.19	 281.19	 1.0	 0.0	 1	 -30.0	 30.0;
	10983	 10985	 0.000274	 0.018775	 0.0	 519.94	 519.94	 519.94	 1.0	 0.0	 1	 -30.0	 30.0;
	11067	 10983	 0.000215	 0.002156	 0.10119	 1014.8	 1014.8	 1014.8	 0.0	 0.0	 1	 -30.0	 30.0;
	10983	 13505	 0.000827	 0.010103	 0.30979	 1208.24	 1208.24	 1208.24	 0.0	 0.0	 1	 -30.0	 30.0;
	10987	 10986	 7.4e-05	 0.005762	 0.0	 1559.03	 1559.03	 1559.03	 1.00625	 0.0	 1	 -30.0	 30.0;
	10986	 10989	 0.000104	 0.009435	 0.0	 1521.68	 1521.68	 1521.68	 1.0	 0.0	 1	 -30.0	 30.0;
	10986	 10990	 0.000121	 0.009022	 0.0	 1521.48	 1521.48	 1521.48	 1.0	 0.0	 1	 -30.0	 30.0;
	10986	 10991	 0.0001	 0.007344	 0.0	 1520.0	 1520.0	 1520.0	 1.0	 0.0	 1	 -30.0	 30.0;
	10988	 10987	 0.00033	 0.020206	 0.0	 478.1	 478.1	 478.1	 1.0	 0.0	 1	 -30.0	 30.0;
	10992	 10993	 0.007159	 0.159086	 0.0	 75.63	 75.63	 75.63	 1.0	 0.0	 1	 -30.0	 30.0;
	10992	 10994	 0.013978	 0.421369	 0.0	 38.68	 38.68	 38.68	 1.0	 0.0	 1	 -30.0	 30.0;
	10992	 10995	 0.008547	 0.247358	 0.0	 38.58	 38.58	 38.58	 1.0	 0.0	 1	 -30.0	 30.0;
	10992	 10996	 0.000294	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 10996	 0.005781	 0.033808	 0.04882	 194.61	 194.61	 194.61	 0.0	 0.0	 1	 -30.0	 30.0;
	10996	 74052	 0.02876	 0.180387	 0.04847	 187.25	 187.25	 187.25	 0.0	 0.0	 1	 -30.0	 30.0;
	10997	 10998	 0.001762	 0.05887	 0.0	 90.96	 90.96	 90.96	 1.00625	 0.0	 1	 -30.0	 30.0;
	10997	 10999	 0.000208	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11001	 11000	 8.5e-05	 0.006675	 0.0	 1321.68	 1321.68	 1321.68	 1.00625	 0.0	 1	 -30.0	 30.0;
	11000	 11005	 6.1e-05	 0.005566	 0.0	 1348.47	 1348.47	 1348.47	 1.0125	 0.0	 1	 -30.0	 30.0;
	11000	 11006	 8.8e-05	 0.007417	 0.0	 1347.93	 1347.93	 1347.93	 1.0125	 0.0	 1	 -30.0	 30.0;
	11000	 13470	 0.000241	 0.007392	 5.03125	 4166.28	 4166.28	 4166.28	 0.0	 0.0	 1	 -30.0	 30.0;
	11000	 13631	 7.1e-05	 0.002038	 1.33413	 4171.2	 4171.2	 4171.2	 0.0	 0.0	 1	 -30.0	 30.0;
	11000	 13666	 0.000214	 0.006337	 2.96301	 4163.81	 4163.81	 4163.81	 0.0	 0.0	 1	 -30.0	 30.0;
	11001	 11004	 0.000799	 0.04744	 0.0	 308.29	 308.29	 308.29	 1.0	 0.0	 1	 -30.0	 30.0;
	11001	 13484	 0.001046	 0.011527	 0.28226	 1205.62	 1205.62	 1205.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13505	 11001	 0.000476	 0.004887	 0.15193	 1187.05	 1187.05	 1187.05	 0.0	 0.0	 1	 -30.0	 30.0;
	11002	 11004	 -0.000396	 -0.023492	 0.0	 183.29	 183.29	 183.29	 1.0	 0.0	 1	 -30.0	 30.0;
	11003	 11004	 0.001641	 0.097413	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11007	 11008	 0.009449	 0.349705	 0.0	 41.36	 41.36	 41.36	 1.05	 0.0	 1	 -30.0	 30.0;
	11007	 11009	 0.003074	 0.094552	 0.0	 67.92	 67.92	 67.92	 1.03125	 0.0	 1	 -30.0	 30.0;
	11007	 11010	 0.000298	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11012	 11011	 0.000134	 0.010297	 0.0	 1456.46	 1456.46	 1456.46	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11014	 0.000136	 0.009991	 0.0	 1896.11	 1896.11	 1896.11	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11015	 0.000102	 0.008645	 0.0	 1867.48	 1867.48	 1867.48	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11016	 0.000102	 0.008082	 0.0	 1864.62	 1864.62	 1864.62	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11017	 7.4e-05	 0.00625	 0.0	 1862.67	 1862.67	 1862.67	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11018	 9.8e-05	 0.007147	 0.0	 1860.99	 1860.99	 1860.99	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11019	 9.1e-05	 0.00691	 0.0	 1858.12	 1858.12	 1858.12	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11020	 0.000127	 0.010419	 0.0	 1056.86	 1056.86	 1056.86	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11021	 0.000165	 0.013311	 0.0	 1045.97	 1045.97	 1045.97	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11022	 8.3e-05	 0.005969	 0.0	 1045.58	 1045.58	 1045.58	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11023	 0.000125	 0.010919	 0.0	 1041.64	 1041.64	 1041.64	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11024	 0.000116	 0.010067	 0.0	 1041.17	 1041.17	 1041.17	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11025	 0.000135	 0.010864	 0.0	 1036.0	 1036.0	 1036.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11011	 11038	 0.00041	 0.011851	 6.01005	 3971.97	 3971.97	 3971.97	 0.0	 0.0	 1	 -30.0	 30.0;
	11011	 11074	 0.00015	 0.004536	 2.70718	 4161.76	 4161.76	 4161.76	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 11012	 0.000488	 0.029055	 0.0	 395.62	 395.62	 395.62	 1.0	 0.0	 1	 -30.0	 30.0;
	11012	 11026	 0.000273	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11026	 11075	 0.002169	 0.022356	 0.54715	 1158.65	 1158.65	 1158.65	 0.0	 0.0	 1	 -30.0	 30.0;
	11027	 11030	 0.0011	 0.062918	 0.0	 583.46	 583.46	 583.46	 1.0	 0.0	 1	 -30.0	 30.0;
	11027	 11031	 0.000447	 0.024803	 0.0	 412.25	 412.25	 412.25	 0.98125	 0.0	 1	 -30.0	 30.0;
	11027	 11032	 0.000504	 0.033263	 0.0	 411.78	 411.78	 411.78	 0.98125	 0.0	 1	 -30.0	 30.0;
	11027	 11033	 0.000484	 0.033471	 0.0	 410.47	 410.47	 410.47	 0.98125	 0.0	 1	 -30.0	 30.0;
	11027	 11034	 0.000236	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11028	 11030	 -0.000498	 -0.028504	 0.0	 433.46	 433.46	 433.46	 1.0	 0.0	 1	 -30.0	 30.0;
	11029	 11030	 0.004031	 0.230498	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11035	 11036	 0.000226	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11036	 11071	 0.001069	 0.00579	 0.00226	 198.6	 198.6	 198.6	 0.0	 0.0	 1	 -30.0	 30.0;
	11039	 11038	 9.6e-05	 0.007443	 0.0	 1284.87	 1284.87	 1284.87	 1.0	 0.0	 1	 -30.0	 30.0;
	11038	 11041	 8.1e-05	 0.006033	 0.0	 1420.29	 1420.29	 1420.29	 1.0	 0.0	 1	 -30.0	 30.0;
	11038	 11042	 0.000114	 0.009339	 0.0	 1419.73	 1419.73	 1419.73	 1.0	 0.0	 1	 -30.0	 30.0;
	11038	 11043	 0.00011	 0.007788	 0.0	 1417.37	 1417.37	 1417.37	 1.0	 0.0	 1	 -30.0	 30.0;
	11038	 11044	 8.6e-05	 0.007833	 0.0	 1412.36	 1412.36	 1412.36	 1.0	 0.0	 1	 -30.0	 30.0;
	11038	 11045	 0.000128	 0.008827	 0.0	 1410.91	 1410.91	 1410.91	 1.0	 0.0	 1	 -30.0	 30.0;
	11038	 11046	 0.000132	 0.00985	 0.0	 1409.22	 1409.22	 1409.22	 1.0	 0.0	 1	 -30.0	 30.0;
	11040	 11039	 0.000713	 0.035293	 0.0	 293.86	 293.86	 293.86	 1.0	 0.0	 1	 -30.0	 30.0;
	74267	 11040	 0.018023	 0.097601	 0.07471	 156.94	 156.94	 156.94	 0.0	 0.0	 1	 -30.0	 30.0;
	11049	 11048	 0.000408	 0.020773	 0.0	 582.29	 582.29	 582.29	 1.01875	 0.0	 1	 -30.0	 30.0;
	11049	 11048	 0.000408	 0.020773	 0.0	 582.29	 582.29	 582.29	 1.1	 0.0	 1	 -30.0	 30.0;
	11048	 11050	 0.000494	 0.029607	 0.0	 574.96	 574.96	 574.96	 1.0	 0.0	 1	 -30.0	 30.0;
	13180	 11048	 0.000361	 0.004017	 0.07054	 1129.8	 1129.8	 1129.8	 0.0	 0.0	 1	 -30.0	 30.0;
	11048	 13302	 0.000422	 0.005371	 0.17849	 1217.22	 1217.22	 1217.22	 0.0	 0.0	 1	 -30.0	 30.0;
	11048	 13648	 0.001633	 0.022497	 0.47014	 1256.23	 1256.23	 1256.23	 0.0	 0.0	 1	 -30.0	 30.0;
	11049	 13123	 0.004494	 0.029868	 0.02877	 221.35	 221.35	 221.35	 0.0	 0.0	 1	 -30.0	 30.0;
	11049	 13155	 0.008345	 0.046357	 0.02243	 244.29	 244.29	 244.29	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 11049	 0.00101	 0.006321	 0.01764	 275.1	 275.1	 275.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 11049	 0.00101	 0.006321	 0.01764	 275.1	 275.1	 275.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 11049	 0.00101	 0.006321	 0.01764	 275.1	 275.1	 275.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13292	 11049	 0.001654	 0.008329	 0.00382	 230.24	 230.24	 230.24	 0.0	 0.0	 1	 -30.0	 30.0;
	11051	 11052	 0.00455	 0.147332	 0.0	 108.17	 108.17	 108.17	 1.0	 0.0	 1	 -30.0	 30.0;
	11051	 11053	 0.005534	 0.154464	 0.0	 107.69	 107.69	 107.69	 1.0	 0.0	 1	 -30.0	 30.0;
	11051	 13427	 0.008172	 0.042147	 0.29396	 262.91	 262.91	 262.91	 0.0	 0.0	 1	 -30.0	 30.0;
	11054	 11055	 0.00024	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11056	 11059	 -0.000116	 -0.005758	 0.0	 396.24	 396.24	 396.24	 1.0	 0.0	 1	 -30.0	 30.0;
	11056	 11060	 0.00025	 0.019182	 0.0	 431.96	 431.96	 431.96	 1.0	 0.0	 1	 -30.0	 30.0;
	11056	 11061	 0.000247	 0.017395	 0.0	 431.59	 431.59	 431.59	 1.0	 0.0	 1	 -30.0	 30.0;
	11057	 11059	 0.00071	 0.035097	 0.0	 371.24	 371.24	 371.24	 1.0	 0.0	 1	 -30.0	 30.0;
	11058	 11059	 0.003239	 0.160153	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	11064	 11063	 0.000544	 0.034046	 0.0	 388.31	 388.31	 388.31	 1.00625	 0.0	 1	 -30.0	 30.0;
	11063	 11065	 0.000617	 0.037423	 0.0	 511.97	 511.97	 511.97	 0.9875	 0.0	 1	 -30.0	 30.0;
	11063	 11066	 0.000281	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13464	 11066	 0.000395	 0.004237	 0.06759	 1077.46	 1077.46	 1077.46	 0.0	 0.0	 1	 -30.0	 30.0;
	11068	 11067	 0.000346	 0.022548	 0.0	 328.7	 328.7	 328.7	 1.0	 0.0	 1	 -30.0	 30.0;
	11067	 11069	 0.00032	 0.018127	 0.0	 527.31	 527.31	 527.31	 1.0	 0.0	 1	 -30.0	 30.0;
	11068	 13467	 0.005917	 0.034189	 0.02855	 196.66	 196.66	 196.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13569	 11068	 0.009444	 0.064799	 0.0126	 202.24	 202.24	 202.24	 0.0	 0.0	 1	 -30.0	 30.0;
	11071	 11070	 0.000445	 0.031392	 0.0	 467.15	 467.15	 467.15	 1.0	 0.0	 1	 -30.0	 30.0;
	11070	 11072	 0.000212	 0.016245	 0.0	 503.43	 503.43	 503.43	 1.0	 0.0	 1	 -30.0	 30.0;
	11070	 11073	 0.000316	 0.024706	 0.0	 503.35	 503.35	 503.35	 1.0	 0.0	 1	 -30.0	 30.0;
	13648	 11070	 0.000389	 0.004895	 0.19067	 1062.35	 1062.35	 1062.35	 0.0	 0.0	 1	 -30.0	 30.0;
	13689	 11070	 0.000624	 0.006457	 0.14909	 1079.4	 1079.4	 1079.4	 0.0	 0.0	 1	 -30.0	 30.0;
	11075	 11074	 7.8e-05	 0.006087	 0.0	 1511.36	 1511.36	 1511.36	 1.0	 0.0	 1	 -30.0	 30.0;
	11074	 11077	 9.9e-05	 0.007869	 0.0	 1290.81	 1290.81	 1290.81	 1.0	 0.0	 1	 -30.0	 30.0;
	11074	 11078	 0.000104	 0.008749	 0.0	 1287.52	 1287.52	 1287.52	 1.0	 0.0	 1	 -30.0	 30.0;
	11074	 11079	 0.00012	 0.009664	 0.0	 1285.45	 1285.45	 1285.45	 1.0	 0.0	 1	 -30.0	 30.0;
	11074	 11080	 0.000127	 0.009211	 0.0	 1283.99	 1283.99	 1283.99	 1.0	 0.0	 1	 -30.0	 30.0;
	11074	 11081	 0.000149	 0.01264	 0.0	 1282.85	 1282.85	 1282.85	 1.0	 0.0	 1	 -30.0	 30.0;
	11074	 11082	 0.000133	 0.010265	 0.0	 1282.3	 1282.3	 1282.3	 1.0	 0.0	 1	 -30.0	 30.0;
	11076	 11075	 0.000324	 0.024539	 0.0	 392.58	 392.58	 392.58	 1.0	 0.0	 1	 -30.0	 30.0;
	13001	 13000	 0.010956	 0.060071	 0.06352	 223.41	 223.41	 223.41	 0.0	 0.0	 1	 -30.0	 30.0;
	13000	 13007	 0.0086	 0.051621	 0.02491	 234.99	 234.99	 234.99	 0.0	 0.0	 1	 -30.0	 30.0;
	13001	 13002	 0.012792	 0.079319	 0.02551	 218.76	 218.76	 218.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13002	 13003	 0.000224	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13002	 13005	 0.029223	 0.14939	 0.03778	 209.42	 209.42	 209.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13011	 13004	 0.008363	 0.049229	 0.0182	 193.53	 193.53	 193.53	 0.0	 0.0	 1	 -30.0	 30.0;
	13024	 13004	 0.013787	 0.075557	 0.08384	 197.54	 197.54	 197.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13005	 13006	 0.000248	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13005	 20006	 0.006363	 0.035995	 0.0471	 228.45	 228.45	 228.45	 0.0	 0.0	 1	 -30.0	 30.0;
	13005	 20008	 0.05124	 0.269366	 0.13242	 222.76	 222.76	 222.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13007	 13008	 0.000245	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13007	 13010	 0.005099	 0.030817	 0.01291	 260.87	 260.87	 260.87	 0.0	 0.0	 1	 -30.0	 30.0;
	13007	 13016	 0.008145	 0.058809	 0.02217	 211.45	 211.45	 211.45	 0.0	 0.0	 1	 -30.0	 30.0;
	13010	 13009	 0.000348	 0.020983	 0.0	 482.03	 482.03	 482.03	 1.0	 0.0	 1	 -30.0	 30.0;
	13076	 13009	 0.003695	 0.034547	 0.75367	 1184.78	 1184.78	 1184.78	 0.0	 0.0	 1	 -30.0	 30.0;
	13011	 13010	 0.006382	 0.028668	 0.00861	 228.33	 228.33	 228.33	 0.0	 0.0	 1	 -30.0	 30.0;
	13011	 13012	 0.000294	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13013	 13020	 0.014487	 0.07511	 0.03997	 240.45	 240.45	 240.45	 0.0	 0.0	 1	 -30.0	 30.0;
	13013	 13024	 0.007341	 0.04295	 0.05934	 216.52	 216.52	 216.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13014	 13015	 0.000244	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13022	 13015	 0.003305	 0.017931	 0.00619	 187.21	 187.21	 187.21	 0.0	 0.0	 1	 -30.0	 30.0;
	13015	 13034	 0.01236	 0.080364	 0.08699	 215.45	 215.45	 215.45	 0.0	 0.0	 1	 -30.0	 30.0;
	13016	 13038	 0.01479	 0.068052	 0.05349	 194.43	 194.43	 194.43	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 13018	 0.000247	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13021	 13017	 0.012797	 0.074419	 0.02879	 213.66	 213.66	 213.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 13022	 0.005465	 0.036346	 0.03056	 170.17	 170.17	 170.17	 0.0	 0.0	 1	 -30.0	 30.0;
	13019	 13029	 0.008002	 0.04224	 0.02783	 225.1	 225.1	 225.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13572	 13020	 0.007438	 0.045244	 0.01913	 250.98	 250.98	 250.98	 0.0	 0.0	 1	 -30.0	 30.0;
	13026	 13021	 0.00594	 0.043277	 0.19117	 222.81	 222.81	 222.81	 0.0	 0.0	 1	 -30.0	 30.0;
	13022	 13572	 0.006917	 0.036606	 0.01139	 186.14	 186.14	 186.14	 0.0	 0.0	 1	 -30.0	 30.0;
	13034	 13023	 0.014415	 0.081509	 0.03595	 221.55	 221.55	 221.55	 0.0	 0.0	 1	 -30.0	 30.0;
	13023	 13115	 0.010125	 0.052862	 0.19191	 228.03	 228.03	 228.03	 0.0	 0.0	 1	 -30.0	 30.0;
	13024	 13025	 0.000296	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13028	 13026	 0.010224	 0.034654	 0.02709	 234.63	 234.63	 234.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13027	 13028	 0.000255	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13081	 13028	 0.00588	 0.025676	 0.16715	 221.31	 221.31	 221.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13512	 13029	 0.006952	 0.043029	 0.02149	 250.06	 250.06	 250.06	 0.0	 0.0	 1	 -30.0	 30.0;
	13030	 13154	 0.004435	 0.028333	 0.16642	 222.17	 222.17	 222.17	 0.0	 0.0	 1	 -30.0	 30.0;
	13030	 13647	 0.009529	 0.064891	 0.05526	 236.56	 236.56	 236.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13031	 13032	 0.000232	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13031	 13033	 0.000285	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13033	 13048	 0.012474	 0.087473	 0.06268	 223.66	 223.66	 223.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13033	 13110	 0.015035	 0.074635	 0.05625	 187.63	 187.63	 187.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13033	 20015	 0.04503	 0.225043	 0.13044	 214.78	 214.78	 214.78	 0.0	 0.0	 1	 -30.0	 30.0;
	13034	 13046	 0.005908	 0.040346	 0.0193	 177.3	 177.3	 177.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13035	 13059	 0.007258	 0.030554	 0.05151	 219.39	 219.39	 219.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13035	 13549	 0.016582	 0.106204	 0.06929	 226.27	 226.27	 226.27	 0.0	 0.0	 1	 -30.0	 30.0;
	13038	 13036	 0.002231	 0.01197	 0.00369	 195.4	 195.4	 195.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13070	 13036	 0.007499	 0.048811	 0.0197	 231.41	 231.41	 231.41	 0.0	 0.0	 1	 -30.0	 30.0;
	13037	 13038	 0.000247	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 13079	 0.008687	 0.041652	 0.04404	 200.36	 200.36	 200.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 13549	 0.005389	 0.03052	 0.02003	 222.42	 222.42	 222.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13040	 13041	 0.000291	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13040	 13042	 0.000218	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13042	 13062	 0.007849	 0.049862	 0.01372	 203.02	 203.02	 203.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13572	 13042	 0.009585	 0.061192	 0.03911	 222.56	 222.56	 222.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13043	 13044	 0.000291	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13043	 13045	 0.000299	 0.001158	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13045	 13060	 0.013865	 0.064564	 0.02883	 210.52	 210.52	 210.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13079	 13045	 0.008191	 0.055596	 0.02044	 223.71	 223.71	 223.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13046	 13047	 0.000266	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13046	 13138	 0.004008	 0.019859	 0.13161	 204.63	 204.63	 204.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13048	 13049	 0.000223	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13048	 13051	 0.006129	 0.044407	 0.01178	 198.06	 198.06	 198.06	 0.0	 0.0	 1	 -30.0	 30.0;
	13048	 13059	 0.00777	 0.045289	 0.02013	 235.16	 235.16	 235.16	 0.0	 0.0	 1	 -30.0	 30.0;
	13050	 13051	 0.000232	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13051	 13059	 0.00586	 0.033274	 0.02175	 233.39	 233.39	 233.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13052	 13053	 0.000271	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13054	 13052	 0.010709	 0.058663	 0.03229	 208.44	 208.44	 208.44	 0.0	 0.0	 1	 -30.0	 30.0;
	13083	 13052	 0.00335	 0.022038	 0.0073	 178.87	 178.87	 178.87	 0.0	 0.0	 1	 -30.0	 30.0;
	13054	 13162	 0.008562	 0.064665	 0.05217	 218.48	 218.48	 218.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13068	 13055	 0.00366	 0.021503	 0.05078	 207.32	 207.32	 207.32	 0.0	 0.0	 1	 -30.0	 30.0;
	13055	 13092	 0.002108	 0.011788	 0.00356	 241.18	 241.18	 241.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13056	 13057	 0.000287	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13057	 13068	 0.002874	 0.017018	 0.00746	 210.9	 210.9	 210.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13057	 13087	 0.007154	 0.033772	 0.02327	 231.24	 231.24	 231.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13059	 13058	 0.000389	 0.02702	 0.0	 432.62	 432.62	 432.62	 1.075	 0.0	 1	 -30.0	 30.0;
	13171	 13058	 0.001442	 0.018218	 0.22579	 1121.38	 1121.38	 1121.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13058	 13548	 0.002085	 0.022862	 0.42379	 1300.81	 1300.81	 1300.81	 0.0	 0.0	 1	 -30.0	 30.0;
	13058	 20005	 0.002822	 0.031035	 0.7278	 1125.15	 1125.15	 1125.15	 0.0	 0.0	 1	 -30.0	 30.0;
	13059	 13060	 0.003706	 0.019661	 0.01471	 190.32	 190.32	 190.32	 0.0	 0.0	 1	 -30.0	 30.0;
	13090	 13059	 0.003028	 0.014647	 0.00981	 185.93	 185.93	 185.93	 0.0	 0.0	 1	 -30.0	 30.0;
	13080	 13061	 0.009009	 0.044888	 0.02225	 213.79	 213.79	 213.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13082	 13061	 0.01512	 0.072197	 0.03061	 222.88	 222.88	 222.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13062	 13063	 0.000226	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13069	 13062	 0.006073	 0.035293	 0.01331	 208.98	 208.98	 208.98	 0.0	 0.0	 1	 -30.0	 30.0;
	13104	 13064	 0.002087	 0.011729	 0.01241	 176.52	 176.52	 176.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13064	 13218	 0.007052	 0.041116	 0.06527	 223.63	 223.63	 223.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13065	 13104	 0.006683	 0.052734	 0.01369	 220.45	 220.45	 220.45	 0.0	 0.0	 1	 -30.0	 30.0;
	13065	 13118	 0.005776	 0.025518	 0.03168	 189.27	 189.27	 189.27	 0.0	 0.0	 1	 -30.0	 30.0;
	13066	 13075	 0.005711	 0.028096	 0.01731	 197.34	 197.34	 197.34	 0.0	 0.0	 1	 -30.0	 30.0;
	13066	 13109	 0.003724	 0.019719	 0.04878	 226.24	 226.24	 226.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13067	 13143	 0.003326	 0.023231	 0.02534	 239.21	 239.21	 239.21	 0.0	 0.0	 1	 -30.0	 30.0;
	13647	 13067	 0.003474	 0.022688	 0.00644	 249.53	 249.53	 249.53	 0.0	 0.0	 1	 -30.0	 30.0;
	13069	 13099	 0.005597	 0.034733	 0.02969	 245.9	 245.9	 245.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13070	 13073	 0.000439	 0.01168	 0.0	 107.9	 107.9	 107.9	 1.0	 0.0	 1	 -30.0	 30.0;
	13070	 13080	 0.004814	 0.028094	 0.00598	 171.96	 171.96	 171.96	 0.0	 0.0	 1	 -30.0	 30.0;
	13070	 13129	 0.007202	 0.048969	 0.04133	 257.25	 257.25	 257.25	 0.0	 0.0	 1	 -30.0	 30.0;
	13071	 13073	 0.009402	 0.24995	 0.0	 53.95	 53.95	 53.95	 1.0	 0.0	 1	 -30.0	 30.0;
	13072	 13073	 0.009402	 0.24995	 0.0	 53.95	 53.95	 53.95	 1.0	 0.0	 1	 -30.0	 30.0;
	13074	 13096	 0.009576	 0.048832	 0.02985	 247.03	 247.03	 247.03	 0.0	 0.0	 1	 -30.0	 30.0;
	13075	 13103	 0.004636	 0.030456	 0.02141	 224.49	 224.49	 224.49	 0.0	 0.0	 1	 -30.0	 30.0;
	13077	 13076	 0.000771	 0.039994	 0.0	 409.62	 409.62	 409.62	 1.025	 0.0	 1	 -30.0	 30.0;
	13562	 13076	 0.000645	 0.007227	 0.19305	 1255.28	 1255.28	 1255.28	 0.0	 0.0	 1	 -30.0	 30.0;
	13083	 13077	 0.004695	 0.021279	 0.00773	 220.3	 220.3	 220.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13078	 13079	 0.000267	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13549	 13079	 0.005458	 0.04014	 0.01995	 230.89	 230.89	 230.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13081	 13157	 0.005759	 0.035407	 0.02898	 233.42	 233.42	 233.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13082	 13582	 0.016275	 0.0774	 0.04693	 253.12	 253.12	 253.12	 0.0	 0.0	 1	 -30.0	 30.0;
	13083	 13113	 0.004621	 0.029335	 0.0123	 177.38	 177.38	 177.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13084	 13085	 0.000221	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13096	 13084	 0.010193	 0.040743	 0.01957	 235.76	 235.76	 235.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13084	 13115	 0.002617	 0.016047	 0.01057	 190.24	 190.24	 190.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13086	 13089	 0.000819	 0.046072	 0.0	 602.26	 602.26	 602.26	 1.0	 0.0	 1	 -30.0	 30.0;
	13086	 13136	 0.00048	 0.005583	 0.14103	 1352.56	 1352.56	 1352.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13571	 13086	 0.001931	 0.023604	 0.43552	 1135.36	 1135.36	 1135.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13087	 13089	 -0.000451	 -0.025347	 0.0	 552.26	 552.26	 552.26	 1.0	 0.0	 1	 -30.0	 30.0;
	13099	 13087	 0.000916	 0.003434	 0.0017	 328.56	 328.56	 328.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13088	 13089	 0.001942	 0.109265	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13090	 13091	 0.000266	 0.001092	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13107	 13090	 0.008566	 0.044611	 0.02186	 205.24	 205.24	 205.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13106	 13092	 0.003063	 0.018208	 0.02299	 254.09	 254.09	 254.09	 0.0	 0.0	 1	 -30.0	 30.0;
	13093	 13094	 0.000295	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13093	 13095	 0.001709	 0.012256	 0.01228	 217.76	 217.76	 217.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13111	 13093	 0.007878	 0.04757	 0.01194	 241.66	 241.66	 241.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13095	 13109	 0.002683	 0.014142	 0.00408	 149.55	 149.55	 149.55	 0.0	 0.0	 1	 -30.0	 30.0;
	13097	 13098	 0.007914	 0.038972	 0.01278	 190.01	 190.01	 190.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13097	 13196	 0.00753	 0.039427	 0.02344	 222.8	 222.8	 222.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13118	 13098	 0.001757	 0.01201	 0.00648	 202.0	 202.0	 202.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13099	 13100	 0.001252	 0.008197	 0.00426	 235.68	 235.68	 235.68	 0.0	 0.0	 1	 -30.0	 30.0;
	13100	 13117	 0.001488	 0.010822	 0.00809	 206.07	 206.07	 206.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13100	 13198	 0.006014	 0.027242	 0.09078	 187.57	 187.57	 187.57	 0.0	 0.0	 1	 -30.0	 30.0;
	13131	 13101	 0.000609	 0.003405	 0.00165	 195.24	 195.24	 195.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 13101	 0.002849	 0.016679	 0.00688	 235.76	 235.76	 235.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13102	 13103	 0.000275	 0.001095	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13103	 13563	 0.004181	 0.02274	 0.01691	 251.84	 251.84	 251.84	 0.0	 0.0	 1	 -30.0	 30.0;
	13104	 13175	 0.007075	 0.03567	 0.03284	 232.35	 232.35	 232.35	 0.0	 0.0	 1	 -30.0	 30.0;
	13137	 13105	 0.001825	 0.008211	 0.0014	 234.77	 234.77	 234.77	 0.0	 0.0	 1	 -30.0	 30.0;
	13105	 13138	 0.001519	 0.007962	 0.00292	 198.77	 198.77	 198.77	 0.0	 0.0	 1	 -30.0	 30.0;
	13106	 13121	 0.002277	 0.016441	 0.02185	 237.24	 237.24	 237.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13106	 13148	 0.008862	 0.04238	 0.04957	 243.55	 243.55	 243.55	 0.0	 0.0	 1	 -30.0	 30.0;
	13107	 13108	 0.000231	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13152	 13107	 0.00394	 0.026843	 0.00938	 215.93	 215.93	 215.93	 0.0	 0.0	 1	 -30.0	 30.0;
	13131	 13109	 0.003829	 0.024233	 0.00992	 217.78	 217.78	 217.78	 0.0	 0.0	 1	 -30.0	 30.0;
	13109	 13189	 0.00746	 0.038071	 0.04543	 218.48	 218.48	 218.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 13173	 0.008999	 0.039433	 0.026	 212.33	 212.33	 212.33	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 20028	 0.02611	 0.134181	 0.05673	 133.25	 133.25	 133.25	 0.0	 0.0	 1	 -30.0	 30.0;
	13111	 13651	 0.010332	 0.05169	 0.08716	 248.22	 248.22	 248.22	 0.0	 0.0	 1	 -30.0	 30.0;
	13112	 13113	 0.000276	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13113	 13135	 0.005293	 0.024623	 0.01645	 212.75	 212.75	 212.75	 0.0	 0.0	 1	 -30.0	 30.0;
	13114	 13115	 0.000224	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13115	 13157	 0.002113	 0.011992	 0.00425	 239.71	 239.71	 239.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13116	 13130	 0.005215	 0.03175	 0.01034	 190.92	 190.92	 190.92	 0.0	 0.0	 1	 -30.0	 30.0;
	13116	 13190	 0.007605	 0.046489	 0.01664	 215.6	 215.6	 215.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13117	 13128	 0.00452	 0.025517	 0.0216	 190.0	 190.0	 190.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13165	 13118	 0.001453	 0.010909	 0.01528	 244.84	 244.84	 244.84	 0.0	 0.0	 1	 -30.0	 30.0;
	13119	 13120	 0.000206	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13119	 13121	 0.000234	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13121	 13137	 0.002413	 0.013049	 0.00616	 262.06	 262.06	 262.06	 0.0	 0.0	 1	 -30.0	 30.0;
	13122	 13123	 0.000239	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 13123	 0.004669	 0.02209	 0.01201	 211.15	 211.15	 211.15	 0.0	 0.0	 1	 -30.0	 30.0;
	13124	 13127	 -0.000107	 -0.003409	 0.0	 259.38	 259.38	 259.38	 1.0	 0.0	 1	 -30.0	 30.0;
	13124	 13128	 0.002183	 0.008481	 0.00565	 210.27	 210.27	 210.27	 0.0	 0.0	 1	 -30.0	 30.0;
	13124	 13163	 0.007379	 0.035399	 0.01943	 199.27	 199.27	 199.27	 0.0	 0.0	 1	 -30.0	 30.0;
	13124	 13257	 0.00804	 0.041417	 0.02581	 224.54	 224.54	 224.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13125	 13127	 0.002717	 0.08689	 0.0	 129.69	 129.69	 129.69	 1.0	 0.0	 1	 -30.0	 30.0;
	13126	 13127	 0.002717	 0.08689	 0.0	 129.69	 129.69	 129.69	 1.0	 0.0	 1	 -30.0	 30.0;
	13129	 13657	 0.008599	 0.059156	 0.062	 260.08	 260.08	 260.08	 0.0	 0.0	 1	 -30.0	 30.0;
	13130	 13563	 0.007502	 0.055611	 0.05343	 213.42	 213.42	 213.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13131	 13134	 0.000724	 0.020454	 0.0	 107.59	 107.59	 107.59	 1.0	 0.0	 1	 -30.0	 30.0;
	13563	 13131	 0.002593	 0.018752	 0.01164	 233.57	 233.57	 233.57	 0.0	 0.0	 1	 -30.0	 30.0;
	13132	 13134	 0.011258	 0.318271	 0.0	 53.8	 53.8	 53.8	 1.0	 0.0	 1	 -30.0	 30.0;
	13133	 13134	 0.011258	 0.318271	 0.0	 53.8	 53.8	 53.8	 1.0	 0.0	 1	 -30.0	 30.0;
	13135	 13563	 0.005478	 0.028538	 0.00558	 201.94	 201.94	 201.94	 0.0	 0.0	 1	 -30.0	 30.0;
	13135	 13582	 0.007489	 0.043674	 0.0172	 232.28	 232.28	 232.28	 0.0	 0.0	 1	 -30.0	 30.0;
	13137	 13136	 0.000415	 0.021378	 0.0	 518.21	 518.21	 518.21	 1.1	 0.0	 1	 -30.0	 30.0;
	13136	 13174	 0.00158	 0.017601	 0.36356	 1261.13	 1261.13	 1261.13	 0.0	 0.0	 1	 -30.0	 30.0;
	13136	 13264	 0.001882	 0.023323	 0.55413	 1308.25	 1308.25	 1308.25	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 13138	 0.005039	 0.023631	 0.01682	 235.47	 235.47	 235.47	 0.0	 0.0	 1	 -30.0	 30.0;
	13139	 13140	 0.000223	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13140	 13141	 0.00389	 0.017797	 0.01906	 206.79	 206.79	 206.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13146	 13140	 0.001964	 0.012602	 0.00369	 207.73	 207.73	 207.73	 0.0	 0.0	 1	 -30.0	 30.0;
	13141	 13142	 0.000293	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13141	 13244	 0.001914	 0.010536	 0.0183	 232.48	 232.48	 232.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13143	 13154	 0.006224	 0.035248	 0.01615	 230.2	 230.2	 230.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13144	 13145	 0.000212	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13144	 13157	 0.004097	 0.018885	 0.01955	 192.11	 192.11	 192.11	 0.0	 0.0	 1	 -30.0	 30.0;
	13175	 13146	 0.002629	 0.012731	 0.00368	 244.42	 244.42	 244.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13154	 13147	 0.006396	 0.036754	 0.01643	 234.3	 234.3	 234.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13148	 13149	 0.000224	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13148	 13196	 0.003268	 0.017868	 0.01506	 250.32	 250.32	 250.32	 0.0	 0.0	 1	 -30.0	 30.0;
	13150	 13151	 0.000254	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13150	 13172	 0.000976	 0.005416	 0.00337	 262.63	 262.63	 262.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13173	 13150	 0.005859	 0.029107	 0.0219	 245.64	 245.64	 245.64	 0.0	 0.0	 1	 -30.0	 30.0;
	13152	 13153	 0.000295	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13152	 13632	 0.00505	 0.031289	 0.0257	 237.26	 237.26	 237.26	 0.0	 0.0	 1	 -30.0	 30.0;
	13157	 13155	 0.001455	 0.007741	 0.00344	 196.6	 196.6	 196.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13156	 13159	 0.001417	 0.083818	 0.0	 633.74	 633.74	 633.74	 1.0	 0.0	 1	 -30.0	 30.0;
	13156	 13160	 0.00026	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13156	 13161	 0.000297	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13157	 13159	 -0.000968	 -0.057261	 0.0	 433.31	 433.31	 433.31	 1.0	 0.0	 1	 -30.0	 30.0;
	13157	 13182	 0.003931	 0.020595	 0.03392	 231.45	 231.45	 231.45	 0.0	 0.0	 1	 -30.0	 30.0;
	13158	 13159	 0.002076	 0.122763	 0.0	 200.42	 200.42	 200.42	 1.0	 0.0	 1	 -30.0	 30.0;
	13160	 13180	 0.000514	 0.006179	 0.12415	 1134.89	 1134.89	 1134.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 13198	 0.006671	 0.033099	 0.02609	 173.36	 173.36	 173.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 13651	 0.011362	 0.068813	 0.06648	 230.03	 230.03	 230.03	 0.0	 0.0	 1	 -30.0	 30.0;
	13163	 13164	 0.00022	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13163	 13259	 0.006045	 0.036553	 0.03244	 214.15	 214.15	 214.15	 0.0	 0.0	 1	 -30.0	 30.0;
	13165	 13166	 0.000215	 0.001095	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13165	 13227	 0.003251	 0.01586	 0.0258	 265.29	 265.29	 265.29	 0.0	 0.0	 1	 -30.0	 30.0;
	13170	 13167	 0.001526	 0.007817	 0.01464	 233.48	 233.48	 233.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13167	 13227	 0.003615	 0.015317	 0.0552	 260.02	 260.02	 260.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13168	 13632	 0.005759	 0.035641	 0.01346	 239.15	 239.15	 239.15	 0.0	 0.0	 1	 -30.0	 30.0;
	13655	 13168	 0.009293	 0.057014	 0.02772	 252.53	 252.53	 252.53	 0.0	 0.0	 1	 -30.0	 30.0;
	13169	 13170	 0.000223	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 13170	 0.004654	 0.024865	 0.01079	 181.1	 181.1	 181.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13172	 13171	 0.000652	 0.031103	 0.0	 417.02	 417.02	 417.02	 1.05625	 0.0	 1	 -30.0	 30.0;
	13171	 20415	 0.0014	 0.018	 0.226	 1100.0	 1100.0	 1100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 13172	 0.00706	 0.034732	 0.02452	 342.8	 342.8	 342.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13175	 13174	 0.000507	 0.026517	 0.0	 507.15	 507.15	 507.15	 1.0875	 0.0	 1	 -30.0	 30.0;
	13174	 13233	 0.000504	 0.006399	 0.11981	 1163.27	 1163.27	 1163.27	 0.0	 0.0	 1	 -30.0	 30.0;
	13174	 13264	 0.000908	 0.0084	 0.21037	 1310.5	 1310.5	 1310.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13176	 13177	 0.000288	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13176	 13218	 0.001772	 0.012273	 0.00752	 204.46	 204.46	 204.46	 0.0	 0.0	 1	 -30.0	 30.0;
	13221	 13176	 0.000562	 0.003342	 0.00188	 256.36	 256.36	 256.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13178	 13179	 0.000292	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13178	 13230	 0.006211	 0.028978	 0.0162	 241.68	 241.68	 241.68	 0.0	 0.0	 1	 -30.0	 30.0;
	13178	 13492	 0.004835	 0.022985	 0.03484	 199.16	 199.16	 199.16	 0.0	 0.0	 1	 -30.0	 30.0;
	13181	 13180	 0.000584	 0.031637	 0.0	 472.58	 472.58	 472.58	 1.0875	 0.0	 1	 -30.0	 30.0;
	13181	 13182	 0.001289	 0.007234	 0.00242	 240.06	 240.06	 240.06	 0.0	 0.0	 1	 -30.0	 30.0;
	13261	 13181	 0.001013	 0.006874	 0.00246	 218.18	 218.18	 218.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13182	 13183	 0.000222	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 13239	 0.005518	 0.03142	 0.0558	 242.16	 242.16	 242.16	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 13186	 0.000281	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 13187	 0.000269	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 13188	 0.000271	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13252	 13187	 0.007179	 0.056089	 0.03825	 228.47	 228.47	 228.47	 0.0	 0.0	 1	 -30.0	 30.0;
	13187	 13563	 0.005055	 0.026161	 0.01129	 185.7	 185.7	 185.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13189	 13532	 0.018843	 0.102153	 0.0509	 248.69	 248.69	 248.69	 0.0	 0.0	 1	 -30.0	 30.0;
	13190	 13191	 0.000264	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13190	 13582	 0.008243	 0.036584	 0.0132	 221.49	 221.49	 221.49	 0.0	 0.0	 1	 -30.0	 30.0;
	13192	 13193	 0.000285	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13192	 13194	 0.00024	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13192	 13195	 0.000244	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13196	 0.006179	 0.028699	 0.0125	 259.38	 259.38	 259.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13227	 13194	 0.005372	 0.025974	 0.01606	 275.31	 275.31	 275.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13227	 13194	 0.005372	 0.025974	 0.01606	 275.31	 275.31	 275.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13227	 13194	 0.005372	 0.025974	 0.01606	 275.31	 275.31	 275.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13237	 0.00454	 0.017294	 0.00789	 228.56	 228.56	 228.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13296	 0.003552	 0.018959	 0.06566	 283.23	 283.23	 283.23	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13296	 0.003552	 0.018959	 0.06566	 283.23	 283.23	 283.23	 0.0	 0.0	 1	 -30.0	 30.0;
	13194	 13296	 0.003552	 0.018959	 0.06566	 283.23	 283.23	 283.23	 0.0	 0.0	 1	 -30.0	 30.0;
	13492	 13196	 0.002232	 0.010513	 0.07493	 233.39	 233.39	 233.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13198	 13197	 0.003783	 0.017856	 0.00471	 200.48	 200.48	 200.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13197	 13252	 0.00332	 0.015904	 0.06204	 180.82	 180.82	 180.82	 0.0	 0.0	 1	 -30.0	 30.0;
	13651	 13197	 0.011878	 0.067861	 0.02862	 227.95	 227.95	 227.95	 0.0	 0.0	 1	 -30.0	 30.0;
	13198	 13199	 0.000203	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13200	 13201	 0.002797	 0.016514	 0.00448	 250.31	 250.31	 250.31	 0.0	 0.0	 1	 -30.0	 30.0;
	20416	 13200	 0.020167	 0.100209	 0.03352	 264.2	 264.2	 264.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13201	 13213	 0.005014	 0.024563	 0.01195	 243.0	 243.0	 243.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13202	 13203	 0.000292	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13202	 13210	 0.002029	 0.01047	 0.00696	 236.69	 236.69	 236.69	 0.0	 0.0	 1	 -30.0	 30.0;
	13212	 13202	 0.001264	 0.007271	 0.00367	 232.88	 232.88	 232.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13202	 13218	 0.003473	 0.016966	 0.01844	 232.69	 232.69	 232.69	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 13205	 0.000263	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 13207	 0.000219	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 13208	 0.000224	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13207	 13242	 0.001873	 0.00976	 0.00366	 233.19	 233.19	 233.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 13207	 0.001641	 0.009752	 0.00778	 208.82	 208.82	 208.82	 0.0	 0.0	 1	 -30.0	 30.0;
	13209	 13210	 0.000283	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13209	 13211	 0.000261	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13210	 13260	 0.004492	 0.024	 0.01609	 255.39	 255.39	 255.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13212	 13272	 0.001676	 0.010055	 0.06321	 263.62	 263.62	 263.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13307	 13213	 0.006425	 0.029046	 0.0146	 208.6	 208.6	 208.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13214	 13215	 0.000208	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13214	 13224	 0.005363	 0.033125	 0.00609	 237.39	 237.39	 237.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13279	 13214	 0.005605	 0.03214	 0.01697	 217.85	 217.85	 217.85	 0.0	 0.0	 1	 -30.0	 30.0;
	13632	 13214	 0.003678	 0.018048	 0.00878	 201.01	 201.01	 201.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13216	 13217	 0.00025	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13216	 13218	 0.000267	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13216	 13219	 0.000244	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13220	 13221	 0.000204	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13221	 13241	 0.002379	 0.015412	 0.02113	 263.5	 263.5	 263.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13221	 13268	 0.001651	 0.010712	 0.01582	 205.69	 205.69	 205.69	 0.0	 0.0	 1	 -30.0	 30.0;
	13222	 13223	 0.000221	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13222	 13224	 0.000271	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13222	 13225	 0.000251	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13224	 13655	 0.011865	 0.074366	 0.01716	 246.86	 246.86	 246.86	 0.0	 0.0	 1	 -30.0	 30.0;
	13226	 13227	 0.000277	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13226	 13228	 0.000257	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13229	 13232	 0.001021	 0.069675	 0.0	 593.64	 593.64	 593.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13229	 13233	 0.000226	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13230	 13232	 -0.000552	 -0.037682	 0.0	 420.79	 420.79	 420.79	 1.0	 0.0	 1	 -30.0	 30.0;
	13230	 13236	 0.003196	 0.017067	 0.0062	 240.12	 240.12	 240.12	 0.0	 0.0	 1	 -30.0	 30.0;
	13230	 13250	 0.001386	 0.006683	 0.00336	 250.88	 250.88	 250.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13231	 13232	 0.002689	 0.183463	 0.0	 172.85	 172.85	 172.85	 1.0	 0.0	 1	 -30.0	 30.0;
	13233	 13264	 0.000536	 0.007062	 0.09304	 1242.89	 1242.89	 1242.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13234	 13235	 0.00023	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13234	 13236	 0.00026	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13244	 13236	 0.002683	 0.012283	 0.00351	 196.58	 196.58	 196.58	 0.0	 0.0	 1	 -30.0	 30.0;
	13237	 13238	 0.000214	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13277	 13237	 0.001223	 0.008642	 0.00191	 190.75	 190.75	 190.75	 0.0	 0.0	 1	 -30.0	 30.0;
	13237	 13293	 0.003331	 0.021382	 0.01681	 235.31	 235.31	 235.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13239	 13240	 0.00021	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13239	 13344	 0.00597	 0.038666	 0.05032	 249.95	 249.95	 249.95	 0.0	 0.0	 1	 -30.0	 30.0;
	13241	 13246	 0.002641	 0.015434	 0.00801	 255.02	 255.02	 255.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13253	 13241	 0.001829	 0.007977	 0.01476	 239.07	 239.07	 239.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13242	 13243	 0.00025	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13242	 13294	 0.003184	 0.019268	 0.01279	 251.38	 251.38	 251.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13244	 13245	 0.000276	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13244	 13262	 0.002093	 0.014123	 0.00919	 239.62	 239.62	 239.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13246	 13304	 0.001121	 0.005099	 0.00125	 271.33	 271.33	 271.33	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 13248	 0.000281	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 13249	 0.000269	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 13253	 0.002763	 0.015351	 0.01278	 262.88	 262.88	 262.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 13249	 0.001165	 0.00629	 0.00316	 375.19	 375.19	 375.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13272	 13250	 0.001215	 0.007094	 0.00351	 275.71	 275.71	 275.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13272	 13250	 0.001215	 0.007094	 0.00351	 275.71	 275.71	 275.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13272	 13250	 0.001215	 0.007094	 0.00351	 275.71	 275.71	 275.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13250	 13274	 0.00076	 0.004194	 0.00347	 268.46	 268.46	 268.46	 0.0	 0.0	 1	 -30.0	 30.0;
	13251	 13252	 0.000246	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13252	 13651	 0.006572	 0.034508	 0.01583	 252.19	 252.19	 252.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13261	 13253	 0.00089	 0.00531	 0.0026	 168.72	 168.72	 168.72	 0.0	 0.0	 1	 -30.0	 30.0;
	13254	 13255	 0.000287	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13254	 13256	 0.000215	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 13268	 0.002029	 0.011781	 0.00545	 210.66	 210.66	 210.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13257	 13258	 0.000267	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13257	 13355	 0.008267	 0.052233	 0.03772	 250.93	 250.93	 250.93	 0.0	 0.0	 1	 -30.0	 30.0;
	13259	 13313	 0.015525	 0.077869	 0.03254	 236.77	 236.77	 236.77	 0.0	 0.0	 1	 -30.0	 30.0;
	13301	 13260	 0.001551	 0.009178	 0.00483	 214.04	 214.04	 214.04	 0.0	 0.0	 1	 -30.0	 30.0;
	13262	 13274	 0.001116	 0.004928	 0.00451	 263.42	 263.42	 263.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13264	 13263	 0.000121	 0.009058	 0.0	 1663.77	 1663.77	 1663.77	 1.0	 0.0	 1	 -30.0	 30.0;
	13264	 13263	 0.000121	 0.009058	 0.0	 1663.77	 1663.77	 1663.77	 1.0	 0.0	 1	 -30.0	 30.0;
	13264	 13263	 0.000121	 0.009058	 0.0	 1663.77	 1663.77	 1663.77	 1.0	 0.0	 1	 -30.0	 30.0;
	13649	 13263	 0.000226	 0.006296	 3.48014	 3979.9	 3979.9	 3979.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13263	 13666	 0.000139	 0.003702	 2.21876	 4246.52	 4246.52	 4246.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13265	 13264	 0.000449	 0.02431	 0.0	 490.32	 490.32	 490.32	 1.0	 0.0	 1	 -30.0	 30.0;
	13264	 13302	 0.000283	 0.003199	 0.05934	 1260.23	 1260.23	 1260.23	 0.0	 0.0	 1	 -30.0	 30.0;
	13324	 13264	 0.000658	 0.007085	 0.07823	 1286.19	 1286.19	 1286.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13295	 13265	 0.001066	 0.004657	 0.00124	 251.94	 251.94	 251.94	 0.0	 0.0	 1	 -30.0	 30.0;
	13265	 13318	 0.00089	 0.006115	 0.00414	 209.98	 209.98	 209.98	 0.0	 0.0	 1	 -30.0	 30.0;
	13266	 13267	 0.000251	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13266	 13268	 0.000206	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13266	 13269	 0.000227	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13268	 13281	 0.003957	 0.021327	 0.01733	 249.5	 249.5	 249.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13270	 13271	 0.000225	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13270	 13272	 0.000269	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13272	 13304	 0.002257	 0.014925	 0.01176	 285.17	 285.17	 285.17	 0.0	 0.0	 1	 -30.0	 30.0;
	13272	 13304	 0.002257	 0.014925	 0.01176	 285.17	 285.17	 285.17	 0.0	 0.0	 1	 -30.0	 30.0;
	13272	 13304	 0.002257	 0.014925	 0.01176	 285.17	 285.17	 285.17	 0.0	 0.0	 1	 -30.0	 30.0;
	13273	 13323	 0.001826	 0.009218	 0.05213	 225.01	 225.01	 225.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13273	 13325	 0.000974	 0.003339	 0.00136	 210.47	 210.47	 210.47	 0.0	 0.0	 1	 -30.0	 30.0;
	13273	 13333	 0.0032	 0.015277	 0.01142	 290.52	 290.52	 290.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13274	 13284	 0.000966	 0.005179	 0.00272	 202.59	 202.59	 202.59	 0.0	 0.0	 1	 -30.0	 30.0;
	13275	 13276	 0.000299	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13284	 13275	 0.00026	 0.001728	 0.00729	 228.32	 228.32	 228.32	 0.0	 0.0	 1	 -30.0	 30.0;
	13286	 13275	 0.002835	 0.015148	 0.01234	 247.18	 247.18	 247.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13277	 13278	 0.000208	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13277	 13325	 0.005205	 0.026596	 0.02419	 234.81	 234.81	 234.81	 0.0	 0.0	 1	 -30.0	 30.0;
	13307	 13279	 0.004303	 0.023553	 0.02783	 248.54	 248.54	 248.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13279	 13367	 0.012158	 0.056466	 0.06385	 246.19	 246.19	 246.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13280	 13281	 0.000263	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13280	 13282	 0.00026	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13281	 13304	 0.002339	 0.014381	 0.00417	 269.43	 269.43	 269.43	 0.0	 0.0	 1	 -30.0	 30.0;
	13286	 13283	 0.001373	 0.007824	 0.00329	 219.38	 219.38	 219.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13283	 13294	 0.002064	 0.011905	 0.02781	 183.02	 183.02	 183.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13283	 13318	 0.001892	 0.008609	 0.0123	 250.96	 250.96	 250.96	 0.0	 0.0	 1	 -30.0	 30.0;
	13285	 13289	 0.001448	 0.008909	 0.01026	 274.29	 274.29	 274.29	 0.0	 0.0	 1	 -30.0	 30.0;
	13285	 13289	 0.001448	 0.008909	 0.01026	 274.29	 274.29	 274.29	 0.0	 0.0	 1	 -30.0	 30.0;
	13285	 13301	 0.000923	 0.006437	 0.00741	 220.99	 220.99	 220.99	 0.0	 0.0	 1	 -30.0	 30.0;
	13286	 13295	 0.001791	 0.008639	 0.00989	 253.07	 253.07	 253.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13288	 0.00025	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13289	 0.000285	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13290	 0.000231	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13287	 13291	 0.000267	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13289	 13297	 0.001084	 0.007277	 0.00477	 230.03	 230.03	 230.03	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13289	 0.000623	 0.004006	 0.00136	 281.4	 281.4	 281.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13289	 0.000623	 0.004006	 0.00136	 281.4	 281.4	 281.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13289	 0.000623	 0.004006	 0.00136	 281.4	 281.4	 281.4	 0.0	 0.0	 1	 -30.0	 30.0;
	13293	 13294	 0.000463	 0.002577	 0.00342	 259.97	 259.97	 259.97	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 13325	 0.000485	 0.00206	 0.00197	 274.36	 274.36	 274.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 13325	 0.000485	 0.00206	 0.00197	 274.36	 274.36	 274.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 13325	 0.000485	 0.00206	 0.00197	 274.36	 274.36	 274.36	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 13295	 0.000826	 0.004053	 0.0014	 216.94	 216.94	 216.94	 0.0	 0.0	 1	 -30.0	 30.0;
	13295	 13328	 0.001172	 0.005879	 0.00365	 240.44	 240.44	 240.44	 0.0	 0.0	 1	 -30.0	 30.0;
	13305	 13296	 0.002642	 0.014037	 0.00358	 225.3	 225.3	 225.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13296	 0.002292	 0.014149	 0.01359	 286.54	 286.54	 286.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13296	 0.002292	 0.014149	 0.01359	 286.54	 286.54	 286.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13296	 0.002292	 0.014149	 0.01359	 286.54	 286.54	 286.54	 0.0	 0.0	 1	 -30.0	 30.0;
	13296	 13351	 0.004307	 0.022929	 0.03564	 233.55	 233.55	 233.55	 0.0	 0.0	 1	 -30.0	 30.0;
	13297	 13298	 0.000265	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13297	 13346	 0.00752	 0.038284	 0.01709	 197.83	 197.83	 197.83	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 13322	 0.001684	 0.008815	 0.06724	 135.78	 135.78	 135.78	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13302	 0.000118	 0.006757	 0.0	 655.05	 655.05	 655.05	 1.06875	 0.0	 1	 -30.0	 30.0;
	13303	 13302	 0.000118	 0.006757	 0.0	 655.05	 655.05	 655.05	 1.06875	 0.0	 1	 -30.0	 30.0;
	13303	 13302	 0.000118	 0.006757	 0.0	 655.05	 655.05	 655.05	 1.06875	 0.0	 1	 -30.0	 30.0;
	13303	 13302	 0.000118	 0.006757	 0.0	 655.05	 655.05	 655.05	 1.06875	 0.0	 1	 -30.0	 30.0;
	13303	 13302	 0.000118	 0.006757	 0.0	 655.05	 655.05	 655.05	 1.01875	 0.0	 1	 -30.0	 30.0;
	13302	 13667	 0.001504	 0.017762	 0.33313	 1314.46	 1314.46	 1314.46	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13304	 0.001133	 0.008032	 0.03607	 287.79	 287.79	 287.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13304	 0.001133	 0.008032	 0.03607	 287.79	 287.79	 287.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13304	 0.001133	 0.008032	 0.03607	 287.79	 287.79	 287.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13304	 0.001133	 0.008032	 0.03607	 287.79	 287.79	 287.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13304	 0.001133	 0.008032	 0.03607	 287.79	 287.79	 287.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13310	 13303	 0.001054	 0.005486	 0.00236	 276.59	 276.59	 276.59	 0.0	 0.0	 1	 -30.0	 30.0;
	13310	 13303	 0.001054	 0.005486	 0.00236	 276.59	 276.59	 276.59	 0.0	 0.0	 1	 -30.0	 30.0;
	13310	 13303	 0.001054	 0.005486	 0.00236	 276.59	 276.59	 276.59	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13312	 0.003752	 0.022951	 0.00818	 218.86	 218.86	 218.86	 0.0	 0.0	 1	 -30.0	 30.0;
	13303	 13337	 0.003503	 0.0206	 0.01055	 236.31	 236.31	 236.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13304	 13318	 0.001648	 0.00661	 0.00892	 241.92	 241.92	 241.92	 0.0	 0.0	 1	 -30.0	 30.0;
	13304	 13328	 0.002188	 0.007346	 0.00253	 223.28	 223.28	 223.28	 0.0	 0.0	 1	 -30.0	 30.0;
	13305	 13306	 0.000227	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13344	 13305	 0.003414	 0.020264	 0.00586	 197.52	 197.52	 197.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13308	 13309	 0.000262	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13308	 13310	 0.000283	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13310	 13330	 0.002038	 0.011821	 0.00362	 253.39	 253.39	 253.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13338	 13310	 0.001117	 0.007782	 0.00559	 259.39	 259.39	 259.39	 0.0	 0.0	 1	 -30.0	 30.0;
	13311	 13312	 0.000232	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13313	 13579	 0.007835	 0.044741	 0.10252	 257.48	 257.48	 257.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13314	 13315	 0.000243	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13316	 13317	 0.000273	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13316	 13318	 0.000214	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13318	 13330	 0.000521	 0.003962	 0.02584	 209.46	 209.46	 209.46	 0.0	 0.0	 1	 -30.0	 30.0;
	13319	 13323	 0.003318	 0.019902	 0.04954	 196.96	 196.96	 196.96	 0.0	 0.0	 1	 -30.0	 30.0;
	13319	 13341	 0.002608	 0.014609	 0.01135	 232.77	 232.77	 232.77	 0.0	 0.0	 1	 -30.0	 30.0;
	13320	 13321	 0.000283	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13320	 13322	 0.000273	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13322	 13351	 0.001549	 0.008557	 0.00376	 224.24	 224.24	 224.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13324	 13327	 0.000283	 0.015071	 0.0	 664.21	 664.21	 664.21	 1.0	 0.0	 1	 -30.0	 30.0;
	13325	 13327	 -8e-05	 -0.004248	 0.0	 564.21	 564.21	 564.21	 1.0	 0.0	 1	 -30.0	 30.0;
	13326	 13327	 0.001029	 0.054788	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13328	 13338	 0.000829	 0.005133	 0.00331	 232.11	 232.11	 232.11	 0.0	 0.0	 1	 -30.0	 30.0;
	13329	 13330	 0.000266	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13330	 13334	 0.000691	 0.00312	 0.00203	 218.34	 218.34	 218.34	 0.0	 0.0	 1	 -30.0	 30.0;
	13331	 13332	 0.000279	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13331	 13333	 0.000206	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13351	 0.002943	 0.018654	 0.01422	 237.32	 237.32	 237.32	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13365	 0.004675	 0.0255	 0.05841	 286.79	 286.79	 286.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13365	 0.004675	 0.0255	 0.05841	 286.79	 286.79	 286.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13365	 0.004675	 0.0255	 0.05841	 286.79	 286.79	 286.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13333	 13365	 0.004675	 0.0255	 0.05841	 286.79	 286.79	 286.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13334	 13350	 0.002676	 0.013514	 0.04748	 177.33	 177.33	 177.33	 0.0	 0.0	 1	 -30.0	 30.0;
	13335	 13336	 0.000228	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13356	 13335	 0.001686	 0.008432	 0.00404	 177.51	 177.51	 177.51	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 13347	 0.00195	 0.011144	 0.00323	 191.79	 191.79	 191.79	 0.0	 0.0	 1	 -30.0	 30.0;
	13338	 13339	 0.000283	 0.001016	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13341	 13340	 0.000513	 0.03113	 0.0	 456.28	 456.28	 456.28	 1.075	 0.0	 1	 -30.0	 30.0;
	13340	 13342	 0.000271	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13351	 13341	 0.00056	 0.003833	 0.00391	 229.5	 229.5	 229.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13341	 13356	 0.000968	 0.005439	 0.00353	 228.82	 228.82	 228.82	 0.0	 0.0	 1	 -30.0	 30.0;
	13343	 13344	 0.000209	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13343	 13345	 0.000202	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13344	 13361	 0.003676	 0.027074	 0.02874	 247.62	 247.62	 247.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13357	 13346	 0.003481	 0.017292	 0.02294	 228.91	 228.91	 228.91	 0.0	 0.0	 1	 -30.0	 30.0;
	13346	 13360	 0.002325	 0.013697	 0.01414	 223.21	 223.21	 223.21	 0.0	 0.0	 1	 -30.0	 30.0;
	13347	 13348	 0.000237	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13349	 13350	 0.000239	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13351	 13352	 0.000206	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13353	 13354	 0.000202	 0.001127	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13353	 13355	 0.000213	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13489	 13355	 0.005807	 0.033319	 0.02527	 259.53	 259.53	 259.53	 0.0	 0.0	 1	 -30.0	 30.0;
	13365	 13357	 0.008218	 0.038425	 0.02378	 286.7	 286.7	 286.7	 0.0	 0.0	 1	 -30.0	 30.0;
	13358	 13513	 0.003105	 0.018953	 0.0127	 206.72	 206.72	 206.72	 0.0	 0.0	 1	 -30.0	 30.0;
	13532	 13358	 0.017075	 0.101799	 0.05284	 215.98	 215.98	 215.98	 0.0	 0.0	 1	 -30.0	 30.0;
	13360	 13359	 0.004224	 0.018725	 0.00542	 195.28	 195.28	 195.28	 0.0	 0.0	 1	 -30.0	 30.0;
	13361	 13362	 0.000204	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13361	 13593	 0.000427	 0.002864	 0.00118	 260.01	 260.01	 260.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13363	 13364	 0.00029	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13363	 13365	 0.000221	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13365	 13401	 0.008071	 0.048255	 0.33362	 287.37	 287.37	 287.37	 0.0	 0.0	 1	 -30.0	 30.0;
	13365	 13401	 0.008071	 0.048255	 0.33362	 287.37	 287.37	 287.37	 0.0	 0.0	 1	 -30.0	 30.0;
	13365	 13401	 0.008071	 0.048255	 0.33362	 287.37	 287.37	 287.37	 0.0	 0.0	 1	 -30.0	 30.0;
	13365	 13401	 0.008071	 0.048255	 0.33362	 287.37	 287.37	 287.37	 0.0	 0.0	 1	 -30.0	 30.0;
	13365	 13401	 0.008071	 0.048255	 0.33362	 287.37	 287.37	 287.37	 0.0	 0.0	 1	 -30.0	 30.0;
	13366	 13367	 0.000268	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13367	 13375	 0.039784	 0.22466	 0.0685	 216.8	 216.8	 216.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13367	 13460	 0.010554	 0.074435	 0.03719	 253.98	 253.98	 253.98	 0.0	 0.0	 1	 -30.0	 30.0;
	13368	 13369	 0.000289	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13454	 13368	 0.009188	 0.050792	 0.01877	 178.75	 178.75	 178.75	 0.0	 0.0	 1	 -30.0	 30.0;
	13370	 13371	 0.000292	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 13370	 0.006305	 0.034217	 0.03998	 193.89	 193.89	 193.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13384	 13370	 0.010838	 0.06203	 0.01888	 168.19	 168.19	 168.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13370	 13522	 0.009536	 0.047267	 0.01964	 226.07	 226.07	 226.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13372	 13373	 0.000235	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13372	 13383	 0.00832	 0.046642	 0.01893	 213.58	 213.58	 213.58	 0.0	 0.0	 1	 -30.0	 30.0;
	13372	 13556	 0.003685	 0.019577	 0.01565	 236.09	 236.09	 236.09	 0.0	 0.0	 1	 -30.0	 30.0;
	13374	 13375	 0.000226	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13375	 13382	 0.031369	 0.155278	 0.07839	 224.64	 224.64	 224.64	 0.0	 0.0	 1	 -30.0	 30.0;
	13376	 13379	 0.0001	 0.002054	 0.0	 107.17	 107.17	 107.17	 1.0	 0.0	 1	 -30.0	 30.0;
	13380	 13376	 0.014506	 0.103076	 0.01928	 239.02	 239.02	 239.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13377	 13379	 0.006288	 0.194196	 0.0	 53.59	 53.59	 53.59	 1.0	 0.0	 1	 -30.0	 30.0;
	13378	 13379	 0.006288	 0.194196	 0.0	 53.59	 53.59	 53.59	 1.0	 0.0	 1	 -30.0	 30.0;
	13381	 13382	 0.011093	 0.075853	 0.03069	 243.71	 243.71	 243.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13381	 13388	 0.008802	 0.05756	 0.03949	 250.81	 250.81	 250.81	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 20271	 0.048871	 0.264727	 0.08703	 177.89	 177.89	 177.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 20323	 0.073951	 0.319762	 0.11082	 191.16	 191.16	 191.16	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 20475	 0.057196	 0.409588	 0.12232	 189.84	 189.84	 189.84	 0.0	 0.0	 1	 -30.0	 30.0;
	13383	 20495	 0.051355	 0.300874	 0.12022	 191.38	 191.38	 191.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13384	 13408	 0.010097	 0.048844	 0.3184	 189.56	 189.56	 189.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13385	 13489	 0.022022	 0.129999	 0.13928	 232.82	 232.82	 232.82	 0.0	 0.0	 1	 -30.0	 30.0;
	13385	 13663	 0.006092	 0.031913	 0.01202	 237.66	 237.66	 237.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13386	 13387	 0.000295	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13388	 0.006864	 0.035539	 0.01645	 206.83	 206.83	 206.83	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13392	 0.00695	 0.046551	 0.03135	 235.95	 235.95	 235.95	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13403	 0.024364	 0.137629	 0.05876	 202.97	 202.97	 202.97	 0.0	 0.0	 1	 -30.0	 30.0;
	13387	 13406	 0.051993	 0.335952	 0.10545	 218.64	 218.64	 218.64	 0.0	 0.0	 1	 -30.0	 30.0;
	13388	 13389	 0.000219	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13388	 13399	 0.002258	 0.01258	 0.03454	 271.87	 271.87	 271.87	 0.0	 0.0	 1	 -30.0	 30.0;
	13390	 13391	 0.000254	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13390	 13394	 0.003919	 0.023958	 0.02925	 276.56	 276.56	 276.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13390	 13394	 0.003919	 0.023958	 0.02925	 276.56	 276.56	 276.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13390	 13394	 0.003919	 0.023958	 0.02925	 276.56	 276.56	 276.56	 0.0	 0.0	 1	 -30.0	 30.0;
	13402	 13390	 0.007487	 0.043223	 0.04822	 282.42	 282.42	 282.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13402	 13390	 0.007487	 0.043223	 0.04822	 282.42	 282.42	 282.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13402	 13390	 0.007487	 0.043223	 0.04822	 282.42	 282.42	 282.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13392	 13393	 0.000205	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13392	 13394	 0.004279	 0.022115	 0.00556	 260.83	 260.83	 260.83	 0.0	 0.0	 1	 -30.0	 30.0;
	13394	 13395	 0.000276	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13394	 13397	 0.002645	 0.014264	 0.00696	 272.82	 272.82	 272.82	 0.0	 0.0	 1	 -30.0	 30.0;
	13397	 13396	 0.000386	 0.027045	 0.0	 521.64	 521.64	 521.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13396	 13398	 0.000207	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13399	 13397	 0.00333	 0.018559	 0.00492	 274.35	 274.35	 274.35	 0.0	 0.0	 1	 -30.0	 30.0;
	13399	 13397	 0.00333	 0.018559	 0.00492	 274.35	 274.35	 274.35	 0.0	 0.0	 1	 -30.0	 30.0;
	13398	 13524	 0.001688	 0.019816	 0.28677	 1139.9	 1139.9	 1139.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13400	 13401	 0.000254	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13401	 13622	 0.001865	 0.013839	 0.00404	 400.97	 400.97	 400.97	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 13402	 0.019398	 0.13571	 0.03638	 236.77	 236.77	 236.77	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13402	 0.014547	 0.066415	 0.49761	 286.5	 286.5	 286.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13402	 0.014547	 0.066415	 0.49761	 286.5	 286.5	 286.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13402	 0.014547	 0.066415	 0.49761	 286.5	 286.5	 286.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13403	 13404	 0.00023	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13405	 13406	 0.00024	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13408	 13406	 0.041067	 0.213382	 0.15008	 214.83	 214.83	 214.83	 0.0	 0.0	 1	 -30.0	 30.0;
	13407	 13408	 0.000217	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20271	 13408	 0.040692	 0.249986	 0.07846	 178.92	 178.92	 178.92	 0.0	 0.0	 1	 -30.0	 30.0;
	13409	 13410	 0.00025	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13410	 13553	 0.008682	 0.050325	 0.02908	 243.74	 243.74	 243.74	 0.0	 0.0	 1	 -30.0	 30.0;
	13676	 13411	 0.003878	 0.018268	 0.0152	 210.71	 210.71	 210.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13411	 13697	 0.007519	 0.048553	 0.03728	 198.19	 198.19	 198.19	 0.0	 0.0	 1	 -30.0	 30.0;
	13412	 13413	 0.000275	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13412	 13615	 0.015371	 0.087538	 0.05438	 177.63	 177.63	 177.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13414	 13676	 0.009235	 0.038136	 0.02398	 213.67	 213.67	 213.67	 0.0	 0.0	 1	 -30.0	 30.0;
	13415	 13416	 0.000241	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13416	 13426	 0.01448	 0.074975	 0.02261	 204.03	 204.03	 204.03	 0.0	 0.0	 1	 -30.0	 30.0;
	13508	 13416	 0.007013	 0.027035	 0.01361	 229.74	 229.74	 229.74	 0.0	 0.0	 1	 -30.0	 30.0;
	13417	 13418	 0.000201	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13418	 13538	 0.003879	 0.020536	 0.01642	 229.14	 229.14	 229.14	 0.0	 0.0	 1	 -30.0	 30.0;
	13419	 13420	 0.000255	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13419	 13423	 0.029152	 0.169418	 0.13212	 217.81	 217.81	 217.81	 0.0	 0.0	 1	 -30.0	 30.0;
	13419	 13425	 0.031445	 0.193026	 0.1113	 230.68	 230.68	 230.68	 0.0	 0.0	 1	 -30.0	 30.0;
	13421	 13422	 0.000273	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13421	 13423	 0.000257	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13421	 13424	 0.000208	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13423	 74000	 0.022594	 0.104777	 0.36343	 198.18	 198.18	 198.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13426	 13425	 0.017356	 0.104878	 0.02471	 209.62	 209.62	 209.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13425	 13615	 0.021775	 0.123479	 0.07206	 213.86	 213.86	 213.86	 0.0	 0.0	 1	 -30.0	 30.0;
	13426	 13573	 0.01239	 0.079383	 0.03281	 231.27	 231.27	 231.27	 0.0	 0.0	 1	 -30.0	 30.0;
	13427	 13442	 0.009036	 0.06066	 0.33254	 245.22	 245.22	 245.22	 0.0	 0.0	 1	 -30.0	 30.0;
	13428	 13429	 0.00022	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13428	 13430	 0.000269	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13432	 13430	 0.001788	 0.007212	 0.00701	 234.44	 234.44	 234.44	 0.0	 0.0	 1	 -30.0	 30.0;
	13431	 13434	 0.000181	 0.010236	 0.0	 468.64	 468.64	 468.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13431	 13438	 0.000269	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13432	 13434	 0.000304	 0.017171	 0.0	 393.64	 393.64	 393.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13432	 13437	 -0.000426	 -0.013094	 0.0	 107.14	 107.14	 107.14	 1.0	 0.0	 1	 -30.0	 30.0;
	13433	 13434	 0.002627	 0.148566	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13435	 13437	 0.008532	 0.262301	 0.0	 53.57	 53.57	 53.57	 1.0	 0.0	 1	 -30.0	 30.0;
	13436	 13437	 0.008532	 0.262301	 0.0	 53.57	 53.57	 53.57	 1.0	 0.0	 1	 -30.0	 30.0;
	13643	 13438	 0.00102	 0.010633	 0.25276	 1167.89	 1167.89	 1167.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13439	 13440	 0.022083	 0.097651	 0.05918	 208.48	 208.48	 208.48	 0.0	 0.0	 1	 -30.0	 30.0;
	13440	 13446	 0.017632	 0.081152	 0.06114	 186.8	 186.8	 186.8	 0.0	 0.0	 1	 -30.0	 30.0;
	13440	 13607	 0.010973	 0.081685	 0.13789	 220.2	 220.2	 220.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13441	 13442	 0.017166	 0.081825	 0.05118	 236.25	 236.25	 236.25	 0.0	 0.0	 1	 -30.0	 30.0;
	13445	 13441	 0.024104	 0.122854	 0.1911	 253.18	 253.18	 253.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13482	 13441	 0.010318	 0.067914	 0.02132	 233.42	 233.42	 233.42	 0.0	 0.0	 1	 -30.0	 30.0;
	13443	 13444	 0.000251	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13443	 13445	 0.000278	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13445	 13688	 0.00395	 0.021189	 0.02742	 212.92	 212.92	 212.92	 0.0	 0.0	 1	 -30.0	 30.0;
	74000	 13445	 0.020308	 0.102346	 0.07242	 239.76	 239.76	 239.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13446	 13449	 0.008505	 0.042579	 0.06672	 210.84	 210.84	 210.84	 0.0	 0.0	 1	 -30.0	 30.0;
	74013	 13446	 0.017434	 0.099208	 0.08052	 221.33	 221.33	 221.33	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 13447	 0.00046	 0.031951	 0.0	 449.04	 449.04	 449.04	 1.00625	 0.0	 1	 -30.0	 30.0;
	13447	 74218	 0.002285	 0.025601	 0.89725	 1213.15	 1213.15	 1213.15	 0.0	 0.0	 1	 -30.0	 30.0;
	13447	 74250	 0.002193	 0.028368	 0.67902	 1393.24	 1393.24	 1393.24	 0.0	 0.0	 1	 -30.0	 30.0;
	74330	 13447	 0.000733	 0.009018	 0.15125	 1155.33	 1155.33	 1155.33	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 13688	 0.011167	 0.067148	 0.03581	 234.85	 234.85	 234.85	 0.0	 0.0	 1	 -30.0	 30.0;
	74004	 13448	 0.012085	 0.061164	 0.03466	 239.01	 239.01	 239.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 74012	 0.009785	 0.057377	 0.03406	 247.62	 247.62	 247.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 74109	 0.017612	 0.12055	 0.11062	 223.92	 223.92	 223.92	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 74327	 0.002139	 0.016915	 0.0641	 252.32	 252.32	 252.32	 0.0	 0.0	 1	 -30.0	 30.0;
	13449	 13452	 0.000373	 0.011854	 0.0	 107.03	 107.03	 107.03	 1.0	 0.0	 1	 -30.0	 30.0;
	13449	 74115	 0.055869	 0.35995	 0.08333	 207.09	 207.09	 207.09	 0.0	 0.0	 1	 -30.0	 30.0;
	13449	 74251	 0.018432	 0.095234	 0.13362	 227.52	 227.52	 227.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13450	 13452	 0.007106	 0.225613	 0.0	 53.52	 53.52	 53.52	 1.0	 0.0	 1	 -30.0	 30.0;
	13451	 13452	 0.007106	 0.225613	 0.0	 53.52	 53.52	 53.52	 1.0	 0.0	 1	 -30.0	 30.0;
	13453	 13456	 0.000318	 0.01766	 0.0	 409.12	 409.12	 409.12	 1.0	 0.0	 1	 -30.0	 30.0;
	13453	 13457	 0.00029	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13454	 13456	 0.000121	 0.006741	 0.0	 284.12	 284.12	 284.12	 1.0	 0.0	 1	 -30.0	 30.0;
	13532	 13454	 0.010022	 0.059368	 0.02281	 257.63	 257.63	 257.63	 0.0	 0.0	 1	 -30.0	 30.0;
	13455	 13456	 0.002421	 0.134349	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13524	 13457	 0.002476	 0.02791	 0.48832	 1267.1	 1267.1	 1267.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13457	 13650	 0.001122	 0.012739	 0.39979	 1256.0	 1256.0	 1256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13591	 13458	 0.007588	 0.02655	 0.00542	 230.01	 230.01	 230.01	 0.0	 0.0	 1	 -30.0	 30.0;
	13460	 13459	 0.000427	 0.024905	 0.0	 373.53	 373.53	 373.53	 1.0	 0.0	 1	 -30.0	 30.0;
	13459	 13461	 0.000293	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13459	 13555	 0.000568	 0.007454	 0.17407	 1294.78	 1294.78	 1294.78	 0.0	 0.0	 1	 -30.0	 30.0;
	13459	 20291	 0.00347	 0.039621	 1.21111	 1214.22	 1214.22	 1214.22	 0.0	 0.0	 1	 -30.0	 30.0;
	20415	 13459	 0.000771	 0.009516	 0.23086	 1071.13	 1071.13	 1071.13	 0.0	 0.0	 1	 -30.0	 30.0;
	13460	 20048	 0.022077	 0.111396	 0.0547	 224.44	 224.44	 224.44	 0.0	 0.0	 1	 -30.0	 30.0;
	13462	 13463	 0.000214	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13463	 13647	 0.000491	 0.003519	 0.00087	 244.93	 244.93	 244.93	 0.0	 0.0	 1	 -30.0	 30.0;
	13463	 13690	 0.000151	 0.0009	 0.00023	 199.11	 199.11	 199.11	 0.0	 0.0	 1	 -30.0	 30.0;
	13465	 13464	 0.000548	 0.03051	 0.0	 350.42	 350.42	 350.42	 1.0	 0.0	 1	 -30.0	 30.0;
	13464	 13466	 0.000407	 0.025882	 0.0	 456.82	 456.82	 456.82	 1.0	 0.0	 1	 -30.0	 30.0;
	13464	 13643	 0.000513	 0.005707	 0.18157	 1022.57	 1022.57	 1022.57	 0.0	 0.0	 1	 -30.0	 30.0;
	13467	 13468	 0.003534	 0.109836	 0.0	 130.65	 130.65	 130.65	 1.01875	 0.0	 1	 -30.0	 30.0;
	13467	 13469	 0.000274	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13591	 13467	 0.002896	 0.018636	 0.00972	 261.61	 261.61	 261.61	 0.0	 0.0	 1	 -30.0	 30.0;
	13617	 13467	 0.002757	 0.01089	 0.00595	 208.57	 208.57	 208.57	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 13470	 0.000126	 0.009831	 0.0	 1276.43	 1276.43	 1276.43	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13475	 9.3e-05	 0.006888	 0.0	 1379.97	 1379.97	 1379.97	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13476	 9.7e-05	 0.007098	 0.0	 1379.32	 1379.32	 1379.32	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13477	 8.4e-05	 0.005589	 0.0	 1378.05	 1378.05	 1378.05	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13478	 0.000132	 0.00972	 0.0	 1377.09	 1377.09	 1377.09	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13479	 0.00017	 0.010586	 0.0	 1375.54	 1375.54	 1375.54	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13480	 4.2e-05	 0.003103	 0.0	 1375.09	 1375.09	 1375.09	 1.0	 0.0	 1	 -30.0	 30.0;
	13470	 13506	 4e-05	 0.001067	 0.80945	 4000.04	 4000.04	 4000.04	 0.0	 0.0	 1	 -30.0	 30.0;
	13695	 13470	 0.000115	 0.003331	 1.48725	 4180.75	 4180.75	 4180.75	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 13474	 0.000985	 0.062869	 0.0	 391.9	 391.9	 391.9	 1.0	 0.0	 1	 -30.0	 30.0;
	13471	 13537	 0.000328	 0.004005	 0.16717	 1132.11	 1132.11	 1132.11	 0.0	 0.0	 1	 -30.0	 30.0;
	13472	 13474	 -0.000451	 -0.028751	 0.0	 366.9	 366.9	 366.9	 1.0	 0.0	 1	 -30.0	 30.0;
	13473	 13474	 0.00311	 0.198487	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13482	 13481	 0.000279	 0.019412	 0.0	 382.46	 382.46	 382.46	 1.0	 0.0	 1	 -30.0	 30.0;
	13481	 13483	 0.000623	 0.033286	 0.0	 418.28	 418.28	 418.28	 1.0	 0.0	 1	 -30.0	 30.0;
	13643	 13481	 0.003082	 0.036065	 0.93073	 1174.88	 1174.88	 1174.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13481	 74250	 0.001934	 0.021655	 0.63603	 1123.41	 1123.41	 1123.41	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 13484	 0.00075	 0.041773	 0.0	 399.81	 399.81	 399.81	 1.0	 0.0	 1	 -30.0	 30.0;
	13484	 13486	 0.000183	 0.012174	 0.0	 478.61	 478.61	 478.61	 1.0	 0.0	 1	 -30.0	 30.0;
	13484	 13487	 0.00044	 0.025367	 0.0	 478.49	 478.49	 478.49	 1.0	 0.0	 1	 -30.0	 30.0;
	13484	 13505	 0.000635	 0.008057	 0.14053	 1183.99	 1183.99	 1183.99	 0.0	 0.0	 1	 -30.0	 30.0;
	13484	 13619	 0.000529	 0.006433	 0.15871	 1194.89	 1194.89	 1194.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13485	 0.004647	 0.028246	 0.00824	 242.84	 242.84	 242.84	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 13591	 0.006067	 0.031969	 0.06053	 278.6	 278.6	 278.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 13591	 0.006067	 0.031969	 0.06053	 278.6	 278.6	 278.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 13591	 0.006067	 0.031969	 0.06053	 278.6	 278.6	 278.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13489	 13488	 0.000786	 0.034042	 0.0	 358.79	 358.79	 358.79	 1.0125	 0.0	 1	 -30.0	 30.0;
	13488	 13490	 0.000287	 0.001178	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13488	 13491	 0.000294	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13491	 13592	 0.001459	 0.018019	 0.38108	 1249.95	 1249.95	 1249.95	 0.0	 0.0	 1	 -30.0	 30.0;
	13650	 13491	 0.000981	 0.012209	 0.27241	 1237.6	 1237.6	 1237.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13492	 13495	 0.000427	 0.011561	 0.0	 234.56	 234.56	 234.56	 1.0	 0.0	 1	 -30.0	 30.0;
	13493	 13495	 0.004312	 0.116793	 0.0	 117.28	 117.28	 117.28	 1.0	 0.0	 1	 -30.0	 30.0;
	13494	 13495	 0.004312	 0.116793	 0.0	 117.28	 117.28	 117.28	 1.0	 0.0	 1	 -30.0	 30.0;
	13497	 13496	 0.000104	 0.007728	 0.0	 1181.72	 1181.72	 1181.72	 1.0	 0.0	 1	 -30.0	 30.0;
	13496	 13499	 0.000157	 0.011317	 0.0	 1738.67	 1738.67	 1738.67	 1.03125	 0.0	 1	 -30.0	 30.0;
	13496	 13500	 6.8e-05	 0.005439	 0.0	 1733.87	 1733.87	 1733.87	 1.0	 0.0	 1	 -30.0	 30.0;
	13496	 13501	 6.9e-05	 0.005188	 0.0	 1733.72	 1733.72	 1733.72	 1.025	 0.0	 1	 -30.0	 30.0;
	13496	 13502	 0.000102	 0.008177	 0.0	 1724.91	 1724.91	 1724.91	 1.03125	 0.0	 1	 -30.0	 30.0;
	13496	 13503	 9e-05	 0.007242	 0.0	 1724.62	 1724.62	 1724.62	 1.025	 0.0	 1	 -30.0	 30.0;
	13496	 13504	 5.6e-05	 0.003705	 0.0	 1723.91	 1723.91	 1723.91	 1.025	 0.0	 1	 -30.0	 30.0;
	13496	 13523	 0.000331	 0.008904	 5.97516	 4233.6	 4233.6	 4233.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13631	 13496	 0.0001	 0.002837	 1.31045	 4092.02	 4092.02	 4092.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13496	 13695	 0.000178	 0.005302	 2.1918	 4094.2	 4094.2	 4094.2	 0.0	 0.0	 1	 -30.0	 30.0;
	13498	 13497	 0.000501	 0.030672	 0.0	 339.62	 339.62	 339.62	 1.0	 0.0	 1	 -30.0	 30.0;
	13497	 13505	 0.00021	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13516	 13505	 0.000445	 0.005546	 0.06585	 1217.0	 1217.0	 1217.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13505	 13621	 0.000844	 0.010705	 0.27607	 1336.14	 1336.14	 1336.14	 0.0	 0.0	 1	 -30.0	 30.0;
	13507	 13506	 6.2e-05	 0.00471	 0.0	 1430.34	 1430.34	 1430.34	 1.0	 0.0	 1	 -30.0	 30.0;
	13506	 13509	 0.000101	 0.007479	 0.0	 1563.97	 1563.97	 1563.97	 1.0	 0.0	 1	 -30.0	 30.0;
	13506	 13510	 9.5e-05	 0.008588	 0.0	 1562.09	 1562.09	 1562.09	 1.0	 0.0	 1	 -30.0	 30.0;
	13506	 13511	 7.1e-05	 0.006502	 0.0	 1559.25	 1559.25	 1559.25	 1.0	 0.0	 1	 -30.0	 30.0;
	13695	 13506	 8e-05	 0.002276	 1.58513	 4217.11	 4217.11	 4217.11	 0.0	 0.0	 1	 -30.0	 30.0;
	13508	 13507	 0.00052	 0.027369	 0.0	 375.38	 375.38	 375.38	 1.0	 0.0	 1	 -30.0	 30.0;
	13537	 13507	 0.000138	 0.001672	 0.03586	 1164.43	 1164.43	 1164.43	 0.0	 0.0	 1	 -30.0	 30.0;
	13512	 13647	 0.005749	 0.031968	 0.02671	 243.13	 243.13	 243.13	 0.0	 0.0	 1	 -30.0	 30.0;
	13513	 13582	 0.008141	 0.056508	 0.05878	 220.81	 220.81	 220.81	 0.0	 0.0	 1	 -30.0	 30.0;
	13514	 13515	 0.0054	 0.154684	 0.0	 89.93	 89.93	 89.93	 1.0	 0.0	 1	 -30.0	 30.0;
	13635	 13514	 0.012274	 0.076812	 0.02977	 208.6	 208.6	 208.6	 0.0	 0.0	 1	 -30.0	 30.0;
	13514	 13683	 0.00611	 0.033383	 0.01119	 190.62	 190.62	 190.62	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 13516	 0.000643	 0.030825	 0.0	 402.62	 402.62	 402.62	 1.0	 0.0	 1	 -30.0	 30.0;
	13516	 13518	 0.000228	 0.015855	 0.0	 483.85	 483.85	 483.85	 1.0	 0.0	 1	 -30.0	 30.0;
	13516	 13519	 0.000322	 0.01648	 0.0	 480.56	 480.56	 480.56	 1.0	 0.0	 1	 -30.0	 30.0;
	13516	 13520	 0.000467	 0.027891	 0.0	 479.72	 479.72	 479.72	 1.0	 0.0	 1	 -30.0	 30.0;
	13516	 13521	 0.001486	 0.076261	 0.0	 152.25	 152.25	 152.25	 1.0	 0.0	 1	 -30.0	 30.0;
	13516	 13619	 0.0007	 0.007982	 0.18419	 1185.93	 1185.93	 1185.93	 0.0	 0.0	 1	 -30.0	 30.0;
	13660	 13517	 0.005604	 0.020278	 0.0152	 210.55	 210.55	 210.55	 0.0	 0.0	 1	 -30.0	 30.0;
	13522	 13556	 0.000363	 0.001968	 0.00056	 186.11	 186.11	 186.11	 0.0	 0.0	 1	 -30.0	 30.0;
	13524	 13523	 8e-05	 0.005883	 0.0	 1486.02	 1486.02	 1486.02	 1.0	 0.0	 1	 -30.0	 30.0;
	13523	 13526	 0.000106	 0.007042	 0.0	 1281.11	 1281.11	 1281.11	 1.0	 0.0	 1	 -30.0	 30.0;
	13523	 13527	 0.00012	 0.01011	 0.0	 1280.43	 1280.43	 1280.43	 1.0	 0.0	 1	 -30.0	 30.0;
	13523	 13528	 0.000123	 0.008829	 0.0	 1279.86	 1279.86	 1279.86	 1.0	 0.0	 1	 -30.0	 30.0;
	13523	 13554	 0.000617	 0.018942	 9.29809	 4347.66	 4347.66	 4347.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13523	 13554	 0.000617	 0.018942	 9.29809	 4347.66	 4347.66	 4347.66	 0.0	 0.0	 1	 -30.0	 30.0;
	13523	 13580	 0.000308	 0.009053	 6.26692	 4286.35	 4286.35	 4286.35	 0.0	 0.0	 1	 -30.0	 30.0;
	13681	 13523	 0.000296	 0.008162	 4.65478	 4266.9	 4266.9	 4266.9	 0.0	 0.0	 1	 -30.0	 30.0;
	13523	 13695	 0.000403	 0.010827	 7.38366	 4255.5	 4255.5	 4255.5	 0.0	 0.0	 1	 -30.0	 30.0;
	13525	 13524	 0.000214	 0.013017	 0.0	 322.26	 322.26	 322.26	 1.0	 0.0	 1	 -30.0	 30.0;
	13525	 13663	 0.006812	 0.035077	 0.01274	 191.96	 191.96	 191.96	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13530	 0.001668	 0.062643	 0.0	 140.4	 140.4	 140.4	 1.0125	 0.0	 1	 -30.0	 30.0;
	13529	 13531	 0.000206	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13575	 0.024754	 0.122037	 0.05167	 225.68	 225.68	 225.68	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13635	 0.006823	 0.031019	 0.00742	 263.52	 263.52	 263.52	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 13660	 0.004471	 0.019628	 0.00656	 253.35	 253.35	 253.35	 0.0	 0.0	 1	 -30.0	 30.0;
	13532	 13535	 0.000534	 0.016384	 0.0	 186.52	 186.52	 186.52	 1.0	 0.0	 1	 -30.0	 30.0;
	13532	 13536	 0.000299	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13533	 13535	 0.005073	 0.155698	 0.0	 93.26	 93.26	 93.26	 1.0	 0.0	 1	 -30.0	 30.0;
	13534	 13535	 0.005073	 0.155698	 0.0	 93.26	 93.26	 93.26	 1.0	 0.0	 1	 -30.0	 30.0;
	13538	 13537	 0.000516	 0.027613	 0.0	 374.09	 374.09	 374.09	 1.0	 0.0	 1	 -30.0	 30.0;
	13537	 13539	 0.000463	 0.034252	 0.0	 496.53	 496.53	 496.53	 1.01875	 0.0	 1	 -30.0	 30.0;
	13537	 13540	 0.000261	 0.014195	 0.0	 493.59	 493.59	 493.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	13537	 13541	 0.000349	 0.021768	 0.0	 493.47	 493.47	 493.47	 1.01875	 0.0	 1	 -30.0	 30.0;
	13537	 13542	 0.000533	 0.022092	 0.0	 493.37	 493.37	 493.37	 1.01875	 0.0	 1	 -30.0	 30.0;
	13675	 13537	 0.000842	 0.009128	 0.15668	 1226.91	 1226.91	 1226.91	 0.0	 0.0	 1	 -30.0	 30.0;
	13543	 13546	 0.000417	 0.023202	 0.0	 437.95	 437.95	 437.95	 1.0	 0.0	 1	 -30.0	 30.0;
	13543	 13547	 0.000242	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13544	 13546	 -9.1e-05	 -0.005075	 0.0	 362.64	 362.64	 362.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13544	 74114	 0.039969	 0.175397	 0.05839	 235.06	 235.06	 235.06	 0.0	 0.0	 1	 -30.0	 30.0;
	74251	 13544	 0.012346	 0.060326	 0.01546	 205.77	 205.77	 205.77	 0.0	 0.0	 1	 -30.0	 30.0;
	13545	 13546	 0.00207	 0.115023	 0.0	 75.31	 75.31	 75.31	 1.0	 0.0	 1	 -30.0	 30.0;
	13595	 13547	 0.001026	 0.012445	 0.20134	 1291.05	 1291.05	 1291.05	 0.0	 0.0	 1	 -30.0	 30.0;
	13547	 74250	 0.000492	 0.00635	 0.12213	 1090.82	 1090.82	 1090.82	 0.0	 0.0	 1	 -30.0	 30.0;
	13547	 74330	 0.003787	 0.03992	 0.9985	 1339.59	 1339.59	 1339.59	 0.0	 0.0	 1	 -30.0	 30.0;
	13549	 13548	 0.000935	 0.041152	 0.0	 427.72	 427.72	 427.72	 1.0375	 0.0	 1	 -30.0	 30.0;
	13548	 13588	 0.003358	 0.034273	 0.76701	 1371.67	 1371.67	 1371.67	 0.0	 0.0	 1	 -30.0	 30.0;
	13550	 13551	 0.002249	 0.069481	 0.0	 173.09	 173.09	 173.09	 0.99375	 0.0	 1	 -30.0	 30.0;
	13550	 13552	 0.002512	 0.079784	 0.0	 173.09	 173.09	 173.09	 0.99375	 0.0	 1	 -30.0	 30.0;
	13550	 13553	 0.000249	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13553	 13615	 0.010985	 0.063556	 0.02175	 212.38	 212.38	 212.38	 0.0	 0.0	 1	 -30.0	 30.0;
	13676	 13553	 0.000203	 0.000654	 0.00029	 273.08	 273.08	 273.08	 0.0	 0.0	 1	 -30.0	 30.0;
	13555	 13554	 0.000116	 0.009383	 0.0	 1480.84	 1480.84	 1480.84	 1.0	 0.0	 1	 -30.0	 30.0;
	13554	 13559	 8.7e-05	 0.006969	 0.0	 1383.46	 1383.46	 1383.46	 1.0	 0.0	 1	 -30.0	 30.0;
	13554	 13560	 0.000129	 0.009636	 0.0	 1381.04	 1381.04	 1381.04	 1.025	 0.0	 1	 -30.0	 30.0;
	13554	 13561	 0.000109	 0.008093	 0.0	 1380.16	 1380.16	 1380.16	 1.025	 0.0	 1	 -30.0	 30.0;
	20321	 13554	 0.000292	 0.008521	 6.3209	 4332.88	 4332.88	 4332.88	 0.0	 0.0	 1	 -30.0	 30.0;
	20321	 13554	 0.000292	 0.008521	 6.3209	 4332.88	 4332.88	 4332.88	 0.0	 0.0	 1	 -30.0	 30.0;
	13554	 20387	 0.000464	 0.012548	 5.56725	 4202.74	 4202.74	 4202.74	 0.0	 0.0	 1	 -30.0	 30.0;
	13555	 13558	 0.000625	 0.043885	 0.0	 478.33	 478.33	 478.33	 1.0	 0.0	 1	 -30.0	 30.0;
	13556	 13558	 -0.000137	 -0.009635	 0.0	 403.33	 403.33	 403.33	 1.0	 0.0	 1	 -30.0	 30.0;
	13556	 20156	 0.02555	 0.125901	 0.08032	 214.22	 214.22	 214.22	 0.0	 0.0	 1	 -30.0	 30.0;
	13557	 13558	 0.00317	 0.222399	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13562	 13565	 0.000294	 0.016962	 0.0	 651.06	 651.06	 651.06	 1.0	 0.0	 1	 -30.0	 30.0;
	13562	 13568	 0.0001	 0.0001	 0.0	 757.79	 757.79	 757.79	 1.03125	 0.0	 1	 -30.0	 30.0;
	13562	 13588	 0.000606	 0.007152	 0.1974	 1160.3	 1160.3	 1160.3	 0.0	 0.0	 1	 -30.0	 30.0;
	13650	 13562	 0.001455	 0.014655	 0.42618	 1317.24	 1317.24	 1317.24	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 13565	 8.4e-05	 0.004864	 0.0	 526.06	 526.06	 526.06	 1.0	 0.0	 1	 -30.0	 30.0;
	13564	 13565	 0.002527	 0.145627	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13566	 13568	 0.000268	 0.02163	 0.0	 378.89	 378.89	 378.89	 1.0	 0.0	 1	 -30.0	 30.0;
	13567	 13568	 0.000268	 0.02163	 0.0	 378.89	 378.89	 378.89	 1.0	 0.0	 1	 -30.0	 30.0;
	13569	 13570	 0.002695	 0.08881	 0.0	 126.1	 126.1	 126.1	 1.0	 0.0	 1	 -30.0	 30.0;
	13569	 13617	 0.00369	 0.014179	 0.00828	 222.69	 222.69	 222.69	 0.0	 0.0	 1	 -30.0	 30.0;
	13572	 13571	 0.000437	 0.028709	 0.0	 433.04	 433.04	 433.04	 1.05	 0.0	 1	 -30.0	 30.0;
	13573	 13638	 0.002258	 0.012598	 0.00665	 245.93	 245.93	 245.93	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 13575	 0.000204	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13575	 13591	 0.005467	 0.026028	 0.02601	 199.64	 199.64	 199.64	 0.0	 0.0	 1	 -30.0	 30.0;
	13576	 13577	 0.009574	 0.31418	 0.0	 60.16	 60.16	 60.16	 1.0	 0.0	 1	 -30.0	 30.0;
	13576	 13578	 0.00747	 0.196598	 0.0	 71.52	 71.52	 71.52	 1.0	 0.0	 1	 -30.0	 30.0;
	13576	 13579	 0.000208	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13579	 13664	 0.006058	 0.031314	 0.14881	 227.22	 227.22	 227.22	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 13580	 0.000111	 0.007821	 0.0	 1579.18	 1579.18	 1579.18	 1.0	 0.0	 1	 -30.0	 30.0;
	13581	 13580	 0.000111	 0.007821	 0.0	 1579.18	 1579.18	 1579.18	 1.0	 0.0	 1	 -30.0	 30.0;
	13580	 13583	 0.000142	 0.011606	 0.0	 1085.78	 1085.78	 1085.78	 1.0	 0.0	 1	 -30.0	 30.0;
	13580	 13584	 0.000254	 0.018477	 0.0	 970.61	 970.61	 970.61	 1.0	 0.0	 1	 -30.0	 30.0;
	13580	 13585	 0.000186	 0.016658	 0.0	 853.18	 853.18	 853.18	 1.0	 0.0	 1	 -30.0	 30.0;
	13580	 13587	 0.00026	 0.021084	 0.0	 813.3	 813.3	 813.3	 1.0	 0.0	 1	 -30.0	 30.0;
	13580	 13631	 0.000262	 0.007499	 4.46471	 4222.83	 4222.83	 4222.83	 0.0	 0.0	 1	 -30.0	 30.0;
	13580	 20321	 0.000801	 0.022112	 13.36136	 4166.89	 4166.89	 4166.89	 0.0	 0.0	 1	 -30.0	 30.0;
	13582	 13581	 0.000735	 0.035205	 0.0	 480.0	 480.0	 480.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13581	 13586	 0.000731	 0.046204	 0.0	 270.44	 270.44	 270.44	 1.0	 0.0	 1	 -30.0	 30.0;
	13581	 13588	 0.000201	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13588	 13656	 0.002783	 0.031203	 0.4839	 1105.95	 1105.95	 1105.95	 0.0	 0.0	 1	 -30.0	 30.0;
	13589	 13590	 0.003511	 0.105317	 0.0	 133.9	 133.9	 133.9	 1.0	 0.0	 1	 -30.0	 30.0;
	13589	 13591	 0.000284	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13593	 13592	 0.000542	 0.033019	 0.0	 402.44	 402.44	 402.44	 1.0	 0.0	 1	 -30.0	 30.0;
	13592	 13667	 0.001524	 0.01837	 0.29557	 1325.02	 1325.02	 1325.02	 0.0	 0.0	 1	 -30.0	 30.0;
	13595	 13594	 8.2e-05	 0.007324	 0.0	 1524.82	 1524.82	 1524.82	 1.0	 0.0	 1	 -30.0	 30.0;
	13594	 13597	 7e-05	 0.004884	 0.0	 1296.98	 1296.98	 1296.98	 1.0	 0.0	 1	 -30.0	 30.0;
	13594	 13598	 0.000166	 0.012938	 0.0	 1295.56	 1295.56	 1295.56	 1.0	 0.0	 1	 -30.0	 30.0;
	13594	 13599	 0.000164	 0.011542	 0.0	 1294.39	 1294.39	 1294.39	 1.0	 0.0	 1	 -30.0	 30.0;
	13596	 13595	 0.000459	 0.028922	 0.0	 364.29	 364.29	 364.29	 1.0	 0.0	 1	 -30.0	 30.0;
	13595	 74250	 0.001163	 0.015757	 0.42526	 1216.69	 1216.69	 1216.69	 0.0	 0.0	 1	 -30.0	 30.0;
	13596	 74113	 0.02984	 0.165693	 0.0855	 227.18	 227.18	 227.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13600	 13657	 0.001714	 0.009642	 0.00451	 194.75	 194.75	 194.75	 0.0	 0.0	 1	 -30.0	 30.0;
	13679	 13600	 0.001723	 0.010085	 0.01441	 182.07	 182.07	 182.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13601	 13604	 -0.000264	 -0.009067	 0.0	 224.41	 224.41	 224.41	 1.0	 0.0	 1	 -30.0	 30.0;
	13601	 13633	 0.004701	 0.023315	 0.03123	 174.76	 174.76	 174.76	 0.0	 0.0	 1	 -30.0	 30.0;
	13601	 13655	 0.019463	 0.107597	 0.13584	 248.49	 248.49	 248.49	 0.0	 0.0	 1	 -30.0	 30.0;
	13657	 13601	 0.001432	 0.008895	 0.00559	 208.49	 208.49	 208.49	 0.0	 0.0	 1	 -30.0	 30.0;
	13601	 13679	 0.001621	 0.007641	 0.00169	 221.71	 221.71	 221.71	 0.0	 0.0	 1	 -30.0	 30.0;
	13602	 13604	 0.003607	 0.123733	 0.0	 112.2	 112.2	 112.2	 1.0	 0.0	 1	 -30.0	 30.0;
	13603	 13604	 0.003607	 0.123733	 0.0	 112.2	 112.2	 112.2	 1.0	 0.0	 1	 -30.0	 30.0;
	13605	 13606	 0.003403	 0.117653	 0.0	 128.57	 128.57	 128.57	 1.0	 0.0	 1	 -30.0	 30.0;
	13605	 13607	 0.000265	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13605	 13608	 0.000208	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13605	 13609	 0.000203	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13605	 13610	 0.000229	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13638	 13607	 0.002609	 0.016475	 0.00613	 204.31	 204.31	 204.31	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 13612	 0.007327	 0.251003	 0.0	 65.57	 65.57	 65.57	 1.00625	 0.0	 1	 -30.0	 30.0;
	13611	 13613	 0.086864	 2.143596	 0.0	 9.36	 9.36	 9.36	 1.0	 0.0	 1	 -30.0	 30.0;
	13633	 13611	 0.033494	 0.204546	 0.06922	 211.1	 211.1	 211.1	 0.0	 0.0	 1	 -30.0	 30.0;
	13655	 13611	 0.012309	 0.063546	 0.01303	 227.58	 227.58	 227.58	 0.0	 0.0	 1	 -30.0	 30.0;
	13614	 13615	 0.00023	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13617	 13616	 0.000523	 0.03074	 0.0	 315.61	 315.61	 315.61	 1.0	 0.0	 1	 -30.0	 30.0;
	13616	 13618	 0.000331	 0.021104	 0.0	 526.22	 526.22	 526.22	 1.0	 0.0	 1	 -30.0	 30.0;
	13616	 13619	 0.000297	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13619	 13675	 0.001317	 0.014208	 0.50862	 1202.07	 1202.07	 1202.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13620	 13624	 0.000258	 0.019011	 0.0	 1507.64	 1507.64	 1507.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13625	 0.000105	 0.009119	 0.0	 1664.47	 1664.47	 1664.47	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13626	 4.8e-05	 0.004118	 0.0	 1662.83	 1662.83	 1662.83	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13627	 9e-05	 0.006117	 0.0	 1662.45	 1662.45	 1662.45	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13628	 0.000126	 0.010685	 0.0	 1661.78	 1661.78	 1661.78	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13629	 8.9e-05	 0.006741	 0.0	 1658.96	 1658.96	 1658.96	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13630	 6.8e-05	 0.005771	 0.0	 1658.66	 1658.66	 1658.66	 1.0	 0.0	 1	 -30.0	 30.0;
	13620	 13631	 0.000201	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13622	 13621	 0.000453	 0.030352	 0.0	 430.69	 430.69	 430.69	 1.0	 0.0	 1	 -30.0	 30.0;
	13621	 13624	 -0.000125	 -0.009216	 0.0	 1407.64	 1407.64	 1407.64	 1.0	 0.0	 1	 -30.0	 30.0;
	13623	 13624	 0.000689	 0.050793	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 13631	 0.000167	 0.004392	 2.32019	 4150.0	 4150.0	 4150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13634	 13635	 0.00028	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13634	 13636	 0.00024	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13637	 13640	 0.000949	 0.046472	 0.0	 527.06	 527.06	 527.06	 1.0	 0.0	 1	 -30.0	 30.0;
	13637	 13641	 0.000512	 0.028771	 0.0	 378.05	 378.05	 378.05	 1.03125	 0.0	 1	 -30.0	 30.0;
	13637	 13642	 0.000558	 0.02863	 0.0	 323.23	 323.23	 323.23	 1.03125	 0.0	 1	 -30.0	 30.0;
	13637	 13643	 0.000237	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13637	 13644	 0.000256	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13638	 13640	 -0.000322	 -0.015747	 0.0	 377.06	 377.06	 377.06	 1.0	 0.0	 1	 -30.0	 30.0;
	13639	 13640	 0.002783	 0.136257	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13646	 13645	 9.6e-05	 0.006494	 0.0	 1388.31	 1388.31	 1388.31	 1.0	 0.0	 1	 -30.0	 30.0;
	13645	 13649	 0.000275	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13647	 13646	 0.000317	 0.018438	 0.0	 448.19	 448.19	 448.19	 1.0	 0.0	 1	 -30.0	 30.0;
	13646	 13648	 0.000261	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13689	 13648	 3.8e-05	 0.000465	 0.00721	 1265.07	 1265.07	 1265.07	 0.0	 0.0	 1	 -30.0	 30.0;
	13651	 13650	 0.000244	 0.016193	 0.0	 547.2	 547.2	 547.2	 1.01875	 0.0	 1	 -30.0	 30.0;
	13650	 13654	 0.0001	 0.004839	 0.0	 641.08	 641.08	 641.08	 1.0125	 0.0	 1	 -30.0	 30.0;
	13652	 13654	 0.000913	 0.048213	 0.0	 320.54	 320.54	 320.54	 1.0	 0.0	 1	 -30.0	 30.0;
	13653	 13654	 0.000913	 0.048213	 0.0	 320.54	 320.54	 320.54	 1.0	 0.0	 1	 -30.0	 30.0;
	13657	 13656	 0.000337	 0.028663	 0.0	 423.57	 423.57	 423.57	 1.00625	 0.0	 1	 -30.0	 30.0;
	13656	 13658	 0.000465	 0.026865	 0.0	 300.14	 300.14	 300.14	 1.0	 0.0	 1	 -30.0	 30.0;
	13656	 13659	 0.000458	 0.028884	 0.0	 298.0	 298.0	 298.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13660	 13661	 0.004295	 0.12431	 0.0	 107.12	 107.12	 107.12	 1.05	 0.0	 1	 -30.0	 30.0;
	13660	 13662	 0.010512	 0.249159	 0.0	 59.4	 59.4	 59.4	 1.05	 0.0	 1	 -30.0	 30.0;
	13664	 13665	 0.005987	 0.170824	 0.0	 69.56	 69.56	 69.56	 0.99375	 0.0	 1	 -30.0	 30.0;
	13667	 13666	 0.000112	 0.008648	 0.0	 1529.43	 1529.43	 1529.43	 1.00625	 0.0	 1	 -30.0	 30.0;
	13666	 13669	 0.000142	 0.012523	 0.0	 1451.16	 1451.16	 1451.16	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 13670	 7.9e-05	 0.005873	 0.0	 1445.51	 1445.51	 1445.51	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 13671	 9.5e-05	 0.007545	 0.0	 1443.57	 1443.57	 1443.57	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 13672	 0.00011	 0.008821	 0.0	 1442.88	 1442.88	 1442.88	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 13673	 8.5e-05	 0.006989	 0.0	 1442.18	 1442.18	 1442.18	 1.0	 0.0	 1	 -30.0	 30.0;
	13666	 13674	 0.000138	 0.011008	 0.0	 1441.35	 1441.35	 1441.35	 1.0	 0.0	 1	 -30.0	 30.0;
	13668	 13667	 0.000274	 0.019065	 0.0	 410.42	 410.42	 410.42	 1.0	 0.0	 1	 -30.0	 30.0;
	13676	 13675	 0.000415	 0.024981	 0.0	 300.33	 300.33	 300.33	 1.0125	 0.0	 1	 -30.0	 30.0;
	13675	 13677	 0.000213	 0.015344	 0.0	 477.43	 477.43	 477.43	 1.0	 0.0	 1	 -30.0	 30.0;
	13675	 13678	 0.000332	 0.019887	 0.0	 474.84	 474.84	 474.84	 0.99375	 0.0	 1	 -30.0	 30.0;
	13675	 13699	 0.00069	 0.008642	 0.11699	 1188.15	 1188.15	 1188.15	 0.0	 0.0	 1	 -30.0	 30.0;
	13679	 13680	 0.004727	 0.149273	 0.0	 72.68	 72.68	 72.68	 1.05625	 0.0	 1	 -30.0	 30.0;
	13682	 13681	 9.5e-05	 0.008076	 0.0	 1375.35	 1375.35	 1375.35	 1.00625	 0.0	 1	 -30.0	 30.0;
	13681	 13684	 3.9e-05	 0.00288	 0.0	 1647.49	 1647.49	 1647.49	 1.025	 0.0	 1	 -30.0	 30.0;
	13681	 13685	 8.2e-05	 0.006753	 0.0	 1647.04	 1647.04	 1647.04	 1.025	 0.0	 1	 -30.0	 30.0;
	13681	 13686	 0.000149	 0.010733	 0.0	 1603.91	 1603.91	 1603.91	 1.0	 0.0	 1	 -30.0	 30.0;
	13681	 13695	 0.000131	 0.003949	 1.4998	 4144.18	 4144.18	 4144.18	 0.0	 0.0	 1	 -30.0	 30.0;
	13683	 13682	 0.000463	 0.028415	 0.0	 291.77	 291.77	 291.77	 1.0	 0.0	 1	 -30.0	 30.0;
	13682	 13699	 0.002218	 0.025864	 0.35189	 1132.23	 1132.23	 1132.23	 0.0	 0.0	 1	 -30.0	 30.0;
	13687	 13688	 0.000216	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13689	 13692	 0.000708	 0.048158	 0.0	 435.8	 435.8	 435.8	 1.0	 0.0	 1	 -30.0	 30.0;
	13689	 13693	 0.000354	 0.020996	 0.0	 567.85	 567.85	 567.85	 0.99375	 0.0	 1	 -30.0	 30.0;
	13689	 13694	 0.000484	 0.021446	 0.0	 565.89	 565.89	 565.89	 0.99375	 0.0	 1	 -30.0	 30.0;
	13690	 13692	 -0.000341	 -0.023161	 0.0	 410.8	 410.8	 410.8	 1.0	 0.0	 1	 -30.0	 30.0;
	13691	 13692	 0.001816	 0.123437	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13696	 13695	 8.3e-05	 0.006819	 0.0	 1289.0	 1289.0	 1289.0	 1.0	 0.0	 1	 -30.0	 30.0;
	13695	 13698	 6.3e-05	 0.005274	 0.0	 1801.93	 1801.93	 1801.93	 1.0	 0.0	 1	 -30.0	 30.0;
	13697	 13696	 0.000409	 0.031812	 0.0	 319.8	 319.8	 319.8	 1.0	 0.0	 1	 -30.0	 30.0;
	13696	 13699	 0.00026	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20000	 20004	 0.000259	 0.00173	 0.00226	 173.79	 173.79	 173.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20000	 20433	 0.004676	 0.028177	 0.01	 208.75	 208.75	 208.75	 0.0	 0.0	 1	 -30.0	 30.0;
	20002	 20001	 0.001724	 0.011736	 0.01624	 243.64	 243.64	 243.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20001	 20010	 0.026974	 0.148936	 0.0679	 210.25	 210.25	 210.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20002	 20003	 0.000247	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20002	 20532	 0.006703	 0.0311	 0.00726	 270.21	 270.21	 270.21	 0.0	 0.0	 1	 -30.0	 30.0;
	20004	 20015	 0.013142	 0.087401	 0.05573	 194.3	 194.3	 194.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20433	 20004	 0.005339	 0.037687	 0.00791	 202.79	 202.79	 202.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20006	 20005	 0.000407	 0.023699	 0.0	 380.02	 380.02	 380.02	 1.0	 0.0	 1	 -30.0	 30.0;
	20005	 20007	 0.000235	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20006	 20028	 0.054383	 0.394748	 0.09079	 179.53	 179.53	 179.53	 0.0	 0.0	 1	 -30.0	 30.0;
	20008	 20009	 0.000269	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20008	 20433	 0.005026	 0.039838	 0.05998	 170.64	 170.64	 170.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20010	 20011	 0.000263	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20017	 20010	 0.012044	 0.053863	 0.04264	 239.36	 239.36	 239.36	 0.0	 0.0	 1	 -30.0	 30.0;
	20026	 20010	 0.012939	 0.096333	 0.08316	 229.87	 229.87	 229.87	 0.0	 0.0	 1	 -30.0	 30.0;
	20012	 20013	 0.000243	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20013	 20014	 0.007445	 0.04934	 0.02837	 187.2	 187.2	 187.2	 0.0	 0.0	 1	 -30.0	 30.0;
	20025	 20013	 0.015128	 0.097786	 0.0558	 165.81	 165.81	 165.81	 0.0	 0.0	 1	 -30.0	 30.0;
	20014	 20017	 0.022426	 0.119515	 0.03646	 233.36	 233.36	 233.36	 0.0	 0.0	 1	 -30.0	 30.0;
	20014	 20019	 0.004572	 0.030479	 0.03655	 202.73	 202.73	 202.73	 0.0	 0.0	 1	 -30.0	 30.0;
	20015	 20016	 0.000293	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20017	 20018	 0.000206	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20019	 20020	 0.000224	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20021	 20019	 0.006281	 0.045433	 0.03337	 179.15	 179.15	 179.15	 0.0	 0.0	 1	 -30.0	 30.0;
	20019	 20023	 0.005716	 0.034201	 0.09267	 175.82	 175.82	 175.82	 0.0	 0.0	 1	 -30.0	 30.0;
	20025	 20021	 0.004115	 0.025533	 0.01599	 186.02	 186.02	 186.02	 0.0	 0.0	 1	 -30.0	 30.0;
	20021	 20031	 0.007093	 0.050804	 0.04349	 185.58	 185.58	 185.58	 0.0	 0.0	 1	 -30.0	 30.0;
	20023	 20022	 0.00066	 0.029275	 0.0	 425.86	 425.86	 425.86	 1.0125	 0.0	 1	 -30.0	 30.0;
	20022	 20024	 0.000261	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20023	 20025	 0.001419	 0.009144	 0.00401	 217.94	 217.94	 217.94	 0.0	 0.0	 1	 -30.0	 30.0;
	20029	 20023	 0.009882	 0.056072	 0.05872	 215.17	 215.17	 215.17	 0.0	 0.0	 1	 -30.0	 30.0;
	20024	 20533	 0.008738	 0.087824	 1.25278	 1234.05	 1234.05	 1234.05	 0.0	 0.0	 1	 -30.0	 30.0;
	20024	 21035	 0.00309	 0.03417	 0.76733	 1142.61	 1142.61	 1142.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 20026	 0.01436	 0.07788	 0.11795	 233.08	 233.08	 233.08	 0.0	 0.0	 1	 -30.0	 30.0;
	20027	 21002	 0.006533	 0.044987	 0.02788	 218.58	 218.58	 218.58	 0.0	 0.0	 1	 -30.0	 30.0;
	20032	 20029	 0.003052	 0.018999	 0.0078	 183.7	 183.7	 183.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20029	 20036	 0.006709	 0.039711	 0.04793	 159.84	 159.84	 159.84	 0.0	 0.0	 1	 -30.0	 30.0;
	20030	 20352	 0.006943	 0.034853	 0.02106	 193.37	 193.37	 193.37	 0.0	 0.0	 1	 -30.0	 30.0;
	20030	 20477	 0.011138	 0.045451	 0.08765	 177.5	 177.5	 177.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20032	 20033	 0.000267	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20036	 20032	 0.00929	 0.04632	 0.01861	 172.73	 172.73	 172.73	 0.0	 0.0	 1	 -30.0	 30.0;
	20034	 20035	 0.000201	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20038	 20034	 0.012471	 0.056592	 0.04122	 190.04	 190.04	 190.04	 0.0	 0.0	 1	 -30.0	 30.0;
	20048	 20034	 0.006838	 0.039084	 0.02297	 210.39	 210.39	 210.39	 0.0	 0.0	 1	 -30.0	 30.0;
	20036	 20486	 0.010002	 0.04543	 0.0327	 217.56	 217.56	 217.56	 0.0	 0.0	 1	 -30.0	 30.0;
	20037	 20305	 0.006402	 0.036197	 0.02017	 216.58	 216.58	 216.58	 0.0	 0.0	 1	 -30.0	 30.0;
	20037	 20450	 0.003257	 0.019951	 0.01996	 240.57	 240.57	 240.57	 0.0	 0.0	 1	 -30.0	 30.0;
	20037	 21011	 0.005668	 0.028882	 0.04043	 233.66	 233.66	 233.66	 0.0	 0.0	 1	 -30.0	 30.0;
	20037	 21047	 0.014821	 0.075095	 0.02742	 206.38	 206.38	 206.38	 0.0	 0.0	 1	 -30.0	 30.0;
	20038	 20039	 0.000204	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20047	 20038	 0.009199	 0.056303	 0.01926	 171.83	 171.83	 171.83	 0.0	 0.0	 1	 -30.0	 30.0;
	20040	 20041	 0.000287	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20040	 20051	 0.004011	 0.023604	 0.01052	 219.62	 219.62	 219.62	 0.0	 0.0	 1	 -30.0	 30.0;
	20040	 20498	 0.001	 0.006637	 0.00287	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20042	 20051	 0.001373	 0.009979	 0.00181	 212.49	 212.49	 212.49	 0.0	 0.0	 1	 -30.0	 30.0;
	20059	 20042	 0.005683	 0.032588	 0.01493	 179.25	 179.25	 179.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20043	 20045	 0.005958	 0.031156	 0.04901	 237.83	 237.83	 237.83	 0.0	 0.0	 1	 -30.0	 30.0;
	20348	 20043	 0.00417	 0.026283	 0.03199	 260.1	 260.1	 260.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20044	 20045	 0.000246	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20056	 20045	 0.016608	 0.088933	 0.02741	 222.5	 222.5	 222.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20046	 20052	 0.008033	 0.050537	 0.0344	 238.78	 238.78	 238.78	 0.0	 0.0	 1	 -30.0	 30.0;
	20046	 20529	 0.008735	 0.038536	 0.01649	 223.46	 223.46	 223.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20047	 20292	 0.006589	 0.036637	 0.28418	 179.82	 179.82	 179.82	 0.0	 0.0	 1	 -30.0	 30.0;
	20048	 20049	 0.000273	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20050	 20051	 0.000202	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20051	 20462	 0.001803	 0.011334	 0.00895	 267.04	 267.04	 267.04	 0.0	 0.0	 1	 -30.0	 30.0;
	20052	 20054	 0.002733	 0.013383	 0.00743	 226.28	 226.28	 226.28	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 20052	 0.00328	 0.014703	 0.00936	 226.27	 226.27	 226.27	 0.0	 0.0	 1	 -30.0	 30.0;
	20053	 20070	 0.007231	 0.038029	 0.26111	 248.18	 248.18	 248.18	 0.0	 0.0	 1	 -30.0	 30.0;
	20298	 20053	 0.010524	 0.056138	 0.05102	 256.66	 256.66	 256.66	 0.0	 0.0	 1	 -30.0	 30.0;
	20054	 20055	 0.000231	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20348	 20054	 0.003114	 0.021447	 0.01317	 188.07	 188.07	 188.07	 0.0	 0.0	 1	 -30.0	 30.0;
	20054	 20389	 0.007307	 0.034326	 0.06555	 238.91	 238.91	 238.91	 0.0	 0.0	 1	 -30.0	 30.0;
	20056	 20058	 0.013047	 0.059066	 0.02331	 232.82	 232.82	 232.82	 0.0	 0.0	 1	 -30.0	 30.0;
	20529	 20056	 0.008456	 0.052574	 0.05247	 226.11	 226.11	 226.11	 0.0	 0.0	 1	 -30.0	 30.0;
	20058	 20057	 0.01175	 0.054293	 0.01902	 209.06	 209.06	 209.06	 0.0	 0.0	 1	 -30.0	 30.0;
	20057	 20087	 0.012595	 0.079061	 0.04745	 191.63	 191.63	 191.63	 0.0	 0.0	 1	 -30.0	 30.0;
	20061	 20059	 0.001624	 0.008681	 0.01003	 223.85	 223.85	 223.85	 0.0	 0.0	 1	 -30.0	 30.0;
	20060	 20061	 0.000261	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20061	 20495	 0.014637	 0.076474	 0.03404	 249.46	 249.46	 249.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20062	 20348	 0.007862	 0.038895	 0.01937	 234.61	 234.61	 234.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20062	 20354	 0.00914	 0.056931	 0.11711	 241.09	 241.09	 241.09	 0.0	 0.0	 1	 -30.0	 30.0;
	20063	 20064	 0.000233	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20063	 20065	 0.000294	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20065	 20080	 0.015902	 0.099438	 0.04517	 224.85	 224.85	 224.85	 0.0	 0.0	 1	 -30.0	 30.0;
	20065	 20498	 0.010693	 0.065923	 0.0972	 243.19	 243.19	 243.19	 0.0	 0.0	 1	 -30.0	 30.0;
	20065	 20529	 0.007106	 0.035918	 0.01468	 201.91	 201.91	 201.91	 0.0	 0.0	 1	 -30.0	 30.0;
	20066	 20334	 0.013604	 0.066733	 0.09367	 234.85	 234.85	 234.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21324	 20066	 0.009045	 0.055487	 0.0106	 236.0	 236.0	 236.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20067	 20068	 0.000284	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20067	 20082	 0.01773	 0.081877	 0.18013	 230.71	 230.71	 230.71	 0.0	 0.0	 1	 -30.0	 30.0;
	20067	 20298	 0.009525	 0.047934	 0.03719	 243.13	 243.13	 243.13	 0.0	 0.0	 1	 -30.0	 30.0;
	20069	 20292	 0.011146	 0.055683	 0.07169	 235.17	 235.17	 235.17	 0.0	 0.0	 1	 -30.0	 30.0;
	20472	 20069	 0.018514	 0.104716	 0.12832	 232.05	 232.05	 232.05	 0.0	 0.0	 1	 -30.0	 30.0;
	20070	 20072	 0.003106	 0.015492	 0.00352	 216.76	 216.76	 216.76	 0.0	 0.0	 1	 -30.0	 30.0;
	20070	 20107	 0.002602	 0.013713	 0.06487	 251.11	 251.11	 251.11	 0.0	 0.0	 1	 -30.0	 30.0;
	20071	 20072	 0.00024	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 20072	 0.004098	 0.022554	 0.00307	 238.6	 238.6	 238.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20074	 20073	 0.000313	 0.021405	 0.0	 407.96	 407.96	 407.96	 1.0	 0.0	 1	 -30.0	 30.0;
	20365	 20073	 0.002886	 0.035449	 1.03912	 1330.87	 1330.87	 1330.87	 0.0	 0.0	 1	 -30.0	 30.0;
	20381	 20073	 0.001091	 0.012953	 0.26465	 1073.79	 1073.79	 1073.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20073	 20396	 0.002446	 0.026146	 1.63411	 1295.99	 1295.99	 1295.99	 0.0	 0.0	 1	 -30.0	 30.0;
	20074	 20077	 0.002894	 0.01593	 0.00349	 232.45	 232.45	 232.45	 0.0	 0.0	 1	 -30.0	 30.0;
	20076	 20075	 0.001755	 0.012157	 0.01232	 244.99	 244.99	 244.99	 0.0	 0.0	 1	 -30.0	 30.0;
	20075	 20519	 0.005733	 0.036801	 0.03292	 226.34	 226.34	 226.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20077	 20076	 0.003201	 0.016537	 0.00955	 203.63	 203.63	 203.63	 0.0	 0.0	 1	 -30.0	 30.0;
	20079	 20076	 0.006051	 0.030588	 0.01334	 192.25	 192.25	 192.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20076	 20109	 0.006503	 0.037568	 0.0628	 234.07	 234.07	 234.07	 0.0	 0.0	 1	 -30.0	 30.0;
	20077	 20078	 0.000296	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20079	 20529	 0.013931	 0.080897	 0.06425	 222.36	 222.36	 222.36	 0.0	 0.0	 1	 -30.0	 30.0;
	20080	 20081	 0.000227	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20080	 20097	 0.003491	 0.017266	 0.00647	 195.15	 195.15	 195.15	 0.0	 0.0	 1	 -30.0	 30.0;
	20082	 20099	 0.015265	 0.065534	 0.11261	 231.26	 231.26	 231.26	 0.0	 0.0	 1	 -30.0	 30.0;
	20082	 21570	 0.003745	 0.019169	 0.00579	 240.75	 240.75	 240.75	 0.0	 0.0	 1	 -30.0	 30.0;
	20083	 20084	 0.000225	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21558	 20084	 0.00343	 0.019514	 0.00977	 195.47	 195.47	 195.47	 0.0	 0.0	 1	 -30.0	 30.0;
	20084	 21570	 0.004539	 0.023392	 0.02846	 214.38	 214.38	 214.38	 0.0	 0.0	 1	 -30.0	 30.0;
	20084	 21674	 0.008452	 0.056036	 0.01616	 191.76	 191.76	 191.76	 0.0	 0.0	 1	 -30.0	 30.0;
	20085	 20086	 0.000221	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20085	 20132	 0.009078	 0.066518	 0.02065	 223.12	 223.12	 223.12	 0.0	 0.0	 1	 -30.0	 30.0;
	20085	 20453	 0.004171	 0.027592	 0.03917	 236.18	 236.18	 236.18	 0.0	 0.0	 1	 -30.0	 30.0;
	20087	 20095	 0.029337	 0.14185	 0.0373	 205.73	 205.73	 205.73	 0.0	 0.0	 1	 -30.0	 30.0;
	20087	 20334	 0.004359	 0.023218	 0.15132	 258.11	 258.11	 258.11	 0.0	 0.0	 1	 -30.0	 30.0;
	20087	 20519	 0.004965	 0.029175	 0.02338	 243.67	 243.67	 243.67	 0.0	 0.0	 1	 -30.0	 30.0;
	20088	 20089	 0.000236	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20088	 21565	 0.011797	 0.052272	 0.01998	 201.34	 201.34	 201.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20088	 21601	 0.000976	 0.007038	 0.00498	 165.89	 165.89	 165.89	 0.0	 0.0	 1	 -30.0	 30.0;
	20088	 21677	 0.002375	 0.011626	 0.01053	 255.28	 255.28	 255.28	 0.0	 0.0	 1	 -30.0	 30.0;
	20088	 23023	 0.02063	 0.095075	 0.03819	 226.05	 226.05	 226.05	 0.0	 0.0	 1	 -30.0	 30.0;
	20090	 20401	 0.001458	 0.007852	 0.00814	 270.46	 270.46	 270.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20090	 21570	 0.005187	 0.029173	 0.03009	 251.87	 251.87	 251.87	 0.0	 0.0	 1	 -30.0	 30.0;
	20091	 20099	 0.002088	 0.009969	 0.00266	 208.27	 208.27	 208.27	 0.0	 0.0	 1	 -30.0	 30.0;
	20091	 20112	 0.005325	 0.0322	 0.02039	 254.75	 254.75	 254.75	 0.0	 0.0	 1	 -30.0	 30.0;
	20091	 20425	 0.000491	 0.002458	 0.00177	 281.12	 281.12	 281.12	 0.0	 0.0	 1	 -30.0	 30.0;
	20092	 20093	 0.000229	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20092	 20094	 0.000214	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20094	 20167	 0.006494	 0.037917	 0.05384	 242.73	 242.73	 242.73	 0.0	 0.0	 1	 -30.0	 30.0;
	20094	 20461	 0.001225	 0.006303	 0.00778	 224.27	 224.27	 224.27	 0.0	 0.0	 1	 -30.0	 30.0;
	20095	 20096	 0.000275	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20095	 20097	 0.002552	 0.013661	 0.00537	 229.05	 229.05	 229.05	 0.0	 0.0	 1	 -30.0	 30.0;
	20109	 20097	 0.006971	 0.040968	 0.01321	 231.59	 231.59	 231.59	 0.0	 0.0	 1	 -30.0	 30.0;
	20098	 20099	 0.000284	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20098	 20100	 0.000231	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20099	 20334	 0.001399	 0.008647	 0.00424	 246.77	 246.77	 246.77	 0.0	 0.0	 1	 -30.0	 30.0;
	20101	 20102	 0.000265	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20101	 20103	 0.000299	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20101	 20104	 0.000235	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20103	 20112	 0.001413	 0.008439	 0.00872	 239.48	 239.48	 239.48	 0.0	 0.0	 1	 -30.0	 30.0;
	20103	 20183	 0.004506	 0.027136	 0.02429	 210.34	 210.34	 210.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20114	 20105	 0.000912	 0.005378	 0.0052	 197.42	 197.42	 197.42	 0.0	 0.0	 1	 -30.0	 30.0;
	20105	 20121	 0.000815	 0.005564	 0.01227	 175.93	 175.93	 175.93	 0.0	 0.0	 1	 -30.0	 30.0;
	20106	 20107	 0.00028	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20121	 20107	 0.001688	 0.012386	 0.00649	 205.04	 205.04	 205.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21569	 20107	 0.002607	 0.018418	 0.00922	 211.73	 211.73	 211.73	 0.0	 0.0	 1	 -30.0	 30.0;
	20108	 20109	 0.000292	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20109	 20325	 0.003191	 0.015711	 0.06817	 277.36	 277.36	 277.36	 0.0	 0.0	 1	 -30.0	 30.0;
	20110	 20130	 0.009255	 0.058395	 0.05508	 233.48	 233.48	 233.48	 0.0	 0.0	 1	 -30.0	 30.0;
	20110	 20438	 0.001371	 0.006901	 0.00304	 258.08	 258.08	 258.08	 0.0	 0.0	 1	 -30.0	 30.0;
	20111	 20112	 0.000257	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20111	 20113	 0.000285	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20114	 20115	 0.000222	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20114	 20136	 0.003714	 0.018552	 0.04086	 221.6	 221.6	 221.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20116	 20133	 0.001353	 0.009595	 0.01534	 185.52	 185.52	 185.52	 0.0	 0.0	 1	 -30.0	 30.0;
	20116	 20171	 0.001387	 0.008306	 0.00956	 203.4	 203.4	 203.4	 0.0	 0.0	 1	 -30.0	 30.0;
	20116	 20510	 0.001129	 0.006516	 0.01186	 240.56	 240.56	 240.56	 0.0	 0.0	 1	 -30.0	 30.0;
	20117	 20161	 0.000914	 0.005464	 0.00646	 198.46	 198.46	 198.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20356	 20117	 0.001925	 0.011301	 0.00719	 230.68	 230.68	 230.68	 0.0	 0.0	 1	 -30.0	 30.0;
	20118	 20119	 0.000261	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20119	 20124	 0.002168	 0.013878	 0.00439	 187.79	 187.79	 187.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20119	 20177	 0.000992	 0.005781	 0.00319	 203.22	 203.22	 203.22	 0.0	 0.0	 1	 -30.0	 30.0;
	20119	 20205	 0.004383	 0.032066	 0.05089	 218.34	 218.34	 218.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20135	 20120	 0.00081	 0.004895	 0.00592	 195.81	 195.81	 195.81	 0.0	 0.0	 1	 -30.0	 30.0;
	20120	 20141	 0.000855	 0.005544	 0.00139	 227.14	 227.14	 227.14	 0.0	 0.0	 1	 -30.0	 30.0;
	20123	 20122	 0.000387	 0.023365	 0.0	 550.17	 550.17	 550.17	 1.00625	 0.0	 1	 -30.0	 30.0;
	20290	 20122	 0.000442	 0.005242	 0.09062	 1153.42	 1153.42	 1153.42	 0.0	 0.0	 1	 -30.0	 30.0;
	20404	 20122	 0.000571	 0.006806	 0.16007	 1144.97	 1144.97	 1144.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20123	 20125	 0.001954	 0.011881	 0.01369	 248.01	 248.01	 248.01	 0.0	 0.0	 1	 -30.0	 30.0;
	20141	 20123	 0.001167	 0.004699	 0.00166	 262.53	 262.53	 262.53	 0.0	 0.0	 1	 -30.0	 30.0;
	20123	 20148	 0.002986	 0.018077	 0.01182	 216.88	 216.88	 216.88	 0.0	 0.0	 1	 -30.0	 30.0;
	20124	 20175	 0.001378	 0.008937	 0.01219	 226.14	 226.14	 226.14	 0.0	 0.0	 1	 -30.0	 30.0;
	20125	 20176	 0.001453	 0.007127	 0.00282	 227.17	 227.17	 227.17	 0.0	 0.0	 1	 -30.0	 30.0;
	20126	 20129	 0.0001	 -0.001263	 0.0	 105.58	 105.58	 105.58	 1.0	 0.0	 1	 -30.0	 30.0;
	20126	 20144	 0.0024	 0.011013	 0.00429	 192.99	 192.99	 192.99	 0.0	 0.0	 1	 -30.0	 30.0;
	20126	 20146	 0.001413	 0.00646	 0.05039	 216.73	 216.73	 216.73	 0.0	 0.0	 1	 -30.0	 30.0;
	20127	 20129	 0.007684	 0.241213	 0.0	 52.79	 52.79	 52.79	 1.0	 0.0	 1	 -30.0	 30.0;
	20128	 20129	 0.007684	 0.241213	 0.0	 52.79	 52.79	 52.79	 1.0	 0.0	 1	 -30.0	 30.0;
	20132	 20130	 0.00276	 0.019384	 0.00899	 245.56	 245.56	 245.56	 0.0	 0.0	 1	 -30.0	 30.0;
	20130	 20522	 0.016146	 0.094758	 0.03967	 220.89	 220.89	 220.89	 0.0	 0.0	 1	 -30.0	 30.0;
	20131	 20132	 0.000253	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20132	 20183	 0.007335	 0.041972	 0.09226	 262.62	 262.62	 262.62	 0.0	 0.0	 1	 -30.0	 30.0;
	20139	 20133	 0.001061	 0.005581	 0.00317	 223.76	 223.76	 223.76	 0.0	 0.0	 1	 -30.0	 30.0;
	20149	 20133	 0.001205	 0.007128	 0.01093	 218.23	 218.23	 218.23	 0.0	 0.0	 1	 -30.0	 30.0;
	20133	 20524	 0.002644	 0.014609	 0.0142	 216.46	 216.46	 216.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20146	 20134	 0.001803	 0.010331	 0.00392	 212.72	 212.72	 212.72	 0.0	 0.0	 1	 -30.0	 30.0;
	20134	 20524	 0.001016	 0.007581	 0.00433	 239.8	 239.8	 239.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21570	 20135	 0.003204	 0.018839	 0.01873	 201.1	 201.1	 201.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20175	 20136	 0.001522	 0.010744	 0.00497	 241.86	 241.86	 241.86	 0.0	 0.0	 1	 -30.0	 30.0;
	20186	 20136	 0.001671	 0.008311	 0.00225	 233.19	 233.19	 233.19	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 20234	 0.002088	 0.012557	 0.0413	 216.27	 216.27	 216.27	 0.0	 0.0	 1	 -30.0	 30.0;
	20136	 20457	 0.008125	 0.047245	 0.08837	 281.94	 281.94	 281.94	 0.0	 0.0	 1	 -30.0	 30.0;
	20137	 20138	 0.000279	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20190	 20137	 0.00206	 0.00744	 0.00208	 191.61	 191.61	 191.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20137	 20289	 0.002598	 0.012719	 0.00268	 218.34	 218.34	 218.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20139	 20140	 0.000289	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21570	 20139	 0.001572	 0.009231	 0.04545	 255.13	 255.13	 255.13	 0.0	 0.0	 1	 -30.0	 30.0;
	20141	 20142	 0.00026	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20141	 21569	 0.004148	 0.01711	 0.0305	 197.17	 197.17	 197.17	 0.0	 0.0	 1	 -30.0	 30.0;
	20143	 20174	 0.001153	 0.007279	 0.0051	 178.24	 178.24	 178.24	 0.0	 0.0	 1	 -30.0	 30.0;
	20143	 20185	 0.003112	 0.014542	 0.00536	 197.97	 197.97	 197.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20144	 20145	 0.000226	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20144	 20152	 0.000577	 0.002747	 0.00318	 196.48	 196.48	 196.48	 0.0	 0.0	 1	 -30.0	 30.0;
	20144	 20163	 0.000309	 0.002386	 0.00335	 228.98	 228.98	 228.98	 0.0	 0.0	 1	 -30.0	 30.0;
	20200	 20144	 0.002797	 0.015879	 0.01266	 221.3	 221.3	 221.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20146	 20147	 0.000281	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20146	 20179	 0.002994	 0.015607	 0.01356	 198.45	 198.45	 198.45	 0.0	 0.0	 1	 -30.0	 30.0;
	20146	 20197	 0.003162	 0.01768	 0.00669	 208.63	 208.63	 208.63	 0.0	 0.0	 1	 -30.0	 30.0;
	20198	 20148	 0.000408	 0.002759	 0.01494	 178.97	 178.97	 178.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20149	 20150	 0.000263	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20161	 20149	 0.001782	 0.01043	 0.03171	 179.42	 179.42	 179.42	 0.0	 0.0	 1	 -30.0	 30.0;
	20151	 20160	 0.002195	 0.013344	 0.05418	 229.9	 229.9	 229.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21558	 20151	 0.010197	 0.054664	 0.01986	 182.51	 182.51	 182.51	 0.0	 0.0	 1	 -30.0	 30.0;
	20152	 20356	 0.002871	 0.013573	 0.00489	 245.69	 245.69	 245.69	 0.0	 0.0	 1	 -30.0	 30.0;
	20153	 20154	 0.000207	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20153	 20155	 0.000289	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20154	 20173	 0.001984	 0.011293	 0.00164	 168.12	 168.12	 168.12	 0.0	 0.0	 1	 -30.0	 30.0;
	20154	 20213	 0.003019	 0.018553	 0.00709	 204.79	 204.79	 204.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20154	 20510	 0.001434	 0.007086	 0.00551	 230.66	 230.66	 230.66	 0.0	 0.0	 1	 -30.0	 30.0;
	20156	 20157	 0.000259	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 20156	 0.030472	 0.163243	 0.0771	 204.24	 204.24	 204.24	 0.0	 0.0	 1	 -30.0	 30.0;
	20158	 20159	 0.000227	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20158	 20160	 0.000269	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20160	 20356	 0.001253	 0.006457	 0.04414	 202.55	 202.55	 202.55	 0.0	 0.0	 1	 -30.0	 30.0;
	20160	 20510	 0.001227	 0.006726	 0.00455	 232.77	 232.77	 232.77	 0.0	 0.0	 1	 -30.0	 30.0;
	20161	 20162	 0.000218	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20163	 20164	 0.000235	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20163	 20356	 0.001875	 0.012085	 0.0047	 250.13	 250.13	 250.13	 0.0	 0.0	 1	 -30.0	 30.0;
	20165	 20166	 0.000241	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20165	 20167	 0.000296	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20167	 20380	 0.006068	 0.033893	 0.07708	 265.24	 265.24	 265.24	 0.0	 0.0	 1	 -30.0	 30.0;
	20168	 20169	 0.000201	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20168	 20373	 0.00378	 0.021209	 0.15264	 223.57	 223.57	 223.57	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 20168	 0.002247	 0.011827	 0.01095	 231.75	 231.75	 231.75	 0.0	 0.0	 1	 -30.0	 30.0;
	20519	 20168	 0.001305	 0.009687	 0.05033	 186.11	 186.11	 186.11	 0.0	 0.0	 1	 -30.0	 30.0;
	20171	 20170	 0.001765	 0.010538	 0.00492	 158.17	 158.17	 158.17	 0.0	 0.0	 1	 -30.0	 30.0;
	20170	 20176	 0.00183	 0.011478	 0.00558	 204.13	 204.13	 204.13	 0.0	 0.0	 1	 -30.0	 30.0;
	20181	 20172	 0.000325	 0.002135	 0.00187	 209.15	 209.15	 209.15	 0.0	 0.0	 1	 -30.0	 30.0;
	20172	 20232	 0.001713	 0.010335	 0.02723	 187.56	 187.56	 187.56	 0.0	 0.0	 1	 -30.0	 30.0;
	20173	 20190	 0.003331	 0.014385	 0.02787	 221.53	 221.53	 221.53	 0.0	 0.0	 1	 -30.0	 30.0;
	20174	 20175	 0.001329	 0.009601	 0.00166	 215.54	 215.54	 215.54	 0.0	 0.0	 1	 -30.0	 30.0;
	20186	 20175	 0.001369	 0.008331	 0.00356	 214.26	 214.26	 214.26	 0.0	 0.0	 1	 -30.0	 30.0;
	20176	 20177	 0.000899	 0.005768	 0.02238	 159.28	 159.28	 159.28	 0.0	 0.0	 1	 -30.0	 30.0;
	20177	 20178	 0.000281	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20179	 20524	 0.002499	 0.010867	 0.00367	 227.46	 227.46	 227.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20180	 20182	 0.001942	 0.010862	 0.06804	 208.94	 208.94	 208.94	 0.0	 0.0	 1	 -30.0	 30.0;
	20195	 20180	 0.002089	 0.011574	 0.00573	 216.88	 216.88	 216.88	 0.0	 0.0	 1	 -30.0	 30.0;
	20206	 20180	 0.001123	 0.008131	 0.00576	 214.09	 214.09	 214.09	 0.0	 0.0	 1	 -30.0	 30.0;
	20181	 20340	 0.007008	 0.040346	 0.03091	 238.79	 238.79	 238.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20182	 20183	 0.003416	 0.018313	 0.01543	 249.74	 249.74	 249.74	 0.0	 0.0	 1	 -30.0	 30.0;
	20184	 20195	 0.003645	 0.019102	 0.00835	 208.72	 208.72	 208.72	 0.0	 0.0	 1	 -30.0	 30.0;
	20184	 20289	 0.002176	 0.015242	 0.00439	 239.9	 239.9	 239.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20185	 20340	 0.003656	 0.02332	 0.01605	 248.59	 248.59	 248.59	 0.0	 0.0	 1	 -30.0	 30.0;
	20186	 20189	 -0.000657	 -0.016004	 0.0	 105.31	 105.31	 105.31	 1.0	 0.0	 1	 -30.0	 30.0;
	20187	 20189	 0.010852	 0.264193	 0.0	 52.65	 52.65	 52.65	 1.0	 0.0	 1	 -30.0	 30.0;
	20188	 20189	 0.010852	 0.264193	 0.0	 52.65	 52.65	 52.65	 1.0	 0.0	 1	 -30.0	 30.0;
	20190	 20191	 0.000251	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20190	 20289	 0.002117	 0.011374	 0.0044	 232.19	 232.19	 232.19	 0.0	 0.0	 1	 -30.0	 30.0;
	20192	 20193	 0.000266	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20192	 20194	 0.00024	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20194	 20202	 0.001919	 0.012424	 0.00796	 214.96	 214.96	 214.96	 0.0	 0.0	 1	 -30.0	 30.0;
	20194	 20213	 0.002089	 0.012785	 0.00785	 190.49	 190.49	 190.49	 0.0	 0.0	 1	 -30.0	 30.0;
	20194	 20219	 0.003786	 0.02499	 0.01457	 233.06	 233.06	 233.06	 0.0	 0.0	 1	 -30.0	 30.0;
	20194	 20237	 0.003649	 0.019365	 0.01478	 220.64	 220.64	 220.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20195	 20196	 0.000265	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20195	 20202	 0.002401	 0.014065	 0.02393	 199.08	 199.08	 199.08	 0.0	 0.0	 1	 -30.0	 30.0;
	20510	 20197	 0.001045	 0.005858	 0.00408	 233.83	 233.83	 233.83	 0.0	 0.0	 1	 -30.0	 30.0;
	20198	 20199	 0.000224	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20198	 20289	 0.003361	 0.01929	 0.01662	 207.2	 207.2	 207.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23031	 20200	 0.016595	 0.087856	 0.0291	 188.9	 188.9	 188.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20201	 20202	 0.00022	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20203	 20204	 0.000208	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20205	 20203	 0.001575	 0.00979	 0.00304	 245.89	 245.89	 245.89	 0.0	 0.0	 1	 -30.0	 30.0;
	20203	 20382	 0.016572	 0.077941	 0.13887	 272.11	 272.11	 272.11	 0.0	 0.0	 1	 -30.0	 30.0;
	20518	 20203	 0.002877	 0.015184	 0.00395	 171.49	 171.49	 171.49	 0.0	 0.0	 1	 -30.0	 30.0;
	20206	 20210	 0.003147	 0.016205	 0.04119	 235.43	 235.43	 235.43	 0.0	 0.0	 1	 -30.0	 30.0;
	20207	 20231	 0.000779	 0.003972	 0.00232	 160.3	 160.3	 160.3	 0.0	 0.0	 1	 -30.0	 30.0;
	20207	 20239	 0.001908	 0.011655	 0.0375	 207.53	 207.53	 207.53	 0.0	 0.0	 1	 -30.0	 30.0;
	20208	 20209	 0.000279	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20236	 20208	 0.001522	 0.00856	 0.00254	 227.46	 227.46	 227.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20208	 20240	 0.000975	 0.00584	 0.00801	 189.16	 189.16	 189.16	 0.0	 0.0	 1	 -30.0	 30.0;
	20234	 20210	 0.001912	 0.011232	 0.00725	 232.97	 232.97	 232.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20210	 20252	 0.008603	 0.044895	 0.06399	 221.23	 221.23	 221.23	 0.0	 0.0	 1	 -30.0	 30.0;
	20211	 20212	 0.000283	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20218	 20211	 0.000822	 0.004739	 0.00308	 181.63	 181.63	 181.63	 0.0	 0.0	 1	 -30.0	 30.0;
	20211	 20231	 0.002091	 0.012901	 0.00822	 207.56	 207.56	 207.56	 0.0	 0.0	 1	 -30.0	 30.0;
	20216	 20214	 0.002915	 0.017417	 0.00891	 186.5	 186.5	 186.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20214	 20346	 0.004651	 0.028896	 0.01202	 205.7	 205.7	 205.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20214	 23318	 0.00244	 0.012545	 0.04457	 189.01	 189.01	 189.01	 0.0	 0.0	 1	 -30.0	 30.0;
	20215	 20216	 0.000295	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20216	 20241	 0.003011	 0.020972	 0.01148	 220.33	 220.33	 220.33	 0.0	 0.0	 1	 -30.0	 30.0;
	20217	 20218	 0.000277	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20244	 20218	 0.000965	 0.005539	 0.00824	 226.31	 226.31	 226.31	 0.0	 0.0	 1	 -30.0	 30.0;
	20244	 20219	 0.000262	 0.001773	 0.00155	 259.6	 259.6	 259.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20220	 20221	 0.000213	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20220	 20467	 0.007033	 0.031326	 0.01578	 240.57	 240.57	 240.57	 0.0	 0.0	 1	 -30.0	 30.0;
	23074	 20220	 0.005789	 0.036453	 0.02261	 238.66	 238.66	 238.66	 0.0	 0.0	 1	 -30.0	 30.0;
	20222	 20225	 0.00034	 0.009987	 0.0	 103.95	 103.95	 103.95	 1.0	 0.0	 1	 -30.0	 30.0;
	20222	 20226	 0.000254	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20222	 20227	 0.000293	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20223	 20225	 0.004825	 0.141731	 0.0	 51.97	 51.97	 51.97	 1.0	 0.0	 1	 -30.0	 30.0;
	20224	 20225	 0.004825	 0.141731	 0.0	 51.97	 51.97	 51.97	 1.0	 0.0	 1	 -30.0	 30.0;
	20226	 20467	 0.006313	 0.035897	 0.02287	 254.82	 254.82	 254.82	 0.0	 0.0	 1	 -30.0	 30.0;
	23058	 20226	 0.004098	 0.026801	 0.02119	 252.61	 252.61	 252.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20240	 20228	 0.001018	 0.005341	 0.00177	 192.9	 192.9	 192.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20228	 20518	 0.00381	 0.017363	 0.043	 227.51	 227.51	 227.51	 0.0	 0.0	 1	 -30.0	 30.0;
	20229	 20230	 0.00025	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20230	 20232	 0.002482	 0.01554	 0.00854	 217.46	 217.46	 217.46	 0.0	 0.0	 1	 -30.0	 30.0;
	20230	 20248	 0.002621	 0.014683	 0.01101	 260.25	 260.25	 260.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20248	 20231	 0.001927	 0.008368	 0.00573	 230.77	 230.77	 230.77	 0.0	 0.0	 1	 -30.0	 30.0;
	20233	 20234	 0.000219	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20233	 20235	 0.000224	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20340	 20234	 0.001628	 0.0087	 0.00944	 237.23	 237.23	 237.23	 0.0	 0.0	 1	 -30.0	 30.0;
	23318	 20234	 0.000549	 0.002981	 0.00079	 249.99	 249.99	 249.99	 0.0	 0.0	 1	 -30.0	 30.0;
	20397	 20236	 0.003066	 0.014707	 0.01031	 241.05	 241.05	 241.05	 0.0	 0.0	 1	 -30.0	 30.0;
	20237	 20253	 0.007017	 0.03578	 0.03432	 234.39	 234.39	 234.39	 0.0	 0.0	 1	 -30.0	 30.0;
	20261	 20238	 0.007322	 0.040012	 0.02581	 238.03	 238.03	 238.03	 0.0	 0.0	 1	 -30.0	 30.0;
	20238	 20543	 0.002506	 0.016288	 0.00492	 252.12	 252.12	 252.12	 0.0	 0.0	 1	 -30.0	 30.0;
	20258	 20239	 0.001894	 0.010522	 0.04577	 221.55	 221.55	 221.55	 0.0	 0.0	 1	 -30.0	 30.0;
	20241	 20242	 0.000256	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20251	 20241	 0.003532	 0.023	 0.03167	 198.96	 198.96	 198.96	 0.0	 0.0	 1	 -30.0	 30.0;
	20346	 20241	 0.003032	 0.019603	 0.01003	 179.58	 179.58	 179.58	 0.0	 0.0	 1	 -30.0	 30.0;
	20241	 20454	 0.007827	 0.048664	 0.05628	 257.37	 257.37	 257.37	 0.0	 0.0	 1	 -30.0	 30.0;
	20243	 20246	 0.001004	 0.050463	 0.0	 657.56	 657.56	 657.56	 1.0	 0.0	 1	 -30.0	 30.0;
	20243	 20247	 0.000283	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20244	 20246	 -0.000476	 -0.023909	 0.0	 498.11	 498.11	 498.11	 1.0	 0.0	 1	 -30.0	 30.0;
	20245	 20246	 0.00275	 0.138143	 0.0	 159.45	 159.45	 159.45	 1.0	 0.0	 1	 -30.0	 30.0;
	20247	 20396	 0.000313	 0.003732	 0.1306	 1202.68	 1202.68	 1202.68	 0.0	 0.0	 1	 -30.0	 30.0;
	20397	 20248	 0.001172	 0.008568	 0.00348	 303.07	 303.07	 303.07	 0.0	 0.0	 1	 -30.0	 30.0;
	20397	 20248	 0.001172	 0.008568	 0.00348	 303.07	 303.07	 303.07	 0.0	 0.0	 1	 -30.0	 30.0;
	20249	 20250	 0.000209	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20249	 20257	 0.003967	 0.02409	 0.01094	 194.87	 194.87	 194.87	 0.0	 0.0	 1	 -30.0	 30.0;
	20249	 20504	 0.003232	 0.023274	 0.02569	 209.25	 209.25	 209.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20251	 20252	 0.002137	 0.01591	 0.00846	 187.65	 187.65	 187.65	 0.0	 0.0	 1	 -30.0	 30.0;
	20264	 20252	 0.004734	 0.031057	 0.02553	 267.96	 267.96	 267.96	 0.0	 0.0	 1	 -30.0	 30.0;
	20254	 20253	 0.000507	 0.00247	 0.01851	 268.27	 268.27	 268.27	 0.0	 0.0	 1	 -30.0	 30.0;
	20253	 20260	 0.004959	 0.02312	 0.00887	 167.77	 167.77	 167.77	 0.0	 0.0	 1	 -30.0	 30.0;
	20254	 20539	 0.006932	 0.04572	 0.14022	 279.45	 279.45	 279.45	 0.0	 0.0	 1	 -30.0	 30.0;
	20255	 20256	 0.000239	 0.001094	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20262	 20255	 0.006627	 0.04337	 0.06203	 200.32	 200.32	 200.32	 0.0	 0.0	 1	 -30.0	 30.0;
	20273	 20255	 0.014453	 0.089218	 0.02681	 194.63	 194.63	 194.63	 0.0	 0.0	 1	 -30.0	 30.0;
	20255	 20360	 0.032938	 0.16029	 0.05276	 188.64	 188.64	 188.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20257	 20261	 0.002424	 0.009759	 0.02182	 217.33	 217.33	 217.33	 0.0	 0.0	 1	 -30.0	 30.0;
	20258	 20259	 0.000241	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20258	 20260	 0.001037	 0.008606	 0.00786	 237.88	 237.88	 237.88	 0.0	 0.0	 1	 -30.0	 30.0;
	20260	 20310	 0.008261	 0.038991	 0.02395	 251.26	 251.26	 251.26	 0.0	 0.0	 1	 -30.0	 30.0;
	20262	 20263	 0.000292	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20262	 20275	 0.024101	 0.11629	 0.04293	 228.69	 228.69	 228.69	 0.0	 0.0	 1	 -30.0	 30.0;
	20262	 20386	 0.005353	 0.036945	 0.02424	 259.22	 259.22	 259.22	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 20262	 0.007867	 0.041448	 0.00705	 228.02	 228.02	 228.02	 0.0	 0.0	 1	 -30.0	 30.0;
	20265	 20264	 0.00428	 0.023975	 0.01061	 219.69	 219.69	 219.69	 0.0	 0.0	 1	 -30.0	 30.0;
	20264	 20373	 0.010316	 0.047474	 0.08465	 243.03	 243.03	 243.03	 0.0	 0.0	 1	 -30.0	 30.0;
	20265	 20534	 0.007395	 0.040538	 0.07994	 227.92	 227.92	 227.92	 0.0	 0.0	 1	 -30.0	 30.0;
	20266	 20310	 0.002897	 0.019974	 0.01165	 253.75	 253.75	 253.75	 0.0	 0.0	 1	 -30.0	 30.0;
	20266	 23092	 0.006927	 0.036355	 0.2739	 224.66	 224.66	 224.66	 0.0	 0.0	 1	 -30.0	 30.0;
	20267	 20268	 0.000281	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23278	 20267	 0.006301	 0.036331	 0.07593	 240.65	 240.65	 240.65	 0.0	 0.0	 1	 -30.0	 30.0;
	23371	 20267	 0.008116	 0.053092	 0.0431	 179.1	 179.1	 179.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20269	 20270	 0.000275	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20273	 20269	 0.012025	 0.069037	 0.02205	 202.7	 202.7	 202.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20360	 20269	 0.006517	 0.043066	 0.07043	 193.74	 193.74	 193.74	 0.0	 0.0	 1	 -30.0	 30.0;
	20269	 20526	 0.021558	 0.12927	 0.13576	 246.97	 246.97	 246.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20272	 20310	 0.007246	 0.021943	 0.11409	 236.52	 236.52	 236.52	 0.0	 0.0	 1	 -30.0	 30.0;
	20272	 20347	 0.002088	 0.011462	 0.03797	 252.62	 252.62	 252.62	 0.0	 0.0	 1	 -30.0	 30.0;
	20273	 20274	 0.000261	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20275	 20278	 0.000239	 0.006661	 0.0	 202.09	 202.09	 202.09	 1.0	 0.0	 1	 -30.0	 30.0;
	30003	 20275	 0.018909	 0.12529	 0.06159	 225.7	 225.7	 225.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20276	 20278	 0.004848	 0.135196	 0.0	 101.04	 101.04	 101.04	 1.0	 0.0	 1	 -30.0	 30.0;
	20277	 20278	 0.004848	 0.135196	 0.0	 101.04	 101.04	 101.04	 1.0	 0.0	 1	 -30.0	 30.0;
	20279	 20434	 0.010738	 0.05878	 0.12764	 251.41	 251.41	 251.41	 0.0	 0.0	 1	 -30.0	 30.0;
	20279	 30013	 0.01235	 0.059161	 0.01454	 215.42	 215.42	 215.42	 0.0	 0.0	 1	 -30.0	 30.0;
	20280	 20281	 0.001996	 0.009987	 0.00415	 208.34	 208.34	 208.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20280	 23214	 0.08102	 0.451561	 0.13653	 168.97	 168.97	 168.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20280	 30007	 0.006083	 0.035344	 0.00881	 169.95	 169.95	 169.95	 0.0	 0.0	 1	 -30.0	 30.0;
	20281	 20282	 0.000279	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 20281	 0.01467	 0.066809	 0.04285	 240.16	 240.16	 240.16	 0.0	 0.0	 1	 -30.0	 30.0;
	30007	 20281	 0.004667	 0.029846	 0.01176	 203.13	 203.13	 203.13	 0.0	 0.0	 1	 -30.0	 30.0;
	20283	 20286	 0.000609	 0.042628	 0.0	 397.73	 397.73	 397.73	 1.0	 0.0	 1	 -30.0	 30.0;
	20283	 20287	 0.000297	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20283	 20422	 0.000626	 0.008914	 0.16555	 766.1	 766.1	 766.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20284	 20286	 -0.000228	 -0.016001	 0.0	 372.73	 372.73	 372.73	 1.0	 0.0	 1	 -30.0	 30.0;
	20284	 20347	 0.004431	 0.024372	 0.0244	 233.0	 233.0	 233.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20285	 20286	 0.00154	 0.107848	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20289	 20288	 0.000596	 0.034845	 0.0	 493.51	 493.51	 493.51	 1.04375	 0.0	 1	 -30.0	 30.0;
	20288	 20290	 0.000254	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20290	 20339	 0.000517	 0.006222	 0.16726	 1118.68	 1118.68	 1118.68	 0.0	 0.0	 1	 -30.0	 30.0;
	20396	 20290	 0.000508	 0.00694	 0.15605	 1131.45	 1131.45	 1131.45	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 20290	 0.000406	 0.00437	 0.12725	 1062.24	 1062.24	 1062.24	 0.0	 0.0	 1	 -30.0	 30.0;
	20292	 20291	 0.000398	 0.025752	 0.0	 254.59	 254.59	 254.59	 1.0	 0.0	 1	 -30.0	 30.0;
	20291	 20293	 0.000478	 0.03152	 0.0	 420.41	 420.41	 420.41	 1.0125	 0.0	 1	 -30.0	 30.0;
	20291	 20322	 0.00041	 0.005387	 0.15211	 1154.28	 1154.28	 1154.28	 0.0	 0.0	 1	 -30.0	 30.0;
	20324	 20291	 0.002707	 0.034234	 1.08662	 1283.44	 1283.44	 1283.44	 0.0	 0.0	 1	 -30.0	 30.0;
	20365	 20291	 0.000496	 0.006253	 0.11532	 1119.83	 1119.83	 1119.83	 0.0	 0.0	 1	 -30.0	 30.0;
	20291	 20527	 0.000782	 0.008112	 0.25113	 965.43	 965.43	 965.43	 0.0	 0.0	 1	 -30.0	 30.0;
	20292	 20354	 0.004164	 0.027946	 0.01544	 204.64	 204.64	 204.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20292	 20475	 0.00286	 0.02033	 0.00961	 232.85	 232.85	 232.85	 0.0	 0.0	 1	 -30.0	 30.0;
	20294	 20295	 0.003028	 0.070734	 0.0	 153.27	 153.27	 153.27	 1.08125	 0.0	 1	 -30.0	 30.0;
	20357	 20294	 0.006179	 0.038374	 0.01135	 200.8	 200.8	 200.8	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 20294	 0.005306	 0.030357	 0.01304	 230.58	 230.58	 230.58	 0.0	 0.0	 1	 -30.0	 30.0;
	20297	 20296	 0.000107	 0.007909	 0.0	 1320.36	 1320.36	 1320.36	 1.00625	 0.0	 1	 -30.0	 30.0;
	20296	 20299	 0.000122	 0.009065	 0.0	 1587.13	 1587.13	 1587.13	 1.0	 0.0	 1	 -30.0	 30.0;
	20296	 20300	 8.3e-05	 0.006792	 0.0	 1585.65	 1585.65	 1585.65	 1.0	 0.0	 1	 -30.0	 30.0;
	20296	 20301	 8e-05	 0.006386	 0.0	 1585.34	 1585.34	 1585.34	 1.0	 0.0	 1	 -30.0	 30.0;
	20296	 20302	 0.000157	 0.012558	 0.0	 955.48	 955.48	 955.48	 1.0	 0.0	 1	 -30.0	 30.0;
	20296	 20303	 0.000262	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20298	 20297	 0.000372	 0.023356	 0.0	 474.76	 474.76	 474.76	 1.0	 0.0	 1	 -30.0	 30.0;
	20297	 20404	 0.002456	 0.027823	 0.71992	 1217.45	 1217.45	 1217.45	 0.0	 0.0	 1	 -30.0	 30.0;
	20297	 20497	 0.004242	 0.04212	 0.96421	 1283.68	 1283.68	 1283.68	 0.0	 0.0	 1	 -30.0	 30.0;
	20303	 21593	 0.000355	 0.010775	 5.19448	 4067.06	 4067.06	 4067.06	 0.0	 0.0	 1	 -30.0	 30.0;
	20304	 20446	 0.000692	 0.002748	 0.00097	 233.14	 233.14	 233.14	 0.0	 0.0	 1	 -30.0	 30.0;
	20304	 21139	 0.008899	 0.057448	 0.06182	 233.6	 233.6	 233.6	 0.0	 0.0	 1	 -30.0	 30.0;
	20305	 20306	 0.005847	 0.159874	 0.0	 95.46	 95.46	 95.46	 1.0	 0.0	 1	 -30.0	 30.0;
	20305	 20307	 0.005901	 0.180481	 0.0	 59.81	 59.81	 59.81	 1.0	 0.0	 1	 -30.0	 30.0;
	20305	 20464	 0.002005	 0.01458	 0.00936	 223.02	 223.02	 223.02	 0.0	 0.0	 1	 -30.0	 30.0;
	20305	 21024	 0.008134	 0.054168	 0.07116	 234.23	 234.23	 234.23	 0.0	 0.0	 1	 -30.0	 30.0;
	20308	 20312	 0.000188	 0.016653	 0.0	 1630.0	 1630.0	 1630.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20308	 20313	 0.00017	 0.011523	 0.0	 1311.78	 1311.78	 1311.78	 1.0	 0.0	 1	 -30.0	 30.0;
	20308	 20314	 8.1e-05	 0.006797	 0.0	 1311.75	 1311.75	 1311.75	 1.0125	 0.0	 1	 -30.0	 30.0;
	20308	 20436	 0.000257	 0.007324	 3.73839	 4130.97	 4130.97	 4130.97	 0.0	 0.0	 1	 -30.0	 30.0;
	23457	 20308	 0.000249	 0.006485	 3.30434	 4152.71	 4152.71	 4152.71	 0.0	 0.0	 1	 -30.0	 30.0;
	20310	 20309	 0.000708	 0.035649	 0.0	 430.03	 430.03	 430.03	 1.0	 0.0	 1	 -30.0	 30.0;
	20309	 20312	 -9.6e-05	 -0.008518	 0.0	 1480.0	 1480.0	 1480.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20309	 20396	 0.0007	 0.009036	 0.23527	 1150.61	 1150.61	 1150.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20309	 23280	 0.001534	 0.01894	 0.2979	 1161.12	 1161.12	 1161.12	 0.0	 0.0	 1	 -30.0	 30.0;
	20310	 20315	 0.037251	 1.100377	 0.0	 9.1	 9.1	 9.1	 1.0625	 0.0	 1	 -30.0	 30.0;
	20311	 20312	 0.000508	 0.044953	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20317	 20316	 0.000153	 0.011052	 0.0	 1451.31	 1451.31	 1451.31	 1.0	 0.0	 1	 -30.0	 30.0;
	20316	 20319	 0.000149	 0.010058	 0.0	 1124.0	 1124.0	 1124.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20316	 20320	 0.000125	 0.00933	 0.0	 1122.82	 1122.82	 1122.82	 1.0	 0.0	 1	 -30.0	 30.0;
	20316	 20321	 0.0002	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20318	 20317	 0.000219	 0.016194	 0.0	 352.07	 352.07	 352.07	 1.0	 0.0	 1	 -30.0	 30.0;
	20317	 20322	 0.000272	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20318	 20495	 0.002587	 0.012832	 0.02174	 171.75	 171.75	 171.75	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 20318	 0.000361	 0.0025	 0.00142	 224.84	 224.84	 224.84	 0.0	 0.0	 1	 -30.0	 30.0;
	20321	 20387	 0.000133	 0.003624	 1.90969	 4211.91	 4211.91	 4211.91	 0.0	 0.0	 1	 -30.0	 30.0;
	20436	 20321	 0.000401	 0.010718	 6.91847	 4276.25	 4276.25	 4276.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20322	 20365	 0.000549	 0.006493	 0.10308	 1212.69	 1212.69	 1212.69	 0.0	 0.0	 1	 -30.0	 30.0;
	20323	 20354	 0.003705	 0.022366	 0.01002	 205.58	 205.58	 205.58	 0.0	 0.0	 1	 -30.0	 30.0;
	20324	 20327	 0.00025	 0.015127	 0.0	 493.73	 493.73	 493.73	 1.0	 0.0	 1	 -30.0	 30.0;
	20324	 20328	 0.000612	 0.03274	 0.0	 377.3	 377.3	 377.3	 1.04375	 0.0	 1	 -30.0	 30.0;
	20324	 20329	 0.000186	 0.011197	 0.0	 376.04	 376.04	 376.04	 1.0375	 0.0	 1	 -30.0	 30.0;
	20378	 20324	 0.000702	 0.008139	 0.20908	 1094.99	 1094.99	 1094.99	 0.0	 0.0	 1	 -30.0	 30.0;
	20324	 20381	 0.000765	 0.008211	 0.19344	 1254.61	 1254.61	 1254.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20325	 20327	 0.000112	 0.006788	 0.0	 393.73	 393.73	 393.73	 1.0	 0.0	 1	 -30.0	 30.0;
	20357	 20325	 0.001736	 0.007316	 0.00166	 238.98	 238.98	 238.98	 0.0	 0.0	 1	 -30.0	 30.0;
	20326	 20327	 0.002205	 0.133449	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20330	 20357	 0.003946	 0.022221	 0.02023	 189.06	 189.06	 189.06	 0.0	 0.0	 1	 -30.0	 30.0;
	20380	 20330	 0.002929	 0.017997	 0.03177	 245.49	 245.49	 245.49	 0.0	 0.0	 1	 -30.0	 30.0;
	20331	 20332	 0.004266	 0.126513	 0.0	 102.51	 102.51	 102.51	 1.0	 0.0	 1	 -30.0	 30.0;
	20331	 20333	 0.000211	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20331	 20334	 0.000216	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20425	 20334	 0.000204	 0.001288	 0.00019	 172.71	 172.71	 172.71	 0.0	 0.0	 1	 -30.0	 30.0;
	20335	 20338	 0.000301	 0.015859	 0.0	 479.44	 479.44	 479.44	 1.0	 0.0	 1	 -30.0	 30.0;
	20422	 20335	 0.000708	 0.007556	 0.13278	 1144.79	 1144.79	 1144.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20335	 30048	 0.001744	 0.019721	 0.84027	 1202.37	 1202.37	 1202.37	 0.0	 0.0	 1	 -30.0	 30.0;
	20336	 20338	 2e-06	 0.000118	 0.0	 379.44	 379.44	 379.44	 1.0	 0.0	 1	 -30.0	 30.0;
	20336	 20347	 0.0032	 0.019317	 0.01693	 221.81	 221.81	 221.81	 0.0	 0.0	 1	 -30.0	 30.0;
	20539	 20336	 0.000435	 0.002732	 0.00133	 206.04	 206.04	 206.04	 0.0	 0.0	 1	 -30.0	 30.0;
	20337	 20338	 0.001679	 0.088586	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20339	 20342	 0.000569	 0.037893	 0.0	 617.66	 617.66	 617.66	 1.0	 0.0	 1	 -30.0	 30.0;
	20339	 20431	 0.001362	 0.014396	 0.29758	 1179.33	 1179.33	 1179.33	 0.0	 0.0	 1	 -30.0	 30.0;
	20340	 20342	 -0.000142	 -0.009483	 0.0	 517.66	 517.66	 517.66	 1.0	 0.0	 1	 -30.0	 30.0;
	20341	 20342	 0.002437	 0.162392	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20343	 20344	 0.007069	 0.207403	 0.0	 61.95	 61.95	 61.95	 1.0125	 0.0	 1	 -30.0	 30.0;
	20343	 20345	 0.012349	 0.463353	 0.0	 21.32	 21.32	 21.32	 1.0	 0.0	 1	 -30.0	 30.0;
	20343	 20346	 0.00026	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20409	 20347	 0.00336	 0.019527	 0.00799	 221.96	 221.96	 221.96	 0.0	 0.0	 1	 -30.0	 30.0;
	20348	 20349	 0.006458	 0.187505	 0.0	 70.81	 70.81	 70.81	 1.03125	 0.0	 1	 -30.0	 30.0;
	20348	 20350	 0.008354	 0.319669	 0.0	 29.77	 29.77	 29.77	 1.025	 0.0	 1	 -30.0	 30.0;
	20352	 20351	 0.000506	 0.025615	 0.0	 327.16	 327.16	 327.16	 1.0	 0.0	 1	 -30.0	 30.0;
	20351	 20480	 0.000658	 0.007962	 0.16914	 1046.25	 1046.25	 1046.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20353	 20354	 0.000223	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20356	 20355	 0.000442	 0.032189	 0.0	 524.24	 524.24	 524.24	 1.05625	 0.0	 1	 -30.0	 30.0;
	20355	 20466	 0.000658	 0.008415	 0.26698	 1048.97	 1048.97	 1048.97	 0.0	 0.0	 1	 -30.0	 30.0;
	20355	 20509	 0.000494	 0.00615	 0.07779	 1132.57	 1132.57	 1132.57	 0.0	 0.0	 1	 -30.0	 30.0;
	20358	 20359	 0.005927	 0.176437	 0.0	 70.39	 70.39	 70.39	 1.0	 0.0	 1	 -30.0	 30.0;
	20358	 20360	 0.000201	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20362	 20361	 0.000739	 0.029369	 0.0	 440.72	 440.72	 440.72	 1.0125	 0.0	 1	 -30.0	 30.0;
	20361	 20363	 0.000527	 0.025415	 0.0	 486.09	 486.09	 486.09	 1.0	 0.0	 1	 -30.0	 30.0;
	20361	 20364	 0.000251	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20362	 21277	 0.005604	 0.030403	 0.02733	 240.27	 240.27	 240.27	 0.0	 0.0	 1	 -30.0	 30.0;
	20362	 21481	 0.001663	 0.008634	 0.01176	 267.12	 267.12	 267.12	 0.0	 0.0	 1	 -30.0	 30.0;
	21482	 20362	 0.002698	 0.016955	 0.00651	 230.81	 230.81	 230.81	 0.0	 0.0	 1	 -30.0	 30.0;
	20362	 21539	 0.009857	 0.058251	 0.01592	 205.97	 205.97	 205.97	 0.0	 0.0	 1	 -30.0	 30.0;
	21716	 20362	 0.000927	 0.005822	 0.00385	 178.38	 178.38	 178.38	 0.0	 0.0	 1	 -30.0	 30.0;
	21759	 20362	 0.001031	 0.005561	 0.00287	 276.31	 276.31	 276.31	 0.0	 0.0	 1	 -30.0	 30.0;
	20364	 21642	 0.000325	 0.003852	 0.06091	 1159.89	 1159.89	 1159.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21682	 20364	 0.000212	 0.002449	 0.04767	 1029.48	 1029.48	 1029.48	 0.0	 0.0	 1	 -30.0	 30.0;
	20366	 20365	 0.000342	 0.02224	 0.0	 377.76	 377.76	 377.76	 1.04375	 0.0	 1	 -30.0	 30.0;
	20365	 20367	 0.00071	 0.033041	 0.0	 342.51	 342.51	 342.51	 1.0125	 0.0	 1	 -30.0	 30.0;
	20365	 20368	 0.000577	 0.036955	 0.0	 340.37	 340.37	 340.37	 1.0125	 0.0	 1	 -30.0	 30.0;
	20365	 20369	 0.00084	 0.055137	 0.0	 288.04	 288.04	 288.04	 1.0125	 0.0	 1	 -30.0	 30.0;
	20365	 20476	 0.001106	 0.013482	 0.45891	 1127.7	 1127.7	 1127.7	 0.0	 0.0	 1	 -30.0	 30.0;
	20366	 20370	 0.02822	 1.016313	 0.0	 9.88	 9.88	 9.88	 1.03125	 0.0	 1	 -30.0	 30.0;
	20366	 20371	 0.016279	 0.428479	 0.0	 17.55	 17.55	 17.55	 1.01875	 0.0	 1	 -30.0	 30.0;
	20366	 20535	 0.005371	 0.028398	 0.02604	 225.68	 225.68	 225.68	 0.0	 0.0	 1	 -30.0	 30.0;
	20372	 20373	 0.000217	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 20374	 0.000646	 0.037263	 0.0	 341.29	 341.29	 341.29	 1.0	 0.0	 1	 -30.0	 30.0;
	20374	 20376	 0.000586	 0.036997	 0.0	 349.25	 349.25	 349.25	 1.0	 0.0	 1	 -30.0	 30.0;
	20374	 20377	 0.000472	 0.025202	 0.0	 348.93	 348.93	 348.93	 1.0	 0.0	 1	 -30.0	 30.0;
	20374	 20378	 0.000237	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 20382	 0.008763	 0.047	 0.16293	 271.54	 271.54	 271.54	 0.0	 0.0	 1	 -30.0	 30.0;
	20386	 20375	 8.1e-05	 0.000345	 0.00107	 232.5	 232.5	 232.5	 0.0	 0.0	 1	 -30.0	 30.0;
	20375	 20472	 0.005037	 0.025068	 0.01754	 254.22	 254.22	 254.22	 0.0	 0.0	 1	 -30.0	 30.0;
	20378	 20388	 0.004038	 0.052441	 0.72727	 1180.1	 1180.1	 1180.1	 0.0	 0.0	 1	 -30.0	 30.0;
	20378	 20404	 0.00387	 0.043587	 1.92918	 1253.64	 1253.64	 1253.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20380	 20379	 0.000434	 0.02744	 0.0	 333.19	 333.19	 333.19	 1.0	 0.0	 1	 -30.0	 30.0;
	20379	 20381	 0.000294	 0.001024	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20437	 20381	 0.000492	 0.00633	 0.17456	 1279.64	 1279.64	 1279.64	 0.0	 0.0	 1	 -30.0	 30.0;
	20382	 20383	 0.003193	 0.112514	 0.0	 99.05	 99.05	 99.05	 0.9875	 0.0	 1	 -30.0	 30.0;
	20382	 20384	 0.034709	 1.004537	 0.0	 15.73	 15.73	 15.73	 1.01	 0.0	 1	 -30.0	 30.0;
	20522	 20382	 0.004112	 0.027673	 0.0074	 221.29	 221.29	 221.29	 0.0	 0.0	 1	 -30.0	 30.0;
	20385	 20386	 0.000206	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20388	 20387	 8.5e-05	 0.006388	 0.0	 1452.96	 1452.96	 1452.96	 1.0	 0.0	 1	 -30.0	 30.0;
	20387	 20390	 0.000114	 0.009816	 0.0	 1261.55	 1261.55	 1261.55	 1.00625	 0.0	 1	 -30.0	 30.0;
	20387	 20391	 8.8e-05	 0.006963	 0.0	 1259.67	 1259.67	 1259.67	 1.00625	 0.0	 1	 -30.0	 30.0;
	20387	 20392	 8.3e-05	 0.007057	 0.0	 1258.35	 1258.35	 1258.35	 1.00625	 0.0	 1	 -30.0	 30.0;
	20387	 20393	 9.3e-05	 0.007226	 0.0	 1254.82	 1254.82	 1254.82	 1.00625	 0.0	 1	 -30.0	 30.0;
	20387	 20394	 9e-05	 0.007111	 0.0	 1253.35	 1253.35	 1253.35	 1.0	 0.0	 1	 -30.0	 30.0;
	20387	 20395	 0.000117	 0.008703	 0.0	 1253.19	 1253.19	 1253.19	 1.0	 0.0	 1	 -30.0	 30.0;
	20387	 20423	 0.000384	 0.012416	 7.63325	 4206.95	 4206.95	 4206.95	 0.0	 0.0	 1	 -30.0	 30.0;
	20387	 20484	 0.000478	 0.014206	 8.36184	 4223.39	 4223.39	 4223.39	 0.0	 0.0	 1	 -30.0	 30.0;
	20387	 20530	 0.000494	 0.014494	 5.76512	 3975.19	 3975.19	 3975.19	 0.0	 0.0	 1	 -30.0	 30.0;
	20389	 20388	 0.000513	 0.029262	 0.0	 398.03	 398.03	 398.03	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 20388	 0.000299	 0.004135	 0.09236	 1108.61	 1108.61	 1108.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20396	 20399	 0.00053	 0.027333	 0.0	 709.93	 709.93	 709.93	 1.0	 0.0	 1	 -30.0	 30.0;
	20397	 20399	 -9.4e-05	 -0.004869	 0.0	 559.93	 559.93	 559.93	 1.0	 0.0	 1	 -30.0	 30.0;
	20398	 20399	 0.002177	 0.112259	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20400	 20403	 0.000509	 0.028517	 0.0	 541.95	 541.95	 541.95	 1.0	 0.0	 1	 -30.0	 30.0;
	20400	 20404	 0.000214	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20401	 20403	 -0.000149	 -0.008319	 0.0	 491.95	 491.95	 491.95	 1.0	 0.0	 1	 -30.0	 30.0;
	20402	 20403	 0.002366	 0.132534	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20431	 20404	 0.001311	 0.013818	 0.31005	 1213.48	 1213.48	 1213.48	 0.0	 0.0	 1	 -30.0	 30.0;
	20404	 21081	 0.00239	 0.023483	 1.35176	 1339.47	 1339.47	 1339.47	 0.0	 0.0	 1	 -30.0	 30.0;
	20405	 20408	 -0.000141	 -0.004402	 0.0	 209.18	 209.18	 209.18	 1.01875	 0.0	 1	 -30.0	 30.0;
	20405	 20409	 0.000232	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20406	 20408	 0.003888	 0.121139	 0.0	 104.59	 104.59	 104.59	 1.0	 0.0	 1	 -30.0	 30.0;
	20407	 20408	 0.003888	 0.121139	 0.0	 104.59	 104.59	 104.59	 1.0	 0.0	 1	 -30.0	 30.0;
	20411	 20410	 0.000464	 0.027838	 0.0	 413.73	 413.73	 413.73	 1.0	 0.0	 1	 -30.0	 30.0;
	20410	 20414	 0.0001	 -0.000236	 0.0	 598.19	 598.19	 598.19	 1.0	 0.0	 1	 -30.0	 30.0;
	20410	 20422	 0.000872	 0.010478	 0.19884	 1106.21	 1106.21	 1106.21	 0.0	 0.0	 1	 -30.0	 30.0;
	20542	 20410	 0.001048	 0.013687	 0.30187	 1176.76	 1176.76	 1176.76	 0.0	 0.0	 1	 -30.0	 30.0;
	20534	 20411	 0.000122	 0.000696	 0.00057	 262.68	 262.68	 262.68	 0.0	 0.0	 1	 -30.0	 30.0;
	20412	 20414	 0.000536	 0.033618	 0.0	 299.1	 299.1	 299.1	 1.0	 0.0	 1	 -30.0	 30.0;
	20413	 20414	 0.000536	 0.033618	 0.0	 299.1	 299.1	 299.1	 1.0	 0.0	 1	 -30.0	 30.0;
	20416	 20415	 0.000456	 0.023696	 0.0	 379.86	 379.86	 379.86	 1.0	 0.0	 1	 -30.0	 30.0;
	20415	 20417	 0.000273	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20418	 20421	 0.001185	 0.056598	 0.0	 416.45	 416.45	 416.45	 1.0	 0.0	 1	 -30.0	 30.0;
	20418	 20422	 0.000272	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20419	 20421	 -0.000612	 -0.029238	 0.0	 366.45	 366.45	 366.45	 1.0	 0.0	 1	 -30.0	 30.0;
	20419	 20454	 0.006643	 0.049157	 0.00983	 225.48	 225.48	 225.48	 0.0	 0.0	 1	 -30.0	 30.0;
	20420	 20421	 0.002975	 0.142082	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 20427	 9.8e-05	 0.007614	 0.0	 1648.26	 1648.26	 1648.26	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 20428	 0.00011	 0.009596	 0.0	 1496.36	 1496.36	 1496.36	 1.0	 0.0	 1	 -30.0	 30.0;
	20423	 20429	 0.000114	 0.009845	 0.0	 1494.48	 1494.48	 1494.48	 1.00625	 0.0	 1	 -30.0	 30.0;
	20423	 20430	 5.4e-05	 0.004037	 0.0	 1493.68	 1493.68	 1493.68	 1.00625	 0.0	 1	 -30.0	 30.0;
	20423	 20436	 0.000141	 0.004174	 1.78505	 4081.19	 4081.19	 4081.19	 0.0	 0.0	 1	 -30.0	 30.0;
	20423	 20465	 0.000255	 0.006384	 3.64373	 4095.59	 4095.59	 4095.59	 0.0	 0.0	 1	 -30.0	 30.0;
	20513	 20423	 0.000177	 0.004708	 2.38241	 4161.79	 4161.79	 4161.79	 0.0	 0.0	 1	 -30.0	 30.0;
	20425	 20424	 0.000601	 0.034593	 0.0	 451.97	 451.97	 451.97	 1.0125	 0.0	 1	 -30.0	 30.0;
	20424	 20427	 1.4e-05	 0.001113	 0.0	 1523.26	 1523.26	 1523.26	 1.0	 0.0	 1	 -30.0	 30.0;
	20424	 20431	 0.000223	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20426	 20427	 0.000591	 0.046033	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	20452	 20431	 0.000406	 0.004981	 0.08352	 1046.44	 1046.44	 1046.44	 0.0	 0.0	 1	 -30.0	 30.0;
	20432	 20433	 0.000246	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20434	 20435	 0.004037	 0.127261	 0.0	 86.08	 86.08	 86.08	 1.025	 0.0	 1	 -30.0	 30.0;
	20434	 20504	 0.002671	 0.013626	 0.00893	 178.31	 178.31	 178.31	 0.0	 0.0	 1	 -30.0	 30.0;
	20434	 20534	 0.003427	 0.016519	 0.01136	 235.17	 235.17	 235.17	 0.0	 0.0	 1	 -30.0	 30.0;
	20437	 20436	 0.000153	 0.012039	 0.0	 1433.96	 1433.96	 1433.96	 1.0	 0.0	 1	 -30.0	 30.0;
	20436	 20439	 0.000151	 0.010465	 0.0	 1248.47	 1248.47	 1248.47	 1.03125	 0.0	 1	 -30.0	 30.0;
	20436	 20440	 0.000132	 0.010352	 0.0	 1246.48	 1246.48	 1246.48	 1.0	 0.0	 1	 -30.0	 30.0;
	20436	 20441	 0.000122	 0.010085	 0.0	 1243.48	 1243.48	 1243.48	 1.0	 0.0	 1	 -30.0	 30.0;
	20436	 20442	 0.000114	 0.008557	 0.0	 1192.38	 1192.38	 1192.38	 1.03125	 0.0	 1	 -30.0	 30.0;
	20436	 20443	 0.000228	 0.018014	 0.0	 1187.01	 1187.01	 1187.01	 1.0375	 0.0	 1	 -30.0	 30.0;
	20436	 20444	 0.000125	 0.010357	 0.0	 1184.72	 1184.72	 1184.72	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 20436	 0.0026	 0.0073	 3.74	 4130.0	 4130.0	 4130.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20438	 20437	 0.000616	 0.028329	 0.0	 457.13	 457.13	 457.13	 1.0	 0.0	 1	 -30.0	 30.0;
	20437	 20445	 0.000983	 0.071364	 0.0	 217.61	 217.61	 217.61	 0.99375	 0.0	 1	 -30.0	 30.0;
	20452	 20437	 0.001332	 0.017507	 0.32624	 1263.84	 1263.84	 1263.84	 0.0	 0.0	 1	 -30.0	 30.0;
	20437	 20542	 0.000823	 0.010351	 0.36194	 1156.25	 1156.25	 1156.25	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 20447	 0.003164	 0.086709	 0.0	 94.93	 94.93	 94.93	 1.01875	 0.0	 1	 -30.0	 30.0;
	20446	 20448	 0.005123	 0.145975	 0.0	 94.04	 94.04	 94.04	 1.01875	 0.0	 1	 -30.0	 30.0;
	20446	 20449	 0.011715	 0.226538	 0.0	 59.2	 59.2	 59.2	 1.01875	 0.0	 1	 -30.0	 30.0;
	20446	 20486	 0.001199	 0.005491	 0.01148	 273.91	 273.91	 273.91	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 21013	 0.009652	 0.038858	 0.03844	 251.66	 251.66	 251.66	 0.0	 0.0	 1	 -30.0	 30.0;
	20446	 21045	 0.003675	 0.024074	 0.02053	 249.59	 249.59	 249.59	 0.0	 0.0	 1	 -30.0	 30.0;
	20450	 20451	 0.000205	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 20450	 0.001166	 0.006524	 0.00221	 246.61	 246.61	 246.61	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 20452	 0.000371	 0.017569	 0.0	 332.53	 332.53	 332.53	 1.0	 0.0	 1	 -30.0	 30.0;
	20452	 21385	 0.002212	 0.025256	 0.81874	 1282.18	 1282.18	 1282.18	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 20457	 0.001936	 0.011237	 0.00688	 238.54	 238.54	 238.54	 0.0	 0.0	 1	 -30.0	 30.0;
	20461	 20453	 0.000241	 0.001457	 0.00056	 200.15	 200.15	 200.15	 0.0	 0.0	 1	 -30.0	 30.0;
	20453	 20471	 0.000118	 0.000719	 0.00032	 222.49	 222.49	 222.49	 0.0	 0.0	 1	 -30.0	 30.0;
	20455	 20456	 0.007431	 0.27363	 0.0	 82.96	 82.96	 82.96	 1.0125	 0.0	 1	 -30.0	 30.0;
	20455	 20457	 0.000287	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20455	 20458	 0.000232	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20457	 20461	 0.001978	 0.011932	 0.00556	 236.65	 236.65	 236.65	 0.0	 0.0	 1	 -30.0	 30.0;
	20459	 20460	 0.003106	 0.096901	 0.0	 83.08	 83.08	 83.08	 1.0	 0.0	 1	 -30.0	 30.0;
	20459	 20461	 0.000232	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20461	 20471	 0.000396	 0.001809	 0.00059	 154.02	 154.02	 154.02	 0.0	 0.0	 1	 -30.0	 30.0;
	20462	 20477	 0.001201	 0.007258	 0.00354	 227.34	 227.34	 227.34	 0.0	 0.0	 1	 -30.0	 30.0;
	20463	 20464	 0.000296	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 20464	 0.000693	 0.004038	 0.00161	 268.57	 268.57	 268.57	 0.0	 0.0	 1	 -30.0	 30.0;
	20464	 21002	 0.003068	 0.018613	 0.0354	 254.44	 254.44	 254.44	 0.0	 0.0	 1	 -30.0	 30.0;
	20466	 20465	 0.000137	 0.011166	 0.0	 1470.47	 1470.47	 1470.47	 1.0	 0.0	 1	 -30.0	 30.0;
	20465	 20468	 9.9e-05	 0.008043	 0.0	 1426.93	 1426.93	 1426.93	 1.03125	 0.0	 1	 -30.0	 30.0;
	20465	 20469	 0.000113	 0.009312	 0.0	 1426.48	 1426.48	 1426.48	 1.03125	 0.0	 1	 -30.0	 30.0;
	20465	 20470	 0.000152	 0.011599	 0.0	 1425.73	 1425.73	 1425.73	 1.0375	 0.0	 1	 -30.0	 30.0;
	20465	 23431	 8.3e-05	 0.00252	 1.59556	 4120.91	 4120.91	 4120.91	 0.0	 0.0	 1	 -30.0	 30.0;
	20467	 20466	 0.000493	 0.024402	 0.0	 491.31	 491.31	 491.31	 1.0	 0.0	 1	 -30.0	 30.0;
	20466	 23473	 0.002434	 0.0283	 0.47009	 1176.03	 1176.03	 1176.03	 0.0	 0.0	 1	 -30.0	 30.0;
	23072	 20467	 0.020126	 0.074013	 0.01044	 213.28	 213.28	 213.28	 0.0	 0.0	 1	 -30.0	 30.0;
	20473	 20474	 0.004528	 0.152327	 0.0	 107.34	 107.34	 107.34	 0.9875	 0.0	 1	 -30.0	 30.0;
	20473	 20486	 0.000524	 0.002972	 0.00346	 218.9	 218.9	 218.9	 0.0	 0.0	 1	 -30.0	 30.0;
	20477	 20476	 0.000706	 0.038417	 0.0	 354.75	 354.75	 354.75	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 20478	 0.000632	 0.036201	 0.0	 409.11	 409.11	 409.11	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 20479	 0.000478	 0.033552	 0.0	 408.68	 408.68	 408.68	 1.0	 0.0	 1	 -30.0	 30.0;
	20476	 20497	 0.000406	 0.005136	 0.13914	 1208.23	 1208.23	 1208.23	 0.0	 0.0	 1	 -30.0	 30.0;
	20481	 20480	 0.000445	 0.02053	 0.0	 381.68	 381.68	 381.68	 1.0	 0.0	 1	 -30.0	 30.0;
	20480	 20482	 0.000491	 0.029752	 0.0	 402.04	 402.04	 402.04	 1.04375	 0.0	 1	 -30.0	 30.0;
	20480	 20483	 0.000556	 0.043588	 0.0	 401.18	 401.18	 401.18	 1.05	 0.0	 1	 -30.0	 30.0;
	20480	 20497	 0.000706	 0.008627	 0.14763	 1111.12	 1111.12	 1111.12	 0.0	 0.0	 1	 -30.0	 30.0;
	20485	 20484	 7.4e-05	 0.00584	 0.0	 1600.17	 1600.17	 1600.17	 1.00625	 0.0	 1	 -30.0	 30.0;
	20485	 20484	 7.4e-05	 0.00584	 0.0	 1600.17	 1600.17	 1600.17	 1.00625	 0.0	 1	 -30.0	 30.0;
	20485	 20484	 7.4e-05	 0.00584	 0.0	 1600.17	 1600.17	 1600.17	 1.00625	 0.0	 1	 -30.0	 30.0;
	20484	 20487	 0.000103	 0.008035	 0.0	 1501.15	 1501.15	 1501.15	 1.0	 0.0	 1	 -30.0	 30.0;
	20484	 20488	 0.000137	 0.009824	 0.0	 1500.6	 1500.6	 1500.6	 1.00625	 0.0	 1	 -30.0	 30.0;
	20484	 20489	 0.000101	 0.009265	 0.0	 1499.1	 1499.1	 1499.1	 1.0	 0.0	 1	 -30.0	 30.0;
	20484	 20490	 9.2e-05	 0.007968	 0.0	 1498.36	 1498.36	 1498.36	 1.00625	 0.0	 1	 -30.0	 30.0;
	20484	 20491	 6.9e-05	 0.005773	 0.0	 1497.0	 1497.0	 1497.0	 1.00625	 0.0	 1	 -30.0	 30.0;
	20484	 20492	 7.4e-05	 0.005652	 0.0	 1496.37	 1496.37	 1496.37	 1.00625	 0.0	 1	 -30.0	 30.0;
	21641	 20484	 0.000289	 0.008129	 4.76994	 4089.54	 4089.54	 4089.54	 0.0	 0.0	 1	 -30.0	 30.0;
	20486	 20485	 0.000432	 0.021287	 0.0	 620.0	 620.0	 620.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	20485	 20493	 0.000285	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21002	 20486	 0.007741	 0.032838	 0.02266	 241.58	 241.58	 241.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21026	 20493	 0.000942	 0.010188	 0.42669	 1433.49	 1433.49	 1433.49	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 20493	 0.001101	 0.014322	 0.22502	 1365.35	 1365.35	 1365.35	 0.0	 0.0	 1	 -30.0	 30.0;
	20494	 20495	 0.000272	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20496	 30003	 0.01534	 0.095211	 0.19749	 253.31	 253.31	 253.31	 0.0	 0.0	 1	 -30.0	 30.0;
	20498	 20497	 0.000625	 0.034684	 0.0	 407.15	 407.15	 407.15	 1.0125	 0.0	 1	 -30.0	 30.0;
	20497	 20502	 0.000799	 0.037001	 0.0	 394.46	 394.46	 394.46	 1.0	 0.0	 1	 -30.0	 30.0;
	20497	 20503	 0.000347	 0.022627	 0.0	 361.51	 361.51	 361.51	 1.0	 0.0	 1	 -30.0	 30.0;
	20498	 20501	 0.0001	 0.003089	 0.0	 237.15	 237.15	 237.15	 1.04375	 0.0	 1	 -30.0	 30.0;
	20499	 20501	 0.004063	 0.136345	 0.0	 118.58	 118.58	 118.58	 1.0	 0.0	 1	 -30.0	 30.0;
	20500	 20501	 0.004063	 0.136345	 0.0	 118.58	 118.58	 118.58	 1.0	 0.0	 1	 -30.0	 30.0;
	20504	 20507	 0.0001	 -0.001033	 0.0	 264.31	 264.31	 264.31	 1.0	 0.0	 1	 -30.0	 30.0;
	20505	 20507	 0.002837	 0.089248	 0.0	 132.15	 132.15	 132.15	 1.0	 0.0	 1	 -30.0	 30.0;
	20506	 20507	 0.002837	 0.089248	 0.0	 132.15	 132.15	 132.15	 1.0	 0.0	 1	 -30.0	 30.0;
	20509	 20508	 0.000159	 0.011471	 0.0	 1451.6	 1451.6	 1451.6	 1.0125	 0.0	 1	 -30.0	 30.0;
	20508	 20513	 0.000221	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20509	 20512	 0.000857	 0.06	 0.0	 562.96	 562.96	 562.96	 1.0	 0.0	 1	 -30.0	 30.0;
	20510	 20512	 -0.000392	 -0.027435	 0.0	 537.96	 537.96	 537.96	 1.0	 0.0	 1	 -30.0	 30.0;
	20511	 20512	 0.002862	 0.20043	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23431	 20513	 0.000142	 0.003488	 1.53798	 4064.85	 4064.85	 4064.85	 0.0	 0.0	 1	 -30.0	 30.0;
	20514	 20515	 0.0073	 0.204472	 0.0	 64.15	 64.15	 64.15	 1.025	 0.0	 1	 -30.0	 30.0;
	20514	 20516	 0.003242	 0.097462	 0.0	 64.48	 64.48	 64.48	 1.025	 0.0	 1	 -30.0	 30.0;
	20514	 20517	 0.031458	 1.048998	 0.0	 11.7	 11.7	 11.7	 1.025	 0.0	 1	 -30.0	 30.0;
	20514	 20518	 0.000248	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20520	 20521	 0.003189	 0.107942	 0.0	 76.07	 76.07	 76.07	 1.0	 0.0	 1	 -30.0	 30.0;
	20520	 20522	 0.00025	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20523	 20524	 0.000243	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20526	 20525	 0.000496	 0.028608	 0.0	 326.7	 326.7	 326.7	 1.0	 0.0	 1	 -30.0	 30.0;
	20525	 20527	 0.000298	 0.001187	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20528	 20529	 0.000221	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20531	 20530	 0.000104	 0.008885	 0.0	 1415.97	 1415.97	 1415.97	 1.04375	 0.0	 1	 -30.0	 30.0;
	20532	 20531	 0.000405	 0.025458	 0.0	 432.19	 432.19	 432.19	 0.9875	 0.0	 1	 -30.0	 30.0;
	20531	 20533	 0.000278	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20535	 20536	 0.002456	 0.083223	 0.0	 104.51	 104.51	 104.51	 1.0	 0.0	 1	 -30.0	 30.0;
	20535	 20537	 0.00738	 0.228545	 0.0	 69.13	 69.13	 69.13	 1.0	 0.0	 1	 -30.0	 30.0;
	20535	 20538	 0.003446	 0.118304	 0.0	 68.88	 68.88	 68.88	 1.0	 0.0	 1	 -30.0	 30.0;
	20539	 20540	 0.002399	 0.078621	 0.0	 110.63	 110.63	 110.63	 0.99375	 0.0	 1	 -30.0	 30.0;
	20539	 20541	 0.003753	 0.099911	 0.0	 110.2	 110.2	 110.2	 0.99375	 0.0	 1	 -30.0	 30.0;
	20543	 20542	 0.000319	 0.021803	 0.0	 404.14	 404.14	 404.14	 1.0	 0.0	 1	 -30.0	 30.0;
	20542	 20544	 0.000523	 0.026157	 0.0	 496.7	 496.7	 496.7	 1.00625	 0.0	 1	 -30.0	 30.0;
	20542	 20545	 0.000413	 0.025881	 0.0	 496.65	 496.65	 496.65	 1.0	 0.0	 1	 -30.0	 30.0;
	21000	 21001	 0.000264	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21002	 21001	 0.002013	 0.013871	 0.05571	 258.05	 258.05	 258.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21001	 21005	 0.003351	 0.017608	 0.05097	 244.41	 244.41	 244.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21002	 21003	 0.000206	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21004	 21005	 0.000257	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21005	 21006	 0.002158	 0.013147	 0.00404	 208.53	 208.53	 208.53	 0.0	 0.0	 1	 -30.0	 30.0;
	21005	 21060	 0.007319	 0.048291	 0.06778	 245.62	 245.62	 245.62	 0.0	 0.0	 1	 -30.0	 30.0;
	21006	 21007	 0.000208	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21027	 21006	 0.001161	 0.006618	 0.00157	 230.36	 230.36	 230.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21008	 21009	 0.000288	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21008	 21010	 0.000226	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21010	 21011	 0.003953	 0.019862	 0.00832	 224.01	 224.01	 224.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21010	 21013	 0.004456	 0.020844	 0.00454	 228.22	 228.22	 228.22	 0.0	 0.0	 1	 -30.0	 30.0;
	21010	 21031	 0.00325	 0.01995	 0.01034	 241.21	 241.21	 241.21	 0.0	 0.0	 1	 -30.0	 30.0;
	21011	 21012	 0.000237	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21015	 0.000221	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21027	 21014	 0.00218	 0.010688	 0.00545	 231.48	 231.48	 231.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21014	 21040	 0.001809	 0.010442	 0.00445	 206.02	 206.02	 206.02	 0.0	 0.0	 1	 -30.0	 30.0;
	21016	 21017	 0.000275	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21016	 21019	 0.003948	 0.026865	 0.01479	 256.96	 256.96	 256.96	 0.0	 0.0	 1	 -30.0	 30.0;
	21016	 21043	 0.002238	 0.014554	 0.00455	 238.57	 238.57	 238.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21018	 21021	 0.000516	 0.033741	 0.0	 567.92	 567.92	 567.92	 1.0	 0.0	 1	 -30.0	 30.0;
	21018	 21026	 0.000649	 0.008149	 0.16779	 1238.5	 1238.5	 1238.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21019	 21021	 -0.000267	 -0.017432	 0.0	 542.92	 542.92	 542.92	 1.0	 0.0	 1	 -30.0	 30.0;
	21019	 21034	 0.001558	 0.009828	 0.00794	 272.54	 272.54	 272.54	 0.0	 0.0	 1	 -30.0	 30.0;
	21020	 21021	 0.001238	 0.080944	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21022	 21023	 0.00029	 0.001094	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21022	 21024	 0.000281	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21022	 21025	 0.000273	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 21024	 0.003277	 0.022881	 0.01057	 209.85	 209.85	 209.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21026	 21029	 0.000602	 0.045598	 0.0	 523.49	 523.49	 523.49	 1.0	 0.0	 1	 -30.0	 30.0;
	21026	 21035	 0.000424	 0.004898	 0.2139	 1137.78	 1137.78	 1137.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21027	 21029	 -0.000228	 -0.017223	 0.0	 448.49	 448.49	 448.49	 1.0	 0.0	 1	 -30.0	 30.0;
	21028	 21029	 0.002067	 0.156428	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21033	 21030	 0.004169	 0.020709	 0.02122	 209.17	 209.17	 209.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21030	 21041	 0.003288	 0.017548	 0.00829	 215.02	 215.02	 215.02	 0.0	 0.0	 1	 -30.0	 30.0;
	21031	 21060	 0.00871	 0.052358	 0.04861	 216.91	 216.91	 216.91	 0.0	 0.0	 1	 -30.0	 30.0;
	21032	 21033	 0.000276	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21033	 21056	 0.001394	 0.007611	 0.02055	 181.56	 181.56	 181.56	 0.0	 0.0	 1	 -30.0	 30.0;
	21034	 21069	 0.007192	 0.040577	 0.11882	 250.41	 250.41	 250.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 21038	 0.000685	 0.041682	 0.0	 475.75	 475.75	 475.75	 1.0	 0.0	 1	 -30.0	 30.0;
	21035	 21039	 0.000216	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 21166	 0.001031	 0.012332	 0.47227	 1345.66	 1345.66	 1345.66	 0.0	 0.0	 1	 -30.0	 30.0;
	21035	 21221	 0.000749	 0.009533	 0.23376	 1145.14	 1145.14	 1145.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21036	 21038	 -0.000134	 -0.008158	 0.0	 425.75	 425.75	 425.75	 1.0	 0.0	 1	 -30.0	 30.0;
	21041	 21036	 0.000995	 0.004499	 0.00947	 249.08	 249.08	 249.08	 0.0	 0.0	 1	 -30.0	 30.0;
	21047	 21036	 0.002741	 0.013607	 0.0131	 214.45	 214.45	 214.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21037	 21038	 0.002865	 0.174239	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21040	 21041	 0.002303	 0.016187	 0.02807	 185.86	 185.86	 185.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21041	 21042	 0.000276	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21043	 21067	 0.004489	 0.02537	 0.01347	 197.45	 197.45	 197.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21055	 21044	 0.001336	 0.007816	 0.00366	 171.35	 171.35	 171.35	 0.0	 0.0	 1	 -30.0	 30.0;
	21044	 21082	 0.001235	 0.007721	 0.00695	 261.26	 261.26	 261.26	 0.0	 0.0	 1	 -30.0	 30.0;
	21045	 21046	 0.000213	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21049	 21045	 0.004964	 0.026323	 0.03149	 243.52	 243.52	 243.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21047	 21048	 0.000221	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21047	 21056	 0.004769	 0.026345	 0.05571	 221.17	 221.17	 221.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21049	 21094	 0.012407	 0.062709	 0.05586	 229.66	 229.66	 229.66	 0.0	 0.0	 1	 -30.0	 30.0;
	21050	 21062	 0.00232	 0.013412	 0.00821	 187.95	 187.95	 187.95	 0.0	 0.0	 1	 -30.0	 30.0;
	21070	 21050	 0.001069	 0.005511	 0.00212	 221.25	 221.25	 221.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21050	 21095	 0.003542	 0.018461	 0.07854	 185.94	 185.94	 185.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21051	 21069	 0.001185	 0.00601	 0.00348	 225.12	 225.12	 225.12	 0.0	 0.0	 1	 -30.0	 30.0;
	21051	 21119	 0.002562	 0.018763	 0.02235	 194.61	 194.61	 194.61	 0.0	 0.0	 1	 -30.0	 30.0;
	21052	 21053	 0.000205	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21052	 21054	 0.000217	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21085	 21054	 0.002269	 0.00897	 0.00461	 232.25	 232.25	 232.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21115	 21054	 0.003868	 0.01815	 0.00447	 250.3	 250.3	 250.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21069	 21055	 0.002439	 0.012787	 0.00542	 204.12	 204.12	 204.12	 0.0	 0.0	 1	 -30.0	 30.0;
	21071	 21055	 0.003237	 0.01981	 0.03027	 173.31	 173.31	 173.31	 0.0	 0.0	 1	 -30.0	 30.0;
	21056	 21057	 0.0003	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21058	 21059	 0.000211	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21058	 21060	 0.000252	 0.001111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21060	 21061	 0.001537	 0.009161	 0.01565	 250.08	 250.08	 250.08	 0.0	 0.0	 1	 -30.0	 30.0;
	21061	 21067	 0.003673	 0.017949	 0.00727	 232.86	 232.86	 232.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21062	 21070	 0.004059	 0.018076	 0.00724	 202.87	 202.87	 202.87	 0.0	 0.0	 1	 -30.0	 30.0;
	21063	 21064	 0.000231	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21111	 21064	 0.003143	 0.015453	 0.008	 259.82	 259.82	 259.82	 0.0	 0.0	 1	 -30.0	 30.0;
	21064	 21115	 0.003015	 0.015328	 0.00765	 228.44	 228.44	 228.44	 0.0	 0.0	 1	 -30.0	 30.0;
	21064	 21167	 0.005847	 0.029088	 0.04264	 240.88	 240.88	 240.88	 0.0	 0.0	 1	 -30.0	 30.0;
	21065	 21066	 0.000247	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21065	 21118	 0.007593	 0.042947	 0.02652	 228.88	 228.88	 228.88	 0.0	 0.0	 1	 -30.0	 30.0;
	21065	 21167	 0.001445	 0.00901	 0.00926	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21067	 21068	 0.000234	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21067	 21071	 0.004459	 0.020874	 0.01512	 223.24	 223.24	 223.24	 0.0	 0.0	 1	 -30.0	 30.0;
	21070	 21167	 0.000535	 0.002989	 0.0042	 258.48	 258.48	 258.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21105	 21072	 0.001939	 0.01118	 0.00687	 202.79	 202.79	 202.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21072	 21119	 0.000336	 0.002212	 0.01	 233.71	 233.71	 233.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21073	 21079	 0.000287	 0.001886	 0.00107	 199.05	 199.05	 199.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21108	 21073	 0.000574	 0.003473	 0.0113	 229.7	 229.7	 229.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21074	 21139	 0.01085	 0.064274	 0.02724	 224.11	 224.11	 224.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21074	 21223	 0.004917	 0.021215	 0.04639	 188.45	 188.45	 188.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21074	 21237	 0.003619	 0.020255	 0.10574	 201.19	 201.19	 201.19	 0.0	 0.0	 1	 -30.0	 30.0;
	21075	 21076	 0.000259	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21075	 21079	 0.001974	 0.013246	 0.00638	 211.61	 211.61	 211.61	 0.0	 0.0	 1	 -30.0	 30.0;
	21075	 21101	 0.0016	 0.010479	 0.00468	 255.14	 255.14	 255.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21077	 21078	 0.000296	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21105	 21078	 0.000905	 0.004876	 0.00158	 199.27	 199.27	 199.27	 0.0	 0.0	 1	 -30.0	 30.0;
	21078	 21111	 0.000921	 0.006894	 0.00326	 201.21	 201.21	 201.21	 0.0	 0.0	 1	 -30.0	 30.0;
	21079	 21080	 0.000246	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21082	 21081	 0.000719	 0.034104	 0.0	 451.13	 451.13	 451.13	 1.08125	 0.0	 1	 -30.0	 30.0;
	21100	 21081	 0.000275	 0.003436	 0.13686	 1222.15	 1222.15	 1222.15	 0.0	 0.0	 1	 -30.0	 30.0;
	21081	 21107	 0.000531	 0.006823	 0.15478	 1127.0	 1127.0	 1127.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21753	 21081	 0.000519	 0.006933	 0.10886	 1130.42	 1130.42	 1130.42	 0.0	 0.0	 1	 -30.0	 30.0;
	21083	 21084	 0.000216	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21083	 21085	 0.000235	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21085	 21091	 0.00259	 0.008503	 0.04619	 269.9	 269.9	 269.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21085	 21101	 0.000842	 0.004924	 0.00426	 255.57	 255.57	 255.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21086	 21087	 0.000726	 0.004011	 0.00461	 211.5	 211.5	 211.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21086	 0.001539	 0.005297	 0.00143	 228.97	 228.97	 228.97	 0.0	 0.0	 1	 -30.0	 30.0;
	21097	 21087	 0.001165	 0.006271	 0.00299	 203.35	 203.35	 203.35	 0.0	 0.0	 1	 -30.0	 30.0;
	21088	 21133	 0.004285	 0.01925	 0.004	 214.52	 214.52	 214.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21146	 21088	 0.000606	 0.00321	 0.00511	 199.58	 199.58	 199.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21089	 21090	 0.000271	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21089	 21091	 0.000274	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21089	 21092	 0.000266	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21098	 0.001188	 0.007128	 0.0029	 177.51	 177.51	 177.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21091	 21099	 0.001168	 0.006129	 0.00618	 191.99	 191.99	 191.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21114	 21091	 0.000836	 0.004228	 0.00408	 210.9	 210.9	 210.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21093	 21136	 0.001907	 0.010144	 0.00576	 232.04	 232.04	 232.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21094	 21177	 0.004144	 0.02514	 0.01834	 205.18	 205.18	 205.18	 0.0	 0.0	 1	 -30.0	 30.0;
	21095	 21177	 0.002815	 0.013795	 0.01483	 150.12	 150.12	 150.12	 0.0	 0.0	 1	 -30.0	 30.0;
	21095	 21178	 0.00662	 0.034159	 0.01376	 222.83	 222.83	 222.83	 0.0	 0.0	 1	 -30.0	 30.0;
	21096	 21151	 0.002058	 0.01106	 0.00612	 253.33	 253.33	 253.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21191	 21096	 0.001321	 0.006991	 0.00354	 239.5	 239.5	 239.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21097	 21106	 0.003461	 0.019363	 0.04	 242.35	 242.35	 242.35	 0.0	 0.0	 1	 -30.0	 30.0;
	21098	 21111	 0.003567	 0.018284	 0.0142	 218.47	 218.47	 218.47	 0.0	 0.0	 1	 -30.0	 30.0;
	21099	 21143	 0.001786	 0.009705	 0.00808	 199.84	 199.84	 199.84	 0.0	 0.0	 1	 -30.0	 30.0;
	21100	 21103	 0.000955	 0.061901	 0.0	 528.05	 528.05	 528.05	 1.0	 0.0	 1	 -30.0	 30.0;
	21100	 21104	 0.000299	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21101	 21103	 -0.000539	 -0.034938	 0.0	 478.05	 478.05	 478.05	 1.0	 0.0	 1	 -30.0	 30.0;
	21102	 21103	 0.002205	 0.14289	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21105	 21125	 0.001091	 0.006845	 0.00556	 211.98	 211.98	 211.98	 0.0	 0.0	 1	 -30.0	 30.0;
	21106	 21145	 0.006051	 0.027862	 0.0245	 216.15	 216.15	 216.15	 0.0	 0.0	 1	 -30.0	 30.0;
	21148	 21106	 0.001091	 0.00478	 0.00308	 186.96	 186.96	 186.96	 0.0	 0.0	 1	 -30.0	 30.0;
	21108	 21107	 0.000427	 0.023884	 0.0	 533.37	 533.37	 533.37	 1.1	 0.0	 1	 -30.0	 30.0;
	21132	 21107	 0.000605	 0.008047	 0.21057	 1183.87	 1183.87	 1183.87	 0.0	 0.0	 1	 -30.0	 30.0;
	21107	 21181	 0.000308	 0.003735	 0.12961	 1153.25	 1153.25	 1153.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21141	 21108	 0.000988	 0.005347	 0.00202	 243.05	 243.05	 243.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21108	 21146	 0.001584	 0.010878	 0.0161	 232.07	 232.07	 232.07	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 21110	 0.000282	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 21111	 0.000246	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21109	 21112	 0.000265	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21143	 21113	 0.001193	 0.007085	 0.00897	 240.81	 240.81	 240.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21113	 21182	 0.000345	 0.001446	 0.0006	 266.85	 266.85	 266.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21114	 21141	 0.001438	 0.007462	 0.01002	 193.05	 193.05	 193.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21115	 21118	 0.002711	 0.013394	 0.02009	 274.81	 274.81	 274.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21115	 21167	 0.002604	 0.013323	 0.09325	 310.11	 310.11	 310.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21115	 21167	 0.002604	 0.013323	 0.09325	 310.11	 310.11	 310.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21115	 21167	 0.002604	 0.013323	 0.09325	 310.11	 310.11	 310.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 21117	 0.000202	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21116	 21118	 0.00022	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21119	 21118	 0.000821	 0.005316	 0.00198	 240.72	 240.72	 240.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21118	 21145	 0.001976	 0.010135	 0.00697	 235.08	 235.08	 235.08	 0.0	 0.0	 1	 -30.0	 30.0;
	21120	 21123	 0.001023	 0.071084	 0.0	 645.3	 645.3	 645.3	 1.0	 0.0	 1	 -30.0	 30.0;
	21181	 21120	 0.00034	 0.003449	 0.10958	 1105.48	 1105.48	 1105.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21120	 21382	 0.00072	 0.008202	 0.18319	 1258.49	 1258.49	 1258.49	 0.0	 0.0	 1	 -30.0	 30.0;
	21121	 21123	 -0.000599	 -0.041654	 0.0	 495.3	 495.3	 495.3	 1.0	 0.0	 1	 -30.0	 30.0;
	21121	 21125	 0.000447	 0.002655	 0.00166	 262.79	 262.79	 262.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21122	 21123	 0.002264	 0.157322	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21124	 21125	 0.000278	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21125	 21130	 0.001249	 0.007212	 0.04604	 228.85	 228.85	 228.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21126	 21129	 0.003077	 0.014922	 0.07271	 239.61	 239.61	 239.61	 0.0	 0.0	 1	 -30.0	 30.0;
	21126	 21143	 0.000692	 0.003942	 0.00152	 214.16	 214.16	 214.16	 0.0	 0.0	 1	 -30.0	 30.0;
	21127	 21128	 0.00023	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21127	 21143	 0.002571	 0.011883	 0.00923	 226.55	 226.55	 226.55	 0.0	 0.0	 1	 -30.0	 30.0;
	21176	 21127	 0.001249	 0.007497	 0.00243	 188.2	 188.2	 188.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21129	 21152	 0.000703	 0.003233	 0.0011	 228.76	 228.76	 228.76	 0.0	 0.0	 1	 -30.0	 30.0;
	21129	 21165	 0.000512	 0.003056	 0.00212	 257.81	 257.81	 257.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21130	 21131	 0.000223	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21130	 21182	 0.001191	 0.009095	 0.00457	 206.72	 206.72	 206.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21132	 21135	 0.001019	 0.067375	 0.0	 604.44	 604.44	 604.44	 1.0	 0.0	 1	 -30.0	 30.0;
	21132	 21232	 0.0004	 0.004651	 0.10825	 1223.95	 1223.95	 1223.95	 0.0	 0.0	 1	 -30.0	 30.0;
	21133	 21135	 -0.000479	 -0.031709	 0.0	 479.44	 479.44	 479.44	 1.0	 0.0	 1	 -30.0	 30.0;
	21133	 21157	 0.003612	 0.017201	 0.01453	 228.72	 228.72	 228.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21133	 21158	 0.004567	 0.02676	 0.01116	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21134	 21135	 0.002707	 0.179053	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21136	 21137	 0.000251	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21136	 21154	 0.001147	 0.007876	 0.00432	 152.78	 152.78	 152.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21138	 21139	 0.000267	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21148	 21140	 0.001995	 0.012612	 0.00791	 239.22	 239.22	 239.22	 0.0	 0.0	 1	 -30.0	 30.0;
	21242	 21140	 0.000818	 0.004549	 0.0019	 286.05	 286.05	 286.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21141	 21142	 0.000249	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 21154	 0.004764	 0.023433	 0.01172	 214.86	 214.86	 214.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 21158	 0.001919	 0.013292	 0.00748	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21144	 21180	 0.003648	 0.020649	 0.03058	 225.57	 225.57	 225.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21147	 21239	 0.001019	 0.007234	 0.00374	 206.85	 206.85	 206.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21147	 21665	 0.002085	 0.013528	 0.00913	 227.26	 227.26	 227.26	 0.0	 0.0	 1	 -30.0	 30.0;
	21149	 21150	 0.00029	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21149	 21151	 0.000274	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21754	 21151	 0.001018	 0.005039	 0.00214	 264.58	 264.58	 264.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21152	 21153	 0.000248	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21152	 21191	 0.001707	 0.010919	 0.02669	 244.87	 244.87	 244.87	 0.0	 0.0	 1	 -30.0	 30.0;
	21154	 21155	 0.000229	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21156	 21157	 0.000206	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21157	 21176	 0.001019	 0.004191	 0.00183	 194.89	 194.89	 194.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21158	 21159	 0.000281	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21160	 21163	 0.000329	 0.018284	 0.0	 701.27	 701.27	 701.27	 1.0	 0.0	 1	 -30.0	 30.0;
	21160	 21164	 0.000251	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21161	 21163	 1.2e-05	 0.000655	 0.0	 551.27	 551.27	 551.27	 1.0	 0.0	 1	 -30.0	 30.0;
	21161	 21165	 0.001405	 0.007757	 0.00971	 302.21	 302.21	 302.21	 0.0	 0.0	 1	 -30.0	 30.0;
	21161	 21190	 0.001112	 0.00667	 0.00453	 209.89	 209.89	 209.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21259	 21161	 0.000916	 0.005212	 0.00296	 207.52	 207.52	 207.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21162	 21163	 0.001849	 0.102748	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21164	 21642	 0.001012	 0.012677	 0.27625	 1304.64	 1304.64	 1304.64	 0.0	 0.0	 1	 -30.0	 30.0;
	21671	 21164	 0.000331	 0.003895	 0.07303	 1086.33	 1086.33	 1086.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21165	 0.002143	 0.014616	 0.00999	 189.63	 189.63	 189.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21167	 21166	 0.000256	 0.013793	 0.0	 599.45	 599.45	 599.45	 1.00625	 0.0	 1	 -30.0	 30.0;
	21167	 21166	 0.000256	 0.013793	 0.0	 599.45	 599.45	 599.45	 1.00625	 0.0	 1	 -30.0	 30.0;
	21167	 21166	 0.000256	 0.013793	 0.0	 599.45	 599.45	 599.45	 1.00625	 0.0	 1	 -30.0	 30.0;
	21753	 21166	 0.000608	 0.006075	 0.10745	 1177.94	 1177.94	 1177.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21168	 21169	 0.00022	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21168	 21170	 0.000232	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 21654	 0.001337	 0.007202	 0.00199	 234.31	 234.31	 234.31	 0.0	 0.0	 1	 -30.0	 30.0;
	21170	 21723	 0.001704	 0.007825	 0.00894	 273.36	 273.36	 273.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 21170	 0.001248	 0.007434	 0.00181	 200.95	 200.95	 200.95	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21172	 0.000273	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21173	 0.000203	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21174	 0.000261	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21171	 21175	 0.000252	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21173	 21195	 0.003407	 0.014974	 0.00752	 235.44	 235.44	 235.44	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 21173	 0.000678	 0.003768	 0.00722	 250.38	 250.38	 250.38	 0.0	 0.0	 1	 -30.0	 30.0;
	21178	 21237	 0.003949	 0.017014	 0.0165	 212.3	 212.3	 212.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21178	 21389	 0.006207	 0.030154	 0.0452	 257.74	 257.74	 257.74	 0.0	 0.0	 1	 -30.0	 30.0;
	21231	 21179	 0.001077	 0.006962	 0.00832	 161.0	 161.0	 161.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21255	 21179	 0.000593	 0.003543	 0.0012	 238.73	 238.73	 238.73	 0.0	 0.0	 1	 -30.0	 30.0;
	21180	 21233	 0.000764	 0.005354	 0.00187	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21182	 21181	 0.000706	 0.029469	 0.0	 500.62	 500.62	 500.62	 1.1	 0.0	 1	 -30.0	 30.0;
	21181	 21671	 0.000337	 0.00388	 0.10754	 1245.69	 1245.69	 1245.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21183	 21184	 0.000215	 0.001095	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21203	 21183	 0.000986	 0.0039	 0.00507	 193.99	 193.99	 193.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21264	 21183	 0.001427	 0.006832	 0.00227	 220.32	 220.32	 220.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21186	 0.000292	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21185	 21192	 0.004958	 0.024444	 0.01875	 230.22	 230.22	 230.22	 0.0	 0.0	 1	 -30.0	 30.0;
	21187	 21188	 0.000501	 0.003229	 0.00148	 243.17	 243.17	 243.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21187	 21273	 0.002666	 0.016922	 0.00958	 229.03	 229.03	 229.03	 0.0	 0.0	 1	 -30.0	 30.0;
	21188	 21201	 0.003966	 0.016343	 0.01263	 186.7	 186.7	 186.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21188	 21633	 0.00146	 0.009006	 0.00468	 261.46	 261.46	 261.46	 0.0	 0.0	 1	 -30.0	 30.0;
	21189	 21206	 0.001591	 0.009157	 0.00452	 206.6	 206.6	 206.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21353	 21189	 0.001974	 0.011138	 0.02276	 179.51	 179.51	 179.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21189	 21717	 0.005714	 0.031862	 0.01989	 229.19	 229.19	 229.19	 0.0	 0.0	 1	 -30.0	 30.0;
	21190	 21259	 0.000782	 0.004062	 0.00291	 191.17	 191.17	 191.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21191	 21195	 0.002086	 0.012404	 0.00328	 220.91	 220.91	 220.91	 0.0	 0.0	 1	 -30.0	 30.0;
	21192	 21208	 0.000984	 0.005982	 0.00291	 270.09	 270.09	 270.09	 0.0	 0.0	 1	 -30.0	 30.0;
	21193	 21194	 0.000249	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21206	 21193	 0.003565	 0.014848	 0.00877	 185.99	 185.99	 185.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21193	 21654	 0.002233	 0.012182	 0.00917	 234.08	 234.08	 234.08	 0.0	 0.0	 1	 -30.0	 30.0;
	21196	 21197	 0.000615	 0.003668	 0.00251	 231.96	 231.96	 231.96	 0.0	 0.0	 1	 -30.0	 30.0;
	21196	 21317	 0.001534	 0.007623	 0.02046	 173.8	 173.8	 173.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21197	 21262	 0.000828	 0.00597	 0.00576	 251.86	 251.86	 251.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21268	 21197	 0.001535	 0.00637	 0.0022	 204.09	 204.09	 204.09	 0.0	 0.0	 1	 -30.0	 30.0;
	21217	 21198	 0.000712	 0.004707	 0.00415	 180.09	 180.09	 180.09	 0.0	 0.0	 1	 -30.0	 30.0;
	21198	 21224	 0.000781	 0.004755	 0.00165	 207.85	 207.85	 207.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21199	 21200	 0.000275	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21200	 21233	 0.001269	 0.005475	 0.0029	 235.81	 235.81	 235.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21200	 21294	 0.000638	 0.003755	 0.00281	 216.44	 216.44	 216.44	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21202	 0.000208	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21201	 21294	 0.003788	 0.019381	 0.03687	 190.87	 190.87	 190.87	 0.0	 0.0	 1	 -30.0	 30.0;
	21203	 21204	 0.000262	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21203	 21233	 0.002486	 0.014427	 0.01256	 215.79	 215.79	 215.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21205	 21213	 0.003571	 0.028331	 0.03156	 202.97	 202.97	 202.97	 0.0	 0.0	 1	 -30.0	 30.0;
	21254	 21205	 0.004359	 0.024255	 0.01505	 230.89	 230.89	 230.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21206	 21207	 0.000285	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21208	 21209	 0.000278	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21283	 21208	 0.002502	 0.011354	 0.00574	 228.67	 228.67	 228.67	 0.0	 0.0	 1	 -30.0	 30.0;
	21208	 21695	 0.002617	 0.014514	 0.00969	 262.58	 262.58	 262.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21227	 21210	 0.002477	 0.012266	 0.0055	 216.14	 216.14	 216.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21210	 21251	 0.002548	 0.012942	 0.00787	 230.77	 230.77	 230.77	 0.0	 0.0	 1	 -30.0	 30.0;
	21213	 21211	 0.001219	 0.007309	 0.00324	 184.84	 184.84	 184.84	 0.0	 0.0	 1	 -30.0	 30.0;
	21211	 21252	 0.0019	 0.013725	 0.02034	 225.93	 225.93	 225.93	 0.0	 0.0	 1	 -30.0	 30.0;
	21212	 21213	 0.000208	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21214	 21265	 0.007483	 0.029668	 0.03265	 203.41	 203.41	 203.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21214	 21294	 0.002086	 0.01442	 0.00782	 230.15	 230.15	 230.15	 0.0	 0.0	 1	 -30.0	 30.0;
	21215	 21216	 0.000246	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21269	 21215	 0.002013	 0.013534	 0.00719	 234.93	 234.93	 234.93	 0.0	 0.0	 1	 -30.0	 30.0;
	21729	 21215	 0.002143	 0.011951	 0.00637	 249.37	 249.37	 249.37	 0.0	 0.0	 1	 -30.0	 30.0;
	21217	 21351	 0.002566	 0.013641	 0.04374	 218.43	 218.43	 218.43	 0.0	 0.0	 1	 -30.0	 30.0;
	21247	 21218	 0.001562	 0.008574	 0.00657	 206.01	 206.01	 206.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21218	 21665	 0.001313	 0.00764	 0.01017	 233.65	 233.65	 233.65	 0.0	 0.0	 1	 -30.0	 30.0;
	21268	 21219	 0.001399	 0.010716	 0.00425	 236.71	 236.71	 236.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21297	 21219	 0.001053	 0.005522	 0.00237	 165.35	 165.35	 165.35	 0.0	 0.0	 1	 -30.0	 30.0;
	21219	 21327	 0.001686	 0.011381	 0.00631	 251.81	 251.81	 251.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21220	 21269	 0.001706	 0.008841	 0.00362	 200.52	 200.52	 200.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21220	 21270	 0.000703	 0.003456	 0.00143	 246.9	 246.9	 246.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21222	 21221	 0.000425	 0.029486	 0.0	 415.7	 415.7	 415.7	 1.0	 0.0	 1	 -30.0	 30.0;
	21221	 21253	 0.000791	 0.00977	 0.13374	 1036.7	 1036.7	 1036.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21222	 21286	 0.002952	 0.020467	 0.05057	 228.29	 228.29	 228.29	 0.0	 0.0	 1	 -30.0	 30.0;
	21324	 21223	 0.005911	 0.037199	 0.02831	 225.5	 225.5	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21224	 21754	 0.004638	 0.024525	 0.0207	 227.42	 227.42	 227.42	 0.0	 0.0	 1	 -30.0	 30.0;
	21225	 21226	 0.000212	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21225	 21227	 0.000288	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21247	 21227	 0.000611	 0.003917	 0.00154	 182.45	 182.45	 182.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21228	 21229	 0.000284	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21228	 21230	 0.000208	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21228	 21231	 0.000292	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21361	 21231	 0.000568	 0.003656	 0.00284	 225.37	 225.37	 225.37	 0.0	 0.0	 1	 -30.0	 30.0;
	21231	 21729	 0.004126	 0.014495	 0.02016	 249.46	 249.46	 249.46	 0.0	 0.0	 1	 -30.0	 30.0;
	21233	 21232	 0.000574	 0.037541	 0.0	 478.66	 478.66	 478.66	 1.025	 0.0	 1	 -30.0	 30.0;
	21232	 21234	 0.000288	 0.001175	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21638	 21232	 0.000723	 0.008604	 0.13972	 1246.8	 1246.8	 1246.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21264	 21233	 0.002209	 0.013369	 0.00561	 188.31	 188.31	 188.31	 0.0	 0.0	 1	 -30.0	 30.0;
	21235	 21236	 0.000215	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21235	 21237	 0.000527	 0.003563	 0.0021	 206.37	 206.37	 206.37	 0.0	 0.0	 1	 -30.0	 30.0;
	21235	 21254	 0.004496	 0.03045	 0.01994	 227.32	 227.32	 227.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21755	 21235	 0.003536	 0.019951	 0.00886	 226.15	 226.15	 226.15	 0.0	 0.0	 1	 -30.0	 30.0;
	21238	 21242	 0.00106	 0.005126	 0.00332	 254.32	 254.32	 254.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21665	 21238	 0.000447	 0.002544	 0.00119	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21239	 21270	 0.000738	 0.004874	 0.00322	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21240	 21241	 0.000263	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21240	 21242	 0.000212	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21240	 21243	 0.000221	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21242	 21715	 0.000906	 0.005691	 0.00189	 285.0	 285.0	 285.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21244	 21297	 0.000942	 0.006747	 0.00204	 234.75	 234.75	 234.75	 0.0	 0.0	 1	 -30.0	 30.0;
	21244	 21327	 0.001288	 0.007047	 0.00444	 249.36	 249.36	 249.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21245	 21246	 0.000273	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21246	 21307	 0.000999	 0.005842	 0.01248	 178.68	 178.68	 178.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21336	 21246	 0.000974	 0.00566	 0.00171	 201.07	 201.07	 201.07	 0.0	 0.0	 1	 -30.0	 30.0;
	21247	 21248	 0.00028	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21249	 21250	 0.000231	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21249	 21251	 0.000263	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21251	 21271	 0.00077	 0.004249	 0.00197	 249.1	 249.1	 249.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21251	 21308	 0.002688	 0.014893	 0.00863	 254.05	 254.05	 254.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21251	 21333	 0.001905	 0.00985	 0.004	 247.69	 247.69	 247.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21252	 21284	 0.006262	 0.041664	 0.02692	 222.83	 222.83	 222.83	 0.0	 0.0	 1	 -30.0	 30.0;
	21252	 21482	 0.00779	 0.041605	 0.02994	 227.94	 227.94	 227.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21254	 21253	 0.000485	 0.031898	 0.0	 434.44	 434.44	 434.44	 1.03125	 0.0	 1	 -30.0	 30.0;
	21388	 21253	 0.00048	 0.005629	 0.08512	 1113.04	 1113.04	 1113.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21286	 21254	 0.002883	 0.014455	 0.00441	 199.72	 199.72	 199.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21255	 21256	 0.000285	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21341	 21255	 0.001386	 0.007419	 0.01372	 152.84	 152.84	 152.84	 0.0	 0.0	 1	 -30.0	 30.0;
	21729	 21255	 0.001562	 0.010932	 0.00831	 255.86	 255.86	 255.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21257	 21258	 0.000226	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21294	 21257	 0.001165	 0.006273	 0.00215	 233.24	 233.24	 233.24	 0.0	 0.0	 1	 -30.0	 30.0;
	21257	 21304	 0.001479	 0.00886	 0.05689	 250.51	 250.51	 250.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21290	 21259	 0.001586	 0.008066	 0.00553	 199.64	 199.64	 199.64	 0.0	 0.0	 1	 -30.0	 30.0;
	21327	 21260	 0.001176	 0.006425	 0.00389	 230.04	 230.04	 230.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21260	 21420	 0.003204	 0.014799	 0.00747	 207.01	 207.01	 207.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21262	 21261	 0.000326	 0.022024	 0.0	 543.22	 543.22	 543.22	 1.0	 0.0	 1	 -30.0	 30.0;
	21261	 21326	 0.000416	 0.004666	 0.10843	 1131.96	 1131.96	 1131.96	 0.0	 0.0	 1	 -30.0	 30.0;
	21728	 21261	 0.000302	 0.003799	 0.08288	 1155.98	 1155.98	 1155.98	 0.0	 0.0	 1	 -30.0	 30.0;
	21262	 21270	 0.000836	 0.005241	 0.00617	 277.72	 277.72	 277.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21315	 21263	 0.001029	 0.006705	 0.01454	 218.25	 218.25	 218.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21263	 21321	 0.001853	 0.009009	 0.00462	 169.65	 169.65	 169.65	 0.0	 0.0	 1	 -30.0	 30.0;
	21265	 21266	 0.000281	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21273	 21265	 0.001785	 0.010546	 0.00699	 201.39	 201.39	 201.39	 0.0	 0.0	 1	 -30.0	 30.0;
	21265	 21322	 0.000918	 0.004804	 0.0121	 192.83	 192.83	 192.83	 0.0	 0.0	 1	 -30.0	 30.0;
	21267	 21268	 0.000272	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21271	 21336	 0.001038	 0.006082	 0.00962	 226.72	 226.72	 226.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21272	 21273	 0.000223	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21274	 21299	 0.006027	 0.034385	 0.01938	 236.28	 236.28	 236.28	 0.0	 0.0	 1	 -30.0	 30.0;
	21402	 21274	 0.002373	 0.0153	 0.00835	 214.32	 214.32	 214.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21276	 21275	 0.000389	 0.026017	 0.0	 513.22	 513.22	 513.22	 1.0	 0.0	 1	 -30.0	 30.0;
	21409	 21275	 0.000403	 0.004258	 0.13684	 1164.6	 1164.6	 1164.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 21474	 0.000906	 0.011318	 0.56645	 1234.96	 1234.96	 1234.96	 0.0	 0.0	 1	 -30.0	 30.0;
	21275	 21638	 0.000455	 0.005691	 0.1035	 1141.53	 1141.53	 1141.53	 0.0	 0.0	 1	 -30.0	 30.0;
	21276	 21292	 0.000904	 0.006523	 0.01315	 224.22	 224.22	 224.22	 0.0	 0.0	 1	 -30.0	 30.0;
	21276	 21315	 0.001273	 0.005647	 0.01112	 238.5	 238.5	 238.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21316	 21276	 0.002441	 0.013628	 0.00341	 239.51	 239.51	 239.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21277	 21278	 0.000212	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21695	 21277	 0.002759	 0.015183	 0.01164	 215.33	 215.33	 215.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21280	 0.000217	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21290	 0.005445	 0.036989	 0.01884	 235.69	 235.69	 235.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21331	 0.00349	 0.017302	 0.00971	 251.8	 251.8	 251.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21279	 21370	 0.001044	 0.00837	 0.00269	 188.04	 188.04	 188.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21281	 21282	 0.000243	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21282	 21695	 0.002761	 0.01471	 0.01052	 200.67	 200.67	 200.67	 0.0	 0.0	 1	 -30.0	 30.0;
	21723	 21282	 0.001124	 0.005744	 0.00152	 174.19	 174.19	 174.19	 0.0	 0.0	 1	 -30.0	 30.0;
	21349	 21283	 0.001548	 0.005643	 0.00251	 212.5	 212.5	 212.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21283	 21717	 0.001283	 0.00871	 0.00228	 223.81	 223.81	 223.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21284	 21285	 0.000282	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21284	 21386	 0.003767	 0.021958	 0.01057	 241.58	 241.58	 241.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21287	 0.00053	 0.0031	 0.00165	 231.59	 231.59	 231.59	 0.0	 0.0	 1	 -30.0	 30.0;
	21287	 21307	 0.001114	 0.005557	 0.00493	 212.86	 212.86	 212.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21288	 21293	 0.001907	 0.011082	 0.00914	 224.25	 224.25	 224.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21288	 21359	 0.003103	 0.01533	 0.03308	 202.71	 202.71	 202.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21289	 21290	 0.000258	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21289	 21291	 0.000279	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21332	 21292	 0.001564	 0.0094	 0.00472	 222.5	 222.5	 222.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21292	 21357	 0.003534	 0.020097	 0.011	 231.17	 231.17	 231.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21317	 21293	 0.002213	 0.011843	 0.01346	 227.67	 227.67	 227.67	 0.0	 0.0	 1	 -30.0	 30.0;
	21293	 21729	 0.002122	 0.00922	 0.00556	 269.69	 269.69	 269.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21294	 21295	 0.000203	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21297	 0.000605	 0.003842	 0.01177	 204.1	 204.1	 204.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21296	 21383	 0.005461	 0.030344	 0.01457	 239.62	 239.62	 239.62	 0.0	 0.0	 1	 -30.0	 30.0;
	21298	 21301	 0.000207	 0.011839	 0.0	 572.54	 572.54	 572.54	 1.0	 0.0	 1	 -30.0	 30.0;
	21298	 21398	 0.000564	 0.006418	 0.29459	 1108.5	 1108.5	 1108.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21298	 21685	 0.000972	 0.012085	 0.31628	 1157.43	 1157.43	 1157.43	 0.0	 0.0	 1	 -30.0	 30.0;
	21299	 21301	 3e-06	 0.000146	 0.0	 522.54	 522.54	 522.54	 1.0	 0.0	 1	 -30.0	 30.0;
	21302	 21299	 0.003302	 0.016482	 0.00607	 242.86	 242.86	 242.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21299	 21337	 0.002874	 0.009945	 0.01248	 238.07	 238.07	 238.07	 0.0	 0.0	 1	 -30.0	 30.0;
	21300	 21301	 0.000998	 0.05716	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21302	 21303	 0.000292	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21302	 21454	 0.004198	 0.021144	 0.03874	 214.67	 214.67	 214.67	 0.0	 0.0	 1	 -30.0	 30.0;
	21334	 21304	 0.002741	 0.016293	 0.01639	 235.01	 235.01	 235.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21633	 21304	 0.003533	 0.019954	 0.00649	 205.4	 205.4	 205.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21305	 21306	 0.000225	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21306	 21359	 0.001631	 0.009838	 0.00454	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21429	 21306	 0.00248	 0.013104	 0.01167	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21308	 21331	 0.0047	 0.022462	 0.03804	 262.36	 262.36	 262.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21309	 21310	 0.000232	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21309	 21311	 0.000288	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21334	 21310	 0.001722	 0.011202	 0.00558	 214.94	 214.94	 214.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21438	 21310	 0.000999	 0.005425	 0.00224	 174.57	 174.57	 174.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21312	 21313	 0.000283	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21340	 21313	 0.001293	 0.005817	 0.00806	 260.03	 260.03	 260.03	 0.0	 0.0	 1	 -30.0	 30.0;
	21313	 21359	 0.001001	 0.004645	 0.00439	 195.58	 195.58	 195.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21378	 21314	 0.001585	 0.006385	 0.00384	 218.97	 218.97	 218.97	 0.0	 0.0	 1	 -30.0	 30.0;
	21314	 21410	 0.000667	 0.003213	 0.00799	 244.21	 244.21	 244.21	 0.0	 0.0	 1	 -30.0	 30.0;
	21316	 21322	 0.000679	 0.004125	 0.00265	 218.04	 218.04	 218.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21318	 21394	 0.002435	 0.017378	 0.04142	 201.78	 201.78	 201.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21318	 21471	 0.003422	 0.019208	 0.02629	 214.44	 214.44	 214.44	 0.0	 0.0	 1	 -30.0	 30.0;
	21319	 21320	 0.00028	 0.00113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21319	 21321	 0.000285	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21321	 21335	 0.001982	 0.009043	 0.00277	 227.33	 227.33	 227.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21323	 21324	 0.000228	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21371	 21325	 0.00122	 0.006082	 0.00279	 208.34	 208.34	 208.34	 0.0	 0.0	 1	 -30.0	 30.0;
	21325	 21392	 0.001525	 0.011339	 0.01422	 239.52	 239.52	 239.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21326	 21329	 0.000524	 0.034039	 0.0	 654.04	 654.04	 654.04	 1.0	 0.0	 1	 -30.0	 30.0;
	21326	 21382	 0.000411	 0.005173	 0.11412	 1211.58	 1211.58	 1211.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21326	 21607	 0.000975	 0.01109	 0.37161	 1312.38	 1312.38	 1312.38	 0.0	 0.0	 1	 -30.0	 30.0;
	21327	 21329	 -0.000243	 -0.015824	 0.0	 554.04	 554.04	 554.04	 1.0	 0.0	 1	 -30.0	 30.0;
	21328	 21329	 0.00152	 0.098816	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21499	 21330	 0.001752	 0.011516	 0.00325	 228.74	 228.74	 228.74	 0.0	 0.0	 1	 -30.0	 30.0;
	21330	 21643	 0.005868	 0.029233	 0.03435	 247.84	 247.84	 247.84	 0.0	 0.0	 1	 -30.0	 30.0;
	21331	 21692	 0.007368	 0.039194	 0.03382	 250.14	 250.14	 250.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21331	 21699	 0.000724	 0.003127	 0.0056	 280.55	 280.55	 280.55	 0.0	 0.0	 1	 -30.0	 30.0;
	21332	 21633	 0.003047	 0.019539	 0.00386	 237.25	 237.25	 237.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21333	 21383	 0.001315	 0.007824	 0.00318	 267.38	 267.38	 267.38	 0.0	 0.0	 1	 -30.0	 30.0;
	21335	 21406	 0.001633	 0.009129	 0.00408	 242.63	 242.63	 242.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21337	 21338	 0.000289	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21337	 21404	 0.003736	 0.022613	 0.01352	 230.88	 230.88	 230.88	 0.0	 0.0	 1	 -30.0	 30.0;
	21340	 21339	 0.00046	 0.02741	 0.0	 493.01	 493.01	 493.01	 1.03125	 0.0	 1	 -30.0	 30.0;
	21405	 21339	 0.000442	 0.004442	 0.11936	 1285.25	 1285.25	 1285.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21339	 21607	 0.001042	 0.013876	 0.5983	 1322.07	 1322.07	 1322.07	 0.0	 0.0	 1	 -30.0	 30.0;
	21728	 21339	 0.000549	 0.006502	 0.26385	 1167.48	 1167.48	 1167.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21361	 21340	 0.000863	 0.004696	 0.00191	 222.79	 222.79	 222.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21341	 21342	 0.000294	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21341	 21729	 0.003107	 0.016454	 0.00437	 236.33	 236.33	 236.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21344	 0.000261	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21363	 0.002106	 0.015545	 0.005	 207.57	 207.57	 207.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21410	 21343	 0.00053	 0.002982	 0.0011	 216.33	 216.33	 216.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21434	 21343	 0.001595	 0.008154	 0.0099	 188.15	 188.15	 188.15	 0.0	 0.0	 1	 -30.0	 30.0;
	21343	 21484	 0.001385	 0.007497	 0.05334	 211.41	 211.41	 211.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21345	 21346	 0.000211	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21346	 21357	 0.000482	 0.004161	 0.00267	 196.36	 196.36	 196.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21346	 21378	 0.001351	 0.007668	 0.00439	 185.52	 185.52	 185.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21347	 21348	 0.000289	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21347	 21349	 0.00026	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21347	 21350	 0.00028	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21349	 21370	 0.002241	 0.008908	 0.01609	 237.16	 237.16	 237.16	 0.0	 0.0	 1	 -30.0	 30.0;
	21351	 21353	 0.001345	 0.008441	 0.00561	 221.57	 221.57	 221.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 21351	 0.001381	 0.008581	 0.00427	 263.57	 263.57	 263.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21352	 21353	 0.00022	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21354	 21729	 0.003606	 0.018946	 0.01385	 260.17	 260.17	 260.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21355	 21356	 0.000254	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21355	 21424	 0.000951	 0.004693	 0.00954	 171.99	 171.99	 171.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21355	 21628	 0.00315	 0.017834	 0.00559	 224.2	 224.2	 224.2	 0.0	 0.0	 1	 -30.0	 30.0;
	21357	 21358	 0.000291	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21357	 21402	 0.00212	 0.012969	 0.04214	 183.13	 183.13	 183.13	 0.0	 0.0	 1	 -30.0	 30.0;
	21359	 21361	 0.002404	 0.010246	 0.00907	 226.69	 226.69	 226.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21359	 21417	 0.001363	 0.008541	 0.01141	 179.68	 179.68	 179.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21360	 21361	 0.00022	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21362	 21363	 0.000246	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21363	 21491	 0.002099	 0.012751	 0.00647	 190.78	 190.78	 190.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21364	 21442	 0.001119	 0.005557	 0.00414	 209.17	 209.17	 209.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21364	 21466	 0.001694	 0.00954	 0.00978	 185.81	 185.81	 185.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21365	 21366	 0.000265	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21365	 21367	 0.000414	 0.002451	 0.01255	 183.71	 183.71	 183.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21386	 21365	 0.002444	 0.01342	 0.00628	 202.35	 202.35	 202.35	 0.0	 0.0	 1	 -30.0	 30.0;
	21674	 21367	 0.002786	 0.013012	 0.0029	 219.85	 219.85	 219.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21368	 21499	 0.001889	 0.009736	 0.00239	 223.01	 223.01	 223.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21368	 21699	 0.004209	 0.023857	 0.03202	 239.29	 239.29	 239.29	 0.0	 0.0	 1	 -30.0	 30.0;
	21369	 21370	 0.000246	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21370	 21643	 0.004527	 0.028061	 0.02472	 258.87	 258.87	 258.87	 0.0	 0.0	 1	 -30.0	 30.0;
	21420	 21371	 0.001186	 0.007584	 0.00247	 173.88	 173.88	 173.88	 0.0	 0.0	 1	 -30.0	 30.0;
	21372	 21392	 0.001586	 0.00903	 0.00522	 225.78	 225.78	 225.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21372	 21470	 0.000933	 0.0064	 0.00151	 220.73	 220.73	 220.73	 0.0	 0.0	 1	 -30.0	 30.0;
	21372	 21555	 0.004891	 0.031346	 0.0209	 214.36	 214.36	 214.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 21373	 0.000436	 0.034214	 0.0	 466.81	 466.81	 466.81	 1.1	 0.0	 1	 -30.0	 30.0;
	21474	 21373	 0.000268	 0.003758	 0.07051	 1169.1	 1169.1	 1169.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 21379	 0.002618	 0.015503	 0.05447	 275.42	 275.42	 275.42	 0.0	 0.0	 1	 -30.0	 30.0;
	21418	 21374	 0.004	 0.024304	 0.00943	 258.63	 258.63	 258.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 21472	 0.001902	 0.009757	 0.00316	 242.14	 242.14	 242.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21374	 21520	 0.004261	 0.019389	 0.01613	 220.86	 220.86	 220.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21375	 21472	 0.002007	 0.011876	 0.01263	 169.32	 169.32	 169.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21375	 21521	 0.001566	 0.010203	 0.00395	 237.9	 237.9	 237.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21376	 21377	 0.00021	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21376	 21378	 0.000203	 0.001111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21430	 21378	 0.00076	 0.00388	 0.00195	 180.81	 180.81	 180.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21477	 21379	 0.001814	 0.008552	 0.01634	 255.41	 255.41	 255.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21380	 21381	 0.000226	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21413	 21380	 0.002899	 0.014874	 0.00452	 218.77	 218.77	 218.77	 0.0	 0.0	 1	 -30.0	 30.0;
	21498	 21380	 0.007155	 0.038778	 0.01729	 188.54	 188.54	 188.54	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 21382	 0.000538	 0.03593	 0.0	 449.27	 449.27	 449.27	 1.0	 0.0	 1	 -30.0	 30.0;
	21382	 21384	 0.000287	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21382	 21474	 0.00048	 0.006557	 0.17042	 1200.95	 1200.95	 1200.95	 0.0	 0.0	 1	 -30.0	 30.0;
	21382	 21642	 0.000684	 0.008202	 0.13093	 1328.23	 1328.23	 1328.23	 0.0	 0.0	 1	 -30.0	 30.0;
	21382	 21649	 0.000434	 0.004887	 0.2838	 1457.69	 1457.69	 1457.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21383	 21432	 0.002322	 0.014542	 0.0493	 281.13	 281.13	 281.13	 0.0	 0.0	 1	 -30.0	 30.0;
	21386	 21385	 0.000453	 0.020834	 0.0	 450.77	 450.77	 450.77	 1.0	 0.0	 1	 -30.0	 30.0;
	21385	 21387	 0.000216	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21388	 21385	 0.000439	 0.005356	 0.13822	 1110.82	 1110.82	 1110.82	 0.0	 0.0	 1	 -30.0	 30.0;
	21462	 21386	 0.003781	 0.016553	 0.00745	 229.32	 229.32	 229.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21389	 21388	 0.000343	 0.018274	 0.0	 448.1	 448.1	 448.1	 1.00625	 0.0	 1	 -30.0	 30.0;
	21657	 21388	 0.00039	 0.004918	 0.12103	 1155.89	 1155.89	 1155.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 21389	 0.000519	 0.002594	 0.01909	 240.78	 240.78	 240.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21389	 21465	 0.002384	 0.014432	 0.00545	 235.09	 235.09	 235.09	 0.0	 0.0	 1	 -30.0	 30.0;
	21390	 21424	 0.001639	 0.009165	 0.00742	 211.9	 211.9	 211.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21390	 21492	 0.001988	 0.011939	 0.00751	 220.6	 220.6	 220.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 21390	 0.000924	 0.005678	 0.00326	 250.87	 250.87	 250.87	 0.0	 0.0	 1	 -30.0	 30.0;
	21390	 21758	 0.000567	 0.00372	 0.00142	 205.5	 205.5	 205.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 21479	 0.000434	 0.001921	 0.00115	 238.32	 238.32	 238.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21391	 21628	 0.001799	 0.011952	 0.01349	 258.81	 258.81	 258.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21392	 21393	 0.000261	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21392	 21394	 0.002377	 0.012584	 0.00591	 226.1	 226.1	 226.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21396	 21392	 0.002964	 0.016777	 0.00526	 254.13	 254.13	 254.13	 0.0	 0.0	 1	 -30.0	 30.0;
	21394	 21395	 0.000263	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21396	 21481	 0.005264	 0.0349	 0.05322	 236.71	 236.71	 236.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21396	 21573	 0.002534	 0.01702	 0.0956	 229.78	 229.78	 229.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21397	 0.002471	 0.015976	 0.04393	 236.1	 236.1	 236.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 21397	 0.015308	 0.102408	 0.0353	 217.76	 217.76	 217.76	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21398	 0.000428	 0.026263	 0.0	 475.45	 475.45	 475.45	 1.0	 0.0	 1	 -30.0	 30.0;
	21398	 21400	 0.000224	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21398	 23016	 0.00085	 0.009479	 0.2867	 1045.39	 1045.39	 1045.39	 0.0	 0.0	 1	 -30.0	 30.0;
	23375	 21398	 0.000503	 0.006645	 0.11618	 1252.16	 1252.16	 1252.16	 0.0	 0.0	 1	 -30.0	 30.0;
	21399	 21437	 0.003946	 0.018339	 0.00544	 270.6	 270.6	 270.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21401	 21402	 0.000232	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21401	 21403	 0.000271	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21404	 21434	 0.003179	 0.020314	 0.03776	 207.46	 207.46	 207.46	 0.0	 0.0	 1	 -30.0	 30.0;
	21405	 21408	 0.00064	 0.03648	 0.0	 519.59	 519.59	 519.59	 1.0	 0.0	 1	 -30.0	 30.0;
	21629	 21405	 0.000359	 0.004393	 0.09111	 1124.55	 1124.55	 1124.55	 0.0	 0.0	 1	 -30.0	 30.0;
	21406	 21408	 -0.000129	 -0.007374	 0.0	 494.59	 494.59	 494.59	 1.0	 0.0	 1	 -30.0	 30.0;
	21429	 21406	 0.001166	 0.006042	 0.00732	 253.57	 253.57	 253.57	 0.0	 0.0	 1	 -30.0	 30.0;
	21438	 21406	 0.00095	 0.005348	 0.00477	 207.18	 207.18	 207.18	 0.0	 0.0	 1	 -30.0	 30.0;
	21407	 21408	 0.002457	 0.140136	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21409	 21412	 0.000301	 0.017814	 0.0	 481.36	 481.36	 481.36	 1.0	 0.0	 1	 -30.0	 30.0;
	21458	 21409	 0.000347	 0.004368	 0.12698	 1160.39	 1160.39	 1160.39	 0.0	 0.0	 1	 -30.0	 30.0;
	21409	 21629	 0.000478	 0.005602	 0.09412	 1158.16	 1158.16	 1158.16	 0.0	 0.0	 1	 -30.0	 30.0;
	21410	 21412	 0.000346	 0.020452	 0.0	 456.36	 456.36	 456.36	 1.0	 0.0	 1	 -30.0	 30.0;
	21411	 21412	 0.002835	 0.167758	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21413	 21414	 0.00024	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21413	 21454	 0.00312	 0.016102	 0.00822	 228.8	 228.8	 228.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21415	 21436	 0.002139	 0.01021	 0.01083	 179.77	 179.77	 179.77	 0.0	 0.0	 1	 -30.0	 30.0;
	21415	 21497	 0.002081	 0.012333	 0.02702	 208.86	 208.86	 208.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21416	 21417	 0.00027	 0.001084	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21417	 21729	 0.006353	 0.028586	 0.02453	 237.51	 237.51	 237.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21418	 21504	 0.003851	 0.023882	 0.01064	 220.71	 220.71	 220.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21419	 21475	 0.000481	 0.002359	 0.00096	 291.81	 291.81	 291.81	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 21419	 0.000981	 0.00678	 0.00279	 274.61	 274.61	 274.61	 0.0	 0.0	 1	 -30.0	 30.0;
	21420	 21421	 0.000223	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 21423	 0.000235	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 21424	 0.000276	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21422	 21425	 0.000295	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21424	 21468	 0.001459	 0.00623	 0.00184	 187.88	 187.88	 187.88	 0.0	 0.0	 1	 -30.0	 30.0;
	21426	 21427	 0.000267	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21426	 21428	 0.000238	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21428	 21466	 0.000803	 0.00519	 0.01358	 217.82	 217.82	 217.82	 0.0	 0.0	 1	 -30.0	 30.0;
	21428	 21734	 0.000412	 0.002988	 0.00222	 254.92	 254.92	 254.92	 0.0	 0.0	 1	 -30.0	 30.0;
	21429	 21439	 0.001292	 0.007436	 0.00377	 185.53	 185.53	 185.53	 0.0	 0.0	 1	 -30.0	 30.0;
	21479	 21430	 0.001871	 0.008118	 0.00705	 214.25	 214.25	 214.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21431	 21444	 0.000424	 0.002862	 0.00716	 203.0	 203.0	 203.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21431	 21494	 0.000588	 0.003891	 0.00126	 176.89	 176.89	 176.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21432	 21433	 0.003017	 0.013795	 0.00502	 229.53	 229.53	 229.53	 0.0	 0.0	 1	 -30.0	 30.0;
	21432	 21608	 0.00361	 0.021267	 0.01324	 270.97	 270.97	 270.97	 0.0	 0.0	 1	 -30.0	 30.0;
	21480	 21433	 0.002181	 0.013095	 0.00762	 254.91	 254.91	 254.91	 0.0	 0.0	 1	 -30.0	 30.0;
	21434	 21435	 0.000283	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21451	 21436	 0.00304	 0.010772	 0.01146	 230.3	 230.3	 230.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 21436	 0.001377	 0.008206	 0.002	 206.15	 206.15	 206.15	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 21498	 0.002618	 0.012046	 0.03219	 208.29	 208.29	 208.29	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 23008	 0.001941	 0.012047	 0.05074	 222.92	 222.92	 222.92	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 23010	 0.003306	 0.018017	 0.01828	 204.07	 204.07	 204.07	 0.0	 0.0	 1	 -30.0	 30.0;
	21437	 23012	 0.043211	 0.168992	 0.05679	 192.25	 192.25	 192.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21439	 21440	 0.00027	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21439	 21734	 0.002324	 0.010878	 0.00519	 202.45	 202.45	 202.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21441	 21442	 0.000267	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21441	 21443	 0.000286	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21529	 21442	 0.000825	 0.004958	 0.00133	 218.68	 218.68	 218.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21734	 21442	 0.00067	 0.004239	 0.00129	 256.4	 256.4	 256.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21444	 21445	 0.000221	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21519	 21444	 0.003269	 0.017418	 0.00865	 150.63	 150.63	 150.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21444	 21686	 0.003141	 0.020601	 0.01593	 228.8	 228.8	 228.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21446	 21447	 0.000248	 0.001066	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21517	 21446	 0.00512	 0.027912	 0.00756	 188.37	 188.37	 188.37	 0.0	 0.0	 1	 -30.0	 30.0;
	23009	 21446	 0.004603	 0.029551	 0.02966	 178.03	 178.03	 178.03	 0.0	 0.0	 1	 -30.0	 30.0;
	21656	 21448	 0.00265	 0.011761	 0.00413	 251.94	 251.94	 251.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21448	 21759	 0.000953	 0.006273	 0.01927	 238.46	 238.46	 238.46	 0.0	 0.0	 1	 -30.0	 30.0;
	21449	 21450	 0.000209	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21450	 21656	 0.003239	 0.017817	 0.03803	 256.94	 256.94	 256.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21451	 21459	 0.000873	 0.005045	 0.00428	 244.32	 244.32	 244.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21452	 21453	 0.000227	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21452	 21454	 0.000212	 0.001158	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21454	 21459	 0.00067	 0.004706	 0.00311	 222.54	 222.54	 222.54	 0.0	 0.0	 1	 -30.0	 30.0;
	21455	 21456	 0.000275	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21455	 21457	 0.00024	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 21494	 0.001289	 0.009962	 0.01046	 214.37	 214.37	 214.37	 0.0	 0.0	 1	 -30.0	 30.0;
	21457	 21532	 0.001658	 0.006937	 0.00537	 227.02	 227.02	 227.02	 0.0	 0.0	 1	 -30.0	 30.0;
	21458	 21461	 0.001374	 0.072333	 0.0	 580.18	 580.18	 580.18	 1.0	 0.0	 1	 -30.0	 30.0;
	21459	 21461	 -0.000772	 -0.040644	 0.0	 455.18	 455.18	 455.18	 1.0	 0.0	 1	 -30.0	 30.0;
	21460	 21461	 0.002985	 0.157144	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21465	 21462	 0.003131	 0.019196	 0.01205	 171.51	 171.51	 171.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21463	 21464	 0.000288	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21463	 21465	 0.000224	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21466	 21467	 0.000202	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21758	 21468	 0.001605	 0.00744	 0.0052	 219.26	 219.26	 219.26	 0.0	 0.0	 1	 -30.0	 30.0;
	21471	 21469	 0.003179	 0.00979	 0.00713	 223.49	 223.49	 223.49	 0.0	 0.0	 1	 -30.0	 30.0;
	21475	 21469	 0.002104	 0.010287	 0.00428	 245.97	 245.97	 245.97	 0.0	 0.0	 1	 -30.0	 30.0;
	21499	 21470	 0.002247	 0.010136	 0.00718	 241.48	 241.48	 241.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21520	 21471	 0.001079	 0.007341	 0.04972	 243.4	 243.4	 243.4	 0.0	 0.0	 1	 -30.0	 30.0;
	21471	 21743	 0.009002	 0.03654	 0.02425	 259.75	 259.75	 259.75	 0.0	 0.0	 1	 -30.0	 30.0;
	21472	 21473	 0.000216	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21472	 21475	 0.002705	 0.016915	 0.01953	 265.17	 265.17	 265.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21475	 21474	 0.000263	 0.020183	 0.0	 577.25	 577.25	 577.25	 1.0	 0.0	 1	 -30.0	 30.0;
	21475	 21474	 0.000263	 0.020183	 0.0	 577.25	 577.25	 577.25	 1.0	 0.0	 1	 -30.0	 30.0;
	21474	 21626	 0.001074	 0.012148	 0.26294	 1314.79	 1314.79	 1314.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21742	 21474	 0.000636	 0.007676	 0.12992	 1222.23	 1222.23	 1222.23	 0.0	 0.0	 1	 -30.0	 30.0;
	21476	 21501	 0.001554	 0.008122	 0.00441	 187.05	 187.05	 187.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21476	 21504	 0.00207	 0.010698	 0.0105	 212.84	 212.84	 212.84	 0.0	 0.0	 1	 -30.0	 30.0;
	21477	 21478	 0.000277	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21477	 21504	 0.001471	 0.010606	 0.00315	 228.48	 228.48	 228.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21650	 21480	 0.000148	 0.000723	 0.00217	 279.36	 279.36	 279.36	 0.0	 0.0	 1	 -30.0	 30.0;
	21482	 21483	 0.000268	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21482	 21716	 0.00344	 0.021045	 0.01019	 225.68	 225.68	 225.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21721	 21484	 0.001873	 0.008525	 0.00796	 230.55	 230.55	 230.55	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 21488	 -0.000737	 -0.024087	 0.0	 103.89	 103.89	 103.89	 1.0	 0.0	 1	 -30.0	 30.0;
	21485	 21489	 0.000295	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 21516	 0.001427	 0.00705	 0.01506	 229.33	 229.33	 229.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 21529	 0.00076	 0.004415	 0.00155	 260.75	 260.75	 260.75	 0.0	 0.0	 1	 -30.0	 30.0;
	21485	 21551	 0.001482	 0.011428	 0.04543	 208.34	 208.34	 208.34	 0.0	 0.0	 1	 -30.0	 30.0;
	21486	 21488	 0.009954	 0.325234	 0.0	 51.94	 51.94	 51.94	 1.0	 0.0	 1	 -30.0	 30.0;
	21487	 21488	 0.009954	 0.325234	 0.0	 51.94	 51.94	 51.94	 1.0	 0.0	 1	 -30.0	 30.0;
	21490	 21491	 0.000251	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 21491	 0.000688	 0.003654	 0.01982	 234.85	 234.85	 234.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21492	 21546	 0.003353	 0.019078	 0.02779	 226.11	 226.11	 226.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21492	 21721	 0.001323	 0.007741	 0.00528	 232.3	 232.3	 232.3	 0.0	 0.0	 1	 -30.0	 30.0;
	21495	 21493	 0.00056	 0.003753	 0.0032	 211.02	 211.02	 211.02	 0.0	 0.0	 1	 -30.0	 30.0;
	21493	 21497	 0.000807	 0.005492	 0.00294	 248.47	 248.47	 248.47	 0.0	 0.0	 1	 -30.0	 30.0;
	21533	 21495	 0.000775	 0.003797	 0.00157	 199.63	 199.63	 199.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 21496	 0.000304	 0.019085	 0.0	 571.48	 571.48	 571.48	 1.0	 0.0	 1	 -30.0	 30.0;
	21496	 21527	 0.000223	 0.002629	 0.06003	 1261.31	 1261.31	 1261.31	 0.0	 0.0	 1	 -30.0	 30.0;
	21496	 21685	 0.000449	 0.005506	 0.1226	 1073.89	 1073.89	 1073.89	 0.0	 0.0	 1	 -30.0	 30.0;
	21497	 21533	 0.000777	 0.004291	 0.01265	 264.14	 264.14	 264.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21500	 21501	 0.00025	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21500	 21502	 0.000219	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21559	 21501	 0.010411	 0.037374	 0.04028	 243.58	 243.58	 243.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21562	 21501	 0.001915	 0.009369	 0.02256	 185.85	 185.85	 185.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21503	 21504	 0.000289	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21503	 21505	 0.000257	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21506	 21509	 0.000401	 0.011719	 0.0	 103.16	 103.16	 103.16	 1.0	 0.0	 1	 -30.0	 30.0;
	21513	 21506	 0.000973	 0.005452	 0.00215	 167.79	 167.79	 167.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21561	 21506	 0.002901	 0.019128	 0.01073	 223.76	 223.76	 223.76	 0.0	 0.0	 1	 -30.0	 30.0;
	21562	 21506	 0.001895	 0.012951	 0.00969	 193.17	 193.17	 193.17	 0.0	 0.0	 1	 -30.0	 30.0;
	21506	 21582	 0.005445	 0.020365	 0.10489	 245.53	 245.53	 245.53	 0.0	 0.0	 1	 -30.0	 30.0;
	21507	 21509	 0.007081	 0.207006	 0.0	 51.58	 51.58	 51.58	 1.0	 0.0	 1	 -30.0	 30.0;
	21508	 21509	 0.007081	 0.207006	 0.0	 51.58	 51.58	 51.58	 1.0	 0.0	 1	 -30.0	 30.0;
	21510	 21511	 0.000226	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21559	 21510	 0.002065	 0.012353	 0.02541	 265.05	 265.05	 265.05	 0.0	 0.0	 1	 -30.0	 30.0;
	21510	 21616	 0.003628	 0.015817	 0.05253	 279.03	 279.03	 279.03	 0.0	 0.0	 1	 -30.0	 30.0;
	21512	 21513	 0.000244	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21550	 21513	 0.001789	 0.010241	 0.00936	 223.03	 223.03	 223.03	 0.0	 0.0	 1	 -30.0	 30.0;
	21514	 21515	 0.000234	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21514	 21516	 0.000299	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21516	 21562	 0.001083	 0.005467	 0.00628	 183.49	 183.49	 183.49	 0.0	 0.0	 1	 -30.0	 30.0;
	21519	 21517	 0.002188	 0.012299	 0.01036	 216.58	 216.58	 216.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21517	 21532	 0.000461	 0.002198	 0.00179	 250.93	 250.93	 250.93	 0.0	 0.0	 1	 -30.0	 30.0;
	21518	 21519	 0.000267	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21521	 21522	 0.000269	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21523	 21524	 0.000291	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 21523	 0.000668	 0.004257	 0.00074	 204.25	 204.25	 204.25	 0.0	 0.0	 1	 -30.0	 30.0;
	21523	 21533	 0.001005	 0.006433	 0.01158	 185.01	 185.01	 185.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 21526	 0.000231	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 21630	 0.002039	 0.011778	 0.00774	 186.48	 186.48	 186.48	 0.0	 0.0	 1	 -30.0	 30.0;
	21525	 21686	 0.002045	 0.013902	 0.0197	 225.46	 225.46	 225.46	 0.0	 0.0	 1	 -30.0	 30.0;
	21528	 21527	 0.000621	 0.029543	 0.0	 508.15	 508.15	 508.15	 1.0	 0.0	 1	 -30.0	 30.0;
	21527	 21700	 0.001368	 0.015827	 0.36248	 1224.22	 1224.22	 1224.22	 0.0	 0.0	 1	 -30.0	 30.0;
	21527	 23432	 0.002045	 0.02562	 0.69406	 1243.7	 1243.7	 1243.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21528	 21542	 0.002096	 0.01394	 0.0654	 236.96	 236.96	 236.96	 0.0	 0.0	 1	 -30.0	 30.0;
	21528	 21544	 0.000983	 0.005686	 0.00262	 251.51	 251.51	 251.51	 0.0	 0.0	 1	 -30.0	 30.0;
	21528	 21547	 0.004629	 0.02777	 0.01729	 212.93	 212.93	 212.93	 0.0	 0.0	 1	 -30.0	 30.0;
	21529	 21734	 0.000976	 0.005038	 0.00327	 268.5	 268.5	 268.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21686	 21530	 0.002615	 0.012942	 0.00644	 233.72	 233.72	 233.72	 0.0	 0.0	 1	 -30.0	 30.0;
	23009	 21530	 0.004949	 0.030795	 0.02199	 175.45	 175.45	 175.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21532	 21531	 0.00062	 0.032729	 0.0	 480.33	 480.33	 480.33	 1.1	 0.0	 1	 -30.0	 30.0;
	21685	 21531	 0.000554	 0.006365	 0.10067	 1183.67	 1183.67	 1183.67	 0.0	 0.0	 1	 -30.0	 30.0;
	21533	 21563	 0.001888	 0.009442	 0.01095	 214.27	 214.27	 214.27	 0.0	 0.0	 1	 -30.0	 30.0;
	21534	 21535	 0.000201	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21535	 21579	 0.002191	 0.014478	 0.01328	 187.45	 187.45	 187.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21630	 21535	 0.001387	 0.006809	 0.00282	 241.64	 241.64	 241.64	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 21537	 0.000266	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21536	 21538	 0.000254	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21555	 21538	 0.003811	 0.022092	 0.01484	 239.78	 239.78	 239.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21538	 21571	 0.001092	 0.005174	 0.0071	 258.45	 258.45	 258.45	 0.0	 0.0	 1	 -30.0	 30.0;
	21675	 21538	 0.003113	 0.012121	 0.00694	 204.21	 204.21	 204.21	 0.0	 0.0	 1	 -30.0	 30.0;
	21675	 21539	 0.00463	 0.023176	 0.01584	 203.26	 203.26	 203.26	 0.0	 0.0	 1	 -30.0	 30.0;
	21540	 21541	 0.00026	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21542	 21540	 0.000493	 0.003213	 0.00368	 209.85	 209.85	 209.85	 0.0	 0.0	 1	 -30.0	 30.0;
	21551	 21540	 0.000821	 0.005449	 0.00178	 171.94	 171.94	 171.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21542	 21543	 0.000268	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21544	 21545	 0.000248	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21544	 21546	 0.006153	 0.029625	 0.00867	 214.18	 214.18	 214.18	 0.0	 0.0	 1	 -30.0	 30.0;
	21563	 21546	 0.001161	 0.007294	 0.00261	 207.39	 207.39	 207.39	 0.0	 0.0	 1	 -30.0	 30.0;
	21551	 21547	 0.000837	 0.004947	 0.00262	 191.12	 191.12	 191.12	 0.0	 0.0	 1	 -30.0	 30.0;
	21548	 21549	 0.000203	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21548	 21550	 0.000254	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21550	 23076	 0.008427	 0.049312	 0.16526	 250.1	 250.1	 250.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21551	 21552	 0.000231	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21553	 21554	 0.000232	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21553	 21555	 0.000239	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21553	 21556	 0.000279	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21564	 21557	 0.005326	 0.021813	 0.02238	 242.14	 242.14	 242.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21622	 21557	 0.002256	 0.011712	 0.0055	 262.71	 262.71	 262.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21558	 21569	 0.004905	 0.029353	 0.04266	 209.54	 209.54	 209.54	 0.0	 0.0	 1	 -30.0	 30.0;
	21560	 21574	 0.001465	 0.009352	 0.00426	 193.63	 193.63	 193.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21743	 21560	 0.001977	 0.010477	 0.00764	 226.32	 226.32	 226.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21568	 21561	 0.0025	 0.01235	 0.00574	 182.27	 182.27	 182.27	 0.0	 0.0	 1	 -30.0	 30.0;
	21568	 21563	 0.00104	 0.005166	 0.00189	 207.06	 207.06	 207.06	 0.0	 0.0	 1	 -30.0	 30.0;
	21564	 23022	 0.003216	 0.015658	 0.01212	 220.8	 220.8	 220.8	 0.0	 0.0	 1	 -30.0	 30.0;
	21565	 21566	 0.000239	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21573	 21565	 0.002276	 0.015977	 0.01252	 242.37	 242.37	 242.37	 0.0	 0.0	 1	 -30.0	 30.0;
	21565	 21622	 0.002845	 0.019325	 0.01647	 248.63	 248.63	 248.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21567	 21568	 0.000254	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21571	 21572	 0.000281	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21622	 21571	 0.002666	 0.011278	 0.00582	 282.68	 282.68	 282.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21580	 21573	 0.000623	 0.004004	 0.00327	 207.71	 207.71	 207.71	 0.0	 0.0	 1	 -30.0	 30.0;
	21574	 21582	 0.007359	 0.039812	 0.05731	 293.79	 293.79	 293.79	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 21574	 0.000589	 0.004592	 0.00559	 297.47	 297.47	 297.47	 0.0	 0.0	 1	 -30.0	 30.0;
	21575	 21576	 0.000282	 0.001158	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21576	 21640	 0.004914	 0.023486	 0.01042	 234.77	 234.77	 234.77	 0.0	 0.0	 1	 -30.0	 30.0;
	23009	 21576	 0.002704	 0.016717	 0.00443	 230.94	 230.94	 230.94	 0.0	 0.0	 1	 -30.0	 30.0;
	21577	 21578	 0.00027	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21579	 21577	 0.003842	 0.02189	 0.01393	 208.19	 208.19	 208.19	 0.0	 0.0	 1	 -30.0	 30.0;
	21577	 21582	 0.00462	 0.030335	 0.08746	 240.11	 240.11	 240.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21580	 21601	 0.012973	 0.046268	 0.04145	 227.06	 227.06	 227.06	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 21585	 0.006156	 0.039554	 0.03376	 228.33	 228.33	 228.33	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 23061	 0.011169	 0.060718	 0.03127	 192.54	 192.54	 192.54	 0.0	 0.0	 1	 -30.0	 30.0;
	21581	 23103	 0.029212	 0.133344	 0.0436	 177.11	 177.11	 177.11	 0.0	 0.0	 1	 -30.0	 30.0;
	21582	 23076	 0.015164	 0.08876	 0.03653	 214.07	 214.07	 214.07	 0.0	 0.0	 1	 -30.0	 30.0;
	21583	 21745	 0.005018	 0.033984	 0.01068	 222.86	 222.86	 222.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21583	 23128	 0.034919	 0.193789	 0.0805	 181.0	 181.0	 181.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21745	 21584	 0.001455	 0.00945	 0.00367	 254.31	 254.31	 254.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23036	 21584	 0.004108	 0.024544	 0.03407	 217.06	 217.06	 217.06	 0.0	 0.0	 1	 -30.0	 30.0;
	21584	 23081	 0.04856	 0.326761	 0.09446	 184.32	 184.32	 184.32	 0.0	 0.0	 1	 -30.0	 30.0;
	21701	 21585	 0.003565	 0.020055	 0.00675	 243.9	 243.9	 243.9	 0.0	 0.0	 1	 -30.0	 30.0;
	21586	 21589	 0.00017	 0.005028	 0.0	 216.59	 216.59	 216.59	 1.0	 0.0	 1	 -30.0	 30.0;
	21616	 21586	 0.003413	 0.018881	 0.00371	 231.47	 231.47	 231.47	 0.0	 0.0	 1	 -30.0	 30.0;
	21586	 23021	 0.005232	 0.031192	 0.03777	 208.65	 208.65	 208.65	 0.0	 0.0	 1	 -30.0	 30.0;
	21587	 21589	 0.003377	 0.09968	 0.0	 108.3	 108.3	 108.3	 1.0	 0.0	 1	 -30.0	 30.0;
	21588	 21589	 0.003377	 0.09968	 0.0	 108.3	 108.3	 108.3	 1.0	 0.0	 1	 -30.0	 30.0;
	21590	 21591	 0.000265	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 21592	 0.002043	 0.011224	 0.00586	 146.24	 146.24	 146.24	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 21601	 0.004148	 0.025716	 0.04914	 253.02	 253.02	 253.02	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 23022	 0.003157	 0.015627	 0.01306	 240.68	 240.68	 240.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 23058	 0.009359	 0.053137	 0.01824	 180.41	 180.41	 180.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21591	 23074	 0.010785	 0.046057	 0.0393	 190.78	 190.78	 190.78	 0.0	 0.0	 1	 -30.0	 30.0;
	21592	 23031	 0.003026	 0.019376	 0.01817	 206.41	 206.41	 206.41	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 21593	 5.5e-05	 0.004894	 0.0	 1892.25	 1892.25	 1892.25	 1.0	 0.0	 1	 -30.0	 30.0;
	21593	 21596	 9.1e-05	 0.007465	 0.0	 1484.81	 1484.81	 1484.81	 1.025	 0.0	 1	 -30.0	 30.0;
	21593	 21597	 0.000102	 0.006792	 0.0	 1483.46	 1483.46	 1483.46	 1.025	 0.0	 1	 -30.0	 30.0;
	21593	 21598	 8.7e-05	 0.007107	 0.0	 1483.42	 1483.42	 1483.42	 1.025	 0.0	 1	 -30.0	 30.0;
	21593	 21599	 0.000115	 0.009135	 0.0	 1482.21	 1482.21	 1482.21	 1.03125	 0.0	 1	 -30.0	 30.0;
	21593	 21641	 3.4e-05	 0.000964	 0.42953	 4059.75	 4059.75	 4059.75	 0.0	 0.0	 1	 -30.0	 30.0;
	21727	 21593	 0.000124	 0.003709	 2.10732	 4134.26	 4134.26	 4134.26	 0.0	 0.0	 1	 -30.0	 30.0;
	23431	 21593	 8.1e-05	 0.002295	 1.0214	 4146.1	 4146.1	 4146.1	 0.0	 0.0	 1	 -30.0	 30.0;
	21595	 21594	 0.000374	 0.02687	 0.0	 447.91	 447.91	 447.91	 1.0	 0.0	 1	 -30.0	 30.0;
	21607	 21594	 0.000215	 0.002455	 0.0597	 1097.7	 1097.7	 1097.7	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 21626	 3e-05	 0.000387	 0.00637	 858.23	 858.23	 858.23	 0.0	 0.0	 1	 -30.0	 30.0;
	21594	 21660	 0.000863	 0.009774	 0.21276	 1215.56	 1215.56	 1215.56	 0.0	 0.0	 1	 -30.0	 30.0;
	21742	 21594	 0.000503	 0.006761	 0.2171	 1322.63	 1322.63	 1322.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21595	 21622	 0.000354	 0.002008	 0.00123	 284.01	 284.01	 284.01	 0.0	 0.0	 1	 -30.0	 30.0;
	21601	 21600	 0.000581	 0.032216	 0.0	 438.14	 438.14	 438.14	 1.0125	 0.0	 1	 -30.0	 30.0;
	21600	 21602	 0.000359	 0.028266	 0.0	 346.49	 346.49	 346.49	 0.9875	 0.0	 1	 -30.0	 30.0;
	21600	 21603	 0.000763	 0.044231	 0.0	 345.53	 345.53	 345.53	 0.9875	 0.0	 1	 -30.0	 30.0;
	21600	 21604	 0.000459	 0.030309	 0.0	 345.15	 345.15	 345.15	 0.9875	 0.0	 1	 -30.0	 30.0;
	21600	 21605	 0.000372	 0.022899	 0.0	 344.51	 344.51	 344.51	 0.9875	 0.0	 1	 -30.0	 30.0;
	21600	 21606	 0.000214	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21626	 21606	 0.000246	 0.003197	 0.12373	 1052.99	 1052.99	 1052.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21606	 21678	 0.000192	 0.002011	 0.0291	 1097.63	 1097.63	 1097.63	 0.0	 0.0	 1	 -30.0	 30.0;
	21607	 21610	 0.001092	 0.064255	 0.0	 481.94	 481.94	 481.94	 1.0	 0.0	 1	 -30.0	 30.0;
	21607	 21611	 0.000297	 0.014324	 0.0	 562.19	 562.19	 562.19	 1.04375	 0.0	 1	 -30.0	 30.0;
	21607	 21612	 0.000487	 0.034028	 0.0	 561.56	 561.56	 561.56	 1.0625	 0.0	 1	 -30.0	 30.0;
	21607	 21613	 0.000334	 0.024093	 0.0	 556.35	 556.35	 556.35	 1.05625	 0.0	 1	 -30.0	 30.0;
	21607	 21614	 0.000331	 0.020364	 0.0	 554.66	 554.66	 554.66	 1.0	 0.0	 1	 -30.0	 30.0;
	21607	 21642	 0.000155	 0.001794	 0.04874	 1150.58	 1150.58	 1150.58	 0.0	 0.0	 1	 -30.0	 30.0;
	21649	 21607	 0.000113	 0.001197	 0.02129	 1059.99	 1059.99	 1059.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21608	 21610	 -0.000597	 -0.035096	 0.0	 431.94	 431.94	 431.94	 1.0	 0.0	 1	 -30.0	 30.0;
	21609	 21610	 0.002498	 0.146946	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21616	 21615	 0.000571	 0.028944	 0.0	 469.5	 469.5	 469.5	 1.0	 0.0	 1	 -30.0	 30.0;
	21615	 21617	 0.000274	 0.016246	 0.0	 594.43	 594.43	 594.43	 1.03125	 0.0	 1	 -30.0	 30.0;
	21615	 21619	 0.000517	 0.038568	 0.0	 312.35	 312.35	 312.35	 1.025	 0.0	 1	 -30.0	 30.0;
	21615	 21620	 0.000939	 0.058743	 0.0	 293.58	 293.58	 293.58	 1.025	 0.0	 1	 -30.0	 30.0;
	21615	 21660	 0.00039	 0.003559	 0.07066	 1137.18	 1137.18	 1137.18	 0.0	 0.0	 1	 -30.0	 30.0;
	21615	 21741	 0.000983	 0.012066	 0.29372	 1292.69	 1292.69	 1292.69	 0.0	 0.0	 1	 -30.0	 30.0;
	21742	 21615	 0.000276	 0.003417	 0.0868	 1093.86	 1093.86	 1093.86	 0.0	 0.0	 1	 -30.0	 30.0;
	21616	 21618	 0.005201	 0.114223	 0.0	 58.41	 58.41	 58.41	 1.03125	 0.0	 1	 -30.0	 30.0;
	21622	 21621	 0.000341	 0.023983	 0.0	 640.0	 640.0	 640.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	21621	 21623	 0.000414	 0.029678	 0.0	 529.78	 529.78	 529.78	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 21624	 0.000435	 0.023363	 0.0	 529.37	 529.37	 529.37	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 21625	 0.000288	 0.020163	 0.0	 528.87	 528.87	 528.87	 1.0	 0.0	 1	 -30.0	 30.0;
	21621	 21626	 0.000231	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21628	 21627	 0.000317	 0.019812	 0.0	 555.85	 555.85	 555.85	 1.03125	 0.0	 1	 -30.0	 30.0;
	21627	 21629	 0.000284	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21721	 21628	 0.00114	 0.006575	 0.00203	 244.14	 244.14	 244.14	 0.0	 0.0	 1	 -30.0	 30.0;
	21629	 21741	 0.000196	 0.00241	 0.0518	 1182.5	 1182.5	 1182.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21630	 21631	 0.002265	 0.074388	 0.0	 95.85	 95.85	 95.85	 1.0	 0.0	 1	 -30.0	 30.0;
	21630	 21686	 0.002922	 0.01558	 0.00707	 212.27	 212.27	 212.27	 0.0	 0.0	 1	 -30.0	 30.0;
	21632	 21635	 0.000758	 0.036316	 0.0	 590.27	 590.27	 590.27	 1.0	 0.0	 1	 -30.0	 30.0;
	21632	 21636	 0.000736	 0.048252	 0.0	 298.27	 298.27	 298.27	 1.0375	 0.0	 1	 -30.0	 30.0;
	21632	 21638	 0.00023	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21633	 21635	 -0.000108	 -0.005162	 0.0	 465.27	 465.27	 465.27	 1.0	 0.0	 1	 -30.0	 30.0;
	21633	 21637	 0.006607	 0.176634	 0.0	 62.03	 62.03	 62.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	21634	 21635	 0.003953	 0.189409	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21639	 21640	 0.000258	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21745	 21640	 0.000209	 0.0014	 0.00043	 172.99	 172.99	 172.99	 0.0	 0.0	 1	 -30.0	 30.0;
	21642	 21641	 7e-05	 0.005426	 0.0	 1677.11	 1677.11	 1677.11	 1.0	 0.0	 1	 -30.0	 30.0;
	21642	 21641	 7e-05	 0.005426	 0.0	 1677.11	 1677.11	 1677.11	 1.0	 0.0	 1	 -30.0	 30.0;
	21642	 21641	 7e-05	 0.005426	 0.0	 1677.11	 1677.11	 1677.11	 1.0	 0.0	 1	 -30.0	 30.0;
	21641	 21646	 0.000127	 0.009096	 0.0	 1788.08	 1788.08	 1788.08	 1.0	 0.0	 1	 -30.0	 30.0;
	21641	 21647	 0.000103	 0.00953	 0.0	 1785.0	 1785.0	 1785.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21641	 21648	 7.4e-05	 0.005688	 0.0	 1771.43	 1771.43	 1771.43	 1.0	 0.0	 1	 -30.0	 30.0;
	21642	 21645	 0.000334	 0.027921	 0.0	 620.82	 620.82	 620.82	 1.0	 0.0	 1	 -30.0	 30.0;
	21642	 21649	 6.1e-05	 0.000863	 0.0244	 1320.65	 1320.65	 1320.65	 0.0	 0.0	 1	 -30.0	 30.0;
	21642	 21698	 0.000509	 0.00608	 0.13833	 1280.74	 1280.74	 1280.74	 0.0	 0.0	 1	 -30.0	 30.0;
	21643	 21645	 -5e-06	 -0.0004	 0.0	 470.82	 470.82	 470.82	 1.0	 0.0	 1	 -30.0	 30.0;
	21644	 21645	 0.002039	 0.170609	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21650	 21649	 0.000486	 0.029821	 0.0	 442.79	 442.79	 442.79	 1.0125	 0.0	 1	 -30.0	 30.0;
	21649	 21651	 0.000187	 0.012228	 0.0	 538.16	 538.16	 538.16	 1.0125	 0.0	 1	 -30.0	 30.0;
	21649	 21652	 0.000444	 0.021772	 0.0	 536.6	 536.6	 536.6	 1.01875	 0.0	 1	 -30.0	 30.0;
	21649	 21653	 0.000333	 0.023784	 0.0	 536.33	 536.33	 536.33	 1.01875	 0.0	 1	 -30.0	 30.0;
	21649	 21671	 0.001	 0.012146	 0.39803	 1319.39	 1319.39	 1319.39	 0.0	 0.0	 1	 -30.0	 30.0;
	21656	 21655	 0.000492	 0.030677	 0.0	 365.68	 365.68	 365.68	 1.0	 0.0	 1	 -30.0	 30.0;
	21655	 21657	 0.0002	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21655	 21658	 0.000218	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21655	 21659	 0.000236	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21657	 21682	 0.000164	 0.002057	 0.06688	 1188.73	 1188.73	 1188.73	 0.0	 0.0	 1	 -30.0	 30.0;
	21661	 21660	 0.000355	 0.020897	 0.0	 457.04	 457.04	 457.04	 1.0125	 0.0	 1	 -30.0	 30.0;
	21660	 21662	 0.000562	 0.038302	 0.0	 417.93	 417.93	 417.93	 1.0	 0.0	 1	 -30.0	 30.0;
	21660	 21663	 0.000411	 0.020532	 0.0	 416.6	 416.6	 416.6	 1.0	 0.0	 1	 -30.0	 30.0;
	21660	 21700	 0.000505	 0.005925	 0.08287	 1106.04	 1106.04	 1106.04	 0.0	 0.0	 1	 -30.0	 30.0;
	21664	 21667	 0.000404	 0.028971	 0.0	 581.89	 581.89	 581.89	 1.0	 0.0	 1	 -30.0	 30.0;
	21664	 21668	 0.000291	 0.020305	 0.0	 400.88	 400.88	 400.88	 0.98125	 0.0	 1	 -30.0	 30.0;
	21664	 21669	 0.000389	 0.032261	 0.0	 400.01	 400.01	 400.01	 0.9875	 0.0	 1	 -30.0	 30.0;
	21664	 21670	 0.000771	 0.039424	 0.0	 397.28	 397.28	 397.28	 1.0	 0.0	 1	 -30.0	 30.0;
	21664	 21671	 0.000281	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21664	 21672	 0.000292	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21665	 21667	 -0.000122	 -0.008775	 0.0	 556.89	 556.89	 556.89	 1.0	 0.0	 1	 -30.0	 30.0;
	21715	 21665	 0.000605	 0.003831	 0.00174	 229.68	 229.68	 229.68	 0.0	 0.0	 1	 -30.0	 30.0;
	21666	 21667	 0.001458	 0.104502	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21673	 21674	 0.00026	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21677	 21676	 0.000406	 0.030647	 0.0	 408.19	 408.19	 408.19	 1.0	 0.0	 1	 -30.0	 30.0;
	21676	 21678	 0.000281	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21678	 21682	 0.000148	 0.00191	 0.0484	 1156.28	 1156.28	 1156.28	 0.0	 0.0	 1	 -30.0	 30.0;
	21680	 21679	 0.000483	 0.028498	 0.0	 400.13	 400.13	 400.13	 1.0	 0.0	 1	 -30.0	 30.0;
	21679	 21681	 0.000453	 0.028311	 0.0	 486.02	 486.02	 486.02	 1.01875	 0.0	 1	 -30.0	 30.0;
	21679	 21682	 0.000221	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21679	 21683	 0.000251	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21692	 21680	 0.000194	 0.001229	 0.00065	 250.6	 250.6	 250.6	 0.0	 0.0	 1	 -30.0	 30.0;
	21684	 21688	 0.000223	 0.019108	 0.0	 1635.13	 1635.13	 1635.13	 1.0	 0.0	 1	 -30.0	 30.0;
	21684	 21689	 9.5e-05	 0.00831	 0.0	 1493.66	 1493.66	 1493.66	 0.99375	 0.0	 1	 -30.0	 30.0;
	21684	 21690	 0.00012	 0.009278	 0.0	 1493.52	 1493.52	 1493.52	 0.99375	 0.0	 1	 -30.0	 30.0;
	21684	 21691	 0.000134	 0.010787	 0.0	 1492.74	 1492.74	 1492.74	 0.99375	 0.0	 1	 -30.0	 30.0;
	23374	 21684	 0.000106	 0.00304	 1.43694	 3868.5	 3868.5	 3868.5	 0.0	 0.0	 1	 -30.0	 30.0;
	21686	 21685	 0.000561	 0.037607	 0.0	 477.5	 477.5	 477.5	 1.0375	 0.0	 1	 -30.0	 30.0;
	21685	 21688	 -0.000112	 -0.009612	 0.0	 1642.59	 1642.59	 1642.59	 1.0	 0.0	 1	 -30.0	 30.0;
	21685	 21751	 0.000802	 0.009161	 0.28208	 1079.73	 1079.73	 1079.73	 0.0	 0.0	 1	 -30.0	 30.0;
	21687	 21688	 0.000663	 0.056828	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21692	 21693	 0.002	 0.054584	 0.0	 133.25	 133.25	 133.25	 1.0	 0.0	 1	 -30.0	 30.0;
	21694	 21695	 0.000298	 0.001187	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21694	 21696	 0.000283	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21694	 21697	 0.000275	 0.001045	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21699	 21698	 0.000613	 0.040523	 0.0	 409.84	 409.84	 409.84	 1.0	 0.0	 1	 -30.0	 30.0;
	21722	 21698	 0.000415	 0.005202	 0.12853	 1201.52	 1201.52	 1201.52	 0.0	 0.0	 1	 -30.0	 30.0;
	21701	 21700	 0.000408	 0.02687	 0.0	 452.41	 452.41	 452.41	 1.0125	 0.0	 1	 -30.0	 30.0;
	21700	 21702	 0.000428	 0.023234	 0.0	 448.66	 448.66	 448.66	 1.0	 0.0	 1	 -30.0	 30.0;
	21700	 21703	 0.000393	 0.025453	 0.0	 447.11	 447.11	 447.11	 1.0	 0.0	 1	 -30.0	 30.0;
	21700	 21704	 0.000446	 0.022854	 0.0	 447.01	 447.01	 447.01	 1.0	 0.0	 1	 -30.0	 30.0;
	21701	 23024	 0.004802	 0.024857	 0.01955	 246.23	 246.23	 246.23	 0.0	 0.0	 1	 -30.0	 30.0;
	21705	 21708	 0.000309	 0.010307	 0.0	 193.34	 193.34	 193.34	 1.0	 0.0	 1	 -30.0	 30.0;
	21705	 21711	 0.0001	 0.001267	 0.0	 262.58	 262.58	 262.58	 0.99375	 0.0	 1	 -30.0	 30.0;
	21705	 21714	 0.0001	 0.0001	 0.0	 103.0	 103.0	 103.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21705	 21715	 0.00025	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21706	 21708	 0.003716	 0.123881	 0.0	 96.67	 96.67	 96.67	 1.0	 0.0	 1	 -30.0	 30.0;
	21707	 21708	 0.003716	 0.123881	 0.0	 96.67	 96.67	 96.67	 1.0	 0.0	 1	 -30.0	 30.0;
	21709	 21711	 0.003143	 0.091171	 0.0	 131.29	 131.29	 131.29	 1.0	 0.0	 1	 -30.0	 30.0;
	21710	 21711	 0.003143	 0.091171	 0.0	 131.29	 131.29	 131.29	 1.0	 0.0	 1	 -30.0	 30.0;
	21712	 21714	 0.006425	 0.192978	 0.0	 51.5	 51.5	 51.5	 1.0	 0.0	 1	 -30.0	 30.0;
	21713	 21714	 0.006425	 0.192978	 0.0	 51.5	 51.5	 51.5	 1.0	 0.0	 1	 -30.0	 30.0;
	21717	 21718	 0.004048	 0.113636	 0.0	 103.78	 103.78	 103.78	 1.0125	 0.0	 1	 -30.0	 30.0;
	21717	 21719	 0.003972	 0.127065	 0.0	 66.02	 66.02	 66.02	 0.99375	 0.0	 1	 -30.0	 30.0;
	21720	 21721	 0.000279	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21722	 21725	 0.000533	 0.020629	 0.0	 462.11	 462.11	 462.11	 1.0	 0.0	 1	 -30.0	 30.0;
	21722	 21726	 0.000396	 0.018119	 0.0	 573.58	 573.58	 573.58	 1.04375	 0.0	 1	 -30.0	 30.0;
	21722	 21753	 0.000438	 0.00529	 0.17342	 1282.84	 1282.84	 1282.84	 0.0	 0.0	 1	 -30.0	 30.0;
	21723	 21725	 0.000399	 0.015436	 0.0	 437.11	 437.11	 437.11	 1.0	 0.0	 1	 -30.0	 30.0;
	21724	 21725	 0.00501	 0.193949	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21728	 21727	 0.000105	 0.009291	 0.0	 1617.48	 1617.48	 1617.48	 1.025	 0.0	 1	 -30.0	 30.0;
	21728	 21727	 0.000105	 0.009291	 0.0	 1617.48	 1617.48	 1617.48	 1.025	 0.0	 1	 -30.0	 30.0;
	21728	 21727	 0.000105	 0.009291	 0.0	 1617.48	 1617.48	 1617.48	 1.025	 0.0	 1	 -30.0	 30.0;
	21727	 21730	 8.2e-05	 0.007139	 0.0	 1531.26	 1531.26	 1531.26	 1.0	 0.0	 1	 -30.0	 30.0;
	21727	 21731	 0.00014	 0.013735	 0.0	 1529.53	 1529.53	 1529.53	 1.0	 0.0	 1	 -30.0	 30.0;
	21727	 21732	 8.8e-05	 0.006888	 0.0	 1525.86	 1525.86	 1525.86	 1.0	 0.0	 1	 -30.0	 30.0;
	21729	 21728	 0.000439	 0.024925	 0.0	 606.89	 606.89	 606.89	 1.01875	 0.0	 1	 -30.0	 30.0;
	21729	 21728	 0.000439	 0.024925	 0.0	 606.89	 606.89	 606.89	 1.01875	 0.0	 1	 -30.0	 30.0;
	21729	 21728	 0.000439	 0.024925	 0.0	 606.89	 606.89	 606.89	 1.01875	 0.0	 1	 -30.0	 30.0;
	21734	 21733	 0.000342	 0.019254	 0.0	 563.53	 563.53	 563.53	 1.1	 0.0	 1	 -30.0	 30.0;
	21733	 21735	 0.000556	 0.03077	 0.0	 369.73	 369.73	 369.73	 1.025	 0.0	 1	 -30.0	 30.0;
	21733	 21736	 0.000285	 0.015675	 0.0	 368.58	 368.58	 368.58	 1.0	 0.0	 1	 -30.0	 30.0;
	21733	 21737	 0.000609	 0.030915	 0.0	 365.11	 365.11	 365.11	 1.025	 0.0	 1	 -30.0	 30.0;
	21733	 21738	 0.00058	 0.030485	 0.0	 364.29	 364.29	 364.29	 1.0	 0.0	 1	 -30.0	 30.0;
	21733	 21739	 0.000702	 0.048498	 0.0	 361.79	 361.79	 361.79	 1.03125	 0.0	 1	 -30.0	 30.0;
	21733	 21740	 0.000628	 0.038625	 0.0	 309.75	 309.75	 309.75	 1.0	 0.0	 1	 -30.0	 30.0;
	21733	 21741	 0.000228	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21743	 21742	 0.000732	 0.028273	 0.0	 425.31	 425.31	 425.31	 1.0	 0.0	 1	 -30.0	 30.0;
	21744	 21747	 8e-05	 0.004838	 0.0	 554.68	 554.68	 554.68	 1.0	 0.0	 1	 -30.0	 30.0;
	21744	 21750	 0.0001	 0.001093	 0.0	 1030.98	 1030.98	 1030.98	 1.0	 0.0	 1	 -30.0	 30.0;
	21744	 21751	 0.000224	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21744	 21752	 0.000216	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21745	 21747	 0.000356	 0.021599	 0.0	 479.68	 479.68	 479.68	 1.0	 0.0	 1	 -30.0	 30.0;
	21745	 23034	 0.003109	 0.021197	 0.03569	 238.18	 238.18	 238.18	 0.0	 0.0	 1	 -30.0	 30.0;
	21746	 21747	 0.002078	 0.126223	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	21748	 21750	 0.000206	 0.012062	 0.0	 515.49	 515.49	 515.49	 1.0	 0.0	 1	 -30.0	 30.0;
	21749	 21750	 0.000206	 0.012062	 0.0	 515.49	 515.49	 515.49	 1.0	 0.0	 1	 -30.0	 30.0;
	23358	 21751	 0.001136	 0.014973	 0.26472	 921.72	 921.72	 921.72	 0.0	 0.0	 1	 -30.0	 30.0;
	21754	 21753	 0.000619	 0.029916	 0.0	 437.2	 437.2	 437.2	 1.01875	 0.0	 1	 -30.0	 30.0;
	21755	 21756	 0.002371	 0.094673	 0.0	 70.5	 70.5	 70.5	 1.0	 0.0	 1	 -30.0	 30.0;
	21755	 21757	 0.020298	 0.67954	 0.0	 28.81	 28.81	 28.81	 1.05	 0.0	 1	 -30.0	 30.0;
	21759	 21760	 0.001734	 0.056106	 0.0	 131.69	 131.69	 131.69	 1.04375	 0.0	 1	 -30.0	 30.0;
	23000	 23001	 0.003486	 0.021672	 0.05375	 223.17	 223.17	 223.17	 0.0	 0.0	 1	 -30.0	 30.0;
	23000	 23004	 0.004992	 0.03537	 0.027	 226.31	 226.31	 226.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23001	 23002	 0.002217	 0.015059	 0.00685	 189.91	 189.91	 189.91	 0.0	 0.0	 1	 -30.0	 30.0;
	23002	 23003	 0.002301	 0.014671	 0.00508	 206.66	 206.66	 206.66	 0.0	 0.0	 1	 -30.0	 30.0;
	23003	 23017	 0.00664	 0.038366	 0.02157	 252.74	 252.74	 252.74	 0.0	 0.0	 1	 -30.0	 30.0;
	23004	 23017	 0.001548	 0.011867	 0.00996	 250.39	 250.39	 250.39	 0.0	 0.0	 1	 -30.0	 30.0;
	23005	 23006	 0.000226	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23005	 23007	 0.000257	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23011	 23006	 0.004923	 0.02924	 0.01157	 239.84	 239.84	 239.84	 0.0	 0.0	 1	 -30.0	 30.0;
	23376	 23006	 0.003273	 0.015475	 0.01002	 270.86	 270.86	 270.86	 0.0	 0.0	 1	 -30.0	 30.0;
	23010	 23008	 0.002782	 0.019618	 0.00416	 180.49	 180.49	 180.49	 0.0	 0.0	 1	 -30.0	 30.0;
	23376	 23010	 0.005582	 0.045828	 0.01657	 222.63	 222.63	 222.63	 0.0	 0.0	 1	 -30.0	 30.0;
	23013	 23011	 0.004456	 0.02544	 0.00769	 238.4	 238.4	 238.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23011	 23014	 0.004996	 0.021874	 0.00644	 239.64	 239.64	 239.64	 0.0	 0.0	 1	 -30.0	 30.0;
	23039	 23012	 0.008319	 0.042249	 0.02034	 170.83	 170.83	 170.83	 0.0	 0.0	 1	 -30.0	 30.0;
	23018	 23013	 0.00452	 0.031035	 0.00899	 178.61	 178.61	 178.61	 0.0	 0.0	 1	 -30.0	 30.0;
	23014	 23017	 0.002093	 0.010799	 0.00511	 282.21	 282.21	 282.21	 0.0	 0.0	 1	 -30.0	 30.0;
	23018	 23015	 0.002297	 0.010812	 0.00911	 241.53	 241.53	 241.53	 0.0	 0.0	 1	 -30.0	 30.0;
	23015	 23376	 0.009166	 0.045456	 0.04037	 262.61	 262.61	 262.61	 0.0	 0.0	 1	 -30.0	 30.0;
	23017	 23016	 0.000497	 0.025394	 0.0	 583.19	 583.19	 583.19	 1.1	 0.0	 1	 -30.0	 30.0;
	23016	 23375	 0.000466	 0.004885	 0.12323	 1279.58	 1279.58	 1279.58	 0.0	 0.0	 1	 -30.0	 30.0;
	23017	 23376	 0.001276	 0.009837	 0.06068	 377.92	 377.92	 377.92	 0.0	 0.0	 1	 -30.0	 30.0;
	23019	 23020	 0.000288	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23021	 23019	 0.002308	 0.013955	 0.00622	 190.63	 190.63	 190.63	 0.0	 0.0	 1	 -30.0	 30.0;
	23024	 23019	 0.002584	 0.014354	 0.00493	 236.65	 236.65	 236.65	 0.0	 0.0	 1	 -30.0	 30.0;
	23021	 23054	 0.005064	 0.024809	 0.01602	 179.69	 179.69	 179.69	 0.0	 0.0	 1	 -30.0	 30.0;
	23022	 23023	 0.004525	 0.026229	 0.03087	 237.39	 237.39	 237.39	 0.0	 0.0	 1	 -30.0	 30.0;
	23040	 23023	 0.00252	 0.012282	 0.01927	 227.95	 227.95	 227.95	 0.0	 0.0	 1	 -30.0	 30.0;
	23025	 23026	 0.000242	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23039	 23026	 0.007025	 0.039485	 0.02078	 195.57	 195.57	 195.57	 0.0	 0.0	 1	 -30.0	 30.0;
	23026	 23330	 0.007403	 0.032781	 0.03582	 226.87	 226.87	 226.87	 0.0	 0.0	 1	 -30.0	 30.0;
	23027	 23030	 0.000471	 0.011554	 0.0	 102.89	 102.89	 102.89	 1.0	 0.0	 1	 -30.0	 30.0;
	23027	 23031	 0.000256	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23028	 23030	 0.011468	 0.281155	 0.0	 51.44	 51.44	 51.44	 1.0	 0.0	 1	 -30.0	 30.0;
	23029	 23030	 0.011468	 0.281155	 0.0	 51.44	 51.44	 51.44	 1.0	 0.0	 1	 -30.0	 30.0;
	23433	 23031	 0.001951	 0.011949	 0.00516	 241.67	 241.67	 241.67	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23033	 0.00023	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23041	 0.003039	 0.014949	 0.00357	 244.04	 244.04	 244.04	 0.0	 0.0	 1	 -30.0	 30.0;
	23032	 23042	 0.00248	 0.015086	 0.0116	 189.17	 189.17	 189.17	 0.0	 0.0	 1	 -30.0	 30.0;
	23034	 23035	 0.000291	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23036	 23034	 0.001484	 0.008952	 0.003	 210.48	 210.48	 210.48	 0.0	 0.0	 1	 -30.0	 30.0;
	23037	 23038	 0.000211	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23037	 23039	 0.0056	 0.035159	 0.03077	 213.2	 213.2	 213.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23286	 23037	 0.022458	 0.110885	 0.09131	 234.43	 234.43	 234.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23040	 23067	 0.002527	 0.013415	 0.06517	 208.87	 208.87	 208.87	 0.0	 0.0	 1	 -30.0	 30.0;
	23041	 23271	 0.003642	 0.019672	 0.01258	 274.08	 274.08	 274.08	 0.0	 0.0	 1	 -30.0	 30.0;
	23042	 23059	 0.002073	 0.013052	 0.00667	 221.01	 221.01	 221.01	 0.0	 0.0	 1	 -30.0	 30.0;
	23043	 23044	 0.002716	 0.015512	 0.00551	 229.75	 229.75	 229.75	 0.0	 0.0	 1	 -30.0	 30.0;
	23043	 23067	 0.004713	 0.022549	 0.05896	 212.09	 212.09	 212.09	 0.0	 0.0	 1	 -30.0	 30.0;
	23044	 23045	 0.000281	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23044	 23053	 0.002524	 0.013082	 0.01612	 252.47	 252.47	 252.47	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 23047	 0.000289	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23056	 23046	 0.002534	 0.011709	 0.0062	 222.77	 222.77	 222.77	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 23086	 0.004684	 0.024621	 0.0332	 230.32	 230.32	 230.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23046	 23402	 0.004013	 0.014378	 0.00746	 205.31	 205.31	 205.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23048	 23051	 0.000265	 0.008557	 0.0	 319.8	 319.8	 319.8	 1.0	 0.0	 1	 -30.0	 30.0;
	23067	 23048	 0.004968	 0.026167	 0.01779	 223.15	 223.15	 223.15	 0.0	 0.0	 1	 -30.0	 30.0;
	23048	 23071	 0.001855	 0.009883	 0.01193	 230.09	 230.09	 230.09	 0.0	 0.0	 1	 -30.0	 30.0;
	23048	 23390	 0.001858	 0.011988	 0.01983	 313.81	 313.81	 313.81	 0.0	 0.0	 1	 -30.0	 30.0;
	23049	 23051	 0.002508	 0.081019	 0.0	 159.9	 159.9	 159.9	 1.0	 0.0	 1	 -30.0	 30.0;
	23050	 23051	 0.002508	 0.081019	 0.0	 159.9	 159.9	 159.9	 1.0	 0.0	 1	 -30.0	 30.0;
	23052	 23053	 0.000267	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23053	 23058	 0.002491	 0.013438	 0.09734	 238.82	 238.82	 238.82	 0.0	 0.0	 1	 -30.0	 30.0;
	23390	 23053	 0.001784	 0.010245	 0.00689	 237.04	 237.04	 237.04	 0.0	 0.0	 1	 -30.0	 30.0;
	23054	 23056	 0.001518	 0.010012	 0.00441	 221.41	 221.41	 221.41	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 23056	 0.00024	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23055	 23057	 0.000201	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23056	 23100	 0.002548	 0.012888	 0.06318	 213.39	 213.39	 213.39	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 23063	 0.008515	 0.045138	 0.03937	 208.32	 208.32	 208.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23059	 23433	 0.005186	 0.02976	 0.01757	 272.08	 272.08	 272.08	 0.0	 0.0	 1	 -30.0	 30.0;
	23060	 23078	 0.004967	 0.031205	 0.02519	 147.29	 147.29	 147.29	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 23060	 0.010871	 0.047144	 0.01994	 212.84	 212.84	 212.84	 0.0	 0.0	 1	 -30.0	 30.0;
	23069	 23061	 0.004267	 0.025902	 0.03003	 191.14	 191.14	 191.14	 0.0	 0.0	 1	 -30.0	 30.0;
	23062	 23063	 0.000267	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23062	 23064	 0.000293	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23063	 23402	 0.004926	 0.02838	 0.01091	 205.38	 205.38	 205.38	 0.0	 0.0	 1	 -30.0	 30.0;
	23065	 23066	 0.000292	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23065	 23067	 0.000276	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23088	 23067	 0.004718	 0.026806	 0.01304	 186.28	 186.28	 186.28	 0.0	 0.0	 1	 -30.0	 30.0;
	23068	 23069	 0.000221	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23355	 23069	 0.005819	 0.031884	 0.03083	 217.55	 217.55	 217.55	 0.0	 0.0	 1	 -30.0	 30.0;
	23070	 23071	 0.000214	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23072	 23073	 0.000251	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23109	 23072	 0.004957	 0.027787	 0.03167	 202.02	 202.02	 202.02	 0.0	 0.0	 1	 -30.0	 30.0;
	23075	 23089	 0.002161	 0.011307	 0.01623	 210.2	 210.2	 210.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23474	 23075	 0.002936	 0.014655	 0.00356	 231.68	 231.68	 231.68	 0.0	 0.0	 1	 -30.0	 30.0;
	23076	 23077	 0.000203	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23076	 23091	 0.00206	 0.012014	 0.01358	 234.49	 234.49	 234.49	 0.0	 0.0	 1	 -30.0	 30.0;
	23076	 23100	 0.002737	 0.018573	 0.00863	 227.6	 227.6	 227.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23076	 23310	 0.004471	 0.023443	 0.00604	 229.63	 229.63	 229.63	 0.0	 0.0	 1	 -30.0	 30.0;
	23078	 23310	 0.00217	 0.01014	 0.00372	 215.59	 215.59	 215.59	 0.0	 0.0	 1	 -30.0	 30.0;
	23079	 23080	 0.000268	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23079	 23089	 0.001314	 0.006991	 0.00389	 209.2	 209.2	 209.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23349	 23079	 0.002605	 0.011981	 0.0057	 248.24	 248.24	 248.24	 0.0	 0.0	 1	 -30.0	 30.0;
	23081	 23082	 0.000299	 0.0012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23405	 23081	 0.00427	 0.027411	 0.02158	 207.6	 207.6	 207.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23083	 23341	 0.002016	 0.013516	 0.00507	 249.06	 249.06	 249.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23084	 23085	 0.000224	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23084	 23086	 0.000281	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23086	 23421	 0.00102	 0.005965	 0.01969	 287.06	 287.06	 287.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23087	 23088	 0.000289	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23119	 23088	 0.007408	 0.051991	 0.02983	 198.2	 198.2	 198.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23089	 23090	 0.000261	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23310	 23091	 0.000793	 0.005446	 0.00333	 267.33	 267.33	 267.33	 0.0	 0.0	 1	 -30.0	 30.0;
	23092	 23109	 0.003011	 0.016872	 0.03434	 226.93	 226.93	 226.93	 0.0	 0.0	 1	 -30.0	 30.0;
	23092	 23278	 0.007962	 0.05497	 0.02786	 201.43	 201.43	 201.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23104	 23093	 0.000903	 0.004991	 0.00406	 191.26	 191.26	 191.26	 0.0	 0.0	 1	 -30.0	 30.0;
	23093	 23310	 0.00376	 0.017636	 0.00824	 227.9	 227.9	 227.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23094	 23104	 0.001925	 0.012418	 0.00357	 215.0	 215.0	 215.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23094	 23444	 0.002607	 0.013173	 0.00681	 249.56	 249.56	 249.56	 0.0	 0.0	 1	 -30.0	 30.0;
	23095	 23096	 0.000247	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23095	 23097	 0.000292	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23097	 23349	 0.001704	 0.010328	 0.00257	 241.74	 241.74	 241.74	 0.0	 0.0	 1	 -30.0	 30.0;
	23097	 23444	 0.004504	 0.021736	 0.03072	 194.59	 194.59	 194.59	 0.0	 0.0	 1	 -30.0	 30.0;
	23098	 23099	 0.000284	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23098	 23100	 0.00022	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23100	 23474	 0.001238	 0.006977	 0.00331	 300.11	 300.11	 300.11	 0.0	 0.0	 1	 -30.0	 30.0;
	23101	 23102	 0.000282	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23349	 23102	 0.00154	 0.008244	 0.00616	 191.43	 191.43	 191.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23102	 23501	 0.015924	 0.057984	 0.08622	 217.23	 217.23	 217.23	 0.0	 0.0	 1	 -30.0	 30.0;
	23103	 23108	 0.00856	 0.04353	 0.04015	 205.28	 205.28	 205.28	 0.0	 0.0	 1	 -30.0	 30.0;
	23108	 23105	 0.002847	 0.019241	 0.00802	 219.25	 219.25	 219.25	 0.0	 0.0	 1	 -30.0	 30.0;
	23105	 23452	 0.022065	 0.113223	 0.04689	 233.59	 233.59	 233.59	 0.0	 0.0	 1	 -30.0	 30.0;
	23106	 23107	 0.000256	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23107	 23112	 0.006306	 0.030254	 0.00669	 220.7	 220.7	 220.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23107	 23444	 0.003206	 0.019179	 0.00806	 244.14	 244.14	 244.14	 0.0	 0.0	 1	 -30.0	 30.0;
	23108	 23350	 0.005009	 0.029253	 0.01615	 208.35	 208.35	 208.35	 0.0	 0.0	 1	 -30.0	 30.0;
	23111	 23110	 0.002575	 0.018614	 0.00964	 193.85	 193.85	 193.85	 0.0	 0.0	 1	 -30.0	 30.0;
	23110	 23128	 0.011144	 0.054096	 0.014	 215.46	 215.46	 215.46	 0.0	 0.0	 1	 -30.0	 30.0;
	23110	 23350	 0.005224	 0.039111	 0.14135	 252.06	 252.06	 252.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23355	 23111	 0.007845	 0.047026	 0.02688	 215.32	 215.32	 215.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23112	 23113	 0.000247	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23120	 23112	 0.004088	 0.025884	 0.01546	 193.06	 193.06	 193.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23114	 23115	 0.000255	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23114	 23127	 0.005145	 0.039542	 0.06767	 245.3	 245.3	 245.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23114	 23278	 0.004218	 0.022122	 0.02693	 266.33	 266.33	 266.33	 0.0	 0.0	 1	 -30.0	 30.0;
	23116	 23117	 0.000219	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23116	 23118	 0.00025	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23118	 23139	 0.008437	 0.045003	 0.11014	 227.73	 227.73	 227.73	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 23118	 0.006019	 0.034878	 0.03372	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23119	 23127	 0.0105	 0.072455	 0.02756	 231.09	 231.09	 231.09	 0.0	 0.0	 1	 -30.0	 30.0;
	23124	 23120	 0.006528	 0.036087	 0.01258	 204.0	 204.0	 204.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 23122	 0.000275	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 23131	 0.004991	 0.03145	 0.05016	 216.69	 216.69	 216.69	 0.0	 0.0	 1	 -30.0	 30.0;
	23121	 23134	 0.002808	 0.012589	 0.00387	 242.5	 242.5	 242.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23123	 23126	 -6.2e-05	 -0.003481	 0.0	 628.52	 628.52	 628.52	 1.0	 0.0	 1	 -30.0	 30.0;
	23159	 23123	 0.001595	 0.019012	 0.55675	 1277.32	 1277.32	 1277.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23443	 23123	 0.001489	 0.015834	 0.17913	 1205.76	 1205.76	 1205.76	 0.0	 0.0	 1	 -30.0	 30.0;
	23123	 23500	 0.001413	 0.016187	 0.22933	 1214.92	 1214.92	 1214.92	 0.0	 0.0	 1	 -30.0	 30.0;
	23124	 23126	 0.000704	 0.039375	 0.0	 442.48	 442.48	 442.48	 1.0	 0.0	 1	 -30.0	 30.0;
	23124	 23140	 0.00546	 0.016265	 0.00671	 240.71	 240.71	 240.71	 0.0	 0.0	 1	 -30.0	 30.0;
	23125	 23126	 0.00381	 0.212982	 0.0	 186.04	 186.04	 186.04	 1.0	 0.0	 1	 -30.0	 30.0;
	23134	 23129	 0.00262	 0.012989	 0.01344	 265.3	 265.3	 265.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23129	 23147	 0.006041	 0.02315	 0.10147	 239.7	 239.7	 239.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23129	 23347	 0.01452	 0.086172	 0.12863	 270.26	 270.26	 270.26	 0.0	 0.0	 1	 -30.0	 30.0;
	23469	 23129	 0.005056	 0.032651	 0.03764	 258.63	 258.63	 258.63	 0.0	 0.0	 1	 -30.0	 30.0;
	23130	 23152	 0.014417	 0.069814	 0.02832	 219.17	 219.17	 219.17	 0.0	 0.0	 1	 -30.0	 30.0;
	23499	 23130	 0.00791	 0.047022	 0.03993	 230.55	 230.55	 230.55	 0.0	 0.0	 1	 -30.0	 30.0;
	23132	 23131	 0.003908	 0.020156	 0.01167	 231.39	 231.39	 231.39	 0.0	 0.0	 1	 -30.0	 30.0;
	23131	 23139	 0.004326	 0.027604	 0.02307	 232.11	 232.11	 232.11	 0.0	 0.0	 1	 -30.0	 30.0;
	23132	 23133	 0.000224	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23132	 23148	 0.007268	 0.048862	 0.03179	 210.22	 210.22	 210.22	 0.0	 0.0	 1	 -30.0	 30.0;
	23134	 23135	 0.00026	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23136	 23145	 0.009652	 0.050279	 0.01333	 215.38	 215.38	 215.38	 0.0	 0.0	 1	 -30.0	 30.0;
	23452	 23136	 0.009175	 0.050475	 0.00813	 227.32	 227.32	 227.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23366	 23137	 0.005048	 0.021693	 0.00762	 224.74	 224.74	 224.74	 0.0	 0.0	 1	 -30.0	 30.0;
	23137	 23449	 0.010545	 0.046048	 0.02253	 239.77	 239.77	 239.77	 0.0	 0.0	 1	 -30.0	 30.0;
	23138	 23312	 0.007209	 0.040482	 0.07732	 212.93	 212.93	 212.93	 0.0	 0.0	 1	 -30.0	 30.0;
	23138	 23387	 0.01585	 0.083121	 0.0935	 231.78	 231.78	 231.78	 0.0	 0.0	 1	 -30.0	 30.0;
	23422	 23138	 0.001117	 0.006529	 0.02084	 188.86	 188.86	 188.86	 0.0	 0.0	 1	 -30.0	 30.0;
	23140	 23139	 0.004372	 0.022418	 0.00756	 220.58	 220.58	 220.58	 0.0	 0.0	 1	 -30.0	 30.0;
	23140	 23143	 0.001035	 0.035989	 0.0	 102.79	 102.79	 102.79	 1.0	 0.0	 1	 -30.0	 30.0;
	23141	 23143	 0.009808	 0.340967	 0.0	 51.4	 51.4	 51.4	 1.0	 0.0	 1	 -30.0	 30.0;
	23142	 23143	 0.009808	 0.340967	 0.0	 51.4	 51.4	 51.4	 1.0	 0.0	 1	 -30.0	 30.0;
	23371	 23144	 0.010255	 0.069248	 0.01449	 172.41	 172.41	 172.41	 0.0	 0.0	 1	 -30.0	 30.0;
	23144	 23489	 0.011279	 0.055821	 0.00908	 198.19	 198.19	 198.19	 0.0	 0.0	 1	 -30.0	 30.0;
	23145	 23146	 0.003729	 0.02217	 0.00903	 226.64	 226.64	 226.64	 0.0	 0.0	 1	 -30.0	 30.0;
	23145	 23160	 0.007865	 0.051844	 0.24435	 257.49	 257.49	 257.49	 0.0	 0.0	 1	 -30.0	 30.0;
	23145	 23273	 0.010585	 0.065301	 0.04517	 236.87	 236.87	 236.87	 0.0	 0.0	 1	 -30.0	 30.0;
	23146	 23281	 0.007336	 0.037419	 0.04381	 173.37	 173.37	 173.37	 0.0	 0.0	 1	 -30.0	 30.0;
	23424	 23146	 0.004028	 0.021926	 0.01273	 257.23	 257.23	 257.23	 0.0	 0.0	 1	 -30.0	 30.0;
	23147	 23496	 0.013518	 0.085057	 0.01649	 227.17	 227.17	 227.17	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23149	 0.000232	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23152	 0.008434	 0.043535	 0.01646	 203.6	 203.6	 203.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23148	 23449	 0.015996	 0.095134	 0.06869	 225.44	 225.44	 225.44	 0.0	 0.0	 1	 -30.0	 30.0;
	23152	 23150	 0.002725	 0.013166	 0.02493	 198.77	 198.77	 198.77	 0.0	 0.0	 1	 -30.0	 30.0;
	23496	 23150	 0.008112	 0.040676	 0.02313	 205.74	 205.74	 205.74	 0.0	 0.0	 1	 -30.0	 30.0;
	23151	 23152	 0.000295	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23162	 23153	 0.003308	 0.018232	 0.0554	 215.75	 215.75	 215.75	 0.0	 0.0	 1	 -30.0	 30.0;
	23366	 23153	 0.005413	 0.0409	 0.03477	 261.36	 261.36	 261.36	 0.0	 0.0	 1	 -30.0	 30.0;
	23154	 23266	 0.010503	 0.045367	 0.09497	 201.69	 201.69	 201.69	 0.0	 0.0	 1	 -30.0	 30.0;
	23312	 23154	 0.008892	 0.050237	 0.01207	 227.9	 227.9	 227.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23154	 25055	 0.072129	 0.428145	 0.11774	 213.79	 213.79	 213.79	 0.0	 0.0	 1	 -30.0	 30.0;
	23154	 26144	 0.017233	 0.090036	 0.06946	 192.1	 192.1	 192.1	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 23156	 0.000297	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 23158	 0.003192	 0.017493	 0.00669	 191.57	 191.57	 191.57	 0.0	 0.0	 1	 -30.0	 30.0;
	23155	 23496	 0.008064	 0.04378	 0.03876	 220.31	 220.31	 220.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23158	 23157	 0.000461	 0.030302	 0.0	 446.31	 446.31	 446.31	 1.025	 0.0	 1	 -30.0	 30.0;
	23157	 23159	 0.000283	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23158	 23177	 0.003196	 0.023677	 0.08495	 268.76	 268.76	 268.76	 0.0	 0.0	 1	 -30.0	 30.0;
	23159	 23184	 0.000876	 0.010616	 0.19309	 1167.37	 1167.37	 1167.37	 0.0	 0.0	 1	 -30.0	 30.0;
	23194	 23160	 0.012354	 0.0778	 0.02523	 238.38	 238.38	 238.38	 0.0	 0.0	 1	 -30.0	 30.0;
	23161	 23216	 0.005886	 0.037813	 0.06913	 242.53	 242.53	 242.53	 0.0	 0.0	 1	 -30.0	 30.0;
	23161	 23366	 0.00961	 0.044431	 0.11391	 263.82	 263.82	 263.82	 0.0	 0.0	 1	 -30.0	 30.0;
	23163	 23162	 0.002237	 0.011861	 0.00539	 238.84	 238.84	 238.84	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23162	 0.004759	 0.023077	 0.03345	 228.54	 228.54	 228.54	 0.0	 0.0	 1	 -30.0	 30.0;
	23163	 23164	 0.000209	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23398	 23163	 0.005671	 0.031145	 0.01761	 266.86	 266.86	 266.86	 0.0	 0.0	 1	 -30.0	 30.0;
	23165	 23166	 0.00026	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23177	 23165	 0.002419	 0.015758	 0.00502	 241.79	 241.79	 241.79	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 23165	 0.001891	 0.01316	 0.00368	 201.2	 201.2	 201.2	 0.0	 0.0	 1	 -30.0	 30.0;
	23167	 23172	 0.002994	 0.019294	 0.00388	 235.08	 235.08	 235.08	 0.0	 0.0	 1	 -30.0	 30.0;
	23167	 23179	 0.003529	 0.021415	 0.016	 184.55	 184.55	 184.55	 0.0	 0.0	 1	 -30.0	 30.0;
	23168	 23169	 0.000267	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23169	 23183	 0.004606	 0.027333	 0.01947	 227.01	 227.01	 227.01	 0.0	 0.0	 1	 -30.0	 30.0;
	23169	 23407	 0.002141	 0.015321	 0.01532	 218.7	 218.7	 218.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23170	 23171	 0.000201	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23170	 23172	 0.004397	 0.028681	 0.01374	 184.07	 184.07	 184.07	 0.0	 0.0	 1	 -30.0	 30.0;
	23194	 23170	 0.012414	 0.076744	 0.02955	 216.28	 216.28	 216.28	 0.0	 0.0	 1	 -30.0	 30.0;
	23172	 23441	 0.004584	 0.028373	 0.17876	 255.25	 255.25	 255.25	 0.0	 0.0	 1	 -30.0	 30.0;
	23173	 23217	 0.00529	 0.023031	 0.0124	 233.06	 233.06	 233.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23173	 23292	 0.008497	 0.045025	 0.03319	 286.05	 286.05	 286.05	 0.0	 0.0	 1	 -30.0	 30.0;
	23174	 23175	 0.006786	 0.035337	 0.02391	 215.91	 215.91	 215.91	 0.0	 0.0	 1	 -30.0	 30.0;
	23266	 23174	 0.002979	 0.01527	 0.00453	 204.54	 204.54	 204.54	 0.0	 0.0	 1	 -30.0	 30.0;
	23174	 23422	 0.022856	 0.101258	 0.03692	 216.37	 216.37	 216.37	 0.0	 0.0	 1	 -30.0	 30.0;
	23174	 23439	 0.008664	 0.043585	 0.01517	 217.15	 217.15	 217.15	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 23176	 0.000267	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 23283	 0.004836	 0.024534	 0.00943	 204.78	 204.78	 204.78	 0.0	 0.0	 1	 -30.0	 30.0;
	23175	 23362	 0.005387	 0.036985	 0.01812	 195.51	 195.51	 195.51	 0.0	 0.0	 1	 -30.0	 30.0;
	23177	 23178	 0.000293	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23183	 23179	 0.00248	 0.013061	 0.01418	 203.6	 203.6	 203.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23180	 23182	 0.001982	 0.012753	 0.00527	 224.86	 224.86	 224.86	 0.0	 0.0	 1	 -30.0	 30.0;
	23182	 23181	 0.002198	 0.013333	 0.0056	 204.36	 204.36	 204.36	 0.0	 0.0	 1	 -30.0	 30.0;
	23407	 23181	 0.00296	 0.017971	 0.00408	 235.92	 235.92	 235.92	 0.0	 0.0	 1	 -30.0	 30.0;
	23182	 23407	 0.004314	 0.017279	 0.01466	 245.19	 245.19	 245.19	 0.0	 0.0	 1	 -30.0	 30.0;
	23183	 23185	 0.00218	 0.010629	 0.00196	 222.96	 222.96	 222.96	 0.0	 0.0	 1	 -30.0	 30.0;
	23183	 23190	 0.004466	 0.026553	 0.0489	 242.63	 242.63	 242.63	 0.0	 0.0	 1	 -30.0	 30.0;
	23184	 23187	 0.000388	 0.018793	 0.0	 514.86	 514.86	 514.86	 1.0	 0.0	 1	 -30.0	 30.0;
	23184	 23188	 0.000219	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23291	 23184	 0.001071	 0.012851	 0.18867	 1184.68	 1184.68	 1184.68	 0.0	 0.0	 1	 -30.0	 30.0;
	23184	 23408	 0.000466	 0.005409	 0.14439	 1162.82	 1162.82	 1162.82	 0.0	 0.0	 1	 -30.0	 30.0;
	23185	 23187	 0.000114	 0.005502	 0.0	 439.86	 439.86	 439.86	 1.0	 0.0	 1	 -30.0	 30.0;
	23185	 23189	 0.003648	 0.017512	 0.00649	 273.64	 273.64	 273.64	 0.0	 0.0	 1	 -30.0	 30.0;
	23186	 23187	 0.003245	 0.157122	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23201	 23189	 0.001498	 0.008199	 0.00496	 229.83	 229.83	 229.83	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 23190	 0.008321	 0.049444	 0.01354	 260.65	 260.65	 260.65	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 23192	 0.000256	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23193	 23191	 0.001685	 0.009359	 0.00661	 210.68	 210.68	 210.68	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 23201	 0.000959	 0.005643	 0.00283	 206.52	 206.52	 206.52	 0.0	 0.0	 1	 -30.0	 30.0;
	23191	 23407	 0.003996	 0.01158	 0.02226	 254.87	 254.87	 254.87	 0.0	 0.0	 1	 -30.0	 30.0;
	23193	 23209	 0.003859	 0.026559	 0.00573	 210.37	 210.37	 210.37	 0.0	 0.0	 1	 -30.0	 30.0;
	23195	 23196	 0.000221	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23195	 23197	 0.000256	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23197	 23210	 0.003758	 0.017147	 0.0397	 180.6	 180.6	 180.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23198	 23199	 0.000284	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23198	 23200	 0.000213	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 23200	 0.002428	 0.014868	 0.00799	 214.68	 214.68	 214.68	 0.0	 0.0	 1	 -30.0	 30.0;
	23204	 23200	 0.001969	 0.010376	 0.00819	 213.42	 213.42	 213.42	 0.0	 0.0	 1	 -30.0	 30.0;
	23200	 23206	 0.003817	 0.021865	 0.01481	 222.54	 222.54	 222.54	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 23203	 0.000294	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23202	 23346	 0.001092	 0.006346	 0.0052	 265.38	 265.38	 265.38	 0.0	 0.0	 1	 -30.0	 30.0;
	23204	 23205	 0.000218	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23407	 23204	 0.00407	 0.015925	 0.01323	 223.36	 223.36	 223.36	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 23207	 0.000283	 0.001143	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 23217	 0.002181	 0.011295	 0.00634	 222.56	 222.56	 222.56	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 23218	 0.003864	 0.02119	 0.01306	 202.32	 202.32	 202.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23206	 23311	 0.011565	 0.064957	 0.06661	 290.71	 290.71	 290.71	 0.0	 0.0	 1	 -30.0	 30.0;
	23208	 23209	 0.000236	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23209	 23217	 0.001951	 0.010723	 0.00469	 242.02	 242.02	 242.02	 0.0	 0.0	 1	 -30.0	 30.0;
	23210	 23211	 0.000289	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23210	 23224	 0.00429	 0.025083	 0.06338	 219.73	 219.73	 219.73	 0.0	 0.0	 1	 -30.0	 30.0;
	23212	 23225	 0.006083	 0.041003	 0.04385	 226.43	 226.43	 226.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23227	 23212	 0.003898	 0.020756	 0.05344	 198.83	 198.83	 198.83	 0.0	 0.0	 1	 -30.0	 30.0;
	23213	 23214	 0.000243	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23214	 23339	 0.017165	 0.095873	 0.10091	 198.7	 198.7	 198.7	 0.0	 0.0	 1	 -30.0	 30.0;
	23215	 23266	 0.005964	 0.033361	 0.04531	 223.02	 223.02	 223.02	 0.0	 0.0	 1	 -30.0	 30.0;
	23426	 23215	 0.002097	 0.009953	 0.00572	 210.61	 210.61	 210.61	 0.0	 0.0	 1	 -30.0	 30.0;
	23216	 23220	 0.010952	 0.053994	 0.01637	 176.34	 176.34	 176.34	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23219	 0.000288	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23218	 23222	 0.002347	 0.015134	 0.02083	 207.72	 207.72	 207.72	 0.0	 0.0	 1	 -30.0	 30.0;
	23362	 23220	 0.006885	 0.038353	 0.01586	 226.32	 226.32	 226.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23221	 23231	 0.004007	 0.023895	 0.03395	 216.43	 216.43	 216.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23221	 23232	 0.007674	 0.030415	 0.03811	 237.78	 237.78	 237.78	 0.0	 0.0	 1	 -30.0	 30.0;
	23223	 23222	 0.001987	 0.01272	 0.00888	 184.87	 184.87	 184.87	 0.0	 0.0	 1	 -30.0	 30.0;
	23222	 23319	 0.014989	 0.079496	 0.04775	 242.36	 242.36	 242.36	 0.0	 0.0	 1	 -30.0	 30.0;
	23223	 23225	 0.004068	 0.019284	 0.00316	 212.79	 212.79	 212.79	 0.0	 0.0	 1	 -30.0	 30.0;
	23346	 23224	 0.004674	 0.023196	 0.00803	 240.64	 240.64	 240.64	 0.0	 0.0	 1	 -30.0	 30.0;
	23225	 23226	 0.000249	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23346	 23225	 0.002848	 0.018661	 0.0234	 183.23	 183.23	 183.23	 0.0	 0.0	 1	 -30.0	 30.0;
	23225	 23494	 0.012223	 0.081909	 0.07572	 273.3	 273.3	 273.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23232	 23227	 0.005875	 0.029528	 0.00972	 204.45	 204.45	 204.45	 0.0	 0.0	 1	 -30.0	 30.0;
	23239	 23227	 0.006543	 0.040391	 0.02051	 207.33	 207.33	 207.33	 0.0	 0.0	 1	 -30.0	 30.0;
	23228	 23229	 0.000251	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23229	 0.003721	 0.017128	 0.01018	 250.53	 250.53	 250.53	 0.0	 0.0	 1	 -30.0	 30.0;
	23235	 23229	 0.004571	 0.023435	 0.01114	 207.81	 207.81	 207.81	 0.0	 0.0	 1	 -30.0	 30.0;
	23249	 23229	 0.007449	 0.04608	 0.00902	 228.23	 228.23	 228.23	 0.0	 0.0	 1	 -30.0	 30.0;
	23230	 23231	 0.000213	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23231	 0.003873	 0.023217	 0.01235	 204.43	 204.43	 204.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23231	 23283	 0.005557	 0.029844	 0.14012	 256.44	 256.44	 256.44	 0.0	 0.0	 1	 -30.0	 30.0;
	23243	 23232	 0.000813	 0.004704	 0.03023	 251.38	 251.38	 251.38	 0.0	 0.0	 1	 -30.0	 30.0;
	23232	 23248	 0.00384	 0.02659	 0.02274	 241.05	 241.05	 241.05	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23233	 0.000448	 0.02435	 0.0	 464.15	 464.15	 464.15	 1.00625	 0.0	 1	 -30.0	 30.0;
	23257	 23233	 0.001281	 0.016982	 0.28365	 1168.9	 1168.9	 1168.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23233	 23265	 0.001154	 0.013882	 0.49753	 1140.18	 1140.18	 1140.18	 0.0	 0.0	 1	 -30.0	 30.0;
	23233	 23345	 0.001268	 0.014474	 0.4335	 1195.5	 1195.5	 1195.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23234	 23237	 0.008506	 0.044267	 0.03222	 228.24	 228.24	 228.24	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23234	 0.003476	 0.020475	 0.02101	 191.22	 191.22	 191.22	 0.0	 0.0	 1	 -30.0	 30.0;
	23235	 23236	 0.000267	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23235	 23426	 0.007382	 0.044917	 0.03588	 260.1	 260.1	 260.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25087	 23237	 0.008341	 0.040628	 0.0291	 209.54	 209.54	 209.54	 0.0	 0.0	 1	 -30.0	 30.0;
	23238	 23239	 0.00029	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23239	 0.004961	 0.025169	 0.02595	 225.54	 225.54	 225.54	 0.0	 0.0	 1	 -30.0	 30.0;
	23240	 23241	 0.000266	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23301	 23241	 0.004064	 0.019501	 0.00518	 233.76	 233.76	 233.76	 0.0	 0.0	 1	 -30.0	 30.0;
	23241	 25076	 0.012972	 0.078382	 0.06138	 220.78	 220.78	 220.78	 0.0	 0.0	 1	 -30.0	 30.0;
	23242	 23245	 0.005174	 0.024362	 0.00543	 214.71	 214.71	 214.71	 0.0	 0.0	 1	 -30.0	 30.0;
	23243	 23437	 0.003953	 0.027691	 0.18509	 281.06	 281.06	 281.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23244	 23245	 0.000254	 0.001175	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23244	 23246	 0.000293	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23245	 23250	 0.008226	 0.040441	 0.01412	 227.53	 227.53	 227.53	 0.0	 0.0	 1	 -30.0	 30.0;
	23247	 23483	 0.010536	 0.070547	 0.02061	 246.49	 246.49	 246.49	 0.0	 0.0	 1	 -30.0	 30.0;
	23248	 23414	 0.01111	 0.071812	 0.11477	 263.22	 263.22	 263.22	 0.0	 0.0	 1	 -30.0	 30.0;
	23255	 23249	 0.009467	 0.046024	 0.03133	 166.37	 166.37	 166.37	 0.0	 0.0	 1	 -30.0	 30.0;
	23250	 23437	 0.012257	 0.047655	 0.17202	 251.44	 251.44	 251.44	 0.0	 0.0	 1	 -30.0	 30.0;
	23251	 23254	 0.0001	 0.000783	 0.0	 102.65	 102.65	 102.65	 1.0	 0.0	 1	 -30.0	 30.0;
	23251	 25086	 0.007952	 0.05476	 0.01835	 212.69	 212.69	 212.69	 0.0	 0.0	 1	 -30.0	 30.0;
	23251	 25165	 0.016562	 0.103114	 0.02991	 202.17	 202.17	 202.17	 0.0	 0.0	 1	 -30.0	 30.0;
	23251	 25240	 0.021265	 0.119196	 0.13739	 162.76	 162.76	 162.76	 0.0	 0.0	 1	 -30.0	 30.0;
	23251	 25241	 0.054658	 0.300521	 0.08564	 192.9	 192.9	 192.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23251	 25962	 0.01651	 0.108469	 0.04082	 221.18	 221.18	 221.18	 0.0	 0.0	 1	 -30.0	 30.0;
	23252	 23254	 0.00787	 0.262585	 0.0	 51.32	 51.32	 51.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23253	 23254	 0.00787	 0.262585	 0.0	 51.32	 51.32	 51.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23255	 23256	 0.000217	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23258	 23255	 0.002456	 0.014676	 0.00425	 230.81	 230.81	 230.81	 0.0	 0.0	 1	 -30.0	 30.0;
	23258	 23257	 0.0007	 0.038693	 0.0	 411.1	 411.1	 411.1	 1.025	 0.0	 1	 -30.0	 30.0;
	23257	 26205	 0.001698	 0.020022	 0.35427	 1086.97	 1086.97	 1086.97	 0.0	 0.0	 1	 -30.0	 30.0;
	23259	 23260	 0.00025	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23336	 23260	 0.00748	 0.039812	 0.02534	 200.21	 200.21	 200.21	 0.0	 0.0	 1	 -30.0	 30.0;
	23392	 23260	 0.007362	 0.035462	 0.01859	 174.96	 174.96	 174.96	 0.0	 0.0	 1	 -30.0	 30.0;
	23261	 23262	 0.000245	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23261	 23336	 0.010723	 0.075085	 0.01832	 196.67	 196.67	 196.67	 0.0	 0.0	 1	 -30.0	 30.0;
	23261	 23392	 0.007194	 0.042423	 0.03463	 195.03	 195.03	 195.03	 0.0	 0.0	 1	 -30.0	 30.0;
	23263	 23264	 0.011951	 0.066023	 0.04847	 185.48	 185.48	 185.48	 0.0	 0.0	 1	 -30.0	 30.0;
	30118	 23263	 0.049243	 0.216127	 0.05466	 194.21	 194.21	 194.21	 0.0	 0.0	 1	 -30.0	 30.0;
	23264	 23397	 0.011033	 0.081199	 0.07906	 211.48	 211.48	 211.48	 0.0	 0.0	 1	 -30.0	 30.0;
	23266	 23265	 0.000443	 0.025926	 0.0	 400.98	 400.98	 400.98	 1.0	 0.0	 1	 -30.0	 30.0;
	23265	 23269	 0.0001	 -0.001741	 0.0	 1037.92	 1037.92	 1037.92	 1.0	 0.0	 1	 -30.0	 30.0;
	23365	 23265	 0.001819	 0.02097	 0.36198	 1198.85	 1198.85	 1198.85	 0.0	 0.0	 1	 -30.0	 30.0;
	23429	 23265	 0.000815	 0.008343	 0.15697	 1104.93	 1104.93	 1104.93	 0.0	 0.0	 1	 -30.0	 30.0;
	23283	 23266	 0.003035	 0.01679	 0.01106	 230.6	 230.6	 230.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23266	 23439	 0.006679	 0.032403	 0.0239	 219.4	 219.4	 219.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23267	 23269	 0.000515	 0.027423	 0.0	 518.96	 518.96	 518.96	 1.0	 0.0	 1	 -30.0	 30.0;
	23268	 23269	 0.000515	 0.027423	 0.0	 518.96	 518.96	 518.96	 1.0	 0.0	 1	 -30.0	 30.0;
	23270	 23271	 0.000208	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23271	 23433	 0.00014	 0.000785	 0.00039	 246.6	 246.6	 246.6	 0.0	 0.0	 1	 -30.0	 30.0;
	23272	 23275	 0.000487	 0.024193	 0.0	 425.46	 425.46	 425.46	 1.0	 0.0	 1	 -30.0	 30.0;
	23272	 23276	 0.000219	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23273	 23275	 -0.000154	 -0.007632	 0.0	 383.24	 383.24	 383.24	 1.0	 0.0	 1	 -30.0	 30.0;
	23274	 23275	 0.002051	 0.101783	 0.0	 42.22	 42.22	 42.22	 1.0	 0.0	 1	 -30.0	 30.0;
	23338	 23276	 0.001125	 0.014305	 0.26291	 992.01	 992.01	 992.01	 0.0	 0.0	 1	 -30.0	 30.0;
	23278	 23277	 0.000449	 0.026561	 0.0	 448.29	 448.29	 448.29	 1.00625	 0.0	 1	 -30.0	 30.0;
	23277	 23279	 0.000296	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23277	 23280	 0.000243	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 23281	 0.005879	 0.031616	 0.0216	 221.06	 221.06	 221.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23282	 23283	 0.00026	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23285	 23284	 9.8e-05	 0.006845	 0.0	 1509.05	 1509.05	 1509.05	 1.0	 0.0	 1	 -30.0	 30.0;
	23284	 23287	 9.8e-05	 0.007969	 0.0	 1234.29	 1234.29	 1234.29	 1.0	 0.0	 1	 -30.0	 30.0;
	23284	 23288	 0.000142	 0.01045	 0.0	 1230.89	 1230.89	 1230.89	 1.0	 0.0	 1	 -30.0	 30.0;
	23284	 23289	 0.000177	 0.014076	 0.0	 1230.32	 1230.32	 1230.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23284	 23290	 0.000119	 0.009065	 0.0	 1224.8	 1224.8	 1224.8	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23284	 0.000277	 0.007267	 3.68776	 4073.0	 4073.0	 4073.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23448	 23284	 0.000234	 0.006745	 3.84708	 4120.88	 4120.88	 4120.88	 0.0	 0.0	 1	 -30.0	 30.0;
	23284	 26048	 0.000388	 0.011257	 7.11674	 4223.31	 4223.31	 4223.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23286	 23285	 0.000646	 0.040447	 0.0	 388.39	 388.39	 388.39	 1.0	 0.0	 1	 -30.0	 30.0;
	23329	 23285	 0.002258	 0.025758	 0.4689	 1137.34	 1137.34	 1137.34	 0.0	 0.0	 1	 -30.0	 30.0;
	23285	 23365	 0.000606	 0.008546	 0.18442	 1289.73	 1289.73	 1289.73	 0.0	 0.0	 1	 -30.0	 30.0;
	23286	 23441	 0.00762	 0.041835	 0.02751	 247.17	 247.17	 247.17	 0.0	 0.0	 1	 -30.0	 30.0;
	23449	 23286	 9.8e-05	 0.000803	 0.0011	 233.76	 233.76	 233.76	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 23291	 0.000438	 0.026826	 0.0	 317.57	 317.57	 317.57	 1.0125	 0.0	 1	 -30.0	 30.0;
	23291	 23293	 0.000758	 0.038169	 0.0	 473.15	 473.15	 473.15	 1.0625	 0.0	 1	 -30.0	 30.0;
	23291	 23296	 0.000788	 0.05453	 0.0	 225.82	 225.82	 225.82	 1.04375	 0.0	 1	 -30.0	 30.0;
	23291	 23297	 0.00076	 0.05056	 0.0	 224.3	 224.3	 224.3	 1.04375	 0.0	 1	 -30.0	 30.0;
	23409	 23291	 0.000636	 0.007706	 0.32713	 1216.26	 1216.26	 1216.26	 0.0	 0.0	 1	 -30.0	 30.0;
	23291	 23429	 0.003424	 0.035823	 0.56502	 1155.84	 1155.84	 1155.84	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 23294	 0.033316	 0.815675	 0.0	 14.69	 14.69	 14.69	 1.0	 0.0	 1	 -30.0	 30.0;
	23292	 23295	 0.006839	 0.223898	 0.0	 40.54	 40.54	 40.54	 1.025	 0.0	 1	 -30.0	 30.0;
	23292	 23306	 0.004925	 0.033196	 0.00943	 246.31	 246.31	 246.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23292	 23328	 0.005776	 0.031962	 0.08433	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23298	 23299	 0.000223	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23299	 23332	 0.000863	 0.003889	 0.0044	 247.11	 247.11	 247.11	 0.0	 0.0	 1	 -30.0	 30.0;
	23385	 23299	 0.000859	 0.004267	 0.00389	 186.11	 186.11	 186.11	 0.0	 0.0	 1	 -30.0	 30.0;
	23301	 23300	 0.00071	 0.035316	 0.0	 341.05	 341.05	 341.05	 1.0	 0.0	 1	 -30.0	 30.0;
	23300	 23302	 0.000728	 0.032413	 0.0	 330.45	 330.45	 330.45	 1.0	 0.0	 1	 -30.0	 30.0;
	23300	 23303	 0.000625	 0.034098	 0.0	 323.18	 323.18	 323.18	 1.0	 0.0	 1	 -30.0	 30.0;
	23300	 23305	 0.000662	 0.035229	 0.0	 285.3	 285.3	 285.3	 1.0	 0.0	 1	 -30.0	 30.0;
	23429	 23300	 0.001415	 0.017763	 0.35513	 1206.57	 1206.57	 1206.57	 0.0	 0.0	 1	 -30.0	 30.0;
	23300	 26090	 0.000465	 0.005999	 0.33456	 1235.27	 1235.27	 1235.27	 0.0	 0.0	 1	 -30.0	 30.0;
	23301	 23304	 0.010024	 0.30618	 0.0	 36.63	 36.63	 36.63	 1.0375	 0.0	 1	 -30.0	 30.0;
	23311	 23306	 0.003018	 0.021365	 0.01437	 174.47	 174.47	 174.47	 0.0	 0.0	 1	 -30.0	 30.0;
	23307	 23308	 0.000251	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23437	 23308	 0.003906	 0.022902	 0.02462	 250.93	 250.93	 250.93	 0.0	 0.0	 1	 -30.0	 30.0;
	23308	 23483	 0.00272	 0.016933	 0.00889	 240.03	 240.03	 240.03	 0.0	 0.0	 1	 -30.0	 30.0;
	23310	 23309	 0.000438	 0.031028	 0.0	 495.4	 495.4	 495.4	 1.01875	 0.0	 1	 -30.0	 30.0;
	23309	 23443	 0.000552	 0.005653	 0.11687	 1147.08	 1147.08	 1147.08	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 23309	 0.00033	 0.004404	 0.05255	 1145.06	 1145.06	 1145.06	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23311	 0.002917	 0.012835	 0.02186	 225.32	 225.32	 225.32	 0.0	 0.0	 1	 -30.0	 30.0;
	23312	 23313	 0.003794	 0.112285	 0.0	 73.69	 73.69	 73.69	 1.0	 0.0	 1	 -30.0	 30.0;
	23312	 23314	 0.000205	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23315	 23316	 0.000284	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23315	 23317	 0.000271	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 23472	 0.001702	 0.012654	 0.00258	 213.47	 213.47	 213.47	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 25000	 0.010348	 0.052895	 0.05044	 216.23	 216.23	 216.23	 0.0	 0.0	 1	 -30.0	 30.0;
	23316	 25003	 0.018312	 0.115702	 0.06237	 213.22	 213.22	 213.22	 0.0	 0.0	 1	 -30.0	 30.0;
	23319	 23483	 0.004238	 0.021784	 0.00578	 172.76	 172.76	 172.76	 0.0	 0.0	 1	 -30.0	 30.0;
	23320	 23323	 -0.000323	 -0.009868	 0.0	 204.65	 204.65	 204.65	 0.99375	 0.0	 1	 -30.0	 30.0;
	23320	 23324	 0.008865	 0.21804	 0.0	 42.31	 42.31	 42.31	 0.99375	 0.0	 1	 -30.0	 30.0;
	23320	 23325	 0.011097	 0.369454	 0.0	 42.1	 42.1	 42.1	 0.99375	 0.0	 1	 -30.0	 30.0;
	23320	 23326	 0.007532	 0.226485	 0.0	 41.97	 41.97	 41.97	 0.99375	 0.0	 1	 -30.0	 30.0;
	23320	 23327	 0.000226	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23320	 23328	 0.000231	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23321	 23323	 0.003966	 0.12113	 0.0	 102.32	 102.32	 102.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23322	 23323	 0.003966	 0.12113	 0.0	 102.32	 102.32	 102.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23328	 23468	 0.001415	 0.009199	 0.01553	 196.21	 196.21	 196.21	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 23329	 0.000663	 0.045467	 0.0	 401.56	 401.56	 401.56	 1.0	 0.0	 1	 -30.0	 30.0;
	23329	 25009	 0.001886	 0.023621	 0.40814	 1168.91	 1168.91	 1168.91	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 23405	 0.000449	 0.002158	 0.00039	 214.34	 214.34	 214.34	 0.0	 0.0	 1	 -30.0	 30.0;
	23330	 23472	 0.004365	 0.026474	 0.13008	 250.68	 250.68	 250.68	 0.0	 0.0	 1	 -30.0	 30.0;
	23332	 23331	 9.2e-05	 0.006757	 0.0	 374.12	 374.12	 374.12	 1.0	 0.0	 1	 -30.0	 30.0;
	23331	 23333	 0.000383	 0.024218	 0.0	 372.06	 372.06	 372.06	 1.0	 0.0	 1	 -30.0	 30.0;
	23331	 23334	 0.00079	 0.044101	 0.0	 306.13	 306.13	 306.13	 1.0	 0.0	 1	 -30.0	 30.0;
	23331	 23335	 0.000229	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23332	 25819	 0.017262	 0.092313	 0.04702	 201.4	 201.4	 201.4	 0.0	 0.0	 1	 -30.0	 30.0;
	23335	 28718	 0.002069	 0.023441	 1.37238	 1108.97	 1108.97	 1108.97	 0.0	 0.0	 1	 -30.0	 30.0;
	28814	 23335	 0.001304	 0.016864	 0.32656	 1034.52	 1034.52	 1034.52	 0.0	 0.0	 1	 -30.0	 30.0;
	23336	 23337	 0.004307	 0.149828	 0.0	 71.49	 71.49	 71.49	 0.99375	 0.0	 1	 -30.0	 30.0;
	23363	 23336	 0.004908	 0.027673	 0.00701	 163.57	 163.57	 163.57	 0.0	 0.0	 1	 -30.0	 30.0;
	23339	 23338	 0.000517	 0.027106	 0.0	 320.5	 320.5	 320.5	 1.0	 0.0	 1	 -30.0	 30.0;
	23338	 23500	 0.001386	 0.015184	 0.34351	 1059.9	 1059.9	 1059.9	 0.0	 0.0	 1	 -30.0	 30.0;
	23339	 23347	 0.001136	 0.006496	 0.00335	 182.31	 182.31	 182.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23340	 23343	 0.00085	 0.039483	 0.0	 595.2	 595.2	 595.2	 1.0	 0.0	 1	 -30.0	 30.0;
	23340	 23344	 0.000203	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23341	 23343	 -0.000294	 -0.013662	 0.0	 459.03	 459.03	 459.03	 1.0	 0.0	 1	 -30.0	 30.0;
	23341	 23421	 0.000194	 0.001079	 0.00033	 248.52	 248.52	 248.52	 0.0	 0.0	 1	 -30.0	 30.0;
	23342	 23343	 0.002718	 0.12621	 0.0	 136.17	 136.17	 136.17	 1.0	 0.0	 1	 -30.0	 30.0;
	23389	 23344	 0.000599	 0.007822	 0.24018	 1115.0	 1115.0	 1115.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23346	 23345	 0.000511	 0.032361	 0.0	 400.86	 400.86	 400.86	 1.0	 0.0	 1	 -30.0	 30.0;
	23345	 23436	 0.000764	 0.008505	 0.19266	 1254.87	 1254.87	 1254.87	 0.0	 0.0	 1	 -30.0	 30.0;
	23348	 23349	 0.000203	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23350	 23351	 0.0029	 0.075823	 0.0	 89.34	 89.34	 89.34	 1.0375	 0.0	 1	 -30.0	 30.0;
	23350	 23352	 0.004671	 0.144989	 0.0	 57.11	 57.11	 57.11	 1.0375	 0.0	 1	 -30.0	 30.0;
	23350	 23444	 0.000255	 0.001867	 0.00171	 239.25	 239.25	 239.25	 0.0	 0.0	 1	 -30.0	 30.0;
	23373	 23353	 0.000739	 0.004492	 0.00446	 266.15	 266.15	 266.15	 0.0	 0.0	 1	 -30.0	 30.0;
	23353	 23494	 0.001092	 0.005184	 0.0016	 262.98	 262.98	 262.98	 0.0	 0.0	 1	 -30.0	 30.0;
	23354	 23357	 0.000929	 0.050227	 0.0	 512.53	 512.53	 512.53	 1.0	 0.0	 1	 -30.0	 30.0;
	23354	 23358	 0.000292	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23355	 23357	 -0.000386	 -0.020875	 0.0	 391.61	 391.61	 391.61	 1.0	 0.0	 1	 -30.0	 30.0;
	23356	 23357	 0.003068	 0.165932	 0.0	 120.92	 120.92	 120.92	 1.0	 0.0	 1	 -30.0	 30.0;
	23359	 23360	 0.020318	 0.475259	 0.0	 35.38	 35.38	 35.38	 1.0	 0.0	 1	 -30.0	 30.0;
	23359	 23361	 0.010789	 0.300011	 0.0	 35.18	 35.18	 35.18	 1.0	 0.0	 1	 -30.0	 30.0;
	23359	 23362	 0.000208	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23363	 23364	 0.000206	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23363	 23414	 0.024148	 0.108436	 0.06757	 212.5	 212.5	 212.5	 0.0	 0.0	 1	 -30.0	 30.0;
	23366	 23365	 0.000582	 0.028387	 0.0	 429.44	 429.44	 429.44	 1.00625	 0.0	 1	 -30.0	 30.0;
	23366	 23369	 -0.000471	 -0.014137	 0.0	 196.04	 196.04	 196.04	 1.0	 0.0	 1	 -30.0	 30.0;
	23366	 23398	 0.002691	 0.020608	 0.03279	 194.56	 194.56	 194.56	 0.0	 0.0	 1	 -30.0	 30.0;
	23367	 23369	 0.006317	 0.189464	 0.0	 98.02	 98.02	 98.02	 1.0	 0.0	 1	 -30.0	 30.0;
	23368	 23369	 0.006317	 0.189464	 0.0	 98.02	 98.02	 98.02	 1.0	 0.0	 1	 -30.0	 30.0;
	23370	 23371	 0.000201	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23372	 23373	 0.000293	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23468	 23373	 0.000101	 0.000525	 0.00039	 154.85	 154.85	 154.85	 0.0	 0.0	 1	 -30.0	 30.0;
	23375	 23374	 8e-05	 0.00646	 0.0	 1582.33	 1582.33	 1582.33	 1.00625	 0.0	 1	 -30.0	 30.0;
	23374	 23377	 6.5e-05	 0.004937	 0.0	 1803.44	 1803.44	 1803.44	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23378	 8.8e-05	 0.00652	 0.0	 1802.12	 1802.12	 1802.12	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23379	 8e-05	 0.006358	 0.0	 1579.0	 1579.0	 1579.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23380	 6.2e-05	 0.004891	 0.0	 1575.67	 1575.67	 1575.67	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23381	 0.000144	 0.011308	 0.0	 1575.31	 1575.31	 1575.31	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23382	 0.00012	 0.009674	 0.0	 1571.96	 1571.96	 1571.96	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23383	 8.2e-05	 0.00733	 0.0	 1569.86	 1569.86	 1569.86	 1.0	 0.0	 1	 -30.0	 30.0;
	23374	 23384	 0.000131	 0.010429	 0.0	 1566.56	 1566.56	 1566.56	 1.0	 0.0	 1	 -30.0	 30.0;
	23376	 23375	 0.000456	 0.027676	 0.0	 548.63	 548.63	 548.63	 1.01875	 0.0	 1	 -30.0	 30.0;
	23385	 25764	 0.021126	 0.128112	 0.18863	 226.07	 226.07	 226.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25819	 23385	 0.009125	 0.064072	 0.04701	 205.69	 205.69	 205.69	 0.0	 0.0	 1	 -30.0	 30.0;
	23385	 25820	 0.022231	 0.111161	 0.04672	 208.28	 208.28	 208.28	 0.0	 0.0	 1	 -30.0	 30.0;
	23386	 23387	 0.000261	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23386	 23388	 0.000245	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23387	 23449	 0.000169	 0.000872	 0.00081	 221.31	 221.31	 221.31	 0.0	 0.0	 1	 -30.0	 30.0;
	23387	 23499	 0.000182	 0.00132	 0.00042	 222.28	 222.28	 222.28	 0.0	 0.0	 1	 -30.0	 30.0;
	23390	 23389	 0.000538	 0.033731	 0.0	 465.04	 465.04	 465.04	 1.0	 0.0	 1	 -30.0	 30.0;
	23432	 23389	 0.000501	 0.006696	 0.1006	 1240.98	 1240.98	 1240.98	 0.0	 0.0	 1	 -30.0	 30.0;
	23392	 23391	 0.0006	 0.032677	 0.0	 305.29	 305.29	 305.29	 1.00625	 0.0	 1	 -30.0	 30.0;
	23391	 23393	 0.000539	 0.031248	 0.0	 319.18	 319.18	 319.18	 1.0	 0.0	 1	 -30.0	 30.0;
	23391	 23394	 0.000211	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23394	 23493	 0.001716	 0.021603	 0.72471	 995.43	 995.43	 995.43	 0.0	 0.0	 1	 -30.0	 30.0;
	23395	 23396	 0.004575	 0.146579	 0.0	 92.92	 92.92	 92.92	 1.0	 0.0	 1	 -30.0	 30.0;
	23395	 23397	 0.000265	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23397	 28760	 0.012245	 0.08142	 0.02193	 229.01	 229.01	 229.01	 0.0	 0.0	 1	 -30.0	 30.0;
	30159	 23397	 0.006113	 0.037785	 0.03731	 214.18	 214.18	 214.18	 0.0	 0.0	 1	 -30.0	 30.0;
	23398	 23399	 0.005896	 0.185374	 0.0	 63.84	 63.84	 63.84	 1.0	 0.0	 1	 -30.0	 30.0;
	23398	 23400	 0.010634	 0.252993	 0.0	 62.99	 62.99	 62.99	 1.0	 0.0	 1	 -30.0	 30.0;
	23398	 23401	 0.004315	 0.168513	 0.0	 62.53	 62.53	 62.53	 1.0	 0.0	 1	 -30.0	 30.0;
	23402	 23403	 0.003393	 0.118308	 0.0	 80.1	 80.1	 80.1	 1.0375	 0.0	 1	 -30.0	 30.0;
	23402	 23404	 0.000214	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23407	 23406	 0.000217	 0.012419	 0.0	 542.84	 542.84	 542.84	 1.0	 0.0	 1	 -30.0	 30.0;
	23406	 23408	 0.000251	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23410	 23409	 0.000485	 0.025626	 0.0	 325.35	 325.35	 325.35	 1.0	 0.0	 1	 -30.0	 30.0;
	23409	 23411	 0.000272	 0.020153	 0.0	 520.9	 520.9	 520.9	 1.00625	 0.0	 1	 -30.0	 30.0;
	23409	 23493	 0.000292	 0.003665	 0.08519	 1085.99	 1085.99	 1085.99	 0.0	 0.0	 1	 -30.0	 30.0;
	23410	 23468	 0.001772	 0.010113	 0.02068	 211.64	 211.64	 211.64	 0.0	 0.0	 1	 -30.0	 30.0;
	23412	 23416	 6e-06	 0.000596	 0.0	 1467.05	 1467.05	 1467.05	 1.0	 0.0	 1	 -30.0	 30.0;
	23412	 23417	 9.6e-05	 0.008311	 0.0	 1713.95	 1713.95	 1713.95	 0.99375	 0.0	 1	 -30.0	 30.0;
	23412	 23418	 0.000141	 0.011058	 0.0	 1711.24	 1711.24	 1711.24	 0.99375	 0.0	 1	 -30.0	 30.0;
	23412	 23419	 7.2e-05	 0.004946	 0.0	 1711.04	 1711.04	 1711.04	 0.99375	 0.0	 1	 -30.0	 30.0;
	23412	 23420	 0.000283	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23412	 23420	 0.000283	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23414	 23413	 0.000629	 0.036015	 0.0	 379.75	 379.75	 379.75	 1.0	 0.0	 1	 -30.0	 30.0;
	23413	 23416	 8e-05	 0.007696	 0.0	 1417.05	 1417.05	 1417.05	 1.0	 0.0	 1	 -30.0	 30.0;
	23488	 23413	 0.000515	 0.006118	 0.12072	 1204.02	 1204.02	 1204.02	 0.0	 0.0	 1	 -30.0	 30.0;
	23415	 23416	 0.000404	 0.038942	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25864	 23420	 0.000535	 0.016047	 7.23715	 4210.01	 4210.01	 4210.01	 0.0	 0.0	 1	 -30.0	 30.0;
	23420	 30387	 0.000698	 0.019555	 8.67547	 4062.01	 4062.01	 4062.01	 0.0	 0.0	 1	 -30.0	 30.0;
	23423	 23424	 0.000244	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23425	 23428	 0.001316	 0.082369	 0.0	 401.46	 401.46	 401.46	 1.0	 0.0	 1	 -30.0	 30.0;
	23425	 23429	 0.000224	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23425	 23430	 0.000202	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23426	 23428	 -0.000613	 -0.038368	 0.0	 376.46	 376.46	 376.46	 1.0	 0.0	 1	 -30.0	 30.0;
	23427	 23428	 0.003523	 0.220494	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23432	 23431	 0.000101	 0.007556	 0.0	 1568.5	 1568.5	 1568.5	 1.0125	 0.0	 1	 -30.0	 30.0;
	23431	 23434	 9.3e-05	 0.006709	 0.0	 1436.7	 1436.7	 1436.7	 1.0	 0.0	 1	 -30.0	 30.0;
	23431	 23435	 0.000126	 0.009872	 0.0	 1214.3	 1214.3	 1214.3	 1.0	 0.0	 1	 -30.0	 30.0;
	23433	 23432	 0.000414	 0.026441	 0.0	 504.56	 504.56	 504.56	 1.025	 0.0	 1	 -30.0	 30.0;
	23437	 23436	 0.000458	 0.030187	 0.0	 417.9	 417.9	 417.9	 1.0	 0.0	 1	 -30.0	 30.0;
	23488	 23436	 0.000515	 0.005578	 0.20369	 1281.3	 1281.3	 1281.3	 0.0	 0.0	 1	 -30.0	 30.0;
	23438	 23439	 0.000223	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23438	 23440	 0.000254	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23443	 23442	 0.000142	 0.010497	 0.0	 1429.53	 1429.53	 1429.53	 1.0	 0.0	 1	 -30.0	 30.0;
	23442	 23445	 0.000103	 0.008336	 0.0	 1195.24	 1195.24	 1195.24	 1.0375	 0.0	 1	 -30.0	 30.0;
	23442	 23446	 0.000167	 0.013961	 0.0	 1193.76	 1193.76	 1193.76	 1.04375	 0.0	 1	 -30.0	 30.0;
	23442	 23447	 0.000102	 0.009602	 0.0	 1192.71	 1192.71	 1192.71	 1.04375	 0.0	 1	 -30.0	 30.0;
	23442	 23448	 0.000237	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23444	 23443	 0.000407	 0.026947	 0.0	 490.01	 490.01	 490.01	 1.0	 0.0	 1	 -30.0	 30.0;
	23448	 23457	 0.000155	 0.004244	 2.06243	 4114.33	 4114.33	 4114.33	 0.0	 0.0	 1	 -30.0	 30.0;
	23449	 23499	 0.000235	 0.001386	 0.00045	 237.56	 237.56	 237.56	 0.0	 0.0	 1	 -30.0	 30.0;
	23451	 23450	 0.000119	 0.009356	 0.0	 1455.05	 1455.05	 1455.05	 1.0	 0.0	 1	 -30.0	 30.0;
	23450	 23453	 0.000118	 0.00902	 0.0	 1358.87	 1358.87	 1358.87	 1.0	 0.0	 1	 -30.0	 30.0;
	23450	 23454	 0.000128	 0.009952	 0.0	 1357.49	 1357.49	 1357.49	 1.0	 0.0	 1	 -30.0	 30.0;
	23450	 23455	 0.000244	 0.017266	 0.0	 825.18	 825.18	 825.18	 1.0	 0.0	 1	 -30.0	 30.0;
	23450	 23457	 0.000208	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23452	 23451	 0.000456	 0.027939	 0.0	 405.16	 405.16	 405.16	 1.0	 0.0	 1	 -30.0	 30.0;
	23451	 23456	 0.000748	 0.051336	 0.0	 270.55	 270.55	 270.55	 1.0	 0.0	 1	 -30.0	 30.0;
	23500	 23451	 0.000687	 0.008889	 0.19333	 1241.0	 1241.0	 1241.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23458	 23461	 -0.000349	 -0.011451	 0.0	 205.7	 205.7	 205.7	 1.01875	 0.0	 1	 -30.0	 30.0;
	23458	 23464	 -0.000436	 -0.014901	 0.0	 205.21	 205.21	 205.21	 1.01875	 0.0	 1	 -30.0	 30.0;
	23458	 23467	 -0.000306	 -0.011656	 0.0	 102.63	 102.63	 102.63	 1.0	 0.0	 1	 -30.0	 30.0;
	23458	 23468	 0.000256	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23459	 23461	 0.005402	 0.177034	 0.0	 102.85	 102.85	 102.85	 1.0	 0.0	 1	 -30.0	 30.0;
	23460	 23461	 0.005402	 0.177034	 0.0	 102.85	 102.85	 102.85	 1.0	 0.0	 1	 -30.0	 30.0;
	23462	 23464	 0.005151	 0.17622	 0.0	 102.61	 102.61	 102.61	 1.0	 0.0	 1	 -30.0	 30.0;
	23463	 23464	 0.005151	 0.17622	 0.0	 102.61	 102.61	 102.61	 1.0	 0.0	 1	 -30.0	 30.0;
	23465	 23467	 0.004005	 0.152776	 0.0	 51.32	 51.32	 51.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23466	 23467	 0.004005	 0.152776	 0.0	 51.32	 51.32	 51.32	 1.0	 0.0	 1	 -30.0	 30.0;
	23469	 23501	 0.003142	 0.020697	 0.0468	 257.38	 257.38	 257.38	 0.0	 0.0	 1	 -30.0	 30.0;
	23470	 23471	 0.003679	 0.092559	 0.0	 72.95	 72.95	 72.95	 1.0	 0.0	 1	 -30.0	 30.0;
	23470	 23472	 0.000225	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 25001	 0.01625	 0.083654	 0.11265	 224.97	 224.97	 224.97	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 25008	 0.016344	 0.089444	 0.02667	 204.96	 204.96	 204.96	 0.0	 0.0	 1	 -30.0	 30.0;
	23472	 25027	 0.047387	 0.253997	 0.15493	 217.35	 217.35	 217.35	 0.0	 0.0	 1	 -30.0	 30.0;
	23473	 23476	 0.000739	 0.045079	 0.0	 605.34	 605.34	 605.34	 1.0	 0.0	 1	 -30.0	 30.0;
	23473	 23477	 0.000733	 0.043813	 0.0	 331.5	 331.5	 331.5	 1.03125	 0.0	 1	 -30.0	 30.0;
	23473	 23478	 0.000446	 0.028385	 0.0	 413.19	 413.19	 413.19	 1.0375	 0.0	 1	 -30.0	 30.0;
	23473	 23479	 0.001034	 0.055348	 0.0	 271.88	 271.88	 271.88	 1.025	 0.0	 1	 -30.0	 30.0;
	23474	 23476	 -0.000178	 -0.010844	 0.0	 480.34	 480.34	 480.34	 1.0	 0.0	 1	 -30.0	 30.0;
	23474	 23480	 0.024365	 0.66884	 0.0	 22.04	 22.04	 22.04	 1.0	 0.0	 1	 -30.0	 30.0;
	23474	 23481	 0.021033	 0.59123	 0.0	 21.84	 21.84	 21.84	 1.0	 0.0	 1	 -30.0	 30.0;
	23475	 23476	 0.002558	 0.156011	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23483	 23482	 0.000554	 0.027981	 0.0	 401.36	 401.36	 401.36	 1.0	 0.0	 1	 -30.0	 30.0;
	23482	 23486	 0.0001	 0.001191	 0.0	 998.22	 998.22	 998.22	 1.0	 0.0	 1	 -30.0	 30.0;
	23482	 23488	 0.000271	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23483	 23487	 0.003527	 0.098726	 0.0	 85.66	 85.66	 85.66	 1.0	 0.0	 1	 -30.0	 30.0;
	23484	 23486	 0.000313	 0.019088	 0.0	 499.11	 499.11	 499.11	 1.0	 0.0	 1	 -30.0	 30.0;
	23485	 23486	 0.000313	 0.019088	 0.0	 499.11	 499.11	 499.11	 1.0	 0.0	 1	 -30.0	 30.0;
	23488	 23493	 0.000908	 0.01081	 0.45483	 1128.85	 1128.85	 1128.85	 0.0	 0.0	 1	 -30.0	 30.0;
	23489	 23492	 -0.000217	 -0.006639	 0.0	 225.84	 225.84	 225.84	 1.075	 0.0	 1	 -30.0	 30.0;
	23489	 30017	 0.010629	 0.064059	 0.22507	 208.69	 208.69	 208.69	 0.0	 0.0	 1	 -30.0	 30.0;
	23490	 23492	 0.003662	 0.112198	 0.0	 112.92	 112.92	 112.92	 1.0	 0.0	 1	 -30.0	 30.0;
	23491	 23492	 0.003662	 0.112198	 0.0	 112.92	 112.92	 112.92	 1.0	 0.0	 1	 -30.0	 30.0;
	23494	 23493	 0.000357	 0.021273	 0.0	 299.82	 299.82	 299.82	 1.00625	 0.0	 1	 -30.0	 30.0;
	23495	 23496	 0.000298	 0.001147	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23495	 23497	 0.000237	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23495	 23498	 0.00023	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23501	 23500	 0.00061	 0.031641	 0.0	 426.51	 426.51	 426.51	 1.0	 0.0	 1	 -30.0	 30.0;
	23500	 23504	 0.0001	 -0.000744	 0.0	 1011.97	 1011.97	 1011.97	 1.0	 0.0	 1	 -30.0	 30.0;
	23502	 23504	 0.000389	 0.029121	 0.0	 505.98	 505.98	 505.98	 1.0	 0.0	 1	 -30.0	 30.0;
	23503	 23504	 0.000389	 0.029121	 0.0	 505.98	 505.98	 505.98	 1.0	 0.0	 1	 -30.0	 30.0;
	23505	 23509	 0.000301	 0.020874	 0.0	 1462.93	 1462.93	 1462.93	 1.0	 0.0	 1	 -30.0	 30.0;
	23505	 23510	 9.2e-05	 0.007777	 0.0	 1550.31	 1550.31	 1550.31	 1.0	 0.0	 1	 -30.0	 30.0;
	23505	 23511	 0.000138	 0.010948	 0.0	 1547.96	 1547.96	 1547.96	 1.0	 0.0	 1	 -30.0	 30.0;
	23505	 23512	 8.6e-05	 0.007227	 0.0	 1547.92	 1547.92	 1547.92	 1.0	 0.0	 1	 -30.0	 30.0;
	23505	 23513	 0.00015	 0.013825	 0.0	 772.06	 772.06	 772.06	 1.0	 0.0	 1	 -30.0	 30.0;
	23505	 23514	 0.000241	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23505	 23515	 0.000269	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23507	 23506	 0.000391	 0.026613	 0.0	 395.47	 395.47	 395.47	 1.00625	 0.0	 1	 -30.0	 30.0;
	23506	 23509	 -0.000173	 -0.011996	 0.0	 1437.93	 1437.93	 1437.93	 1.0	 0.0	 1	 -30.0	 30.0;
	23506	 28759	 0.000396	 0.0055	 0.11628	 1121.54	 1121.54	 1121.54	 0.0	 0.0	 1	 -30.0	 30.0;
	23506	 30125	 0.001302	 0.01619	 0.35147	 1136.11	 1136.11	 1136.11	 0.0	 0.0	 1	 -30.0	 30.0;
	23507	 28645	 0.067651	 0.430675	 0.09614	 222.13	 222.13	 222.13	 0.0	 0.0	 1	 -30.0	 30.0;
	23507	 28716	 0.04464	 0.280664	 0.07514	 201.52	 201.52	 201.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28891	 23507	 0.004495	 0.027292	 0.02226	 225.0	 225.0	 225.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23507	 30180	 0.008757	 0.057501	 0.0706	 253.42	 253.42	 253.42	 0.0	 0.0	 1	 -30.0	 30.0;
	23508	 23509	 0.000682	 0.047374	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	23514	 28758	 3.5e-05	 0.001012	 0.45173	 4085.13	 4085.13	 4085.13	 0.0	 0.0	 1	 -30.0	 30.0;
	23514	 30399	 0.000156	 0.004221	 1.80982	 4036.16	 4036.16	 4036.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25000	 25007	 0.011491	 0.077831	 0.05899	 197.21	 197.21	 197.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25001	 25002	 0.004605	 0.023609	 0.01009	 178.2	 178.2	 178.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25002	 25003	 0.002257	 0.012251	 0.08891	 190.76	 190.76	 190.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25015	 25003	 0.002688	 0.012173	 0.00524	 171.75	 171.75	 171.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25005	 25004	 0.00043	 0.031793	 0.0	 423.48	 423.48	 423.48	 1.00625	 0.0	 1	 -30.0	 30.0;
	25004	 25009	 0.001352	 0.014748	 0.32863	 1100.79	 1100.79	 1100.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25030	 25004	 0.000922	 0.011293	 0.66266	 1189.55	 1189.55	 1189.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25004	 26136	 0.000639	 0.007461	 0.11658	 1216.57	 1216.57	 1216.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25016	 25005	 0.003551	 0.021523	 0.00916	 209.34	 209.34	 209.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25005	 25024	 0.006239	 0.032776	 0.0205	 226.22	 226.22	 226.22	 0.0	 0.0	 1	 -30.0	 30.0;
	25006	 25007	 0.000291	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25026	 25007	 0.003574	 0.017277	 0.02719	 212.63	 212.63	 212.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25007	 26132	 0.00624	 0.035835	 0.00697	 223.2	 223.2	 223.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25010	 25008	 0.004647	 0.025317	 0.01036	 201.76	 201.76	 201.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25009	 25012	 0.000942	 0.060446	 0.0	 479.1	 479.1	 479.1	 1.0	 0.0	 1	 -30.0	 30.0;
	25010	 25012	 -0.00045	 -0.028846	 0.0	 404.1	 404.1	 404.1	 1.0	 0.0	 1	 -30.0	 30.0;
	25010	 25015	 0.010434	 0.058709	 0.0355	 212.94	 212.94	 212.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25011	 25012	 0.003032	 0.194537	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25013	 25014	 0.000258	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25013	 25015	 0.000202	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25016	 25017	 0.00028	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25026	 25016	 0.004561	 0.028262	 0.02689	 164.75	 164.75	 164.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25018	 25026	 0.004371	 0.018958	 0.00731	 219.67	 219.67	 219.67	 0.0	 0.0	 1	 -30.0	 30.0;
	26132	 25018	 0.005169	 0.02592	 0.01596	 228.79	 228.79	 228.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25019	 25022	 -0.000641	 -0.019459	 0.0	 102.15	 102.15	 102.15	 1.0	 0.0	 1	 -30.0	 30.0;
	25019	 25023	 0.000234	 0.001127	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25019	 25026	 0.007184	 0.031468	 0.02065	 226.54	 226.54	 226.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25037	 25019	 0.003029	 0.017676	 0.00802	 211.69	 211.69	 211.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25020	 25022	 0.009856	 0.299402	 0.0	 51.07	 51.07	 51.07	 1.0	 0.0	 1	 -30.0	 30.0;
	25021	 25022	 0.009856	 0.299402	 0.0	 51.07	 51.07	 51.07	 1.0	 0.0	 1	 -30.0	 30.0;
	25024	 25025	 0.000296	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25037	 25024	 0.007168	 0.043217	 0.02816	 209.16	 209.16	 209.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 25027	 0.005419	 0.035291	 0.01422	 160.44	 160.44	 160.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25027	 25046	 0.032341	 0.113088	 0.06004	 198.19	 198.19	 198.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 25029	 0.000237	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 25032	 0.007378	 0.035597	 0.02317	 195.69	 195.69	 195.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25028	 25045	 0.007811	 0.047305	 0.03541	 200.16	 200.16	 200.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 25030	 0.000511	 0.031891	 0.0	 461.63	 461.63	 461.63	 1.0125	 0.0	 1	 -30.0	 30.0;
	25048	 25030	 0.001255	 0.016352	 0.33495	 1293.11	 1293.11	 1293.11	 0.0	 0.0	 1	 -30.0	 30.0;
	26136	 25030	 0.00121	 0.013227	 0.48008	 1268.43	 1268.43	 1268.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25038	 25031	 0.003147	 0.013619	 0.00452	 235.1	 235.1	 235.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25031	 25039	 0.006055	 0.031996	 0.01024	 219.91	 219.91	 219.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 25033	 0.000242	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25032	 26132	 0.020442	 0.078708	 0.03769	 236.73	 236.73	 236.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25037	 25034	 0.008432	 0.049937	 0.01833	 205.45	 205.45	 205.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25034	 26144	 0.010083	 0.051675	 0.08612	 226.62	 226.62	 226.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25035	 25036	 0.000214	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25035	 25037	 0.000229	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25037	 25043	 0.006554	 0.040835	 0.29361	 231.86	 231.86	 231.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25040	 25038	 0.00553	 0.039154	 0.02305	 210.25	 210.25	 210.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25044	 25039	 0.007632	 0.035931	 0.02053	 178.36	 178.36	 178.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25040	 25041	 0.000232	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25040	 25043	 0.005807	 0.02855	 0.04234	 197.2	 197.2	 197.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25042	 25043	 0.000229	 0.001128	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25047	 25044	 0.009212	 0.046151	 0.04878	 212.97	 212.97	 212.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25044	 26168	 0.010178	 0.05598	 0.16902	 229.24	 229.24	 229.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25045	 25998	 0.011112	 0.059056	 0.14892	 224.33	 224.33	 224.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25047	 25046	 0.011333	 0.048989	 0.02179	 191.16	 191.16	 191.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25049	 25046	 0.005017	 0.026985	 0.02255	 173.6	 173.6	 173.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25055	 25047	 0.013611	 0.068803	 0.03673	 202.64	 202.64	 202.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25048	 25051	 0.000467	 0.030182	 0.0	 445.09	 445.09	 445.09	 1.0	 0.0	 1	 -30.0	 30.0;
	25048	 25059	 0.000979	 0.010445	 0.27427	 1233.41	 1233.41	 1233.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25049	 25051	 -3.1e-05	 -0.001971	 0.0	 395.09	 395.09	 395.09	 1.0	 0.0	 1	 -30.0	 30.0;
	25052	 25049	 0.001877	 0.009227	 0.01268	 205.97	 205.97	 205.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25050	 25051	 0.002585	 0.166888	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25983	 25052	 0.003362	 0.01961	 0.00607	 201.65	 201.65	 201.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25053	 25054	 0.000261	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25057	 25053	 0.00129	 0.005966	 0.0101	 220.23	 220.23	 220.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25053	 25058	 0.006586	 0.032104	 0.08427	 245.92	 245.92	 245.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25063	 25053	 0.006464	 0.024453	 0.05559	 248.98	 248.98	 248.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25053	 25115	 0.003839	 0.023917	 0.09655	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25056	 25882	 0.008878	 0.048999	 0.01977	 163.13	 163.13	 163.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25056	 25983	 0.011407	 0.067658	 0.03898	 207.67	 207.67	 207.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25065	 25057	 0.001061	 0.005509	 0.00811	 197.23	 197.23	 197.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25058	 25060	 0.002926	 0.014911	 0.0027	 262.76	 262.76	 262.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25059	 25062	 0.000125	 0.007616	 0.0	 615.8	 615.8	 615.8	 1.0	 0.0	 1	 -30.0	 30.0;
	25064	 25059	 0.000989	 0.011127	 0.30915	 1247.55	 1247.55	 1247.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25848	 25059	 0.003712	 0.034352	 0.78203	 1229.56	 1229.56	 1229.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25060	 25062	 2e-05	 0.001248	 0.0	 515.8	 515.8	 515.8	 1.0	 0.0	 1	 -30.0	 30.0;
	25060	 25063	 0.003015	 0.018123	 0.00613	 264.3	 264.3	 264.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25882	 25060	 0.003239	 0.01885	 0.02793	 226.48	 226.48	 226.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25061	 25062	 0.000678	 0.041306	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25065	 25064	 0.000742	 0.04059	 0.0	 411.93	 411.93	 411.93	 1.025	 0.0	 1	 -30.0	 30.0;
	25064	 26005	 0.000659	 0.008548	 0.24039	 1172.93	 1172.93	 1172.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25065	 25073	 0.004232	 0.02108	 0.02844	 200.75	 200.75	 200.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25065	 25074	 0.005655	 0.027534	 0.01804	 245.1	 245.1	 245.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25066	 25067	 0.000268	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25066	 25069	 0.00668	 0.034472	 0.0088	 221.06	 221.06	 221.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25066	 25127	 0.008412	 0.048515	 0.08908	 203.3	 203.3	 203.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25068	 25069	 0.000241	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25068	 25070	 0.000263	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25913	 25069	 0.010874	 0.070781	 0.01638	 234.14	 234.14	 234.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25071	 25072	 0.000284	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25072	 26162	 0.007674	 0.047927	 0.0138	 199.03	 199.03	 199.03	 0.0	 0.0	 1	 -30.0	 30.0;
	26185	 25072	 0.002593	 0.018423	 0.00524	 191.2	 191.2	 191.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25079	 25073	 0.00467	 0.030916	 0.02659	 227.03	 227.03	 227.03	 0.0	 0.0	 1	 -30.0	 30.0;
	25074	 25075	 0.00027	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25084	 25074	 0.001938	 0.011102	 0.01997	 241.08	 241.08	 241.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25076	 25077	 0.00021	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25088	 25076	 0.008135	 0.046525	 0.01149	 155.0	 155.0	 155.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25076	 25959	 0.007334	 0.034435	 0.02439	 177.57	 177.57	 177.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25111	 25078	 0.006791	 0.032088	 0.01497	 196.7	 196.7	 196.7	 0.0	 0.0	 1	 -30.0	 30.0;
	26154	 25078	 0.008451	 0.041555	 0.02319	 226.57	 226.57	 226.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25079	 26072	 0.019348	 0.119882	 0.04352	 231.48	 231.48	 231.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25089	 25080	 0.001817	 0.010318	 0.00442	 214.19	 214.19	 214.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25107	 25080	 0.002159	 0.013597	 0.0126	 229.93	 229.93	 229.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25080	 25841	 0.001384	 0.008631	 0.00605	 222.88	 222.88	 222.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25081	 25082	 0.000275	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25081	 25083	 0.000246	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 25083	 0.001339	 0.005911	 0.00522	 234.7	 234.7	 234.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25083	 25114	 0.004696	 0.022677	 0.01245	 207.83	 207.83	 207.83	 0.0	 0.0	 1	 -30.0	 30.0;
	25114	 25084	 0.002372	 0.014273	 0.01065	 217.39	 217.39	 217.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25085	 25086	 0.000212	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26091	 25086	 0.008176	 0.041017	 0.02071	 234.73	 234.73	 234.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25087	 25943	 0.00786	 0.033375	 0.01698	 198.67	 198.67	 198.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25088	 26091	 0.007019	 0.034404	 0.00841	 203.48	 203.48	 203.48	 0.0	 0.0	 1	 -30.0	 30.0;
	26037	 25089	 0.001183	 0.006775	 0.00675	 235.72	 235.72	 235.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25099	 25090	 0.000785	 0.003983	 0.00516	 234.85	 234.85	 234.85	 0.0	 0.0	 1	 -30.0	 30.0;
	25090	 25116	 0.0072	 0.041222	 0.01393	 214.5	 214.5	 214.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25092	 0.000208	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25123	 0.004114	 0.028845	 0.0062	 208.73	 208.73	 208.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25918	 0.005479	 0.030281	 0.01286	 211.69	 211.69	 211.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25091	 25959	 0.00761	 0.041873	 0.12961	 246.24	 246.24	 246.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25093	 25094	 0.000276	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25093	 25095	 0.000208	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25143	 25094	 0.00459	 0.027964	 0.02617	 213.03	 213.03	 213.03	 0.0	 0.0	 1	 -30.0	 30.0;
	25094	 26218	 0.007064	 0.045684	 0.07857	 233.87	 233.87	 233.87	 0.0	 0.0	 1	 -30.0	 30.0;
	25096	 25107	 0.001713	 0.009051	 0.00833	 190.9	 190.9	 190.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25096	 25157	 0.004117	 0.024513	 0.10376	 223.97	 223.97	 223.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25826	 25096	 0.000994	 0.005145	 0.00802	 255.11	 255.11	 255.11	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 25115	 0.003416	 0.013849	 0.01283	 195.41	 195.41	 195.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25097	 25893	 0.00152	 0.008224	 0.0182	 250.36	 250.36	 250.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25098	 25099	 0.00022	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25098	 25100	 0.000293	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25098	 25101	 0.000247	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25099	 25115	 0.001363	 0.007455	 0.00218	 237.75	 237.75	 237.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25099	 25150	 0.004434	 0.028005	 0.05384	 227.74	 227.74	 227.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25099	 26006	 0.002063	 0.012676	 0.01363	 237.74	 237.74	 237.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25102	 25104	 0.003942	 0.021024	 0.02377	 226.38	 226.38	 226.38	 0.0	 0.0	 1	 -30.0	 30.0;
	25102	 25113	 0.002784	 0.016398	 0.00715	 204.18	 204.18	 204.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25104	 25103	 0.000261	 0.017986	 0.0	 508.53	 508.53	 508.53	 1.0	 0.0	 1	 -30.0	 30.0;
	25103	 25156	 0.000579	 0.007303	 0.25594	 1211.18	 1211.18	 1211.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25103	 26005	 0.000533	 0.005607	 0.08897	 1200.39	 1200.39	 1200.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25103	 26036	 0.000599	 0.007165	 0.11341	 1218.72	 1218.72	 1218.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25104	 25105	 0.000612	 0.003932	 0.01034	 264.27	 264.27	 264.27	 0.0	 0.0	 1	 -30.0	 30.0;
	25105	 25106	 0.000278	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25105	 25130	 0.003448	 0.017955	 0.0089	 238.72	 238.72	 238.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25109	 25108	 0.000211	 0.014577	 0.0	 393.86	 393.86	 393.86	 1.00625	 0.0	 1	 -30.0	 30.0;
	25108	 25110	 0.000225	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 25108	 0.00052	 0.006471	 0.09856	 1073.88	 1073.88	 1073.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25108	 26153	 0.001053	 0.012881	 0.19712	 1197.36	 1197.36	 1197.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25109	 25111	 0.00196	 0.010791	 0.01024	 212.31	 212.31	 212.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25133	 25109	 0.00273	 0.017116	 0.00392	 220.39	 220.39	 220.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25112	 25152	 0.001153	 0.005791	 0.02332	 207.84	 207.84	 207.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25112	 25202	 0.007877	 0.041733	 0.02804	 191.2	 191.2	 191.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25113	 25114	 0.001685	 0.007041	 0.00792	 174.2	 174.2	 174.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25114	 25146	 0.002401	 0.010944	 0.08271	 212.0	 212.0	 212.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 25116	 0.005961	 0.02304	 0.0121	 219.85	 219.85	 219.85	 0.0	 0.0	 1	 -30.0	 30.0;
	25163	 25116	 0.003406	 0.019793	 0.01301	 219.3	 219.3	 219.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25117	 25118	 0.000219	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25127	 25117	 0.002327	 0.014487	 0.01626	 232.48	 232.48	 232.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25117	 25915	 0.003608	 0.012931	 0.01542	 221.02	 221.02	 221.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25117	 26009	 0.001039	 0.007229	 0.00438	 234.36	 234.36	 234.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25119	 25120	 0.000219	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25120	 25127	 0.001585	 0.009122	 0.00504	 227.36	 227.36	 227.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25128	 25120	 0.001965	 0.011161	 0.01136	 177.43	 177.43	 177.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 25122	 0.000259	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 25141	 0.00348	 0.027942	 0.0081	 231.86	 231.86	 231.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25121	 25143	 0.001676	 0.00966	 0.01212	 248.49	 248.49	 248.49	 0.0	 0.0	 1	 -30.0	 30.0;
	25123	 25143	 0.001802	 0.007898	 0.00446	 183.66	 183.66	 183.66	 0.0	 0.0	 1	 -30.0	 30.0;
	25124	 25125	 0.000279	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25124	 25126	 0.000247	 0.001092	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 25141	 0.006821	 0.041926	 0.07053	 211.69	 211.69	 211.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 25146	 0.018927	 0.084572	 0.07461	 232.19	 232.19	 232.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25125	 25903	 0.011383	 0.070054	 0.01577	 223.65	 223.65	 223.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25127	 25133	 0.001482	 0.008824	 0.00343	 185.75	 185.75	 185.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25839	 25128	 0.003025	 0.021532	 0.00983	 215.86	 215.86	 215.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25129	 25130	 0.000209	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25130	 25131	 0.005939	 0.026802	 0.0118	 222.72	 222.72	 222.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25131	 25150	 0.006572	 0.034704	 0.06844	 206.31	 206.31	 206.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25177	 25131	 0.002995	 0.019506	 0.01253	 221.22	 221.22	 221.22	 0.0	 0.0	 1	 -30.0	 30.0;
	25132	 25139	 0.001433	 0.009104	 0.00415	 200.9	 200.9	 200.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25132	 25144	 0.003613	 0.02548	 0.01029	 192.37	 192.37	 192.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25134	 25135	 0.000228	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25134	 25136	 0.000241	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 25188	 0.002016	 0.014243	 0.11607	 276.63	 276.63	 276.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 25188	 0.002016	 0.014243	 0.11607	 276.63	 276.63	 276.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 25188	 0.002016	 0.014243	 0.11607	 276.63	 276.63	 276.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 26006	 0.003405	 0.015917	 0.06105	 289.14	 289.14	 289.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 26006	 0.003405	 0.015917	 0.06105	 289.14	 289.14	 289.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25135	 26006	 0.003405	 0.015917	 0.06105	 289.14	 289.14	 289.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25152	 25137	 0.002786	 0.019092	 0.00674	 232.04	 232.04	 232.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25137	 25826	 0.004328	 0.018226	 0.0456	 248.31	 248.31	 248.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25139	 25138	 0.000803	 0.030005	 0.0	 384.88	 384.88	 384.88	 1.0125	 0.0	 1	 -30.0	 30.0;
	25142	 25138	 0.000538	 0.006796	 0.11595	 1126.83	 1126.83	 1126.83	 0.0	 0.0	 1	 -30.0	 30.0;
	25168	 25138	 0.000647	 0.00741	 0.14733	 1057.69	 1057.69	 1057.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25138	 26057	 0.000678	 0.007203	 0.14794	 1167.64	 1167.64	 1167.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25140	 25141	 0.000252	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25162	 25141	 0.002092	 0.013621	 0.00255	 198.66	 198.66	 198.66	 0.0	 0.0	 1	 -30.0	 30.0;
	25143	 25142	 0.000518	 0.028988	 0.0	 432.0	 432.0	 432.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	25142	 25902	 0.000779	 0.010269	 0.16366	 1221.1	 1221.1	 1221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25142	 26049	 0.001216	 0.015145	 0.49977	 1225.42	 1225.42	 1225.42	 0.0	 0.0	 1	 -30.0	 30.0;
	25144	 25145	 0.000261	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25144	 25169	 0.004741	 0.02536	 0.02381	 184.41	 184.41	 184.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25144	 25890	 0.007801	 0.033733	 0.05074	 225.29	 225.29	 225.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25148	 25146	 0.00201	 0.010359	 0.00628	 233.36	 233.36	 233.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25147	 25148	 0.000275	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25182	 25148	 0.003866	 0.029274	 0.02787	 216.31	 216.31	 216.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25149	 25150	 0.000272	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25149	 25151	 0.000219	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25152	 25153	 0.000208	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25154	 25155	 0.000225	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25154	 25177	 0.001753	 0.009878	 0.0071	 204.01	 204.01	 204.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25154	 25179	 0.002139	 0.013873	 0.06248	 193.12	 193.12	 193.12	 0.0	 0.0	 1	 -30.0	 30.0;
	25156	 25159	 0.000355	 0.023488	 0.0	 558.72	 558.72	 558.72	 1.0	 0.0	 1	 -30.0	 30.0;
	25156	 25196	 0.00059	 0.00762	 0.15266	 1035.43	 1035.43	 1035.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25157	 25159	 2.2e-05	 0.001468	 0.0	 483.72	 483.72	 483.72	 1.0	 0.0	 1	 -30.0	 30.0;
	25176	 25157	 0.001423	 0.00932	 0.00344	 276.04	 276.04	 276.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 25157	 0.001423	 0.00932	 0.00344	 276.04	 276.04	 276.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25158	 25159	 0.002084	 0.137933	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25258	 25160	 0.003549	 0.019214	 0.00454	 178.0	 178.0	 178.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25160	 25339	 0.002069	 0.009283	 0.00251	 205.42	 205.42	 205.42	 0.0	 0.0	 1	 -30.0	 30.0;
	25161	 25162	 0.000237	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25918	 25162	 0.008186	 0.041844	 0.01226	 226.05	 226.05	 226.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25163	 25221	 0.011592	 0.051106	 0.04113	 189.28	 189.28	 189.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25172	 25164	 0.00243	 0.010449	 0.00519	 233.1	 233.1	 233.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25164	 25175	 0.000702	 0.003981	 0.00231	 216.4	 216.4	 216.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25198	 25164	 0.001258	 0.007687	 0.00304	 231.66	 231.66	 231.66	 0.0	 0.0	 1	 -30.0	 30.0;
	25165	 25166	 0.004183	 0.021854	 0.00911	 209.2	 209.2	 209.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25166	 25167	 0.000233	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25269	 25166	 0.006367	 0.042848	 0.02667	 237.74	 237.74	 237.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25169	 25168	 0.000501	 0.038608	 0.0	 362.23	 362.23	 362.23	 1.0125	 0.0	 1	 -30.0	 30.0;
	25170	 25910	 0.004018	 0.027656	 0.15064	 208.77	 208.77	 208.77	 0.0	 0.0	 1	 -30.0	 30.0;
	25170	 26034	 0.008145	 0.034748	 0.02022	 206.97	 206.97	 206.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25171	 25172	 0.000285	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25172	 25212	 0.001741	 0.011047	 0.01469	 176.67	 176.67	 176.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25173	 25174	 0.000274	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25173	 25175	 0.000255	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25182	 25175	 0.003029	 0.020182	 0.02118	 193.98	 193.98	 193.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25175	 26084	 0.007603	 0.049806	 0.11577	 257.13	 257.13	 257.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25179	 25176	 0.001516	 0.00995	 0.00362	 241.08	 241.08	 241.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25176	 25187	 0.002749	 0.014697	 0.01064	 248.84	 248.84	 248.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25178	 25179	 0.000205	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25179	 25208	 0.005361	 0.040853	 0.04053	 222.25	 222.25	 222.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25180	 25181	 0.004729	 0.017704	 0.0377	 228.13	 228.13	 228.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25180	 25192	 0.002128	 0.00843	 0.00674	 193.82	 193.82	 193.82	 0.0	 0.0	 1	 -30.0	 30.0;
	25180	 25216	 0.003839	 0.025195	 0.03111	 222.26	 222.26	 222.26	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 25181	 0.001952	 0.009843	 0.00305	 241.27	 241.27	 241.27	 0.0	 0.0	 1	 -30.0	 30.0;
	25182	 25183	 0.000216	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25185	 25184	 0.000408	 0.024777	 0.0	 503.8	 503.8	 503.8	 1.0125	 0.0	 1	 -30.0	 30.0;
	25184	 25186	 0.000213	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25196	 25184	 0.000603	 0.007381	 0.12902	 1189.0	 1189.0	 1189.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25199	 25184	 0.00049	 0.006004	 0.11249	 1188.56	 1188.56	 1188.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25184	 25902	 0.001457	 0.017206	 0.75155	 1271.29	 1271.29	 1271.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25184	 26195	 0.000619	 0.00723	 0.20679	 1309.35	 1309.35	 1309.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25185	 25193	 0.001708	 0.008811	 0.0055	 250.17	 250.17	 250.17	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 25185	 0.000793	 0.004709	 0.00352	 243.7	 243.7	 243.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25187	 25300	 0.003698	 0.018715	 0.05852	 238.86	 238.86	 238.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25189	 25188	 0.00152	 0.0096	 0.0058	 261.19	 261.19	 261.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25202	 25188	 0.001021	 0.006915	 0.00568	 245.86	 245.86	 245.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25202	 25189	 0.001665	 0.010673	 0.00365	 222.11	 222.11	 222.11	 0.0	 0.0	 1	 -30.0	 30.0;
	25189	 25210	 0.003779	 0.015924	 0.00539	 237.09	 237.09	 237.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25189	 25212	 0.003028	 0.015422	 0.00467	 212.26	 212.26	 212.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25221	 25189	 0.001975	 0.011319	 0.01833	 195.35	 195.35	 195.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25190	 25191	 0.000261	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25203	 25191	 0.000953	 0.006627	 0.00353	 189.96	 189.96	 189.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25191	 25235	 0.000893	 0.004285	 0.00883	 204.15	 204.15	 204.15	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 25192	 0.006074	 0.041683	 0.01731	 219.98	 219.98	 219.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25193	 25252	 0.001804	 0.013827	 0.0093	 239.07	 239.07	 239.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25195	 25194	 0.000471	 0.02592	 0.0	 543.13	 543.13	 543.13	 1.1	 0.0	 1	 -30.0	 30.0;
	25194	 25196	 0.000285	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25195	 25220	 0.002029	 0.013932	 0.00665	 243.71	 243.71	 243.71	 0.0	 0.0	 1	 -30.0	 30.0;
	25222	 25195	 0.000575	 0.004246	 0.00292	 244.48	 244.48	 244.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25195	 25253	 0.001328	 0.006814	 0.0015	 225.78	 225.78	 225.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25196	 25483	 0.000504	 0.006492	 0.2182	 1250.89	 1250.89	 1250.89	 0.0	 0.0	 1	 -30.0	 30.0;
	25196	 26195	 0.001157	 0.012223	 0.43157	 1288.39	 1288.39	 1288.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25198	 25197	 0.000594	 0.02739	 0.0	 485.09	 485.09	 485.09	 1.0	 0.0	 1	 -30.0	 30.0;
	25197	 25199	 0.000248	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25215	 25198	 0.001705	 0.009425	 0.04157	 232.75	 232.75	 232.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25200	 25201	 0.000255	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25223	 25200	 0.001542	 0.008768	 0.01319	 246.34	 246.34	 246.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25200	 25243	 0.002817	 0.018614	 0.03123	 231.83	 231.83	 231.83	 0.0	 0.0	 1	 -30.0	 30.0;
	25253	 25200	 0.001073	 0.004567	 0.00437	 191.44	 191.44	 191.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25203	 25204	 0.000286	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25217	 25203	 0.003321	 0.013921	 0.002	 244.91	 244.91	 244.91	 0.0	 0.0	 1	 -30.0	 30.0;
	26207	 25203	 0.000984	 0.006897	 0.00585	 267.07	 267.07	 267.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25205	 25216	 0.003372	 0.017118	 0.01976	 227.03	 227.03	 227.03	 0.0	 0.0	 1	 -30.0	 30.0;
	25206	 25207	 0.000282	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25206	 25219	 0.002098	 0.008461	 0.00539	 203.96	 203.96	 203.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25206	 25244	 0.001301	 0.008529	 0.01153	 158.65	 158.65	 158.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25208	 25300	 0.001949	 0.011544	 0.00449	 204.43	 204.43	 204.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25209	 25210	 0.000203	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25209	 25211	 0.000292	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25210	 25232	 0.004273	 0.01904	 0.00318	 225.5	 225.5	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25212	 25213	 0.000216	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25214	 25215	 0.00024	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25215	 25216	 0.001509	 0.007669	 0.00656	 236.67	 236.67	 236.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25215	 25223	 0.001897	 0.009449	 0.00688	 246.37	 246.37	 246.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25217	 25218	 0.000222	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25217	 25223	 0.002456	 0.015946	 0.04337	 232.01	 232.01	 232.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25222	 25219	 0.002542	 0.013026	 0.00618	 222.51	 222.51	 222.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25220	 25230	 0.001605	 0.006862	 0.00166	 229.84	 229.84	 229.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 25225	 0.00023	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 25226	 0.00023	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25224	 25227	 0.000298	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25230	 25227	 0.001526	 0.009034	 0.00203	 198.52	 198.52	 198.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25231	 25227	 0.003149	 0.013946	 0.00394	 228.33	 228.33	 228.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25228	 25229	 0.000238	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25275	 25228	 0.002164	 0.012583	 0.00413	 243.82	 243.82	 243.82	 0.0	 0.0	 1	 -30.0	 30.0;
	25228	 25291	 0.001043	 0.006667	 0.04257	 212.26	 212.26	 212.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25231	 25322	 0.001674	 0.011649	 0.00579	 241.02	 241.02	 241.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25244	 25232	 0.001537	 0.008806	 0.00251	 209.51	 209.51	 209.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25233	 25234	 0.000222	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25234	 25306	 0.000978	 0.006719	 0.00283	 235.88	 235.88	 235.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25234	 25333	 0.002577	 0.011934	 0.00305	 255.78	 255.78	 255.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25235	 25236	 0.000207	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25237	 25235	 0.001065	 0.006716	 0.00336	 245.66	 245.66	 245.66	 0.0	 0.0	 1	 -30.0	 30.0;
	26221	 25237	 0.004088	 0.024946	 0.02614	 262.92	 262.92	 262.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25250	 25238	 0.00222	 0.01537	 0.00502	 269.48	 269.48	 269.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25238	 25271	 0.00208	 0.014899	 0.0185	 209.87	 209.87	 209.87	 0.0	 0.0	 1	 -30.0	 30.0;
	25238	 25944	 0.0066	 0.039436	 0.03404	 275.39	 275.39	 275.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25238	 25944	 0.0066	 0.039436	 0.03404	 275.39	 275.39	 275.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25239	 25240	 0.000225	 0.001135	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25240	 25967	 0.005336	 0.031634	 0.05036	 211.16	 211.16	 211.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25241	 26046	 0.003336	 0.021507	 0.02623	 218.07	 218.07	 218.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25242	 25303	 0.00066	 0.003556	 0.01687	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25242	 25365	 0.001327	 0.00783	 0.00215	 221.97	 221.97	 221.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25325	 25243	 0.000538	 0.00328	 0.00475	 211.0	 211.0	 211.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25244	 25245	 0.000217	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25246	 25299	 0.001683	 0.005345	 0.00125	 212.35	 212.35	 212.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25246	 25322	 0.000915	 0.00524	 0.00413	 264.84	 264.84	 264.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25333	 25246	 0.001666	 0.007301	 0.0068	 266.91	 266.91	 266.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 25248	 0.000291	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 25333	 0.001163	 0.006502	 0.00496	 232.29	 232.29	 232.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25247	 26105	 0.002471	 0.017183	 0.03463	 254.74	 254.74	 254.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25250	 0.00323	 0.017533	 0.0176	 253.69	 253.69	 253.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25249	 25306	 0.001337	 0.007669	 0.00927	 239.39	 239.39	 239.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25250	 25251	 0.000231	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25252	 25299	 0.002911	 0.01683	 0.01125	 206.95	 206.95	 206.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25254	 25330	 0.002005	 0.012622	 0.01433	 237.48	 237.48	 237.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25254	 25337	 0.001361	 0.007686	 0.00469	 216.05	 216.05	 216.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25255	 25293	 0.000604	 0.004351	 0.00432	 222.54	 222.54	 222.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25255	 25369	 0.001084	 0.006536	 0.01152	 245.74	 245.74	 245.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25256	 25257	 0.000244	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25256	 25363	 0.001628	 0.00904	 0.0102	 246.0	 246.0	 246.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26033	 25256	 0.00132	 0.007387	 0.00315	 233.02	 233.02	 233.02	 0.0	 0.0	 1	 -30.0	 30.0;
	26214	 25256	 0.000923	 0.006856	 0.00351	 231.99	 231.99	 231.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25258	 25259	 0.000275	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25258	 25300	 0.003667	 0.01924	 0.00558	 209.74	 209.74	 209.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25260	 25290	 0.003326	 0.020712	 0.02193	 243.54	 243.54	 243.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25260	 25330	 0.000971	 0.004691	 0.0048	 221.31	 221.31	 221.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25261	 25264	 0.000984	 0.023601	 0.0	 102.09	 102.09	 102.09	 1.0	 0.0	 1	 -30.0	 30.0;
	25261	 25265	 0.000254	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25261	 25267	 0.001291	 0.008157	 0.01037	 214.25	 214.25	 214.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25331	 25261	 0.001077	 0.006374	 0.00479	 179.37	 179.37	 179.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25262	 25264	 0.011521	 0.2764	 0.0	 51.05	 51.05	 51.05	 1.0	 0.0	 1	 -30.0	 30.0;
	25263	 25264	 0.011521	 0.2764	 0.0	 51.05	 51.05	 51.05	 1.0	 0.0	 1	 -30.0	 30.0;
	25267	 25266	 0.000339	 0.019275	 0.0	 568.01	 568.01	 568.01	 1.04375	 0.0	 1	 -30.0	 30.0;
	25266	 25268	 0.000202	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 25334	 0.000637	 0.007815	 0.19485	 1239.97	 1239.97	 1239.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 25475	 0.000591	 0.006836	 0.20808	 1207.91	 1207.91	 1207.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25266	 26126	 0.00054	 0.005684	 0.14269	 1302.75	 1302.75	 1302.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25326	 25267	 0.000368	 0.002032	 0.00085	 238.78	 238.78	 238.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25267	 25381	 0.001807	 0.011452	 0.00393	 216.48	 216.48	 216.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 25267	 0.00201	 0.011152	 0.00767	 244.02	 244.02	 244.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25267	 25423	 0.001013	 0.006741	 0.02627	 243.05	 243.05	 243.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25269	 26206	 0.003857	 0.027312	 0.03244	 248.65	 248.65	 248.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25270	 25271	 0.000214	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25271	 25349	 0.003096	 0.0136	 0.00695	 163.92	 163.92	 163.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25272	 25273	 0.000238	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25272	 25274	 0.000291	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25274	 25299	 0.005577	 0.03405	 0.03357	 233.28	 233.28	 233.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25274	 26196	 0.002751	 0.019618	 0.0526	 246.88	 246.88	 246.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25275	 25276	 0.000255	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25275	 26060	 0.001109	 0.007268	 0.01658	 273.42	 273.42	 273.42	 0.0	 0.0	 1	 -30.0	 30.0;
	25275	 26060	 0.001109	 0.007268	 0.01658	 273.42	 273.42	 273.42	 0.0	 0.0	 1	 -30.0	 30.0;
	25277	 25278	 0.000231	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25277	 25279	 0.000258	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25277	 25280	 0.000291	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25288	 25279	 0.000129	 0.000667	 0.00281	 298.96	 298.96	 298.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25279	 25362	 0.000896	 0.00572	 0.00131	 258.16	 258.16	 258.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25281	 25282	 0.000298	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25281	 25283	 0.000275	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25283	 25380	 0.000956	 0.00632	 0.00342	 225.97	 225.97	 225.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25283	 25383	 0.002566	 0.010827	 0.01308	 202.8	 202.8	 202.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25446	 25283	 0.001288	 0.008985	 0.00732	 174.72	 174.72	 174.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25285	 0.000204	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25284	 25286	 0.000206	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25285	 25348	 0.003451	 0.020852	 0.02034	 226.46	 226.46	 226.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25285	 26060	 0.001453	 0.008281	 0.00523	 210.77	 210.77	 210.77	 0.0	 0.0	 1	 -30.0	 30.0;
	25288	 25287	 0.000498	 0.032225	 0.0	 495.54	 495.54	 495.54	 1.0	 0.0	 1	 -30.0	 30.0;
	25287	 25289	 0.000221	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 25489	 0.000351	 0.003781	 0.05059	 1220.5	 1220.5	 1220.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26059	 25287	 0.0004	 0.003779	 0.06172	 1174.78	 1174.78	 1174.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 26104	 0.000633	 0.007446	 0.32805	 1217.4	 1217.4	 1217.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26126	 25287	 0.000135	 0.001483	 0.05293	 1294.05	 1294.05	 1294.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25287	 26237	 0.000247	 0.002874	 0.07259	 1181.7	 1181.7	 1181.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25288	 25330	 0.000643	 0.004783	 0.01257	 226.09	 226.09	 226.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25308	 25290	 0.002709	 0.017574	 0.0083	 232.93	 232.93	 232.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25290	 25310	 0.000759	 0.004736	 0.00355	 287.31	 287.31	 287.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25290	 25310	 0.000759	 0.004736	 0.00355	 287.31	 287.31	 287.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25290	 25310	 0.000759	 0.004736	 0.00355	 287.31	 287.31	 287.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25290	 25360	 0.000772	 0.003562	 0.00194	 261.39	 261.39	 261.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25291	 25292	 0.000278	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25356	 25291	 0.001273	 0.007824	 0.00524	 181.67	 181.67	 181.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25293	 25294	 0.000292	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25365	 25293	 0.000718	 0.004542	 0.00263	 203.16	 203.16	 203.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25295	 25296	 0.000226	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25295	 25297	 0.000297	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25297	 25381	 0.001171	 0.00637	 0.01038	 177.22	 177.22	 177.22	 0.0	 0.0	 1	 -30.0	 30.0;
	26027	 25297	 0.00101	 0.00535	 0.0059	 202.73	 202.73	 202.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25298	 25306	 0.003645	 0.015385	 0.01517	 232.23	 232.23	 232.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25298	 25331	 0.00116	 0.006834	 0.01397	 212.45	 212.45	 212.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25300	 25301	 0.000251	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25300	 25329	 0.002508	 0.016356	 0.00774	 195.46	 195.46	 195.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25303	 25302	 0.000336	 0.025091	 0.0	 533.21	 533.21	 533.21	 1.0375	 0.0	 1	 -30.0	 30.0;
	25302	 26213	 7.9e-05	 0.000889	 0.04975	 1232.02	 1232.02	 1232.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25303	 25376	 0.00053	 0.002935	 0.00153	 230.29	 230.29	 230.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25305	 0.00029	 0.001009	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25402	 0.002115	 0.01205	 0.00403	 229.84	 229.84	 229.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25304	 25520	 0.00112	 0.006624	 0.00428	 216.8	 216.8	 216.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25306	 25307	 0.000291	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25308	 25341	 0.002226	 0.012321	 0.00456	 208.01	 208.01	 208.01	 0.0	 0.0	 1	 -30.0	 30.0;
	26060	 25308	 0.001363	 0.00813	 0.00242	 203.26	 203.26	 203.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25309	 0.000299	 0.019785	 0.0	 632.16	 632.16	 632.16	 1.01875	 0.0	 1	 -30.0	 30.0;
	25310	 25309	 0.000299	 0.019785	 0.0	 632.16	 632.16	 632.16	 1.01875	 0.0	 1	 -30.0	 30.0;
	25310	 25309	 0.000299	 0.019785	 0.0	 632.16	 632.16	 632.16	 1.01875	 0.0	 1	 -30.0	 30.0;
	25309	 25334	 0.000203	 0.002925	 0.1656	 1127.18	 1127.18	 1127.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25309	 25990	 0.001286	 0.012105	 0.43315	 1320.92	 1320.92	 1320.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25309	 26104	 0.000482	 0.0056	 0.13106	 1234.38	 1234.38	 1234.38	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25348	 0.001271	 0.006863	 0.00318	 244.21	 244.21	 244.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25404	 0.003201	 0.016232	 0.0215	 281.43	 281.43	 281.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25404	 0.003201	 0.016232	 0.0215	 281.43	 281.43	 281.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25310	 25404	 0.003201	 0.016232	 0.0215	 281.43	 281.43	 281.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25311	 25312	 0.000271	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 25353	 0.004465	 0.024057	 0.05293	 294.07	 294.07	 294.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 25353	 0.004465	 0.024057	 0.05293	 294.07	 294.07	 294.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 25353	 0.004465	 0.024057	 0.05293	 294.07	 294.07	 294.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25312	 0.003112	 0.017862	 0.00546	 292.1	 292.1	 292.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25312	 0.003112	 0.017862	 0.00546	 292.1	 292.1	 292.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25312	 0.003112	 0.017862	 0.00546	 292.1	 292.1	 292.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 25712	 0.011403	 0.052676	 0.07744	 260.36	 260.36	 260.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25312	 26123	 0.01102	 0.063936	 0.09415	 247.0	 247.0	 247.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25313	 25363	 0.002855	 0.014731	 0.0157	 216.64	 216.64	 216.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25470	 25313	 0.002238	 0.012609	 0.00862	 216.09	 216.09	 216.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25313	 26016	 0.000233	 0.001631	 0.00099	 254.41	 254.41	 254.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25314	 25315	 0.000223	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25314	 25316	 0.000236	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25316	 25319	 0.00045	 0.002756	 0.02145	 238.09	 238.09	 238.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25346	 25316	 0.000261	 0.001694	 0.00266	 220.34	 220.34	 220.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25317	 25318	 0.000221	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25317	 25319	 0.000223	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25317	 25320	 0.00029	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 25482	 0.000704	 0.003723	 0.00134	 276.2	 276.2	 276.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 25482	 0.000704	 0.003723	 0.00134	 276.2	 276.2	 276.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 25482	 0.000704	 0.003723	 0.00134	 276.2	 276.2	 276.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25319	 25500	 0.000495	 0.003943	 0.02627	 256.39	 256.39	 256.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25321	 25447	 0.002001	 0.011622	 0.01309	 220.13	 220.13	 220.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25321	 25459	 0.001015	 0.006775	 0.00326	 237.06	 237.06	 237.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25322	 25323	 0.000266	 0.001178	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25324	 25325	 0.000257	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25325	 25329	 0.001477	 0.009094	 0.0095	 181.93	 181.93	 181.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25337	 25325	 0.001076	 0.008181	 0.00196	 197.26	 197.26	 197.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25329	 25326	 0.001361	 0.006084	 0.00254	 208.33	 208.33	 208.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25346	 25327	 0.000955	 0.004309	 0.00801	 227.58	 227.58	 227.58	 0.0	 0.0	 1	 -30.0	 30.0;
	25327	 25383	 0.000768	 0.003518	 0.00104	 213.19	 213.19	 213.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25327	 25417	 0.001169	 0.007743	 0.02117	 207.95	 207.95	 207.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25328	 25351	 0.003276	 0.022715	 0.00564	 197.58	 197.58	 197.58	 0.0	 0.0	 1	 -30.0	 30.0;
	25375	 25328	 0.000766	 0.005235	 0.00289	 176.25	 176.25	 176.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25328	 25435	 0.001052	 0.006503	 0.00658	 203.37	 203.37	 203.37	 0.0	 0.0	 1	 -30.0	 30.0;
	26027	 25329	 0.000381	 0.002059	 0.00153	 179.33	 179.33	 179.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25333	 25332	 0.000618	 0.027741	 0.0	 478.46	 478.46	 478.46	 1.0125	 0.0	 1	 -30.0	 30.0;
	25332	 25334	 0.000214	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 25335	 0.000231	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25332	 25336	 0.000291	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26059	 25334	 0.000236	 0.002593	 0.08556	 992.53	 992.53	 992.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25334	 26083	 0.00132	 0.012761	 0.56908	 1250.07	 1250.07	 1250.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25334	 26195	 0.000859	 0.011688	 0.30194	 1306.69	 1306.69	 1306.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25338	 25364	 0.003839	 0.018051	 0.00802	 206.23	 206.23	 206.23	 0.0	 0.0	 1	 -30.0	 30.0;
	26016	 25338	 0.000912	 0.006248	 0.00298	 228.25	 228.25	 228.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25339	 25340	 0.00027	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25368	 25339	 0.001313	 0.005044	 0.00175	 245.12	 245.12	 245.12	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25341	 0.002883	 0.017124	 0.00411	 205.15	 205.15	 205.15	 0.0	 0.0	 1	 -30.0	 30.0;
	25342	 25343	 0.000236	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25342	 25344	 0.000251	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25360	 25344	 0.002357	 0.012514	 0.00408	 239.39	 239.39	 239.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25517	 25344	 0.004133	 0.017911	 0.01054	 207.45	 207.45	 207.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25518	 25345	 0.002757	 0.012752	 0.00909	 267.45	 267.45	 267.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25345	 25664	 0.008135	 0.05161	 0.05792	 243.14	 243.14	 243.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25346	 25501	 0.002193	 0.00828	 0.01946	 240.23	 240.23	 240.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25356	 0.000956	 0.00629	 0.00264	 218.45	 218.45	 218.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25412	 25347	 0.001151	 0.006676	 0.00682	 220.0	 220.0	 220.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25347	 25490	 0.001413	 0.006944	 0.00571	 270.09	 270.09	 270.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25349	 25514	 0.004232	 0.026871	 0.04419	 211.84	 211.84	 211.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25350	 25351	 0.000276	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25351	 26016	 0.001941	 0.010896	 0.0037	 224.2	 224.2	 224.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25410	 25352	 0.001161	 0.006882	 0.00231	 162.29	 162.29	 162.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25352	 25454	 0.000918	 0.005465	 0.00215	 212.23	 212.23	 212.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25354	 0.000294	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25851	 25353	 0.001684	 0.008632	 0.02188	 237.52	 237.52	 237.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25900	 0.004197	 0.019232	 0.04717	 261.6	 261.6	 261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25935	 0.000724	 0.005681	 0.0043	 279.56	 279.56	 279.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25935	 0.000724	 0.005681	 0.0043	 279.56	 279.56	 279.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25353	 25935	 0.000724	 0.005681	 0.0043	 279.56	 279.56	 279.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25355	 25397	 0.00352	 0.020166	 0.01246	 220.44	 220.44	 220.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25355	 26151	 0.004357	 0.027196	 0.02206	 199.84	 199.84	 199.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25356	 25361	 0.002149	 0.009565	 0.0051	 164.3	 164.3	 164.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25357	 25486	 0.001064	 0.006171	 0.00305	 247.56	 247.56	 247.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25359	 0.000237	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25358	 25360	 0.00029	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25361	 25478	 0.000944	 0.006627	 0.00473	 234.34	 234.34	 234.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25412	 25362	 0.002083	 0.008583	 0.00388	 210.49	 210.49	 210.49	 0.0	 0.0	 1	 -30.0	 30.0;
	25363	 25405	 0.001054	 0.005722	 0.00706	 239.63	 239.63	 239.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25364	 25376	 0.002201	 0.012308	 0.05478	 190.0	 190.0	 190.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26137	 25364	 0.000357	 0.001867	 0.00191	 218.56	 218.56	 218.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25366	 25367	 0.000251	 0.001066	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25366	 25368	 0.000272	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25399	 25368	 0.001132	 0.006018	 0.00385	 213.62	 213.62	 213.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25368	 26214	 0.001272	 0.009091	 0.01475	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 25370	 0.00022	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 25371	 0.000237	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25369	 26214	 0.001497	 0.008288	 0.06067	 266.32	 266.32	 266.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25372	 25373	 0.000211	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25400	 25372	 0.001408	 0.009033	 0.00491	 224.93	 224.93	 224.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25372	 25418	 0.000613	 0.003744	 0.00303	 215.61	 215.61	 215.61	 0.0	 0.0	 1	 -30.0	 30.0;
	25372	 25451	 0.002264	 0.011604	 0.01782	 238.33	 238.33	 238.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25372	 25457	 0.000554	 0.002855	 0.00114	 263.92	 263.92	 263.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25374	 25470	 0.000771	 0.004298	 0.00386	 195.27	 195.27	 195.27	 0.0	 0.0	 1	 -30.0	 30.0;
	25374	 25590	 0.001161	 0.005999	 0.02536	 236.56	 236.56	 236.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25374	 26137	 0.001374	 0.007585	 0.0026	 202.41	 202.41	 202.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25375	 25530	 0.001306	 0.009225	 0.00903	 243.97	 243.97	 243.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25377	 25378	 0.000206	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25377	 25379	 0.000295	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25378	 25501	 0.001004	 0.006439	 0.02994	 234.96	 234.96	 234.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25561	 25378	 0.001326	 0.00901	 0.00703	 195.72	 195.72	 195.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25380	 25449	 0.000853	 0.005427	 0.00506	 241.69	 241.69	 241.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25438	 25382	 0.001153	 0.005755	 0.00417	 230.47	 230.47	 230.47	 0.0	 0.0	 1	 -30.0	 30.0;
	25382	 25533	 0.000757	 0.005073	 0.00438	 181.35	 181.35	 181.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25383	 25431	 0.001124	 0.006022	 0.00987	 226.97	 226.97	 226.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25500	 25383	 0.000804	 0.003957	 0.00184	 225.2	 225.2	 225.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25384	 25385	 0.000242	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25384	 25937	 0.002151	 0.013417	 0.01212	 232.33	 232.33	 232.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25384	 26016	 0.000417	 0.003026	 0.00074	 205.64	 205.64	 205.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25386	 25387	 0.000242	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25386	 25407	 0.002317	 0.01373	 0.00279	 209.13	 209.13	 209.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25386	 26033	 0.001588	 0.009208	 0.00479	 230.34	 230.34	 230.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25388	 25435	 0.001116	 0.00665	 0.00498	 221.01	 221.01	 221.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25388	 25528	 0.000949	 0.005665	 0.0016	 248.43	 248.43	 248.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25389	 25390	 0.000263	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25389	 25391	 0.000291	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25389	 25392	 0.00021	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25389	 25393	 0.000211	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25390	 25396	 0.002205	 0.014218	 0.01042	 243.01	 243.01	 243.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25390	 25406	 0.002437	 0.012532	 0.00423	 247.68	 247.68	 247.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25390	 25418	 0.002505	 0.012081	 0.00688	 238.34	 238.34	 238.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 25390	 0.000966	 0.006562	 0.00881	 291.25	 291.25	 291.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 25390	 0.000966	 0.006562	 0.00881	 291.25	 291.25	 291.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 25390	 0.000966	 0.006562	 0.00881	 291.25	 291.25	 291.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 25395	 0.000296	 0.001186	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 25527	 0.001646	 0.008254	 0.01213	 262.32	 262.32	 262.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 25574	 0.001499	 0.008997	 0.00285	 231.5	 231.5	 231.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25394	 26238	 0.002764	 0.010199	 0.00445	 241.2	 241.2	 241.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25396	 25422	 0.001669	 0.009395	 0.00471	 196.2	 196.2	 196.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25396	 25446	 0.001112	 0.007044	 0.00834	 220.43	 220.43	 220.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25397	 25398	 0.000282	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25397	 25935	 0.002448	 0.016494	 0.00796	 208.24	 208.24	 208.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25397	 26236	 0.002294	 0.016041	 0.00483	 222.63	 222.63	 222.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25399	 25459	 0.001268	 0.007983	 0.00987	 203.01	 203.01	 203.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25400	 25490	 0.001723	 0.00946	 0.00463	 268.75	 268.75	 268.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25402	 25401	 0.000381	 0.02264	 0.0	 536.89	 536.89	 536.89	 1.05	 0.0	 1	 -30.0	 30.0;
	25401	 25403	 0.00028	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25463	 25401	 0.000218	 0.002537	 0.02834	 985.91	 985.91	 985.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25401	 25919	 0.000254	 0.003126	 0.08505	 1312.12	 1312.12	 1312.12	 0.0	 0.0	 1	 -30.0	 30.0;
	25402	 25407	 0.00134	 0.005687	 0.02151	 254.6	 254.6	 254.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25402	 0.000554	 0.003271	 0.00153	 292.06	 292.06	 292.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25402	 0.000554	 0.003271	 0.00153	 292.06	 292.06	 292.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25402	 0.000554	 0.003271	 0.00153	 292.06	 292.06	 292.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25537	 0.001727	 0.01152	 0.00486	 231.97	 231.97	 231.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25550	 0.00272	 0.017441	 0.01404	 271.18	 271.18	 271.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25404	 25550	 0.00272	 0.017441	 0.01404	 271.18	 271.18	 271.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25405	 25584	 0.001116	 0.006974	 0.01505	 228.9	 228.9	 228.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25406	 25569	 0.002105	 0.012089	 0.01188	 229.64	 229.64	 229.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25407	 25408	 0.000207	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25407	 25937	 0.00154	 0.010263	 0.00414	 255.73	 255.73	 255.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25409	 25410	 0.000258	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 25410	 0.001047	 0.007506	 0.00302	 228.5	 228.5	 228.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25410	 25431	 0.003643	 0.020678	 0.00818	 207.71	 207.71	 207.71	 0.0	 0.0	 1	 -30.0	 30.0;
	25411	 25412	 0.000263	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25411	 25413	 0.00025	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 25415	 0.000214	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25414	 25422	 0.000923	 0.00478	 0.00201	 216.82	 216.82	 216.82	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 25416	 0.001065	 0.005252	 0.00492	 202.06	 202.06	 202.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25416	 25444	 0.000766	 0.005123	 0.00544	 209.43	 209.43	 209.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25416	 25537	 0.001477	 0.007646	 0.00353	 213.07	 213.07	 213.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25538	 25416	 0.001883	 0.009314	 0.00395	 188.75	 188.75	 188.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25417	 25482	 0.001278	 0.00849	 0.00707	 234.79	 234.79	 234.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25419	 25420	 0.000214	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25560	 25419	 0.001033	 0.006085	 0.00145	 223.9	 223.9	 223.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25419	 25566	 0.000752	 0.004981	 0.00555	 262.11	 262.11	 262.11	 0.0	 0.0	 1	 -30.0	 30.0;
	25419	 25578	 0.002048	 0.010452	 0.01205	 265.34	 265.34	 265.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 25421	 0.000808	 0.003863	 0.0015	 220.63	 220.63	 220.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25421	 26081	 0.001124	 0.005412	 0.00274	 180.79	 180.79	 180.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25423	 25424	 0.000202	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25423	 25482	 0.000561	 0.00302	 0.00083	 211.47	 211.47	 211.47	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 25425	 0.000332	 0.023444	 0.0	 558.65	 558.65	 558.65	 1.0	 0.0	 1	 -30.0	 30.0;
	25425	 25427	 0.000236	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25425	 25428	 0.000207	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 25452	 0.002326	 0.010823	 0.00345	 231.13	 231.13	 231.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 25453	 0.001175	 0.006177	 0.01225	 241.33	 241.33	 241.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25426	 25499	 0.000397	 0.002581	 0.00432	 209.37	 209.37	 209.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25546	 25426	 0.000801	 0.004348	 0.00167	 218.38	 218.38	 218.38	 0.0	 0.0	 1	 -30.0	 30.0;
	25427	 25674	 0.000396	 0.005383	 0.13732	 1217.63	 1217.63	 1217.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 25427	 0.00023	 0.002854	 0.09287	 1184.13	 1184.13	 1184.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25427	 26126	 0.000547	 0.005213	 0.10553	 1352.66	 1352.66	 1352.66	 0.0	 0.0	 1	 -30.0	 30.0;
	26237	 25427	 0.000309	 0.003912	 0.0723	 1265.36	 1265.36	 1265.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 25430	 0.000289	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25429	 25465	 0.00159	 0.00735	 0.00479	 247.36	 247.36	 247.36	 0.0	 0.0	 1	 -30.0	 30.0;
	25431	 25432	 0.000239	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25431	 25516	 0.000917	 0.006361	 0.00794	 218.21	 218.21	 218.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25433	 25434	 0.000224	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25433	 25588	 0.000819	 0.005474	 0.00196	 204.75	 204.75	 204.75	 0.0	 0.0	 1	 -30.0	 30.0;
	26000	 25433	 0.001468	 0.007243	 0.00164	 228.17	 228.17	 228.17	 0.0	 0.0	 1	 -30.0	 30.0;
	25436	 25937	 0.002091	 0.011654	 0.00569	 204.28	 204.28	 204.28	 0.0	 0.0	 1	 -30.0	 30.0;
	26033	 25436	 0.001018	 0.005073	 0.00345	 197.61	 197.61	 197.61	 0.0	 0.0	 1	 -30.0	 30.0;
	25438	 25437	 0.000413	 0.03235	 0.0	 469.22	 469.22	 469.22	 1.0	 0.0	 1	 -30.0	 30.0;
	25437	 25439	 0.000261	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25437	 25440	 0.00029	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25437	 25441	 0.000263	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25438	 25447	 0.001026	 0.006218	 0.00251	 230.5	 230.5	 230.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25438	 25477	 0.00117	 0.007118	 0.02261	 247.51	 247.51	 247.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25575	 25440	 0.000145	 0.001973	 0.06483	 1107.74	 1107.74	 1107.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25440	 26126	 0.00062	 0.00763	 0.18315	 1339.37	 1339.37	 1339.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 25442	 0.001368	 0.008253	 0.00182	 236.39	 236.39	 236.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25550	 25442	 0.002122	 0.011073	 0.00809	 254.34	 254.34	 254.34	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 25443	 0.001549	 0.008398	 0.00403	 162.15	 162.15	 162.15	 0.0	 0.0	 1	 -30.0	 30.0;
	25443	 26238	 0.001252	 0.007289	 0.00233	 220.55	 220.55	 220.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25444	 25916	 0.000732	 0.003682	 0.00206	 231.69	 231.69	 231.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25445	 25446	 0.000282	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25449	 0.000239	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25448	 25450	 0.000236	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25459	 25449	 0.000558	 0.003474	 0.00145	 267.02	 267.02	 267.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25451	 26127	 0.001747	 0.008791	 0.00369	 255.84	 255.84	 255.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25452	 25488	 0.000998	 0.003887	 0.00143	 186.03	 186.03	 186.03	 0.0	 0.0	 1	 -30.0	 30.0;
	25569	 25453	 0.000637	 0.00474	 0.00271	 203.29	 203.29	 203.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25455	 0.000233	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25501	 0.000943	 0.006417	 0.00268	 249.27	 249.27	 249.27	 0.0	 0.0	 1	 -30.0	 30.0;
	25454	 25520	 0.00042	 0.00312	 0.00332	 188.51	 188.51	 188.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25456	 25556	 0.001126	 0.005631	 0.00348	 183.68	 183.68	 183.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25456	 25593	 0.001793	 0.0087	 0.04422	 222.62	 222.62	 222.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25457	 0.001245	 0.006723	 0.0135	 235.17	 235.17	 235.17	 0.0	 0.0	 1	 -30.0	 30.0;
	25458	 25461	 0.000404	 0.026815	 0.0	 535.76	 535.76	 535.76	 1.0	 0.0	 1	 -30.0	 30.0;
	25458	 25462	 0.000228	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25458	 25463	 0.000242	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25458	 25464	 0.000206	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25459	 25461	 -3.9e-05	 -0.002602	 0.0	 510.76	 510.76	 510.76	 1.0	 0.0	 1	 -30.0	 30.0;
	25460	 25461	 0.001547	 0.102669	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25463	 26126	 0.000739	 0.008249	 0.15432	 1262.95	 1262.95	 1262.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25465	 25466	 0.00026	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25465	 25937	 0.00284	 0.011044	 0.02611	 271.81	 271.81	 271.81	 0.0	 0.0	 1	 -30.0	 30.0;
	25467	 25468	 0.00028	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25608	 25467	 0.001042	 0.005207	 0.00458	 237.56	 237.56	 237.56	 0.0	 0.0	 1	 -30.0	 30.0;
	26000	 25467	 0.000204	 0.001492	 0.00223	 295.94	 295.94	 295.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25469	 25486	 0.00164	 0.00909	 0.01076	 271.72	 271.72	 271.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25469	 25486	 0.00164	 0.00909	 0.01076	 271.72	 271.72	 271.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25471	 25472	 0.000294	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25471	 25499	 0.002523	 0.010684	 0.01199	 248.65	 248.65	 248.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25541	 25471	 0.000729	 0.004852	 0.00252	 224.45	 224.45	 224.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25471	 26045	 0.001652	 0.009493	 0.01407	 258.1	 258.1	 258.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25473	 0.000294	 0.01909	 0.0	 629.99	 629.99	 629.99	 1.1	 0.0	 1	 -30.0	 30.0;
	25474	 25473	 0.000294	 0.01909	 0.0	 629.99	 629.99	 629.99	 1.04375	 0.0	 1	 -30.0	 30.0;
	25474	 25473	 0.000294	 0.01909	 0.0	 629.99	 629.99	 629.99	 1.04375	 0.0	 1	 -30.0	 30.0;
	25473	 25475	 0.000274	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25477	 0.000459	 0.003488	 0.00185	 284.24	 284.24	 284.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25477	 0.000459	 0.003488	 0.00185	 284.24	 284.24	 284.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25477	 0.000459	 0.003488	 0.00185	 284.24	 284.24	 284.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25551	 0.00183	 0.008801	 0.00353	 226.73	 226.73	 226.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25587	 25474	 0.001315	 0.008085	 0.00453	 286.98	 286.98	 286.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25598	 0.000649	 0.003437	 0.00284	 273.67	 273.67	 273.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25474	 25598	 0.000649	 0.003437	 0.00284	 273.67	 273.67	 273.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25575	 25475	 0.0002	 0.002719	 0.04011	 1109.76	 1109.76	 1109.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25475	 25999	 0.000126	 0.001664	 0.03866	 1358.52	 1358.52	 1358.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25476	 25477	 0.000259	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 25548	 0.000247	 0.001322	 0.00348	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 25548	 0.000247	 0.001322	 0.00348	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25477	 25548	 0.000247	 0.001322	 0.00348	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25551	 25477	 0.000897	 0.004756	 0.00319	 210.78	 210.78	 210.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25478	 25479	 0.000224	 0.001185	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25478	 26127	 0.001511	 0.006317	 0.00292	 250.1	 250.1	 250.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25480	 25562	 0.002062	 0.012987	 0.00436	 216.41	 216.41	 216.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25633	 25480	 0.000907	 0.005386	 0.00398	 234.64	 234.64	 234.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25482	 25481	 0.000356	 0.021404	 0.0	 565.33	 565.33	 565.33	 1.0375	 0.0	 1	 -30.0	 30.0;
	25481	 25483	 0.000237	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25489	 25483	 0.000294	 0.003591	 0.06658	 1050.19	 1050.19	 1050.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25484	 25485	 0.000212	 0.001135	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25491	 0.002003	 0.009867	 0.01136	 244.97	 244.97	 244.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25485	 25683	 0.001289	 0.007553	 0.00836	 220.41	 220.41	 220.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25486	 25487	 0.000219	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25486	 25989	 0.001359	 0.009602	 0.01179	 286.95	 286.95	 286.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25486	 25989	 0.001359	 0.009602	 0.01179	 286.95	 286.95	 286.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25486	 25989	 0.001359	 0.009602	 0.01179	 286.95	 286.95	 286.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25488	 0.00065	 0.003646	 0.00107	 209.35	 209.35	 209.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25488	 25660	 0.000808	 0.004793	 0.01063	 200.62	 200.62	 200.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25490	 25489	 0.000372	 0.024377	 0.0	 623.91	 623.91	 623.91	 1.01875	 0.0	 1	 -30.0	 30.0;
	25490	 25489	 0.000372	 0.024377	 0.0	 623.91	 623.91	 623.91	 1.1	 0.0	 1	 -30.0	 30.0;
	25490	 25489	 0.000372	 0.024377	 0.0	 623.91	 623.91	 623.91	 1.1	 0.0	 1	 -30.0	 30.0;
	25489	 26126	 0.000216	 0.00265	 0.04475	 1419.32	 1419.32	 1419.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25541	 25490	 0.001494	 0.00794	 0.00263	 245.21	 245.21	 245.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25491	 25494	 0.000465	 0.015086	 0.0	 101.85	 101.85	 101.85	 1.0	 0.0	 1	 -30.0	 30.0;
	25549	 25491	 0.000544	 0.003553	 0.00614	 232.41	 232.41	 232.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25491	 25853	 0.000277	 0.001718	 0.00118	 199.01	 199.01	 199.01	 0.0	 0.0	 1	 -30.0	 30.0;
	26192	 25491	 0.000333	 0.001923	 0.00077	 227.3	 227.3	 227.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25492	 25494	 0.009981	 0.323978	 0.0	 50.93	 50.93	 50.93	 1.0	 0.0	 1	 -30.0	 30.0;
	25493	 25494	 0.009981	 0.323978	 0.0	 50.93	 50.93	 50.93	 1.0	 0.0	 1	 -30.0	 30.0;
	25495	 25496	 0.000288	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25567	 25495	 0.00187	 0.010211	 0.00394	 241.15	 241.15	 241.15	 0.0	 0.0	 1	 -30.0	 30.0;
	25495	 25928	 0.0013	 0.006953	 0.00895	 234.44	 234.44	 234.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25495	 25989	 0.002222	 0.011976	 0.01197	 229.55	 229.55	 229.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25497	 25593	 0.001025	 0.00649	 0.01049	 202.86	 202.86	 202.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25556	 25498	 0.000881	 0.00518	 0.00193	 228.51	 228.51	 228.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25985	 25498	 0.001385	 0.006722	 0.00727	 240.72	 240.72	 240.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25499	 25660	 0.001462	 0.007524	 0.00948	 236.53	 236.53	 236.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25501	 25502	 0.000237	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25503	 25504	 0.000241	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25503	 25580	 0.000839	 0.00524	 0.00948	 226.67	 226.67	 226.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25503	 25634	 0.001233	 0.009279	 0.01564	 201.51	 201.51	 201.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25643	 25503	 0.001171	 0.006589	 0.00415	 190.66	 190.66	 190.66	 0.0	 0.0	 1	 -30.0	 30.0;
	25505	 25506	 0.000237	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25505	 0.001537	 0.0068	 0.00855	 248.51	 248.51	 248.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25505	 25581	 0.001253	 0.006689	 0.00559	 233.23	 233.23	 233.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25507	 25608	 0.001265	 0.009004	 0.00405	 223.91	 223.91	 223.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25626	 25507	 0.000722	 0.004327	 0.00144	 170.0	 170.0	 170.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25591	 25508	 0.004588	 0.026268	 0.01973	 255.06	 255.06	 255.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25508	 25631	 0.009501	 0.047234	 0.01628	 228.9	 228.9	 228.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25508	 0.002223	 0.013964	 0.01433	 286.68	 286.68	 286.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25508	 0.002223	 0.013964	 0.01433	 286.68	 286.68	 286.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25508	 0.002223	 0.013964	 0.01433	 286.68	 286.68	 286.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25508	 25642	 0.003602	 0.020697	 0.01378	 248.12	 248.12	 248.12	 0.0	 0.0	 1	 -30.0	 30.0;
	25509	 25536	 0.003259	 0.014185	 0.03554	 241.72	 241.72	 241.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25509	 0.00092	 0.006284	 0.00357	 280.69	 280.69	 280.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25509	 0.00092	 0.006284	 0.00357	 280.69	 280.69	 280.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25579	 25509	 0.00092	 0.006284	 0.00357	 280.69	 280.69	 280.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25605	 25509	 0.000948	 0.006016	 0.00383	 258.37	 258.37	 258.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25536	 0.001722	 0.008241	 0.02067	 216.86	 216.86	 216.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25563	 0.000572	 0.00304	 0.00177	 199.04	 199.04	 199.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25510	 25838	 0.002861	 0.018327	 0.01129	 232.17	 232.17	 232.17	 0.0	 0.0	 1	 -30.0	 30.0;
	25511	 25517	 0.002475	 0.01315	 0.01705	 170.84	 170.84	 170.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25511	 25538	 0.001852	 0.010625	 0.00952	 199.76	 199.76	 199.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25620	 25511	 0.001475	 0.0073	 0.00257	 221.79	 221.79	 221.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25512	 25513	 0.000236	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25512	 25516	 0.002605	 0.01216	 0.00624	 190.03	 190.03	 190.03	 0.0	 0.0	 1	 -30.0	 30.0;
	25512	 25633	 0.000932	 0.004865	 0.00176	 220.69	 220.69	 220.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25514	 25515	 0.004086	 0.019503	 0.00629	 228.38	 228.38	 228.38	 0.0	 0.0	 1	 -30.0	 30.0;
	25514	 25727	 0.016346	 0.082799	 0.0293	 199.46	 199.46	 199.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25518	 0.004452	 0.022528	 0.09062	 293.79	 293.79	 293.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25518	 0.004452	 0.022528	 0.09062	 293.79	 293.79	 293.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25518	 0.004452	 0.022528	 0.09062	 293.79	 293.79	 293.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25515	 25991	 0.00303	 0.016937	 0.00871	 269.95	 269.95	 269.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25516	 25569	 0.001763	 0.00771	 0.00584	 227.88	 227.88	 227.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25516	 25612	 0.0026	 0.012692	 0.00338	 201.0	 201.0	 201.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25516	 25665	 0.001079	 0.006299	 0.04133	 238.25	 238.25	 238.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25518	 25519	 0.000219	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25518	 25620	 0.005432	 0.033404	 0.02259	 249.94	 249.94	 249.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25518	 0.002447	 0.017045	 0.00754	 248.07	 248.07	 248.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25521	 25536	 0.001965	 0.007093	 0.01422	 232.75	 232.75	 232.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25552	 25521	 0.000761	 0.004957	 0.00347	 207.5	 207.5	 207.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25522	 25523	 0.000249	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25523	 25545	 0.000796	 0.005435	 0.00524	 189.19	 189.19	 189.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25523	 25685	 0.001266	 0.006631	 0.00165	 225.9	 225.9	 225.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25524	 25591	 0.001886	 0.010663	 0.00296	 244.8	 244.8	 244.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25690	 25524	 0.000848	 0.006344	 0.00233	 214.49	 214.49	 214.49	 0.0	 0.0	 1	 -30.0	 30.0;
	25525	 25526	 0.00029	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25525	 25527	 0.000206	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25527	 25547	 0.000518	 0.003034	 0.0062	 223.23	 223.23	 223.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25564	 25527	 0.001781	 0.009616	 0.01115	 212.09	 212.09	 212.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25528	 25529	 0.000223	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25875	 25528	 0.002045	 0.009155	 0.00547	 217.65	 217.65	 217.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25528	 25989	 0.000608	 0.003514	 0.00238	 399.96	 399.96	 399.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25530	 26041	 0.000326	 0.002106	 0.00141	 269.37	 269.37	 269.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25530	 26041	 0.000326	 0.002106	 0.00141	 269.37	 269.37	 269.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25531	 25602	 0.005831	 0.0301	 0.0579	 236.82	 236.82	 236.82	 0.0	 0.0	 1	 -30.0	 30.0;
	25531	 25640	 0.00206	 0.013997	 0.00823	 230.32	 230.32	 230.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25532	 25533	 0.000235	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25533	 25563	 0.001241	 0.007203	 0.00908	 202.56	 202.56	 202.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 25533	 0.001162	 0.005296	 0.00173	 226.86	 226.86	 226.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25534	 25535	 0.00021	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25535	 25576	 0.001287	 0.009351	 0.00504	 209.37	 209.37	 209.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25535	 25598	 0.00043	 0.003194	 0.00355	 194.01	 194.01	 194.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25536	 25688	 0.001448	 0.008985	 0.00364	 179.39	 179.39	 179.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25538	 25539	 0.000294	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25540	 25541	 0.000215	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25542	 25543	 0.00026	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25606	 25544	 0.001486	 0.00779	 0.00477	 237.53	 237.53	 237.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25858	 25544	 0.001588	 0.005752	 0.00245	 266.05	 266.05	 266.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25636	 25545	 0.001164	 0.007638	 0.00275	 224.65	 224.65	 224.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25547	 25546	 0.000987	 0.006259	 0.00569	 197.15	 197.15	 197.15	 0.0	 0.0	 1	 -30.0	 30.0;
	25548	 25656	 0.000428	 0.002708	 0.00103	 275.45	 275.45	 275.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25548	 25656	 0.000428	 0.002708	 0.00103	 275.45	 275.45	 275.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25989	 25549	 0.0006	 0.003308	 0.00258	 273.5	 273.5	 273.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25989	 25549	 0.0006	 0.003308	 0.00258	 273.5	 273.5	 273.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25549	 26081	 0.000834	 0.004941	 0.002	 226.02	 226.02	 226.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25573	 25551	 0.001116	 0.006057	 0.00263	 207.08	 207.08	 207.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25552	 25553	 0.000232	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25552	 25555	 0.000737	 0.003864	 0.00183	 212.32	 212.32	 212.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25554	 25555	 0.000251	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25555	 25656	 0.000951	 0.006041	 0.0087	 252.96	 252.96	 252.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25610	 25556	 0.001467	 0.009289	 0.00366	 208.08	 208.08	 208.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25558	 25557	 0.000558	 0.033536	 0.0	 461.86	 461.86	 461.86	 1.03125	 0.0	 1	 -30.0	 30.0;
	25557	 25559	 0.000224	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 25874	 0.000432	 0.005025	 0.24746	 1182.55	 1182.55	 1182.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 26095	 0.000412	 0.004699	 0.08724	 1250.21	 1250.21	 1250.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25557	 28158	 0.000679	 0.008567	 0.3748	 1229.32	 1229.32	 1229.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25558	 25604	 0.000514	 0.002768	 0.00172	 264.8	 264.8	 264.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25558	 28030	 0.005367	 0.029019	 0.03272	 220.77	 220.77	 220.77	 0.0	 0.0	 1	 -30.0	 30.0;
	25560	 25875	 0.001045	 0.006196	 0.00302	 248.7	 248.7	 248.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25581	 25561	 0.000581	 0.003564	 0.00284	 217.91	 217.91	 217.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25562	 25658	 0.00236	 0.013581	 0.00331	 196.82	 196.82	 196.82	 0.0	 0.0	 1	 -30.0	 30.0;
	25562	 25665	 0.001355	 0.008732	 0.00435	 162.06	 162.06	 162.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25598	 25563	 0.000767	 0.004143	 0.00278	 224.42	 224.42	 224.42	 0.0	 0.0	 1	 -30.0	 30.0;
	25564	 25888	 0.001426	 0.008249	 0.00573	 202.62	 202.62	 202.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25565	 25570	 0.001135	 0.006932	 0.00892	 223.98	 223.98	 223.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25610	 25565	 0.000972	 0.004081	 0.00323	 184.32	 184.32	 184.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25853	 25566	 0.000325	 0.002334	 0.00227	 237.55	 237.55	 237.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25566	 26081	 0.000236	 0.001387	 0.00397	 241.1	 241.1	 241.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25567	 25568	 0.000281	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25985	 25570	 0.001132	 0.006602	 0.00272	 262.44	 262.44	 262.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 25572	 0.000273	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 25673	 0.002105	 0.011735	 0.01784	 179.57	 179.57	 179.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25571	 25931	 0.002776	 0.017597	 0.01494	 218.21	 218.21	 218.21	 0.0	 0.0	 1	 -30.0	 30.0;
	26000	 25573	 0.001385	 0.008389	 0.00449	 214.62	 214.62	 214.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 25574	 0.00268	 0.012065	 0.00802	 269.23	 269.23	 269.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 26238	 0.000764	 0.003648	 0.00186	 280.4	 280.4	 280.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 26238	 0.000764	 0.003648	 0.00186	 280.4	 280.4	 280.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25574	 26238	 0.000764	 0.003648	 0.00186	 280.4	 280.4	 280.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 25575	 0.000492	 0.036238	 0.0	 459.85	 459.85	 459.85	 1.04375	 0.0	 1	 -30.0	 30.0;
	26021	 25575	 0.000416	 0.005532	 0.12839	 1172.35	 1172.35	 1172.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25576	 25584	 0.001373	 0.005494	 0.00427	 137.17	 137.17	 137.17	 0.0	 0.0	 1	 -30.0	 30.0;
	25577	 25578	 0.000256	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25578	 25673	 0.001873	 0.007895	 0.03089	 238.16	 238.16	 238.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25579	 0.000566	 0.003439	 0.0009	 294.43	 294.43	 294.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25579	 0.000566	 0.003439	 0.0009	 294.43	 294.43	 294.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25579	 0.000566	 0.003439	 0.0009	 294.43	 294.43	 294.43	 0.0	 0.0	 1	 -30.0	 30.0;
	25605	 25580	 0.001066	 0.006199	 0.0027	 240.37	 240.37	 240.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25582	 25583	 0.000283	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25582	 25584	 0.000295	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25582	 25585	 0.00021	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25709	 25586	 0.000519	 0.003549	 0.00542	 220.45	 220.45	 220.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25931	 25586	 0.001521	 0.007237	 0.00238	 248.46	 248.46	 248.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25587	 25626	 0.002202	 0.012065	 0.0086	 214.81	 214.81	 214.81	 0.0	 0.0	 1	 -30.0	 30.0;
	25588	 25589	 0.000236	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25656	 25588	 0.000813	 0.004197	 0.00217	 218.67	 218.67	 218.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25875	 0.000429	 0.002814	 0.00159	 299.5	 299.5	 299.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25875	 0.000429	 0.002814	 0.00159	 299.5	 299.5	 299.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25875	 0.000429	 0.002814	 0.00159	 299.5	 299.5	 299.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25590	 25875	 0.000429	 0.002814	 0.00159	 299.5	 299.5	 299.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25591	 25592	 0.000287	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 25593	 0.001491	 0.007839	 0.0061	 223.78	 223.78	 223.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25594	 25597	 0.000129	 0.010173	 0.0	 680.0	 680.0	 680.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25594	 25639	 0.000623	 0.007131	 0.42443	 1319.11	 1319.11	 1319.11	 0.0	 0.0	 1	 -30.0	 30.0;
	25713	 25594	 0.000311	 0.00383	 0.04742	 1262.48	 1262.48	 1262.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25594	 25986	 0.000288	 0.003591	 0.047	 1155.18	 1155.18	 1155.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25594	 26126	 0.000683	 0.008867	 0.14383	 1244.0	 1244.0	 1244.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 25597	 4.9e-05	 0.00383	 0.0	 730.24	 730.24	 730.24	 1.0	 0.0	 1	 -30.0	 30.0;
	25595	 25637	 0.001673	 0.00938	 0.0068	 254.69	 254.69	 254.69	 0.0	 0.0	 1	 -30.0	 30.0;
	25715	 25595	 0.001804	 0.010238	 0.01121	 217.68	 217.68	 217.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 25726	 0.001043	 0.006463	 0.00196	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25595	 25743	 0.002044	 0.013362	 0.02393	 254.76	 254.76	 254.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25596	 25597	 0.000927	 0.073183	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25599	 25600	 0.000284	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25600	 25602	 0.005449	 0.034106	 0.00798	 240.51	 240.51	 240.51	 0.0	 0.0	 1	 -30.0	 30.0;
	25600	 25851	 0.00695	 0.036348	 0.07053	 257.05	 257.05	 257.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25601	 25602	 0.000219	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25602	 25710	 0.003765	 0.024465	 0.02566	 207.14	 207.14	 207.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25603	 25604	 0.00024	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25604	 25622	 0.001798	 0.010245	 0.00272	 210.95	 210.95	 210.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28000	 25604	 0.000284	 0.001746	 0.00589	 240.44	 240.44	 240.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25606	 25621	 0.005354	 0.026605	 0.02051	 226.78	 226.78	 226.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25683	 25606	 0.001238	 0.005991	 0.00164	 179.44	 179.44	 179.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25634	 25607	 0.000986	 0.006378	 0.00333	 204.59	 204.59	 204.59	 0.0	 0.0	 1	 -30.0	 30.0;
	25651	 25607	 0.000889	 0.004657	 0.00591	 231.83	 231.83	 231.83	 0.0	 0.0	 1	 -30.0	 30.0;
	25607	 28024	 0.003717	 0.020747	 0.02216	 258.06	 258.06	 258.06	 0.0	 0.0	 1	 -30.0	 30.0;
	25609	 26172	 0.003158	 0.015689	 0.00752	 285.3	 285.3	 285.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25609	 28042	 0.001094	 0.006989	 0.0026	 242.04	 242.04	 242.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25610	 25611	 0.000256	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25663	 25610	 0.00072	 0.00366	 0.00707	 186.56	 186.56	 186.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25612	 25613	 0.000226	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25612	 26000	 0.001632	 0.009772	 0.00526	 242.95	 242.95	 242.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25614	 25615	 0.00025	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25614	 25616	 0.000291	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25709	 25615	 0.001324	 0.006587	 0.00649	 236.16	 236.16	 236.16	 0.0	 0.0	 1	 -30.0	 30.0;
	28004	 25615	 0.000973	 0.005555	 0.00263	 187.44	 187.44	 187.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25617	 25618	 0.000238	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25619	 25664	 0.003167	 0.017742	 0.04214	 228.35	 228.35	 228.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25695	 25619	 0.001713	 0.008052	 0.00301	 206.48	 206.48	 206.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25621	 25652	 0.00225	 0.006999	 0.00581	 206.52	 206.52	 206.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 25623	 0.000269	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28000	 25622	 0.000751	 0.004178	 0.00921	 231.05	 231.05	 231.05	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 28008	 0.000818	 0.00503	 0.00186	 197.79	 197.79	 197.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25622	 28063	 0.001905	 0.011141	 0.01238	 217.29	 217.29	 217.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25624	 25696	 0.00272	 0.013644	 0.01088	 210.38	 210.38	 210.38	 0.0	 0.0	 1	 -30.0	 30.0;
	25624	 25985	 0.001799	 0.013449	 0.00492	 237.23	 237.23	 237.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25625	 25626	 0.000214	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25625	 25627	 0.000262	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25628	 25695	 0.003492	 0.018256	 0.01783	 169.48	 169.48	 169.48	 0.0	 0.0	 1	 -30.0	 30.0;
	25628	 26076	 0.002081	 0.012061	 0.00499	 217.86	 217.86	 217.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25629	 25630	 0.000276	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25629	 25631	 0.000267	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25715	 25631	 0.002336	 0.010711	 0.00448	 192.23	 192.23	 192.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25633	 25632	 0.000889	 0.026981	 0.0	 543.1	 543.1	 543.1	 1.1	 0.0	 1	 -30.0	 30.0;
	25632	 25930	 0.000436	 0.005457	 0.11562	 1146.87	 1146.87	 1146.87	 0.0	 0.0	 1	 -30.0	 30.0;
	25632	 26126	 0.00061	 0.006877	 0.16653	 1344.33	 1344.33	 1344.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25633	 25663	 0.000755	 0.005666	 0.0139	 243.49	 243.49	 243.49	 0.0	 0.0	 1	 -30.0	 30.0;
	25635	 25636	 0.000211	 0.001128	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25636	 28024	 0.001827	 0.012942	 0.00452	 280.21	 280.21	 280.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25637	 25638	 0.000282	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25637	 25694	 0.000751	 0.004487	 0.01059	 239.27	 239.27	 239.27	 0.0	 0.0	 1	 -30.0	 30.0;
	25640	 25639	 0.000723	 0.039687	 0.0	 442.6	 442.6	 442.6	 1.0	 0.0	 1	 -30.0	 30.0;
	25639	 25641	 0.000236	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25990	 25639	 0.001215	 0.012933	 0.24775	 1284.21	 1284.21	 1284.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25639	 26228	 0.001014	 0.010589	 0.27521	 1221.86	 1221.86	 1221.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25768	 25642	 0.002592	 0.014555	 0.04823	 212.97	 212.97	 212.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25643	 25673	 0.001209	 0.006436	 0.00924	 187.86	 187.86	 187.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25644	 25645	 0.000235	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28001	 25644	 0.00097	 0.004256	 0.00167	 210.75	 210.75	 210.75	 0.0	 0.0	 1	 -30.0	 30.0;
	25644	 28022	 0.000841	 0.003987	 0.00166	 242.58	 242.58	 242.58	 0.0	 0.0	 1	 -30.0	 30.0;
	25644	 28025	 0.001294	 0.007208	 0.02264	 240.26	 240.26	 240.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25646	 25838	 0.002674	 0.012093	 0.0084	 216.63	 216.63	 216.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25646	 26081	 0.001296	 0.006463	 0.01972	 236.1	 236.1	 236.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25647	 25648	 0.00022	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25647	 25649	 0.0002	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25647	 25650	 0.000267	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25649	 25700	 0.001337	 0.007371	 0.0035	 383.49	 383.49	 383.49	 0.0	 0.0	 1	 -30.0	 30.0;
	25649	 26172	 0.000959	 0.005247	 0.00528	 319.93	 319.93	 319.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25649	 26172	 0.000959	 0.005247	 0.00528	 319.93	 319.93	 319.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25649	 26172	 0.000959	 0.005247	 0.00528	 319.93	 319.93	 319.93	 0.0	 0.0	 1	 -30.0	 30.0;
	25649	 26172	 0.000959	 0.005247	 0.00528	 319.93	 319.93	 319.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 25649	 0.001273	 0.007891	 0.00436	 297.03	 297.03	 297.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 25649	 0.001273	 0.007891	 0.00436	 297.03	 297.03	 297.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 25649	 0.001273	 0.007891	 0.00436	 297.03	 297.03	 297.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 25649	 0.001273	 0.007891	 0.00436	 297.03	 297.03	 297.03	 0.0	 0.0	 1	 -30.0	 30.0;
	25651	 28004	 0.003304	 0.015274	 0.01509	 209.78	 209.78	 209.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 25653	 0.000245	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 25686	 0.000699	 0.004321	 0.00256	 240.12	 240.12	 240.12	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 28009	 0.001466	 0.006326	 0.00328	 374.8	 374.8	 374.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 28010	 0.001856	 0.009474	 0.01292	 239.99	 239.99	 239.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25652	 28100	 0.002783	 0.013916	 0.01675	 230.3	 230.3	 230.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25654	 25655	 0.000221	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25654	 25656	 0.000205	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25657	 25675	 0.000876	 0.005469	 0.02829	 222.62	 222.62	 222.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25742	 25657	 0.001726	 0.008477	 0.00356	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25658	 25985	 0.00344	 0.025416	 0.01528	 223.22	 223.22	 223.22	 0.0	 0.0	 1	 -30.0	 30.0;
	25659	 25671	 0.001266	 0.006641	 0.00874	 214.45	 214.45	 214.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 25659	 0.001574	 0.011737	 0.0082	 217.84	 217.84	 217.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25661	 25662	 0.000242	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25661	 25663	 0.001615	 0.007352	 0.00945	 221.4	 221.4	 221.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25661	 25690	 0.001471	 0.008994	 0.06424	 175.31	 175.31	 175.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25696	 25661	 0.000986	 0.005719	 0.0037	 163.04	 163.04	 163.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25666	 25669	 0.00049	 0.016487	 0.0	 100.36	 100.36	 100.36	 1.0	 0.0	 1	 -30.0	 30.0;
	25666	 25670	 0.000289	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25666	 25671	 0.000281	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25667	 25669	 0.007409	 0.249453	 0.0	 50.18	 50.18	 50.18	 1.0	 0.0	 1	 -30.0	 30.0;
	25668	 25669	 0.007409	 0.249453	 0.0	 50.18	 50.18	 50.18	 1.0	 0.0	 1	 -30.0	 30.0;
	25671	 25694	 0.000466	 0.002827	 0.00273	 218.5	 218.5	 218.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25671	 25726	 0.00208	 0.013663	 0.0104	 222.53	 222.53	 222.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25688	 25672	 0.000619	 0.003088	 0.00606	 199.76	 199.76	 199.76	 0.0	 0.0	 1	 -30.0	 30.0;
	25672	 25931	 0.000985	 0.00466	 0.00206	 238.26	 238.26	 238.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25674	 25677	 0.001933	 0.105649	 0.0	 565.72	 565.72	 565.72	 1.0	 0.0	 1	 -30.0	 30.0;
	25930	 25674	 0.000185	 0.002158	 0.03521	 1037.8	 1037.8	 1037.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25675	 25677	 -0.001254	 -0.068551	 0.0	 490.72	 490.72	 490.72	 1.0	 0.0	 1	 -30.0	 30.0;
	25676	 25677	 0.003943	 0.215533	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25678	 25679	 0.000234	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25678	 25680	 0.000203	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25680	 25717	 0.002342	 0.011904	 0.00363	 228.23	 228.23	 228.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25730	 25680	 0.001206	 0.007821	 0.00317	 253.35	 253.35	 253.35	 0.0	 0.0	 1	 -30.0	 30.0;
	28016	 25680	 0.001784	 0.010216	 0.0081	 205.26	 205.26	 205.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25681	 25682	 0.000205	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25681	 25683	 0.000248	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25684	 28001	 0.000297	 0.001923	 0.00127	 181.02	 181.02	 181.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 25684	 0.000987	 0.004366	 0.00123	 227.99	 227.99	 227.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25685	 28003	 0.001664	 0.007481	 0.0044	 255.37	 255.37	 255.37	 0.0	 0.0	 1	 -30.0	 30.0;
	28001	 25686	 0.000932	 0.005424	 0.00426	 289.53	 289.53	 289.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28001	 25686	 0.000932	 0.005424	 0.00426	 289.53	 289.53	 289.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28001	 25686	 0.000932	 0.005424	 0.00426	 289.53	 289.53	 289.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25686	 28033	 0.003248	 0.017342	 0.00645	 225.5	 225.5	 225.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25686	 28073	 0.002044	 0.007674	 0.00293	 248.39	 248.39	 248.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25734	 25687	 0.001538	 0.006623	 0.00192	 207.02	 207.02	 207.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25878	 25687	 0.001427	 0.007824	 0.00593	 226.89	 226.89	 226.89	 0.0	 0.0	 1	 -30.0	 30.0;
	25688	 25689	 0.000273	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25691	 25692	 0.000264	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25692	 25734	 0.000934	 0.00499	 0.00684	 219.15	 219.15	 219.15	 0.0	 0.0	 1	 -30.0	 30.0;
	25743	 25692	 0.00125	 0.007275	 0.00243	 236.35	 236.35	 236.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25693	 25720	 0.001828	 0.010581	 0.06592	 199.68	 199.68	 199.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25693	 25985	 0.001322	 0.008768	 0.01167	 227.99	 227.99	 227.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25696	 25697	 0.000219	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25698	 25728	 0.003409	 0.015671	 0.02048	 229.57	 229.57	 229.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25698	 26076	 0.001972	 0.010757	 0.00274	 241.98	 241.98	 241.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25699	 25709	 0.001607	 0.008905	 0.01252	 232.11	 232.11	 232.11	 0.0	 0.0	 1	 -30.0	 30.0;
	25699	 28024	 0.003492	 0.019317	 0.01204	 250.07	 250.07	 250.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25700	 25701	 0.000263	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 25700	 0.001471	 0.007704	 0.00252	 268.95	 268.95	 268.95	 0.0	 0.0	 1	 -30.0	 30.0;
	25702	 25717	 0.001796	 0.009118	 0.00331	 203.53	 203.53	 203.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28084	 25702	 0.004035	 0.023757	 0.0049	 178.45	 178.45	 178.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 25704	 0.000234	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25706	 25703	 0.001639	 0.008869	 0.00152	 214.74	 214.74	 214.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25703	 25714	 0.001503	 0.009025	 0.00369	 239.58	 239.58	 239.58	 0.0	 0.0	 1	 -30.0	 30.0;
	25747	 25703	 0.001275	 0.008215	 0.00557	 198.26	 198.26	 198.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25724	 25705	 0.001372	 0.005354	 0.00284	 212.02	 212.02	 212.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25726	 25705	 0.000867	 0.003198	 0.00484	 229.29	 229.29	 229.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25706	 25707	 0.00024	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25759	 25706	 0.001089	 0.006394	 0.00401	 181.81	 181.81	 181.81	 0.0	 0.0	 1	 -30.0	 30.0;
	25716	 25708	 0.000699	 0.003526	 0.00177	 195.78	 195.78	 195.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25708	 25723	 0.001526	 0.010837	 0.01919	 234.77	 234.77	 234.77	 0.0	 0.0	 1	 -30.0	 30.0;
	26076	 25708	 0.000823	 0.004345	 0.00286	 261.16	 261.16	 261.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25710	 25711	 0.000293	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25710	 25773	 0.007343	 0.04642	 0.01552	 229.66	 229.66	 229.66	 0.0	 0.0	 1	 -30.0	 30.0;
	25768	 25712	 0.009192	 0.045699	 0.0388	 241.79	 241.79	 241.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 25713	 0.000304	 0.01907	 0.0	 690.0	 690.0	 690.0	 1.1	 0.0	 1	 -30.0	 30.0;
	25713	 25771	 0.000602	 0.006199	 0.11273	 1228.6	 1228.6	 1228.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25713	 28141	 0.000562	 0.006096	 0.20275	 1182.65	 1182.65	 1182.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 25721	 0.002139	 0.013936	 0.02372	 236.08	 236.08	 236.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25714	 25737	 0.001122	 0.007677	 0.00596	 178.53	 178.53	 178.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25763	 25714	 0.002677	 0.009183	 0.00472	 231.7	 231.7	 231.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25716	 25878	 0.00311	 0.015426	 0.01309	 200.74	 200.74	 200.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28019	 25718	 0.000446	 0.002236	 0.00432	 226.79	 226.79	 226.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25718	 28947	 0.000398	 0.002431	 0.00281	 201.21	 201.21	 201.21	 0.0	 0.0	 1	 -30.0	 30.0;
	25719	 25720	 0.000281	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25738	 25720	 0.001189	 0.007204	 0.00369	 198.28	 198.28	 198.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25721	 25722	 0.000263	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25721	 25759	 0.001296	 0.007879	 0.00399	 194.55	 194.55	 194.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25723	 28084	 0.000949	 0.005307	 0.00143	 214.01	 214.01	 214.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25724	 25725	 0.000234	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25724	 25737	 0.002022	 0.012719	 0.00406	 180.28	 180.28	 180.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25727	 25775	 0.005427	 0.032137	 0.02368	 218.12	 218.12	 218.12	 0.0	 0.0	 1	 -30.0	 30.0;
	25728	 25751	 0.001453	 0.010529	 0.01567	 218.33	 218.33	 218.33	 0.0	 0.0	 1	 -30.0	 30.0;
	25728	 25790	 0.001113	 0.005658	 0.00369	 215.8	 215.8	 215.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28032	 25728	 0.002277	 0.010708	 0.00391	 199.45	 199.45	 199.45	 0.0	 0.0	 1	 -30.0	 30.0;
	25730	 25729	 0.000553	 0.033688	 0.0	 485.64	 485.64	 485.64	 1.0	 0.0	 1	 -30.0	 30.0;
	25729	 25930	 0.000277	 0.003342	 0.04919	 1062.91	 1062.91	 1062.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 25986	 0.000616	 0.007267	 0.22848	 1224.52	 1224.52	 1224.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25729	 28038	 0.000424	 0.004916	 0.11231	 1122.08	 1122.08	 1122.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25731	 25732	 0.000207	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25731	 25733	 0.000265	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25733	 25744	 0.000842	 0.004779	 0.0086	 197.28	 197.28	 197.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25733	 25878	 0.002866	 0.015075	 0.01104	 238.82	 238.82	 238.82	 0.0	 0.0	 1	 -30.0	 30.0;
	28087	 25733	 0.002521	 0.009696	 0.00759	 211.97	 211.97	 211.97	 0.0	 0.0	 1	 -30.0	 30.0;
	25734	 25735	 0.000224	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25745	 25736	 0.00104	 0.005948	 0.00572	 211.9	 211.9	 211.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25748	 25736	 0.002096	 0.011033	 0.00675	 189.86	 189.86	 189.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25737	 25749	 0.003302	 0.017225	 0.01813	 180.11	 180.11	 180.11	 0.0	 0.0	 1	 -30.0	 30.0;
	25749	 25738	 0.002824	 0.011533	 0.0106	 215.44	 215.44	 215.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25738	 25768	 0.001558	 0.010018	 0.00813	 238.19	 238.19	 238.19	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 25754	 0.001168	 0.007267	 0.00519	 198.28	 198.28	 198.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 28053	 0.002441	 0.016405	 0.01142	 217.94	 217.94	 217.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 28054	 0.002629	 0.019537	 0.01829	 197.63	 197.63	 197.63	 0.0	 0.0	 1	 -30.0	 30.0;
	25739	 28111	 0.00043	 0.002495	 0.0025	 200.78	 200.78	 200.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25740	 25741	 0.000218	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25740	 25742	 0.000227	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25742	 25931	 0.003649	 0.017779	 0.01221	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25744	 28142	 0.00218	 0.013305	 0.01164	 227.08	 227.08	 227.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25745	 25746	 0.000268	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25812	 25745	 0.002797	 0.016583	 0.00964	 240.98	 240.98	 240.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25747	 25763	 0.001403	 0.008034	 0.00347	 211.35	 211.35	 211.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25748	 25768	 0.005837	 0.026836	 0.03193	 237.53	 237.53	 237.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25748	 25799	 0.001246	 0.008013	 0.00346	 214.04	 214.04	 214.04	 0.0	 0.0	 1	 -30.0	 30.0;
	25750	 25751	 0.000208	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25878	 25751	 0.003174	 0.017058	 0.00395	 233.3	 233.3	 233.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25752	 25780	 0.002591	 0.012619	 0.02237	 196.13	 196.13	 196.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25752	 25878	 0.003302	 0.021645	 0.00656	 218.59	 218.59	 218.59	 0.0	 0.0	 1	 -30.0	 30.0;
	25753	 28172	 0.002089	 0.009756	 0.03083	 212.32	 212.32	 212.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25753	 29045	 0.001068	 0.007492	 0.00229	 176.44	 176.44	 176.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25754	 28071	 0.001515	 0.00935	 0.00428	 203.37	 203.37	 203.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 25756	 0.000225	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 25757	 0.00021	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25755	 25758	 0.000212	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25780	 25757	 0.001689	 0.009126	 0.01165	 200.91	 200.91	 200.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25757	 25781	 0.00209	 0.011261	 0.01523	 222.52	 222.52	 222.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25759	 25762	 0.0001	 -0.001745	 0.0	 222.63	 222.63	 222.63	 1.0	 0.0	 1	 -30.0	 30.0;
	25759	 25799	 0.002391	 0.0124	 0.01877	 174.46	 174.46	 174.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25760	 25762	 0.005299	 0.146264	 0.0	 111.32	 111.32	 111.32	 1.0	 0.0	 1	 -30.0	 30.0;
	25761	 25762	 0.005299	 0.146264	 0.0	 111.32	 111.32	 111.32	 1.0	 0.0	 1	 -30.0	 30.0;
	26111	 25764	 0.004776	 0.024165	 0.02159	 182.07	 182.07	 182.07	 0.0	 0.0	 1	 -30.0	 30.0;
	25765	 25766	 0.000297	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25766	 25823	 0.005141	 0.02399	 0.03131	 232.0	 232.0	 232.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28192	 25766	 0.009754	 0.061971	 0.01948	 192.92	 192.92	 192.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25767	 25770	 0.000951	 0.051255	 0.0	 594.32	 594.32	 594.32	 1.0	 0.0	 1	 -30.0	 30.0;
	25767	 25771	 0.000275	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25767	 25772	 0.000283	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25768	 25770	 -0.000344	 -0.018529	 0.0	 468.92	 468.92	 468.92	 1.0	 0.0	 1	 -30.0	 30.0;
	25768	 25794	 0.002142	 0.014345	 0.03609	 233.5	 233.5	 233.5	 0.0	 0.0	 1	 -30.0	 30.0;
	25769	 25770	 0.00315	 0.16976	 0.0	 125.4	 125.4	 125.4	 1.0	 0.0	 1	 -30.0	 30.0;
	25771	 25774	 0.001338	 0.016715	 0.34852	 1179.79	 1179.79	 1179.79	 0.0	 0.0	 1	 -30.0	 30.0;
	25813	 25771	 0.000708	 0.007864	 0.10673	 1194.2	 1194.2	 1194.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25771	 25936	 0.001408	 0.01765	 0.75869	 1370.44	 1370.44	 1370.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25773	 26003	 0.01591	 0.068637	 0.06762	 260.16	 260.16	 260.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 25777	 0.00023	 0.017309	 0.0	 446.99	 446.99	 446.99	 1.0	 0.0	 1	 -30.0	 30.0;
	25774	 25778	 0.000254	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25774	 25869	 0.001377	 0.015992	 0.30866	 1233.81	 1233.81	 1233.81	 0.0	 0.0	 1	 -30.0	 30.0;
	25775	 25777	 0.000133	 0.010028	 0.0	 296.99	 296.99	 296.99	 1.0	 0.0	 1	 -30.0	 30.0;
	25775	 26092	 0.004487	 0.026208	 0.15998	 268.59	 268.59	 268.59	 0.0	 0.0	 1	 -30.0	 30.0;
	28271	 25775	 0.011223	 0.058969	 0.03932	 263.84	 263.84	 263.84	 0.0	 0.0	 1	 -30.0	 30.0;
	25776	 25777	 0.002227	 0.167486	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25779	 25780	 0.000233	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25783	 25780	 0.002403	 0.012056	 0.00362	 199.67	 199.67	 199.67	 0.0	 0.0	 1	 -30.0	 30.0;
	25780	 28087	 0.002025	 0.012443	 0.03353	 210.77	 210.77	 210.77	 0.0	 0.0	 1	 -30.0	 30.0;
	25781	 25782	 0.000251	 0.0012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25781	 25789	 0.000499	 0.003483	 0.00137	 242.24	 242.24	 242.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28142	 25783	 0.001438	 0.008914	 0.00271	 234.32	 234.32	 234.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25793	 25784	 0.001216	 0.007407	 0.00395	 203.09	 203.09	 203.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25784	 25812	 0.001964	 0.012251	 0.00265	 220.65	 220.65	 220.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 25814	 0.000936	 0.004248	 0.0074	 190.85	 190.85	 190.85	 0.0	 0.0	 1	 -30.0	 30.0;
	25785	 28218	 0.00392	 0.025966	 0.01107	 213.62	 213.62	 213.62	 0.0	 0.0	 1	 -30.0	 30.0;
	25786	 25800	 0.003427	 0.015924	 0.00791	 198.56	 198.56	 198.56	 0.0	 0.0	 1	 -30.0	 30.0;
	25786	 25814	 0.001151	 0.006642	 0.03245	 173.0	 173.0	 173.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25787	 25788	 0.000221	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25787	 25789	 0.000237	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26023	 25789	 0.001115	 0.005833	 0.0034	 262.97	 262.97	 262.97	 0.0	 0.0	 1	 -30.0	 30.0;
	28032	 25790	 0.000761	 0.004959	 0.00315	 173.46	 173.46	 173.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25791	 25792	 0.000225	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25792	 25802	 0.008724	 0.058211	 0.05353	 194.24	 194.24	 194.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25823	 25792	 0.00864	 0.047406	 0.01863	 209.13	 209.13	 209.13	 0.0	 0.0	 1	 -30.0	 30.0;
	25794	 25793	 0.001687	 0.008885	 0.00336	 217.25	 217.25	 217.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25815	 25793	 0.001344	 0.006699	 0.00604	 210.14	 210.14	 210.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25795	 25796	 0.000264	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25795	 25797	 0.000296	 0.001024	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25797	 26023	 0.002192	 0.009618	 0.00893	 237.08	 237.08	 237.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25797	 28173	 0.002822	 0.011965	 0.00521	 221.6	 221.6	 221.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28232	 25797	 0.002104	 0.013876	 0.01241	 170.94	 170.94	 170.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25798	 25799	 0.000298	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25800	 25801	 0.000242	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28218	 25800	 0.002887	 0.015117	 0.01186	 226.94	 226.94	 226.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25802	 25810	 0.002726	 0.011061	 0.06135	 192.02	 192.02	 192.02	 0.0	 0.0	 1	 -30.0	 30.0;
	25802	 25815	 0.000943	 0.005149	 0.00484	 156.83	 156.83	 156.83	 0.0	 0.0	 1	 -30.0	 30.0;
	25802	 28267	 0.006125	 0.031502	 0.03617	 161.96	 161.96	 161.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25803	 25806	 0.000769	 0.055067	 0.0	 511.47	 511.47	 511.47	 1.0	 0.0	 1	 -30.0	 30.0;
	25803	 28141	 0.000186	 0.002424	 0.0334	 1190.08	 1190.08	 1190.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25804	 25806	 -0.000384	 -0.027528	 0.0	 486.47	 486.47	 486.47	 1.0	 0.0	 1	 -30.0	 30.0;
	28172	 25804	 0.00098	 0.005228	 0.00276	 274.99	 274.99	 274.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25805	 25806	 0.002307	 0.16519	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25807	 25808	 0.000269	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25807	 25809	 0.000266	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28142	 25809	 0.001999	 0.009227	 0.01075	 228.72	 228.72	 228.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25809	 28173	 0.002676	 0.015419	 0.00592	 191.03	 191.03	 191.03	 0.0	 0.0	 1	 -30.0	 30.0;
	26023	 25810	 0.001798	 0.007851	 0.00331	 226.44	 226.44	 226.44	 0.0	 0.0	 1	 -30.0	 30.0;
	25812	 25811	 0.000706	 0.032117	 0.0	 482.47	 482.47	 482.47	 1.075	 0.0	 1	 -30.0	 30.0;
	25811	 25813	 0.00028	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25814	 25812	 0.000805	 0.004592	 0.00504	 244.91	 244.91	 244.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 25813	 0.000531	 0.005052	 0.1459	 1182.16	 1182.16	 1182.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25813	 26024	 0.000272	 0.003436	 0.07147	 1189.18	 1189.18	 1189.18	 0.0	 0.0	 1	 -30.0	 30.0;
	25816	 25817	 0.000212	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25816	 25818	 0.000201	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25816	 25819	 0.000272	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25820	 25819	 0.006104	 0.044899	 0.02044	 189.28	 189.28	 189.28	 0.0	 0.0	 1	 -30.0	 30.0;
	25820	 25821	 0.00023	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25820	 28610	 0.063548	 0.338623	 0.05964	 161.57	 161.57	 161.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25822	 25823	 0.000272	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25823	 28195	 0.006599	 0.040332	 0.04416	 208.77	 208.77	 208.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28234	 25823	 0.003363	 0.017279	 0.02349	 215.66	 215.66	 215.66	 0.0	 0.0	 1	 -30.0	 30.0;
	25823	 28271	 0.005109	 0.028834	 0.04325	 248.23	 248.23	 248.23	 0.0	 0.0	 1	 -30.0	 30.0;
	25825	 25824	 0.000131	 0.00994	 0.0	 1461.46	 1461.46	 1461.46	 1.00625	 0.0	 1	 -30.0	 30.0;
	25824	 25829	 8.2e-05	 0.006045	 0.0	 1852.31	 1852.31	 1852.31	 1.0	 0.0	 1	 -30.0	 30.0;
	25824	 25830	 5.4e-05	 0.004617	 0.0	 1851.18	 1851.18	 1851.18	 1.0	 0.0	 1	 -30.0	 30.0;
	25824	 25831	 0.000107	 0.008719	 0.0	 967.77	 967.77	 967.77	 1.0	 0.0	 1	 -30.0	 30.0;
	26035	 25824	 3.4e-05	 0.000901	 0.51577	 3958.64	 3958.64	 3958.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25824	 26212	 0.000176	 0.00514	 2.34552	 4060.7	 4060.7	 4060.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25825	 25828	 0.001131	 0.065655	 0.0	 574.21	 574.21	 574.21	 1.0	 0.0	 1	 -30.0	 30.0;
	26005	 25825	 0.000267	 0.003317	 0.06249	 1169.01	 1169.01	 1169.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25826	 25828	 -0.000615	 -0.035717	 0.0	 499.21	 499.21	 499.21	 1.0	 0.0	 1	 -30.0	 30.0;
	25827	 25828	 0.002372	 0.13767	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25833	 25832	 0.000343	 0.01862	 0.0	 324.0	 324.0	 324.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25832	 25834	 0.000409	 0.023491	 0.0	 518.59	 518.59	 518.59	 1.0	 0.0	 1	 -30.0	 30.0;
	25850	 25832	 0.000197	 0.002379	 0.06342	 1236.54	 1236.54	 1236.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25832	 25971	 0.000529	 0.005897	 0.11103	 1158.54	 1158.54	 1158.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25833	 25851	 0.002523	 0.015023	 0.00875	 264.54	 264.54	 264.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25833	 25994	 0.004197	 0.023515	 0.03492	 250.2	 250.2	 250.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25835	 25958	 0.002828	 0.014881	 0.00591	 217.59	 217.59	 217.59	 0.0	 0.0	 1	 -30.0	 30.0;
	25835	 25994	 0.001127	 0.006763	 0.00742	 229.94	 229.94	 229.94	 0.0	 0.0	 1	 -30.0	 30.0;
	25835	 26011	 0.000781	 0.00519	 0.04489	 219.41	 219.41	 219.41	 0.0	 0.0	 1	 -30.0	 30.0;
	25836	 25837	 0.004246	 0.139813	 0.0	 96.28	 96.28	 96.28	 1.0125	 0.0	 1	 -30.0	 30.0;
	25836	 25838	 0.000204	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25839	 26034	 0.004102	 0.031078	 0.01442	 215.99	 215.99	 215.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25840	 25841	 0.000262	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25840	 25842	 0.000203	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26006	 25841	 0.000175	 0.00109	 0.00026	 198.77	 198.77	 198.77	 0.0	 0.0	 1	 -30.0	 30.0;
	25844	 25843	 0.000327	 0.022217	 0.0	 287.24	 287.24	 287.24	 1.0	 0.0	 1	 -30.0	 30.0;
	25843	 25847	 0.0001	 0.001808	 0.0	 1046.7	 1046.7	 1046.7	 1.0	 0.0	 1	 -30.0	 30.0;
	25843	 25848	 0.000201	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25843	 25849	 0.000262	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25844	 25913	 0.005787	 0.027627	 0.04554	 208.3	 208.3	 208.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25845	 25847	 0.000409	 0.022373	 0.0	 523.35	 523.35	 523.35	 1.0	 0.0	 1	 -30.0	 30.0;
	25846	 25847	 0.000409	 0.022373	 0.0	 523.35	 523.35	 523.35	 1.0	 0.0	 1	 -30.0	 30.0;
	25848	 26143	 0.000468	 0.005596	 0.12366	 1160.16	 1160.16	 1160.16	 0.0	 0.0	 1	 -30.0	 30.0;
	25851	 25850	 0.000619	 0.027983	 0.0	 380.37	 380.37	 380.37	 1.00625	 0.0	 1	 -30.0	 30.0;
	25850	 25852	 0.000407	 0.027123	 0.0	 489.63	 489.63	 489.63	 1.0375	 0.0	 1	 -30.0	 30.0;
	25850	 25897	 0.000543	 0.004589	 0.08006	 1221.98	 1221.98	 1221.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25850	 25990	 0.000623	 0.008448	 0.19364	 1226.32	 1226.32	 1226.32	 0.0	 0.0	 1	 -30.0	 30.0;
	25850	 26228	 0.001026	 0.012233	 0.40999	 1263.2	 1263.2	 1263.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25853	 25856	 0.000189	 0.006836	 0.0	 284.62	 284.62	 284.62	 0.9875	 0.0	 1	 -30.0	 30.0;
	25853	 25858	 0.00082	 0.006298	 0.00134	 193.01	 193.01	 193.01	 0.0	 0.0	 1	 -30.0	 30.0;
	25853	 26192	 0.000251	 0.001625	 0.00037	 222.55	 222.55	 222.55	 0.0	 0.0	 1	 -30.0	 30.0;
	25854	 25856	 0.002375	 0.08569	 0.0	 142.31	 142.31	 142.31	 1.0	 0.0	 1	 -30.0	 30.0;
	25855	 25856	 0.002375	 0.08569	 0.0	 142.31	 142.31	 142.31	 1.0	 0.0	 1	 -30.0	 30.0;
	25857	 25858	 0.000269	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25858	 0.00054	 0.003152	 0.00186	 248.1	 248.1	 248.1	 0.0	 0.0	 1	 -30.0	 30.0;
	25859	 25862	 0.000264	 0.014464	 0.0	 428.78	 428.78	 428.78	 1.0	 0.0	 1	 -30.0	 30.0;
	25859	 25863	 0.000398	 0.026292	 0.0	 470.02	 470.02	 470.02	 1.0	 0.0	 1	 -30.0	 30.0;
	26010	 25859	 0.000823	 0.008929	 0.128	 1171.31	 1171.31	 1171.31	 0.0	 0.0	 1	 -30.0	 30.0;
	26087	 25859	 0.000413	 0.004993	 0.08535	 1139.92	 1139.92	 1139.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25860	 25862	 4e-05	 0.002178	 0.0	 353.78	 353.78	 353.78	 1.0	 0.0	 1	 -30.0	 30.0;
	25860	 25899	 0.005624	 0.027235	 0.00688	 220.39	 220.39	 220.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25861	 25862	 0.001733	 0.095019	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25865	 25864	 0.000138	 0.010847	 0.0	 1285.24	 1285.24	 1285.24	 1.00625	 0.0	 1	 -30.0	 30.0;
	25864	 25867	 0.000111	 0.008026	 0.0	 1356.5	 1356.5	 1356.5	 1.025	 0.0	 1	 -30.0	 30.0;
	25864	 25868	 0.00011	 0.008258	 0.0	 1355.43	 1355.43	 1355.43	 1.025	 0.0	 1	 -30.0	 30.0;
	25884	 25864	 8.3e-05	 0.002176	 1.14875	 4013.08	 4013.08	 4013.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25864	 26125	 0.000226	 0.005938	 3.86127	 4161.78	 4161.78	 4161.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25866	 25865	 0.000224	 0.015495	 0.0	 384.63	 384.63	 384.63	 1.00625	 0.0	 1	 -30.0	 30.0;
	25865	 25936	 0.000415	 0.005904	 0.16838	 1280.82	 1280.82	 1280.82	 0.0	 0.0	 1	 -30.0	 30.0;
	25865	 25956	 0.000139	 0.001715	 0.03975	 1166.73	 1166.73	 1166.73	 0.0	 0.0	 1	 -30.0	 30.0;
	25866	 25900	 0.003495	 0.022905	 0.03791	 252.14	 252.14	 252.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25994	 25866	 0.000514	 0.003859	 0.00074	 238.65	 238.65	 238.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25866	 25997	 0.002973	 0.018208	 0.0074	 194.4	 194.4	 194.4	 0.0	 0.0	 1	 -30.0	 30.0;
	25866	 26003	 0.001043	 0.006357	 0.0162	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 25869	 0.000413	 0.025006	 0.0	 289.8	 289.8	 289.8	 1.0	 0.0	 1	 -30.0	 30.0;
	25869	 25873	 0.0001	 0.000644	 0.0	 942.51	 942.51	 942.51	 1.0	 0.0	 1	 -30.0	 30.0;
	25869	 28460	 0.002132	 0.023147	 0.41048	 1140.57	 1140.57	 1140.57	 0.0	 0.0	 1	 -30.0	 30.0;
	25869	 28718	 0.000659	 0.009145	 0.11401	 1292.7	 1292.7	 1292.7	 0.0	 0.0	 1	 -30.0	 30.0;
	25978	 25870	 0.000604	 0.00313	 0.0016	 236.25	 236.25	 236.25	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 26111	 0.002903	 0.019104	 0.02891	 227.17	 227.17	 227.17	 0.0	 0.0	 1	 -30.0	 30.0;
	25870	 28645	 0.021965	 0.145946	 0.12098	 189.98	 189.98	 189.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25871	 25873	 0.000408	 0.024541	 0.0	 471.25	 471.25	 471.25	 1.0	 0.0	 1	 -30.0	 30.0;
	25872	 25873	 0.000408	 0.024541	 0.0	 471.25	 471.25	 471.25	 1.0	 0.0	 1	 -30.0	 30.0;
	25875	 25874	 0.000331	 0.018124	 0.0	 617.57	 617.57	 617.57	 1.0125	 0.0	 1	 -30.0	 30.0;
	25875	 25874	 0.000331	 0.018124	 0.0	 617.57	 617.57	 617.57	 1.0125	 0.0	 1	 -30.0	 30.0;
	25875	 25874	 0.000331	 0.018124	 0.0	 617.57	 617.57	 617.57	 1.0125	 0.0	 1	 -30.0	 30.0;
	25874	 25972	 0.000212	 0.002696	 0.05978	 1120.83	 1120.83	 1120.83	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 25874	 0.000175	 0.001876	 0.03058	 1288.9	 1288.9	 1288.9	 0.0	 0.0	 1	 -30.0	 30.0;
	26021	 25874	 0.000425	 0.005354	 0.17176	 1144.0	 1144.0	 1144.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 25876	 9.4e-05	 0.007075	 0.0	 1609.63	 1609.63	 1609.63	 1.03125	 0.0	 1	 -30.0	 30.0;
	25877	 25876	 9.4e-05	 0.007075	 0.0	 1609.63	 1609.63	 1609.63	 1.03125	 0.0	 1	 -30.0	 30.0;
	25877	 25876	 9.4e-05	 0.007075	 0.0	 1609.63	 1609.63	 1609.63	 1.03125	 0.0	 1	 -30.0	 30.0;
	25876	 25879	 0.000232	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25878	 25877	 0.000472	 0.031199	 0.0	 537.48	 537.48	 537.48	 1.04375	 0.0	 1	 -30.0	 30.0;
	25877	 25930	 0.000425	 0.005518	 0.14886	 1164.8	 1164.8	 1164.8	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 26024	 0.000579	 0.00635	 0.09979	 1227.61	 1227.61	 1227.61	 0.0	 0.0	 1	 -30.0	 30.0;
	26075	 25877	 0.000293	 0.003565	 0.06231	 1194.86	 1194.86	 1194.86	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 28118	 0.000767	 0.008482	 0.15716	 1240.3	 1240.3	 1240.3	 0.0	 0.0	 1	 -30.0	 30.0;
	25877	 29079	 0.000646	 0.007904	 0.09561	 1186.46	 1186.46	 1186.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25879	 26204	 0.000247	 0.006638	 3.13676	 4094.74	 4094.74	 4094.74	 0.0	 0.0	 1	 -30.0	 30.0;
	25879	 28794	 0.000105	 0.002815	 1.44628	 3982.98	 3982.98	 3982.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25880	 25881	 0.005459	 0.158981	 0.0	 97.91	 97.91	 97.91	 1.0	 0.0	 1	 -30.0	 30.0;
	25880	 25882	 0.000275	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25880	 25883	 0.000217	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25885	 25884	 3.9e-05	 0.003606	 0.0	 1510.81	 1510.81	 1510.81	 1.0	 0.0	 1	 -30.0	 30.0;
	25884	 25887	 9.5e-05	 0.007659	 0.0	 1602.23	 1602.23	 1602.23	 1.0	 0.0	 1	 -30.0	 30.0;
	25909	 25884	 0.000111	 0.00306	 1.21801	 4162.68	 4162.68	 4162.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25884	 26058	 0.000147	 0.00399	 2.73471	 4123.37	 4123.37	 4123.37	 0.0	 0.0	 1	 -30.0	 30.0;
	25886	 25885	 0.000402	 0.024258	 0.0	 340.85	 340.85	 340.85	 1.0	 0.0	 1	 -30.0	 30.0;
	25885	 25990	 0.000472	 0.005946	 0.11667	 1242.54	 1242.54	 1242.54	 0.0	 0.0	 1	 -30.0	 30.0;
	26195	 25885	 0.000654	 0.007188	 0.31726	 1210.4	 1210.4	 1210.4	 0.0	 0.0	 1	 -30.0	 30.0;
	26236	 25886	 0.001749	 0.011183	 0.00346	 210.35	 210.35	 210.35	 0.0	 0.0	 1	 -30.0	 30.0;
	25888	 25889	 0.003261	 0.088802	 0.0	 107.05	 107.05	 107.05	 1.05	 0.0	 1	 -30.0	 30.0;
	25888	 25985	 0.000247	 0.001107	 0.00055	 210.6	 210.6	 210.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 25890	 0.002766	 0.017723	 0.01239	 204.26	 204.26	 204.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25891	 25892	 0.005242	 0.142156	 0.0	 89.16	 89.16	 89.16	 1.0	 0.0	 1	 -30.0	 30.0;
	25891	 25893	 0.000255	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25893	 26037	 0.000327	 0.002497	 0.00066	 230.39	 230.39	 230.39	 0.0	 0.0	 1	 -30.0	 30.0;
	25895	 25894	 0.000309	 0.025137	 0.0	 382.14	 382.14	 382.14	 1.0	 0.0	 1	 -30.0	 30.0;
	25894	 25896	 0.000474	 0.032388	 0.0	 444.86	 444.86	 444.86	 1.0	 0.0	 1	 -30.0	 30.0;
	25894	 25897	 0.000277	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25894	 25898	 0.000229	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25895	 26046	 0.005425	 0.028366	 0.01638	 231.9	 231.9	 231.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25897	 26010	 0.000369	 0.004682	 0.13998	 1181.1	 1181.1	 1181.1	 0.0	 0.0	 1	 -30.0	 30.0;
	26088	 25899	 0.006946	 0.029851	 0.01622	 205.99	 205.99	 205.99	 0.0	 0.0	 1	 -30.0	 30.0;
	25902	 25901	 0.000135	 0.010481	 0.0	 1469.73	 1469.73	 1469.73	 1.0	 0.0	 1	 -30.0	 30.0;
	25901	 25904	 0.000107	 0.008319	 0.0	 1365.79	 1365.79	 1365.79	 1.025	 0.0	 1	 -30.0	 30.0;
	25901	 25905	 0.0001	 0.008704	 0.0	 1364.74	 1364.74	 1364.74	 1.025	 0.0	 1	 -30.0	 30.0;
	25901	 25906	 6.9e-05	 0.005831	 0.0	 1363.66	 1363.66	 1363.66	 1.025	 0.0	 1	 -30.0	 30.0;
	25901	 25907	 0.000119	 0.008727	 0.0	 1360.05	 1360.05	 1360.05	 1.025	 0.0	 1	 -30.0	 30.0;
	25901	 25908	 7.3e-05	 0.005827	 0.0	 1359.67	 1359.67	 1359.67	 1.025	 0.0	 1	 -30.0	 30.0;
	25901	 25909	 0.000289	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25903	 25902	 0.000496	 0.033248	 0.0	 368.94	 368.94	 368.94	 1.0	 0.0	 1	 -30.0	 30.0;
	25902	 26083	 0.000875	 0.010644	 0.20293	 1261.91	 1261.91	 1261.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25909	 26048	 0.000204	 0.00475	 3.12724	 4177.77	 4177.77	 4177.77	 0.0	 0.0	 1	 -30.0	 30.0;
	25909	 26160	 0.000176	 0.005117	 3.20719	 4185.64	 4185.64	 4185.64	 0.0	 0.0	 1	 -30.0	 30.0;
	25909	 26204	 9.5e-05	 0.002584	 1.65666	 4245.24	 4245.24	 4245.24	 0.0	 0.0	 1	 -30.0	 30.0;
	25910	 25911	 0.005358	 0.173074	 0.0	 71.67	 71.67	 71.67	 1.0	 0.0	 1	 -30.0	 30.0;
	25910	 25912	 0.000277	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25910	 25943	 0.005708	 0.03852	 0.02414	 208.92	 208.92	 208.92	 0.0	 0.0	 1	 -30.0	 30.0;
	25913	 25914	 0.007296	 0.204094	 0.0	 82.64	 82.64	 82.64	 1.0	 0.0	 1	 -30.0	 30.0;
	26230	 25913	 0.002158	 0.011796	 0.00793	 169.5	 169.5	 169.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26034	 25915	 0.001997	 0.011675	 0.00371	 200.85	 200.85	 200.85	 0.0	 0.0	 1	 -30.0	 30.0;
	25916	 26045	 0.000158	 0.001055	 0.00036	 187.67	 187.67	 187.67	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 25916	 0.000271	 0.00144	 0.00035	 196.54	 196.54	 196.54	 0.0	 0.0	 1	 -30.0	 30.0;
	25967	 25917	 0.001318	 0.009549	 0.00518	 216.31	 216.31	 216.31	 0.0	 0.0	 1	 -30.0	 30.0;
	25997	 25917	 0.000654	 0.002178	 0.00071	 192.98	 192.98	 192.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25919	 25922	 0.00066	 0.038298	 0.0	 561.98	 561.98	 561.98	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 25923	 0.000578	 0.03588	 0.0	 468.4	 468.4	 468.4	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 25924	 0.000469	 0.030815	 0.0	 467.4	 467.4	 467.4	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 25925	 0.000551	 0.034819	 0.0	 466.15	 466.15	 466.15	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 25926	 0.000426	 0.023921	 0.0	 463.61	 463.61	 463.61	 1.0	 0.0	 1	 -30.0	 30.0;
	25919	 26213	 3.8e-05	 0.000414	 0.01323	 968.29	 968.29	 968.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25920	 25922	 -0.000118	 -0.006844	 0.0	 461.98	 461.98	 461.98	 1.0	 0.0	 1	 -30.0	 30.0;
	25920	 25937	 0.000215	 0.001348	 0.00035	 217.49	 217.49	 217.49	 0.0	 0.0	 1	 -30.0	 30.0;
	26214	 25920	 0.000536	 0.003171	 0.00135	 247.88	 247.88	 247.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25921	 25922	 0.002363	 0.137066	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25927	 25928	 0.000292	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25927	 25929	 0.000288	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25928	 25973	 0.000603	 0.003939	 0.0022	 215.26	 215.26	 215.26	 0.0	 0.0	 1	 -30.0	 30.0;
	25931	 25930	 0.000215	 0.017957	 0.0	 568.82	 568.82	 568.82	 1.0	 0.0	 1	 -30.0	 30.0;
	25930	 25932	 0.000394	 0.02404	 0.0	 379.54	 379.54	 379.54	 1.0	 0.0	 1	 -30.0	 30.0;
	25931	 25933	 0.005567	 0.177311	 0.0	 41.87	 41.87	 41.87	 1.0	 0.0	 1	 -30.0	 30.0;
	25935	 25934	 0.00047	 0.029335	 0.0	 371.28	 371.28	 371.28	 1.0125	 0.0	 1	 -30.0	 30.0;
	25934	 25936	 0.000276	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25935	 26211	 0.00812	 0.033895	 0.03052	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25936	 25990	 0.000485	 0.00623	 0.1143	 1240.12	 1240.12	 1240.12	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 25936	 0.000491	 0.005861	 0.1967	 1327.46	 1327.46	 1327.46	 0.0	 0.0	 1	 -30.0	 30.0;
	25937	 25938	 0.000524	 0.017055	 0.0	 444.6	 444.6	 444.6	 1.0	 0.0	 1	 -30.0	 30.0;
	25939	 25940	 0.004819	 0.112375	 0.0	 99.89	 99.89	 99.89	 1.03125	 0.0	 1	 -30.0	 30.0;
	25939	 25941	 0.029401	 1.001581	 0.0	 11.05	 11.05	 11.05	 1.0	 0.0	 1	 -30.0	 30.0;
	25939	 25942	 0.000236	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 25942	 0.002628	 0.010663	 0.00302	 211.91	 211.91	 211.91	 0.0	 0.0	 1	 -30.0	 30.0;
	25942	 26011	 0.000797	 0.005339	 0.00528	 238.84	 238.84	 238.84	 0.0	 0.0	 1	 -30.0	 30.0;
	26151	 25944	 0.008573	 0.048205	 0.02722	 221.2	 221.2	 221.2	 0.0	 0.0	 1	 -30.0	 30.0;
	25944	 26236	 0.005266	 0.028226	 0.04368	 260.14	 260.14	 260.14	 0.0	 0.0	 1	 -30.0	 30.0;
	25946	 25945	 0.000641	 0.031233	 0.0	 356.29	 356.29	 356.29	 1.0	 0.0	 1	 -30.0	 30.0;
	25945	 25949	 0.0001	 -0.003404	 0.0	 620.28	 620.28	 620.28	 1.00625	 0.0	 1	 -30.0	 30.0;
	25945	 25950	 0.000682	 0.039427	 0.0	 358.32	 358.32	 358.32	 1.0	 0.0	 1	 -30.0	 30.0;
	25945	 25951	 0.000476	 0.027814	 0.0	 348.08	 348.08	 348.08	 1.00625	 0.0	 1	 -30.0	 30.0;
	25945	 25954	 0.000645	 0.038997	 0.0	 308.95	 308.95	 308.95	 1.00625	 0.0	 1	 -30.0	 30.0;
	25945	 25956	 0.000254	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25946	 25952	 0.011287	 0.266302	 0.0	 59.81	 59.81	 59.81	 1.0	 0.0	 1	 -30.0	 30.0;
	25946	 25953	 0.006573	 0.223478	 0.0	 55.88	 55.88	 55.88	 1.0125	 0.0	 1	 -30.0	 30.0;
	25946	 25955	 0.041968	 1.159892	 0.0	 11.21	 11.21	 11.21	 1.0	 0.0	 1	 -30.0	 30.0;
	25946	 25976	 0.001002	 0.00512	 0.0109	 204.65	 204.65	 204.65	 0.0	 0.0	 1	 -30.0	 30.0;
	25947	 25949	 0.000856	 0.038454	 0.0	 310.14	 310.14	 310.14	 1.0	 0.0	 1	 -30.0	 30.0;
	25948	 25949	 0.000856	 0.038454	 0.0	 310.14	 310.14	 310.14	 1.0	 0.0	 1	 -30.0	 30.0;
	25956	 25971	 0.000235	 0.002992	 0.08728	 1055.63	 1055.63	 1055.63	 0.0	 0.0	 1	 -30.0	 30.0;
	26118	 25956	 0.000164	 0.00191	 0.03752	 1033.53	 1033.53	 1033.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25957	 25958	 0.000279	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25958	 25967	 0.001725	 0.012367	 0.00742	 231.53	 231.53	 231.53	 0.0	 0.0	 1	 -30.0	 30.0;
	25959	 25960	 0.010275	 0.265859	 0.0	 59.64	 59.64	 59.64	 1.0	 0.0	 1	 -30.0	 30.0;
	25959	 25961	 0.005907	 0.156234	 0.0	 59.41	 59.41	 59.41	 1.0	 0.0	 1	 -30.0	 30.0;
	25959	 25962	 0.000605	 0.003543	 0.00231	 181.68	 181.68	 181.68	 0.0	 0.0	 1	 -30.0	 30.0;
	25959	 25981	 0.000959	 0.00417	 0.00366	 230.49	 230.49	 230.49	 0.0	 0.0	 1	 -30.0	 30.0;
	25962	 25965	 -0.000136	 -0.003579	 0.0	 244.93	 244.93	 244.93	 1.03125	 0.0	 1	 -30.0	 30.0;
	25963	 25965	 0.004264	 0.112271	 0.0	 122.47	 122.47	 122.47	 1.0	 0.0	 1	 -30.0	 30.0;
	25964	 25965	 0.004264	 0.112271	 0.0	 122.47	 122.47	 122.47	 1.0	 0.0	 1	 -30.0	 30.0;
	25967	 25966	 0.000454	 0.028372	 0.0	 252.64	 252.64	 252.64	 1.0	 0.0	 1	 -30.0	 30.0;
	25966	 25968	 0.000507	 0.029969	 0.0	 456.24	 456.24	 456.24	 1.04375	 0.0	 1	 -30.0	 30.0;
	25966	 25971	 0.000204	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25967	 25969	 0.010898	 0.351306	 0.0	 54.44	 54.44	 54.44	 1.04375	 0.0	 1	 -30.0	 30.0;
	25967	 25970	 0.061735	 1.733727	 0.0	 8.97	 8.97	 8.97	 1.0625	 0.0	 1	 -30.0	 30.0;
	26123	 25967	 0.002249	 0.013813	 0.00388	 236.08	 236.08	 236.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25973	 25972	 0.00047	 0.032127	 0.0	 438.22	 438.22	 438.22	 1.00625	 0.0	 1	 -30.0	 30.0;
	25974	 25975	 0.001966	 0.060503	 0.0	 171.6	 171.6	 171.6	 1.0	 0.0	 1	 -30.0	 30.0;
	25974	 25976	 0.000249	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26003	 25976	 0.000402	 0.002731	 0.00191	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25977	 26235	 0.001308	 0.006765	 0.00545	 168.68	 168.68	 168.68	 0.0	 0.0	 1	 -30.0	 30.0;
	26092	 25978	 0.000709	 0.003788	 0.00068	 251.08	 251.08	 251.08	 0.0	 0.0	 1	 -30.0	 30.0;
	25978	 28270	 0.015596	 0.079692	 0.06711	 236.9	 236.9	 236.9	 0.0	 0.0	 1	 -30.0	 30.0;
	25978	 28869	 0.005456	 0.02798	 0.03891	 251.98	 251.98	 251.98	 0.0	 0.0	 1	 -30.0	 30.0;
	25979	 25980	 0.002761	 0.077259	 0.0	 88.42	 88.42	 88.42	 1.0	 0.0	 1	 -30.0	 30.0;
	25979	 25981	 0.000201	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26055	 25981	 0.001126	 0.004502	 0.00578	 195.09	 195.09	 195.09	 0.0	 0.0	 1	 -30.0	 30.0;
	25982	 25983	 0.000252	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25985	 25984	 0.000335	 0.027837	 0.0	 540.48	 540.48	 540.48	 1.0	 0.0	 1	 -30.0	 30.0;
	25984	 25986	 0.000233	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25986	 26126	 0.000495	 0.005506	 0.14044	 1304.78	 1304.78	 1304.78	 0.0	 0.0	 1	 -30.0	 30.0;
	25986	 26237	 0.000337	 0.003947	 0.1358	 1213.52	 1213.52	 1213.52	 0.0	 0.0	 1	 -30.0	 30.0;
	25988	 25987	 0.000146	 0.011471	 0.0	 1593.68	 1593.68	 1593.68	 1.025	 0.0	 1	 -30.0	 30.0;
	25988	 25987	 0.000146	 0.011471	 0.0	 1593.68	 1593.68	 1593.68	 1.025	 0.0	 1	 -30.0	 30.0;
	26014	 25987	 3.9e-05	 0.001055	 0.50845	 4064.29	 4064.29	 4064.29	 0.0	 0.0	 1	 -30.0	 30.0;
	25987	 26103	 3.7e-05	 0.001066	 0.52784	 4104.88	 4104.88	 4104.88	 0.0	 0.0	 1	 -30.0	 30.0;
	25987	 26212	 5.6e-05	 0.001526	 0.75463	 4096.96	 4096.96	 4096.96	 0.0	 0.0	 1	 -30.0	 30.0;
	25989	 25988	 0.000336	 0.018667	 0.0	 624.56	 624.56	 624.56	 1.0125	 0.0	 1	 -30.0	 30.0;
	25989	 25988	 0.000336	 0.018667	 0.0	 624.56	 624.56	 624.56	 1.0125	 0.0	 1	 -30.0	 30.0;
	25989	 25988	 0.000336	 0.018667	 0.0	 624.56	 624.56	 624.56	 1.0125	 0.0	 1	 -30.0	 30.0;
	26070	 25989	 0.000951	 0.006061	 0.00524	 237.72	 237.72	 237.72	 0.0	 0.0	 1	 -30.0	 30.0;
	25990	 25993	 0.000756	 0.036015	 0.0	 444.42	 444.42	 444.42	 1.0	 0.0	 1	 -30.0	 30.0;
	25991	 25993	 -0.000234	 -0.011156	 0.0	 419.42	 419.42	 419.42	 1.0	 0.0	 1	 -30.0	 30.0;
	25992	 25993	 0.003067	 0.146054	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	25994	 25995	 0.002489	 0.063476	 0.0	 195.0	 195.0	 195.0	 1.05625	 0.0	 1	 -30.0	 30.0;
	25996	 25997	 0.000246	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26162	 25998	 0.004175	 0.023245	 0.00898	 178.6	 178.6	 178.6	 0.0	 0.0	 1	 -30.0	 30.0;
	25999	 26002	 0.000607	 0.032646	 0.0	 576.26	 576.26	 576.26	 1.0	 0.0	 1	 -30.0	 30.0;
	25999	 26126	 0.000629	 0.007631	 0.15519	 1318.96	 1318.96	 1318.96	 0.0	 0.0	 1	 -30.0	 30.0;
	26000	 26002	 -0.000173	 -0.009296	 0.0	 551.26	 551.26	 551.26	 1.0	 0.0	 1	 -30.0	 30.0;
	26001	 26002	 0.002264	 0.121841	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26003	 26004	 0.003044	 0.07058	 0.0	 195.0	 195.0	 195.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26005	 26008	 0.000149	 0.006879	 0.0	 712.3	 712.3	 712.3	 1.0	 0.0	 1	 -30.0	 30.0;
	26036	 26005	 0.000233	 0.003025	 0.05299	 1176.98	 1176.98	 1176.98	 0.0	 0.0	 1	 -30.0	 30.0;
	26006	 26008	 0.000205	 0.009441	 0.0	 562.3	 562.3	 562.3	 1.0	 0.0	 1	 -30.0	 30.0;
	26007	 26008	 0.002055	 0.094778	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26009	 26013	 0.002481	 0.014892	 0.00625	 225.29	 225.29	 225.29	 0.0	 0.0	 1	 -30.0	 30.0;
	26011	 26010	 0.000606	 0.036966	 0.0	 341.99	 341.99	 341.99	 1.00625	 0.0	 1	 -30.0	 30.0;
	26010	 26012	 0.000311	 0.015771	 0.0	 505.96	 505.96	 505.96	 1.03125	 0.0	 1	 -30.0	 30.0;
	26010	 26118	 0.000178	 0.002432	 0.04036	 1126.05	 1126.05	 1126.05	 0.0	 0.0	 1	 -30.0	 30.0;
	26013	 26055	 0.000135	 0.000646	 0.00029	 224.54	 224.54	 224.54	 0.0	 0.0	 1	 -30.0	 30.0;
	26015	 26014	 0.000172	 0.011286	 0.0	 1517.25	 1517.25	 1517.25	 1.0375	 0.0	 1	 -30.0	 30.0;
	26014	 26017	 9.8e-05	 0.007522	 0.0	 1699.55	 1699.55	 1699.55	 1.0	 0.0	 1	 -30.0	 30.0;
	26014	 26018	 0.000124	 0.009124	 0.0	 1696.63	 1696.63	 1696.63	 1.0	 0.0	 1	 -30.0	 30.0;
	26014	 26019	 0.0001	 0.008497	 0.0	 1695.49	 1695.49	 1695.49	 1.0	 0.0	 1	 -30.0	 30.0;
	26014	 26020	 8.3e-05	 0.006349	 0.0	 1695.05	 1695.05	 1695.05	 1.0	 0.0	 1	 -30.0	 30.0;
	26016	 26015	 0.000376	 0.02304	 0.0	 522.12	 522.12	 522.12	 1.03125	 0.0	 1	 -30.0	 30.0;
	26015	 26021	 0.00021	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26023	 26022	 0.000559	 0.02718	 0.0	 494.08	 494.08	 494.08	 1.0625	 0.0	 1	 -30.0	 30.0;
	26022	 26024	 0.000206	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26022	 26025	 0.000236	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26024	 28141	 0.000152	 0.001957	 0.10915	 1219.68	 1219.68	 1219.68	 0.0	 0.0	 1	 -30.0	 30.0;
	26026	 26027	 0.000227	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26026	 26028	 0.000254	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26029	 26032	 -0.000218	 -0.005919	 0.0	 275.2	 275.2	 275.2	 0.9875	 0.0	 1	 -30.0	 30.0;
	26029	 26033	 0.000277	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26030	 26032	 0.003309	 0.089866	 0.0	 137.6	 137.6	 137.6	 1.0	 0.0	 1	 -30.0	 30.0;
	26031	 26032	 0.003309	 0.089866	 0.0	 137.6	 137.6	 137.6	 1.0	 0.0	 1	 -30.0	 30.0;
	26036	 26035	 7.9e-05	 0.007217	 0.0	 1516.32	 1516.32	 1516.32	 1.05625	 0.0	 1	 -30.0	 30.0;
	26035	 26038	 7e-05	 0.005977	 0.0	 1524.88	 1524.88	 1524.88	 1.0	 0.0	 1	 -30.0	 30.0;
	26035	 26039	 4.7e-05	 0.004452	 0.0	 1524.84	 1524.84	 1524.84	 1.0	 0.0	 1	 -30.0	 30.0;
	26035	 26040	 0.000136	 0.011472	 0.0	 1345.21	 1345.21	 1345.21	 1.0	 0.0	 1	 -30.0	 30.0;
	26035	 26125	 0.000205	 0.005979	 3.83504	 4115.85	 4115.85	 4115.85	 0.0	 0.0	 1	 -30.0	 30.0;
	26035	 26152	 0.000296	 0.008244	 4.61728	 4158.61	 4158.61	 4158.61	 0.0	 0.0	 1	 -30.0	 30.0;
	26037	 26036	 0.000807	 0.03961	 0.0	 434.98	 434.98	 434.98	 1.1	 0.0	 1	 -30.0	 30.0;
	26041	 26042	 0.004063	 0.110989	 0.0	 98.53	 98.53	 98.53	 1.0	 0.0	 1	 -30.0	 30.0;
	26041	 26043	 0.037054	 0.958814	 0.0	 13.0	 13.0	 13.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26041	 26070	 0.00021	 0.001249	 0.00064	 241.27	 241.27	 241.27	 0.0	 0.0	 1	 -30.0	 30.0;
	26044	 26045	 0.000227	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26046	 26047	 0.002384	 0.073906	 0.0	 195.0	 195.0	 195.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26049	 26048	 0.000118	 0.010349	 0.0	 1401.81	 1401.81	 1401.81	 1.0	 0.0	 1	 -30.0	 30.0;
	26048	 26051	 7.7e-05	 0.006267	 0.0	 1471.6	 1471.6	 1471.6	 1.0	 0.0	 1	 -30.0	 30.0;
	26048	 26052	 0.000116	 0.009965	 0.0	 1471.33	 1471.33	 1471.33	 1.05	 0.0	 1	 -30.0	 30.0;
	26048	 26053	 0.000121	 0.009066	 0.0	 1470.72	 1470.72	 1470.72	 1.05	 0.0	 1	 -30.0	 30.0;
	26048	 26160	 3.3e-05	 0.000853	 0.42773	 4088.49	 4088.49	 4088.49	 0.0	 0.0	 1	 -30.0	 30.0;
	26048	 26204	 0.000248	 0.007644	 4.45653	 4197.78	 4197.78	 4197.78	 0.0	 0.0	 1	 -30.0	 30.0;
	26050	 26049	 0.000395	 0.024408	 0.0	 274.24	 274.24	 274.24	 1.0	 0.0	 1	 -30.0	 30.0;
	26049	 26071	 0.000571	 0.006641	 0.11578	 1196.49	 1196.49	 1196.49	 0.0	 0.0	 1	 -30.0	 30.0;
	26167	 26049	 0.000122	 0.001644	 0.05996	 1214.04	 1214.04	 1214.04	 0.0	 0.0	 1	 -30.0	 30.0;
	26168	 26050	 0.003535	 0.017619	 0.00475	 209.8	 209.8	 209.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26050	 26185	 0.001319	 0.006822	 0.00232	 204.8	 204.8	 204.8	 0.0	 0.0	 1	 -30.0	 30.0;
	26055	 26054	 0.000334	 0.020573	 0.0	 325.5	 325.5	 325.5	 1.0	 0.0	 1	 -30.0	 30.0;
	26054	 26057	 0.000289	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26055	 26056	 0.005341	 0.151071	 0.0	 78.79	 78.79	 78.79	 1.025	 0.0	 1	 -30.0	 30.0;
	26057	 26090	 0.000961	 0.010974	 0.25445	 1184.54	 1184.54	 1184.54	 0.0	 0.0	 1	 -30.0	 30.0;
	26059	 26058	 0.000133	 0.01058	 0.0	 1464.46	 1464.46	 1464.46	 1.025	 0.0	 1	 -30.0	 30.0;
	26058	 26061	 9.1e-05	 0.007915	 0.0	 1492.14	 1492.14	 1492.14	 1.0125	 0.0	 1	 -30.0	 30.0;
	26058	 26062	 0.00011	 0.009294	 0.0	 1490.38	 1490.38	 1490.38	 1.0	 0.0	 1	 -30.0	 30.0;
	26058	 26063	 9.9e-05	 0.007779	 0.0	 1490.03	 1490.03	 1490.03	 1.0125	 0.0	 1	 -30.0	 30.0;
	26058	 26064	 0.000168	 0.012363	 0.0	 1076.7	 1076.7	 1076.7	 1.00625	 0.0	 1	 -30.0	 30.0;
	26058	 26125	 2.9e-05	 0.000806	 0.41858	 4280.36	 4280.36	 4280.36	 0.0	 0.0	 1	 -30.0	 30.0;
	26204	 26058	 0.000103	 0.003039	 1.55733	 4122.13	 4122.13	 4122.13	 0.0	 0.0	 1	 -30.0	 30.0;
	26060	 26059	 0.00055	 0.031345	 0.0	 498.16	 498.16	 498.16	 1.01875	 0.0	 1	 -30.0	 30.0;
	26065	 26068	 0.000327	 0.010823	 0.0	 144.85	 144.85	 144.85	 1.0	 0.0	 1	 -30.0	 30.0;
	26065	 26069	 0.012737	 0.347084	 0.0	 30.46	 30.46	 30.46	 1.0	 0.0	 1	 -30.0	 30.0;
	26065	 26070	 0.000225	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26066	 26068	 0.003053	 0.101078	 0.0	 72.43	 72.43	 72.43	 1.0	 0.0	 1	 -30.0	 30.0;
	26067	 26068	 0.003053	 0.101078	 0.0	 72.43	 72.43	 72.43	 1.0	 0.0	 1	 -30.0	 30.0;
	26072	 26071	 0.00032	 0.022687	 0.0	 398.16	 398.16	 398.16	 1.0	 0.0	 1	 -30.0	 30.0;
	26071	 26073	 0.000673	 0.039378	 0.0	 320.33	 320.33	 320.33	 1.0125	 0.0	 1	 -30.0	 30.0;
	26071	 26153	 0.000487	 0.006474	 0.20471	 1199.38	 1199.38	 1199.38	 0.0	 0.0	 1	 -30.0	 30.0;
	26071	 26195	 0.001531	 0.020388	 0.95909	 1330.76	 1330.76	 1330.76	 0.0	 0.0	 1	 -30.0	 30.0;
	26072	 26074	 0.026799	 0.806912	 0.0	 25.64	 25.64	 25.64	 1.0375	 0.0	 1	 -30.0	 30.0;
	26072	 26218	 0.001343	 0.005251	 0.0016	 204.35	 204.35	 204.35	 0.0	 0.0	 1	 -30.0	 30.0;
	26076	 26075	 0.00053	 0.033312	 0.0	 501.06	 501.06	 501.06	 1.05	 0.0	 1	 -30.0	 30.0;
	26075	 26079	 0.0001	 -0.003462	 0.0	 707.47	 707.47	 707.47	 1.03125	 0.0	 1	 -30.0	 30.0;
	26077	 26079	 0.000771	 0.042073	 0.0	 353.74	 353.74	 353.74	 1.0	 0.0	 1	 -30.0	 30.0;
	26078	 26079	 0.000771	 0.042073	 0.0	 353.74	 353.74	 353.74	 1.0	 0.0	 1	 -30.0	 30.0;
	26080	 26081	 0.00025	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26080	 26082	 0.000236	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26084	 26083	 0.000525	 0.030002	 0.0	 423.78	 423.78	 423.78	 1.00625	 0.0	 1	 -30.0	 30.0;
	26083	 26085	 0.000552	 0.03331	 0.0	 396.32	 396.32	 396.32	 1.0	 0.0	 1	 -30.0	 30.0;
	26083	 26086	 0.000615	 0.034436	 0.0	 278.71	 278.71	 278.71	 1.0	 0.0	 1	 -30.0	 30.0;
	26083	 26195	 0.000649	 0.006337	 0.10418	 1105.79	 1105.79	 1105.79	 0.0	 0.0	 1	 -30.0	 30.0;
	26088	 26087	 0.000519	 0.029001	 0.0	 311.37	 311.37	 311.37	 1.0	 0.0	 1	 -30.0	 30.0;
	26087	 26089	 0.00047	 0.025545	 0.0	 503.53	 503.53	 503.53	 1.05	 0.0	 1	 -30.0	 30.0;
	26088	 26235	 0.011239	 0.053483	 0.05429	 202.76	 202.76	 202.76	 0.0	 0.0	 1	 -30.0	 30.0;
	26091	 26090	 0.000571	 0.033419	 0.0	 389.66	 389.66	 389.66	 1.00625	 0.0	 1	 -30.0	 30.0;
	26092	 26093	 0.008747	 0.281294	 0.0	 81.4	 81.4	 81.4	 1.0	 0.0	 1	 -30.0	 30.0;
	26095	 26094	 0.000119	 0.008742	 0.0	 1652.58	 1652.58	 1652.58	 1.1	 0.0	 1	 -30.0	 30.0;
	26095	 26094	 0.000119	 0.008742	 0.0	 1652.58	 1652.58	 1652.58	 1.05625	 0.0	 1	 -30.0	 30.0;
	26095	 26094	 0.000119	 0.008742	 0.0	 1652.58	 1652.58	 1652.58	 1.05625	 0.0	 1	 -30.0	 30.0;
	26094	 26097	 0.000111	 0.008944	 0.0	 1684.78	 1684.78	 1684.78	 1.01875	 0.0	 1	 -30.0	 30.0;
	26094	 26098	 0.000117	 0.008288	 0.0	 1682.29	 1682.29	 1682.29	 1.01875	 0.0	 1	 -30.0	 30.0;
	26094	 26099	 0.0001	 0.007955	 0.0	 1682.03	 1682.03	 1682.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	26094	 26100	 7.6e-05	 0.005515	 0.0	 1679.27	 1679.27	 1679.27	 1.0125	 0.0	 1	 -30.0	 30.0;
	26094	 26101	 9.2e-05	 0.007356	 0.0	 1676.4	 1676.4	 1676.4	 1.0125	 0.0	 1	 -30.0	 30.0;
	26094	 26102	 9.6e-05	 0.007315	 0.0	 1675.98	 1675.98	 1675.98	 1.0	 0.0	 1	 -30.0	 30.0;
	26094	 26103	 0.000274	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26096	 26095	 0.000536	 0.033462	 0.0	 441.53	 441.53	 441.53	 1.01875	 0.0	 1	 -30.0	 30.0;
	26095	 26184	 3.4e-05	 0.000342	 0.00526	 1680.0	 1680.0	 1680.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 28011	 0.000227	 0.002788	 0.07698	 1371.37	 1371.37	 1371.37	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 28023	 0.00014	 0.001385	 0.03387	 1454.34	 1454.34	 1454.34	 0.0	 0.0	 1	 -30.0	 30.0;
	26095	 28049	 0.000656	 0.008982	 0.16298	 1290.67	 1290.67	 1290.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28006	 26096	 0.000461	 0.002602	 0.00183	 412.19	 412.19	 412.19	 0.0	 0.0	 1	 -30.0	 30.0;
	26103	 29039	 4.6e-05	 0.001256	 0.60173	 4036.5	 4036.5	 4036.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26105	 26104	 0.000625	 0.036298	 0.0	 426.98	 426.98	 426.98	 1.0	 0.0	 1	 -30.0	 30.0;
	26104	 26195	 0.00068	 0.00929	 0.20681	 1286.64	 1286.64	 1286.64	 0.0	 0.0	 1	 -30.0	 30.0;
	26228	 26104	 0.000447	 0.005047	 0.12038	 1256.49	 1256.49	 1256.49	 0.0	 0.0	 1	 -30.0	 30.0;
	26105	 26108	 0.000294	 0.009039	 0.0	 192.61	 192.61	 192.61	 1.0	 0.0	 1	 -30.0	 30.0;
	26105	 26207	 0.000623	 0.003256	 0.00084	 245.32	 245.32	 245.32	 0.0	 0.0	 1	 -30.0	 30.0;
	26106	 26108	 0.003783	 0.116253	 0.0	 96.31	 96.31	 96.31	 1.0	 0.0	 1	 -30.0	 30.0;
	26107	 26108	 0.003783	 0.116253	 0.0	 96.31	 96.31	 96.31	 1.0	 0.0	 1	 -30.0	 30.0;
	26109	 26110	 0.006709	 0.202014	 0.0	 85.47	 85.47	 85.47	 1.0	 0.0	 1	 -30.0	 30.0;
	26109	 26111	 0.000255	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26112	 26115	 0.000707	 0.032251	 0.0	 506.71	 506.71	 506.71	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 26116	 0.000481	 0.031013	 0.0	 505.29	 505.29	 505.29	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 26117	 0.000393	 0.025437	 0.0	 421.52	 421.52	 421.52	 1.0	 0.0	 1	 -30.0	 30.0;
	26112	 26118	 0.000253	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26113	 26115	 -0.000135	 -0.006148	 0.0	 356.71	 356.71	 356.71	 1.0	 0.0	 1	 -30.0	 30.0;
	26113	 26211	 0.000242	 0.001397	 0.00026	 233.78	 233.78	 233.78	 0.0	 0.0	 1	 -30.0	 30.0;
	26113	 26235	 0.00126	 0.008292	 0.01418	 257.26	 257.26	 257.26	 0.0	 0.0	 1	 -30.0	 30.0;
	26114	 26115	 0.003442	 0.156984	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26119	 26120	 0.001709	 0.052897	 0.0	 117.0	 117.0	 117.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26119	 26121	 0.035394	 1.005638	 0.0	 14.76	 14.76	 14.76	 1.0125	 0.0	 1	 -30.0	 30.0;
	26119	 26122	 0.009053	 0.312638	 0.0	 38.53	 38.53	 38.53	 1.01875	 0.0	 1	 -30.0	 30.0;
	26119	 26123	 0.000277	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26119	 26124	 0.000284	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26126	 26125	 4.4e-05	 0.003451	 0.0	 1827.89	 1827.89	 1827.89	 1.01875	 0.0	 1	 -30.0	 30.0;
	26126	 26125	 4.4e-05	 0.003451	 0.0	 3000.0	 3000.0	 3000.0	 1.1	 0.0	 1	 -30.0	 30.0;
	26126	 26125	 4.4e-05	 0.003451	 0.0	 1827.89	 1827.89	 1827.89	 1.01875	 0.0	 1	 -30.0	 30.0;
	26126	 26125	 4.4e-05	 0.003451	 0.0	 1827.89	 1827.89	 1827.89	 1.01875	 0.0	 1	 -30.0	 30.0;
	26126	 26125	 4.4e-05	 0.003451	 0.0	 3000.0	 3000.0	 3000.0	 1.1	 0.0	 1	 -30.0	 30.0;
	26125	 26128	 0.000123	 0.009697	 0.0	 1452.53	 1452.53	 1452.53	 1.0	 0.0	 1	 -30.0	 30.0;
	26125	 26129	 0.000108	 0.008244	 0.0	 1452.09	 1452.09	 1452.09	 1.0	 0.0	 1	 -30.0	 30.0;
	26125	 26204	 0.000141	 0.00422	 2.08813	 4133.54	 4133.54	 4133.54	 0.0	 0.0	 1	 -30.0	 30.0;
	26127	 26126	 0.000502	 0.030256	 0.0	 521.0	 521.0	 521.0	 1.03125	 0.0	 1	 -30.0	 30.0;
	26237	 26126	 0.000145	 0.002017	 0.03157	 1384.25	 1384.25	 1384.25	 0.0	 0.0	 1	 -30.0	 30.0;
	26131	 26130	 7.6e-05	 0.005437	 0.0	 1555.44	 1555.44	 1555.44	 1.0	 0.0	 1	 -30.0	 30.0;
	26130	 26133	 7.1e-05	 0.005273	 0.0	 1952.82	 1952.82	 1952.82	 1.0	 0.0	 1	 -30.0	 30.0;
	26130	 26134	 7.2e-05	 0.005698	 0.0	 1905.41	 1905.41	 1905.41	 1.0	 0.0	 1	 -30.0	 30.0;
	26130	 26135	 0.000295	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26130	 26135	 0.000295	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26132	 26131	 0.000422	 0.023122	 0.0	 476.18	 476.18	 476.18	 1.0	 0.0	 1	 -30.0	 30.0;
	26131	 26136	 0.000236	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26142	 26135	 0.000179	 0.00528	 2.34714	 4098.3	 4098.3	 4098.3	 0.0	 0.0	 1	 -30.0	 30.0;
	26135	 26160	 0.000306	 0.008553	 4.20686	 4113.38	 4113.38	 4113.38	 0.0	 0.0	 1	 -30.0	 30.0;
	26137	 26140	 0.000275	 0.008604	 0.0	 187.76	 187.76	 187.76	 1.0	 0.0	 1	 -30.0	 30.0;
	26137	 26141	 0.008724	 0.24918	 0.0	 43.17	 43.17	 43.17	 1.0125	 0.0	 1	 -30.0	 30.0;
	26138	 26140	 0.003268	 0.102391	 0.0	 93.88	 93.88	 93.88	 1.0	 0.0	 1	 -30.0	 30.0;
	26139	 26140	 0.003268	 0.102391	 0.0	 93.88	 93.88	 93.88	 1.0	 0.0	 1	 -30.0	 30.0;
	26143	 26142	 0.000101	 0.006735	 0.0	 1397.92	 1397.92	 1397.92	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26145	 8.1e-05	 0.005626	 0.0	 1253.1	 1253.1	 1253.1	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26146	 0.000137	 0.01042	 0.0	 1252.9	 1252.9	 1252.9	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26147	 0.000115	 0.00995	 0.0	 1252.16	 1252.16	 1252.16	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26148	 0.000131	 0.010876	 0.0	 1250.83	 1250.83	 1250.83	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26149	 8.7e-05	 0.007779	 0.0	 1248.85	 1248.85	 1248.85	 1.0	 0.0	 1	 -30.0	 30.0;
	26142	 26160	 0.000108	 0.003097	 1.86074	 4129.09	 4129.09	 4129.09	 0.0	 0.0	 1	 -30.0	 30.0;
	26144	 26143	 0.000553	 0.039499	 0.0	 356.68	 356.68	 356.68	 1.0	 0.0	 1	 -30.0	 30.0;
	26150	 26151	 0.000217	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26152	 26156	 0.000388	 0.02842	 0.0	 1543.19	 1543.19	 1543.19	 1.0	 0.0	 1	 -30.0	 30.0;
	26152	 26157	 6.4e-05	 0.004799	 0.0	 1546.49	 1546.49	 1546.49	 1.03125	 0.0	 1	 -30.0	 30.0;
	26152	 26158	 0.000132	 0.011229	 0.0	 1469.72	 1469.72	 1469.72	 1.03125	 0.0	 1	 -30.0	 30.0;
	26152	 26159	 0.000166	 0.011376	 0.0	 1466.96	 1466.96	 1466.96	 1.0	 0.0	 1	 -30.0	 30.0;
	26160	 26152	 3.6e-05	 0.001011	 0.46454	 4126.36	 4126.36	 4126.36	 0.0	 0.0	 1	 -30.0	 30.0;
	26154	 26153	 0.000387	 0.024325	 0.0	 376.11	 376.11	 376.11	 1.00625	 0.0	 1	 -30.0	 30.0;
	26153	 26156	 -0.000204	 -0.014961	 0.0	 1393.19	 1393.19	 1393.19	 1.0	 0.0	 1	 -30.0	 30.0;
	26153	 26161	 0.000369	 0.004691	 0.07915	 1226.0	 1226.0	 1226.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26153	 26167	 0.000588	 0.006697	 0.13711	 1064.5	 1064.5	 1064.5	 0.0	 0.0	 1	 -30.0	 30.0;
	26155	 26156	 0.00095	 0.069574	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26161	 26160	 9.1e-05	 0.006645	 0.0	 1421.43	 1421.43	 1421.43	 1.0	 0.0	 1	 -30.0	 30.0;
	26160	 26163	 6.5e-05	 0.004804	 0.0	 1789.62	 1789.62	 1789.62	 1.0	 0.0	 1	 -30.0	 30.0;
	26160	 26164	 9.3e-05	 0.008388	 0.0	 1668.82	 1668.82	 1668.82	 1.0	 0.0	 1	 -30.0	 30.0;
	26160	 26165	 0.000109	 0.008898	 0.0	 1656.05	 1656.05	 1656.05	 1.0	 0.0	 1	 -30.0	 30.0;
	26160	 26166	 0.00011	 0.009336	 0.0	 1654.12	 1654.12	 1654.12	 1.0	 0.0	 1	 -30.0	 30.0;
	26162	 26161	 0.000286	 0.022393	 0.0	 328.06	 328.06	 328.06	 1.0	 0.0	 1	 -30.0	 30.0;
	26167	 26170	 0.000615	 0.038652	 0.0	 362.62	 362.62	 362.62	 1.0	 0.0	 1	 -30.0	 30.0;
	26229	 26167	 0.000579	 0.006848	 0.20893	 1107.78	 1107.78	 1107.78	 0.0	 0.0	 1	 -30.0	 30.0;
	26168	 26170	 -1.6e-05	 -0.000993	 0.0	 337.62	 337.62	 337.62	 1.0	 0.0	 1	 -30.0	 30.0;
	26169	 26170	 0.003423	 0.215183	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26172	 26171	 0.000206	 0.01782	 0.0	 647.89	 647.89	 647.89	 1.00625	 0.0	 1	 -30.0	 30.0;
	26172	 26171	 0.000206	 0.01782	 0.0	 647.89	 647.89	 647.89	 1.00625	 0.0	 1	 -30.0	 30.0;
	26172	 26171	 0.000206	 0.01782	 0.0	 647.89	 647.89	 647.89	 1.00625	 0.0	 1	 -30.0	 30.0;
	26172	 26171	 0.000206	 0.01782	 0.0	 647.89	 647.89	 647.89	 1.00625	 0.0	 1	 -30.0	 30.0;
	26171	 26173	 0.000452	 0.027938	 0.0	 541.43	 541.43	 541.43	 1.0	 0.0	 1	 -30.0	 30.0;
	26171	 26174	 0.000356	 0.022933	 0.0	 538.63	 538.63	 538.63	 1.0125	 0.0	 1	 -30.0	 30.0;
	26171	 26175	 0.000275	 0.016559	 0.0	 532.18	 532.18	 532.18	 1.0	 0.0	 1	 -30.0	 30.0;
	26171	 26176	 0.000577	 0.02299	 0.0	 531.58	 531.58	 531.58	 1.0125	 0.0	 1	 -30.0	 30.0;
	26171	 26177	 0.000295	 0.015216	 0.0	 531.01	 531.01	 531.01	 1.01875	 0.0	 1	 -30.0	 30.0;
	26171	 26178	 0.000285	 0.021112	 0.0	 444.19	 444.19	 444.19	 1.01875	 0.0	 1	 -30.0	 30.0;
	26171	 26179	 0.000312	 0.020231	 0.0	 442.59	 442.59	 442.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	26171	 26180	 0.000368	 0.021415	 0.0	 440.44	 440.44	 440.44	 1.01875	 0.0	 1	 -30.0	 30.0;
	26171	 26181	 0.000315	 0.020868	 0.0	 439.99	 439.99	 439.99	 1.01875	 0.0	 1	 -30.0	 30.0;
	26171	 26182	 0.000512	 0.031778	 0.0	 439.56	 439.56	 439.56	 1.0125	 0.0	 1	 -30.0	 30.0;
	26171	 26183	 0.000393	 0.026696	 0.0	 439.49	 439.49	 439.49	 1.01875	 0.0	 1	 -30.0	 30.0;
	26171	 26184	 0.000274	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 28003	 0.00041	 0.002825	 0.00198	 274.08	 274.08	 274.08	 0.0	 0.0	 1	 -30.0	 30.0;
	26172	 28003	 0.00041	 0.002825	 0.00198	 274.08	 274.08	 274.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28006	 26172	 0.000689	 0.004144	 0.00071	 219.2	 219.2	 219.2	 0.0	 0.0	 1	 -30.0	 30.0;
	26184	 28023	 0.000154	 0.00168	 0.02651	 1375.0	 1375.0	 1375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26186	 26189	 -0.000218	 -0.007484	 0.0	 99.05	 99.05	 99.05	 1.0	 0.0	 1	 -30.0	 30.0;
	26186	 26190	 0.004501	 0.135367	 0.0	 105.31	 105.31	 105.31	 1.0	 0.0	 1	 -30.0	 30.0;
	26186	 26191	 0.006818	 0.205619	 0.0	 69.9	 69.9	 69.9	 1.0	 0.0	 1	 -30.0	 30.0;
	26186	 26192	 0.000239	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26186	 26193	 0.000249	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26187	 26189	 0.007199	 0.24724	 0.0	 49.53	 49.53	 49.53	 1.0	 0.0	 1	 -30.0	 30.0;
	26188	 26189	 0.007199	 0.24724	 0.0	 49.53	 49.53	 49.53	 1.0	 0.0	 1	 -30.0	 30.0;
	26195	 26194	 6.8e-05	 0.005344	 0.0	 1601.13	 1601.13	 1601.13	 1.0	 0.0	 1	 -30.0	 30.0;
	26195	 26194	 6.8e-05	 0.005344	 0.0	 1601.13	 1601.13	 1601.13	 1.0	 0.0	 1	 -30.0	 30.0;
	26195	 26194	 6.8e-05	 0.005344	 0.0	 1601.13	 1601.13	 1601.13	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26197	 6e-05	 0.005047	 0.0	 1619.35	 1619.35	 1619.35	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26198	 9e-05	 0.006669	 0.0	 1618.58	 1618.58	 1618.58	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26199	 0.000151	 0.011158	 0.0	 1613.93	 1613.93	 1613.93	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26200	 8.8e-05	 0.007188	 0.0	 1610.52	 1610.52	 1610.52	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26201	 0.000106	 0.007527	 0.0	 1606.62	 1606.62	 1606.62	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26202	 0.000113	 0.009945	 0.0	 1606.32	 1606.32	 1606.32	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26203	 0.000125	 0.009347	 0.0	 1073.58	 1073.58	 1073.58	 1.0	 0.0	 1	 -30.0	 30.0;
	26194	 26204	 0.000232	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26196	 26195	 0.000389	 0.02834	 0.0	 506.26	 506.26	 506.26	 1.0	 0.0	 1	 -30.0	 30.0;
	26195	 26228	 0.000405	 0.004968	 0.15952	 1275.08	 1275.08	 1275.08	 0.0	 0.0	 1	 -30.0	 30.0;
	26206	 26205	 0.000458	 0.022659	 0.0	 386.16	 386.16	 386.16	 1.0	 0.0	 1	 -30.0	 30.0;
	26207	 26208	 0.006104	 0.156725	 0.0	 77.11	 77.11	 77.11	 1.03125	 0.0	 1	 -30.0	 30.0;
	26209	 26210	 0.00175	 0.061478	 0.0	 132.6	 132.6	 132.6	 1.05	 0.0	 1	 -30.0	 30.0;
	26209	 26211	 0.000233	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26213	 26212	 0.000146	 0.012067	 0.0	 1503.53	 1503.53	 1503.53	 1.01875	 0.0	 1	 -30.0	 30.0;
	26212	 26215	 3.7e-05	 0.003036	 0.0	 1623.71	 1623.71	 1623.71	 1.0125	 0.0	 1	 -30.0	 30.0;
	26212	 26216	 7.8e-05	 0.00605	 0.0	 1622.57	 1622.57	 1622.57	 1.0125	 0.0	 1	 -30.0	 30.0;
	26212	 26217	 0.000101	 0.008673	 0.0	 1620.91	 1620.91	 1620.91	 1.0125	 0.0	 1	 -30.0	 30.0;
	26214	 26213	 0.000344	 0.021614	 0.0	 532.93	 532.93	 532.93	 1.01875	 0.0	 1	 -30.0	 30.0;
	26218	 26219	 0.003513	 0.110794	 0.0	 78.55	 78.55	 78.55	 1.01875	 0.0	 1	 -30.0	 30.0;
	26221	 26220	 0.000407	 0.028935	 0.0	 420.31	 420.31	 420.31	 1.0125	 0.0	 1	 -30.0	 30.0;
	26220	 26224	 0.0001	 -0.001944	 0.0	 629.73	 629.73	 629.73	 1.0	 0.0	 1	 -30.0	 30.0;
	26220	 26226	 0.00069	 0.037477	 0.0	 299.38	 299.38	 299.38	 1.0	 0.0	 1	 -30.0	 30.0;
	26220	 26227	 0.000337	 0.021758	 0.0	 290.52	 290.52	 290.52	 1.0	 0.0	 1	 -30.0	 30.0;
	26220	 26228	 0.000224	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26221	 26225	 0.027975	 0.758398	 0.0	 18.45	 18.45	 18.45	 1.0	 0.0	 1	 -30.0	 30.0;
	26222	 26224	 0.000476	 0.03149	 0.0	 314.86	 314.86	 314.86	 1.0	 0.0	 1	 -30.0	 30.0;
	26223	 26224	 0.000476	 0.03149	 0.0	 314.86	 314.86	 314.86	 1.0	 0.0	 1	 -30.0	 30.0;
	26229	 26232	 0.000748	 0.046201	 0.0	 402.45	 402.45	 402.45	 1.0	 0.0	 1	 -30.0	 30.0;
	26230	 26232	 -0.000173	 -0.010659	 0.0	 377.45	 377.45	 377.45	 1.0	 0.0	 1	 -30.0	 30.0;
	26231	 26232	 0.004035	 0.249189	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	26233	 26234	 0.001299	 0.035591	 0.0	 179.4	 179.4	 179.4	 1.0	 0.0	 1	 -30.0	 30.0;
	26233	 26235	 0.0003	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26238	 26237	 0.000736	 0.037984	 0.0	 464.56	 464.56	 464.56	 1.00625	 0.0	 1	 -30.0	 30.0;
	28042	 28000	 0.000828	 0.003773	 0.00461	 207.09	 207.09	 207.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28001	 28002	 0.000292	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 28001	 0.000501	 0.002089	 0.00258	 293.88	 293.88	 293.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 28001	 0.000501	 0.002089	 0.00258	 293.88	 293.88	 293.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28022	 28001	 0.000501	 0.002089	 0.00258	 293.88	 293.88	 293.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28005	 28012	 0.001388	 0.010173	 0.01386	 252.45	 252.45	 252.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28005	 28022	 0.0016	 0.011332	 0.00707	 262.54	 262.54	 262.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28005	 28052	 0.001644	 0.009273	 0.0135	 255.12	 255.12	 255.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28073	 28005	 0.001141	 0.004604	 0.00333	 234.38	 234.38	 234.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28006	 28007	 0.000224	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28006	 28029	 0.002993	 0.016843	 0.01022	 271.14	 271.14	 271.14	 0.0	 0.0	 1	 -30.0	 30.0;
	28008	 29041	 0.001256	 0.008121	 0.00366	 216.34	 216.34	 216.34	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 28021	 0.002572	 0.015104	 0.01283	 262.9	 262.9	 262.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28009	 28024	 0.002702	 0.011442	 0.00359	 423.59	 423.59	 423.59	 0.0	 0.0	 1	 -30.0	 30.0;
	28010	 28103	 0.00115	 0.006268	 0.01238	 213.85	 213.85	 213.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28012	 28011	 0.000461	 0.029911	 0.0	 487.88	 487.88	 487.88	 1.0	 0.0	 1	 -30.0	 30.0;
	28011	 28013	 0.000268	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28011	 28035	 0.000367	 0.004177	 0.16672	 1176.26	 1176.26	 1176.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28012	 28025	 0.001548	 0.009464	 0.004	 241.77	 241.77	 241.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28042	 28012	 0.001248	 0.005738	 0.00449	 190.5	 190.5	 190.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28012	 28110	 0.004449	 0.030584	 0.02967	 236.55	 236.55	 236.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28014	 28015	 0.0002	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28014	 28029	 0.004383	 0.020749	 0.00992	 246.02	 246.02	 246.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28100	 28014	 0.001125	 0.006134	 0.00245	 186.98	 186.98	 186.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28103	 28014	 0.001866	 0.009407	 0.00543	 198.58	 198.58	 198.58	 0.0	 0.0	 1	 -30.0	 30.0;
	28016	 28017	 0.000233	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28016	 28021	 0.000681	 0.00323	 0.00713	 246.1	 246.1	 246.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28016	 28111	 0.00344	 0.017726	 0.00918	 220.8	 220.8	 220.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28018	 28019	 0.000243	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28018	 28020	 0.000269	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28019	 28073	 0.001048	 0.005479	 0.00517	 245.99	 245.99	 245.99	 0.0	 0.0	 1	 -30.0	 30.0;
	28024	 28023	 0.00042	 0.026145	 0.0	 587.96	 587.96	 587.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28024	 28023	 0.00042	 0.026145	 0.0	 587.96	 587.96	 587.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28024	 28023	 0.00042	 0.026145	 0.0	 587.96	 587.96	 587.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28023	 28038	 0.000465	 0.005224	 0.1116	 1207.6	 1207.6	 1207.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28025	 28026	 0.000265	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28025	 28068	 0.001395	 0.00979	 0.04559	 257.06	 257.06	 257.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28027	 28028	 0.000227	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28028	 28070	 0.002175	 0.012033	 0.0095	 212.22	 212.22	 212.22	 0.0	 0.0	 1	 -30.0	 30.0;
	28028	 28100	 0.001664	 0.010987	 0.01874	 193.14	 193.14	 193.14	 0.0	 0.0	 1	 -30.0	 30.0;
	28030	 28031	 0.000261	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28075	 28030	 0.001269	 0.007472	 0.00912	 204.26	 204.26	 204.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28114	 28030	 0.001193	 0.00782	 0.00273	 202.29	 202.29	 202.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28032	 28087	 0.001879	 0.010205	 0.0075	 214.23	 214.23	 214.23	 0.0	 0.0	 1	 -30.0	 30.0;
	28033	 28034	 0.000233	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28033	 28039	 0.000785	 0.004906	 0.00201	 185.76	 185.76	 185.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28073	 28033	 0.000849	 0.005103	 0.00494	 206.51	 206.51	 206.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28033	 28107	 0.00149	 0.008627	 0.00599	 207.38	 207.38	 207.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28036	 28035	 0.000482	 0.030644	 0.0	 507.24	 507.24	 507.24	 1.0625	 0.0	 1	 -30.0	 30.0;
	28035	 28037	 0.000274	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28038	 28035	 0.000233	 0.00275	 0.0518	 1114.67	 1114.67	 1114.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28035	 28118	 0.000207	 0.002492	 0.05129	 1159.9	 1159.9	 1159.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28035	 29079	 0.000202	 0.00256	 0.07365	 1157.47	 1157.47	 1157.47	 0.0	 0.0	 1	 -30.0	 30.0;
	28036	 28045	 0.000865	 0.002992	 0.00117	 247.31	 247.31	 247.31	 0.0	 0.0	 1	 -30.0	 30.0;
	28036	 28115	 0.001044	 0.005902	 0.00137	 226.46	 226.46	 226.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28036	 28129	 0.001572	 0.006895	 0.01026	 254.3	 254.3	 254.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28039	 28038	 0.000562	 0.030731	 0.0	 506.48	 506.48	 506.48	 1.1	 0.0	 1	 -30.0	 30.0;
	28039	 28053	 0.00076	 0.003391	 0.00334	 278.19	 278.19	 278.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28100	 28039	 0.001249	 0.007799	 0.0045	 188.89	 188.89	 188.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28039	 28107	 0.001611	 0.008837	 0.00312	 202.36	 202.36	 202.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28040	 28041	 0.000291	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28040	 28075	 0.001176	 0.008625	 0.00267	 252.16	 252.16	 252.16	 0.0	 0.0	 1	 -30.0	 30.0;
	28040	 28133	 0.001302	 0.008645	 0.00932	 218.83	 218.83	 218.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28043	 28044	 0.000296	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28043	 28149	 0.001325	 0.007341	 0.00293	 209.45	 209.45	 209.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28043	 28822	 0.002197	 0.013813	 0.01442	 240.63	 240.63	 240.63	 0.0	 0.0	 1	 -30.0	 30.0;
	28045	 28054	 0.000866	 0.005091	 0.00525	 232.8	 232.8	 232.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28045	 28110	 0.000892	 0.004092	 0.00268	 200.8	 200.8	 200.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28115	 28045	 0.000973	 0.005756	 0.00237	 175.15	 175.15	 175.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28047	 28046	 0.00048	 0.029274	 0.0	 470.63	 470.63	 470.63	 1.1	 0.0	 1	 -30.0	 30.0;
	28046	 28048	 0.000272	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28046	 28049	 0.000204	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28047	 28088	 0.002197	 0.01143	 0.00537	 240.63	 240.63	 240.63	 0.0	 0.0	 1	 -30.0	 30.0;
	28047	 28117	 0.002127	 0.013428	 0.00728	 242.41	 242.41	 242.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28145	 28047	 0.00185	 0.010393	 0.00393	 228.35	 228.35	 228.35	 0.0	 0.0	 1	 -30.0	 30.0;
	28097	 28049	 0.000319	 0.00375	 0.06694	 1094.55	 1094.55	 1094.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28050	 28051	 0.00029	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28055	 28050	 0.00085	 0.004692	 0.00183	 233.62	 233.62	 233.62	 0.0	 0.0	 1	 -30.0	 30.0;
	28050	 29076	 0.000534	 0.003411	 0.00103	 261.39	 261.39	 261.39	 0.0	 0.0	 1	 -30.0	 30.0;
	28052	 28071	 0.00128	 0.007439	 0.04553	 249.43	 249.43	 249.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28052	 28947	 0.000741	 0.005082	 0.00169	 211.46	 211.46	 211.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28065	 28053	 0.001592	 0.008722	 0.00795	 199.17	 199.17	 199.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28053	 28106	 0.001396	 0.009245	 0.00539	 227.23	 227.23	 227.23	 0.0	 0.0	 1	 -30.0	 30.0;
	28055	 28058	 0.000133	 0.004202	 0.0	 96.52	 96.52	 96.52	 1.0	 0.0	 1	 -30.0	 30.0;
	28055	 28111	 0.002073	 0.012174	 0.00885	 199.74	 199.74	 199.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28056	 28058	 0.0058	 0.183643	 0.0	 48.26	 48.26	 48.26	 1.0	 0.0	 1	 -30.0	 30.0;
	28057	 28058	 0.0058	 0.183643	 0.0	 48.26	 48.26	 48.26	 1.0	 0.0	 1	 -30.0	 30.0;
	28059	 28062	 0.000238	 0.015376	 0.0	 551.47	 551.47	 551.47	 1.0	 0.0	 1	 -30.0	 30.0;
	28074	 28059	 0.000314	 0.003734	 0.07745	 1220.53	 1220.53	 1220.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28059	 28097	 0.000287	 0.003493	 0.06452	 1032.03	 1032.03	 1032.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28060	 28062	 0.000128	 0.008285	 0.0	 501.47	 501.47	 501.47	 1.0	 0.0	 1	 -30.0	 30.0;
	28060	 28066	 0.000726	 0.003586	 0.00243	 249.44	 249.44	 249.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28822	 28060	 0.001457	 0.007561	 0.00392	 230.26	 230.26	 230.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28061	 28062	 0.002291	 0.148141	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28063	 28064	 0.000293	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29041	 28063	 0.002783	 0.01479	 0.00633	 223.43	 223.43	 223.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28065	 28875	 0.001884	 0.008333	 0.00673	 225.24	 225.24	 225.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28066	 28114	 0.001701	 0.011446	 0.00705	 210.59	 210.59	 210.59	 0.0	 0.0	 1	 -30.0	 30.0;
	28066	 28152	 0.002228	 0.014674	 0.00584	 242.75	 242.75	 242.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28067	 28075	 0.002922	 0.015422	 0.0053	 239.26	 239.26	 239.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28067	 28133	 0.000851	 0.004889	 0.00386	 202.13	 202.13	 202.13	 0.0	 0.0	 1	 -30.0	 30.0;
	28068	 28069	 0.000226	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28068	 28090	 0.001809	 0.009608	 0.00277	 223.46	 223.46	 223.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28070	 29041	 0.00207	 0.01304	 0.00747	 251.72	 251.72	 251.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28071	 28072	 0.000231	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28074	 28077	 0.001014	 0.070143	 0.0	 566.8	 566.8	 566.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28074	 28078	 0.000223	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29040	 28074	 0.000145	 0.001804	 0.04608	 1427.5	 1427.5	 1427.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28075	 28077	 -0.000531	 -0.036719	 0.0	 466.8	 466.8	 466.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28076	 28077	 0.002801	 0.193668	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28079	 28080	 0.000235	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28079	 28090	 0.002546	 0.012752	 0.00891	 215.45	 215.45	 215.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28079	 28117	 0.001786	 0.01068	 0.00734	 200.93	 200.93	 200.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28081	 28082	 0.000234	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28081	 28083	 0.000299	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28092	 28083	 0.001306	 0.006645	 0.00305	 227.38	 227.38	 227.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28083	 28132	 0.000542	 0.00329	 0.02616	 165.62	 165.62	 165.62	 0.0	 0.0	 1	 -30.0	 30.0;
	28083	 29076	 0.001274	 0.006311	 0.01036	 246.72	 246.72	 246.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28085	 28086	 0.000263	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28085	 28087	 0.000298	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28088	 28089	 0.000224	 0.001185	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28088	 28133	 0.002532	 0.014541	 0.02059	 198.91	 198.91	 198.91	 0.0	 0.0	 1	 -30.0	 30.0;
	28088	 28138	 0.001435	 0.010201	 0.01032	 231.01	 231.01	 231.01	 0.0	 0.0	 1	 -30.0	 30.0;
	28090	 28145	 0.002143	 0.010804	 0.00399	 202.07	 202.07	 202.07	 0.0	 0.0	 1	 -30.0	 30.0;
	28091	 28092	 0.000251	 0.001016	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28131	 28092	 0.002571	 0.01632	 0.00868	 196.52	 196.52	 196.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28093	 28096	 0.000639	 0.02079	 0.0	 95.23	 95.23	 95.23	 1.0	 0.0	 1	 -30.0	 30.0;
	28119	 28093	 0.000777	 0.005461	 0.00306	 255.25	 255.25	 255.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28093	 28129	 0.001037	 0.004984	 0.00881	 176.65	 176.65	 176.65	 0.0	 0.0	 1	 -30.0	 30.0;
	28093	 28153	 0.002345	 0.013882	 0.00654	 235.95	 235.95	 235.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28094	 28096	 0.00661	 0.215085	 0.0	 47.62	 47.62	 47.62	 1.0	 0.0	 1	 -30.0	 30.0;
	28095	 28096	 0.00661	 0.215085	 0.0	 47.62	 47.62	 47.62	 1.0	 0.0	 1	 -30.0	 30.0;
	28098	 28097	 0.000438	 0.028652	 0.0	 468.05	 468.05	 468.05	 1.1	 0.0	 1	 -30.0	 30.0;
	28097	 28099	 0.000203	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28097	 28118	 0.00044	 0.0049	 0.19039	 1167.44	 1167.44	 1167.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28098	 28116	 0.001943	 0.008565	 0.00267	 260.5	 260.5	 260.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28148	 28098	 0.003376	 0.019707	 0.01541	 242.42	 242.42	 242.42	 0.0	 0.0	 1	 -30.0	 30.0;
	28100	 28101	 0.000237	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28100	 28102	 0.000241	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28104	 28105	 0.000295	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28104	 28125	 0.002235	 0.012037	 0.0103	 213.75	 213.75	 213.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28138	 28104	 0.000674	 0.004051	 0.00178	 198.74	 198.74	 198.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28106	 28129	 0.001763	 0.007993	 0.01221	 170.89	 170.89	 170.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28108	 28109	 0.000269	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28108	 29045	 0.001425	 0.010122	 0.01289	 196.55	 196.55	 196.55	 0.0	 0.0	 1	 -30.0	 30.0;
	29076	 28108	 0.001553	 0.009201	 0.00417	 230.12	 230.12	 230.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28111	 28112	 0.000254	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28116	 28113	 0.001187	 0.008297	 0.00136	 234.21	 234.21	 234.21	 0.0	 0.0	 1	 -30.0	 30.0;
	28113	 28117	 0.0021	 0.008897	 0.01197	 190.94	 190.94	 190.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28118	 28121	 0.00099	 0.065594	 0.0	 585.9	 585.9	 585.9	 1.0	 0.0	 1	 -30.0	 30.0;
	28119	 28121	 -0.000611	 -0.040513	 0.0	 535.9	 535.9	 535.9	 1.0	 0.0	 1	 -30.0	 30.0;
	28119	 28124	 0.0001	 -0.002828	 0.0	 341.93	 341.93	 341.93	 1.0	 0.0	 1	 -30.0	 30.0;
	28119	 28125	 0.001337	 0.008324	 0.0033	 239.04	 239.04	 239.04	 0.0	 0.0	 1	 -30.0	 30.0;
	28120	 28121	 0.002246	 0.148775	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28122	 28124	 0.002606	 0.079544	 0.0	 170.96	 170.96	 170.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28123	 28124	 0.002606	 0.079544	 0.0	 170.96	 170.96	 170.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28125	 28126	 0.000265	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28127	 28128	 0.000216	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28127	 28129	 0.00025	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28130	 28131	 0.000237	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28199	 28131	 0.001576	 0.008435	 0.00402	 204.19	 204.19	 204.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28132	 28172	 0.002632	 0.016675	 0.01191	 214.69	 214.69	 214.69	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 28134	 0.001106	 0.00587	 0.00235	 252.02	 252.02	 252.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28134	 28205	 0.0043	 0.022398	 0.01285	 214.45	 214.45	 214.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28135	 28136	 0.000248	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28135	 28137	 0.000238	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28137	 28148	 0.001565	 0.008489	 0.00606	 197.6	 197.6	 197.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28169	 28137	 0.000575	 0.003466	 0.00451	 232.06	 232.06	 232.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28137	 28207	 0.002358	 0.014559	 0.02078	 218.36	 218.36	 218.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28153	 28139	 0.001055	 0.00533	 0.00426	 187.02	 187.02	 187.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28139	 28870	 0.006049	 0.030919	 0.02328	 227.41	 227.41	 227.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28144	 28140	 0.001685	 0.011892	 0.00395	 185.9	 185.9	 185.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28172	 28140	 0.003163	 0.017104	 0.00728	 210.12	 210.12	 210.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28142	 28141	 0.000427	 0.028214	 0.0	 513.49	 513.49	 513.49	 1.05625	 0.0	 1	 -30.0	 30.0;
	28143	 28144	 0.000219	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28161	 28144	 0.003806	 0.021506	 0.02348	 214.89	 214.89	 214.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28144	 28199	 0.002387	 0.01484	 0.01537	 216.93	 216.93	 216.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28144	 28933	 0.004037	 0.022822	 0.03268	 248.21	 248.21	 248.21	 0.0	 0.0	 1	 -30.0	 30.0;
	28146	 28147	 0.000276	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28146	 28148	 0.000206	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28148	 28179	 0.002035	 0.012099	 0.01905	 206.29	 206.29	 206.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28149	 28150	 0.000216	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28149	 28151	 0.000241	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28152	 28149	 0.001003	 0.006164	 0.00171	 208.79	 208.79	 208.79	 0.0	 0.0	 1	 -30.0	 30.0;
	28149	 28167	 0.001779	 0.012988	 0.0199	 191.44	 191.44	 191.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28212	 28154	 0.007451	 0.038446	 0.00928	 206.25	 206.25	 206.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 28155	 0.000223	 0.014256	 0.0	 568.35	 568.35	 568.35	 1.1	 0.0	 1	 -30.0	 30.0;
	28155	 28157	 0.000224	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28155	 28158	 0.000255	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28159	 28156	 0.003278	 0.014035	 0.00748	 238.01	 238.01	 238.01	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 28185	 0.000851	 0.005272	 0.00304	 253.73	 253.73	 253.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28156	 28189	 0.000915	 0.006165	 0.00687	 270.51	 270.51	 270.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28168	 28158	 0.000391	 0.00481	 0.11121	 1093.92	 1093.92	 1093.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28211	 28158	 0.000686	 0.006284	 0.15108	 1063.73	 1063.73	 1063.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28159	 28160	 0.000257	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28159	 28203	 0.0013	 0.009392	 0.00941	 185.96	 185.96	 185.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28161	 28162	 0.000285	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28161	 28227	 0.001896	 0.010556	 0.02251	 238.56	 238.56	 238.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28163	 28175	 0.001222	 0.005845	 0.01473	 243.45	 243.45	 243.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28163	 28190	 0.00084	 0.005754	 0.00352	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28163	 28232	 0.001385	 0.00638	 0.00621	 251.51	 251.51	 251.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28164	 28165	 0.000295	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28164	 28166	 0.000234	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28165	 28205	 0.001757	 0.008677	 0.00386	 200.03	 200.03	 200.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28167	 28189	 0.001867	 0.008852	 0.00542	 231.9	 231.9	 231.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28169	 28168	 0.000523	 0.037268	 0.0	 465.5	 465.5	 465.5	 1.1	 0.0	 1	 -30.0	 30.0;
	28168	 29081	 0.001279	 0.015088	 0.29241	 1218.68	 1218.68	 1218.68	 0.0	 0.0	 1	 -30.0	 30.0;
	28169	 28196	 0.001626	 0.011974	 0.0024	 241.49	 241.49	 241.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28170	 28171	 0.000284	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28196	 28171	 0.003314	 0.010879	 0.00809	 204.5	 204.5	 204.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28221	 28171	 0.003329	 0.01841	 0.0327	 210.72	 210.72	 210.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28173	 28174	 0.000272	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28180	 28173	 0.002202	 0.011559	 0.00267	 191.36	 191.36	 191.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28175	 28176	 0.000228	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28175	 28181	 0.001056	 0.006472	 0.00435	 206.43	 206.43	 206.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28177	 28178	 0.000264	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28177	 28179	 0.000223	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28197	 28179	 0.00151	 0.010869	 0.00866	 178.71	 178.71	 178.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28180	 28231	 0.004243	 0.025898	 0.02757	 237.15	 237.15	 237.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28181	 28182	 0.00023	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28181	 28191	 0.001027	 0.005247	 0.00287	 225.12	 225.12	 225.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28225	 28181	 0.003892	 0.014997	 0.00898	 241.48	 241.48	 241.48	 0.0	 0.0	 1	 -30.0	 30.0;
	28183	 28184	 0.000292	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28183	 28185	 0.000289	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28183	 28186	 0.000233	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28203	 28185	 0.001771	 0.009754	 0.0039	 229.04	 229.04	 229.04	 0.0	 0.0	 1	 -30.0	 30.0;
	28187	 28188	 0.000232	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28187	 28189	 0.000297	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28189	 28198	 0.002846	 0.016834	 0.05324	 185.56	 185.56	 185.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28190	 28218	 0.000701	 0.002969	 0.00115	 286.64	 286.64	 286.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28190	 28218	 0.000701	 0.002969	 0.00115	 286.64	 286.64	 286.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28190	 28218	 0.000701	 0.002969	 0.00115	 286.64	 286.64	 286.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28191	 28199	 0.007004	 0.025839	 0.04048	 222.75	 222.75	 222.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28191	 28232	 0.001118	 0.005896	 0.00266	 224.27	 224.27	 224.27	 0.0	 0.0	 1	 -30.0	 30.0;
	28216	 28192	 0.001575	 0.008412	 0.0098	 222.19	 222.19	 222.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28192	 28228	 0.002041	 0.014145	 0.01239	 230.63	 230.63	 230.63	 0.0	 0.0	 1	 -30.0	 30.0;
	28193	 28194	 0.000202	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28193	 28195	 0.000274	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28231	 28195	 0.001721	 0.010676	 0.00812	 182.59	 182.59	 182.59	 0.0	 0.0	 1	 -30.0	 30.0;
	28197	 28205	 0.001973	 0.009423	 0.02003	 189.57	 189.57	 189.57	 0.0	 0.0	 1	 -30.0	 30.0;
	28210	 28197	 0.00111	 0.007903	 0.00628	 164.89	 164.89	 164.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28197	 28219	 0.001411	 0.009658	 0.00466	 214.89	 214.89	 214.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28197	 28252	 0.003179	 0.019247	 0.02768	 198.6	 198.6	 198.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28197	 28253	 0.002118	 0.014324	 0.01612	 218.96	 218.96	 218.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28220	 28198	 0.001428	 0.01061	 0.00745	 226.03	 226.03	 226.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28200	 28275	 0.002083	 0.009489	 0.0033	 165.73	 165.73	 165.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28200	 28999	 0.003578	 0.026893	 0.02166	 231.94	 231.94	 231.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28201	 28202	 0.000264	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28201	 28203	 0.000286	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28201	 28204	 0.000227	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28203	 28210	 0.001707	 0.010037	 0.03982	 215.5	 215.5	 215.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28205	 28206	 0.000242	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28207	 28219	 0.00244	 0.016173	 0.00983	 169.79	 169.79	 169.79	 0.0	 0.0	 1	 -30.0	 30.0;
	28208	 28209	 0.000243	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28208	 28210	 0.000212	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28212	 28211	 0.000309	 0.018675	 0.0	 495.98	 495.98	 495.98	 1.06875	 0.0	 1	 -30.0	 30.0;
	28211	 29025	 0.001188	 0.013828	 0.31114	 1239.74	 1239.74	 1239.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28212	 28220	 0.003141	 0.018921	 0.01624	 245.28	 245.28	 245.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28272	 28212	 0.004145	 0.028106	 0.00855	 237.94	 237.94	 237.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28215	 28213	 0.001103	 0.006734	 0.00375	 175.46	 175.46	 175.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28213	 28363	 0.003557	 0.016676	 0.03232	 207.71	 207.71	 207.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28214	 28215	 0.000276	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28215	 28272	 0.00295	 0.019827	 0.01609	 216.54	 216.54	 216.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28224	 28216	 0.001586	 0.010331	 0.0031	 180.8	 180.8	 180.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28218	 28217	 0.000467	 0.024371	 0.0	 595.59	 595.59	 595.59	 1.0	 0.0	 1	 -30.0	 30.0;
	28218	 28217	 0.000467	 0.024371	 0.0	 595.59	 595.59	 595.59	 1.0	 0.0	 1	 -30.0	 30.0;
	28218	 28217	 0.000467	 0.024371	 0.0	 595.59	 595.59	 595.59	 1.0	 0.0	 1	 -30.0	 30.0;
	28795	 28217	 0.000413	 0.005601	 0.13783	 1302.28	 1302.28	 1302.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28217	 28831	 0.000636	 0.007879	 0.22127	 1215.62	 1215.62	 1215.62	 0.0	 0.0	 1	 -30.0	 30.0;
	28218	 28225	 0.001969	 0.008534	 0.0391	 257.4	 257.4	 257.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28218	 28231	 0.001374	 0.007175	 0.00423	 265.52	 265.52	 265.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28221	 28233	 0.002245	 0.01365	 0.00934	 223.75	 223.75	 223.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28221	 28250	 0.003356	 0.020857	 0.02781	 225.72	 225.72	 225.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28223	 28222	 0.00032	 0.02184	 0.0	 507.42	 507.42	 507.42	 1.0	 0.0	 1	 -30.0	 30.0;
	28222	 29003	 0.000377	 0.004792	 0.12343	 1212.85	 1212.85	 1212.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28223	 28275	 0.001997	 0.011508	 0.00999	 227.07	 227.07	 227.07	 0.0	 0.0	 1	 -30.0	 30.0;
	28223	 29014	 0.001045	 0.006146	 0.00139	 268.2	 268.2	 268.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28224	 28267	 0.001882	 0.012581	 0.0169	 221.39	 221.39	 221.39	 0.0	 0.0	 1	 -30.0	 30.0;
	28225	 28226	 0.000232	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28227	 28800	 0.002007	 0.010401	 0.00256	 264.45	 264.45	 264.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28228	 28229	 0.000203	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28228	 28282	 0.002708	 0.015039	 0.0084	 226.21	 226.21	 226.21	 0.0	 0.0	 1	 -30.0	 30.0;
	28228	 28796	 0.003792	 0.022408	 0.00677	 232.11	 232.11	 232.11	 0.0	 0.0	 1	 -30.0	 30.0;
	28230	 28260	 0.001365	 0.008867	 0.004	 204.17	 204.17	 204.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28266	 28230	 0.00315	 0.017468	 0.01212	 247.48	 247.48	 247.48	 0.0	 0.0	 1	 -30.0	 30.0;
	28233	 28870	 0.002421	 0.010388	 0.00236	 239.74	 239.74	 239.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28271	 28234	 0.007545	 0.032204	 0.03192	 243.61	 243.61	 243.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28235	 28236	 0.000241	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28244	 28235	 0.000916	 0.005986	 0.00328	 211.39	 211.39	 211.39	 0.0	 0.0	 1	 -30.0	 30.0;
	28235	 29014	 0.001625	 0.009917	 0.00567	 232.87	 232.87	 232.87	 0.0	 0.0	 1	 -30.0	 30.0;
	28237	 28238	 0.000225	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28933	 28238	 0.001104	 0.006433	 0.00446	 233.79	 233.79	 233.79	 0.0	 0.0	 1	 -30.0	 30.0;
	28238	 28985	 0.001471	 0.009042	 0.0037	 215.78	 215.78	 215.78	 0.0	 0.0	 1	 -30.0	 30.0;
	28238	 28999	 0.002495	 0.011537	 0.04415	 228.03	 228.03	 228.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28239	 28240	 0.000271	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28239	 28241	 0.00028	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28239	 28242	 0.000204	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28251	 28240	 0.001915	 0.011133	 0.00801	 240.17	 240.17	 240.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28256	 28240	 0.00161	 0.0093	 0.00374	 261.1	 261.1	 261.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28243	 28250	 0.002343	 0.011456	 0.00332	 251.24	 251.24	 251.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28800	 28243	 0.001981	 0.010543	 0.01247	 272.34	 272.34	 272.34	 0.0	 0.0	 1	 -30.0	 30.0;
	28244	 28251	 0.001935	 0.008796	 0.00219	 203.83	 203.83	 203.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28273	 28245	 0.001113	 0.006573	 0.00979	 215.89	 215.89	 215.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28245	 28832	 0.00341	 0.023898	 0.03078	 237.07	 237.07	 237.07	 0.0	 0.0	 1	 -30.0	 30.0;
	28246	 28267	 0.002226	 0.013595	 0.00908	 254.41	 254.41	 254.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28246	 28341	 0.00968	 0.043053	 0.03155	 268.92	 268.92	 268.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28247	 28260	 0.000999	 0.006403	 0.00367	 207.29	 207.29	 207.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28247	 28933	 0.001155	 0.007626	 0.02489	 178.79	 178.79	 178.79	 0.0	 0.0	 1	 -30.0	 30.0;
	28248	 28249	 0.000251	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28248	 28250	 0.000219	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28252	 28327	 0.001701	 0.009091	 0.00726	 224.09	 224.09	 224.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28253	 28254	 0.00022	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28253	 28304	 0.005509	 0.032758	 0.02952	 239.65	 239.65	 239.65	 0.0	 0.0	 1	 -30.0	 30.0;
	28255	 28263	 0.003478	 0.021318	 0.01891	 180.18	 180.18	 180.18	 0.0	 0.0	 1	 -30.0	 30.0;
	28255	 28800	 0.002256	 0.012995	 0.00603	 210.36	 210.36	 210.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28292	 28256	 0.000811	 0.005536	 0.00212	 237.56	 237.56	 237.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28999	 28256	 0.000849	 0.004501	 0.0021	 283.69	 283.69	 283.69	 0.0	 0.0	 1	 -30.0	 30.0;
	28999	 28256	 0.000849	 0.004501	 0.0021	 283.69	 283.69	 283.69	 0.0	 0.0	 1	 -30.0	 30.0;
	28257	 28258	 0.000294	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28257	 28279	 0.001361	 0.006226	 0.00399	 199.33	 199.33	 199.33	 0.0	 0.0	 1	 -30.0	 30.0;
	28257	 28292	 0.001494	 0.009583	 0.01213	 193.98	 193.98	 193.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28257	 28832	 0.002825	 0.015042	 0.0079	 236.7	 236.7	 236.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28259	 28260	 0.000239	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28259	 28261	 0.000219	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28260	 28796	 0.002438	 0.012378	 0.00151	 235.02	 235.02	 235.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28262	 28298	 0.001758	 0.010156	 0.01193	 222.54	 222.54	 222.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28299	 28262	 0.000579	 0.003096	 0.00087	 194.15	 194.15	 194.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28263	 28264	 0.000249	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28279	 28263	 0.003068	 0.01799	 0.00574	 207.55	 207.55	 207.55	 0.0	 0.0	 1	 -30.0	 30.0;
	29005	 28263	 0.000994	 0.004978	 0.03276	 247.56	 247.56	 247.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28265	 28266	 0.000249	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28266	 28293	 0.005019	 0.030106	 0.02526	 209.52	 209.52	 209.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28266	 28301	 0.000766	 0.004535	 0.00221	 166.61	 166.61	 166.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28266	 28344	 0.003179	 0.016249	 0.04249	 279.93	 279.93	 279.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28268	 28269	 0.00023	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28268	 28270	 0.000243	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28312	 28270	 0.001683	 0.010775	 0.00619	 184.94	 184.94	 184.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28270	 28357	 0.003956	 0.019631	 0.06677	 231.21	 231.21	 231.21	 0.0	 0.0	 1	 -30.0	 30.0;
	28271	 28849	 0.010155	 0.056046	 0.01468	 252.95	 252.95	 252.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28273	 28274	 0.000299	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28273	 28306	 0.002112	 0.01388	 0.00326	 217.73	 217.73	 217.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28323	 28273	 0.003159	 0.019329	 0.0103	 185.17	 185.17	 185.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28273	 28943	 0.005111	 0.025002	 0.02525	 235.5	 235.5	 235.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28276	 28277	 0.000203	 0.001187	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28276	 28278	 0.000214	 0.001092	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28324	 28277	 0.001658	 0.010881	 0.00437	 224.54	 224.54	 224.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28277	 28371	 0.002333	 0.012384	 0.07703	 226.12	 226.12	 226.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28277	 28400	 0.001888	 0.012681	 0.00816	 231.51	 231.51	 231.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28280	 28291	 0.001956	 0.012241	 0.0125	 246.65	 246.65	 246.65	 0.0	 0.0	 1	 -30.0	 30.0;
	28280	 28306	 0.000492	 0.002942	 0.002	 216.4	 216.4	 216.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28281	 28282	 0.000272	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28985	 28282	 0.000558	 0.00358	 0.00206	 253.49	 253.49	 253.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28283	 28284	 0.000231	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28283	 28285	 0.000278	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28290	 28284	 0.000504	 0.004478	 0.00168	 218.03	 218.03	 218.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28284	 28366	 0.002435	 0.013613	 0.05802	 245.26	 245.26	 245.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28284	 28462	 0.005999	 0.025529	 0.02566	 250.27	 250.27	 250.27	 0.0	 0.0	 1	 -30.0	 30.0;
	28355	 28286	 0.003227	 0.019104	 0.00725	 252.81	 252.81	 252.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28286	 28849	 0.0024	 0.010149	 0.00966	 273.12	 273.12	 273.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28287	 28288	 0.000231	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28287	 28339	 0.001914	 0.009251	 0.00438	 250.77	 250.77	 250.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28348	 28287	 0.002909	 0.013061	 0.01717	 228.52	 228.52	 228.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28896	 28287	 0.002785	 0.012878	 0.00932	 243.97	 243.97	 243.97	 0.0	 0.0	 1	 -30.0	 30.0;
	28289	 28290	 0.000296	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28341	 28290	 0.00224	 0.014886	 0.00379	 244.43	 244.43	 244.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28326	 28291	 0.000928	 0.004703	 0.00195	 269.81	 269.81	 269.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28293	 28999	 0.003777	 0.023115	 0.00982	 150.8	 150.8	 150.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28344	 28294	 0.001186	 0.006443	 0.00246	 172.23	 172.23	 172.23	 0.0	 0.0	 1	 -30.0	 30.0;
	28294	 28355	 0.004716	 0.03648	 0.06388	 231.38	 231.38	 231.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28401	 28295	 0.000902	 0.005876	 0.00166	 235.67	 235.67	 235.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28783	 28295	 0.002842	 0.016227	 0.01223	 263.2	 263.2	 263.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28296	 28297	 0.000278	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28296	 28298	 0.000208	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28329	 28298	 0.001251	 0.005392	 0.00602	 217.75	 217.75	 217.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28298	 28861	 0.001436	 0.006227	 0.00283	 269.1	 269.1	 269.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28299	 28339	 0.002017	 0.014159	 0.00729	 238.41	 238.41	 238.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28300	 28301	 0.000225	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28301	 28861	 0.004526	 0.019967	 0.0191	 227.46	 227.46	 227.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28302	 28350	 0.00383	 0.020523	 0.01463	 196.8	 196.8	 196.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28302	 28432	 0.002471	 0.010339	 0.00669	 255.67	 255.67	 255.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28303	 28318	 0.003594	 0.027937	 0.00895	 225.03	 225.03	 225.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28303	 28372	 0.005785	 0.026408	 0.0063	 152.25	 152.25	 152.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28304	 28305	 0.000226	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28372	 28304	 0.004195	 0.019889	 0.00791	 215.5	 215.5	 215.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28304	 28429	 0.001248	 0.006554	 0.00384	 250.56	 250.56	 250.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28304	 29082	 0.005506	 0.029586	 0.02156	 231.93	 231.93	 231.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28306	 28307	 0.000289	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28308	 28309	 0.000205	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28308	 28349	 0.002935	 0.016476	 0.05855	 254.49	 254.49	 254.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28308	 28400	 0.001655	 0.009522	 0.003	 246.81	 246.81	 246.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28418	 28308	 0.001708	 0.009785	 0.02111	 244.88	 244.88	 244.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28310	 28337	 0.001167	 0.00533	 0.00977	 286.01	 286.01	 286.01	 0.0	 0.0	 1	 -30.0	 30.0;
	28310	 28363	 0.001782	 0.010783	 0.01036	 245.06	 245.06	 245.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28310	 29026	 0.00166	 0.010634	 0.06229	 225.86	 225.86	 225.86	 0.0	 0.0	 1	 -30.0	 30.0;
	28311	 28316	 0.006948	 0.044947	 0.02677	 244.85	 244.85	 244.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28311	 28462	 0.002688	 0.01619	 0.07616	 269.54	 269.54	 269.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28311	 28849	 0.00108	 0.006818	 0.00552	 246.95	 246.95	 246.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28312	 28315	 -0.000241	 -0.006647	 0.0	 224.42	 224.42	 224.42	 1.0	 0.0	 1	 -30.0	 30.0;
	28849	 28312	 0.001257	 0.009828	 0.00683	 218.26	 218.26	 218.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28313	 28315	 0.002957	 0.081401	 0.0	 112.21	 112.21	 112.21	 1.0	 0.0	 1	 -30.0	 30.0;
	28314	 28315	 0.002957	 0.081401	 0.0	 112.21	 112.21	 112.21	 1.0	 0.0	 1	 -30.0	 30.0;
	28316	 28719	 0.011578	 0.061218	 0.03189	 248.44	 248.44	 248.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28318	 28317	 0.000416	 0.02226	 0.0	 479.04	 479.04	 479.04	 1.0	 0.0	 1	 -30.0	 30.0;
	28317	 28428	 0.000629	 0.00749	 0.08482	 1183.48	 1183.48	 1183.48	 0.0	 0.0	 1	 -30.0	 30.0;
	28318	 28319	 0.002766	 0.013454	 0.00418	 241.06	 241.06	 241.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28411	 28318	 0.002208	 0.015781	 0.00319	 208.72	 208.72	 208.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28319	 28320	 0.000251	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28319	 28338	 0.004076	 0.022208	 0.01953	 192.76	 192.76	 192.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28321	 28322	 0.000213	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28321	 28323	 0.0003	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28323	 28328	 0.000923	 0.006077	 0.00563	 205.73	 205.73	 205.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28324	 28326	 0.00141	 0.009191	 0.00382	 254.58	 254.58	 254.58	 0.0	 0.0	 1	 -30.0	 30.0;
	28326	 28325	 0.000649	 0.030012	 0.0	 516.78	 516.78	 516.78	 1.0	 0.0	 1	 -30.0	 30.0;
	28325	 28782	 0.000544	 0.006886	 0.14678	 1216.15	 1216.15	 1216.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28326	 28375	 0.001111	 0.006636	 0.0026	 192.13	 192.13	 192.13	 0.0	 0.0	 1	 -30.0	 30.0;
	28958	 28326	 0.000337	 0.002007	 0.00162	 225.99	 225.99	 225.99	 0.0	 0.0	 1	 -30.0	 30.0;
	28327	 28371	 0.003732	 0.01709	 0.0052	 201.99	 201.99	 201.99	 0.0	 0.0	 1	 -30.0	 30.0;
	28327	 28418	 0.007206	 0.036904	 0.0622	 241.96	 241.96	 241.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28328	 28381	 0.004505	 0.027005	 0.03904	 243.37	 243.37	 243.37	 0.0	 0.0	 1	 -30.0	 30.0;
	28402	 28329	 0.002128	 0.013729	 0.00265	 193.39	 193.39	 193.39	 0.0	 0.0	 1	 -30.0	 30.0;
	28330	 28333	 -0.000296	 -0.006907	 0.0	 93.76	 93.76	 93.76	 1.0	 0.0	 1	 -30.0	 30.0;
	28330	 28353	 0.000981	 0.004626	 0.00384	 222.29	 222.29	 222.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28330	 28391	 0.002226	 0.012989	 0.00868	 190.0	 190.0	 190.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28331	 28333	 0.005384	 0.125743	 0.0	 46.88	 46.88	 46.88	 1.0	 0.0	 1	 -30.0	 30.0;
	28332	 28333	 0.005384	 0.125743	 0.0	 46.88	 46.88	 46.88	 1.0	 0.0	 1	 -30.0	 30.0;
	28334	 28335	 0.00022	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28354	 28334	 0.001449	 0.008208	 0.0033	 188.54	 188.54	 188.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28334	 29026	 0.001491	 0.008407	 0.00405	 210.42	 210.42	 210.42	 0.0	 0.0	 1	 -30.0	 30.0;
	28336	 28337	 0.000269	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28337	 28365	 0.000428	 0.002437	 0.00549	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28338	 28439	 0.006213	 0.03121	 0.09625	 206.1	 206.1	 206.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28339	 28340	 0.000294	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28341	 28342	 0.000254	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28341	 28348	 0.002999	 0.019014	 0.01532	 256.24	 256.24	 256.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28849	 28341	 0.005497	 0.031072	 0.03398	 295.25	 295.25	 295.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28849	 28341	 0.005497	 0.031072	 0.03398	 295.25	 295.25	 295.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28849	 28341	 0.005497	 0.031072	 0.03398	 295.25	 295.25	 295.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28343	 28346	 0.001264	 0.064699	 0.0	 617.38	 617.38	 617.38	 1.0	 0.0	 1	 -30.0	 30.0;
	28343	 28347	 0.00021	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28343	 28460	 0.000836	 0.008933	 0.25586	 1326.6	 1326.6	 1326.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28860	 28343	 0.000319	 0.004208	 0.09877	 1129.33	 1129.33	 1129.33	 0.0	 0.0	 1	 -30.0	 30.0;
	28344	 28346	 -0.000842	 -0.043091	 0.0	 492.38	 492.38	 492.38	 1.0	 0.0	 1	 -30.0	 30.0;
	28344	 28896	 0.000414	 0.002462	 0.00175	 230.56	 230.56	 230.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28345	 28346	 0.00207	 0.105931	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28362	 28349	 0.001906	 0.010998	 0.009	 263.1	 263.1	 263.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28349	 28432	 0.000866	 0.005068	 0.00193	 281.64	 281.64	 281.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28442	 28349	 0.001498	 0.009643	 0.00542	 231.19	 231.19	 231.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28349	 28463	 0.001703	 0.009524	 0.00681	 218.51	 218.51	 218.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28360	 28350	 0.001233	 0.007219	 0.00402	 209.3	 209.3	 209.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28351	 28352	 0.000224	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28365	 28351	 0.002599	 0.016872	 0.0052	 196.32	 196.32	 196.32	 0.0	 0.0	 1	 -30.0	 30.0;
	28351	 28503	 0.006646	 0.033323	 0.03091	 212.4	 212.4	 212.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28353	 28354	 0.005775	 0.013901	 0.00664	 220.2	 220.2	 220.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28353	 28368	 0.001021	 0.00481	 0.00192	 222.67	 222.67	 222.67	 0.0	 0.0	 1	 -30.0	 30.0;
	29026	 28354	 0.000445	 0.002801	 0.00096	 264.4	 264.4	 264.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28355	 28356	 0.000253	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28357	 28427	 0.004397	 0.030089	 0.03174	 272.98	 272.98	 272.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28357	 28459	 0.003157	 0.021349	 0.01058	 265.23	 265.23	 265.23	 0.0	 0.0	 1	 -30.0	 30.0;
	28358	 28359	 0.000228	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28358	 28360	 0.000206	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28360	 28367	 0.001509	 0.010307	 0.00353	 215.05	 215.05	 215.05	 0.0	 0.0	 1	 -30.0	 30.0;
	28464	 28360	 0.001494	 0.007766	 0.00163	 225.17	 225.17	 225.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28361	 28362	 0.000286	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28362	 28375	 0.003452	 0.016956	 0.01692	 215.43	 215.43	 215.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28365	 28364	 0.000442	 0.029693	 0.0	 521.2	 521.2	 521.2	 1.03125	 0.0	 1	 -30.0	 30.0;
	29025	 28364	 0.000392	 0.004643	 0.09787	 1219.84	 1219.84	 1219.84	 0.0	 0.0	 1	 -30.0	 30.0;
	28365	 28383	 0.003202	 0.016378	 0.00752	 204.59	 204.59	 204.59	 0.0	 0.0	 1	 -30.0	 30.0;
	28441	 28366	 0.003414	 0.019833	 0.01362	 235.44	 235.44	 235.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28367	 28427	 0.007302	 0.034774	 0.03334	 234.44	 234.44	 234.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28368	 28369	 0.000281	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28368	 29026	 0.001283	 0.008586	 0.00278	 250.64	 250.64	 250.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28370	 28382	 0.003527	 0.018135	 0.00885	 213.84	 213.84	 213.84	 0.0	 0.0	 1	 -30.0	 30.0;
	28373	 28374	 0.000208	 0.001024	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28417	 28373	 0.00126	 0.006088	 0.00423	 250.46	 250.46	 250.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28373	 28418	 0.000475	 0.003085	 0.00132	 413.4	 413.4	 413.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28373	 28555	 0.003628	 0.021624	 0.06744	 255.17	 255.17	 255.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28375	 28376	 0.000249	 0.001066	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28377	 28378	 0.000299	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28377	 28404	 0.005667	 0.021706	 0.02762	 182.49	 182.49	 182.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28377	 28447	 0.005379	 0.023482	 0.01082	 233.6	 233.6	 233.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28379	 28380	 0.000213	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28379	 28425	 0.00222	 0.013694	 0.01138	 192.06	 192.06	 192.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28379	 28472	 0.003343	 0.02296	 0.04745	 211.98	 211.98	 211.98	 0.0	 0.0	 1	 -30.0	 30.0;
	29082	 28381	 0.000752	 0.004821	 0.00188	 257.34	 257.34	 257.34	 0.0	 0.0	 1	 -30.0	 30.0;
	28382	 28404	 0.003512	 0.021653	 0.01076	 231.82	 231.82	 231.82	 0.0	 0.0	 1	 -30.0	 30.0;
	28383	 28384	 0.000264	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28383	 28466	 0.007756	 0.035155	 0.03234	 187.85	 187.85	 187.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28385	 28504	 0.001291	 0.009736	 0.00287	 200.28	 200.28	 200.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28385	 28508	 0.002295	 0.015175	 0.02726	 248.85	 248.85	 248.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28386	 28783	 0.004221	 0.024396	 0.03034	 264.22	 264.22	 264.22	 0.0	 0.0	 1	 -30.0	 30.0;
	28958	 28386	 0.000743	 0.003913	 0.00448	 225.83	 225.83	 225.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28387	 28388	 0.000255	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28388	 28391	 0.002329	 0.012149	 0.01	 225.0	 225.0	 225.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28388	 28393	 0.001921	 0.011799	 0.00371	 205.64	 205.64	 205.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28436	 28388	 0.001343	 0.009643	 0.00526	 237.54	 237.54	 237.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28388	 28724	 0.001843	 0.011253	 0.01856	 266.08	 266.08	 266.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28389	 28436	 0.001802	 0.007584	 0.0034	 203.33	 203.33	 203.33	 0.0	 0.0	 1	 -30.0	 30.0;
	28467	 28389	 0.002074	 0.013379	 0.00564	 192.98	 192.98	 192.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28390	 28391	 0.000283	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28392	 28393	 0.000223	 0.001187	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28393	 29004	 0.002798	 0.013419	 0.01282	 239.28	 239.28	 239.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28394	 28395	 0.000228	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28547	 28394	 0.001756	 0.009226	 0.01437	 208.36	 208.36	 208.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28394	 28558	 0.001322	 0.006888	 0.00952	 185.62	 185.62	 185.62	 0.0	 0.0	 1	 -30.0	 30.0;
	28396	 28397	 0.000233	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28396	 28398	 0.00061	 0.003721	 0.0016	 224.88	 224.88	 224.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28396	 28908	 0.003696	 0.016258	 0.0098	 248.84	 248.84	 248.84	 0.0	 0.0	 1	 -30.0	 30.0;
	28398	 28456	 0.001957	 0.010558	 0.08385	 167.11	 167.11	 167.11	 0.0	 0.0	 1	 -30.0	 30.0;
	28399	 28400	 0.000235	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28402	 28401	 0.002169	 0.008898	 0.00961	 212.61	 212.61	 212.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28441	 28402	 0.001841	 0.011896	 0.01271	 241.96	 241.96	 241.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28403	 28406	 0.000151	 0.009811	 0.0	 610.09	 610.09	 610.09	 1.0	 0.0	 1	 -30.0	 30.0;
	28403	 28407	 0.000215	 0.001095	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28403	 28408	 0.000226	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28404	 28406	 0.000347	 0.022569	 0.0	 485.09	 485.09	 485.09	 1.0	 0.0	 1	 -30.0	 30.0;
	28404	 28409	 0.000543	 0.003416	 0.00118	 255.71	 255.71	 255.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28404	 28836	 0.000917	 0.004775	 0.00182	 217.83	 217.83	 217.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28405	 28406	 0.002537	 0.164989	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28780	 28408	 0.000369	 0.003678	 0.0492	 1094.55	 1094.55	 1094.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28842	 28408	 0.000789	 0.009199	 0.21014	 1280.67	 1280.67	 1280.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28409	 28443	 0.000422	 0.002832	 0.00172	 207.56	 207.56	 207.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28409	 28450	 0.001611	 0.008566	 0.00414	 243.37	 243.37	 243.37	 0.0	 0.0	 1	 -30.0	 30.0;
	28409	 28473	 0.001368	 0.008143	 0.0076	 256.8	 256.8	 256.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28453	 28410	 0.000802	 0.005887	 0.00232	 237.55	 237.55	 237.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 28410	 0.001467	 0.006699	 0.01172	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28411	 28469	 0.004173	 0.021236	 0.02892	 194.51	 194.51	 194.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28412	 28413	 0.00028	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28412	 28414	 0.000219	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28412	 28415	 0.00021	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28421	 28413	 0.00559	 0.027178	 0.02098	 194.73	 194.73	 194.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28413	 28469	 0.002224	 0.014396	 0.08574	 240.0	 240.0	 240.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28413	 28808	 0.001598	 0.009772	 0.00295	 260.0	 260.0	 260.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28417	 28416	 0.000513	 0.02369	 0.0	 519.4	 519.4	 519.4	 1.0375	 0.0	 1	 -30.0	 30.0;
	28416	 28782	 0.000583	 0.007441	 0.15213	 1217.42	 1217.42	 1217.42	 0.0	 0.0	 1	 -30.0	 30.0;
	28508	 28417	 0.001254	 0.007657	 0.003	 246.98	 246.98	 246.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28419	 28420	 0.000262	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28419	 28421	 0.000271	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28421	 28808	 0.007234	 0.041313	 0.0148	 209.14	 209.14	 209.14	 0.0	 0.0	 1	 -30.0	 30.0;
	28422	 28481	 0.003427	 0.021275	 0.0116	 222.35	 222.35	 222.35	 0.0	 0.0	 1	 -30.0	 30.0;
	28422	 28724	 0.001378	 0.005804	 0.00593	 247.2	 247.2	 247.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28423	 28424	 0.000236	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28424	 28446	 0.002434	 0.016946	 0.0051	 231.19	 231.19	 231.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28456	 28424	 0.001128	 0.007043	 0.00404	 211.98	 211.98	 211.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28424	 28495	 0.003443	 0.017183	 0.00925	 226.58	 226.58	 226.58	 0.0	 0.0	 1	 -30.0	 30.0;
	28425	 28426	 0.000295	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28425	 28836	 0.001307	 0.008229	 0.00295	 234.59	 234.59	 234.59	 0.0	 0.0	 1	 -30.0	 30.0;
	28427	 28441	 0.005563	 0.033014	 0.0318	 230.06	 230.06	 230.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28428	 28431	 0.001271	 0.074842	 0.0	 474.08	 474.08	 474.08	 1.0	 0.0	 1	 -30.0	 30.0;
	28428	 29081	 0.000337	 0.004395	 0.18401	 1299.3	 1299.3	 1299.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28429	 28431	 -0.000637	 -0.037512	 0.0	 449.08	 449.08	 449.08	 1.0	 0.0	 1	 -30.0	 30.0;
	28430	 28431	 0.002674	 0.157499	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28432	 28433	 0.000218	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28432	 28783	 0.001101	 0.005233	 0.00387	 291.75	 291.75	 291.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28432	 28783	 0.001101	 0.005233	 0.00387	 291.75	 291.75	 291.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28432	 28783	 0.001101	 0.005233	 0.00387	 291.75	 291.75	 291.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28434	 28435	 0.000269	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28508	 28434	 0.005898	 0.023892	 0.0269	 217.98	 217.98	 217.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28434	 28531	 0.002792	 0.015496	 0.00497	 250.12	 250.12	 250.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28437	 28524	 0.001796	 0.011983	 0.00401	 231.95	 231.95	 231.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28437	 28843	 0.00181	 0.011372	 0.01106	 233.56	 233.56	 233.56	 0.0	 0.0	 1	 -30.0	 30.0;
	29004	 28437	 0.001739	 0.008551	 0.00997	 217.89	 217.89	 217.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28469	 28438	 0.001386	 0.008444	 0.03017	 226.55	 226.55	 226.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28438	 28626	 0.004713	 0.021782	 0.03814	 248.39	 248.39	 248.39	 0.0	 0.0	 1	 -30.0	 30.0;
	29082	 28439	 0.003421	 0.023146	 0.0061	 239.17	 239.17	 239.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28440	 28504	 0.001972	 0.010313	 0.00498	 196.19	 196.19	 196.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28440	 28583	 0.006036	 0.030919	 0.02487	 236.73	 236.73	 236.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28442	 28783	 0.00184	 0.00959	 0.01751	 251.06	 251.06	 251.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28444	 28445	 0.000298	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28444	 28446	 0.000233	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28979	 28446	 0.003268	 0.013167	 0.01028	 251.88	 251.88	 251.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28447	 28493	 0.002736	 0.017034	 0.02478	 229.85	 229.85	 229.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28447	 28495	 0.002088	 0.009614	 0.00166	 254.76	 254.76	 254.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28447	 28979	 0.00066	 0.00404	 0.02855	 287.41	 287.41	 287.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28447	 28979	 0.00066	 0.00404	 0.02855	 287.41	 287.41	 287.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28447	 28979	 0.00066	 0.00404	 0.02855	 287.41	 287.41	 287.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28448	 28449	 0.000234	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28448	 28572	 0.001707	 0.009456	 0.0033	 157.5	 157.5	 157.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28448	 28806	 0.002773	 0.015589	 0.0314	 238.05	 238.05	 238.05	 0.0	 0.0	 1	 -30.0	 30.0;
	28450	 28451	 0.000205	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28774	 28450	 0.001696	 0.011952	 0.01164	 265.32	 265.32	 265.32	 0.0	 0.0	 1	 -30.0	 30.0;
	28452	 28453	 0.000252	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28452	 28454	 0.000286	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28453	 28455	 0.001393	 0.007918	 0.00298	 202.61	 202.61	 202.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28456	 28457	 0.000206	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28459	 28458	 0.000179	 0.010006	 0.0	 468.62	 468.62	 468.62	 1.0125	 0.0	 1	 -30.0	 30.0;
	28458	 28460	 0.000264	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28458	 28461	 0.000262	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28459	 28476	 0.002731	 0.014452	 0.00534	 212.44	 212.44	 212.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28460	 28848	 0.000487	 0.006681	 0.14866	 1113.41	 1113.41	 1113.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28460	 28964	 0.001354	 0.017412	 0.32271	 1273.95	 1273.95	 1273.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28464	 28463	 0.001167	 0.005088	 0.00565	 244.85	 244.85	 244.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28463	 28783	 0.001213	 0.006676	 0.00139	 303.76	 303.76	 303.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28464	 28465	 0.000219	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28503	 28466	 0.00334	 0.016197	 0.00525	 228.51	 228.51	 228.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28467	 28468	 0.000214	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28524	 28467	 0.002235	 0.014311	 0.00896	 232.78	 232.78	 232.78	 0.0	 0.0	 1	 -30.0	 30.0;
	28469	 28470	 0.000269	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28469	 28471	 0.001905	 0.0105	 0.00692	 163.4	 163.4	 163.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28471	 28567	 0.007744	 0.047353	 0.01454	 225.93	 225.93	 225.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28472	 28549	 0.001206	 0.005633	 0.00713	 231.71	 231.71	 231.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28473	 28485	 0.003285	 0.020508	 0.00993	 217.11	 217.11	 217.11	 0.0	 0.0	 1	 -30.0	 30.0;
	28474	 28475	 0.001428	 0.007983	 0.00785	 192.38	 192.38	 192.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28474	 28522	 0.001521	 0.009362	 0.00755	 203.67	 203.67	 203.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28474	 28774	 0.000594	 0.003522	 0.0032	 306.87	 306.87	 306.87	 0.0	 0.0	 1	 -30.0	 30.0;
	28475	 28490	 0.001668	 0.009581	 0.02331	 268.06	 268.06	 268.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28475	 28523	 0.004855	 0.026373	 0.01176	 174.96	 174.96	 174.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28979	 28475	 0.000291	 0.001848	 0.00074	 282.1	 282.1	 282.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28979	 28475	 0.000291	 0.001848	 0.00074	 282.1	 282.1	 282.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28477	 28476	 0.003826	 0.025394	 0.00485	 174.37	 174.37	 174.37	 0.0	 0.0	 1	 -30.0	 30.0;
	28477	 28478	 0.000204	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28477	 28619	 0.008665	 0.056071	 0.02118	 218.3	 218.3	 218.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28485	 28479	 0.001763	 0.012289	 0.0153	 207.08	 207.08	 207.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28577	 28479	 0.004126	 0.023976	 0.00683	 236.41	 236.41	 236.41	 0.0	 0.0	 1	 -30.0	 30.0;
	28480	 28485	 0.002621	 0.013746	 0.00512	 194.58	 194.58	 194.58	 0.0	 0.0	 1	 -30.0	 30.0;
	28480	 28488	 0.001377	 0.008901	 0.00195	 201.24	 201.24	 201.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28481	 28501	 0.001573	 0.007902	 0.02294	 208.8	 208.8	 208.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28980	 28481	 0.000813	 0.003958	 0.0022	 216.61	 216.61	 216.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28482	 28483	 0.000265	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28482	 28513	 0.001272	 0.006006	 0.00341	 173.12	 173.12	 173.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28482	 28545	 0.000878	 0.003888	 0.00123	 241.49	 241.49	 241.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28482	 29017	 0.002024	 0.013137	 0.03476	 261.77	 261.77	 261.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28484	 28513	 0.001365	 0.00587	 0.00514	 192.11	 192.11	 192.11	 0.0	 0.0	 1	 -30.0	 30.0;
	28544	 28484	 0.00284	 0.014328	 0.00503	 207.81	 207.81	 207.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28485	 28486	 0.000232	 0.001025	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28487	 28488	 0.000283	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28487	 28489	 0.000208	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28980	 28488	 0.00305	 0.017099	 0.0059	 240.52	 240.52	 240.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28490	 28541	 0.000905	 0.006022	 0.01615	 231.38	 231.38	 231.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28572	 28490	 0.001248	 0.007413	 0.00154	 220.24	 220.24	 220.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28491	 28492	 0.000208	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28491	 28563	 0.002254	 0.013041	 0.01061	 218.36	 218.36	 218.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28491	 28599	 0.004194	 0.021349	 0.02057	 235.83	 235.83	 235.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28493	 28494	 0.000232	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28493	 28516	 0.000731	 0.003092	 0.00269	 156.92	 156.92	 156.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28495	 28496	 0.000253	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28497	 29017	 0.003627	 0.021488	 0.02124	 228.69	 228.69	 228.69	 0.0	 0.0	 1	 -30.0	 30.0;
	28497	 29061	 0.001333	 0.008494	 0.01012	 191.09	 191.09	 191.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28519	 28498	 0.003003	 0.012345	 0.00736	 220.42	 220.42	 220.42	 0.0	 0.0	 1	 -30.0	 30.0;
	28547	 28498	 0.000336	 0.002014	 0.00825	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28499	 28500	 0.000273	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28499	 28501	 0.000208	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28501	 28790	 0.001871	 0.012446	 0.00572	 243.12	 243.12	 243.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28503	 28502	 0.000641	 0.032529	 0.0	 505.66	 505.66	 505.66	 1.025	 0.0	 1	 -30.0	 30.0;
	28813	 28502	 0.000529	 0.006402	 0.16369	 1108.12	 1108.12	 1108.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28842	 28502	 0.000448	 0.004555	 0.09488	 1276.48	 1276.48	 1276.48	 0.0	 0.0	 1	 -30.0	 30.0;
	28604	 28503	 0.002124	 0.010453	 0.00274	 241.29	 241.29	 241.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28504	 28505	 0.000281	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28506	 28507	 0.000268	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28506	 28508	 0.000259	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28510	 28509	 0.003777	 0.023884	 0.00752	 228.1	 228.1	 228.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28567	 28509	 0.004011	 0.024461	 0.00407	 231.92	 231.92	 231.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28509	 28624	 0.007636	 0.03919	 0.01674	 211.96	 211.96	 211.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28510	 28564	 0.003487	 0.018593	 0.01782	 195.02	 195.02	 195.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28511	 28512	 0.000243	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28511	 28513	 0.000254	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28513	 28728	 0.005743	 0.023318	 0.02475	 240.7	 240.7	 240.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28514	 28515	 0.000211	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28514	 28516	 0.000289	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28514	 28517	 0.000202	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28544	 28516	 0.000301	 0.001885	 0.00141	 231.45	 231.45	 231.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28518	 28519	 0.000217	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 28519	 0.000536	 0.003428	 0.00505	 258.23	 258.23	 258.23	 0.0	 0.0	 1	 -30.0	 30.0;
	28520	 28521	 0.000261	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28520	 28544	 0.001607	 0.008743	 0.00667	 225.6	 225.6	 225.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28520	 28549	 0.001273	 0.007881	 0.00141	 195.87	 195.87	 195.87	 0.0	 0.0	 1	 -30.0	 30.0;
	28522	 28979	 0.002183	 0.016313	 0.00496	 210.76	 210.76	 210.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28523	 28900	 0.003969	 0.014519	 0.01615	 205.89	 205.89	 205.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28524	 28808	 0.009035	 0.048758	 0.01939	 231.26	 231.26	 231.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28525	 28603	 0.001322	 0.009854	 0.00429	 206.15	 206.15	 206.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28604	 28525	 0.003351	 0.018083	 0.02797	 201.53	 201.53	 201.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28526	 28527	 0.000221	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28526	 28528	 0.000233	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28526	 28529	 0.000217	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28595	 28528	 0.001126	 0.007515	 0.00776	 216.75	 216.75	 216.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28528	 28979	 0.002054	 0.009955	 0.0059	 264.44	 264.44	 264.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28592	 28530	 0.001193	 0.006716	 0.00336	 194.35	 194.35	 194.35	 0.0	 0.0	 1	 -30.0	 30.0;
	28530	 28806	 0.001014	 0.005348	 0.00219	 215.64	 215.64	 215.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28530	 28856	 0.001481	 0.007512	 0.00186	 216.12	 216.12	 216.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28531	 28582	 0.003152	 0.023568	 0.01093	 235.1	 235.1	 235.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28531	 28640	 0.007016	 0.042666	 0.03831	 230.98	 230.98	 230.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28532	 28533	 0.000207	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28532	 28534	 0.000251	 0.001066	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28635	 28534	 0.002848	 0.014757	 0.00435	 238.77	 238.77	 238.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28534	 28688	 0.018785	 0.116496	 0.12636	 260.57	 260.57	 260.57	 0.0	 0.0	 1	 -30.0	 30.0;
	28536	 28535	 0.00038	 0.02022	 0.0	 528.49	 528.49	 528.49	 1.0	 0.0	 1	 -30.0	 30.0;
	28535	 28540	 0.000288	 0.001175	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28535	 28631	 0.000567	 0.005723	 0.10686	 1038.78	 1038.78	 1038.78	 0.0	 0.0	 1	 -30.0	 30.0;
	28842	 28535	 0.000642	 0.008285	 0.13102	 1291.81	 1291.81	 1291.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28536	 28539	 0.000403	 0.01295	 0.0	 91.99	 91.99	 91.99	 1.0	 0.0	 1	 -30.0	 30.0;
	28536	 28577	 0.00237	 0.017953	 0.00404	 258.08	 258.08	 258.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28578	 28536	 0.005281	 0.026571	 0.00951	 237.67	 237.67	 237.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28536	 28603	 0.002886	 0.021928	 0.03047	 244.24	 244.24	 244.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28623	 28536	 0.004533	 0.026702	 0.02044	 202.45	 202.45	 202.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28536	 28635	 0.00214	 0.009092	 0.00561	 174.91	 174.91	 174.91	 0.0	 0.0	 1	 -30.0	 30.0;
	28536	 28637	 0.002795	 0.019746	 0.01268	 178.76	 178.76	 178.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28537	 28539	 0.007135	 0.229177	 0.0	 46.0	 46.0	 46.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28538	 28539	 0.007135	 0.229177	 0.0	 46.0	 46.0	 46.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28541	 28542	 0.000212	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28541	 28606	 0.001755	 0.010184	 0.00138	 214.95	 214.95	 214.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28541	 28932	 0.002059	 0.016963	 0.01654	 206.4	 206.4	 206.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28544	 28543	 0.000395	 0.02875	 0.0	 518.57	 518.57	 518.57	 1.0	 0.0	 1	 -30.0	 30.0;
	28548	 28543	 0.000144	 0.00165	 0.03324	 1086.3	 1086.3	 1086.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28543	 29016	 0.000667	 0.008593	 0.11304	 1271.29	 1271.29	 1271.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28544	 28547	 0.001475	 0.009689	 0.00693	 229.44	 229.44	 229.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28545	 28546	 0.000282	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28580	 28545	 0.001844	 0.009275	 0.00925	 206.09	 206.09	 206.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28547	 28932	 0.001509	 0.00621	 0.00259	 233.15	 233.15	 233.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28548	 28551	 0.000761	 0.043032	 0.0	 527.18	 527.18	 527.18	 1.0	 0.0	 1	 -30.0	 30.0;
	28548	 28598	 0.000489	 0.005972	 0.15484	 1129.75	 1129.75	 1129.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28548	 28909	 0.000288	 0.003719	 0.06617	 1227.94	 1227.94	 1227.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28978	 28548	 0.000524	 0.006392	 0.08859	 1158.83	 1158.83	 1158.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28548	 29016	 0.000526	 0.006135	 0.23	 1368.54	 1368.54	 1368.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28549	 28551	 -0.000197	 -0.011167	 0.0	 502.18	 502.18	 502.18	 1.0	 0.0	 1	 -30.0	 30.0;
	28549	 28560	 0.001798	 0.007627	 0.00163	 228.89	 228.89	 228.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28550	 28551	 0.003094	 0.174953	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28573	 28552	 0.002324	 0.013694	 0.00374	 213.76	 213.76	 213.76	 0.0	 0.0	 1	 -30.0	 30.0;
	28552	 28580	 0.001346	 0.006996	 0.00182	 177.42	 177.42	 177.42	 0.0	 0.0	 1	 -30.0	 30.0;
	28552	 28601	 0.002232	 0.015179	 0.01308	 204.39	 204.39	 204.39	 0.0	 0.0	 1	 -30.0	 30.0;
	28554	 28553	 0.002062	 0.01303	 0.00812	 236.75	 236.75	 236.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28558	 28553	 0.001749	 0.00877	 0.01068	 218.53	 218.53	 218.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28553	 28599	 0.001618	 0.009732	 0.00678	 254.17	 254.17	 254.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28553	 29061	 0.000988	 0.004655	 0.00526	 231.62	 231.62	 231.62	 0.0	 0.0	 1	 -30.0	 30.0;
	28563	 28554	 0.001793	 0.006096	 0.00636	 190.48	 190.48	 190.48	 0.0	 0.0	 1	 -30.0	 30.0;
	28597	 28555	 0.004121	 0.021402	 0.02249	 195.62	 195.62	 195.62	 0.0	 0.0	 1	 -30.0	 30.0;
	28638	 28555	 0.004232	 0.021946	 0.00804	 254.48	 254.48	 254.48	 0.0	 0.0	 1	 -30.0	 30.0;
	28556	 28568	 0.003251	 0.019089	 0.00709	 188.27	 188.27	 188.27	 0.0	 0.0	 1	 -30.0	 30.0;
	28556	 28617	 0.001867	 0.011648	 0.00565	 215.49	 215.49	 215.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28557	 28558	 0.000276	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28557	 28559	 0.000242	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28560	 28561	 0.000236	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28560	 28606	 0.001495	 0.009252	 0.02308	 201.32	 201.32	 201.32	 0.0	 0.0	 1	 -30.0	 30.0;
	28562	 28563	 0.000284	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28564	 28565	 0.000244	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28564	 28808	 0.005796	 0.031142	 0.00904	 227.68	 227.68	 227.68	 0.0	 0.0	 1	 -30.0	 30.0;
	28567	 28566	 0.000277	 0.018819	 0.0	 436.61	 436.61	 436.61	 1.04375	 0.0	 1	 -30.0	 30.0;
	28566	 28625	 0.000753	 0.008655	 0.09514	 1139.95	 1139.95	 1139.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28567	 28646	 0.011476	 0.062471	 0.06278	 210.73	 210.73	 210.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28568	 29082	 0.002308	 0.013192	 0.01772	 236.92	 236.92	 236.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28569	 28611	 0.004005	 0.022542	 0.00928	 176.79	 176.79	 176.79	 0.0	 0.0	 1	 -30.0	 30.0;
	28569	 28647	 0.014586	 0.068852	 0.05078	 218.56	 218.56	 218.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28570	 28571	 0.00029	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28570	 28572	 0.000217	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28573	 28575	 0.00227	 0.012263	 0.00503	 239.24	 239.24	 239.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28575	 28574	 0.000378	 0.024683	 0.0	 536.86	 536.86	 536.86	 1.05	 0.0	 1	 -30.0	 30.0;
	28574	 28780	 0.000605	 0.006459	 0.28526	 1151.74	 1151.74	 1151.74	 0.0	 0.0	 1	 -30.0	 30.0;
	29016	 28574	 0.000489	 0.006197	 0.1491	 1342.46	 1342.46	 1342.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28601	 28575	 0.001925	 0.01384	 0.00621	 237.45	 237.45	 237.45	 0.0	 0.0	 1	 -30.0	 30.0;
	28575	 28628	 0.001422	 0.008964	 0.06002	 220.87	 220.87	 220.87	 0.0	 0.0	 1	 -30.0	 30.0;
	28575	 28629	 0.001524	 0.007806	 0.00238	 226.84	 226.84	 226.84	 0.0	 0.0	 1	 -30.0	 30.0;
	28612	 28576	 0.003278	 0.016356	 0.00759	 187.46	 187.46	 187.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28618	 28576	 0.001222	 0.009429	 0.00404	 200.71	 200.71	 200.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28578	 28579	 0.000294	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28578	 28595	 0.001517	 0.010166	 0.01317	 187.77	 187.77	 187.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28580	 28615	 0.004728	 0.025567	 0.01709	 214.12	 214.12	 214.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28582	 28581	 0.000286	 0.020307	 0.0	 492.92	 492.92	 492.92	 1.0125	 0.0	 1	 -30.0	 30.0;
	28581	 28782	 0.000582	 0.007312	 0.1438	 1038.88	 1038.88	 1038.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28581	 28924	 0.001141	 0.014195	 0.36488	 1169.06	 1169.06	 1169.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28582	 28583	 0.006072	 0.030332	 0.01813	 255.2	 255.2	 255.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28583	 28584	 0.000237	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28596	 28583	 0.002868	 0.012815	 0.00338	 187.92	 187.92	 187.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28585	 28586	 0.000293	 0.001009	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28585	 28615	 0.000845	 0.005335	 0.00526	 234.74	 234.74	 234.74	 0.0	 0.0	 1	 -30.0	 30.0;
	29017	 28585	 0.001438	 0.007647	 0.00422	 258.99	 258.99	 258.99	 0.0	 0.0	 1	 -30.0	 30.0;
	28587	 28588	 0.000252	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28588	 29017	 0.001172	 0.006328	 0.00372	 184.57	 184.57	 184.57	 0.0	 0.0	 1	 -30.0	 30.0;
	28588	 29059	 0.001256	 0.006825	 0.00199	 220.09	 220.09	 220.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28599	 28589	 0.0011	 0.005548	 0.00156	 223.87	 223.87	 223.87	 0.0	 0.0	 1	 -30.0	 30.0;
	28613	 28589	 0.001458	 0.008551	 0.00446	 174.95	 174.95	 174.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28628	 28590	 0.002395	 0.011393	 0.01113	 192.73	 192.73	 192.73	 0.0	 0.0	 1	 -30.0	 30.0;
	28590	 28632	 0.004226	 0.02167	 0.0102	 221.77	 221.77	 221.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28591	 28629	 0.000723	 0.005353	 0.00109	 189.86	 189.86	 189.86	 0.0	 0.0	 1	 -30.0	 30.0;
	28856	 28591	 0.002394	 0.013662	 0.01007	 222.1	 222.1	 222.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28592	 28593	 0.000202	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28592	 28806	 0.001124	 0.007297	 0.00482	 218.5	 218.5	 218.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28594	 28595	 0.003107	 0.013474	 0.00681	 200.77	 200.77	 200.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28594	 28979	 0.002296	 0.016672	 0.01562	 241.56	 241.56	 241.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28595	 28608	 0.001045	 0.00467	 0.00117	 162.15	 162.15	 162.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28597	 28596	 0.005194	 0.037502	 0.01786	 227.31	 227.31	 227.31	 0.0	 0.0	 1	 -30.0	 30.0;
	28597	 29066	 0.006471	 0.036353	 0.04068	 260.71	 260.71	 260.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28599	 28598	 0.000458	 0.027057	 0.0	 531.69	 531.69	 531.69	 1.04375	 0.0	 1	 -30.0	 30.0;
	28598	 29016	 0.000451	 0.005296	 0.06266	 1328.35	 1328.35	 1328.35	 0.0	 0.0	 1	 -30.0	 30.0;
	28600	 28601	 0.000276	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28600	 28602	 0.000288	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28601	 28643	 0.003363	 0.019005	 0.02907	 159.68	 159.68	 159.68	 0.0	 0.0	 1	 -30.0	 30.0;
	28605	 28606	 0.000244	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28605	 28607	 0.000279	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28608	 28609	 0.000255	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28608	 28856	 0.004348	 0.016352	 0.01468	 229.63	 229.63	 229.63	 0.0	 0.0	 1	 -30.0	 30.0;
	28610	 28891	 0.031096	 0.228525	 0.22336	 236.5	 236.5	 236.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28611	 28626	 0.00263	 0.01222	 0.00745	 206.4	 206.4	 206.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28617	 28612	 0.001825	 0.009147	 0.00435	 234.53	 234.53	 234.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28626	 28612	 0.002459	 0.012731	 0.00622	 254.93	 254.93	 254.93	 0.0	 0.0	 1	 -30.0	 30.0;
	28613	 28614	 0.000226	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28613	 29059	 0.00364	 0.019783	 0.03368	 226.26	 226.26	 226.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28616	 28617	 0.000291	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28618	 28654	 0.013812	 0.088682	 0.04242	 225.17	 225.17	 225.17	 0.0	 0.0	 1	 -30.0	 30.0;
	28619	 28620	 0.000267	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28641	 28619	 0.010946	 0.06244	 0.04838	 206.39	 206.39	 206.39	 0.0	 0.0	 1	 -30.0	 30.0;
	28619	 28960	 0.016233	 0.059501	 0.03923	 242.24	 242.24	 242.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28621	 28622	 0.000209	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28622	 28623	 0.001773	 0.009025	 0.00594	 193.58	 193.58	 193.58	 0.0	 0.0	 1	 -30.0	 30.0;
	28622	 28632	 0.004233	 0.020182	 0.00968	 206.4	 206.4	 206.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28632	 28623	 0.002013	 0.012957	 0.00415	 212.43	 212.43	 212.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28624	 28656	 0.008699	 0.05022	 0.08175	 245.33	 245.33	 245.33	 0.0	 0.0	 1	 -30.0	 30.0;
	28626	 28625	 0.000296	 0.017602	 0.0	 490.73	 490.73	 490.73	 1.03125	 0.0	 1	 -30.0	 30.0;
	28625	 28627	 0.000261	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28763	 28625	 0.001107	 0.013283	 0.38728	 1330.67	 1330.67	 1330.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28629	 28630	 0.0003	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28632	 28631	 0.00051	 0.03385	 0.0	 448.66	 448.66	 448.66	 1.03125	 0.0	 1	 -30.0	 30.0;
	28857	 28631	 0.000607	 0.006722	 0.11238	 1125.35	 1125.35	 1125.35	 0.0	 0.0	 1	 -30.0	 30.0;
	28633	 28634	 0.000209	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28644	 28634	 0.003666	 0.017688	 0.00861	 229.53	 229.53	 229.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28634	 28756	 0.017874	 0.082557	 0.05883	 264.05	 264.05	 264.05	 0.0	 0.0	 1	 -30.0	 30.0;
	28635	 28636	 0.000201	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28635	 28637	 0.000894	 0.004473	 0.02714	 211.31	 211.31	 211.31	 0.0	 0.0	 1	 -30.0	 30.0;
	28638	 28639	 0.000296	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28640	 28638	 0.002344	 0.012177	 0.00592	 192.81	 192.81	 192.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28638	 29037	 0.003202	 0.018563	 0.13723	 265.72	 265.72	 265.72	 0.0	 0.0	 1	 -30.0	 30.0;
	29062	 28640	 0.005577	 0.033559	 0.02274	 253.88	 253.88	 253.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28662	 28641	 0.010992	 0.060836	 0.0276	 162.18	 162.18	 162.18	 0.0	 0.0	 1	 -30.0	 30.0;
	28642	 28643	 0.000248	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28643	 28644	 0.005291	 0.029732	 0.02283	 196.26	 196.26	 196.26	 0.0	 0.0	 1	 -30.0	 30.0;
	28646	 28685	 0.008439	 0.055889	 0.07645	 220.72	 220.72	 220.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28647	 28859	 0.006098	 0.031523	 0.01346	 241.82	 241.82	 241.82	 0.0	 0.0	 1	 -30.0	 30.0;
	28648	 28917	 0.001373	 0.007958	 0.00992	 176.2	 176.2	 176.2	 0.0	 0.0	 1	 -30.0	 30.0;
	29038	 28648	 0.001501	 0.009381	 0.00511	 236.37	 236.37	 236.37	 0.0	 0.0	 1	 -30.0	 30.0;
	29066	 28648	 0.000689	 0.004356	 0.00617	 214.52	 214.52	 214.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28649	 28652	 0.000518	 0.014407	 0.0	 91.24	 91.24	 91.24	 1.0	 0.0	 1	 -30.0	 30.0;
	28658	 28649	 0.002492	 0.01261	 0.0059	 207.43	 207.43	 207.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28649	 28925	 0.002714	 0.013867	 0.01261	 233.72	 233.72	 233.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28650	 28652	 0.00741	 0.206222	 0.0	 45.62	 45.62	 45.62	 1.0	 0.0	 1	 -30.0	 30.0;
	28651	 28652	 0.00741	 0.206222	 0.0	 45.62	 45.62	 45.62	 1.0	 0.0	 1	 -30.0	 30.0;
	28653	 28654	 0.000214	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29038	 28654	 0.006121	 0.029492	 0.0159	 247.44	 247.44	 247.44	 0.0	 0.0	 1	 -30.0	 30.0;
	28656	 28655	 0.000613	 0.036358	 0.0	 426.81	 426.81	 426.81	 1.01875	 0.0	 1	 -30.0	 30.0;
	28655	 28657	 0.000273	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28655	 28684	 0.000487	 0.006578	 0.13033	 1099.42	 1099.42	 1099.42	 0.0	 0.0	 1	 -30.0	 30.0;
	28655	 28924	 0.000676	 0.008481	 0.2442	 1100.94	 1100.94	 1100.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28664	 28656	 0.002683	 0.015994	 0.00645	 177.89	 177.89	 177.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28656	 28666	 0.003767	 0.017862	 0.00332	 220.49	 220.49	 220.49	 0.0	 0.0	 1	 -30.0	 30.0;
	28658	 28659	 0.003995	 0.029107	 0.0104	 189.25	 189.25	 189.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28859	 28658	 0.002348	 0.013596	 0.01431	 212.24	 212.24	 212.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28659	 28726	 0.006813	 0.041535	 0.02418	 216.95	 216.95	 216.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28660	 28661	 0.000277	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29055	 28660	 0.006107	 0.03772	 0.03133	 243.6	 243.6	 243.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28660	 29062	 0.00493	 0.026326	 0.1733	 227.94	 227.94	 227.94	 0.0	 0.0	 1	 -30.0	 30.0;
	28662	 28663	 0.000278	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28662	 28673	 0.00879	 0.043178	 0.05805	 202.75	 202.75	 202.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28664	 28665	 0.00026	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28664	 28917	 0.007638	 0.04316	 0.05355	 211.64	 211.64	 211.64	 0.0	 0.0	 1	 -30.0	 30.0;
	28666	 28667	 0.00339	 0.017073	 0.0174	 177.36	 177.36	 177.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28667	 28675	 0.001586	 0.009473	 0.0149	 204.88	 204.88	 204.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28668	 28671	 -0.000794	 -0.022571	 0.0	 89.67	 89.67	 89.67	 1.0	 0.0	 1	 -30.0	 30.0;
	28668	 28672	 0.003002	 0.018889	 0.00501	 193.53	 193.53	 193.53	 0.0	 0.0	 1	 -30.0	 30.0;
	28685	 28668	 0.005702	 0.030116	 0.01206	 234.11	 234.11	 234.11	 0.0	 0.0	 1	 -30.0	 30.0;
	28669	 28671	 0.010873	 0.308973	 0.0	 44.83	 44.83	 44.83	 1.0	 0.0	 1	 -30.0	 30.0;
	28670	 28671	 0.010873	 0.308973	 0.0	 44.83	 44.83	 44.83	 1.0	 0.0	 1	 -30.0	 30.0;
	28677	 28672	 0.00239	 0.015046	 0.00415	 195.77	 195.77	 195.77	 0.0	 0.0	 1	 -30.0	 30.0;
	29055	 28673	 0.005069	 0.032149	 0.01738	 219.95	 219.95	 219.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28674	 28680	 0.006996	 0.038153	 0.00929	 221.24	 221.24	 221.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28674	 28948	 0.019488	 0.099499	 0.12665	 244.81	 244.81	 244.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28675	 28676	 0.00025	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28675	 28677	 0.002717	 0.019825	 0.03785	 218.65	 218.65	 218.65	 0.0	 0.0	 1	 -30.0	 30.0;
	28675	 28685	 0.002573	 0.010282	 0.0046	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28677	 28678	 0.000202	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28834	 28679	 0.010178	 0.060755	 0.01593	 218.51	 218.51	 218.51	 0.0	 0.0	 1	 -30.0	 30.0;
	28996	 28679	 0.00603	 0.031426	 0.01075	 198.66	 198.66	 198.66	 0.0	 0.0	 1	 -30.0	 30.0;
	28680	 28681	 0.000278	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28834	 28680	 0.006528	 0.028882	 0.01305	 224.36	 224.36	 224.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28680	 28996	 0.002107	 0.013089	 0.00757	 215.09	 215.09	 215.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28682	 28683	 0.000257	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28682	 28685	 0.001877	 0.00969	 0.00551	 241.54	 241.54	 241.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28996	 28682	 0.003314	 0.014386	 0.0046	 257.75	 257.75	 257.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28684	 28687	 0.000621	 0.040714	 0.0	 544.45	 544.45	 544.45	 1.0	 0.0	 1	 -30.0	 30.0;
	28833	 28684	 0.000508	 0.006278	 0.15503	 1225.18	 1225.18	 1225.18	 0.0	 0.0	 1	 -30.0	 30.0;
	28685	 28687	 -0.000244	 -0.016016	 0.0	 469.45	 469.45	 469.45	 1.0	 0.0	 1	 -30.0	 30.0;
	28686	 28687	 0.001921	 0.125946	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28688	 28986	 0.013167	 0.062966	 0.0719	 238.24	 238.24	 238.24	 0.0	 0.0	 1	 -30.0	 30.0;
	28688	 29053	 0.011356	 0.078624	 0.08039	 228.14	 228.14	 228.14	 0.0	 0.0	 1	 -30.0	 30.0;
	28689	 28690	 0.000265	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28694	 28689	 0.005178	 0.028201	 0.03942	 219.97	 219.97	 219.97	 0.0	 0.0	 1	 -30.0	 30.0;
	28689	 28823	 0.017979	 0.082826	 0.07012	 244.78	 244.78	 244.78	 0.0	 0.0	 1	 -30.0	 30.0;
	28691	 28692	 0.000269	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28691	 28693	 0.000227	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28697	 28693	 0.014305	 0.102427	 0.02731	 195.61	 195.61	 195.61	 0.0	 0.0	 1	 -30.0	 30.0;
	29055	 28693	 0.00965	 0.051571	 0.02042	 186.91	 186.91	 186.91	 0.0	 0.0	 1	 -30.0	 30.0;
	28694	 28834	 0.003719	 0.021366	 0.01697	 198.0	 198.0	 198.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28695	 28696	 0.000237	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28755	 28695	 0.006592	 0.034904	 0.01558	 178.2	 178.2	 178.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28695	 28835	 0.003401	 0.026237	 0.00968	 226.0	 226.0	 226.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28739	 28697	 0.017762	 0.108954	 0.04964	 234.7	 234.7	 234.7	 0.0	 0.0	 1	 -30.0	 30.0;
	28699	 28698	 0.002123	 0.012031	 0.00546	 185.75	 185.75	 185.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28698	 28750	 0.004898	 0.019046	 0.0128	 228.03	 228.03	 228.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28699	 28700	 0.000225	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28699	 28921	 0.003078	 0.017213	 0.00913	 216.68	 216.68	 216.68	 0.0	 0.0	 1	 -30.0	 30.0;
	28701	 28702	 0.000237	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28701	 28703	 0.000298	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28703	 28858	 0.005653	 0.034539	 0.00739	 183.47	 183.47	 183.47	 0.0	 0.0	 1	 -30.0	 30.0;
	29009	 28703	 0.001904	 0.01174	 0.0024	 191.98	 191.98	 191.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28705	 28704	 0.006824	 0.044675	 0.01267	 186.82	 186.82	 186.82	 0.0	 0.0	 1	 -30.0	 30.0;
	28894	 28704	 0.007295	 0.033571	 0.0311	 182.56	 182.56	 182.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28704	 28966	 0.001524	 0.008383	 0.01047	 228.05	 228.05	 228.05	 0.0	 0.0	 1	 -30.0	 30.0;
	28705	 29023	 0.004627	 0.025614	 0.04998	 208.02	 208.02	 208.02	 0.0	 0.0	 1	 -30.0	 30.0;
	28706	 28707	 0.000295	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28706	 28750	 0.004987	 0.024956	 0.01967	 233.13	 233.13	 233.13	 0.0	 0.0	 1	 -30.0	 30.0;
	28905	 28706	 0.011233	 0.06335	 0.03051	 224.08	 224.08	 224.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28708	 28709	 0.000233	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28708	 28710	 0.001334	 0.006333	 0.00697	 192.66	 192.66	 192.66	 0.0	 0.0	 1	 -30.0	 30.0;
	28835	 28708	 0.008914	 0.032755	 0.01994	 216.67	 216.67	 216.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28710	 28878	 0.004213	 0.028488	 0.0384	 189.83	 189.83	 189.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28712	 28711	 0.005752	 0.170643	 0.0	 128.88	 128.88	 128.88	 1.1	 0.0	 1	 -30.0	 30.0;
	28711	 28731	 0.011891	 0.051545	 0.01501	 181.12	 181.12	 181.12	 0.0	 0.0	 1	 -30.0	 30.0;
	28711	 28915	 0.030105	 0.116986	 0.02462	 195.58	 195.58	 195.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40725	 28712	 0.017504	 0.090659	 0.03607	 116.63	 116.63	 116.63	 0.0	 0.0	 1	 -30.0	 30.0;
	28713	 28714	 0.000268	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28713	 28881	 0.006491	 0.036963	 0.01801	 220.96	 220.96	 220.96	 0.0	 0.0	 1	 -30.0	 30.0;
	28950	 28713	 0.020467	 0.11568	 0.02786	 178.78	 178.78	 178.78	 0.0	 0.0	 1	 -30.0	 30.0;
	28715	 28716	 0.000211	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28716	 30285	 0.031951	 0.182144	 0.06322	 179.3	 179.3	 179.3	 0.0	 0.0	 1	 -30.0	 30.0;
	28718	 28717	 8.4e-05	 0.006128	 0.0	 1413.96	 1413.96	 1413.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28717	 28720	 9.5e-05	 0.006815	 0.0	 1346.86	 1346.86	 1346.86	 1.0	 0.0	 1	 -30.0	 30.0;
	28717	 28721	 6.3e-05	 0.004708	 0.0	 1345.34	 1345.34	 1345.34	 1.0	 0.0	 1	 -30.0	 30.0;
	28717	 28722	 8.6e-05	 0.006996	 0.0	 948.78	 948.78	 948.78	 1.0	 0.0	 1	 -30.0	 30.0;
	28758	 28717	 0.000462	 0.01289	 5.71685	 4198.08	 4198.08	 4198.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28717	 28847	 0.000106	 0.003043	 1.71323	 4162.78	 4162.78	 4162.78	 0.0	 0.0	 1	 -30.0	 30.0;
	28719	 28718	 0.000465	 0.028568	 0.0	 346.98	 346.98	 346.98	 1.0	 0.0	 1	 -30.0	 30.0;
	28718	 28723	 0.001244	 0.062371	 0.0	 205.46	 205.46	 205.46	 1.0	 0.0	 1	 -30.0	 30.0;
	28719	 28869	 0.002769	 0.014742	 0.00317	 226.1	 226.1	 226.1	 0.0	 0.0	 1	 -30.0	 30.0;
	28724	 28725	 0.006557	 0.18535	 0.0	 98.71	 98.71	 98.71	 1.0625	 0.0	 1	 -30.0	 30.0;
	28843	 28724	 0.000272	 0.001296	 0.00063	 285.9	 285.9	 285.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28843	 28724	 0.000272	 0.001296	 0.00063	 285.9	 285.9	 285.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28724	 29004	 0.000382	 0.002473	 0.00072	 244.29	 244.29	 244.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28726	 28727	 0.003807	 0.126047	 0.0	 86.45	 86.45	 86.45	 1.0	 0.0	 1	 -30.0	 30.0;
	28726	 28764	 0.001044	 0.005691	 0.00888	 188.8	 188.8	 188.8	 0.0	 0.0	 1	 -30.0	 30.0;
	28726	 28925	 0.001132	 0.004496	 0.00234	 193.15	 193.15	 193.15	 0.0	 0.0	 1	 -30.0	 30.0;
	28728	 28729	 0.003883	 0.128235	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29059	 28728	 0.000411	 0.002268	 0.00092	 189.9	 189.9	 189.9	 0.0	 0.0	 1	 -30.0	 30.0;
	28731	 28730	 0.000352	 0.023191	 0.0	 277.42	 277.42	 277.42	 1.0	 0.0	 1	 -30.0	 30.0;
	28730	 28920	 0.000875	 0.009846	 0.2077	 980.2	 980.2	 980.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28731	 28734	 -0.000495	 -0.014013	 0.0	 166.53	 166.53	 166.53	 1.0	 0.0	 1	 -30.0	 30.0;
	28731	 28735	 0.012395	 0.371207	 0.0	 40.58	 40.58	 40.58	 1.0	 0.0	 1	 -30.0	 30.0;
	28731	 28736	 0.008678	 0.257527	 0.0	 65.03	 65.03	 65.03	 1.0	 0.0	 1	 -30.0	 30.0;
	28731	 28921	 0.00503	 0.034818	 0.05319	 198.46	 198.46	 198.46	 0.0	 0.0	 1	 -30.0	 30.0;
	28732	 28734	 0.006437	 0.182281	 0.0	 83.27	 83.27	 83.27	 1.0	 0.0	 1	 -30.0	 30.0;
	28733	 28734	 0.006437	 0.182281	 0.0	 83.27	 83.27	 83.27	 1.0	 0.0	 1	 -30.0	 30.0;
	28738	 28737	 9.3e-05	 0.007486	 0.0	 1328.6	 1328.6	 1328.6	 0.98125	 0.0	 1	 -30.0	 30.0;
	28737	 28740	 0.000102	 0.008545	 0.0	 1031.43	 1031.43	 1031.43	 1.00625	 0.0	 1	 -30.0	 30.0;
	28737	 28741	 0.000122	 0.009723	 0.0	 1025.1	 1025.1	 1025.1	 1.0	 0.0	 1	 -30.0	 30.0;
	28737	 28742	 0.000126	 0.010612	 0.0	 1013.74	 1013.74	 1013.74	 1.00625	 0.0	 1	 -30.0	 30.0;
	28737	 28743	 0.000131	 0.009688	 0.0	 1003.52	 1003.52	 1003.52	 1.00625	 0.0	 1	 -30.0	 30.0;
	28737	 28744	 0.000209	 0.015009	 0.0	 997.12	 997.12	 997.12	 1.00625	 0.0	 1	 -30.0	 30.0;
	28737	 28745	 0.00011	 0.000963	 0.0	 7500.0	 7500.0	 7500.0	 1.0	 -7.696	 1	 -30.0	 30.0;
	28737	 28746	 0.000205	 0.014972	 0.0	 1119.42	 1119.42	 1119.42	 1.00625	 0.0	 1	 -30.0	 30.0;
	28737	 28747	 0.000212	 0.014485	 0.0	 1116.24	 1116.24	 1116.24	 1.00625	 0.0	 1	 -30.0	 30.0;
	28737	 28748	 0.000138	 0.012996	 0.0	 1113.56	 1113.56	 1113.56	 1.00625	 0.0	 1	 -30.0	 30.0;
	28888	 28737	 0.000181	 0.005213	 2.54517	 4121.36	 4121.36	 4121.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28737	 40759	 0.000333	 0.009713	 4.18378	 4073.72	 4073.72	 4073.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28739	 28738	 0.000397	 0.025497	 0.0	 376.68	 376.68	 376.68	 0.99375	 0.0	 1	 -30.0	 30.0;
	28954	 28738	 0.000978	 0.012635	 0.33844	 1201.27	 1201.27	 1201.27	 0.0	 0.0	 1	 -30.0	 30.0;
	29054	 28738	 0.002089	 0.028181	 0.57276	 1238.4	 1238.4	 1238.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28745	 28772	 0.000299	 0.008353	 3.54094	 4125.56	 4125.56	 4125.56	 0.0	 0.0	 1	 -30.0	 30.0;
	28745	 28841	 0.00047	 0.01269	 7.0159	 4128.28	 4128.28	 4128.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28750	 28749	 0.000314	 0.021986	 0.0	 327.13	 327.13	 327.13	 1.0	 0.0	 1	 -30.0	 30.0;
	28749	 28751	 0.000629	 0.035494	 0.0	 348.68	 348.68	 348.68	 1.025	 0.0	 1	 -30.0	 30.0;
	28749	 28752	 0.000808	 0.049621	 0.0	 302.8	 302.8	 302.8	 1.025	 0.0	 1	 -30.0	 30.0;
	28749	 28753	 0.0007	 0.035812	 0.0	 348.15	 348.15	 348.15	 1.025	 0.0	 1	 -30.0	 30.0;
	28749	 28754	 0.000694	 0.036722	 0.0	 302.42	 302.42	 302.42	 1.025	 0.0	 1	 -30.0	 30.0;
	28911	 28749	 0.000287	 0.00402	 0.10139	 1223.2	 1223.2	 1223.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28749	 28935	 0.000222	 0.002743	 0.05679	 1140.08	 1140.08	 1140.08	 0.0	 0.0	 1	 -30.0	 30.0;
	29023	 28750	 0.001628	 0.008672	 0.00309	 247.65	 247.65	 247.65	 0.0	 0.0	 1	 -30.0	 30.0;
	28755	 28902	 0.00432	 0.023726	 0.04436	 220.01	 220.01	 220.01	 0.0	 0.0	 1	 -30.0	 30.0;
	28756	 28757	 0.002985	 0.093858	 0.0	 90.21	 90.21	 90.21	 1.0	 0.0	 1	 -30.0	 30.0;
	28905	 28756	 0.018024	 0.07819	 0.03084	 251.43	 251.43	 251.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28759	 28758	 0.00012	 0.009785	 0.0	 1410.98	 1410.98	 1410.98	 1.0	 0.0	 1	 -30.0	 30.0;
	28758	 28761	 0.000103	 0.009452	 0.0	 1321.41	 1321.41	 1321.41	 1.0	 0.0	 1	 -30.0	 30.0;
	28758	 40979	 0.000193	 0.00547	 3.31232	 4074.29	 4074.29	 4074.29	 0.0	 0.0	 1	 -30.0	 30.0;
	28760	 28759	 0.000358	 0.025244	 0.0	 321.21	 321.21	 321.21	 1.0	 0.0	 1	 -30.0	 30.0;
	28759	 28964	 0.004011	 0.043676	 1.18581	 1300.28	 1300.28	 1300.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28760	 28891	 0.001366	 0.009712	 0.00333	 209.52	 209.52	 209.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28763	 28762	 0.00011	 0.008054	 0.0	 1518.98	 1518.98	 1518.98	 1.01875	 0.0	 1	 -30.0	 30.0;
	28762	 28765	 0.00015	 0.011906	 0.0	 1318.81	 1318.81	 1318.81	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28766	 0.000108	 0.009172	 0.0	 1317.23	 1317.23	 1317.23	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28767	 0.00013	 0.010372	 0.0	 1315.75	 1315.75	 1315.75	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28768	 9.4e-05	 0.007515	 0.0	 1314.66	 1314.66	 1314.66	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28769	 6.9e-05	 0.005924	 0.0	 1314.25	 1314.25	 1314.25	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28770	 0.000153	 0.010517	 0.0	 1312.58	 1312.58	 1312.58	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28771	 0.000236	 0.018326	 0.0	 720.55	 720.55	 720.55	 1.0	 0.0	 1	 -30.0	 30.0;
	28762	 28772	 0.000282	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28764	 28763	 0.000421	 0.030883	 0.0	 411.73	 411.73	 411.73	 1.0125	 0.0	 1	 -30.0	 30.0;
	28924	 28763	 0.000134	 0.001845	 0.02286	 1103.03	 1103.03	 1103.03	 0.0	 0.0	 1	 -30.0	 30.0;
	28764	 28825	 0.001147	 0.007382	 0.00185	 217.15	 217.15	 217.15	 0.0	 0.0	 1	 -30.0	 30.0;
	29038	 28764	 0.0006	 0.003019	 0.00068	 235.13	 235.13	 235.13	 0.0	 0.0	 1	 -30.0	 30.0;
	28772	 28781	 0.000167	 0.004633	 1.95642	 4021.48	 4021.48	 4021.48	 0.0	 0.0	 1	 -30.0	 30.0;
	29080	 28772	 0.000152	 0.004347	 1.82886	 4022.54	 4022.54	 4022.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28774	 28773	 0.000518	 0.025802	 0.0	 474.34	 474.34	 474.34	 1.05625	 0.0	 1	 -30.0	 30.0;
	28773	 28778	 0.000695	 0.040452	 0.0	 339.33	 339.33	 339.33	 1.025	 0.0	 1	 -30.0	 30.0;
	28773	 28779	 0.000828	 0.041988	 0.0	 338.83	 338.83	 338.83	 1.025	 0.0	 1	 -30.0	 30.0;
	28773	 28780	 0.00024	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28774	 28777	 0.000771	 0.01932	 0.0	 89.5	 89.5	 89.5	 1.0	 0.0	 1	 -30.0	 30.0;
	28774	 28900	 0.000167	 0.000978	 0.00033	 203.92	 203.92	 203.92	 0.0	 0.0	 1	 -30.0	 30.0;
	28775	 28777	 0.008049	 0.201673	 0.0	 44.75	 44.75	 44.75	 1.0	 0.0	 1	 -30.0	 30.0;
	28776	 28777	 0.008049	 0.201673	 0.0	 44.75	 44.75	 44.75	 1.0	 0.0	 1	 -30.0	 30.0;
	28780	 28978	 0.00016	 0.001912	 0.04146	 1143.85	 1143.85	 1143.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28782	 28781	 8.5e-05	 0.006933	 0.0	 1722.57	 1722.57	 1722.57	 1.00625	 0.0	 1	 -30.0	 30.0;
	28782	 28781	 8.5e-05	 0.006933	 0.0	 1722.57	 1722.57	 1722.57	 1.00625	 0.0	 1	 -30.0	 30.0;
	28782	 28781	 8.5e-05	 0.006933	 0.0	 1722.57	 1722.57	 1722.57	 1.00625	 0.0	 1	 -30.0	 30.0;
	28781	 28784	 0.000129	 0.010359	 0.0	 1402.46	 1402.46	 1402.46	 0.99375	 0.0	 1	 -30.0	 30.0;
	28781	 28785	 0.000131	 0.012166	 0.0	 1400.9	 1400.9	 1400.9	 0.99375	 0.0	 1	 -30.0	 30.0;
	28781	 28786	 0.000113	 0.00855	 0.0	 1400.44	 1400.44	 1400.44	 0.99375	 0.0	 1	 -30.0	 30.0;
	28781	 28787	 0.000145	 0.011595	 0.0	 1399.39	 1399.39	 1399.39	 0.99375	 0.0	 1	 -30.0	 30.0;
	28781	 28788	 9.9e-05	 0.007866	 0.0	 1397.33	 1397.33	 1397.33	 0.99375	 0.0	 1	 -30.0	 30.0;
	28781	 28789	 0.000126	 0.01005	 0.0	 1393.9	 1393.9	 1393.9	 0.99375	 0.0	 1	 -30.0	 30.0;
	28794	 28781	 6.2e-05	 0.001885	 0.99176	 3978.4	 3978.4	 3978.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28781	 28847	 0.000153	 0.00384	 2.14967	 4122.47	 4122.47	 4122.47	 0.0	 0.0	 1	 -30.0	 30.0;
	28783	 28782	 0.000327	 0.022855	 0.0	 641.55	 641.55	 641.55	 1.0125	 0.0	 1	 -30.0	 30.0;
	28783	 28782	 0.000327	 0.022855	 0.0	 641.55	 641.55	 641.55	 1.0125	 0.0	 1	 -30.0	 30.0;
	28783	 28782	 0.000327	 0.022855	 0.0	 641.55	 641.55	 641.55	 1.0125	 0.0	 1	 -30.0	 30.0;
	28782	 28831	 0.000413	 0.004304	 0.09676	 1336.47	 1336.47	 1336.47	 0.0	 0.0	 1	 -30.0	 30.0;
	28782	 29003	 0.000694	 0.008971	 0.13922	 1293.85	 1293.85	 1293.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28790	 28793	 0.0001	 0.002421	 0.0	 254.08	 254.08	 254.08	 1.0	 0.0	 1	 -30.0	 30.0;
	28790	 29004	 0.001097	 0.005301	 0.00269	 200.75	 200.75	 200.75	 0.0	 0.0	 1	 -30.0	 30.0;
	28791	 28793	 0.004025	 0.114233	 0.0	 127.04	 127.04	 127.04	 1.0	 0.0	 1	 -30.0	 30.0;
	28792	 28793	 0.004025	 0.114233	 0.0	 127.04	 127.04	 127.04	 1.0	 0.0	 1	 -30.0	 30.0;
	28795	 28794	 0.000124	 0.00924	 0.0	 1522.96	 1522.96	 1522.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28794	 28797	 5.8e-05	 0.004985	 0.0	 1709.17	 1709.17	 1709.17	 1.05	 0.0	 1	 -30.0	 30.0;
	28794	 28798	 0.000105	 0.00797	 0.0	 1699.8	 1699.8	 1699.8	 1.05	 0.0	 1	 -30.0	 30.0;
	28796	 28795	 0.000512	 0.035942	 0.0	 475.85	 475.85	 475.85	 1.0	 0.0	 1	 -30.0	 30.0;
	28795	 28803	 0.000451	 0.005677	 0.06907	 1187.28	 1187.28	 1187.28	 0.0	 0.0	 1	 -30.0	 30.0;
	28860	 28795	 0.000559	 0.006095	 0.19559	 1128.71	 1128.71	 1128.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28796	 28985	 0.000422	 0.00252	 0.00132	 245.55	 245.55	 245.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28799	 28802	 0.000698	 0.037364	 0.0	 621.39	 621.39	 621.39	 1.0	 0.0	 1	 -30.0	 30.0;
	28799	 28803	 0.000291	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28800	 28802	 -0.000269	 -0.014378	 0.0	 521.39	 521.39	 521.39	 1.0	 0.0	 1	 -30.0	 30.0;
	28801	 28802	 0.002795	 0.149576	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28804	 28912	 0.004053	 0.02342	 0.04318	 202.61	 202.61	 202.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28804	 28966	 0.00131	 0.005816	 0.00259	 180.47	 180.47	 180.47	 0.0	 0.0	 1	 -30.0	 30.0;
	28805	 28806	 0.000291	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28856	 28806	 0.000193	 0.000942	 0.00028	 248.13	 248.13	 248.13	 0.0	 0.0	 1	 -30.0	 30.0;
	28807	 28810	 0.000497	 0.026028	 0.0	 610.25	 610.25	 610.25	 1.0	 0.0	 1	 -30.0	 30.0;
	28807	 28811	 0.000422	 0.020904	 0.0	 353.21	 353.21	 353.21	 1.0125	 0.0	 1	 -30.0	 30.0;
	28807	 28812	 0.000354	 0.02248	 0.0	 350.43	 350.43	 350.43	 1.0125	 0.0	 1	 -30.0	 30.0;
	28807	 28813	 0.000285	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28808	 28810	 1.6e-05	 0.000861	 0.0	 485.25	 485.25	 485.25	 1.0	 0.0	 1	 -30.0	 30.0;
	28809	 28810	 0.002452	 0.128466	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28815	 28814	 0.000275	 0.0176	 0.0	 336.85	 336.85	 336.85	 1.0	 0.0	 1	 -30.0	 30.0;
	28815	 28818	 0.000166	 0.003879	 0.0	 198.69	 198.69	 198.69	 1.0	 0.0	 1	 -30.0	 30.0;
	28840	 28815	 0.017863	 0.112851	 0.13384	 212.74	 212.74	 212.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28816	 28818	 0.004423	 0.103258	 0.0	 99.34	 99.34	 99.34	 1.0	 0.0	 1	 -30.0	 30.0;
	28817	 28818	 0.004423	 0.103258	 0.0	 99.34	 99.34	 99.34	 1.0	 0.0	 1	 -30.0	 30.0;
	28819	 28820	 0.015686	 0.411749	 0.0	 34.31	 34.31	 34.31	 1.0	 0.0	 1	 -30.0	 30.0;
	28819	 28821	 0.016728	 0.489978	 0.0	 30.23	 30.23	 30.23	 1.0	 0.0	 1	 -30.0	 30.0;
	28819	 28822	 0.000245	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28948	 28823	 0.000346	 0.001831	 0.00028	 205.19	 205.19	 205.19	 0.0	 0.0	 1	 -30.0	 30.0;
	28823	 28981	 0.000826	 0.004915	 0.00339	 244.88	 244.88	 244.88	 0.0	 0.0	 1	 -30.0	 30.0;
	28824	 28825	 0.000234	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28825	 29037	 0.001744	 0.008671	 0.00362	 242.61	 242.61	 242.61	 0.0	 0.0	 1	 -30.0	 30.0;
	28827	 28826	 0.000454	 0.022451	 0.0	 335.59	 335.59	 335.59	 1.0	 0.0	 1	 -30.0	 30.0;
	28826	 28828	 0.000744	 0.034349	 0.0	 340.12	 340.12	 340.12	 1.0375	 0.0	 1	 -30.0	 30.0;
	28826	 28830	 0.000821	 0.058568	 0.0	 259.84	 259.84	 259.84	 1.0375	 0.0	 1	 -30.0	 30.0;
	28826	 28833	 0.002325	 0.023245	 0.51202	 1235.91	 1235.91	 1235.91	 0.0	 0.0	 1	 -30.0	 30.0;
	28877	 28826	 0.000464	 0.005096	 0.14484	 1176.4	 1176.4	 1176.4	 0.0	 0.0	 1	 -30.0	 30.0;
	29008	 28826	 0.000526	 0.006661	 0.14761	 1058.55	 1058.55	 1058.55	 0.0	 0.0	 1	 -30.0	 30.0;
	28827	 28829	 0.027323	 0.640997	 0.0	 21.67	 21.67	 21.67	 1.0125	 0.0	 1	 -30.0	 30.0;
	28827	 28902	 0.000209	 0.001627	 0.00027	 216.4	 216.4	 216.4	 0.0	 0.0	 1	 -30.0	 30.0;
	28832	 28831	 0.000634	 0.029761	 0.0	 500.38	 500.38	 500.38	 1.0	 0.0	 1	 -30.0	 30.0;
	28832	 29005	 0.000236	 0.001861	 0.01408	 246.52	 246.52	 246.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28834	 28833	 0.00054	 0.034111	 0.0	 381.84	 381.84	 381.84	 1.0	 0.0	 1	 -30.0	 30.0;
	28894	 28835	 0.003236	 0.019464	 0.00736	 216.09	 216.09	 216.09	 0.0	 0.0	 1	 -30.0	 30.0;
	28836	 28837	 0.006624	 0.185279	 0.0	 41.49	 41.49	 41.49	 1.0125	 0.0	 1	 -30.0	 30.0;
	28836	 28838	 0.041807	 0.895375	 0.0	 14.3	 14.3	 14.3	 1.05	 0.0	 1	 -30.0	 30.0;
	28839	 28840	 0.000252	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28840	 28869	 0.001062	 0.004651	 0.00247	 252.36	 252.36	 252.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28842	 28841	 8.1e-05	 0.006561	 0.0	 1614.73	 1614.73	 1614.73	 1.00625	 0.0	 1	 -30.0	 30.0;
	28842	 28841	 8.1e-05	 0.006561	 0.0	 1614.73	 1614.73	 1614.73	 1.00625	 0.0	 1	 -30.0	 30.0;
	28842	 28841	 8.1e-05	 0.006561	 0.0	 1614.73	 1614.73	 1614.73	 1.00625	 0.0	 1	 -30.0	 30.0;
	28841	 28844	 7e-05	 0.0056	 0.0	 1440.14	 1440.14	 1440.14	 1.0	 0.0	 1	 -30.0	 30.0;
	28841	 28845	 0.000151	 0.011444	 0.0	 1438.13	 1438.13	 1438.13	 1.0	 0.0	 1	 -30.0	 30.0;
	28841	 28846	 9.3e-05	 0.007228	 0.0	 1437.86	 1437.86	 1437.86	 1.0	 0.0	 1	 -30.0	 30.0;
	29015	 28841	 0.000151	 0.004067	 2.15945	 3852.7	 3852.7	 3852.7	 0.0	 0.0	 1	 -30.0	 30.0;
	29024	 28841	 4.9e-05	 0.001417	 0.61232	 3974.25	 3974.25	 3974.25	 0.0	 0.0	 1	 -30.0	 30.0;
	28843	 28842	 0.000479	 0.032584	 0.0	 540.95	 540.95	 540.95	 1.03125	 0.0	 1	 -30.0	 30.0;
	28842	 28978	 0.000905	 0.010584	 0.21928	 1285.06	 1285.06	 1285.06	 0.0	 0.0	 1	 -30.0	 30.0;
	28848	 28847	 7e-05	 0.005288	 0.0	 1568.87	 1568.87	 1568.87	 1.0125	 0.0	 1	 -30.0	 30.0;
	28847	 28850	 6.8e-05	 0.006353	 0.0	 1504.14	 1504.14	 1504.14	 1.0	 0.0	 1	 -30.0	 30.0;
	28847	 28851	 0.000113	 0.008305	 0.0	 1503.87	 1503.87	 1503.87	 1.0	 0.0	 1	 -30.0	 30.0;
	28847	 28852	 0.000118	 0.008852	 0.0	 1502.78	 1502.78	 1502.78	 1.0	 0.0	 1	 -30.0	 30.0;
	28847	 28853	 0.0001	 0.008101	 0.0	 1501.47	 1501.47	 1501.47	 1.0	 0.0	 1	 -30.0	 30.0;
	28847	 28854	 0.000241	 0.021687	 0.0	 875.87	 875.87	 875.87	 1.0	 0.0	 1	 -30.0	 30.0;
	28849	 28848	 0.000275	 0.015583	 0.0	 607.21	 607.21	 607.21	 1.00625	 0.0	 1	 -30.0	 30.0;
	28849	 28848	 0.000275	 0.015583	 0.0	 607.21	 607.21	 607.21	 1.00625	 0.0	 1	 -30.0	 30.0;
	28849	 28848	 0.000275	 0.015583	 0.0	 607.21	 607.21	 607.21	 1.00625	 0.0	 1	 -30.0	 30.0;
	28856	 28855	 0.000844	 0.03912	 0.0	 455.68	 455.68	 455.68	 1.01875	 0.0	 1	 -30.0	 30.0;
	28855	 28857	 0.000219	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28857	 29016	 0.00083	 0.009828	 0.14916	 1227.5	 1227.5	 1227.5	 0.0	 0.0	 1	 -30.0	 30.0;
	28858	 28950	 0.015673	 0.095222	 0.1359	 224.77	 224.77	 224.77	 0.0	 0.0	 1	 -30.0	 30.0;
	28858	 28981	 0.001981	 0.007795	 0.00484	 244.14	 244.14	 244.14	 0.0	 0.0	 1	 -30.0	 30.0;
	28859	 28925	 0.001025	 0.007154	 0.0058	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28861	 28860	 0.00052	 0.031741	 0.0	 467.61	 467.61	 467.61	 1.1	 0.0	 1	 -30.0	 30.0;
	28860	 28864	 0.0001	 -0.000598	 0.0	 757.6	 757.6	 757.6	 1.0	 0.0	 1	 -30.0	 30.0;
	28860	 28865	 0.0006	 0.035445	 0.0	 392.45	 392.45	 392.45	 1.0	 0.0	 1	 -30.0	 30.0;
	28860	 28866	 0.000499	 0.028733	 0.0	 391.96	 391.96	 391.96	 1.0	 0.0	 1	 -30.0	 30.0;
	28860	 28867	 0.000259	 0.015818	 0.0	 391.14	 391.14	 391.14	 1.0	 0.0	 1	 -30.0	 30.0;
	28860	 28868	 0.000386	 0.028354	 0.0	 391.04	 391.04	 391.04	 1.0	 0.0	 1	 -30.0	 30.0;
	28862	 28864	 0.000391	 0.023162	 0.0	 378.8	 378.8	 378.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28863	 28864	 0.000391	 0.023162	 0.0	 378.8	 378.8	 378.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28870	 28873	 0.000272	 0.006656	 0.0	 235.08	 235.08	 235.08	 1.0125	 0.0	 1	 -30.0	 30.0;
	29014	 28870	 0.00197	 0.011282	 0.00891	 240.81	 240.81	 240.81	 0.0	 0.0	 1	 -30.0	 30.0;
	28871	 28873	 0.004139	 0.101296	 0.0	 117.54	 117.54	 117.54	 1.0	 0.0	 1	 -30.0	 30.0;
	28872	 28873	 0.004139	 0.101296	 0.0	 117.54	 117.54	 117.54	 1.0	 0.0	 1	 -30.0	 30.0;
	28874	 28875	 0.00027	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28874	 28876	 0.000285	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29076	 28875	 0.000593	 0.002707	 0.00102	 163.91	 163.91	 163.91	 0.0	 0.0	 1	 -30.0	 30.0;
	28878	 28877	 0.000452	 0.026474	 0.0	 290.44	 290.44	 290.44	 1.0	 0.0	 1	 -30.0	 30.0;
	28877	 28911	 0.000902	 0.011089	 0.45225	 1068.67	 1068.67	 1068.67	 0.0	 0.0	 1	 -30.0	 30.0;
	28880	 28879	 0.000125	 0.009656	 0.0	 1401.76	 1401.76	 1401.76	 1.0	 0.0	 1	 -30.0	 30.0;
	28879	 28885	 7.5e-05	 0.006256	 0.0	 1466.18	 1466.18	 1466.18	 1.0	 0.0	 1	 -30.0	 30.0;
	28879	 28886	 7.5e-05	 0.006691	 0.0	 1464.85	 1464.85	 1464.85	 1.0	 0.0	 1	 -30.0	 30.0;
	28879	 28887	 0.000144	 0.011301	 0.0	 1463.57	 1463.57	 1463.57	 1.0	 0.0	 1	 -30.0	 30.0;
	28879	 28888	 0.000259	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28880	 28884	 0.000329	 0.019854	 0.0	 386.95	 386.95	 386.95	 1.0	 0.0	 1	 -30.0	 30.0;
	28880	 28954	 0.000773	 0.010013	 0.21518	 1080.2	 1080.2	 1080.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28880	 40726	 0.00227	 0.028237	 0.85365	 1123.71	 1123.71	 1123.71	 0.0	 0.0	 1	 -30.0	 30.0;
	28882	 28881	 0.004648	 0.147601	 0.0	 92.04	 92.04	 92.04	 1.0	 0.0	 1	 -30.0	 30.0;
	28881	 28884	 0.000153	 0.009233	 0.0	 361.95	 361.95	 361.95	 1.0	 0.0	 1	 -30.0	 30.0;
	28881	 28989	 0.029336	 0.224669	 0.11529	 202.95	 202.95	 202.95	 0.0	 0.0	 1	 -30.0	 30.0;
	28882	 40013	 0.020381	 0.115992	 0.01379	 151.01	 151.01	 151.01	 0.0	 0.0	 1	 -30.0	 30.0;
	28883	 28884	 0.002539	 0.153449	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40722	 28888	 0.000238	 0.0065	 3.47824	 3998.89	 3998.89	 3998.89	 0.0	 0.0	 1	 -30.0	 30.0;
	28888	 40909	 0.000424	 0.010974	 4.9925	 4129.38	 4129.38	 4129.38	 0.0	 0.0	 1	 -30.0	 30.0;
	28889	 28890	 0.002742	 0.072142	 0.0	 172.9	 172.9	 172.9	 1.0	 0.0	 1	 -30.0	 30.0;
	28889	 28891	 0.0002	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28892	 28893	 0.0047	 0.12492	 0.0	 74.14	 74.14	 74.14	 1.0	 0.0	 1	 -30.0	 30.0;
	28892	 28894	 0.000252	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28892	 28895	 0.000267	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28896	 28899	 0.000173	 0.005664	 0.0	 155.01	 155.01	 155.01	 1.0	 0.0	 1	 -30.0	 30.0;
	28897	 28899	 0.004828	 0.157726	 0.0	 77.51	 77.51	 77.51	 1.0	 0.0	 1	 -30.0	 30.0;
	28898	 28899	 0.004828	 0.157726	 0.0	 77.51	 77.51	 77.51	 1.0	 0.0	 1	 -30.0	 30.0;
	28900	 28901	 0.003886	 0.128195	 0.0	 86.03	 86.03	 86.03	 1.0	 0.0	 1	 -30.0	 30.0;
	28902	 28948	 0.000753	 0.004299	 0.00499	 223.83	 223.83	 223.83	 0.0	 0.0	 1	 -30.0	 30.0;
	28902	 28986	 0.000439	 0.002461	 0.00082	 214.6	 214.6	 214.6	 0.0	 0.0	 1	 -30.0	 30.0;
	28904	 28903	 0.000113	 0.008591	 0.0	 1320.73	 1320.73	 1320.73	 1.0	 0.0	 1	 -30.0	 30.0;
	28903	 28906	 9.8e-05	 0.007967	 0.0	 1605.84	 1605.84	 1605.84	 1.0375	 0.0	 1	 -30.0	 30.0;
	28903	 28919	 0.00011	 0.003044	 1.75251	 4131.86	 4131.86	 4131.86	 0.0	 0.0	 1	 -30.0	 30.0;
	29015	 28903	 0.000226	 0.006176	 3.18597	 4185.2	 4185.2	 4185.2	 0.0	 0.0	 1	 -30.0	 30.0;
	28905	 28904	 0.000446	 0.023855	 0.0	 356.16	 356.16	 356.16	 1.0	 0.0	 1	 -30.0	 30.0;
	28911	 28904	 0.000653	 0.008951	 0.24623	 1247.21	 1247.21	 1247.21	 0.0	 0.0	 1	 -30.0	 30.0;
	29016	 28904	 0.002177	 0.025102	 0.76899	 1299.33	 1299.33	 1299.33	 0.0	 0.0	 1	 -30.0	 30.0;
	28908	 28907	 0.000287	 0.019251	 0.0	 541.1	 541.1	 541.1	 1.025	 0.0	 1	 -30.0	 30.0;
	28907	 28909	 0.000241	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28907	 28910	 0.000226	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28912	 28911	 0.00058	 0.037665	 0.0	 322.38	 322.38	 322.38	 1.0	 0.0	 1	 -30.0	 30.0;
	28911	 28913	 0.000366	 0.024327	 0.0	 477.72	 477.72	 477.72	 1.0	 0.0	 1	 -30.0	 30.0;
	28920	 28911	 0.000457	 0.006081	 0.13169	 1086.72	 1086.72	 1086.72	 0.0	 0.0	 1	 -30.0	 30.0;
	28915	 28914	 0.000535	 0.031212	 0.0	 282.8	 282.8	 282.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28914	 28916	 0.000205	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40726	 28916	 5.9e-05	 0.000741	 0.015	 985.21	 985.21	 985.21	 0.0	 0.0	 1	 -30.0	 30.0;
	28917	 28918	 0.002618	 0.089651	 0.0	 77.94	 77.94	 77.94	 1.0375	 0.0	 1	 -30.0	 30.0;
	28920	 28919	 0.000122	 0.009823	 0.0	 1281.2	 1281.2	 1281.2	 1.00625	 0.0	 1	 -30.0	 30.0;
	28919	 40722	 0.000161	 0.004817	 3.00507	 4073.08	 4073.08	 4073.08	 0.0	 0.0	 1	 -30.0	 30.0;
	28920	 28923	 0.000393	 0.026604	 0.0	 436.49	 436.49	 436.49	 1.0	 0.0	 1	 -30.0	 30.0;
	28921	 28923	 -9.5e-05	 -0.006412	 0.0	 311.49	 311.49	 311.49	 1.0	 0.0	 1	 -30.0	 30.0;
	28922	 28923	 0.001418	 0.095885	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28925	 28924	 0.000699	 0.040891	 0.0	 396.47	 396.47	 396.47	 1.00625	 0.0	 1	 -30.0	 30.0;
	28924	 28926	 0.000399	 0.026804	 0.0	 414.54	 414.54	 414.54	 1.03125	 0.0	 1	 -30.0	 30.0;
	29054	 28924	 0.001464	 0.015797	 0.28754	 1189.52	 1189.52	 1189.52	 0.0	 0.0	 1	 -30.0	 30.0;
	28925	 28927	 0.004215	 0.107728	 0.0	 90.16	 90.16	 90.16	 1.05625	 0.0	 1	 -30.0	 30.0;
	28925	 29049	 0.000934	 0.005493	 0.00237	 192.74	 192.74	 192.74	 0.0	 0.0	 1	 -30.0	 30.0;
	28928	 28931	 0.000452	 0.011999	 0.0	 142.35	 142.35	 142.35	 1.04375	 0.0	 1	 -30.0	 30.0;
	28928	 28932	 0.000248	 0.001024	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28929	 28931	 0.007755	 0.20566	 0.0	 71.18	 71.18	 71.18	 1.0	 0.0	 1	 -30.0	 30.0;
	28930	 28931	 0.007755	 0.20566	 0.0	 71.18	 71.18	 71.18	 1.0	 0.0	 1	 -30.0	 30.0;
	28933	 28934	 0.003805	 0.114886	 0.0	 66.59	 66.59	 66.59	 0.9875	 0.0	 1	 -30.0	 30.0;
	28936	 28935	 0.000501	 0.03262	 0.0	 209.29	 209.29	 209.29	 1.00625	 0.0	 1	 -30.0	 30.0;
	28935	 28976	 0.000159	 0.002085	 0.07592	 1031.03	 1031.03	 1031.03	 0.0	 0.0	 1	 -30.0	 30.0;
	29023	 28936	 0.003865	 0.019634	 0.00572	 173.43	 173.43	 173.43	 0.0	 0.0	 1	 -30.0	 30.0;
	28937	 28940	 0.000439	 0.013869	 0.0	 155.99	 155.99	 155.99	 1.0	 0.0	 1	 -30.0	 30.0;
	28937	 28941	 0.023679	 0.655281	 0.0	 14.56	 14.56	 14.56	 1.0	 0.0	 1	 -30.0	 30.0;
	28937	 28942	 0.033854	 0.869121	 0.0	 14.56	 14.56	 14.56	 1.0	 0.0	 1	 -30.0	 30.0;
	28937	 28943	 0.000299	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28937	 28944	 0.000231	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28938	 28940	 0.004008	 0.126599	 0.0	 78.0	 78.0	 78.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28939	 28940	 0.004008	 0.126599	 0.0	 78.0	 78.0	 78.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29005	 28943	 0.000191	 0.00083	 0.00035	 218.16	 218.16	 218.16	 0.0	 0.0	 1	 -30.0	 30.0;
	28945	 28946	 0.005034	 0.138771	 0.0	 87.67	 87.67	 87.67	 1.0	 0.0	 1	 -30.0	 30.0;
	28945	 28947	 0.00024	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28948	 29053	 0.001508	 0.007712	 0.01664	 188.98	 188.98	 188.98	 0.0	 0.0	 1	 -30.0	 30.0;
	28950	 28949	 0.000557	 0.032469	 0.0	 366.88	 366.88	 366.88	 0.99375	 0.0	 1	 -30.0	 30.0;
	28949	 28951	 0.000353	 0.020829	 0.0	 460.36	 460.36	 460.36	 1.0375	 0.0	 1	 -30.0	 30.0;
	28949	 28952	 0.000373	 0.023093	 0.0	 458.54	 458.54	 458.54	 1.0	 0.0	 1	 -30.0	 30.0;
	28949	 28954	 0.000249	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28949	 28955	 0.000292	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28949	 28956	 0.00023	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28950	 28953	 0.009827	 0.337751	 0.0	 40.42	 40.42	 40.42	 1.0	 0.0	 1	 -30.0	 30.0;
	28954	 28988	 0.002662	 0.038344	 0.72087	 1134.85	 1134.85	 1134.85	 0.0	 0.0	 1	 -30.0	 30.0;
	28957	 28958	 0.000245	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28960	 28959	 0.000473	 0.032628	 0.0	 347.41	 347.41	 347.41	 1.0	 0.0	 1	 -30.0	 30.0;
	28959	 28961	 0.000402	 0.026823	 0.0	 303.83	 303.83	 303.83	 1.025	 0.0	 1	 -30.0	 30.0;
	28959	 28964	 0.000205	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28960	 28962	 0.014478	 0.392282	 0.0	 33.42	 33.42	 33.42	 1.03125	 0.0	 1	 -30.0	 30.0;
	28960	 28963	 0.005692	 0.13455	 0.0	 56.13	 56.13	 56.13	 1.03125	 0.0	 1	 -30.0	 30.0;
	28965	 28968	 0.000268	 0.019689	 0.0	 281.17	 281.17	 281.17	 1.0	 0.0	 1	 -30.0	 30.0;
	28965	 28971	 0.0001	 -0.004672	 0.0	 657.6	 657.6	 657.6	 1.0	 0.0	 1	 -30.0	 30.0;
	28965	 28974	 0.000703	 0.039939	 0.0	 256.13	 256.13	 256.13	 1.0	 0.0	 1	 -30.0	 30.0;
	28965	 28975	 0.00089	 0.040102	 0.0	 250.09	 250.09	 250.09	 1.0	 0.0	 1	 -30.0	 30.0;
	28965	 28976	 0.000283	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28965	 28977	 0.000215	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28966	 28968	 0.000135	 0.009939	 0.0	 256.17	 256.17	 256.17	 1.0	 0.0	 1	 -30.0	 30.0;
	28966	 28972	 0.007248	 0.211591	 0.0	 65.82	 65.82	 65.82	 1.0125	 0.0	 1	 -30.0	 30.0;
	28966	 28973	 0.007315	 0.235967	 0.0	 62.47	 62.47	 62.47	 1.0125	 0.0	 1	 -30.0	 30.0;
	28967	 28968	 0.002256	 0.165799	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	28969	 28971	 0.00093	 0.057915	 0.0	 328.8	 328.8	 328.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28970	 28971	 0.00093	 0.057915	 0.0	 328.8	 328.8	 328.8	 1.0	 0.0	 1	 -30.0	 30.0;
	28979	 28978	 0.000406	 0.020407	 0.0	 612.64	 612.64	 612.64	 1.0125	 0.0	 1	 -30.0	 30.0;
	28979	 28978	 0.000406	 0.020407	 0.0	 612.64	 612.64	 612.64	 1.0125	 0.0	 1	 -30.0	 30.0;
	28979	 28978	 0.000406	 0.020407	 0.0	 612.64	 612.64	 612.64	 1.0125	 0.0	 1	 -30.0	 30.0;
	28981	 28982	 0.004973	 0.16093	 0.0	 69.65	 69.65	 69.65	 1.0	 0.0	 1	 -30.0	 30.0;
	28983	 28984	 0.005014	 0.144756	 0.0	 86.89	 86.89	 86.89	 1.04375	 0.0	 1	 -30.0	 30.0;
	28983	 28985	 0.000282	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28986	 28987	 0.005444	 0.185901	 0.0	 98.11	 98.11	 98.11	 1.0	 0.0	 1	 -30.0	 30.0;
	28989	 28988	 0.000307	 0.019966	 0.0	 344.04	 344.04	 344.04	 1.0	 0.0	 1	 -30.0	 30.0;
	28988	 28991	 0.000349	 0.022381	 0.0	 357.43	 357.43	 357.43	 1.0	 0.0	 1	 -30.0	 30.0;
	28988	 28992	 0.000529	 0.036928	 0.0	 354.38	 354.38	 354.38	 1.0	 0.0	 1	 -30.0	 30.0;
	28988	 40039	 0.000419	 0.005027	 0.07203	 1071.54	 1071.54	 1071.54	 0.0	 0.0	 1	 -30.0	 30.0;
	28990	 28989	 0.00647	 0.206993	 0.0	 90.0	 90.0	 90.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40027	 28990	 0.024745	 0.126434	 0.02021	 138.66	 138.66	 138.66	 0.0	 0.0	 1	 -30.0	 30.0;
	28990	 40040	 0.012761	 0.047678	 0.00677	 112.36	 112.36	 112.36	 0.0	 0.0	 1	 -30.0	 30.0;
	28993	 28994	 0.003991	 0.115545	 0.0	 82.61	 82.61	 82.61	 1.0	 0.0	 1	 -30.0	 30.0;
	28993	 28995	 0.003847	 0.098161	 0.0	 81.7	 81.7	 81.7	 1.0	 0.0	 1	 -30.0	 30.0;
	28993	 28996	 0.000241	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28993	 28997	 0.000211	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28999	 28998	 0.000268	 0.016797	 0.0	 561.05	 561.05	 561.05	 1.05	 0.0	 1	 -30.0	 30.0;
	28998	 29000	 0.000802	 0.055594	 0.0	 330.41	 330.41	 330.41	 1.0	 0.0	 1	 -30.0	 30.0;
	28998	 29001	 0.000721	 0.035482	 0.0	 412.91	 412.91	 412.91	 1.0	 0.0	 1	 -30.0	 30.0;
	28998	 29002	 0.000652	 0.034766	 0.0	 329.38	 329.38	 329.38	 1.0	 0.0	 1	 -30.0	 30.0;
	28998	 29003	 0.00026	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29005	 29006	 0.007241	 0.250658	 0.0	 43.1	 43.1	 43.1	 1.0	 0.0	 1	 -30.0	 30.0;
	29005	 29007	 0.01132	 0.290211	 0.0	 42.58	 42.58	 42.58	 1.0	 0.0	 1	 -30.0	 30.0;
	29009	 29008	 0.000426	 0.024348	 0.0	 292.89	 292.89	 292.89	 1.0	 0.0	 1	 -30.0	 30.0;
	29008	 29010	 0.00042	 0.03078	 0.0	 360.71	 360.71	 360.71	 1.0	 0.0	 1	 -30.0	 30.0;
	29008	 29011	 0.000628	 0.032996	 0.0	 360.32	 360.32	 360.32	 1.0	 0.0	 1	 -30.0	 30.0;
	29012	 29013	 0.003751	 0.138156	 0.0	 82.64	 82.64	 82.64	 1.0	 0.0	 1	 -30.0	 30.0;
	29012	 29014	 0.000254	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29016	 29015	 6.8e-05	 0.005385	 0.0	 1624.34	 1624.34	 1624.34	 1.0125	 0.0	 1	 -30.0	 30.0;
	29016	 29015	 6.8e-05	 0.005385	 0.0	 1624.34	 1624.34	 1624.34	 1.0125	 0.0	 1	 -30.0	 30.0;
	29016	 29015	 6.8e-05	 0.005385	 0.0	 1624.34	 1624.34	 1624.34	 1.0125	 0.0	 1	 -30.0	 30.0;
	29015	 29018	 0.000117	 0.009223	 0.0	 1558.2	 1558.2	 1558.2	 1.0	 0.0	 1	 -30.0	 30.0;
	29015	 29019	 0.000117	 0.009172	 0.0	 1553.84	 1553.84	 1553.84	 1.0	 0.0	 1	 -30.0	 30.0;
	29015	 29020	 0.000114	 0.009521	 0.0	 1553.42	 1553.42	 1553.42	 1.0	 0.0	 1	 -30.0	 30.0;
	29017	 29016	 0.000565	 0.031918	 0.0	 535.64	 535.64	 535.64	 1.025	 0.0	 1	 -30.0	 30.0;
	29021	 29022	 0.002364	 0.072383	 0.0	 167.57	 167.57	 167.57	 1.0	 0.0	 1	 -30.0	 30.0;
	29021	 29023	 0.000264	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29025	 29024	 7.3e-05	 0.006066	 0.0	 1562.59	 1562.59	 1562.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	29024	 29027	 0.000157	 0.011804	 0.0	 1458.75	 1458.75	 1458.75	 1.0	 0.0	 1	 -30.0	 30.0;
	29024	 29028	 0.000104	 0.007569	 0.0	 1458.52	 1458.52	 1458.52	 1.0	 0.0	 1	 -30.0	 30.0;
	29024	 29029	 9.6e-05	 0.007493	 0.0	 1457.66	 1457.66	 1457.66	 1.0	 0.0	 1	 -30.0	 30.0;
	29024	 29030	 0.000127	 0.010171	 0.0	 1457.01	 1457.01	 1457.01	 1.0	 0.0	 1	 -30.0	 30.0;
	29024	 29031	 7.3e-05	 0.007447	 0.0	 1456.82	 1456.82	 1456.82	 1.0	 0.0	 1	 -30.0	 30.0;
	29026	 29025	 0.00041	 0.031674	 0.0	 539.43	 539.43	 539.43	 1.03125	 0.0	 1	 -30.0	 30.0;
	29025	 29032	 0.000483	 0.030877	 0.0	 276.86	 276.86	 276.86	 1.0	 0.0	 1	 -30.0	 30.0;
	29033	 29036	 0.000475	 0.016565	 0.0	 149.31	 149.31	 149.31	 1.0	 0.0	 1	 -30.0	 30.0;
	29033	 29037	 0.000201	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29034	 29036	 0.00529	 0.184486	 0.0	 74.65	 74.65	 74.65	 1.0	 0.0	 1	 -30.0	 30.0;
	29035	 29036	 0.00529	 0.184486	 0.0	 74.65	 74.65	 74.65	 1.0	 0.0	 1	 -30.0	 30.0;
	29038	 29049	 0.000658	 0.003857	 0.00364	 216.3	 216.3	 216.3	 0.0	 0.0	 1	 -30.0	 30.0;
	29040	 29039	 0.000146	 0.008801	 0.0	 1541.07	 1541.07	 1541.07	 1.01875	 0.0	 1	 -30.0	 30.0;
	29039	 29042	 0.000137	 0.01084	 0.0	 1523.34	 1523.34	 1523.34	 1.0	 0.0	 1	 -30.0	 30.0;
	29039	 29043	 6.3e-05	 0.005748	 0.0	 1522.14	 1522.14	 1522.14	 1.0	 0.0	 1	 -30.0	 30.0;
	29041	 29040	 0.000533	 0.038043	 0.0	 455.81	 455.81	 455.81	 1.01875	 0.0	 1	 -30.0	 30.0;
	29044	 29045	 0.00027	 0.001084	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29046	 29047	 0.007161	 0.168415	 0.0	 103.19	 103.19	 103.19	 0.98125	 0.0	 1	 -30.0	 30.0;
	29046	 29048	 0.008271	 0.2286	 0.0	 54.42	 54.42	 54.42	 1.0	 0.0	 1	 -30.0	 30.0;
	29046	 29049	 0.000261	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29050	 29051	 0.006535	 0.157843	 0.0	 93.99	 93.99	 93.99	 1.0	 0.0	 1	 -30.0	 30.0;
	29050	 29052	 0.010076	 0.309834	 0.0	 43.4	 43.4	 43.4	 1.0	 0.0	 1	 -30.0	 30.0;
	29050	 29053	 0.000208	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29055	 29054	 0.000314	 0.023453	 0.0	 400.8	 400.8	 400.8	 1.0	 0.0	 1	 -30.0	 30.0;
	29055	 29058	 -0.000408	 -0.012263	 0.0	 152.39	 152.39	 152.39	 1.03125	 0.0	 1	 -30.0	 30.0;
	29056	 29058	 0.005361	 0.16101	 0.0	 76.2	 76.2	 76.2	 1.0	 0.0	 1	 -30.0	 30.0;
	29057	 29058	 0.005361	 0.16101	 0.0	 76.2	 76.2	 76.2	 1.0	 0.0	 1	 -30.0	 30.0;
	29060	 29061	 0.000234	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29062	 29065	 0.0001	 0.0001	 0.0	 228.73	 228.73	 228.73	 1.0	 0.0	 1	 -30.0	 30.0;
	29063	 29065	 0.003105	 0.097455	 0.0	 114.36	 114.36	 114.36	 1.0	 0.0	 1	 -30.0	 30.0;
	29064	 29065	 0.003105	 0.097455	 0.0	 114.36	 114.36	 114.36	 1.0	 0.0	 1	 -30.0	 30.0;
	29066	 29069	 0.000702	 0.021999	 0.0	 87.56	 87.56	 87.56	 1.0	 0.0	 1	 -30.0	 30.0;
	29066	 29070	 0.00356	 0.102947	 0.0	 100.72	 100.72	 100.72	 1.0	 0.0	 1	 -30.0	 30.0;
	29066	 29071	 0.009131	 0.283869	 0.0	 65.41	 65.41	 65.41	 1.0	 0.0	 1	 -30.0	 30.0;
	29067	 29069	 0.006815	 0.213618	 0.0	 43.78	 43.78	 43.78	 1.0	 0.0	 1	 -30.0	 30.0;
	29068	 29069	 0.006815	 0.213618	 0.0	 43.78	 43.78	 43.78	 1.0	 0.0	 1	 -30.0	 30.0;
	29072	 29073	 0.002299	 0.069935	 0.0	 173.42	 173.42	 173.42	 1.0	 0.0	 1	 -30.0	 30.0;
	29072	 29074	 0.000204	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29074	 30118	 0.016855	 0.094509	 0.051	 218.89	 218.89	 218.89	 0.0	 0.0	 1	 -30.0	 30.0;
	29074	 30159	 0.015041	 0.111929	 0.04631	 224.35	 224.35	 224.35	 0.0	 0.0	 1	 -30.0	 30.0;
	29075	 29078	 0.00155	 0.078249	 0.0	 611.2	 611.2	 611.2	 1.0	 0.0	 1	 -30.0	 30.0;
	29075	 29079	 0.000265	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29076	 29078	 -0.000933	 -0.047093	 0.0	 511.2	 511.2	 511.2	 1.0	 0.0	 1	 -30.0	 30.0;
	29077	 29078	 0.002843	 0.143542	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	29081	 29080	 8.5e-05	 0.006929	 0.0	 1580.28	 1580.28	 1580.28	 1.06875	 0.0	 1	 -30.0	 30.0;
	29080	 29083	 0.000115	 0.009408	 0.0	 1756.48	 1756.48	 1756.48	 1.0	 0.0	 1	 -30.0	 30.0;
	29080	 29084	 8.8e-05	 0.007418	 0.0	 1752.74	 1752.74	 1752.74	 1.0	 0.0	 1	 -30.0	 30.0;
	29082	 29081	 0.000474	 0.022542	 0.0	 544.08	 544.08	 544.08	 1.03125	 0.0	 1	 -30.0	 30.0;
	30016	 30000	 0.00317	 0.020324	 0.02237	 253.92	 253.92	 253.92	 0.0	 0.0	 1	 -30.0	 30.0;
	30000	 30046	 0.000936	 0.00546	 0.00697	 276.08	 276.08	 276.08	 0.0	 0.0	 1	 -30.0	 30.0;
	30001	 30002	 0.000497	 0.00325	 0.00171	 265.03	 265.03	 265.03	 0.0	 0.0	 1	 -30.0	 30.0;
	30001	 30014	 0.008378	 0.048508	 0.03489	 187.14	 187.14	 187.14	 0.0	 0.0	 1	 -30.0	 30.0;
	30003	 30002	 0.00251	 0.086554	 0.0	 114.9	 114.9	 114.9	 1.05625	 0.0	 1	 -30.0	 30.0;
	30003	 30002	 0.00251	 0.086554	 0.0	 114.9	 114.9	 114.9	 1.05625	 0.0	 1	 -30.0	 30.0;
	30003	 30002	 0.00251	 0.086554	 0.0	 114.9	 114.9	 114.9	 1.05625	 0.0	 1	 -30.0	 30.0;
	30002	 30004	 0.000204	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30002	 30005	 0.008268	 0.052162	 0.04158	 234.53	 234.53	 234.53	 0.0	 0.0	 1	 -30.0	 30.0;
	30002	 30028	 0.004572	 0.023635	 0.01391	 250.51	 250.51	 250.51	 0.0	 0.0	 1	 -30.0	 30.0;
	30036	 30005	 0.007733	 0.044417	 0.01705	 244.75	 244.75	 244.75	 0.0	 0.0	 1	 -30.0	 30.0;
	30006	 30009	 0.006595	 0.245106	 0.0	 181.77	 181.77	 181.77	 1.0	 0.0	 1	 -30.0	 30.0;
	30006	 30010	 0.000224	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30006	 30011	 0.000223	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30007	 30009	 -0.003161	 -0.117477	 0.0	 106.77	 106.77	 106.77	 1.0	 0.0	 1	 -30.0	 30.0;
	30008	 30009	 0.015344	 0.570289	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30011	 30034	 0.002717	 0.014716	 0.01448	 235.71	 235.71	 235.71	 0.0	 0.0	 1	 -30.0	 30.0;
	30013	 30012	 0.006154	 0.198695	 0.0	 120.0	 120.0	 120.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30012	 30014	 0.00022	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30015	 30014	 0.000593	 0.003262	 0.0066	 214.91	 214.91	 214.91	 0.0	 0.0	 1	 -30.0	 30.0;
	30031	 30015	 0.004463	 0.026032	 0.01018	 249.89	 249.89	 249.89	 0.0	 0.0	 1	 -30.0	 30.0;
	30015	 30051	 0.002455	 0.014557	 0.09408	 220.6	 220.6	 220.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30017	 30016	 0.003592	 0.109681	 0.0	 82.6	 82.6	 82.6	 1.0	 0.0	 1	 -30.0	 30.0;
	30038	 30016	 0.002437	 0.013818	 0.0271	 255.78	 255.78	 255.78	 0.0	 0.0	 1	 -30.0	 30.0;
	30018	 30033	 0.002382	 0.014105	 0.02793	 249.53	 249.53	 249.53	 0.0	 0.0	 1	 -30.0	 30.0;
	30018	 30042	 0.002811	 0.015791	 0.01896	 270.04	 270.04	 270.04	 0.0	 0.0	 1	 -30.0	 30.0;
	30019	 30020	 0.000255	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30019	 30022	 0.000581	 0.00319	 0.00267	 239.29	 239.29	 239.29	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30019	 0.001565	 0.009786	 0.00912	 250.29	 250.29	 250.29	 0.0	 0.0	 1	 -30.0	 30.0;
	30019	 30062	 0.003163	 0.01818	 0.0247	 245.08	 245.08	 245.08	 0.0	 0.0	 1	 -30.0	 30.0;
	30021	 30022	 0.000266	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30021	 30023	 0.000233	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30022	 30042	 0.002077	 0.012599	 0.00852	 247.74	 247.74	 247.74	 0.0	 0.0	 1	 -30.0	 30.0;
	30024	 30025	 0.000215	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30024	 30046	 0.004073	 0.023629	 0.03522	 263.66	 263.66	 263.66	 0.0	 0.0	 1	 -30.0	 30.0;
	30049	 30024	 0.001662	 0.010287	 0.00943	 242.84	 242.84	 242.84	 0.0	 0.0	 1	 -30.0	 30.0;
	30026	 30027	 0.000221	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30026	 0.000937	 0.005757	 0.01425	 233.45	 233.45	 233.45	 0.0	 0.0	 1	 -30.0	 30.0;
	30026	 30311	 0.002105	 0.011772	 0.00914	 259.69	 259.69	 259.69	 0.0	 0.0	 1	 -30.0	 30.0;
	30028	 30039	 0.001001	 0.004867	 0.01091	 243.15	 243.15	 243.15	 0.0	 0.0	 1	 -30.0	 30.0;
	30029	 30030	 0.001482	 0.008318	 0.00809	 242.4	 242.4	 242.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30036	 30029	 0.001059	 0.007154	 0.01783	 263.3	 263.3	 263.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30029	 30059	 0.001608	 0.008421	 0.03768	 248.01	 248.01	 248.01	 0.0	 0.0	 1	 -30.0	 30.0;
	30030	 30036	 0.002076	 0.010596	 0.00441	 260.18	 260.18	 260.18	 0.0	 0.0	 1	 -30.0	 30.0;
	30046	 30031	 0.001949	 0.010723	 0.00696	 260.2	 260.2	 260.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30033	 30032	 0.001169	 0.005614	 0.00412	 259.7	 259.7	 259.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30039	 30032	 0.002401	 0.013142	 0.00934	 205.57	 205.57	 205.57	 0.0	 0.0	 1	 -30.0	 30.0;
	30040	 30033	 0.00035	 0.002028	 0.0029	 266.07	 266.07	 266.07	 0.0	 0.0	 1	 -30.0	 30.0;
	30034	 30038	 0.003359	 0.020474	 0.02284	 237.84	 237.84	 237.84	 0.0	 0.0	 1	 -30.0	 30.0;
	30034	 30066	 0.003803	 0.024638	 0.02621	 242.53	 242.53	 242.53	 0.0	 0.0	 1	 -30.0	 30.0;
	30036	 30035	 0.000441	 0.02827	 0.0	 415.09	 415.09	 415.09	 1.0	 0.0	 1	 -30.0	 30.0;
	30035	 30037	 0.000249	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30388	 30035	 0.000845	 0.009721	 0.20184	 1165.99	 1165.99	 1165.99	 0.0	 0.0	 1	 -30.0	 30.0;
	30038	 30049	 0.002546	 0.0151	 0.01417	 240.16	 240.16	 240.16	 0.0	 0.0	 1	 -30.0	 30.0;
	30039	 30389	 0.005195	 0.034616	 0.04597	 280.9	 280.9	 280.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30040	 30389	 0.00307	 0.020207	 0.05495	 304.32	 304.32	 304.32	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30041	 0.000495	 0.031042	 0.0	 461.74	 461.74	 461.74	 1.01875	 0.0	 1	 -30.0	 30.0;
	30041	 30043	 0.000295	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30048	 30041	 0.000765	 0.009436	 0.16692	 1034.67	 1034.67	 1034.67	 0.0	 0.0	 1	 -30.0	 30.0;
	30041	 30458	 0.001278	 0.017542	 0.66424	 1192.42	 1192.42	 1192.42	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30044	 0.002073	 0.012071	 0.00785	 250.59	 250.59	 250.59	 0.0	 0.0	 1	 -30.0	 30.0;
	30042	 30053	 0.001539	 0.01002	 0.00943	 219.11	 219.11	 219.11	 0.0	 0.0	 1	 -30.0	 30.0;
	30044	 30398	 0.002879	 0.015512	 0.01707	 255.32	 255.32	 255.32	 0.0	 0.0	 1	 -30.0	 30.0;
	30046	 30045	 0.000477	 0.035213	 0.0	 446.13	 446.13	 446.13	 1.0875	 0.0	 1	 -30.0	 30.0;
	30045	 30047	 0.000211	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30045	 30048	 0.00028	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30067	 30049	 0.005093	 0.029184	 0.0431	 259.01	 259.01	 259.01	 0.0	 0.0	 1	 -30.0	 30.0;
	30050	 30051	 0.000254	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30050	 30052	 0.000245	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30275	 30051	 0.002955	 0.016384	 0.02867	 278.93	 278.93	 278.93	 0.0	 0.0	 1	 -30.0	 30.0;
	30053	 30054	 0.000271	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30053	 30428	 0.00478	 0.033784	 0.03343	 254.8	 254.8	 254.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30055	 30311	 0.003004	 0.01723	 0.02144	 247.07	 247.07	 247.07	 0.0	 0.0	 1	 -30.0	 30.0;
	30055	 30459	 0.012331	 0.070223	 0.13088	 278.37	 278.37	 278.37	 0.0	 0.0	 1	 -30.0	 30.0;
	30056	 30057	 0.002192	 0.012072	 0.0139	 239.99	 239.99	 239.99	 0.0	 0.0	 1	 -30.0	 30.0;
	30056	 30059	 0.000994	 0.005796	 0.01224	 262.26	 262.26	 262.26	 0.0	 0.0	 1	 -30.0	 30.0;
	30056	 30426	 0.009941	 0.057896	 0.12427	 285.05	 285.05	 285.05	 0.0	 0.0	 1	 -30.0	 30.0;
	30056	 30436	 0.007251	 0.049911	 0.5093	 256.49	 256.49	 256.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30057	 30058	 0.000214	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30057	 30282	 0.006173	 0.035238	 0.03154	 259.87	 259.87	 259.87	 0.0	 0.0	 1	 -30.0	 30.0;
	30063	 30059	 0.001286	 0.009509	 0.00977	 243.59	 243.59	 243.59	 0.0	 0.0	 1	 -30.0	 30.0;
	30060	 30061	 0.000204	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30060	 30062	 0.000275	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30062	 30063	 0.00116	 0.006978	 0.00907	 275.91	 275.91	 275.91	 0.0	 0.0	 1	 -30.0	 30.0;
	30062	 30071	 0.009064	 0.054767	 0.0743	 279.25	 279.25	 279.25	 0.0	 0.0	 1	 -30.0	 30.0;
	30428	 30062	 0.002835	 0.016549	 0.01328	 273.27	 273.27	 273.27	 0.0	 0.0	 1	 -30.0	 30.0;
	30063	 30064	 0.000255	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30288	 30065	 0.012077	 0.070559	 0.11851	 256.38	 256.38	 256.38	 0.0	 0.0	 1	 -30.0	 30.0;
	30436	 30065	 0.007791	 0.046976	 0.0637	 250.1	 250.1	 250.1	 0.0	 0.0	 1	 -30.0	 30.0;
	30066	 30072	 0.015071	 0.083153	 0.05342	 264.18	 264.18	 264.18	 0.0	 0.0	 1	 -30.0	 30.0;
	30067	 30069	 0.003179	 0.017789	 0.04417	 289.83	 289.83	 289.83	 0.0	 0.0	 1	 -30.0	 30.0;
	30068	 30072	 0.005022	 0.027998	 0.01614	 244.9	 244.9	 244.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30068	 30459	 0.007392	 0.058509	 0.11471	 255.42	 255.42	 255.42	 0.0	 0.0	 1	 -30.0	 30.0;
	30069	 30282	 0.005273	 0.03272	 0.07888	 235.47	 235.47	 235.47	 0.0	 0.0	 1	 -30.0	 30.0;
	30069	 30334	 0.017244	 0.095732	 0.14273	 266.9	 266.9	 266.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30069	 30459	 0.009571	 0.059817	 0.03616	 278.49	 278.49	 278.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30071	 30070	 0.000259	 0.018963	 0.0	 427.97	 427.97	 427.97	 1.0	 0.0	 1	 -30.0	 30.0;
	30271	 30070	 0.004583	 0.061853	 1.14869	 1168.49	 1168.49	 1168.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30070	 30367	 0.005744	 0.06956	 1.38699	 1154.09	 1154.09	 1154.09	 0.0	 0.0	 1	 -30.0	 30.0;
	30388	 30070	 0.000755	 0.00883	 0.33948	 1179.26	 1179.26	 1179.26	 0.0	 0.0	 1	 -30.0	 30.0;
	30073	 30072	 0.016244	 0.078071	 0.0727	 241.53	 241.53	 241.53	 0.0	 0.0	 1	 -30.0	 30.0;
	30072	 30381	 0.017114	 0.12925	 0.11163	 252.36	 252.36	 252.36	 0.0	 0.0	 1	 -30.0	 30.0;
	30073	 30074	 0.000216	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30073	 30381	 0.015407	 0.100004	 0.04354	 249.9	 249.9	 249.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30076	 30075	 0.000341	 0.019415	 0.0	 393.4	 393.4	 393.4	 1.025	 0.0	 1	 -30.0	 30.0;
	30307	 30075	 0.001595	 0.020222	 0.39972	 1199.66	 1199.66	 1199.66	 0.0	 0.0	 1	 -30.0	 30.0;
	30458	 30075	 0.002429	 0.032283	 0.62766	 1144.39	 1144.39	 1144.39	 0.0	 0.0	 1	 -30.0	 30.0;
	30278	 30076	 0.014738	 0.07633	 0.04549	 206.44	 206.44	 206.44	 0.0	 0.0	 1	 -30.0	 30.0;
	30079	 30077	 0.023228	 0.141227	 0.12036	 226.72	 226.72	 226.72	 0.0	 0.0	 1	 -30.0	 30.0;
	30077	 30315	 0.026285	 0.160881	 0.14992	 262.49	 262.49	 262.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30309	 30078	 0.019275	 0.120771	 0.17913	 258.23	 258.23	 258.23	 0.0	 0.0	 1	 -30.0	 30.0;
	30078	 30360	 0.016611	 0.099706	 0.09643	 272.45	 272.45	 272.45	 0.0	 0.0	 1	 -30.0	 30.0;
	30079	 30272	 0.025265	 0.133132	 0.31969	 232.42	 232.42	 232.42	 0.0	 0.0	 1	 -30.0	 30.0;
	30315	 30080	 0.006924	 0.040639	 0.17102	 207.61	 207.61	 207.61	 0.0	 0.0	 1	 -30.0	 30.0;
	30080	 30318	 0.011437	 0.0666	 0.03238	 277.02	 277.02	 277.02	 0.0	 0.0	 1	 -30.0	 30.0;
	30360	 30080	 0.019269	 0.113545	 0.05381	 263.16	 263.16	 263.16	 0.0	 0.0	 1	 -30.0	 30.0;
	30081	 30082	 0.000275	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30082	 30087	 0.031629	 0.170472	 0.08597	 267.09	 267.09	 267.09	 0.0	 0.0	 1	 -30.0	 30.0;
	30082	 30363	 0.025922	 0.150472	 0.0857	 273.48	 273.48	 273.48	 0.0	 0.0	 1	 -30.0	 30.0;
	30084	 30083	 0.020677	 0.113294	 0.06016	 218.95	 218.95	 218.95	 0.0	 0.0	 1	 -30.0	 30.0;
	30083	 30091	 0.019448	 0.085848	 0.38627	 232.24	 232.24	 232.24	 0.0	 0.0	 1	 -30.0	 30.0;
	30099	 30084	 0.032335	 0.177406	 0.09271	 175.35	 175.35	 175.35	 0.0	 0.0	 1	 -30.0	 30.0;
	30085	 30086	 0.000241	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30085	 30087	 0.000219	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30087	 30100	 0.040964	 0.273447	 0.16727	 262.06	 262.06	 262.06	 0.0	 0.0	 1	 -30.0	 30.0;
	30088	 30089	 0.000273	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30088	 30092	 0.023096	 0.145178	 0.12988	 211.81	 211.81	 211.81	 0.0	 0.0	 1	 -30.0	 30.0;
	30088	 30097	 0.019701	 0.095785	 0.1148	 234.82	 234.82	 234.82	 0.0	 0.0	 1	 -30.0	 30.0;
	30088	 30303	 0.012509	 0.077243	 0.05788	 199.38	 199.38	 199.38	 0.0	 0.0	 1	 -30.0	 30.0;
	30091	 30090	 0.000606	 0.040163	 0.0	 389.29	 389.29	 389.29	 1.00625	 0.0	 1	 -30.0	 30.0;
	30090	 30173	 0.001647	 0.022173	 0.53612	 1088.44	 1088.44	 1088.44	 0.0	 0.0	 1	 -30.0	 30.0;
	30092	 30252	 0.029023	 0.188757	 0.1371	 199.86	 199.86	 199.86	 0.0	 0.0	 1	 -30.0	 30.0;
	30094	 30093	 0.000451	 0.0307	 0.0	 386.33	 386.33	 386.33	 1.0	 0.0	 1	 -30.0	 30.0;
	30302	 30093	 0.00276	 0.030717	 0.71915	 1285.68	 1285.68	 1285.68	 0.0	 0.0	 1	 -30.0	 30.0;
	30093	 74223	 0.005013	 0.052548	 2.01649	 1340.36	 1340.36	 1340.36	 0.0	 0.0	 1	 -30.0	 30.0;
	30095	 30094	 0.00314	 0.110459	 0.0	 108.29	 108.29	 108.29	 1.05625	 0.0	 1	 -30.0	 30.0;
	30289	 30094	 0.013996	 0.087163	 0.03224	 243.05	 243.05	 243.05	 0.0	 0.0	 1	 -30.0	 30.0;
	30303	 30094	 0.024612	 0.127653	 0.17421	 276.9	 276.9	 276.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30290	 30095	 0.01447	 0.093658	 0.02964	 227.21	 227.21	 227.21	 0.0	 0.0	 1	 -30.0	 30.0;
	30096	 30097	 0.000216	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30097	 30243	 0.0153	 0.07603	 0.21469	 268.23	 268.23	 268.23	 0.0	 0.0	 1	 -30.0	 30.0;
	30098	 30099	 0.000211	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30100	 30099	 0.022861	 0.144447	 0.21934	 257.03	 257.03	 257.03	 0.0	 0.0	 1	 -30.0	 30.0;
	30109	 30099	 0.003154	 0.018246	 0.0333	 230.88	 230.88	 230.88	 0.0	 0.0	 1	 -30.0	 30.0;
	30101	 30103	 0.001419	 0.00707	 0.00729	 280.29	 280.29	 280.29	 0.0	 0.0	 1	 -30.0	 30.0;
	30116	 30101	 0.001199	 0.006892	 0.00933	 231.63	 231.63	 231.63	 0.0	 0.0	 1	 -30.0	 30.0;
	30101	 30129	 0.001604	 0.010535	 0.01029	 234.19	 234.19	 234.19	 0.0	 0.0	 1	 -30.0	 30.0;
	30102	 30103	 0.000296	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30124	 30103	 0.000731	 0.004373	 0.00283	 305.27	 305.27	 305.27	 0.0	 0.0	 1	 -30.0	 30.0;
	30104	 30137	 0.002164	 0.015419	 0.06346	 277.99	 277.99	 277.99	 0.0	 0.0	 1	 -30.0	 30.0;
	30104	 30144	 0.00129	 0.007489	 0.0033	 224.49	 224.49	 224.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30105	 30129	 0.001925	 0.0101	 0.01278	 290.75	 290.75	 290.75	 0.0	 0.0	 1	 -30.0	 30.0;
	30105	 30153	 0.000911	 0.005154	 0.00234	 262.89	 262.89	 262.89	 0.0	 0.0	 1	 -30.0	 30.0;
	30105	 30185	 0.001669	 0.010077	 0.03507	 308.31	 308.31	 308.31	 0.0	 0.0	 1	 -30.0	 30.0;
	30106	 30147	 0.001455	 0.006813	 0.00939	 242.29	 242.29	 242.29	 0.0	 0.0	 1	 -30.0	 30.0;
	30106	 30186	 0.000408	 0.002508	 0.01384	 282.91	 282.91	 282.91	 0.0	 0.0	 1	 -30.0	 30.0;
	30107	 30188	 0.000613	 0.003387	 0.00246	 290.93	 290.93	 290.93	 0.0	 0.0	 1	 -30.0	 30.0;
	30107	 30380	 0.002765	 0.016757	 0.05078	 315.23	 315.23	 315.23	 0.0	 0.0	 1	 -30.0	 30.0;
	30108	 30110	 0.001726	 0.009485	 0.0123	 295.66	 295.66	 295.66	 0.0	 0.0	 1	 -30.0	 30.0;
	30108	 30168	 0.002202	 0.011388	 0.02559	 276.59	 276.59	 276.59	 0.0	 0.0	 1	 -30.0	 30.0;
	30169	 30108	 0.001646	 0.010066	 0.01228	 279.36	 279.36	 279.36	 0.0	 0.0	 1	 -30.0	 30.0;
	30137	 30109	 0.001943	 0.013315	 0.00678	 272.75	 272.75	 272.75	 0.0	 0.0	 1	 -30.0	 30.0;
	30110	 30111	 0.000283	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30110	 30133	 0.002328	 0.014092	 0.04808	 296.29	 296.29	 296.29	 0.0	 0.0	 1	 -30.0	 30.0;
	30170	 30110	 0.001365	 0.008816	 0.00549	 265.32	 265.32	 265.32	 0.0	 0.0	 1	 -30.0	 30.0;
	30113	 30112	 0.000527	 0.025587	 0.0	 471.72	 471.72	 471.72	 1.03125	 0.0	 1	 -30.0	 30.0;
	30112	 30114	 0.000273	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30112	 30115	 0.000201	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30138	 30113	 0.000987	 0.006025	 0.00196	 252.81	 252.81	 252.81	 0.0	 0.0	 1	 -30.0	 30.0;
	30113	 30140	 0.001794	 0.011665	 0.00893	 288.95	 288.95	 288.95	 0.0	 0.0	 1	 -30.0	 30.0;
	30173	 30114	 0.000427	 0.004989	 0.06657	 1027.62	 1027.62	 1027.62	 0.0	 0.0	 1	 -30.0	 30.0;
	30114	 30433	 0.00037	 0.00444	 0.17128	 1161.11	 1161.11	 1161.11	 0.0	 0.0	 1	 -30.0	 30.0;
	30133	 30116	 0.000877	 0.005149	 0.00846	 258.15	 258.15	 258.15	 0.0	 0.0	 1	 -30.0	 30.0;
	30140	 30116	 0.002464	 0.016776	 0.01368	 250.16	 250.16	 250.16	 0.0	 0.0	 1	 -30.0	 30.0;
	30118	 30117	 0.002862	 0.099751	 0.0	 108.45	 108.45	 108.45	 1.0125	 0.0	 1	 -30.0	 30.0;
	30117	 30119	 0.000224	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30117	 30158	 0.001656	 0.0111	 0.00985	 247.27	 247.27	 247.27	 0.0	 0.0	 1	 -30.0	 30.0;
	30117	 30434	 0.007599	 0.041094	 0.08184	 264.77	 264.77	 264.77	 0.0	 0.0	 1	 -30.0	 30.0;
	30120	 30121	 0.000261	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30120	 30122	 0.000252	 0.00109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30124	 30122	 0.001609	 0.008821	 0.011	 267.39	 267.39	 267.39	 0.0	 0.0	 1	 -30.0	 30.0;
	30122	 30136	 0.000808	 0.004771	 0.00337	 234.55	 234.55	 234.55	 0.0	 0.0	 1	 -30.0	 30.0;
	30124	 30123	 0.000416	 0.025345	 0.0	 517.18	 517.18	 517.18	 1.0	 0.0	 1	 -30.0	 30.0;
	30123	 30125	 0.00023	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30125	 30416	 0.001096	 0.010976	 0.21027	 1119.94	 1119.94	 1119.94	 0.0	 0.0	 1	 -30.0	 30.0;
	30126	 30127	 0.000791	 0.004027	 0.03376	 291.86	 291.86	 291.86	 0.0	 0.0	 1	 -30.0	 30.0;
	30174	 30126	 0.001332	 0.007524	 0.00407	 220.75	 220.75	 220.75	 0.0	 0.0	 1	 -30.0	 30.0;
	30197	 30127	 0.000666	 0.003146	 0.00221	 326.17	 326.17	 326.17	 0.0	 0.0	 1	 -30.0	 30.0;
	30128	 30129	 0.000257	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30130	 30131	 0.000237	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30136	 30130	 0.001125	 0.006695	 0.00537	 276.24	 276.24	 276.24	 0.0	 0.0	 1	 -30.0	 30.0;
	30130	 30160	 0.002691	 0.015534	 0.03896	 265.33	 265.33	 265.33	 0.0	 0.0	 1	 -30.0	 30.0;
	30130	 30197	 0.001949	 0.012358	 0.01151	 290.15	 290.15	 290.15	 0.0	 0.0	 1	 -30.0	 30.0;
	30132	 30174	 0.000332	 0.001897	 0.00258	 239.76	 239.76	 239.76	 0.0	 0.0	 1	 -30.0	 30.0;
	30132	 30189	 0.003665	 0.019538	 0.03239	 280.01	 280.01	 280.01	 0.0	 0.0	 1	 -30.0	 30.0;
	30134	 30135	 0.000289	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30134	 30136	 0.000208	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30137	 30172	 0.001772	 0.010334	 0.05353	 332.26	 332.26	 332.26	 0.0	 0.0	 1	 -30.0	 30.0;
	30138	 30155	 0.001561	 0.007598	 0.00591	 251.78	 251.78	 251.78	 0.0	 0.0	 1	 -30.0	 30.0;
	30139	 30200	 0.001739	 0.009716	 0.06323	 245.0	 245.0	 245.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30430	 30139	 0.000623	 0.004289	 0.01923	 284.46	 284.46	 284.46	 0.0	 0.0	 1	 -30.0	 30.0;
	30140	 30141	 0.00022	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30142	 30143	 0.000291	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30142	 30145	 0.001332	 0.008263	 0.00573	 251.91	 251.91	 251.91	 0.0	 0.0	 1	 -30.0	 30.0;
	30430	 30142	 0.002062	 0.012442	 0.01122	 298.66	 298.66	 298.66	 0.0	 0.0	 1	 -30.0	 30.0;
	30144	 30174	 0.000844	 0.00513	 0.01792	 298.05	 298.05	 298.05	 0.0	 0.0	 1	 -30.0	 30.0;
	30145	 30146	 0.00026	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30145	 30152	 0.001749	 0.01087	 0.00633	 275.93	 275.93	 275.93	 0.0	 0.0	 1	 -30.0	 30.0;
	30188	 30145	 0.000554	 0.003176	 0.0156	 242.33	 242.33	 242.33	 0.0	 0.0	 1	 -30.0	 30.0;
	30147	 30158	 0.003068	 0.015829	 0.01292	 260.26	 260.26	 260.26	 0.0	 0.0	 1	 -30.0	 30.0;
	30148	 30149	 0.000273	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30148	 30164	 0.000911	 0.003603	 0.00239	 247.45	 247.45	 247.45	 0.0	 0.0	 1	 -30.0	 30.0;
	30148	 30213	 0.001747	 0.009432	 0.0044	 264.03	 264.03	 264.03	 0.0	 0.0	 1	 -30.0	 30.0;
	30150	 30151	 0.000267	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30150	 30152	 0.0002	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30178	 30152	 0.0005	 0.002721	 0.02238	 310.6	 310.6	 310.6	 0.0	 0.0	 1	 -30.0	 30.0;
	30156	 30153	 0.000867	 0.005458	 0.00303	 294.08	 294.08	 294.08	 0.0	 0.0	 1	 -30.0	 30.0;
	30154	 30160	 0.001508	 0.008361	 0.00622	 257.63	 257.63	 257.63	 0.0	 0.0	 1	 -30.0	 30.0;
	30154	 30209	 0.000795	 0.004907	 0.01448	 293.15	 293.15	 293.15	 0.0	 0.0	 1	 -30.0	 30.0;
	30154	 30286	 0.011058	 0.058825	 0.14868	 218.47	 218.47	 218.47	 0.0	 0.0	 1	 -30.0	 30.0;
	30155	 30172	 0.003728	 0.022583	 0.02609	 291.32	 291.32	 291.32	 0.0	 0.0	 1	 -30.0	 30.0;
	30156	 30157	 0.000281	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30197	 30156	 0.000208	 0.001406	 0.00264	 316.35	 316.35	 316.35	 0.0	 0.0	 1	 -30.0	 30.0;
	30159	 30158	 0.003118	 0.114643	 0.0	 104.73	 104.73	 104.73	 1.0	 0.0	 1	 -30.0	 30.0;
	30161	 30159	 0.003132	 0.017609	 0.01036	 219.0	 219.0	 219.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30159	 30327	 0.015318	 0.076242	 0.03888	 199.21	 199.21	 199.21	 0.0	 0.0	 1	 -30.0	 30.0;
	30160	 30163	 0.007679	 0.219094	 0.0	 173.27	 173.27	 173.27	 1.0	 0.0	 1	 -30.0	 30.0;
	30161	 30163	 -0.003211	 -0.091624	 0.0	 98.27	 98.27	 98.27	 1.0	 0.0	 1	 -30.0	 30.0;
	30180	 30161	 0.00093	 0.006034	 0.00711	 203.38	 203.38	 203.38	 0.0	 0.0	 1	 -30.0	 30.0;
	30162	 30163	 0.023896	 0.681808	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30164	 30165	 0.000239	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30164	 30166	 0.001586	 0.011661	 0.01716	 290.25	 290.25	 290.25	 0.0	 0.0	 1	 -30.0	 30.0;
	30185	 30166	 0.000977	 0.005883	 0.00443	 263.85	 263.85	 263.85	 0.0	 0.0	 1	 -30.0	 30.0;
	30166	 30232	 0.001156	 0.007544	 0.04333	 306.53	 306.53	 306.53	 0.0	 0.0	 1	 -30.0	 30.0;
	30166	 30401	 0.001092	 0.006713	 0.02179	 283.73	 283.73	 283.73	 0.0	 0.0	 1	 -30.0	 30.0;
	30215	 30167	 0.001722	 0.010277	 0.0047	 265.53	 265.53	 265.53	 0.0	 0.0	 1	 -30.0	 30.0;
	30167	 30450	 0.007013	 0.036063	 0.09312	 295.91	 295.91	 295.91	 0.0	 0.0	 1	 -30.0	 30.0;
	30172	 30168	 0.000476	 0.00286	 0.00496	 310.14	 310.14	 310.14	 0.0	 0.0	 1	 -30.0	 30.0;
	30170	 30169	 0.001726	 0.010412	 0.00829	 306.4	 306.4	 306.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30169	 30172	 0.000521	 0.00336	 0.00304	 309.13	 309.13	 309.13	 0.0	 0.0	 1	 -30.0	 30.0;
	30169	 30427	 0.002764	 0.018128	 0.06051	 464.69	 464.69	 464.69	 0.0	 0.0	 1	 -30.0	 30.0;
	30172	 30171	 0.000243	 0.016551	 0.0	 599.02	 599.02	 599.02	 1.025	 0.0	 1	 -30.0	 30.0;
	30172	 30171	 0.000243	 0.016551	 0.0	 599.02	 599.02	 599.02	 1.025	 0.0	 1	 -30.0	 30.0;
	30172	 30171	 0.000243	 0.016551	 0.0	 599.02	 599.02	 599.02	 1.025	 0.0	 1	 -30.0	 30.0;
	30171	 30378	 0.000841	 0.009339	 0.14897	 1244.21	 1244.21	 1244.21	 0.0	 0.0	 1	 -30.0	 30.0;
	30444	 30171	 0.000595	 0.007143	 0.16387	 1269.95	 1269.95	 1269.95	 0.0	 0.0	 1	 -30.0	 30.0;
	30174	 30173	 0.000618	 0.032789	 0.0	 460.36	 460.36	 460.36	 1.1	 0.0	 1	 -30.0	 30.0;
	30173	 30416	 0.000674	 0.008093	 0.14533	 1225.7	 1225.7	 1225.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30177	 30175	 0.000707	 0.003981	 0.00671	 284.48	 284.48	 284.48	 0.0	 0.0	 1	 -30.0	 30.0;
	30175	 30186	 0.000376	 0.002051	 0.00575	 268.71	 268.71	 268.71	 0.0	 0.0	 1	 -30.0	 30.0;
	30176	 30177	 0.000209	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30177	 30197	 0.000317	 0.001904	 0.00165	 308.4	 308.4	 308.4	 0.0	 0.0	 1	 -30.0	 30.0;
	30191	 30178	 0.001145	 0.006876	 0.00979	 317.3	 317.3	 317.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30178	 30430	 0.001324	 0.006321	 0.00415	 286.94	 286.94	 286.94	 0.0	 0.0	 1	 -30.0	 30.0;
	30180	 30179	 0.00405	 0.108994	 0.0	 94.75	 94.75	 94.75	 1.0	 0.0	 1	 -30.0	 30.0;
	30179	 30209	 0.001147	 0.006801	 0.0045	 220.88	 220.88	 220.88	 0.0	 0.0	 1	 -30.0	 30.0;
	30181	 30206	 0.00254	 0.012052	 0.01928	 237.41	 237.41	 237.41	 0.0	 0.0	 1	 -30.0	 30.0;
	30181	 30215	 0.000937	 0.005144	 0.00592	 232.55	 232.55	 232.55	 0.0	 0.0	 1	 -30.0	 30.0;
	30181	 30339	 0.005384	 0.030366	 0.04962	 267.11	 267.11	 267.11	 0.0	 0.0	 1	 -30.0	 30.0;
	30182	 30183	 0.000297	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30183	 30203	 0.001185	 0.007286	 0.0092	 243.49	 243.49	 243.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30183	 30237	 0.001764	 0.011694	 0.01805	 246.38	 246.38	 246.38	 0.0	 0.0	 1	 -30.0	 30.0;
	30183	 30277	 0.003351	 0.022584	 0.0433	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30203	 30184	 0.000595	 0.003382	 0.00241	 249.67	 249.67	 249.67	 0.0	 0.0	 1	 -30.0	 30.0;
	30238	 30184	 0.002142	 0.011834	 0.00626	 272.72	 272.72	 272.72	 0.0	 0.0	 1	 -30.0	 30.0;
	30185	 30380	 0.001893	 0.010498	 0.0216	 314.31	 314.31	 314.31	 0.0	 0.0	 1	 -30.0	 30.0;
	30186	 30187	 0.000282	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30186	 30230	 0.001762	 0.008822	 0.01175	 297.72	 297.72	 297.72	 0.0	 0.0	 1	 -30.0	 30.0;
	30226	 30189	 0.000502	 0.003375	 0.00329	 200.41	 200.41	 200.41	 0.0	 0.0	 1	 -30.0	 30.0;
	30189	 30425	 0.002955	 0.018422	 0.04588	 318.97	 318.97	 318.97	 0.0	 0.0	 1	 -30.0	 30.0;
	30190	 30236	 0.002178	 0.011466	 0.01785	 254.87	 254.87	 254.87	 0.0	 0.0	 1	 -30.0	 30.0;
	30190	 30380	 0.002716	 0.01701	 0.00742	 263.82	 263.82	 263.82	 0.0	 0.0	 1	 -30.0	 30.0;
	30191	 30296	 0.003128	 0.020012	 0.10652	 391.54	 391.54	 391.54	 0.0	 0.0	 1	 -30.0	 30.0;
	30234	 30192	 0.000403	 0.002444	 0.00283	 257.2	 257.2	 257.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30192	 30380	 0.001247	 0.007573	 0.00914	 304.86	 304.86	 304.86	 0.0	 0.0	 1	 -30.0	 30.0;
	30193	 30194	 0.000202	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30193	 30195	 0.00022	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30195	 30216	 0.001028	 0.00583	 0.00666	 244.49	 244.49	 244.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30195	 30222	 0.001683	 0.010605	 0.01111	 255.83	 255.83	 255.83	 0.0	 0.0	 1	 -30.0	 30.0;
	30197	 30196	 0.000352	 0.022677	 0.0	 593.49	 593.49	 593.49	 1.0	 0.0	 1	 -30.0	 30.0;
	30197	 30196	 0.000352	 0.022677	 0.0	 593.49	 593.49	 593.49	 1.0	 0.0	 1	 -30.0	 30.0;
	30197	 30196	 0.000352	 0.022677	 0.0	 593.49	 593.49	 593.49	 1.0	 0.0	 1	 -30.0	 30.0;
	30379	 30196	 0.00041	 0.00466	 0.15802	 1169.72	 1169.72	 1169.72	 0.0	 0.0	 1	 -30.0	 30.0;
	30196	 30416	 0.000528	 0.006558	 0.1088	 1324.12	 1324.12	 1324.12	 0.0	 0.0	 1	 -30.0	 30.0;
	30198	 30199	 0.000215	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 30199	 0.002627	 0.016388	 0.00747	 277.27	 277.27	 277.27	 0.0	 0.0	 1	 -30.0	 30.0;
	30199	 30221	 0.001706	 0.009711	 0.00487	 301.99	 301.99	 301.99	 0.0	 0.0	 1	 -30.0	 30.0;
	30199	 30333	 0.001196	 0.007781	 0.06371	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30202	 30200	 0.001888	 0.011105	 0.01156	 243.2	 243.2	 243.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30201	 30202	 0.000226	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30202	 30224	 0.001502	 0.008526	 0.01091	 278.13	 278.13	 278.13	 0.0	 0.0	 1	 -30.0	 30.0;
	30203	 30244	 0.002078	 0.011983	 0.05491	 288.19	 288.19	 288.19	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 30205	 0.00025	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30204	 30232	 0.001617	 0.01042	 0.01345	 254.84	 254.84	 254.84	 0.0	 0.0	 1	 -30.0	 30.0;
	30206	 30207	 0.000257	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30216	 30206	 0.000456	 0.002901	 0.00291	 243.09	 243.09	 243.09	 0.0	 0.0	 1	 -30.0	 30.0;
	30206	 30401	 0.000965	 0.004592	 0.01249	 295.51	 295.51	 295.51	 0.0	 0.0	 1	 -30.0	 30.0;
	30209	 30208	 0.000435	 0.028153	 0.0	 455.17	 455.17	 455.17	 1.04375	 0.0	 1	 -30.0	 30.0;
	30324	 30208	 0.000421	 0.005358	 0.14006	 1161.72	 1161.72	 1161.72	 0.0	 0.0	 1	 -30.0	 30.0;
	30208	 30355	 0.000553	 0.006933	 0.1531	 950.25	 950.25	 950.25	 0.0	 0.0	 1	 -30.0	 30.0;
	30209	 30215	 0.001541	 0.009991	 0.00677	 234.82	 234.82	 234.82	 0.0	 0.0	 1	 -30.0	 30.0;
	30210	 30211	 0.000203	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30210	 30352	 0.003744	 0.024837	 0.01754	 256.99	 256.99	 256.99	 0.0	 0.0	 1	 -30.0	 30.0;
	30210	 30368	 0.002912	 0.018811	 0.03082	 253.54	 253.54	 253.54	 0.0	 0.0	 1	 -30.0	 30.0;
	30212	 30213	 0.000217	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30213	 30234	 0.001351	 0.00874	 0.0121	 302.34	 302.34	 302.34	 0.0	 0.0	 1	 -30.0	 30.0;
	30219	 30214	 0.000921	 0.00509	 0.00378	 280.74	 280.74	 280.74	 0.0	 0.0	 1	 -30.0	 30.0;
	30214	 30236	 0.000242	 0.001438	 0.00558	 242.62	 242.62	 242.62	 0.0	 0.0	 1	 -30.0	 30.0;
	30216	 30217	 0.000293	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30216	 30223	 0.001325	 0.009661	 0.05778	 247.34	 247.34	 247.34	 0.0	 0.0	 1	 -30.0	 30.0;
	30216	 30323	 0.00103	 0.006572	 0.00488	 291.17	 291.17	 291.17	 0.0	 0.0	 1	 -30.0	 30.0;
	30219	 30218	 0.000416	 0.025783	 0.0	 431.35	 431.35	 431.35	 1.05	 0.0	 1	 -30.0	 30.0;
	30218	 30220	 0.00026	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30324	 30218	 0.000413	 0.004693	 0.12768	 1210.87	 1210.87	 1210.87	 0.0	 0.0	 1	 -30.0	 30.0;
	30219	 30232	 0.001403	 0.006848	 0.00728	 270.54	 270.54	 270.54	 0.0	 0.0	 1	 -30.0	 30.0;
	30224	 30221	 0.000666	 0.003592	 0.00872	 303.95	 303.95	 303.95	 0.0	 0.0	 1	 -30.0	 30.0;
	30221	 30425	 0.003312	 0.020157	 0.03179	 306.58	 306.58	 306.58	 0.0	 0.0	 1	 -30.0	 30.0;
	30323	 30222	 0.000707	 0.004004	 0.00252	 288.46	 288.46	 288.46	 0.0	 0.0	 1	 -30.0	 30.0;
	30223	 30352	 0.003069	 0.01776	 0.01573	 280.41	 280.41	 280.41	 0.0	 0.0	 1	 -30.0	 30.0;
	30224	 30225	 0.000285	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30226	 30224	 0.000319	 0.001897	 0.00179	 295.38	 295.38	 295.38	 0.0	 0.0	 1	 -30.0	 30.0;
	30224	 30242	 0.007734	 0.036072	 0.13768	 311.68	 311.68	 311.68	 0.0	 0.0	 1	 -30.0	 30.0;
	30227	 30228	 0.000281	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30227	 30229	 0.000261	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30231	 30229	 0.002137	 0.013059	 0.01497	 263.63	 263.63	 263.63	 0.0	 0.0	 1	 -30.0	 30.0;
	30229	 30232	 0.001081	 0.006952	 0.01769	 244.49	 244.49	 244.49	 0.0	 0.0	 1	 -30.0	 30.0;
	30229	 30256	 0.00602	 0.040725	 0.09021	 313.3	 313.3	 313.3	 0.0	 0.0	 1	 -30.0	 30.0;
	30230	 30380	 0.0013	 0.008994	 0.02804	 327.68	 327.68	 327.68	 0.0	 0.0	 1	 -30.0	 30.0;
	30231	 30239	 0.000417	 0.003034	 0.00184	 215.7	 215.7	 215.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30232	 30348	 0.002078	 0.011708	 0.03102	 307.7	 307.7	 307.7	 0.0	 0.0	 1	 -30.0	 30.0;
	30244	 30233	 0.00149	 0.009911	 0.00709	 247.08	 247.08	 247.08	 0.0	 0.0	 1	 -30.0	 30.0;
	30233	 30450	 0.006961	 0.043859	 0.01565	 280.08	 280.08	 280.08	 0.0	 0.0	 1	 -30.0	 30.0;
	30401	 30234	 0.000309	 0.001991	 0.00083	 304.34	 304.34	 304.34	 0.0	 0.0	 1	 -30.0	 30.0;
	30235	 30236	 0.000261	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30236	 30380	 0.000806	 0.005189	 0.00668	 286.34	 286.34	 286.34	 0.0	 0.0	 1	 -30.0	 30.0;
	30352	 30237	 0.003878	 0.022782	 0.01214	 282.67	 282.67	 282.67	 0.0	 0.0	 1	 -30.0	 30.0;
	30238	 30240	 0.001668	 0.009827	 0.01039	 243.66	 243.66	 243.66	 0.0	 0.0	 1	 -30.0	 30.0;
	30238	 30323	 0.001146	 0.007489	 0.00485	 290.65	 290.65	 290.65	 0.0	 0.0	 1	 -30.0	 30.0;
	30323	 30239	 0.000744	 0.00483	 0.00463	 277.72	 277.72	 277.72	 0.0	 0.0	 1	 -30.0	 30.0;
	30241	 30240	 0.00614	 0.159197	 0.0	 106.73	 106.73	 106.73	 1.0	 0.0	 1	 -30.0	 30.0;
	30241	 30245	 0.005267	 0.024014	 0.01607	 186.93	 186.93	 186.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40021	 30241	 0.039427	 0.14101	 0.06815	 138.12	 138.12	 138.12	 0.0	 0.0	 1	 -30.0	 30.0;
	30242	 30267	 0.019151	 0.098081	 0.11387	 312.91	 312.91	 312.91	 0.0	 0.0	 1	 -30.0	 30.0;
	30248	 30243	 0.031199	 0.150282	 0.13652	 271.78	 271.78	 271.78	 0.0	 0.0	 1	 -30.0	 30.0;
	30243	 30265	 0.044561	 0.233161	 0.13295	 219.46	 219.46	 219.46	 0.0	 0.0	 1	 -30.0	 30.0;
	30244	 30247	 0.00653	 0.183636	 0.0	 243.59	 243.59	 243.59	 1.0	 0.0	 1	 -30.0	 30.0;
	30245	 30247	 -0.001582	 -0.044484	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40981	 30245	 0.015587	 0.05621	 0.01038	 201.46	 201.46	 201.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40981	 30245	 0.015587	 0.05621	 0.01038	 201.46	 201.46	 201.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40981	 30245	 0.015587	 0.05621	 0.01038	 201.46	 201.46	 201.46	 0.0	 0.0	 1	 -30.0	 30.0;
	30246	 30247	 0.026478	 0.744608	 0.0	 133.75	 133.75	 133.75	 1.0	 0.0	 1	 -30.0	 30.0;
	30248	 30251	 0.012993	 0.291316	 0.0	 239.52	 239.52	 239.52	 1.0	 0.0	 1	 -30.0	 30.0;
	30249	 30251	 -0.006783	 -0.152073	 0.0	 114.52	 114.52	 114.52	 1.0	 0.0	 1	 -30.0	 30.0;
	30249	 74261	 0.038597	 0.229165	 0.13224	 223.88	 223.88	 223.88	 0.0	 0.0	 1	 -30.0	 30.0;
	30249	 74307	 0.077076	 0.485086	 0.11312	 212.88	 212.88	 212.88	 0.0	 0.0	 1	 -30.0	 30.0;
	30249	 74336	 0.061019	 0.310622	 0.07229	 171.73	 171.73	 171.73	 0.0	 0.0	 1	 -30.0	 30.0;
	30250	 30251	 0.031318	 0.702154	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30383	 30252	 0.019127	 0.127075	 0.05971	 250.79	 250.79	 250.79	 0.0	 0.0	 1	 -30.0	 30.0;
	30254	 30253	 0.005386	 0.163664	 0.0	 102.77	 102.77	 102.77	 1.1	 0.0	 1	 -30.0	 30.0;
	30253	 30255	 0.000297	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30286	 30253	 0.011169	 0.071112	 0.06433	 229.93	 229.93	 229.93	 0.0	 0.0	 1	 -30.0	 30.0;
	30254	 40009	 0.006329	 0.031208	 0.01019	 134.4	 134.4	 134.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 30254	 0.003038	 0.014831	 0.03013	 124.25	 124.25	 124.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40731	 30254	 0.004492	 0.020711	 0.00373	 128.96	 128.96	 128.96	 0.0	 0.0	 1	 -30.0	 30.0;
	30256	 30259	 0.01783	 0.113973	 0.27312	 320.46	 320.46	 320.46	 0.0	 0.0	 1	 -30.0	 30.0;
	30257	 30258	 0.000253	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30257	 30259	 0.000298	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30257	 30260	 0.000202	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30263	 30259	 0.015382	 0.075549	 0.08636	 305.68	 305.68	 305.68	 0.0	 0.0	 1	 -30.0	 30.0;
	50001	 30259	 0.018098	 0.100853	 0.13832	 265.19	 265.19	 265.19	 0.0	 0.0	 1	 -30.0	 30.0;
	30261	 30263	 0.019714	 0.116416	 0.08458	 265.8	 265.8	 265.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30261	 50422	 0.037295	 0.255195	 0.23277	 275.07	 275.07	 275.07	 0.0	 0.0	 1	 -30.0	 30.0;
	30262	 30333	 0.004204	 0.02116	 0.22002	 304.04	 304.04	 304.04	 0.0	 0.0	 1	 -30.0	 30.0;
	30346	 30262	 0.004051	 0.023764	 0.03097	 309.9	 309.9	 309.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50000	 30263	 0.009422	 0.055994	 0.06475	 279.47	 279.47	 279.47	 0.0	 0.0	 1	 -30.0	 30.0;
	30264	 30265	 0.000247	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30264	 30266	 0.000283	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30264	 50006	 0.009	 0.049	 0.048	 277.0	 277.0	 277.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50002	 30267	 0.008133	 0.054783	 0.0904	 323.15	 323.15	 323.15	 0.0	 0.0	 1	 -30.0	 30.0;
	30267	 50014	 0.030317	 0.184719	 0.1327	 275.01	 275.01	 275.01	 0.0	 0.0	 1	 -30.0	 30.0;
	30268	 30269	 0.003806	 0.090566	 0.0	 132.77	 132.77	 132.77	 1.00625	 0.0	 1	 -30.0	 30.0;
	30268	 30270	 0.000252	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30270	 30311	 0.000292	 0.001773	 0.00123	 251.81	 251.81	 251.81	 0.0	 0.0	 1	 -30.0	 30.0;
	30270	 30428	 0.005086	 0.028821	 0.06004	 243.87	 243.87	 243.87	 0.0	 0.0	 1	 -30.0	 30.0;
	30270	 30445	 0.000483	 0.003048	 0.00104	 221.74	 221.74	 221.74	 0.0	 0.0	 1	 -30.0	 30.0;
	30272	 30271	 0.000342	 0.022418	 0.0	 264.77	 264.77	 264.77	 1.0	 0.0	 1	 -30.0	 30.0;
	30314	 30271	 0.002853	 0.03697	 0.51708	 1160.89	 1160.89	 1160.89	 0.0	 0.0	 1	 -30.0	 30.0;
	30273	 30274	 0.006748	 0.208225	 0.0	 71.44	 71.44	 71.44	 1.025	 0.0	 1	 -30.0	 30.0;
	30273	 30275	 0.000289	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30273	 30276	 0.000243	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30398	 30275	 0.000178	 0.001303	 0.00123	 273.26	 273.26	 273.26	 0.0	 0.0	 1	 -30.0	 30.0;
	30277	 30339	 0.000132	 0.000919	 0.00042	 280.23	 280.23	 280.23	 0.0	 0.0	 1	 -30.0	 30.0;
	30278	 30279	 0.006385	 0.2312	 0.0	 60.48	 60.48	 60.48	 1.0	 0.0	 1	 -30.0	 30.0;
	30278	 30280	 0.015253	 0.509316	 0.0	 24.08	 24.08	 24.08	 1.0	 0.0	 1	 -30.0	 30.0;
	30278	 30308	 0.013526	 0.076996	 0.27521	 267.82	 267.82	 267.82	 0.0	 0.0	 1	 -30.0	 30.0;
	30278	 30381	 0.012767	 0.081183	 0.09089	 276.9	 276.9	 276.9	 0.0	 0.0	 1	 -30.0	 30.0;
	30281	 30282	 0.000297	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30281	 30283	 0.000204	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30428	 30282	 0.000223	 0.00155	 0.00207	 237.43	 237.43	 237.43	 0.0	 0.0	 1	 -30.0	 30.0;
	30285	 30284	 0.003024	 0.113376	 0.0	 85.79	 85.79	 85.79	 1.0	 0.0	 1	 -30.0	 30.0;
	30284	 30286	 0.000207	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30287	 30288	 0.000245	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30288	 30309	 0.002691	 0.01403	 0.0097	 275.25	 275.25	 275.25	 0.0	 0.0	 1	 -30.0	 30.0;
	30288	 30426	 0.005515	 0.02744	 0.04746	 265.92	 265.92	 265.92	 0.0	 0.0	 1	 -30.0	 30.0;
	30290	 30289	 0.004047	 0.133198	 0.0	 70.41	 70.41	 70.41	 1.0	 0.0	 1	 -30.0	 30.0;
	30289	 30291	 0.003968	 0.119673	 0.0	 95.66	 95.66	 95.66	 1.00625	 0.0	 1	 -30.0	 30.0;
	30290	 74104	 0.034212	 0.192591	 0.04478	 226.8	 226.8	 226.8	 0.0	 0.0	 1	 -30.0	 30.0;
	30293	 30292	 0.004297	 0.149969	 0.0	 109.39	 109.39	 109.39	 1.0125	 0.0	 1	 -30.0	 30.0;
	30292	 30294	 0.000201	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40981	 30293	 0.019657	 0.077704	 0.02034	 135.82	 135.82	 135.82	 0.0	 0.0	 1	 -30.0	 30.0;
	30294	 30348	 0.000438	 0.002659	 0.00152	 260.11	 260.11	 260.11	 0.0	 0.0	 1	 -30.0	 30.0;
	30296	 30295	 0.000364	 0.020203	 0.0	 452.45	 452.45	 452.45	 1.0	 0.0	 1	 -30.0	 30.0;
	30295	 30297	 0.00018	 0.011182	 0.0	 516.33	 516.33	 516.33	 1.0	 0.0	 1	 -30.0	 30.0;
	30295	 30298	 0.000321	 0.017896	 0.0	 516.12	 516.12	 516.12	 1.025	 0.0	 1	 -30.0	 30.0;
	30295	 30299	 0.000535	 0.028439	 0.0	 515.8	 515.8	 515.8	 1.03125	 0.0	 1	 -30.0	 30.0;
	30295	 30300	 0.000546	 0.033821	 0.0	 410.17	 410.17	 410.17	 1.025	 0.0	 1	 -30.0	 30.0;
	30295	 30301	 0.000678	 0.033768	 0.0	 409.89	 409.89	 409.89	 1.025	 0.0	 1	 -30.0	 30.0;
	30444	 30295	 0.000218	 0.002754	 0.05078	 1038.57	 1038.57	 1038.57	 0.0	 0.0	 1	 -30.0	 30.0;
	30302	 30305	 0.001109	 0.066015	 0.0	 327.48	 327.48	 327.48	 1.0	 0.0	 1	 -30.0	 30.0;
	30302	 30306	 0.000303	 0.020173	 0.0	 570.57	 570.57	 570.57	 1.0	 0.0	 1	 -30.0	 30.0;
	30302	 30307	 0.00385	 0.045511	 0.87823	 1197.35	 1197.35	 1197.35	 0.0	 0.0	 1	 -30.0	 30.0;
	30314	 30302	 0.001972	 0.025083	 0.37741	 1175.0	 1175.0	 1175.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30303	 30305	 -0.000661	 -0.039357	 0.0	 277.48	 277.48	 277.48	 1.0	 0.0	 1	 -30.0	 30.0;
	30318	 30303	 0.0064	 0.033076	 0.03976	 270.59	 270.59	 270.59	 0.0	 0.0	 1	 -30.0	 30.0;
	30304	 30305	 0.002314	 0.137754	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30308	 30307	 0.000798	 0.040359	 0.0	 370.0	 370.0	 370.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30309	 30334	 0.007729	 0.055499	 0.07594	 212.55	 212.55	 212.55	 0.0	 0.0	 1	 -30.0	 30.0;
	30310	 30311	 0.000226	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30310	 30312	 0.000212	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30311	 30398	 0.000611	 0.003503	 0.00642	 281.55	 281.55	 281.55	 0.0	 0.0	 1	 -30.0	 30.0;
	30311	 30445	 0.000184	 0.001228	 0.00265	 249.95	 249.95	 249.95	 0.0	 0.0	 1	 -30.0	 30.0;
	30314	 30313	 0.000118	 0.009824	 0.0	 1080.78	 1080.78	 1080.78	 1.0	 0.0	 1	 -30.0	 30.0;
	30313	 30316	 0.000109	 0.00899	 0.0	 1641.37	 1641.37	 1641.37	 1.05	 0.0	 1	 -30.0	 30.0;
	30313	 30317	 4.2e-05	 0.003168	 0.0	 1640.35	 1640.35	 1640.35	 1.04375	 0.0	 1	 -30.0	 30.0;
	30387	 30313	 0.000986	 0.025739	 13.59557	 4016.08	 4016.08	 4016.08	 0.0	 0.0	 1	 -30.0	 30.0;
	30315	 30314	 0.000527	 0.030754	 0.0	 346.96	 346.96	 346.96	 1.0	 0.0	 1	 -30.0	 30.0;
	30318	 30321	 -0.00038	 -0.010669	 0.0	 289.78	 289.78	 289.78	 1.0125	 0.0	 1	 -30.0	 30.0;
	30319	 30321	 0.004317	 0.121335	 0.0	 144.89	 144.89	 144.89	 1.0	 0.0	 1	 -30.0	 30.0;
	30320	 30321	 0.004317	 0.121335	 0.0	 144.89	 144.89	 144.89	 1.0	 0.0	 1	 -30.0	 30.0;
	30323	 30322	 0.000426	 0.022224	 0.0	 487.5	 487.5	 487.5	 1.01875	 0.0	 1	 -30.0	 30.0;
	30322	 30324	 0.000287	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30322	 30325	 0.00026	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30416	 30324	 0.000211	 0.002446	 0.06605	 1251.16	 1251.16	 1251.16	 0.0	 0.0	 1	 -30.0	 30.0;
	30324	 30457	 0.00066	 0.007484	 0.20557	 1269.04	 1269.04	 1269.04	 0.0	 0.0	 1	 -30.0	 30.0;
	30326	 30329	 0.005824	 0.168241	 0.0	 145.49	 145.49	 145.49	 1.0	 0.0	 1	 -30.0	 30.0;
	30326	 30330	 0.00022	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30326	 30331	 0.000203	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30327	 30329	 -0.002051	 -0.059265	 0.0	 95.49	 95.49	 95.49	 1.0	 0.0	 1	 -30.0	 30.0;
	30328	 30329	 0.019463	 0.562271	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30339	 30330	 0.000345	 0.002267	 0.00161	 243.99	 243.99	 243.99	 0.0	 0.0	 1	 -30.0	 30.0;
	30332	 30333	 0.00026	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30333	 30371	 0.001755	 0.010403	 0.00574	 296.14	 296.14	 296.14	 0.0	 0.0	 1	 -30.0	 30.0;
	30334	 30335	 0.002283	 0.075489	 0.0	 138.38	 138.38	 138.38	 1.00625	 0.0	 1	 -30.0	 30.0;
	30334	 30336	 0.003419	 0.116721	 0.0	 91.06	 91.06	 91.06	 1.00625	 0.0	 1	 -30.0	 30.0;
	30334	 30337	 0.020884	 0.803441	 0.0	 15.34	 15.34	 15.34	 1.00625	 0.0	 1	 -30.0	 30.0;
	30338	 30341	 -9.2e-05	 -0.004951	 0.0	 529.32	 529.32	 529.32	 1.0	 0.0	 1	 -30.0	 30.0;
	30338	 30342	 0.000474	 0.032899	 0.0	 514.4	 514.4	 514.4	 0.9875	 0.0	 1	 -30.0	 30.0;
	30338	 30343	 0.000263	 0.015021	 0.0	 514.32	 514.32	 514.32	 0.9875	 0.0	 1	 -30.0	 30.0;
	30338	 30344	 0.000283	 0.014577	 0.0	 513.31	 513.31	 513.31	 0.9875	 0.0	 1	 -30.0	 30.0;
	30338	 30355	 0.000414	 0.005428	 0.07144	 1098.84	 1098.84	 1098.84	 0.0	 0.0	 1	 -30.0	 30.0;
	30339	 30341	 0.00062	 0.033224	 0.0	 429.32	 429.32	 429.32	 1.0	 0.0	 1	 -30.0	 30.0;
	30368	 30339	 0.000743	 0.004929	 0.00282	 254.14	 254.14	 254.14	 0.0	 0.0	 1	 -30.0	 30.0;
	30339	 30434	 0.001035	 0.005355	 0.00526	 221.58	 221.58	 221.58	 0.0	 0.0	 1	 -30.0	 30.0;
	30340	 30341	 0.002592	 0.138864	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30346	 30345	 0.000627	 0.038806	 0.0	 388.92	 388.92	 388.92	 1.0	 0.0	 1	 -30.0	 30.0;
	30345	 30347	 0.00044	 0.024238	 0.0	 588.4	 588.4	 588.4	 1.0	 0.0	 1	 -30.0	 30.0;
	30345	 30424	 0.000723	 0.009243	 0.41192	 1202.56	 1202.56	 1202.56	 0.0	 0.0	 1	 -30.0	 30.0;
	30348	 30349	 0.002441	 0.082691	 0.0	 190.68	 190.68	 190.68	 1.0	 0.0	 1	 -30.0	 30.0;
	30348	 30350	 0.002102	 0.070343	 0.0	 170.68	 170.68	 170.68	 1.0	 0.0	 1	 -30.0	 30.0;
	30351	 30354	 0.000832	 0.055307	 0.0	 538.9	 538.9	 538.9	 1.0	 0.0	 1	 -30.0	 30.0;
	30351	 30355	 0.000238	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30352	 30354	 -0.000439	 -0.02917	 0.0	 413.9	 413.9	 413.9	 1.0	 0.0	 1	 -30.0	 30.0;
	30434	 30352	 0.001814	 0.010818	 0.02595	 234.73	 234.73	 234.73	 0.0	 0.0	 1	 -30.0	 30.0;
	30353	 30354	 0.002095	 0.139247	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30356	 30359	 0.0001	 0.000401	 0.0	 330.14	 330.14	 330.14	 1.0	 0.0	 1	 -30.0	 30.0;
	30356	 30360	 0.000219	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30356	 30361	 0.000231	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30357	 30359	 0.001255	 0.044777	 0.0	 165.07	 165.07	 165.07	 1.0	 0.0	 1	 -30.0	 30.0;
	30358	 30359	 0.001255	 0.044777	 0.0	 165.07	 165.07	 165.07	 1.0	 0.0	 1	 -30.0	 30.0;
	30363	 30362	 0.000663	 0.030499	 0.0	 374.16	 374.16	 374.16	 1.0	 0.0	 1	 -30.0	 30.0;
	30362	 30366	 0.0001	 0.002732	 0.0	 787.67	 787.67	 787.67	 0.9875	 0.0	 1	 -30.0	 30.0;
	30362	 30367	 0.000214	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30362	 30367	 0.000214	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30364	 30366	 0.000469	 0.029324	 0.0	 393.84	 393.84	 393.84	 1.0	 0.0	 1	 -30.0	 30.0;
	30365	 30366	 0.000469	 0.029324	 0.0	 393.84	 393.84	 393.84	 1.0	 0.0	 1	 -30.0	 30.0;
	30367	 30382	 0.007167	 0.088441	 1.53091	 1177.37	 1177.37	 1177.37	 0.0	 0.0	 1	 -30.0	 30.0;
	30370	 30369	 0.000105	 0.00803	 0.0	 1514.04	 1514.04	 1514.04	 1.0	 0.0	 1	 -30.0	 30.0;
	30369	 30372	 8.1e-05	 0.007265	 0.0	 1601.71	 1601.71	 1601.71	 1.0	 0.0	 1	 -30.0	 30.0;
	30369	 30373	 0.000151	 0.009484	 0.0	 1598.29	 1598.29	 1598.29	 1.0	 0.0	 1	 -30.0	 30.0;
	30369	 30374	 7.8e-05	 0.005705	 0.0	 1595.71	 1595.71	 1595.71	 1.0	 0.0	 1	 -30.0	 30.0;
	30369	 30375	 0.000111	 0.007779	 0.0	 1592.69	 1592.69	 1592.69	 1.0	 0.0	 1	 -30.0	 30.0;
	30369	 30376	 2.3e-05	 0.001936	 0.0	 1591.17	 1591.17	 1591.17	 1.0	 0.0	 1	 -30.0	 30.0;
	30369	 30377	 6.5e-05	 0.005341	 0.0	 1587.51	 1587.51	 1587.51	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30369	 9.2e-05	 0.002536	 1.44205	 3937.64	 3937.64	 3937.64	 0.0	 0.0	 1	 -30.0	 30.0;
	30371	 30370	 0.000784	 0.040698	 0.0	 401.26	 401.26	 401.26	 1.0	 0.0	 1	 -30.0	 30.0;
	30370	 30378	 0.000283	 0.001016	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30378	 30424	 0.000187	 0.002074	 0.03354	 1176.79	 1176.79	 1176.79	 0.0	 0.0	 1	 -30.0	 30.0;
	30380	 30379	 0.000219	 0.015008	 0.0	 602.06	 602.06	 602.06	 1.01875	 0.0	 1	 -30.0	 30.0;
	30380	 30379	 0.000219	 0.015008	 0.0	 602.06	 602.06	 602.06	 1.01875	 0.0	 1	 -30.0	 30.0;
	30380	 30379	 0.000219	 0.015008	 0.0	 602.06	 602.06	 602.06	 1.01875	 0.0	 1	 -30.0	 30.0;
	30379	 30416	 0.000293	 0.003374	 0.03267	 1375.66	 1375.66	 1375.66	 0.0	 0.0	 1	 -30.0	 30.0;
	30379	 30457	 0.000951	 0.011095	 0.21074	 1254.05	 1254.05	 1254.05	 0.0	 0.0	 1	 -30.0	 30.0;
	30382	 30385	 0.001135	 0.061359	 0.0	 393.97	 393.97	 393.97	 1.0	 0.0	 1	 -30.0	 30.0;
	30382	 30386	 0.000588	 0.037111	 0.0	 484.58	 484.58	 484.58	 1.0	 0.0	 1	 -30.0	 30.0;
	30382	 50410	 0.005166	 0.058896	 0.94177	 1059.25	 1059.25	 1059.25	 0.0	 0.0	 1	 -30.0	 30.0;
	30383	 30385	 -0.000478	 -0.025817	 0.0	 318.97	 318.97	 318.97	 1.0	 0.0	 1	 -30.0	 30.0;
	50422	 30383	 0.049325	 0.301011	 0.21986	 221.89	 221.89	 221.89	 0.0	 0.0	 1	 -30.0	 30.0;
	30384	 30385	 0.003726	 0.201426	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30388	 30387	 0.000153	 0.010725	 0.0	 1348.7	 1348.7	 1348.7	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30390	 0.000126	 0.008857	 0.0	 1354.74	 1354.74	 1354.74	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30391	 9.6e-05	 0.007048	 0.0	 1353.79	 1353.79	 1353.79	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30392	 0.000131	 0.009598	 0.0	 1352.62	 1352.62	 1352.62	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30393	 5.4e-05	 0.004383	 0.0	 1351.51	 1351.51	 1351.51	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30394	 0.000125	 0.009471	 0.0	 1350.55	 1350.55	 1350.55	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30395	 0.000102	 0.008322	 0.0	 1269.57	 1269.57	 1269.57	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30396	 0.000146	 0.011892	 0.0	 1141.11	 1141.11	 1141.11	 1.0	 0.0	 1	 -30.0	 30.0;
	30387	 30397	 9.3e-05	 0.008196	 0.0	 1127.17	 1127.17	 1127.17	 1.0	 0.0	 1	 -30.0	 30.0;
	30389	 30388	 0.000492	 0.024947	 0.0	 441.79	 441.79	 441.79	 1.0	 0.0	 1	 -30.0	 30.0;
	30428	 30389	 0.000843	 0.004454	 0.00123	 252.41	 252.41	 252.41	 0.0	 0.0	 1	 -30.0	 30.0;
	30400	 30399	 9.8e-05	 0.006285	 0.0	 1652.28	 1652.28	 1652.28	 1.0125	 0.0	 1	 -30.0	 30.0;
	30400	 30399	 9.8e-05	 0.006285	 0.0	 1652.28	 1652.28	 1652.28	 1.0125	 0.0	 1	 -30.0	 30.0;
	30400	 30399	 9.8e-05	 0.006285	 0.0	 1652.28	 1652.28	 1652.28	 1.0125	 0.0	 1	 -30.0	 30.0;
	30399	 30404	 0.000102	 0.008108	 0.0	 1306.07	 1306.07	 1306.07	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30405	 0.000143	 0.012255	 0.0	 1305.21	 1305.21	 1305.21	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30406	 3.4e-05	 0.00265	 0.0	 1302.02	 1302.02	 1302.02	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30407	 0.000125	 0.010927	 0.0	 1301.73	 1301.73	 1301.73	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30408	 8e-05	 0.007103	 0.0	 1300.98	 1300.98	 1300.98	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30409	 0.000101	 0.007539	 0.0	 1298.79	 1298.79	 1298.79	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30410	 3.4e-05	 0.002545	 0.0	 1178.77	 1178.77	 1178.77	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30411	 0.000125	 0.012409	 0.0	 1167.98	 1167.98	 1167.98	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30412	 0.000134	 0.010864	 0.0	 1164.05	 1164.05	 1164.05	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30413	 0.000128	 0.009458	 0.0	 1161.93	 1161.93	 1161.93	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30414	 0.000115	 0.009561	 0.0	 1161.04	 1161.04	 1161.04	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 30415	 0.000193	 0.015313	 0.0	 1156.9	 1156.9	 1156.9	 1.0	 0.0	 1	 -30.0	 30.0;
	30399	 40783	 0.000895	 0.023936	 9.76203	 4235.96	 4235.96	 4235.96	 0.0	 0.0	 1	 -30.0	 30.0;
	30400	 30403	 0.001591	 0.080969	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30400	 30416	 0.000245	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30401	 30403	 -0.001049	 -0.053382	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30402	 30403	 0.002901	 0.147657	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30417	 30420	 0.000562	 0.033677	 0.0	 590.15	 590.15	 590.15	 1.0	 0.0	 1	 -30.0	 30.0;
	30417	 30421	 0.000485	 0.026716	 0.0	 535.02	 535.02	 535.02	 1.0	 0.0	 1	 -30.0	 30.0;
	30417	 30422	 0.000511	 0.027791	 0.0	 534.8	 534.8	 534.8	 1.06875	 0.0	 1	 -30.0	 30.0;
	30417	 30423	 0.000295	 0.019823	 0.0	 532.91	 532.91	 532.91	 1.0625	 0.0	 1	 -30.0	 30.0;
	30417	 30424	 0.000293	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30418	 30420	 -0.000247	 -0.014789	 0.0	 465.15	 465.15	 465.15	 1.0	 0.0	 1	 -30.0	 30.0;
	30418	 30425	 0.000439	 0.002513	 0.00837	 385.2	 385.2	 385.2	 0.0	 0.0	 1	 -30.0	 30.0;
	30438	 30418	 0.000426	 0.00255	 0.002	 258.46	 258.46	 258.46	 0.0	 0.0	 1	 -30.0	 30.0;
	30419	 30420	 0.001604	 0.096048	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30433	 30424	 0.000671	 0.00803	 0.15516	 1210.24	 1210.24	 1210.24	 0.0	 0.0	 1	 -30.0	 30.0;
	30424	 30444	 6.7e-05	 0.000726	 0.00621	 1114.68	 1114.68	 1114.68	 0.0	 0.0	 1	 -30.0	 30.0;
	30425	 30427	 0.000345	 0.001907	 0.00097	 248.02	 248.02	 248.02	 0.0	 0.0	 1	 -30.0	 30.0;
	30427	 30438	 0.000843	 0.004522	 0.00731	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30429	 30432	 0.000584	 0.034248	 0.0	 646.25	 646.25	 646.25	 1.0	 0.0	 1	 -30.0	 30.0;
	30429	 30433	 0.000225	 0.001199	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30430	 30432	 -0.00026	 -0.015271	 0.0	 521.25	 521.25	 521.25	 1.0	 0.0	 1	 -30.0	 30.0;
	30431	 30432	 0.001607	 0.094308	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30435	 30436	 0.000257	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30437	 30440	 0.000493	 0.024326	 0.0	 608.7	 608.7	 608.7	 1.0	 0.0	 1	 -30.0	 30.0;
	30437	 30441	 0.000402	 0.022896	 0.0	 525.45	 525.45	 525.45	 1.0375	 0.0	 1	 -30.0	 30.0;
	30437	 30442	 0.000522	 0.037645	 0.0	 525.0	 525.0	 525.0	 1.05	 0.0	 1	 -30.0	 30.0;
	30437	 30443	 0.000279	 0.017058	 0.0	 523.79	 523.79	 523.79	 1.03125	 0.0	 1	 -30.0	 30.0;
	30437	 30444	 0.000203	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30438	 30440	 -8.4e-05	 -0.004127	 0.0	 458.7	 458.7	 458.7	 1.0	 0.0	 1	 -30.0	 30.0;
	30439	 30440	 0.00214	 0.105569	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	30445	 30448	 0.000279	 0.005887	 0.0	 283.04	 283.04	 283.04	 0.99375	 0.0	 1	 -30.0	 30.0;
	30446	 30448	 0.00387	 0.081778	 0.0	 141.52	 141.52	 141.52	 1.0	 0.0	 1	 -30.0	 30.0;
	30447	 30448	 0.00387	 0.081778	 0.0	 141.52	 141.52	 141.52	 1.0	 0.0	 1	 -30.0	 30.0;
	30450	 30449	 0.000492	 0.030133	 0.0	 451.13	 451.13	 451.13	 1.0	 0.0	 1	 -30.0	 30.0;
	30449	 30451	 0.000461	 0.027344	 0.0	 511.9	 511.9	 511.9	 1.0	 0.0	 1	 -30.0	 30.0;
	30449	 30452	 0.000455	 0.027211	 0.0	 511.4	 511.4	 511.4	 0.99375	 0.0	 1	 -30.0	 30.0;
	30449	 30453	 0.000321	 0.019817	 0.0	 511.02	 511.02	 511.02	 0.99375	 0.0	 1	 -30.0	 30.0;
	30449	 30454	 0.000442	 0.026759	 0.0	 510.01	 510.01	 510.01	 0.99375	 0.0	 1	 -30.0	 30.0;
	30449	 30455	 0.000373	 0.023718	 0.0	 509.74	 509.74	 509.74	 0.99375	 0.0	 1	 -30.0	 30.0;
	30449	 30456	 0.000617	 0.03546	 0.0	 508.11	 508.11	 508.11	 0.99375	 0.0	 1	 -30.0	 30.0;
	30449	 30457	 0.000262	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30449	 30457	 0.000262	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30459	 30458	 0.000423	 0.021148	 0.0	 453.65	 453.65	 453.65	 1.04375	 0.0	 1	 -30.0	 30.0;
	30458	 30460	 0.000223	 0.014942	 0.0	 450.18	 450.18	 450.18	 1.05	 0.0	 1	 -30.0	 30.0;
	30458	 30461	 0.000601	 0.033383	 0.0	 449.56	 449.56	 449.56	 1.05625	 0.0	 1	 -30.0	 30.0;
	40000	 40951	 0.017717	 0.072944	 0.04499	 158.83	 158.83	 158.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40002	 40001	 0.004408	 0.022479	 0.00309	 115.41	 115.41	 115.41	 0.0	 0.0	 1	 -30.0	 30.0;
	40001	 40861	 0.008505	 0.042408	 0.02236	 161.83	 161.83	 161.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40002	 40016	 0.010153	 0.047793	 0.03641	 148.54	 148.54	 148.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40002	 40861	 0.012691	 0.051073	 0.01136	 157.11	 157.11	 157.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 40003	 0.005867	 0.024431	 0.00949	 167.84	 167.84	 167.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40003	 40013	 0.013718	 0.078763	 0.37112	 151.03	 151.03	 151.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40003	 40861	 0.010751	 0.032845	 0.00476	 151.1	 151.1	 151.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40004	 40005	 0.000266	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 40725	 0.002902	 0.013434	 0.00383	 202.63	 202.63	 202.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 40725	 0.002902	 0.013434	 0.00383	 202.63	 202.63	 202.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40005	 40725	 0.002902	 0.013434	 0.00383	 202.63	 202.63	 202.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40861	 40005	 0.002178	 0.008863	 0.00117	 151.87	 151.87	 151.87	 0.0	 0.0	 1	 -30.0	 30.0;
	40006	 40007	 0.000254	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40012	 40006	 0.009198	 0.039238	 0.00812	 159.72	 159.72	 159.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40006	 40026	 0.0177	 0.077957	 0.0522	 121.13	 121.13	 121.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40008	 40012	 0.004584	 0.022629	 0.02362	 171.25	 171.25	 171.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40008	 40731	 0.006099	 0.026942	 0.02352	 190.76	 190.76	 190.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40009	 40753	 0.017244	 0.060858	 0.03221	 171.29	 171.29	 171.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40010	 40011	 0.000221	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40010	 40012	 0.000212	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40013	 40029	 0.023518	 0.102275	 0.02546	 126.06	 126.06	 126.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40014	 40015	 0.000294	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40731	 40014	 0.0021	 0.010269	 0.0148	 139.89	 139.89	 139.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40016	 40017	 0.000229	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40016	 40028	 0.020387	 0.114025	 0.02617	 153.37	 153.37	 153.37	 0.0	 0.0	 1	 -30.0	 30.0;
	40016	 40725	 0.005883	 0.034456	 0.03095	 167.43	 167.43	 167.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40951	 40016	 0.01063	 0.042369	 0.00989	 127.35	 127.35	 127.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40018	 40019	 0.000279	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40019	 40022	 0.017025	 0.063779	 0.01847	 163.62	 163.62	 163.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40019	 40832	 0.016387	 0.088028	 0.02848	 169.18	 169.18	 169.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40020	 40021	 0.000277	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 40021	 0.046479	 0.168383	 0.02019	 131.39	 131.39	 131.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40022	 40026	 0.004948	 0.022763	 0.0102	 97.89	 97.89	 97.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 40024	 0.000265	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40023	 40731	 0.012728	 0.051382	 0.02332	 150.74	 150.74	 150.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40025	 40026	 0.000285	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40040	 40026	 0.013998	 0.068394	 0.0291	 167.79	 167.79	 167.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40027	 40040	 0.042501	 0.190997	 0.02799	 133.27	 133.27	 133.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40028	 40034	 0.025675	 0.117272	 0.02923	 163.89	 163.89	 163.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40029	 40030	 0.000239	 0.001059	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40029	 40044	 0.025885	 0.129402	 0.02565	 142.6	 142.6	 142.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40031	 40032	 0.000219	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40031	 40034	 0.003912	 0.019863	 0.00458	 174.62	 174.62	 174.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40031	 40699	 0.040353	 0.171291	 0.04551	 163.01	 163.01	 163.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40031	 40951	 0.037002	 0.16706	 0.03804	 162.9	 162.9	 162.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40033	 40036	 0.000379	 0.025896	 0.0	 993.03	 993.03	 993.03	 1.0	 0.0	 1	 -30.0	 30.0;
	40033	 40037	 0.000276	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40034	 40036	 -0.000151	 -0.010353	 0.0	 752.25	 752.25	 752.25	 1.0	 0.0	 1	 -30.0	 30.0;
	40035	 40036	 0.001416	 0.096869	 0.0	 240.79	 240.79	 240.79	 1.0	 0.0	 1	 -30.0	 30.0;
	40037	 40698	 0.000563	 0.008917	 0.68622	 2681.57	 2681.57	 2681.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40037	 40723	 0.000455	 0.009854	 1.28051	 2409.64	 2409.64	 2409.64	 0.0	 0.0	 1	 -30.0	 30.0;
	40039	 40038	 0.000226	 0.016307	 0.0	 659.91	 659.91	 659.91	 1.0	 0.0	 1	 -30.0	 30.0;
	40752	 40038	 0.000632	 0.011085	 0.92185	 2202.32	 2202.32	 2202.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40040	 40039	 0.000454	 0.035618	 0.0	 434.18	 434.18	 434.18	 1.0	 0.0	 1	 -30.0	 30.0;
	40039	 41007	 0.002038	 0.022801	 0.59582	 1112.55	 1112.55	 1112.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40041	 40043	 0.026754	 0.15784	 0.07177	 150.12	 150.12	 150.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40041	 40049	 0.046576	 0.195321	 0.05596	 153.52	 153.52	 153.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 40043	 0.005302	 0.022754	 0.00359	 163.01	 163.01	 163.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40042	 40046	 0.0278	 0.0101	 0.0186	 170.0	 170.0	 170.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40047	 40042	 0.028057	 0.161719	 0.03035	 127.32	 127.32	 127.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40043	 41017	 0.02781	 0.101215	 0.01863	 170.21	 170.21	 170.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40045	 40044	 0.030903	 0.159725	 0.0414	 146.75	 146.75	 146.75	 0.0	 0.0	 1	 -30.0	 30.0;
	40051	 40045	 0.02371	 0.111277	 0.0481	 135.82	 135.82	 135.82	 0.0	 0.0	 1	 -30.0	 30.0;
	41004	 40045	 0.027684	 0.158581	 0.04404	 163.96	 163.96	 163.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40832	 40046	 0.021256	 0.127795	 0.03952	 149.83	 149.83	 149.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40046	 41008	 0.020075	 0.092916	 0.04582	 163.52	 163.52	 163.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40047	 40055	 0.051985	 0.169386	 0.06323	 111.14	 111.14	 111.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40048	 40049	 0.000243	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40049	 40061	 0.064457	 0.270963	 0.05932	 162.07	 162.07	 162.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40050	 40051	 0.00022	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40051	 40058	 0.033403	 0.152688	 0.0137	 132.02	 132.02	 132.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40052	 40053	 0.000207	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40068	 40052	 0.027642	 0.110826	 0.03129	 136.56	 136.56	 136.56	 0.0	 0.0	 1	 -30.0	 30.0;
	40749	 40052	 0.018089	 0.083202	 0.01634	 129.49	 129.49	 129.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40054	 40064	 0.040651	 0.116696	 0.02779	 165.46	 165.46	 165.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40054	 40999	 0.006569	 0.03369	 0.0219	 177.12	 177.12	 177.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40055	 40057	 0.045611	 0.180333	 0.07506	 121.85	 121.85	 121.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40061	 40056	 0.021233	 0.097573	 0.02519	 166.55	 166.55	 166.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40056	 50022	 0.006455	 0.035803	 0.01821	 175.79	 175.79	 175.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40057	 40078	 0.02408	 0.121094	 0.03402	 167.77	 167.77	 167.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40749	 40057	 0.027121	 0.143148	 0.01964	 127.39	 127.39	 127.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40059	 40058	 0.018396	 0.089598	 0.01083	 116.74	 116.74	 116.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40059	 40060	 0.000226	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40059	 40068	 0.026615	 0.123192	 0.0389	 146.88	 146.88	 146.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40062	 40063	 0.000254	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40063	 40117	 0.027185	 0.145661	 0.05904	 183.73	 183.73	 183.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40063	 40883	 0.00452	 0.023141	 0.01084	 188.5	 188.5	 188.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40106	 40064	 0.011317	 0.053488	 0.03358	 195.32	 195.32	 195.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40106	 40064	 0.011317	 0.053488	 0.03358	 195.32	 195.32	 195.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40064	 40996	 0.006865	 0.027436	 0.0048	 191.57	 191.57	 191.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40065	 40066	 0.000228	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40286	 40065	 0.045023	 0.240316	 0.03936	 159.81	 159.81	 159.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40958	 40065	 0.057023	 0.133418	 0.14244	 164.37	 164.37	 164.37	 0.0	 0.0	 1	 -30.0	 30.0;
	40078	 40067	 0.02244	 0.094698	 0.02249	 174.13	 174.13	 174.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40067	 40716	 0.020681	 0.096716	 0.02001	 177.06	 177.06	 177.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40068	 40133	 0.012843	 0.052448	 0.19365	 162.01	 162.01	 162.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40069	 40070	 0.000274	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40069	 40071	 0.000254	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40069	 40072	 0.000224	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 40071	 0.009948	 0.057582	 0.01193	 125.12	 125.12	 125.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40071	 40111	 0.016364	 0.056119	 0.0192	 143.55	 143.55	 143.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40073	 40096	 0.024918	 0.085236	 0.01236	 144.27	 144.27	 144.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40073	 40720	 0.011892	 0.056031	 0.02237	 189.12	 189.12	 189.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 40074	 0.000166	 0.013131	 0.0	 915.65	 915.65	 915.65	 1.04375	 0.0	 1	 -30.0	 30.0;
	40074	 40076	 0.000208	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40152	 40074	 0.000246	 0.004502	 0.38249	 2663.43	 2663.43	 2663.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40074	 40273	 0.00042	 0.006512	 0.6713	 2570.74	 2570.74	 2570.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40074	 40298	 0.000349	 0.006109	 0.73908	 2741.69	 2741.69	 2741.69	 0.0	 0.0	 1	 -30.0	 30.0;
	40841	 40074	 0.000216	 0.00405	 0.57356	 2924.68	 2924.68	 2924.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40074	 40965	 0.000346	 0.00528	 0.67146	 2806.35	 2806.35	 2806.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40967	 40074	 0.000248	 0.004835	 0.56267	 2758.86	 2758.86	 2758.86	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 40257	 0.010778	 0.036177	 0.07537	 216.15	 216.15	 216.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 40257	 0.010778	 0.036177	 0.07537	 216.15	 216.15	 216.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40075	 40257	 0.010778	 0.036177	 0.07537	 216.15	 216.15	 216.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40077	 40078	 0.000248	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40079	 40080	 0.000246	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40080	 0.003101	 0.015747	 0.00417	 175.38	 175.38	 175.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40080	 40092	 0.00535	 0.027373	 0.01298	 112.06	 112.06	 112.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 40080	 0.00342	 0.01651	 0.01425	 161.21	 161.21	 161.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 40082	 0.000203	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 40094	 0.002744	 0.012641	 0.00542	 174.32	 174.32	 174.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40081	 40179	 0.007739	 0.025764	 0.08937	 155.51	 155.51	 155.51	 0.0	 0.0	 1	 -30.0	 30.0;
	40089	 40083	 0.017544	 0.084662	 0.01143	 172.17	 172.17	 172.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40083	 40228	 0.014357	 0.064316	 0.01771	 132.64	 132.64	 132.64	 0.0	 0.0	 1	 -30.0	 30.0;
	40084	 40085	 0.000213	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40084	 40086	 0.000212	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40084	 40087	 0.000217	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40108	 0.002785	 0.011521	 0.00199	 204.39	 204.39	 204.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40108	 0.002785	 0.011521	 0.00199	 204.39	 204.39	 204.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40108	 0.002785	 0.011521	 0.00199	 204.39	 204.39	 204.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40116	 0.00262	 0.016294	 0.00666	 111.08	 111.08	 111.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40129	 0.003538	 0.017985	 0.00262	 135.15	 135.15	 135.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40086	 40146	 0.005686	 0.023849	 0.01139	 177.4	 177.4	 177.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40088	 40091	 0.000303	 0.021282	 0.0	 938.81	 938.81	 938.81	 1.0	 0.0	 1	 -30.0	 30.0;
	40260	 40088	 0.000447	 0.007015	 0.57008	 2463.01	 2463.01	 2463.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40089	 40091	 -6.8e-05	 -0.004742	 0.0	 787.81	 787.81	 787.81	 1.0	 0.0	 1	 -30.0	 30.0;
	40089	 40124	 0.008202	 0.035647	 0.0105	 176.02	 176.02	 176.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40834	 40089	 0.003767	 0.021747	 0.00344	 157.42	 157.42	 157.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40090	 40091	 0.001518	 0.10647	 0.0	 151.0	 151.0	 151.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40092	 40093	 0.000219	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40092	 40103	 0.002612	 0.016965	 0.00131	 187.85	 187.85	 187.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40092	 40117	 0.006419	 0.031979	 0.01783	 167.06	 167.06	 167.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40094	 40106	 0.004754	 0.018492	 0.00301	 170.82	 170.82	 170.82	 0.0	 0.0	 1	 -30.0	 30.0;
	40113	 40094	 0.005511	 0.019345	 0.00988	 162.42	 162.42	 162.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40095	 40096	 0.006915	 0.02928	 0.00516	 185.54	 185.54	 185.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40095	 40234	 0.009871	 0.046649	 0.03056	 179.21	 179.21	 179.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40095	 41016	 0.014446	 0.056154	 0.12998	 206.77	 206.77	 206.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40095	 41016	 0.014446	 0.056154	 0.12998	 206.77	 206.77	 206.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40095	 41016	 0.014446	 0.056154	 0.12998	 206.77	 206.77	 206.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40180	 40096	 0.016038	 0.07866	 0.03301	 168.34	 168.34	 168.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40097	 40098	 0.000204	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40097	 40123	 0.006387	 0.024924	 0.01846	 165.0	 165.0	 165.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40097	 40834	 0.005116	 0.02821	 0.01368	 163.19	 163.19	 163.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40097	 41015	 0.005089	 0.025297	 0.00367	 167.23	 167.23	 167.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40099	 40100	 0.000275	 0.001045	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40099	 40101	 0.00026	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40099	 40102	 0.000234	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40101	 40136	 0.004353	 0.0197	 0.00543	 134.96	 134.96	 134.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40156	 40101	 0.00417	 0.0203	 0.0035	 149.12	 149.12	 149.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40103	 40109	 0.0035	 0.016606	 0.01056	 135.18	 135.18	 135.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40103	 40781	 0.023624	 0.093588	 0.05467	 193.19	 193.19	 193.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40104	 40105	 0.000215	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40104	 40106	 0.000219	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40107	 0.000166	 0.012424	 0.0	 1130.59	 1130.59	 1130.59	 1.1	 0.0	 1	 -30.0	 30.0;
	40108	 40107	 0.000166	 0.012424	 0.0	 1130.59	 1130.59	 1130.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	40108	 40107	 0.000166	 0.012424	 0.0	 1130.59	 1130.59	 1130.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	40107	 40991	 0.000508	 0.00868	 0.83382	 2892.48	 2892.48	 2892.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40107	 41003	 0.000571	 0.007969	 1.09716	 2947.73	 2947.73	 2947.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40113	 40108	 0.001921	 0.010093	 0.00158	 284.88	 284.88	 284.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40116	 0.002477	 0.011404	 0.00236	 261.81	 261.81	 261.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40127	 40108	 0.003016	 0.01237	 0.00485	 290.2	 290.2	 290.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40129	 0.001014	 0.004544	 0.00262	 223.7	 223.7	 223.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40129	 0.001014	 0.004544	 0.00262	 223.7	 223.7	 223.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40129	 0.001014	 0.004544	 0.00262	 223.7	 223.7	 223.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40129	 0.001014	 0.004544	 0.00262	 223.7	 223.7	 223.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40108	 40129	 0.001014	 0.004544	 0.00262	 223.7	 223.7	 223.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40109	 40996	 0.013194	 0.08157	 0.03676	 177.74	 177.74	 177.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 40110	 0.003403	 0.016147	 0.00647	 154.27	 154.27	 154.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 40127	 0.001531	 0.006066	 0.00246	 209.63	 209.63	 209.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 40127	 0.001531	 0.006066	 0.00246	 209.63	 209.63	 209.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 40127	 0.001531	 0.006066	 0.00246	 209.63	 209.63	 209.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 40146	 0.003726	 0.015896	 0.00287	 154.5	 154.5	 154.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40170	 40110	 0.000348	 0.001731	 0.00581	 235.5	 235.5	 235.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40110	 40810	 0.003367	 0.015254	 0.01192	 191.31	 191.31	 191.31	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 40111	 0.004028	 0.016308	 0.00387	 194.39	 194.39	 194.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 40111	 0.004028	 0.016308	 0.00387	 194.39	 194.39	 194.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40145	 40111	 0.007084	 0.024569	 0.00117	 174.17	 174.17	 174.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40112	 40113	 0.000299	 0.001016	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40113	 40114	 0.004679	 0.020029	 0.01406	 182.97	 182.97	 182.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 40113	 0.001705	 0.009103	 0.00316	 155.31	 155.31	 155.31	 0.0	 0.0	 1	 -30.0	 30.0;
	40128	 40113	 0.00234	 0.011303	 0.00299	 130.8	 130.8	 130.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40113	 40129	 0.002618	 0.010608	 0.00305	 164.09	 164.09	 164.09	 0.0	 0.0	 1	 -30.0	 30.0;
	40114	 40115	 0.000262	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40114	 40145	 0.004888	 0.016541	 0.00239	 160.44	 160.44	 160.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 40125	 0.003627	 0.016329	 0.01112	 190.59	 190.59	 190.59	 0.0	 0.0	 1	 -30.0	 30.0;
	40116	 40128	 0.002556	 0.010525	 0.0015	 156.7	 156.7	 156.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 40116	 0.000509	 0.002355	 0.00631	 214.72	 214.72	 214.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 40116	 0.000509	 0.002355	 0.00631	 214.72	 214.72	 214.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40129	 40116	 0.000509	 0.002355	 0.00631	 214.72	 214.72	 214.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40136	 40117	 0.004152	 0.018463	 0.00327	 180.16	 180.16	 180.16	 0.0	 0.0	 1	 -30.0	 30.0;
	40132	 40118	 0.001407	 0.007397	 0.0018	 130.37	 130.37	 130.37	 0.0	 0.0	 1	 -30.0	 30.0;
	40118	 40147	 0.004415	 0.023144	 0.01062	 167.91	 167.91	 167.91	 0.0	 0.0	 1	 -30.0	 30.0;
	40137	 40119	 0.001198	 0.005166	 0.00164	 164.41	 164.41	 164.41	 0.0	 0.0	 1	 -30.0	 30.0;
	40119	 40169	 0.003423	 0.012796	 0.0091	 142.88	 142.88	 142.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40120	 40121	 0.000284	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40121	 40132	 0.00333	 0.016341	 0.00536	 165.27	 165.27	 165.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40121	 40151	 0.005655	 0.025131	 0.00582	 189.82	 189.82	 189.82	 0.0	 0.0	 1	 -30.0	 30.0;
	40157	 40122	 0.002999	 0.00939	 0.00386	 145.52	 145.52	 145.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40122	 40159	 0.001868	 0.008167	 0.00103	 138.52	 138.52	 138.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40122	 40170	 0.003505	 0.019083	 0.00519	 144.18	 144.18	 144.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40122	 40810	 0.001839	 0.007548	 0.00507	 265.26	 265.26	 265.26	 0.0	 0.0	 1	 -30.0	 30.0;
	40123	 40133	 0.003116	 0.014974	 0.0031	 117.69	 117.69	 117.69	 0.0	 0.0	 1	 -30.0	 30.0;
	40124	 40133	 0.007858	 0.038803	 0.01892	 141.4	 141.4	 141.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 40137	 0.001845	 0.007416	 0.01058	 192.06	 192.06	 192.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40125	 40157	 0.001914	 0.00786	 0.0014	 163.33	 163.33	 163.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40126	 40127	 0.000297	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40127	 40129	 0.002368	 0.014093	 0.00259	 205.07	 205.07	 205.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40127	 40129	 0.002368	 0.014093	 0.00259	 205.07	 205.07	 205.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40127	 40129	 0.002368	 0.014093	 0.00259	 205.07	 205.07	 205.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40130	 40131	 0.000268	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40151	 40130	 0.005773	 0.023965	 0.00285	 160.28	 160.28	 160.28	 0.0	 0.0	 1	 -30.0	 30.0;
	40130	 40174	 0.011572	 0.043756	 0.02	 129.83	 129.83	 129.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40132	 40156	 0.004009	 0.017625	 0.00244	 125.54	 125.54	 125.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40133	 40134	 0.000277	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40133	 40198	 0.006621	 0.034502	 0.00978	 165.65	 165.65	 165.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40135	 40136	 0.000217	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40167	 40138	 0.001127	 0.004775	 0.00086	 189.2	 189.2	 189.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40138	 40210	 0.003938	 0.014348	 0.00453	 144.89	 144.89	 144.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40138	 40279	 0.003488	 0.014238	 0.01694	 149.33	 149.33	 149.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40141	 40139	 0.003444	 0.015159	 0.0053	 126.6	 126.6	 126.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 40146	 0.004572	 0.019618	 0.00231	 155.43	 155.43	 155.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 40160	 0.003395	 0.015008	 0.00433	 145.11	 145.11	 145.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40139	 40170	 0.004446	 0.020099	 0.00625	 162.91	 162.91	 162.91	 0.0	 0.0	 1	 -30.0	 30.0;
	40140	 40141	 0.000274	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40141	 40187	 0.004428	 0.022844	 0.00656	 181.12	 181.12	 181.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40141	 40209	 0.003444	 0.016068	 0.00331	 136.55	 136.55	 136.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40142	 40143	 0.009673	 0.047437	 0.00934	 140.17	 140.17	 140.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40142	 40145	 0.002783	 0.015344	 0.02418	 148.59	 148.59	 148.59	 0.0	 0.0	 1	 -30.0	 30.0;
	40161	 40142	 0.003994	 0.022412	 0.00847	 134.34	 134.34	 134.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40719	 40143	 0.0064	 0.029673	 0.0071	 178.21	 178.21	 178.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40144	 40168	 0.00297	 0.014369	 0.00391	 172.56	 172.56	 172.56	 0.0	 0.0	 1	 -30.0	 30.0;
	40144	 40209	 0.004676	 0.017211	 0.03938	 144.11	 144.11	 144.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40147	 40148	 0.004311	 0.01667	 0.00384	 206.2	 206.2	 206.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 40149	 0.000231	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 40155	 0.002153	 0.008325	 0.00175	 157.15	 157.15	 157.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 40796	 0.001502	 0.00657	 0.00112	 199.47	 199.47	 199.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 40796	 0.001502	 0.00657	 0.00112	 199.47	 199.47	 199.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40148	 40796	 0.001502	 0.00657	 0.00112	 199.47	 199.47	 199.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40151	 40150	 0.000221	 0.014443	 0.0	 998.89	 998.89	 998.89	 1.04375	 0.0	 1	 -30.0	 30.0;
	40150	 40152	 0.000211	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40192	 40151	 0.004426	 0.019717	 0.00153	 197.35	 197.35	 197.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40192	 40151	 0.004426	 0.019717	 0.00153	 197.35	 197.35	 197.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40151	 40207	 0.004594	 0.019836	 0.00646	 215.47	 215.47	 215.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40152	 40298	 0.000154	 0.002724	 0.29069	 2569.78	 2569.78	 2569.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40795	 40152	 8.3e-05	 0.001239	 0.16036	 2195.77	 2195.77	 2195.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40152	 40847	 0.000779	 0.012736	 1.42538	 2543.21	 2543.21	 2543.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40153	 40154	 0.000284	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40165	 40153	 0.003061	 0.012558	 0.00421	 171.15	 171.15	 171.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40796	 40153	 0.004126	 0.021297	 0.00479	 196.81	 196.81	 196.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40796	 40153	 0.004126	 0.021297	 0.00479	 196.81	 196.81	 196.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40155	 40191	 0.003441	 0.015885	 0.00209	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40155	 40227	 0.001558	 0.006449	 0.00177	 130.57	 130.57	 130.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40156	 40192	 0.004635	 0.022644	 0.01381	 178.68	 178.68	 178.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40157	 40158	 0.000201	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40159	 40167	 0.004186	 0.016975	 0.00516	 136.96	 136.96	 136.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40159	 40810	 0.002058	 0.009712	 0.0023	 175.81	 175.81	 175.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40209	 40160	 0.003097	 0.013739	 0.00194	 134.91	 134.91	 134.91	 0.0	 0.0	 1	 -30.0	 30.0;
	40160	 40810	 0.005582	 0.02251	 0.01203	 171.36	 171.36	 171.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40161	 40162	 0.00026	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40179	 40161	 0.005494	 0.025488	 0.00412	 109.1	 109.1	 109.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40161	 40187	 0.00595	 0.022362	 0.01105	 190.06	 190.06	 190.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40187	 0.000747	 0.003028	 0.00026	 221.17	 221.17	 221.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40187	 0.000747	 0.003028	 0.00026	 221.17	 221.17	 221.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40187	 0.000747	 0.003028	 0.00026	 221.17	 221.17	 221.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40187	 0.000747	 0.003028	 0.00026	 221.17	 221.17	 221.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40187	 0.000747	 0.003028	 0.00026	 221.17	 221.17	 221.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40163	 0.003095	 0.016585	 0.00544	 182.47	 182.47	 182.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40210	 0.006343	 0.022909	 0.00899	 190.13	 190.13	 190.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40210	 0.006343	 0.022909	 0.00899	 190.13	 190.13	 190.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 40163	 0.002128	 0.011717	 0.00259	 204.92	 204.92	 204.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 40163	 0.002128	 0.011717	 0.00259	 204.92	 204.92	 204.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 40163	 0.002128	 0.011717	 0.00259	 204.92	 204.92	 204.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40224	 0.001421	 0.005878	 0.00192	 272.07	 272.07	 272.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40163	 40233	 0.012514	 0.044363	 0.01828	 170.12	 170.12	 170.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40164	 40165	 0.000295	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40165	 40184	 0.00161	 0.007646	 0.00311	 144.79	 144.79	 144.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40168	 40166	 0.002947	 0.011564	 0.00305	 160.83	 160.83	 160.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40166	 40217	 0.00316	 0.014165	 0.00808	 157.58	 157.58	 157.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40166	 40229	 0.004011	 0.015709	 0.02307	 144.16	 144.16	 144.16	 0.0	 0.0	 1	 -30.0	 30.0;
	40167	 40168	 0.002683	 0.011227	 0.00296	 145.42	 145.42	 145.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40167	 40810	 0.003424	 0.017651	 0.00222	 168.52	 168.52	 168.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40168	 40171	 0.003739	 0.017183	 0.00508	 173.62	 173.62	 173.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40210	 40168	 0.002559	 0.012388	 0.00148	 198.57	 198.57	 198.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40810	 40168	 0.001645	 0.006993	 0.01028	 215.76	 215.76	 215.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40810	 40168	 0.001645	 0.006993	 0.01028	 215.76	 215.76	 215.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40810	 40168	 0.001645	 0.006993	 0.01028	 215.76	 215.76	 215.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40183	 40169	 0.001033	 0.00508	 0.00151	 183.28	 183.28	 183.28	 0.0	 0.0	 1	 -30.0	 30.0;
	40184	 40169	 0.001591	 0.00558	 0.00395	 141.19	 141.19	 141.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40171	 40184	 0.000887	 0.003863	 0.0007	 141.93	 141.93	 141.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40172	 40173	 0.000228	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40172	 40197	 0.002084	 0.007448	 0.00241	 159.84	 159.84	 159.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40207	 40172	 0.003665	 0.015103	 0.00572	 182.07	 182.07	 182.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40174	 40257	 0.001515	 0.007399	 0.00119	 171.6	 171.6	 171.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40175	 40176	 0.000289	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40176	 40270	 0.007399	 0.039598	 0.02799	 205.6	 205.6	 205.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40274	 40176	 0.003481	 0.012557	 0.0025	 197.02	 197.02	 197.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40274	 40176	 0.003481	 0.012557	 0.0025	 197.02	 197.02	 197.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40177	 40178	 0.000237	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40177	 40205	 0.001599	 0.009168	 0.01645	 138.53	 138.53	 138.53	 0.0	 0.0	 1	 -30.0	 30.0;
	40245	 40177	 0.00097	 0.004735	 0.00203	 177.97	 177.97	 177.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40205	 40179	 0.003079	 0.013435	 0.00548	 243.49	 243.49	 243.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40255	 40179	 0.004611	 0.026059	 0.01242	 174.24	 174.24	 174.24	 0.0	 0.0	 1	 -30.0	 30.0;
	40180	 40289	 0.015849	 0.053471	 0.01054	 111.68	 111.68	 111.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40196	 40181	 0.001357	 0.006871	 0.00212	 178.13	 178.13	 178.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40229	 40181	 0.0027	 0.012531	 0.00174	 129.07	 129.07	 129.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40259	 40181	 0.00178	 0.006779	 0.00232	 192.87	 192.87	 192.87	 0.0	 0.0	 1	 -30.0	 30.0;
	40259	 40181	 0.00178	 0.006779	 0.00232	 192.87	 192.87	 192.87	 0.0	 0.0	 1	 -30.0	 30.0;
	40182	 40183	 0.000254	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40183	 40810	 0.004735	 0.020785	 0.00462	 194.21	 194.21	 194.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40183	 40810	 0.004735	 0.020785	 0.00462	 194.21	 194.21	 194.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40184	 40185	 0.000207	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40187	 40186	 0.000193	 0.013167	 0.0	 1179.99	 1179.99	 1179.99	 1.06875	 0.0	 1	 -30.0	 30.0;
	40187	 40186	 0.000193	 0.013167	 0.0	 1179.99	 1179.99	 1179.99	 1.06875	 0.0	 1	 -30.0	 30.0;
	40187	 40186	 0.000193	 0.013167	 0.0	 1179.99	 1179.99	 1179.99	 1.06875	 0.0	 1	 -30.0	 30.0;
	40254	 40186	 0.000149	 0.002708	 0.32199	 2222.71	 2222.71	 2222.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40186	 40795	 0.000216	 0.003765	 0.35493	 2637.44	 2637.44	 2637.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40186	 40809	 0.000138	 0.002326	 0.26006	 2488.2	 2488.2	 2488.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40186	 40967	 0.000526	 0.009554	 1.14034	 2892.72	 2892.72	 2892.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40187	 40217	 0.003756	 0.017071	 0.00229	 183.6	 183.6	 183.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40187	 40220	 0.004947	 0.017601	 0.00219	 174.22	 174.22	 174.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40224	 40187	 0.002461	 0.009635	 0.00108	 214.35	 214.35	 214.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40224	 40187	 0.002461	 0.009635	 0.00108	 214.35	 214.35	 214.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40224	 40187	 0.002461	 0.009635	 0.00108	 214.35	 214.35	 214.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40188	 40189	 0.000263	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40190	 0.001255	 0.0067	 0.00347	 178.53	 178.53	 178.53	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40224	 0.002944	 0.012252	 0.00322	 206.58	 206.58	 206.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40224	 0.002944	 0.012252	 0.00322	 206.58	 206.58	 206.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40224	 0.002944	 0.012252	 0.00322	 206.58	 206.58	 206.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40245	 0.002374	 0.008965	 0.00335	 196.76	 196.76	 196.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40245	 0.002374	 0.008965	 0.00335	 196.76	 196.76	 196.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40189	 40247	 0.002839	 0.013962	 0.00741	 169.39	 169.39	 169.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40190	 40277	 0.002735	 0.013691	 0.00399	 155.99	 155.99	 155.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40191	 40207	 0.001949	 0.008114	 0.00187	 274.88	 274.88	 274.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40191	 40257	 0.002039	 0.010443	 0.0309	 199.01	 199.01	 199.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40191	 40257	 0.002039	 0.010443	 0.0309	 199.01	 199.01	 199.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40191	 40257	 0.002039	 0.010443	 0.0309	 199.01	 199.01	 199.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40199	 40193	 0.007247	 0.020649	 0.01094	 160.52	 160.52	 160.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40193	 40226	 0.010064	 0.05158	 0.0159	 142.48	 142.48	 142.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40194	 40195	 0.000246	 0.001128	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40194	 40473	 0.0192	 0.081676	 0.06743	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40716	 40194	 0.017531	 0.06603	 0.01571	 178.42	 178.42	 178.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40231	 40196	 0.002388	 0.009862	 0.00262	 160.0	 160.0	 160.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40271	 40197	 0.002629	 0.01426	 0.00591	 139.97	 139.97	 139.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40261	 40198	 0.010094	 0.052195	 0.01257	 173.1	 173.1	 173.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40199	 40200	 0.000234	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40199	 40255	 0.003198	 0.018037	 0.01234	 189.93	 189.93	 189.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40199	 40255	 0.003198	 0.018037	 0.01234	 189.93	 189.93	 189.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40201	 40204	 0.0001	 0.002383	 0.0	 177.93	 177.93	 177.93	 1.0	 0.0	 1	 -30.0	 30.0;
	40201	 40205	 0.000221	 0.001135	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40202	 40204	 0.003262	 0.094821	 0.0	 120.0	 120.0	 120.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40203	 40204	 0.003262	 0.094821	 0.0	 88.97	 88.97	 88.97	 1.0	 0.0	 1	 -30.0	 30.0;
	40206	 40250	 0.002782	 0.014768	 0.00276	 158.53	 158.53	 158.53	 0.0	 0.0	 1	 -30.0	 30.0;
	40299	 40206	 0.001286	 0.005404	 0.0013	 193.49	 193.49	 193.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40299	 40206	 0.001286	 0.005404	 0.0013	 193.49	 193.49	 193.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40207	 40208	 0.000272	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40224	 40209	 0.003558	 0.01389	 0.00547	 181.6	 181.6	 181.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40210	 40247	 0.006677	 0.029844	 0.01206	 154.1	 154.1	 154.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40211	 40212	 0.0002	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40228	 40211	 0.007191	 0.035215	 0.032	 173.23	 173.23	 173.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40211	 40261	 0.013854	 0.056198	 0.04197	 185.41	 185.41	 185.41	 0.0	 0.0	 1	 -30.0	 30.0;
	40213	 40250	 0.003918	 0.018915	 0.01612	 170.85	 170.85	 170.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40257	 40213	 0.002863	 0.012728	 0.00495	 180.93	 180.93	 180.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40215	 40214	 0.000318	 0.020739	 0.0	 963.0	 963.0	 963.0	 1.1	 0.0	 1	 -30.0	 30.0;
	40298	 40214	 0.000159	 0.00186	 0.24686	 2323.95	 2323.95	 2323.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40335	 40214	 0.000144	 0.002675	 0.27997	 2463.37	 2463.37	 2463.37	 0.0	 0.0	 1	 -30.0	 30.0;
	40214	 40795	 0.000149	 0.002644	 0.29971	 2783.99	 2783.99	 2783.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40222	 40215	 0.001189	 0.007031	 0.00112	 194.05	 194.05	 194.05	 0.0	 0.0	 1	 -30.0	 30.0;
	40222	 40215	 0.001189	 0.007031	 0.00112	 194.05	 194.05	 194.05	 0.0	 0.0	 1	 -30.0	 30.0;
	40215	 40241	 0.000494	 0.002364	 0.00082	 182.82	 182.82	 182.82	 0.0	 0.0	 1	 -30.0	 30.0;
	40215	 40280	 0.004595	 0.021469	 0.01509	 205.0	 205.0	 205.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40215	 40310	 0.003787	 0.012165	 0.00398	 251.83	 251.83	 251.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40216	 40250	 0.001384	 0.005914	 0.00063	 139.11	 139.11	 139.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40216	 40299	 0.002182	 0.010267	 0.00132	 178.28	 178.28	 178.28	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 40217	 0.000909	 0.0046	 0.00128	 197.23	 197.23	 197.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 40217	 0.000909	 0.0046	 0.00128	 197.23	 197.23	 197.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40217	 40231	 0.003775	 0.017787	 0.0329	 176.41	 176.41	 176.41	 0.0	 0.0	 1	 -30.0	 30.0;
	40217	 40238	 0.00222	 0.013204	 0.00426	 272.34	 272.34	 272.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40218	 40219	 0.00027	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40218	 40220	 0.000289	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40220	 40279	 0.00273	 0.016671	 0.00751	 177.33	 177.33	 177.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40231	 40221	 0.003579	 0.012086	 0.00223	 157.78	 157.78	 157.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40240	 40221	 0.001291	 0.00578	 0.00179	 121.29	 121.29	 121.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40221	 40241	 0.002372	 0.010099	 0.0017	 164.55	 164.55	 164.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40221	 40297	 0.003914	 0.017718	 0.01368	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40225	 40222	 0.002041	 0.009018	 0.00342	 195.0	 195.0	 195.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40247	 40223	 0.001999	 0.007667	 0.00959	 205.74	 205.74	 205.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40223	 40255	 0.007348	 0.030482	 0.02067	 193.06	 193.06	 193.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40223	 40255	 0.007348	 0.030482	 0.02067	 193.06	 193.06	 193.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40223	 40282	 0.0047	 0.018	 0.0045	 190.0	 190.0	 190.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40223	 40322	 0.004502	 0.022121	 0.01681	 163.24	 163.24	 163.24	 0.0	 0.0	 1	 -30.0	 30.0;
	40266	 40225	 0.001791	 0.00856	 0.00174	 148.4	 148.4	 148.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40225	 40267	 0.001867	 0.00837	 0.00079	 203.3	 203.3	 203.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40305	 40226	 0.001556	 0.007341	 0.00318	 153.36	 153.36	 153.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40226	 40322	 0.001323	 0.005945	 0.00189	 119.63	 119.63	 119.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40227	 40796	 0.002034	 0.010003	 0.00137	 173.58	 173.58	 173.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40719	 40228	 0.00977	 0.043183	 0.14603	 170.03	 170.03	 170.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40230	 40231	 0.000231	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40230	 40232	 0.000281	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40233	 40231	 0.002438	 0.011403	 0.00252	 138.61	 138.61	 138.61	 0.0	 0.0	 1	 -30.0	 30.0;
	40274	 40234	 0.010543	 0.037767	 0.00731	 148.95	 148.95	 148.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40235	 40236	 0.000238	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40235	 40237	 0.000222	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40311	 40236	 0.001012	 0.004524	 0.00192	 277.85	 277.85	 277.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 40316	 0.004634	 0.017155	 0.00394	 137.66	 137.66	 137.66	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 40318	 0.001963	 0.008375	 0.00178	 143.93	 143.93	 143.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 40738	 0.002377	 0.010608	 0.01492	 199.84	 199.84	 199.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 40738	 0.002377	 0.010608	 0.01492	 199.84	 199.84	 199.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40236	 40738	 0.002377	 0.010608	 0.01492	 199.84	 199.84	 199.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40238	 40239	 0.000284	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40238	 40277	 0.002306	 0.008361	 0.00303	 147.07	 147.07	 147.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40238	 40284	 0.002999	 0.011781	 0.00873	 130.97	 130.97	 130.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40240	 40250	 0.002887	 0.013025	 0.05681	 167.83	 167.83	 167.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40242	 40243	 0.00027	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40242	 40244	 0.000277	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40244	 40300	 0.005233	 0.02042	 0.00877	 166.37	 166.37	 166.37	 0.0	 0.0	 1	 -30.0	 30.0;
	40244	 40738	 0.003875	 0.01777	 0.00551	 183.25	 183.25	 183.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40246	 40247	 0.000277	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40247	 40284	 0.000469	 0.002407	 0.00124	 155.02	 155.02	 155.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40248	 40249	 0.000275	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40331	 40248	 0.012784	 0.06435	 0.01212	 132.25	 132.25	 132.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40251	 40252	 0.000291	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40251	 40253	 0.000263	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40253	 40299	 0.002332	 0.012833	 0.00784	 195.66	 195.66	 195.66	 0.0	 0.0	 1	 -30.0	 30.0;
	40253	 40299	 0.002332	 0.012833	 0.00784	 195.66	 195.66	 195.66	 0.0	 0.0	 1	 -30.0	 30.0;
	40253	 40308	 0.001254	 0.005211	 0.00115	 240.0	 240.0	 240.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40255	 40254	 0.00022	 0.0178	 0.0	 930.43	 930.43	 930.43	 1.06875	 0.0	 1	 -30.0	 30.0;
	40254	 40256	 0.000207	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40254	 40260	 0.000906	 0.015243	 1.72978	 2878.89	 2878.89	 2878.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40255	 40305	 0.006328	 0.032081	 0.00592	 181.35	 181.35	 181.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40257	 40258	 0.00023	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40259	 40796	 0.005152	 0.025813	 0.01597	 200.68	 200.68	 200.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40259	 40796	 0.005152	 0.025813	 0.01597	 200.68	 200.68	 200.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40259	 40796	 0.005152	 0.025813	 0.01597	 200.68	 200.68	 200.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40260	 40263	 7.7e-05	 0.00635	 0.0	 1207.62	 1207.62	 1207.62	 1.0	 0.0	 1	 -30.0	 30.0;
	40260	 40428	 0.000624	 0.011689	 1.09213	 2961.12	 2961.12	 2961.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40715	 40260	 0.000746	 0.012299	 1.36717	 2911.25	 2911.25	 2911.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40260	 40752	 0.00201	 0.036311	 3.42071	 2118.51	 2118.51	 2118.51	 0.0	 0.0	 1	 -30.0	 30.0;
	40261	 40263	 4.1e-05	 0.003389	 0.0	 966.58	 966.58	 966.58	 1.0	 0.0	 1	 -30.0	 30.0;
	40261	 40386	 0.020934	 0.093822	 0.02176	 153.57	 153.57	 153.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40261	 40392	 0.013673	 0.066469	 0.02022	 170.44	 170.44	 170.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40261	 40422	 0.013941	 0.071164	 0.0488	 159.74	 159.74	 159.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40261	 41015	 0.011904	 0.048284	 0.08425	 166.91	 166.91	 166.91	 0.0	 0.0	 1	 -30.0	 30.0;
	40262	 40263	 0.000734	 0.060595	 0.0	 241.04	 241.04	 241.04	 1.0	 0.0	 1	 -30.0	 30.0;
	40264	 40265	 0.000281	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40264	 40465	 0.035456	 0.193176	 0.04308	 145.31	 145.31	 145.31	 0.0	 0.0	 1	 -30.0	 30.0;
	40264	 40468	 0.040149	 0.188635	 0.08589	 153.0	 153.0	 153.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40271	 40266	 0.002911	 0.015291	 0.00409	 140.03	 140.03	 140.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40266	 40299	 0.005968	 0.028585	 0.00678	 170.6	 170.6	 170.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40267	 40268	 0.000243	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40300	 40267	 0.001505	 0.008116	 0.00207	 234.31	 234.31	 234.31	 0.0	 0.0	 1	 -30.0	 30.0;
	40267	 40302	 0.006569	 0.029217	 0.00625	 157.04	 157.04	 157.04	 0.0	 0.0	 1	 -30.0	 30.0;
	40269	 40270	 0.000251	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40270	 40272	 0.005261	 0.021817	 0.00533	 150.76	 150.76	 150.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40270	 40311	 0.003899	 0.016248	 0.005	 131.91	 131.91	 131.91	 0.0	 0.0	 1	 -30.0	 30.0;
	40271	 40299	 0.003074	 0.015034	 0.00152	 186.2	 186.2	 186.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40311	 40272	 0.003957	 0.018254	 0.0045	 150.1	 150.1	 150.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40273	 40276	 4.6e-05	 0.002926	 0.0	 931.57	 931.57	 931.57	 1.0	 0.0	 1	 -30.0	 30.0;
	40274	 40276	 0.000181	 0.011617	 0.0	 881.57	 881.57	 881.57	 1.0	 0.0	 1	 -30.0	 30.0;
	40274	 40289	 0.010383	 0.045066	 0.01508	 166.74	 166.74	 166.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40274	 40343	 0.010882	 0.055088	 0.01621	 181.0	 181.0	 181.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40275	 40276	 0.001362	 0.08752	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40277	 40278	 0.000263	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40280	 40281	 0.000289	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40290	 40280	 0.000988	 0.00413	 0.00098	 143.75	 143.75	 143.75	 0.0	 0.0	 1	 -30.0	 30.0;
	40282	 40283	 0.000294	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40282	 40320	 0.003416	 0.016282	 0.05474	 179.02	 179.02	 179.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40336	 40282	 0.005391	 0.023463	 0.00459	 192.83	 192.83	 192.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40336	 40282	 0.005391	 0.023463	 0.00459	 192.83	 192.83	 192.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40284	 40285	 0.000278	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40286	 40474	 0.043554	 0.235805	 0.03096	 143.3	 143.3	 143.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40287	 40288	 0.000254	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40287	 40350	 0.014491	 0.049795	 0.02988	 151.22	 151.22	 151.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40867	 40287	 0.010501	 0.043513	 0.01438	 181.95	 181.95	 181.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40290	 40291	 0.000208	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40290	 40303	 0.004057	 0.017428	 0.00673	 144.84	 144.84	 144.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40321	 40290	 0.002489	 0.010889	 0.00188	 151.08	 151.08	 151.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40290	 40359	 0.000633	 0.00307	 0.01356	 181.43	 181.43	 181.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40292	 40295	 -0.001519	 -0.033019	 0.0	 72.83	 72.83	 72.83	 1.0	 0.0	 1	 -30.0	 30.0;
	40292	 40296	 0.000244	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40292	 40297	 0.000245	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40293	 40295	 0.016728	 0.363607	 0.0	 36.42	 36.42	 36.42	 1.0	 0.0	 1	 -30.0	 30.0;
	40294	 40295	 0.016728	 0.363607	 0.0	 36.42	 36.42	 36.42	 1.0	 0.0	 1	 -30.0	 30.0;
	40297	 40303	 0.000629	 0.003078	 0.00228	 144.32	 144.32	 144.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40299	 40298	 0.000181	 0.013723	 0.0	 1044.8	 1044.8	 1044.8	 1.1	 0.0	 1	 -30.0	 30.0;
	40300	 40301	 0.000221	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40940	 40302	 0.004746	 0.020503	 0.00392	 182.47	 182.47	 182.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40303	 40336	 0.002733	 0.014423	 0.00626	 191.43	 191.43	 191.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40304	 40336	 0.005412	 0.021347	 0.00451	 182.46	 182.46	 182.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40372	 40304	 0.004147	 0.01824	 0.00222	 162.05	 162.05	 162.05	 0.0	 0.0	 1	 -30.0	 30.0;
	40304	 40403	 0.004961	 0.02419	 0.01662	 172.54	 172.54	 172.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40305	 40306	 0.000284	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40305	 40331	 0.005379	 0.024974	 0.0283	 156.94	 156.94	 156.94	 0.0	 0.0	 1	 -30.0	 30.0;
	40307	 40345	 0.000946	 0.004493	 0.01849	 185.0	 185.0	 185.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40362	 40307	 0.001106	 0.00585	 0.00172	 174.59	 174.59	 174.59	 0.0	 0.0	 1	 -30.0	 30.0;
	40308	 40309	 0.000276	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40308	 40321	 0.004102	 0.019654	 0.03133	 193.38	 193.38	 193.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40708	 40308	 0.001762	 0.00852	 0.00582	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40310	 40324	 0.002653	 0.010656	 0.04386	 153.21	 153.21	 153.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40311	 40312	 0.000253	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40313	 40324	 0.001336	 0.007793	 0.00071	 202.95	 202.95	 202.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40313	 40324	 0.001336	 0.007793	 0.00071	 202.95	 202.95	 202.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40313	 40324	 0.001336	 0.007793	 0.00071	 202.95	 202.95	 202.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40346	 40313	 0.002441	 0.011107	 0.00808	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40314	 40315	 0.000268	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40314	 40316	 0.000219	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40738	 40316	 0.005112	 0.018018	 0.00281	 166.06	 166.06	 166.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40317	 40318	 0.00027	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40317	 40319	 0.000207	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40738	 40318	 0.00351	 0.017354	 0.0052	 163.88	 163.88	 163.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40320	 40340	 0.002542	 0.010324	 0.00466	 147.74	 147.74	 147.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40321	 40340	 0.003133	 0.016548	 0.00335	 155.97	 155.97	 155.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40321	 40376	 0.005287	 0.029646	 0.02261	 147.84	 147.84	 147.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40322	 40327	 0.00524	 0.026369	 0.00856	 132.36	 132.36	 132.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40323	 40324	 0.00022	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40324	 40864	 0.0031	 0.014433	 0.0044	 210.48	 210.48	 210.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40324	 40864	 0.0031	 0.014433	 0.0044	 210.48	 210.48	 210.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40324	 40864	 0.0031	 0.014433	 0.0044	 210.48	 210.48	 210.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40325	 40326	 0.000223	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40325	 40340	 0.00383	 0.021564	 0.00452	 149.14	 149.14	 149.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40346	 40325	 0.001742	 0.009349	 0.00472	 158.39	 158.39	 158.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40327	 40328	 0.000291	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40329	 40330	 0.000269	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40329	 40331	 0.000276	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40331	 40332	 0.006767	 0.028096	 0.00441	 135.85	 135.85	 135.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40332	 40333	 0.000224	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40332	 40455	 0.015566	 0.06789	 0.11775	 169.73	 169.73	 169.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40354	 40334	 0.005666	 0.026079	 0.0051	 146.97	 146.97	 146.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40392	 40334	 0.005177	 0.026537	 0.00524	 168.18	 168.18	 168.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40334	 40455	 0.020165	 0.084663	 0.13618	 172.19	 172.19	 172.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40335	 40338	 0.000285	 0.020017	 0.0	 1191.18	 1191.18	 1191.18	 1.0	 0.0	 1	 -30.0	 30.0;
	40335	 40339	 0.0002	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40382	 40335	 0.000242	 0.004408	 0.41415	 2491.44	 2491.44	 2491.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40335	 40809	 0.000292	 0.004729	 0.43641	 2411.29	 2411.29	 2411.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40336	 40338	 -0.00012	 -0.008444	 0.0	 1066.18	 1066.18	 1066.18	 1.0	 0.0	 1	 -30.0	 30.0;
	40341	 40336	 0.003713	 0.016267	 0.00248	 181.03	 181.03	 181.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40359	 40336	 0.00433	 0.02538	 0.00386	 175.72	 175.72	 175.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40372	 40336	 0.002264	 0.010777	 0.00153	 189.49	 189.49	 189.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40336	 40381	 0.0079	 0.037893	 0.02707	 171.82	 171.82	 171.82	 0.0	 0.0	 1	 -30.0	 30.0;
	40337	 40338	 0.000792	 0.055582	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40359	 40341	 0.003329	 0.014714	 0.00813	 150.7	 150.7	 150.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40376	 40342	 0.006505	 0.030664	 0.01383	 163.95	 163.95	 163.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40342	 40383	 0.004782	 0.021812	 0.02182	 186.57	 186.57	 186.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40343	 40352	 0.002334	 0.011357	 0.00316	 138.53	 138.53	 138.53	 0.0	 0.0	 1	 -30.0	 30.0;
	40344	 40369	 0.00517	 0.023048	 0.00465	 186.99	 186.99	 186.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40344	 40389	 0.002447	 0.011856	 0.00169	 155.35	 155.35	 155.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40390	 40345	 0.003691	 0.015221	 0.00205	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40404	 40345	 0.002212	 0.008028	 0.00087	 190.0	 190.0	 190.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40346	 40347	 0.000208	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40346	 40380	 0.013173	 0.0571	 0.02579	 150.12	 150.12	 150.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40348	 40349	 0.000278	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40348	 40350	 0.000203	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40348	 40351	 0.0003	 0.001044	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40402	 40350	 0.011289	 0.052675	 0.01734	 172.72	 172.72	 172.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40350	 40411	 0.002947	 0.015812	 0.00751	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40352	 40353	 0.000294	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40352	 40404	 0.007506	 0.02404	 0.00714	 178.44	 178.44	 178.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40352	 40738	 0.003434	 0.016742	 0.00804	 190.5	 190.5	 190.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40352	 40738	 0.003434	 0.016742	 0.00804	 190.5	 190.5	 190.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40354	 40355	 0.000225	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40424	 40354	 0.024273	 0.120704	 0.02002	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40356	 40357	 0.000277	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40356	 40367	 0.001173	 0.006524	 0.00095	 194.08	 194.08	 194.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40356	 40367	 0.001173	 0.006524	 0.00095	 194.08	 194.08	 194.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 40356	 0.0008	 0.00297	 0.00077	 201.44	 201.44	 201.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 40356	 0.0008	 0.00297	 0.00077	 201.44	 201.44	 201.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 40356	 0.0008	 0.00297	 0.00077	 201.44	 201.44	 201.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40390	 40358	 0.001225	 0.005093	 0.00647	 154.0	 154.0	 154.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40358	 40395	 0.002248	 0.011411	 0.00891	 173.3	 173.3	 173.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40358	 40405	 0.000723	 0.003794	 0.00388	 237.53	 237.53	 237.53	 0.0	 0.0	 1	 -30.0	 30.0;
	40360	 40361	 0.000206	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40360	 40383	 0.003891	 0.011092	 0.00295	 189.84	 189.84	 189.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40395	 40360	 0.002055	 0.00965	 0.00243	 169.06	 169.06	 169.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40362	 40378	 0.003593	 0.015555	 0.00288	 139.1	 139.1	 139.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40940	 40362	 0.008138	 0.028522	 0.00475	 189.78	 189.78	 189.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40363	 40369	 0.002812	 0.013676	 0.00662	 190.55	 190.55	 190.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40363	 40369	 0.002812	 0.013676	 0.00662	 190.55	 190.55	 190.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40387	 40363	 0.002758	 0.012143	 0.00193	 161.39	 161.39	 161.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40364	 40365	 0.000214	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40364	 40366	 0.00023	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40366	 40369	 0.013522	 0.049916	 0.0054	 158.07	 158.07	 158.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40366	 40369	 0.013522	 0.049916	 0.0054	 158.07	 158.07	 158.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40366	 40900	 0.003157	 0.01063	 0.00319	 143.33	 143.33	 143.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40366	 40900	 0.003157	 0.01063	 0.00319	 143.33	 143.33	 143.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40367	 40405	 0.0019	 0.007616	 0.00312	 147.68	 147.68	 147.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40367	 40410	 0.001148	 0.00562	 0.0011	 130.56	 130.56	 130.56	 0.0	 0.0	 1	 -30.0	 30.0;
	40368	 40371	 0.000196	 0.013564	 0.0	 1112.81	 1112.81	 1112.81	 1.0	 0.0	 1	 -30.0	 30.0;
	40368	 40866	 0.00031	 0.005038	 0.6395	 2312.83	 2312.83	 2312.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40368	 40899	 0.000128	 0.002123	 0.27561	 2720.75	 2720.75	 2720.75	 0.0	 0.0	 1	 -30.0	 30.0;
	40369	 40371	 1.6e-05	 0.001137	 0.0	 1012.81	 1012.81	 1012.81	 1.0	 0.0	 1	 -30.0	 30.0;
	40369	 40406	 0.002384	 0.009447	 0.00372	 207.62	 207.62	 207.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40411	 40369	 0.005236	 0.022329	 0.00645	 159.68	 159.68	 159.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40369	 40434	 0.008141	 0.039086	 0.00683	 168.46	 168.46	 168.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40370	 40371	 0.001221	 0.084458	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40372	 40373	 0.000203	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40374	 40375	 0.000203	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40374	 40376	 0.000241	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40376	 40403	 0.004567	 0.019152	 0.00622	 137.42	 137.42	 137.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40377	 40421	 0.011501	 0.052228	 0.01626	 140.19	 140.19	 140.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40377	 40867	 0.010473	 0.046737	 0.01577	 156.0	 156.0	 156.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40378	 40384	 0.000889	 0.004194	 0.0009	 178.12	 178.12	 178.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40397	 40379	 0.001984	 0.009261	 0.00316	 170.33	 170.33	 170.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40379	 40453	 0.009543	 0.039231	 0.01091	 119.5	 119.5	 119.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40403	 40380	 0.005322	 0.021774	 0.00617	 157.62	 157.62	 157.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40381	 40403	 0.008879	 0.041059	 0.01699	 149.34	 149.34	 149.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40382	 0.000169	 0.01168	 0.0	 1110.72	 1110.72	 1110.72	 1.025	 0.0	 1	 -30.0	 30.0;
	40382	 40439	 0.000141	 0.002118	 0.2698	 2655.92	 2655.92	 2655.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40899	 40382	 9.5e-05	 0.00192	 0.17067	 2882.29	 2882.29	 2882.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40390	 0.005899	 0.033482	 0.01141	 180.08	 180.08	 180.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40397	 0.000937	 0.003751	 0.00137	 206.99	 206.99	 206.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40397	 0.000937	 0.003751	 0.00137	 206.99	 206.99	 206.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40383	 40397	 0.000937	 0.003751	 0.00137	 206.99	 206.99	 206.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40418	 40383	 0.00267	 0.013607	 0.00348	 190.63	 190.63	 190.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40384	 40385	 0.000216	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40384	 40940	 0.005267	 0.01853	 0.00471	 193.72	 193.72	 193.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40386	 40422	 0.007614	 0.038855	 0.03568	 124.78	 124.78	 124.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40387	 40388	 0.000217	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40406	 40387	 0.001349	 0.007164	 0.00152	 162.77	 162.77	 162.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40387	 40412	 0.007311	 0.03459	 0.01733	 154.17	 154.17	 154.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40389	 40410	 0.003713	 0.016339	 0.00705	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40414	 40391	 0.00138	 0.007291	 0.00186	 161.33	 161.33	 161.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 40391	 0.00425	 0.016815	 0.00308	 195.22	 195.22	 195.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 40391	 0.00425	 0.016815	 0.00308	 195.22	 195.22	 195.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40422	 40392	 0.010955	 0.053631	 0.02537	 140.18	 140.18	 140.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40393	 40394	 0.000292	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40393	 40395	 0.000226	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40393	 40396	 0.000233	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40418	 40395	 0.001301	 0.004632	 0.00201	 170.03	 170.03	 170.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40397	 40407	 0.00256	 0.01515	 0.00249	 293.43	 293.43	 293.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40398	 40399	 0.000205	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40398	 40443	 0.009275	 0.033916	 0.01434	 147.16	 147.16	 147.16	 0.0	 0.0	 1	 -30.0	 30.0;
	40398	 40891	 0.008483	 0.039342	 0.02097	 167.38	 167.38	 167.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40400	 40401	 0.000231	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40400	 40402	 0.00022	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40443	 40402	 0.00397	 0.021459	 0.00582	 156.29	 156.29	 156.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40891	 40402	 0.006811	 0.035924	 0.0167	 190.16	 190.16	 190.16	 0.0	 0.0	 1	 -30.0	 30.0;
	40891	 40402	 0.006811	 0.035924	 0.0167	 190.16	 190.16	 190.16	 0.0	 0.0	 1	 -30.0	 30.0;
	40405	 40900	 0.002453	 0.011339	 0.00506	 175.44	 175.44	 175.44	 0.0	 0.0	 1	 -30.0	 30.0;
	40407	 40408	 0.000204	 0.001024	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40407	 40415	 0.002032	 0.011097	 0.00831	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40407	 40437	 0.004326	 0.017426	 0.00294	 152.18	 152.18	 152.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40419	 40409	 0.002423	 0.013739	 0.00273	 185.94	 185.94	 185.94	 0.0	 0.0	 1	 -30.0	 30.0;
	40409	 40440	 0.00376	 0.018118	 0.00349	 205.12	 205.12	 205.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40409	 40440	 0.00376	 0.018118	 0.00349	 205.12	 205.12	 205.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40409	 40440	 0.00376	 0.018118	 0.00349	 205.12	 205.12	 205.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40458	 40409	 0.003641	 0.018294	 0.00634	 159.49	 159.49	 159.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40410	 40433	 0.003368	 0.013109	 0.00809	 203.8	 203.8	 203.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40410	 40900	 0.001021	 0.004601	 0.00088	 290.3	 290.3	 290.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40411	 40434	 0.003773	 0.016495	 0.00388	 177.78	 177.78	 177.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40414	 40412	 0.0047	 0.018	 0.0045	 161.0	 161.0	 161.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40442	 40412	 0.008818	 0.024463	 0.00262	 151.59	 151.59	 151.59	 0.0	 0.0	 1	 -30.0	 30.0;
	40442	 40412	 0.008818	 0.024463	 0.00262	 151.59	 151.59	 151.59	 0.0	 0.0	 1	 -30.0	 30.0;
	40807	 40412	 0.004669	 0.017892	 0.00454	 160.99	 160.99	 160.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40413	 40431	 0.001662	 0.008339	 0.00371	 158.76	 158.76	 158.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40413	 40440	 0.006933	 0.029207	 0.00536	 178.9	 178.9	 178.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40414	 40415	 0.002689	 0.009735	 0.02013	 174.31	 174.31	 174.31	 0.0	 0.0	 1	 -30.0	 30.0;
	40415	 40416	 0.000286	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40415	 40431	 0.001189	 0.005605	 0.0023	 160.53	 160.53	 160.53	 0.0	 0.0	 1	 -30.0	 30.0;
	40440	 40417	 0.004834	 0.021394	 0.00953	 176.65	 176.65	 176.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40417	 40447	 0.006823	 0.028775	 0.01225	 133.73	 133.73	 133.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40419	 40420	 0.000299	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40431	 40419	 0.003164	 0.017996	 0.00566	 126.57	 126.57	 126.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40437	 40419	 0.002049	 0.01009	 0.00325	 158.25	 158.25	 158.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40456	 40421	 0.010256	 0.045856	 0.01372	 145.08	 145.08	 145.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40421	 40459	 0.012005	 0.05982	 0.04418	 157.36	 157.36	 157.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40422	 40423	 0.000298	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40424	 40425	 0.000241	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40429	 40424	 0.013216	 0.068452	 0.02204	 197.54	 197.54	 197.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40426	 40427	 0.000224	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40426	 40429	 0.018705	 0.04768	 0.00363	 171.96	 171.96	 171.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40426	 40472	 0.01378	 0.071217	 0.00913	 130.79	 130.79	 130.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40429	 40428	 0.000236	 0.012627	 0.0	 814.45	 814.45	 814.45	 1.00625	 0.0	 1	 -30.0	 30.0;
	40429	 40428	 0.000236	 0.012627	 0.0	 814.45	 814.45	 814.45	 1.00625	 0.0	 1	 -30.0	 30.0;
	40930	 40428	 0.001786	 0.026879	 2.93678	 3286.04	 3286.04	 3286.04	 0.0	 0.0	 1	 -30.0	 30.0;
	40429	 40473	 0.015741	 0.064115	 0.01703	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40430	 40431	 0.000297	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40431	 40433	 0.001015	 0.00415	 0.00128	 167.86	 167.86	 167.86	 0.0	 0.0	 1	 -30.0	 30.0;
	40432	 40433	 0.000231	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40433	 40440	 0.004481	 0.024998	 0.01279	 187.29	 187.29	 187.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40436	 40434	 0.005372	 0.023469	 0.0087	 168.61	 168.61	 168.61	 0.0	 0.0	 1	 -30.0	 30.0;
	40435	 40436	 0.000261	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40436	 40462	 0.011314	 0.042427	 0.03053	 140.78	 140.78	 140.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40437	 40438	 0.000257	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40440	 40439	 0.00034	 0.020204	 0.0	 995.32	 995.32	 995.32	 1.1	 0.0	 1	 -30.0	 30.0;
	40439	 40441	 0.000233	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40439	 40947	 0.001555	 0.026409	 3.17399	 2986.74	 2986.74	 2986.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40955	 40439	 0.000345	 0.005677	 0.58948	 2460.23	 2460.23	 2460.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40442	 40477	 0.013847	 0.068107	 0.04008	 161.14	 161.14	 161.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40443	 40446	 -0.000122	 -0.003052	 0.0	 122.01	 122.01	 122.01	 1.0	 0.0	 1	 -30.0	 30.0;
	40443	 40867	 0.007487	 0.015575	 0.01136	 261.6	 261.6	 261.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40444	 40446	 0.008513	 0.212445	 0.0	 61.01	 61.01	 61.01	 1.0	 0.0	 1	 -30.0	 30.0;
	40445	 40446	 0.008513	 0.212445	 0.0	 61.01	 61.01	 61.01	 1.0	 0.0	 1	 -30.0	 30.0;
	40450	 40447	 0.005816	 0.026948	 0.01165	 172.93	 172.93	 172.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 40448	 0.007111	 0.027681	 0.00389	 174.85	 174.85	 174.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40448	 40458	 0.005348	 0.022217	 0.00489	 138.69	 138.69	 138.69	 0.0	 0.0	 1	 -30.0	 30.0;
	40449	 40450	 0.0003	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 40450	 0.001569	 0.008068	 0.02027	 198.64	 198.64	 198.64	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 40450	 0.001569	 0.008068	 0.02027	 198.64	 198.64	 198.64	 0.0	 0.0	 1	 -30.0	 30.0;
	40450	 40464	 0.001311	 0.007911	 0.00223	 210.7	 210.7	 210.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40450	 40464	 0.001311	 0.007911	 0.00223	 210.7	 210.7	 210.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40450	 40464	 0.001311	 0.007911	 0.00223	 210.7	 210.7	 210.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40451	 40452	 0.000288	 0.001175	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40451	 40453	 0.000205	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40454	 40453	 0.008382	 0.029511	 0.00787	 161.04	 161.04	 161.04	 0.0	 0.0	 1	 -30.0	 30.0;
	40455	 40478	 0.011052	 0.052837	 0.02516	 118.72	 118.72	 118.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40456	 40459	 0.017506	 0.09335	 0.03704	 156.38	 156.38	 156.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40463	 40457	 0.006242	 0.033025	 0.0055	 153.26	 153.26	 153.26	 0.0	 0.0	 1	 -30.0	 30.0;
	40457	 40874	 0.004725	 0.019062	 0.00436	 147.46	 147.46	 147.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40459	 40460	 0.000244	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40459	 40463	 0.016707	 0.052828	 0.01411	 179.88	 179.88	 179.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40459	 40477	 0.012106	 0.065023	 0.06953	 179.95	 179.95	 179.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40821	 40459	 0.001826	 0.009331	 0.00153	 211.48	 211.48	 211.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40821	 40459	 0.001826	 0.009331	 0.00153	 211.48	 211.48	 211.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40821	 40459	 0.001826	 0.009331	 0.00153	 211.48	 211.48	 211.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40461	 40478	 0.02609	 0.129598	 0.03131	 128.98	 128.98	 128.98	 0.0	 0.0	 1	 -30.0	 30.0;
	40462	 40776	 0.010071	 0.044597	 0.07199	 176.38	 176.38	 176.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40464	 40954	 0.00826	 0.040372	 0.02464	 215.96	 215.96	 215.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40464	 40954	 0.00826	 0.040372	 0.02464	 215.96	 215.96	 215.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40464	 40954	 0.00826	 0.040372	 0.02464	 215.96	 215.96	 215.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40465	 40466	 0.000255	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40492	 40465	 0.04075	 0.140118	 0.02285	 137.23	 137.23	 137.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40467	 40468	 0.000276	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40467	 40785	 0.0155	 0.03	 0.009	 240.0	 240.0	 240.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40923	 40468	 0.015555	 0.063275	 0.00957	 172.07	 172.07	 172.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40469	 40470	 0.000213	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40469	 40504	 0.014534	 0.051747	 0.03933	 148.86	 148.86	 148.86	 0.0	 0.0	 1	 -30.0	 30.0;
	40469	 40694	 0.008959	 0.045458	 0.01615	 179.62	 179.62	 179.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40471	 40472	 0.00026	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40473	 40472	 0.005398	 0.024761	 0.00823	 139.62	 139.62	 139.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40472	 40533	 0.050547	 0.180801	 0.03314	 153.07	 153.07	 153.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40496	 40474	 0.017253	 0.085777	 0.0333	 125.23	 125.23	 125.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40475	 40510	 0.007892	 0.040913	 0.05738	 137.73	 137.73	 137.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40475	 40774	 0.008369	 0.030227	 0.05456	 138.7	 138.7	 138.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40476	 40477	 0.000278	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40478	 40596	 0.048917	 0.247299	 0.04202	 177.69	 177.69	 177.69	 0.0	 0.0	 1	 -30.0	 30.0;
	40480	 40479	 0.012878	 0.054132	 0.00833	 135.62	 135.62	 135.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40488	 40479	 0.013069	 0.06336	 0.07319	 164.47	 164.47	 164.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40479	 40506	 0.013206	 0.061507	 0.01545	 181.89	 181.89	 181.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40480	 40481	 0.000216	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40874	 40480	 0.009517	 0.04346	 0.03135	 173.34	 173.34	 173.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40482	 40483	 0.000253	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40482	 40549	 0.033139	 0.146716	 0.05437	 137.23	 137.23	 137.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40714	 40482	 0.015939	 0.05809	 0.0123	 144.34	 144.34	 144.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40484	 40495	 0.006407	 0.03744	 0.00668	 171.85	 171.85	 171.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40484	 40806	 0.006932	 0.030991	 0.00646	 189.9	 189.9	 189.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40510	 40485	 0.012296	 0.035225	 0.0235	 184.74	 184.74	 184.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40485	 40519	 0.003962	 0.019964	 0.04571	 169.31	 169.31	 169.31	 0.0	 0.0	 1	 -30.0	 30.0;
	40486	 40487	 0.000218	 0.001016	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40486	 40496	 0.026673	 0.124675	 0.01129	 132.17	 132.17	 132.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40505	 40486	 0.018835	 0.096805	 0.01007	 102.98	 102.98	 102.98	 0.0	 0.0	 1	 -30.0	 30.0;
	40488	 40489	 0.000296	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40488	 40520	 0.007619	 0.045592	 0.00944	 147.65	 147.65	 147.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40490	 40549	 0.009202	 0.033031	 0.02284	 161.83	 161.83	 161.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40954	 40490	 0.020979	 0.116005	 0.03452	 168.43	 168.43	 168.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40502	 40491	 0.003123	 0.015959	 0.00649	 149.92	 149.92	 149.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40491	 40510	 0.002692	 0.011331	 0.00194	 178.58	 178.58	 178.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40492	 40493	 0.000299	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40492	 40578	 0.023946	 0.089576	 0.02074	 143.34	 143.34	 143.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40492	 40588	 0.039214	 0.181892	 0.09054	 159.22	 159.22	 159.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40494	 40495	 0.012464	 0.046291	 0.00555	 156.35	 156.35	 156.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40494	 40694	 0.017804	 0.081685	 0.03478	 183.15	 183.15	 183.15	 0.0	 0.0	 1	 -30.0	 30.0;
	40495	 40519	 0.00248	 0.012993	 0.0024	 159.97	 159.97	 159.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40496	 40526	 0.015464	 0.062707	 0.05555	 164.35	 164.35	 164.35	 0.0	 0.0	 1	 -30.0	 30.0;
	40538	 40496	 0.005968	 0.033004	 0.04855	 147.84	 147.84	 147.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40497	 40503	 0.000903	 0.005161	 0.00125	 188.17	 188.17	 188.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40497	 40518	 0.004956	 0.02571	 0.0266	 191.27	 191.27	 191.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40497	 40540	 0.001684	 0.009443	 0.00307	 144.0	 144.0	 144.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40498	 40532	 0.002419	 0.014324	 0.00323	 150.46	 150.46	 150.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40498	 40561	 0.007971	 0.037208	 0.03386	 162.97	 162.97	 162.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40498	 40806	 0.004911	 0.021663	 0.02304	 190.79	 190.79	 190.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40565	 40499	 0.028433	 0.116688	 0.03686	 146.91	 146.91	 146.91	 0.0	 0.0	 1	 -30.0	 30.0;
	40499	 40785	 0.026476	 0.126759	 0.01418	 154.04	 154.04	 154.04	 0.0	 0.0	 1	 -30.0	 30.0;
	40500	 40501	 0.00028	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40500	 40508	 0.017397	 0.065681	 0.01277	 170.47	 170.47	 170.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40500	 40550	 0.007338	 0.039999	 0.03697	 127.49	 127.49	 127.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40502	 40516	 0.002848	 0.014883	 0.00195	 134.07	 134.07	 134.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40502	 40526	 0.003291	 0.016926	 0.00857	 126.4	 126.4	 126.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40502	 40865	 0.009783	 0.05062	 0.01343	 155.01	 155.01	 155.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40503	 40519	 0.007956	 0.031165	 0.00739	 162.84	 162.84	 162.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40504	 40540	 0.007774	 0.039291	 0.01409	 172.49	 172.49	 172.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40806	 40504	 0.00328	 0.017165	 0.00209	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40505	 40579	 0.008149	 0.042323	 0.02507	 172.79	 172.79	 172.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40506	 40891	 0.008013	 0.040289	 0.11733	 183.95	 183.95	 183.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40508	 40507	 0.00017	 0.010748	 0.0	 813.77	 813.77	 813.77	 1.0	 0.0	 1	 -30.0	 30.0;
	40507	 40860	 0.00032	 0.004471	 0.42938	 2493.54	 2493.54	 2493.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40508	 40547	 0.012388	 0.05628	 0.00742	 174.9	 174.9	 174.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40508	 40579	 0.018202	 0.099835	 0.04151	 169.5	 169.5	 169.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40509	 40512	 0.000494	 0.03409	 0.0	 991.07	 991.07	 991.07	 1.0	 0.0	 1	 -30.0	 30.0;
	40509	 40513	 0.000272	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40509	 40514	 0.000249	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40509	 40515	 0.000237	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40510	 40512	 -0.000231	 -0.015922	 0.0	 841.07	 841.07	 841.07	 1.0	 0.0	 1	 -30.0	 30.0;
	40516	 40510	 0.002505	 0.013016	 0.0022	 182.95	 182.95	 182.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40511	 40512	 0.001664	 0.114754	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40513	 40562	 0.000237	 0.004208	 0.52264	 2047.36	 2047.36	 2047.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40513	 40860	 0.000165	 0.002396	 0.28357	 2657.39	 2657.39	 2657.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40518	 40517	 0.000221	 0.012813	 0.0	 998.73	 998.73	 998.73	 1.0	 0.0	 1	 -30.0	 30.0;
	40517	 40805	 0.000302	 0.003756	 0.36043	 2430.73	 2430.73	 2430.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40860	 40517	 0.000115	 0.001934	 0.20306	 2417.13	 2417.13	 2417.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40553	 40518	 0.002463	 0.010454	 0.0015	 201.71	 201.71	 201.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40553	 40518	 0.002463	 0.010454	 0.0015	 201.71	 201.71	 201.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40553	 40518	 0.002463	 0.010454	 0.0015	 201.71	 201.71	 201.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40518	 40865	 0.001924	 0.011345	 0.00459	 115.26	 115.26	 115.26	 0.0	 0.0	 1	 -30.0	 30.0;
	40518	 40966	 0.002823	 0.015127	 0.01839	 165.52	 165.52	 165.52	 0.0	 0.0	 1	 -30.0	 30.0;
	40522	 40519	 0.001946	 0.00877	 0.00123	 167.55	 167.55	 167.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40520	 40522	 0.007784	 0.034509	 0.06053	 126.8	 126.8	 126.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40520	 40580	 0.022411	 0.108976	 0.04919	 146.36	 146.36	 146.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40520	 40591	 0.023746	 0.113774	 0.0246	 109.68	 109.68	 109.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40521	 40522	 0.000259	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40523	 40524	 0.000208	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40523	 40541	 0.003766	 0.016689	 0.01362	 126.92	 126.92	 126.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40523	 40865	 0.012236	 0.048858	 0.01434	 166.95	 166.95	 166.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40525	 40568	 0.020358	 0.073235	 0.01433	 150.45	 150.45	 150.45	 0.0	 0.0	 1	 -30.0	 30.0;
	40525	 40694	 0.025675	 0.090941	 0.03988	 176.29	 176.29	 176.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40853	 40526	 0.005467	 0.024704	 0.00408	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40527	 40547	 0.007804	 0.030173	 0.02855	 125.03	 125.03	 125.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40527	 40853	 0.005873	 0.024888	 0.00547	 165.02	 165.02	 165.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40528	 40529	 0.001046	 0.006242	 0.00159	 220.68	 220.68	 220.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40528	 40541	 0.002357	 0.013969	 0.00928	 157.61	 157.61	 157.61	 0.0	 0.0	 1	 -30.0	 30.0;
	40575	 40528	 0.004397	 0.021566	 0.00921	 134.08	 134.08	 134.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40553	 40529	 0.002398	 0.009888	 0.00521	 182.89	 182.89	 182.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40529	 40966	 0.002942	 0.012365	 0.0208	 191.74	 191.74	 191.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40530	 40531	 0.00028	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40530	 40532	 0.000282	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40532	 40774	 0.007073	 0.034563	 0.02689	 156.99	 156.99	 156.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40592	 40533	 0.031331	 0.151789	 0.05251	 158.42	 158.42	 158.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40534	 40563	 0.007318	 0.034713	 0.02301	 161.36	 161.36	 161.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40534	 40920	 0.004792	 0.02172	 0.00855	 160.86	 160.86	 160.86	 0.0	 0.0	 1	 -30.0	 30.0;
	40535	 40536	 0.00106	 0.005823	 0.00265	 141.32	 141.32	 141.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40535	 40574	 0.002064	 0.009148	 0.00503	 157.6	 157.6	 157.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40535	 40853	 0.004045	 0.014934	 0.00892	 195.92	 195.92	 195.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40535	 40853	 0.004045	 0.014934	 0.00892	 195.92	 195.92	 195.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40536	 40537	 0.002096	 0.009358	 0.003	 136.96	 136.96	 136.96	 0.0	 0.0	 1	 -30.0	 30.0;
	40536	 40563	 0.007006	 0.030973	 0.02687	 149.62	 149.62	 149.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40536	 40920	 0.00271	 0.01356	 0.00706	 141.48	 141.48	 141.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40574	 40537	 0.000756	 0.003742	 0.00078	 144.17	 144.17	 144.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40537	 40966	 0.002659	 0.014174	 0.00681	 170.05	 170.05	 170.05	 0.0	 0.0	 1	 -30.0	 30.0;
	40538	 40539	 0.000225	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40538	 40543	 0.029356	 0.130864	 0.03783	 162.51	 162.51	 162.51	 0.0	 0.0	 1	 -30.0	 30.0;
	40541	 40542	 0.000269	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40705	 40543	 0.011389	 0.055338	 0.0096	 192.09	 192.09	 192.09	 0.0	 0.0	 1	 -30.0	 30.0;
	40705	 40543	 0.011389	 0.055338	 0.0096	 192.09	 192.09	 192.09	 0.0	 0.0	 1	 -30.0	 30.0;
	40547	 40544	 0.003413	 0.018875	 0.00519	 141.32	 141.32	 141.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40544	 40558	 0.008158	 0.029493	 0.01605	 156.68	 156.68	 156.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40545	 40546	 0.000293	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40545	 40547	 0.000206	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40545	 40548	 0.000216	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40549	 40570	 0.020993	 0.065001	 0.01919	 135.49	 135.49	 135.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40549	 40580	 0.03397	 0.118224	 0.02314	 153.88	 153.88	 153.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40550	 40551	 0.000225	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40550	 40871	 0.001078	 0.003929	 0.00175	 168.4	 168.4	 168.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40552	 40555	 0.005177	 0.025576	 0.00616	 159.21	 159.21	 159.21	 0.0	 0.0	 1	 -30.0	 30.0;
	40560	 40552	 0.006041	 0.029827	 0.0064	 134.06	 134.06	 134.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40571	 40552	 0.002953	 0.011399	 0.00232	 83.79	 83.79	 83.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40871	 40553	 0.001862	 0.009197	 0.0013	 163.51	 163.51	 163.51	 0.0	 0.0	 1	 -30.0	 30.0;
	40554	 40557	 0.000346	 0.030677	 0.0	 1009.11	 1009.11	 1009.11	 1.0	 0.0	 1	 -30.0	 30.0;
	40860	 40554	 0.000147	 0.002925	 0.28131	 2528.2	 2528.2	 2528.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40555	 40557	 -8.8e-05	 -0.007827	 0.0	 828.67	 828.67	 828.67	 1.0	 0.0	 1	 -30.0	 30.0;
	40555	 40564	 0.003279	 0.012199	 0.00232	 174.66	 174.66	 174.66	 0.0	 0.0	 1	 -30.0	 30.0;
	40575	 40555	 0.001001	 0.005322	 0.0008	 190.92	 190.92	 190.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40575	 40555	 0.001001	 0.005322	 0.0008	 190.92	 190.92	 190.92	 0.0	 0.0	 1	 -30.0	 30.0;
	40556	 40557	 0.001624	 0.144154	 0.0	 180.44	 180.44	 180.44	 1.0	 0.0	 1	 -30.0	 30.0;
	40853	 40558	 0.001346	 0.006776	 0.01265	 202.13	 202.13	 202.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40558	 40920	 0.000987	 0.004423	 0.0035	 168.13	 168.13	 168.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40559	 40560	 0.000217	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40563	 40560	 0.005505	 0.025507	 0.00303	 173.42	 173.42	 173.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40561	 40564	 0.003476	 0.015314	 0.01467	 150.62	 150.62	 150.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40563	 40562	 0.000199	 0.014192	 0.0	 954.83	 954.83	 954.83	 1.025	 0.0	 1	 -30.0	 30.0;
	40562	 40860	 0.000191	 0.002895	 0.21539	 2635.47	 2635.47	 2635.47	 0.0	 0.0	 1	 -30.0	 30.0;
	40563	 40571	 0.008151	 0.036676	 0.01218	 169.13	 169.13	 169.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40573	 40563	 0.003317	 0.015042	 0.00397	 246.1	 246.1	 246.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40564	 40575	 0.002548	 0.013805	 0.00234	 160.87	 160.87	 160.87	 0.0	 0.0	 1	 -30.0	 30.0;
	40565	 40588	 0.013407	 0.063268	 0.01108	 162.55	 162.55	 162.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40565	 40785	 0.042549	 0.207155	 0.06092	 155.8	 155.8	 155.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40566	 40567	 0.000205	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40566	 40568	 0.000213	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40591	 40568	 0.017719	 0.077848	 0.0124	 138.4	 138.4	 138.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40573	 40569	 0.003045	 0.015711	 0.00694	 174.62	 174.62	 174.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40585	 40569	 0.012171	 0.048996	 0.01726	 110.5	 110.5	 110.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40569	 40598	 0.032224	 0.142148	 0.02162	 116.12	 116.12	 116.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40597	 40570	 0.017787	 0.093395	 0.00825	 149.01	 149.01	 149.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40572	 40573	 0.000227	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40576	 40577	 0.000208	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40576	 40578	 0.00029	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40592	 40578	 0.019938	 0.086614	 0.02661	 138.22	 138.22	 138.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40604	 40579	 0.036775	 0.130308	 0.03328	 135.2	 135.2	 135.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40581	 40582	 0.0002	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40581	 40583	 0.000237	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40582	 40609	 0.024643	 0.116743	 0.02229	 139.89	 139.89	 139.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40582	 40933	 0.026683	 0.125107	 0.02474	 149.83	 149.83	 149.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40584	 40585	 0.00026	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40584	 40586	 0.000227	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40585	 40624	 0.01605	 0.089284	 0.09728	 174.48	 174.48	 174.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40587	 40588	 0.000243	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40587	 40589	 0.000236	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40587	 40590	 0.000295	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40592	 40593	 0.022435	 0.084049	 0.01288	 136.3	 136.3	 136.3	 0.0	 0.0	 1	 -30.0	 30.0;
	40628	 40592	 0.030479	 0.139223	 0.01875	 133.72	 133.72	 133.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40614	 40593	 0.03509	 0.153276	 0.01828	 141.61	 141.61	 141.61	 0.0	 0.0	 1	 -30.0	 30.0;
	40594	 40595	 0.00027	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40594	 40596	 0.000256	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40596	 40601	 0.022658	 0.105266	 0.02455	 132.71	 132.71	 132.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40596	 40918	 0.014862	 0.078925	 0.01785	 153.11	 153.11	 153.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40596	 40948	 0.014917	 0.073205	 0.0619	 166.34	 166.34	 166.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40605	 40597	 0.014483	 0.065493	 0.02195	 130.18	 130.18	 130.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40642	 40597	 0.044053	 0.216887	 0.04536	 156.48	 156.48	 156.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40643	 40598	 0.030698	 0.142416	 0.02672	 153.4	 153.4	 153.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40604	 40599	 0.011868	 0.058271	 0.01602	 156.0	 156.0	 156.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40748	 40599	 0.002082	 0.007765	 0.00187	 165.11	 165.11	 165.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40600	 40601	 0.000298	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40601	 40630	 0.032391	 0.13117	 0.04157	 137.05	 137.05	 137.05	 0.0	 0.0	 1	 -30.0	 30.0;
	40602	 40610	 0.045113	 0.198913	 0.04769	 145.24	 145.24	 145.24	 0.0	 0.0	 1	 -30.0	 30.0;
	50332	 40602	 0.068054	 0.250001	 0.04426	 148.99	 148.99	 148.99	 0.0	 0.0	 1	 -30.0	 30.0;
	40603	 40604	 0.000269	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40605	 40606	 0.000281	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40619	 40605	 0.013526	 0.068794	 0.02048	 132.11	 132.11	 132.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40640	 40605	 0.032054	 0.149127	 0.03149	 131.71	 131.71	 131.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40607	 40608	 0.000213	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40607	 40609	 0.000286	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40609	 40629	 0.006549	 0.039748	 0.0209	 112.07	 112.07	 112.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40933	 40609	 0.011249	 0.053316	 0.01552	 146.01	 146.01	 146.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40610	 40613	 0.000203	 0.005055	 0.0	 124.82	 124.82	 124.82	 1.0	 0.0	 1	 -30.0	 30.0;
	40610	 40614	 0.021846	 0.093378	 0.0354	 114.85	 114.85	 114.85	 0.0	 0.0	 1	 -30.0	 30.0;
	40611	 40613	 0.002653	 0.066143	 0.0	 62.41	 62.41	 62.41	 1.0	 0.0	 1	 -30.0	 30.0;
	40612	 40613	 0.002653	 0.066143	 0.0	 62.41	 62.41	 62.41	 1.0	 0.0	 1	 -30.0	 30.0;
	40645	 40614	 0.01167	 0.067471	 0.03774	 158.7	 158.7	 158.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40616	 40615	 0.007386	 0.038461	 0.00578	 132.32	 132.32	 132.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40615	 40624	 0.01519	 0.078513	 0.0168	 158.57	 158.57	 158.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40748	 40616	 0.017741	 0.049826	 0.01873	 156.87	 156.87	 156.87	 0.0	 0.0	 1	 -30.0	 30.0;
	40617	 40618	 0.00026	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40617	 40619	 0.000226	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40619	 40640	 0.007362	 0.040795	 0.05168	 136.4	 136.4	 136.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40620	 40621	 0.000244	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40638	 40620	 0.009238	 0.051573	 0.00493	 147.36	 147.36	 147.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40620	 40660	 0.021122	 0.090622	 0.05514	 142.94	 142.94	 142.94	 0.0	 0.0	 1	 -30.0	 30.0;
	40620	 40748	 0.014308	 0.060857	 0.04047	 155.65	 155.65	 155.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40624	 40622	 0.008606	 0.031907	 0.00913	 167.98	 167.98	 167.98	 0.0	 0.0	 1	 -30.0	 30.0;
	40624	 40622	 0.008606	 0.031907	 0.00913	 167.98	 167.98	 167.98	 0.0	 0.0	 1	 -30.0	 30.0;
	40622	 40647	 0.006783	 0.041088	 0.02126	 117.23	 117.23	 117.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40624	 40623	 0.000215	 0.014158	 0.0	 803.83	 803.83	 803.83	 1.05625	 0.0	 1	 -30.0	 30.0;
	40623	 40666	 0.000876	 0.013956	 1.32266	 2372.88	 2372.88	 2372.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40704	 40623	 0.000624	 0.011195	 1.28515	 2101.79	 2101.79	 2101.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40623	 53250	 0.001814	 0.033801	 4.2326	 2298.84	 2298.84	 2298.84	 0.0	 0.0	 1	 -30.0	 30.0;
	40624	 40627	 -0.001798	 -0.044537	 0.0	 68.53	 68.53	 68.53	 1.0	 0.0	 1	 -30.0	 30.0;
	40624	 40748	 0.009286	 0.035783	 0.02081	 160.33	 160.33	 160.33	 0.0	 0.0	 1	 -30.0	 30.0;
	40625	 40627	 0.021323	 0.528108	 0.0	 34.26	 34.26	 34.26	 1.0	 0.0	 1	 -30.0	 30.0;
	40626	 40627	 0.021323	 0.528108	 0.0	 34.26	 34.26	 34.26	 1.0	 0.0	 1	 -30.0	 30.0;
	40654	 40628	 0.022697	 0.135487	 0.03362	 145.69	 145.69	 145.69	 0.0	 0.0	 1	 -30.0	 30.0;
	40632	 40629	 0.009279	 0.037564	 0.14458	 134.54	 134.54	 134.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40634	 40629	 0.041906	 0.131712	 0.02165	 137.28	 137.28	 137.28	 0.0	 0.0	 1	 -30.0	 30.0;
	40629	 40933	 0.02308	 0.095321	 0.01856	 135.27	 135.27	 135.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40632	 40630	 0.011509	 0.05845	 0.01144	 125.89	 125.89	 125.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40630	 40782	 0.011833	 0.042404	 0.03187	 147.39	 147.39	 147.39	 0.0	 0.0	 1	 -30.0	 30.0;
	40631	 40632	 0.00029	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40631	 40633	 0.000233	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40948	 40632	 0.002766	 0.015254	 0.00373	 138.05	 138.05	 138.05	 0.0	 0.0	 1	 -30.0	 30.0;
	40634	 40635	 0.00027	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40663	 40634	 0.010142	 0.051416	 0.09495	 145.2	 145.2	 145.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40636	 40637	 0.000225	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40636	 40638	 0.000268	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40767	 40638	 0.026522	 0.130926	 0.02353	 152.94	 152.94	 152.94	 0.0	 0.0	 1	 -30.0	 30.0;
	40639	 40644	 0.01649	 0.068578	 0.00974	 133.73	 133.73	 133.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40658	 40639	 0.038745	 0.149557	 0.03361	 160.62	 160.62	 160.62	 0.0	 0.0	 1	 -30.0	 30.0;
	40640	 40641	 0.000214	 0.001084	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40653	 40640	 0.02901	 0.087073	 0.02302	 156.03	 156.03	 156.03	 0.0	 0.0	 1	 -30.0	 30.0;
	40642	 40649	 0.051384	 0.132204	 0.02152	 170.54	 170.54	 170.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40643	 40767	 0.027646	 0.112483	 0.03288	 171.63	 171.63	 171.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40644	 40649	 0.009979	 0.049239	 0.00688	 157.72	 157.72	 157.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40645	 40646	 0.000245	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 40645	 0.016942	 0.101731	 0.01544	 161.98	 161.98	 161.98	 0.0	 0.0	 1	 -30.0	 30.0;
	40647	 40727	 0.026231	 0.116377	 0.03778	 148.42	 148.42	 148.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40648	 40649	 0.000284	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40649	 40657	 0.020551	 0.083174	 0.02433	 173.98	 173.98	 173.98	 0.0	 0.0	 1	 -30.0	 30.0;
	40649	 40675	 0.014748	 0.083145	 0.05604	 167.22	 167.22	 167.22	 0.0	 0.0	 1	 -30.0	 30.0;
	40650	 40651	 0.000272	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40661	 40650	 0.032088	 0.149056	 0.014	 127.12	 127.12	 127.12	 0.0	 0.0	 1	 -30.0	 30.0;
	50332	 40650	 0.048882	 0.153197	 0.02206	 133.26	 133.26	 133.26	 0.0	 0.0	 1	 -30.0	 30.0;
	40652	 40653	 0.000222	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40664	 40653	 0.052366	 0.224728	 0.05583	 149.81	 149.81	 149.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40653	 40665	 0.027067	 0.147815	 0.03604	 154.01	 154.01	 154.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40654	 40656	 0.020512	 0.088897	 0.04985	 176.83	 176.83	 176.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40663	 40654	 0.042234	 0.17152	 0.05048	 148.88	 148.88	 148.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 40655	 0.000237	 0.017161	 0.0	 732.81	 732.81	 732.81	 1.0	 0.0	 1	 -30.0	 30.0;
	40932	 40655	 0.001467	 0.02324	 2.13367	 2947.77	 2947.77	 2947.77	 0.0	 0.0	 1	 -30.0	 30.0;
	53220	 40655	 0.00093	 0.017901	 2.27205	 3104.37	 3104.37	 3104.37	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 40682	 0.019334	 0.084513	 0.07831	 157.4	 157.4	 157.4	 0.0	 0.0	 1	 -30.0	 30.0;
	40656	 40689	 0.022651	 0.09371	 0.03056	 153.13	 153.13	 153.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40657	 40762	 0.028675	 0.129454	 0.04193	 176.25	 176.25	 176.25	 0.0	 0.0	 1	 -30.0	 30.0;
	40658	 40948	 0.021303	 0.093623	 0.04063	 164.73	 164.73	 164.73	 0.0	 0.0	 1	 -30.0	 30.0;
	40659	 40660	 0.000223	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40660	 40767	 0.024398	 0.102285	 0.0212	 155.34	 155.34	 155.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40661	 40662	 0.02039	 0.079045	 0.01274	 119.78	 119.78	 119.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40662	 40674	 0.034744	 0.140329	 0.03833	 132.57	 132.57	 132.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40685	 40663	 0.016993	 0.091124	 0.03928	 81.23	 81.23	 81.23	 0.0	 0.0	 1	 -30.0	 30.0;
	53204	 40664	 0.038996	 0.196028	 0.04256	 163.14	 163.14	 163.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40665	 40688	 0.007503	 0.036794	 0.04503	 160.06	 160.06	 160.06	 0.0	 0.0	 1	 -30.0	 30.0;
	40667	 40666	 0.000219	 0.015755	 0.0	 666.53	 666.53	 666.53	 1.0	 0.0	 1	 -30.0	 30.0;
	40666	 40668	 0.001369	 0.023494	 2.0741	 2524.63	 2524.63	 2524.63	 0.0	 0.0	 1	 -30.0	 30.0;
	40727	 40667	 0.026766	 0.090748	 0.01999	 156.88	 156.88	 156.88	 0.0	 0.0	 1	 -30.0	 30.0;
	40667	 53174	 0.08941	 0.372807	 0.06602	 125.18	 125.18	 125.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40668	 40671	 0.00018	 0.012252	 0.0	 783.99	 783.99	 783.99	 1.0	 0.0	 1	 -30.0	 30.0;
	40766	 40668	 0.00082	 0.014729	 1.7788	 2536.8	 2536.8	 2536.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40668	 40876	 0.00184	 0.029417	 3.05585	 2975.83	 2975.83	 2975.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40669	 40671	 -3.9e-05	 -0.002643	 0.0	 633.99	 633.99	 633.99	 1.0	 0.0	 1	 -30.0	 30.0;
	40669	 40688	 0.010038	 0.045595	 0.02067	 142.27	 142.27	 142.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40670	 40671	 0.000738	 0.050067	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40672	 40673	 0.000275	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40675	 40672	 0.01413	 0.081413	 0.01605	 175.49	 175.49	 175.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40672	 40877	 0.007242	 0.035098	 0.01806	 192.0	 192.0	 192.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53204	 40672	 0.03818	 0.207065	 0.04334	 165.07	 165.07	 165.07	 0.0	 0.0	 1	 -30.0	 30.0;
	40674	 50353	 0.03889	 0.184786	 0.03304	 142.86	 142.86	 142.86	 0.0	 0.0	 1	 -30.0	 30.0;
	40675	 40676	 0.000218	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40677	 40678	 0.000265	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40677	 40679	 0.000258	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40679	 40762	 0.002357	 0.011118	 0.00147	 154.34	 154.34	 154.34	 0.0	 0.0	 1	 -30.0	 30.0;
	40679	 53209	 0.021464	 0.110251	 0.08312	 141.23	 141.23	 141.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40680	 40681	 0.000241	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40682	 40681	 0.0169	 0.073782	 0.0124	 139.55	 139.55	 139.55	 0.0	 0.0	 1	 -30.0	 30.0;
	40687	 40681	 0.008187	 0.048108	 0.04123	 147.9	 147.9	 147.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40682	 53211	 0.028334	 0.169052	 0.06798	 147.7	 147.7	 147.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40683	 40684	 0.000276	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40684	 40685	 0.010579	 0.054828	 0.03441	 114.43	 114.43	 114.43	 0.0	 0.0	 1	 -30.0	 30.0;
	53209	 40684	 0.034117	 0.156652	 0.01672	 127.7	 127.7	 127.7	 0.0	 0.0	 1	 -30.0	 30.0;
	40685	 40686	 0.019788	 0.101639	 0.01472	 126.11	 126.11	 126.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40686	 40692	 0.022077	 0.096183	 0.02266	 148.01	 148.01	 148.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40686	 53203	 0.012923	 0.072906	 0.01895	 131.27	 131.27	 131.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40687	 53187	 0.072309	 0.303454	 0.05731	 124.6	 124.6	 124.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53199	 40687	 0.030725	 0.13878	 0.04918	 161.48	 161.48	 161.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40688	 53247	 0.038633	 0.163053	 0.05496	 149.95	 149.95	 149.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40689	 40690	 0.012689	 0.053602	 0.01723	 131.27	 131.27	 131.27	 0.0	 0.0	 1	 -30.0	 30.0;
	40690	 40691	 0.00021	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40692	 40690	 0.024338	 0.09933	 0.02467	 163.6	 163.6	 163.6	 0.0	 0.0	 1	 -30.0	 30.0;
	40690	 53202	 0.017387	 0.084365	 0.03339	 164.97	 164.97	 164.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40692	 53208	 0.016524	 0.094225	 0.02203	 131.95	 131.95	 131.95	 0.0	 0.0	 1	 -30.0	 30.0;
	40694	 40693	 0.000238	 0.015529	 0.0	 794.59	 794.59	 794.59	 1.0	 0.0	 1	 -30.0	 30.0;
	40693	 40695	 0.0004	 0.032439	 0.0	 551.52	 551.52	 551.52	 1.04375	 0.0	 1	 -30.0	 30.0;
	40693	 40696	 0.000341	 0.025523	 0.0	 549.43	 549.43	 549.43	 1.0	 0.0	 1	 -30.0	 30.0;
	40693	 40697	 0.000249	 0.016958	 0.0	 547.59	 547.59	 547.59	 1.0375	 0.0	 1	 -30.0	 30.0;
	40805	 40693	 0.000209	 0.003973	 0.35225	 2785.76	 2785.76	 2785.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40693	 40831	 0.000361	 0.007382	 0.84219	 2593.12	 2593.12	 2593.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40890	 40693	 0.000599	 0.007923	 0.76316	 2532.2	 2532.2	 2532.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40699	 40698	 0.000311	 0.023073	 0.0	 505.63	 505.63	 505.63	 1.0	 0.0	 1	 -30.0	 30.0;
	40698	 40700	 0.000189	 0.014221	 0.0	 752.64	 752.64	 752.64	 1.0	 0.0	 1	 -30.0	 30.0;
	40698	 40701	 0.00014	 0.008288	 0.0	 752.54	 752.54	 752.54	 1.0	 0.0	 1	 -30.0	 30.0;
	40698	 40702	 0.00022	 0.016421	 0.0	 751.15	 751.15	 751.15	 1.0	 0.0	 1	 -30.0	 30.0;
	40698	 40910	 0.000679	 0.010924	 1.11227	 2274.74	 2274.74	 2274.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40919	 40699	 0.008678	 0.051282	 0.01203	 146.17	 146.17	 146.17	 0.0	 0.0	 1	 -30.0	 30.0;
	40703	 40832	 0.002329	 0.013769	 0.00163	 178.48	 178.48	 178.48	 0.0	 0.0	 1	 -30.0	 30.0;
	40703	 41008	 0.004231	 0.016208	 0.00258	 113.36	 113.36	 113.36	 0.0	 0.0	 1	 -30.0	 30.0;
	40705	 40704	 0.000323	 0.018547	 0.0	 685.14	 685.14	 685.14	 1.075	 0.0	 1	 -30.0	 30.0;
	40705	 40704	 0.000323	 0.018547	 0.0	 685.14	 685.14	 685.14	 1.00625	 0.0	 1	 -30.0	 30.0;
	40704	 40706	 0.000243	 0.017079	 0.0	 530.72	 530.72	 530.72	 0.99375	 0.0	 1	 -30.0	 30.0;
	40704	 40707	 0.000249	 0.01557	 0.0	 529.53	 529.53	 529.53	 0.9875	 0.0	 1	 -30.0	 30.0;
	40708	 40711	 0.000592	 0.017976	 0.0	 86.08	 86.08	 86.08	 0.99375	 0.0	 1	 -30.0	 30.0;
	40940	 40708	 0.002542	 0.012867	 0.00369	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40709	 40711	 0.008621	 0.261936	 0.0	 43.04	 43.04	 43.04	 1.0	 0.0	 1	 -30.0	 30.0;
	40710	 40711	 0.008621	 0.261936	 0.0	 43.04	 43.04	 43.04	 1.0	 0.0	 1	 -30.0	 30.0;
	40712	 40713	 0.00027	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40712	 40714	 0.000264	 0.001098	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40715	 40718	 0.000141	 0.006737	 0.0	 782.8	 782.8	 782.8	 1.0	 0.0	 1	 -30.0	 30.0;
	40716	 40718	 0.000139	 0.006623	 0.0	 707.8	 707.8	 707.8	 1.0	 0.0	 1	 -30.0	 30.0;
	40717	 40718	 0.00149	 0.071229	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40720	 40721	 0.022422	 0.537955	 0.0	 19.5	 19.5	 19.5	 0.99375	 0.0	 1	 -30.0	 30.0;
	40720	 40791	 0.000537	 0.002905	 0.00106	 201.65	 201.65	 201.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40720	 40791	 0.000537	 0.002905	 0.00106	 201.65	 201.65	 201.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40720	 40791	 0.000537	 0.002905	 0.00106	 201.65	 201.65	 201.65	 0.0	 0.0	 1	 -30.0	 30.0;
	40958	 40720	 0.005419	 0.028987	 0.00356	 162.16	 162.16	 162.16	 0.0	 0.0	 1	 -30.0	 30.0;
	41016	 40720	 0.002394	 0.005824	 0.00105	 194.89	 194.89	 194.89	 0.0	 0.0	 1	 -30.0	 30.0;
	41016	 40720	 0.002394	 0.005824	 0.00105	 194.89	 194.89	 194.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40723	 40722	 7.3e-05	 0.00654	 0.0	 1370.1	 1370.1	 1370.1	 1.0	 0.0	 1	 -30.0	 30.0;
	40724	 40723	 0.000276	 0.020681	 0.0	 741.71	 741.71	 741.71	 1.0	 0.0	 1	 -30.0	 30.0;
	40725	 40724	 0.000267	 0.018763	 0.0	 548.61	 548.61	 548.61	 1.0	 0.0	 1	 -30.0	 30.0;
	40724	 40726	 0.000246	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40725	 40861	 0.004898	 0.023982	 0.00582	 247.2	 247.2	 247.2	 0.0	 0.0	 1	 -30.0	 30.0;
	40727	 40728	 0.017214	 0.404239	 0.0	 38.43	 38.43	 38.43	 1.0	 0.0	 1	 -30.0	 30.0;
	40730	 40729	 0.000138	 0.009283	 0.0	 754.42	 754.42	 754.42	 1.0	 0.0	 1	 -30.0	 30.0;
	40729	 40732	 0.000368	 0.025886	 0.0	 508.23	 508.23	 508.23	 1.0375	 0.0	 1	 -30.0	 30.0;
	40729	 40733	 0.000373	 0.025756	 0.0	 496.43	 496.43	 496.43	 1.0375	 0.0	 1	 -30.0	 30.0;
	40729	 40734	 0.000113	 0.006274	 0.0	 478.17	 478.17	 478.17	 1.0	 0.0	 1	 -30.0	 30.0;
	40729	 40735	 0.000371	 0.022275	 0.0	 466.05	 466.05	 466.05	 1.03125	 0.0	 1	 -30.0	 30.0;
	40729	 40736	 0.000633	 0.043775	 0.0	 455.01	 455.01	 455.01	 1.0375	 0.0	 1	 -30.0	 30.0;
	40729	 40752	 0.000347	 0.005599	 0.60861	 2644.51	 2644.51	 2644.51	 0.0	 0.0	 1	 -30.0	 30.0;
	40980	 40729	 0.000926	 0.014313	 1.26232	 2671.46	 2671.46	 2671.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40731	 40730	 0.000466	 0.034095	 0.0	 452.09	 452.09	 452.09	 1.0	 0.0	 1	 -30.0	 30.0;
	40730	 41007	 0.001118	 0.014144	 0.29638	 1036.13	 1036.13	 1036.13	 0.0	 0.0	 1	 -30.0	 30.0;
	40738	 40737	 0.00017	 0.016569	 0.0	 1003.61	 1003.61	 1003.61	 1.0	 0.0	 1	 -30.0	 30.0;
	40737	 40739	 0.00019	 0.015792	 0.0	 794.16	 794.16	 794.16	 1.0	 0.0	 1	 -30.0	 30.0;
	40737	 40740	 6.6e-05	 0.006123	 0.0	 794.14	 794.14	 794.14	 1.01875	 0.0	 1	 -30.0	 30.0;
	40737	 40741	 0.000314	 0.020619	 0.0	 546.42	 546.42	 546.42	 1.0	 0.0	 1	 -30.0	 30.0;
	40737	 40742	 0.000423	 0.028665	 0.0	 545.29	 545.29	 545.29	 1.025	 0.0	 1	 -30.0	 30.0;
	40737	 40743	 0.000215	 0.017117	 0.0	 544.92	 544.92	 544.92	 1.01875	 0.0	 1	 -30.0	 30.0;
	40737	 40744	 0.000529	 0.03353	 0.0	 523.57	 523.57	 523.57	 1.025	 0.0	 1	 -30.0	 30.0;
	40737	 40745	 0.000167	 0.011268	 0.0	 514.73	 514.73	 514.73	 1.01875	 0.0	 1	 -30.0	 30.0;
	40737	 40746	 0.000223	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40746	 40899	 0.000162	 0.002906	 0.31457	 2532.18	 2532.18	 2532.18	 0.0	 0.0	 1	 -30.0	 30.0;
	40939	 40746	 7.6e-05	 0.001631	 0.1491	 2315.49	 2315.49	 2315.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40747	 40748	 0.000264	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40749	 40750	 0.022388	 0.513363	 0.0	 19.5	 19.5	 19.5	 1.0	 0.0	 1	 -30.0	 30.0;
	40751	 40755	 0.000145	 0.012316	 0.0	 1585.42	 1585.42	 1585.42	 1.0	 0.0	 1	 -30.0	 30.0;
	40751	 40756	 8e-05	 0.006845	 0.0	 1585.24	 1585.24	 1585.24	 1.025	 0.0	 1	 -30.0	 30.0;
	40751	 40757	 6.2e-05	 0.005042	 0.0	 1583.3	 1583.3	 1583.3	 1.0	 0.0	 1	 -30.0	 30.0;
	40751	 40758	 0.000152	 0.011717	 0.0	 1581.54	 1581.54	 1581.54	 1.025	 0.0	 1	 -30.0	 30.0;
	40751	 40759	 0.000249	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40753	 40752	 0.000273	 0.019323	 0.0	 582.57	 582.57	 582.57	 1.025	 0.0	 1	 -30.0	 30.0;
	40752	 40755	 -8.3e-05	 -0.007019	 0.0	 1485.42	 1485.42	 1485.42	 1.0	 0.0	 1	 -30.0	 30.0;
	41012	 40752	 0.00043	 0.006856	 0.61453	 2399.59	 2399.59	 2399.59	 0.0	 0.0	 1	 -30.0	 30.0;
	40754	 40755	 0.000372	 0.031475	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40761	 40760	 8.3e-05	 0.0071	 0.0	 1439.54	 1439.54	 1439.54	 1.0	 0.0	 1	 -30.0	 30.0;
	40760	 40763	 8.4e-05	 0.006633	 0.0	 1761.89	 1761.89	 1761.89	 1.0375	 0.0	 1	 -30.0	 30.0;
	40760	 40764	 9.2e-05	 0.0069	 0.0	 1756.88	 1756.88	 1756.88	 1.0375	 0.0	 1	 -30.0	 30.0;
	40760	 40882	 8.1e-05	 0.002122	 1.01167	 4043.49	 4043.49	 4043.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40760	 40938	 0.000325	 0.00863	 3.20607	 4045.51	 4045.51	 4045.51	 0.0	 0.0	 1	 -30.0	 30.0;
	40762	 40761	 0.000201	 0.014483	 0.0	 666.98	 666.98	 666.98	 1.0	 0.0	 1	 -30.0	 30.0;
	40876	 40761	 0.000229	 0.004843	 0.49288	 2442.58	 2442.58	 2442.58	 0.0	 0.0	 1	 -30.0	 30.0;
	40761	 40947	 0.000824	 0.012673	 1.44104	 2814.24	 2814.24	 2814.24	 0.0	 0.0	 1	 -30.0	 30.0;
	40761	 53234	 0.001441	 0.022523	 2.12443	 2810.72	 2810.72	 2810.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40766	 40765	 0.000123	 0.009858	 0.0	 1382.15	 1382.15	 1382.15	 1.0	 0.0	 1	 -30.0	 30.0;
	40765	 40768	 0.000124	 0.009835	 0.0	 1475.68	 1475.68	 1475.68	 1.0	 0.0	 1	 -30.0	 30.0;
	40765	 40769	 8.1e-05	 0.008	 0.0	 1473.92	 1473.92	 1473.92	 1.0	 0.0	 1	 -30.0	 30.0;
	40765	 40770	 9.3e-05	 0.008591	 0.0	 1107.56	 1107.56	 1107.56	 1.0	 0.0	 1	 -30.0	 30.0;
	40765	 40771	 0.000206	 0.015603	 0.0	 975.74	 975.74	 975.74	 1.0	 0.0	 1	 -30.0	 30.0;
	40765	 40772	 0.000122	 0.010032	 0.0	 1142.07	 1142.07	 1142.07	 1.0	 0.0	 1	 -30.0	 30.0;
	40765	 40773	 0.000206	 0.015946	 0.0	 973.94	 973.94	 973.94	 1.0	 0.0	 1	 -30.0	 30.0;
	40851	 40765	 0.000231	 0.006885	 3.77011	 3974.79	 3974.79	 3974.79	 0.0	 0.0	 1	 -30.0	 30.0;
	40767	 40766	 0.000276	 0.019482	 0.0	 726.38	 726.38	 726.38	 1.0	 0.0	 1	 -30.0	 30.0;
	40766	 40860	 0.000856	 0.015035	 1.2754	 2553.69	 2553.69	 2553.69	 0.0	 0.0	 1	 -30.0	 30.0;
	40774	 40997	 0.002937	 0.013804	 0.00474	 158.46	 158.46	 158.46	 0.0	 0.0	 1	 -30.0	 30.0;
	40775	 40776	 0.000283	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40776	 40949	 0.008638	 0.035376	 0.00784	 173.83	 173.83	 173.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40777	 40778	 0.010937	 0.266633	 0.0	 90.0	 90.0	 90.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40777	 40779	 0.005049	 0.139706	 0.0	 67.08	 67.08	 67.08	 1.0	 0.0	 1	 -30.0	 30.0;
	40777	 40780	 0.006354	 0.173205	 0.0	 37.59	 37.59	 37.59	 1.0	 0.0	 1	 -30.0	 30.0;
	40777	 40781	 0.000294	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40781	 40839	 0.006183	 0.025677	 0.0036	 134.01	 134.01	 134.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40782	 40918	 0.013312	 0.059797	 0.01137	 151.57	 151.57	 151.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40784	 40783	 8.3e-05	 0.006465	 0.0	 2207.54	 2207.54	 2207.54	 1.1	 0.0	 1	 -30.0	 30.0;
	40784	 40783	 8.3e-05	 0.006465	 0.0	 2207.54	 2207.54	 2207.54	 1.00625	 0.0	 1	 -30.0	 30.0;
	40783	 40786	 9.1e-05	 0.007498	 0.0	 1834.75	 1834.75	 1834.75	 1.01875	 0.0	 1	 -30.0	 30.0;
	40783	 40787	 0.000132	 0.010434	 0.0	 1827.2	 1827.2	 1827.2	 1.01875	 0.0	 1	 -30.0	 30.0;
	40783	 40788	 8.1e-05	 0.006112	 0.0	 1826.09	 1826.09	 1826.09	 1.01875	 0.0	 1	 -30.0	 30.0;
	40785	 40784	 0.00024	 0.016162	 0.0	 589.54	 589.54	 589.54	 1.0	 0.0	 1	 -30.0	 30.0;
	40784	 40789	 0.000227	 0.001116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40789	 40930	 0.000107	 0.00181	 0.17725	 2646.19	 2646.19	 2646.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40790	 40791	 0.000266	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40790	 40792	 0.000265	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40791	 40883	 0.002889	 0.016305	 0.00955	 206.5	 206.5	 206.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40791	 40883	 0.002889	 0.016305	 0.00955	 206.5	 206.5	 206.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40791	 40883	 0.002889	 0.016305	 0.00955	 206.5	 206.5	 206.5	 0.0	 0.0	 1	 -30.0	 30.0;
	40791	 40958	 0.003823	 0.022109	 0.0051	 165.19	 165.19	 165.19	 0.0	 0.0	 1	 -30.0	 30.0;
	41016	 40791	 0.001566	 0.00779	 0.00155	 269.78	 269.78	 269.78	 0.0	 0.0	 1	 -30.0	 30.0;
	40992	 40793	 0.000835	 0.004342	 0.0021	 179.1	 179.1	 179.1	 0.0	 0.0	 1	 -30.0	 30.0;
	40793	 40999	 0.001797	 0.008419	 0.0053	 115.43	 115.43	 115.43	 0.0	 0.0	 1	 -30.0	 30.0;
	40795	 40794	 0.000121	 0.008104	 0.0	 1585.62	 1585.62	 1585.62	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40797	 0.000102	 0.008004	 0.0	 1436.69	 1436.69	 1436.69	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40798	 9.3e-05	 0.008033	 0.0	 1435.15	 1435.15	 1435.15	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40799	 7.9e-05	 0.006657	 0.0	 1434.98	 1434.98	 1434.98	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40800	 0.000158	 0.010711	 0.0	 1430.11	 1430.11	 1430.11	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40801	 7.8e-05	 0.00582	 0.0	 1429.12	 1429.12	 1429.12	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40802	 0.000117	 0.009989	 0.0	 1428.3	 1428.3	 1428.3	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40803	 0.000119	 0.010545	 0.0	 1067.55	 1067.55	 1067.55	 1.0	 0.0	 1	 -30.0	 30.0;
	40794	 40804	 0.000113	 0.009604	 0.0	 1066.37	 1066.37	 1066.37	 1.0	 0.0	 1	 -30.0	 30.0;
	40846	 40794	 0.000165	 0.004669	 2.0874	 4042.87	 4042.87	 4042.87	 0.0	 0.0	 1	 -30.0	 30.0;
	40796	 40795	 0.000157	 0.012887	 0.0	 1056.68	 1056.68	 1056.68	 1.0	 0.0	 1	 -30.0	 30.0;
	40795	 40841	 0.000509	 0.008711	 1.09547	 2769.42	 2769.42	 2769.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40806	 40805	 0.000303	 0.019931	 0.0	 816.58	 816.58	 816.58	 1.0125	 0.0	 1	 -30.0	 30.0;
	40806	 40997	 0.012169	 0.048927	 0.01801	 144.12	 144.12	 144.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40807	 40808	 0.009743	 0.206013	 0.0	 24.7	 24.7	 24.7	 0.95625	 0.0	 1	 -30.0	 30.0;
	40807	 40874	 0.014334	 0.054223	 0.01583	 148.83	 148.83	 148.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40809	 40812	 4.7e-05	 0.003627	 0.0	 1254.38	 1254.38	 1254.38	 1.0	 0.0	 1	 -30.0	 30.0;
	40809	 40813	 0.000208	 0.014682	 0.0	 762.22	 762.22	 762.22	 1.025	 0.0	 1	 -30.0	 30.0;
	40809	 40814	 0.000152	 0.012276	 0.0	 758.41	 758.41	 758.41	 1.025	 0.0	 1	 -30.0	 30.0;
	40809	 40815	 0.000242	 0.018452	 0.0	 756.95	 756.95	 756.95	 1.03125	 0.0	 1	 -30.0	 30.0;
	40809	 40816	 0.000554	 0.029423	 0.0	 610.07	 610.07	 610.07	 1.03125	 0.0	 1	 -30.0	 30.0;
	40809	 40817	 0.000247	 0.019666	 0.0	 601.63	 601.63	 601.63	 1.025	 0.0	 1	 -30.0	 30.0;
	40809	 40818	 0.000419	 0.034651	 0.0	 591.81	 591.81	 591.81	 1.03125	 0.0	 1	 -30.0	 30.0;
	40809	 40841	 0.000475	 0.008273	 0.99968	 2911.02	 2911.02	 2911.02	 0.0	 0.0	 1	 -30.0	 30.0;
	40810	 40812	 8.8e-05	 0.006852	 0.0	 1104.38	 1104.38	 1104.38	 1.0	 0.0	 1	 -30.0	 30.0;
	40811	 40812	 0.000701	 0.054305	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40823	 8.1e-05	 0.006444	 0.0	 1586.52	 1586.52	 1586.52	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40824	 0.000155	 0.010326	 0.0	 1278.61	 1278.61	 1278.61	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40825	 0.000152	 0.011223	 0.0	 1277.17	 1277.17	 1277.17	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40826	 0.000116	 0.009887	 0.0	 1277.16	 1277.16	 1277.16	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40827	 0.000103	 0.008799	 0.0	 1275.72	 1275.72	 1275.72	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40828	 0.000134	 0.009334	 0.0	 1275.18	 1275.18	 1275.18	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40829	 0.00013	 0.012482	 0.0	 1272.78	 1272.78	 1272.78	 1.0	 0.0	 1	 -30.0	 30.0;
	40819	 40830	 0.000289	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40821	 40820	 0.00016	 0.011964	 0.0	 823.7	 823.7	 823.7	 1.00625	 0.0	 1	 -30.0	 30.0;
	40820	 40823	 -5e-06	 -0.000389	 0.0	 1536.52	 1536.52	 1536.52	 1.0	 0.0	 1	 -30.0	 30.0;
	40820	 40831	 0.000217	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40822	 40823	 0.000432	 0.03455	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40851	 40830	 0.000242	 0.007033	 2.98346	 4109.72	 4109.72	 4109.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40830	 40898	 0.000131	 0.003587	 1.64335	 4022.71	 4022.71	 4022.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40956	 40830	 0.000288	 0.007536	 3.40238	 4055.71	 4055.71	 4055.71	 0.0	 0.0	 1	 -30.0	 30.0;
	40890	 40831	 8.9e-05	 0.001587	 0.17893	 2239.08	 2239.08	 2239.08	 0.0	 0.0	 1	 -30.0	 30.0;
	40832	 40833	 0.032759	 0.765188	 0.0	 11.7	 11.7	 11.7	 1.0	 0.0	 1	 -30.0	 30.0;
	40835	 40836	 0.001629	 0.039556	 0.0	 299.69	 299.69	 299.69	 1.0	 0.0	 1	 -30.0	 30.0;
	40835	 40837	 0.001023	 0.028654	 0.0	 299.69	 299.69	 299.69	 1.0	 0.0	 1	 -30.0	 30.0;
	40835	 40838	 0.001767	 0.038358	 0.0	 299.69	 299.69	 299.69	 0.99375	 0.0	 1	 -30.0	 30.0;
	40835	 40839	 0.000206	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40839	 40968	 0.002667	 0.012558	 0.00317	 176.81	 176.81	 176.81	 0.0	 0.0	 1	 -30.0	 30.0;
	40992	 40839	 0.003701	 0.01349	 0.00168	 155.42	 155.42	 155.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40839	 40999	 0.000257	 0.001145	 0.00018	 207.54	 207.54	 207.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40839	 40999	 0.000257	 0.001145	 0.00018	 207.54	 207.54	 207.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40839	 40999	 0.000257	 0.001145	 0.00018	 207.54	 207.54	 207.54	 0.0	 0.0	 1	 -30.0	 30.0;
	40841	 40840	 0.000127	 0.011287	 0.0	 1789.86	 1789.86	 1789.86	 1.04375	 0.0	 1	 -30.0	 30.0;
	40841	 40840	 0.000127	 0.011287	 0.0	 1789.86	 1789.86	 1789.86	 1.04375	 0.0	 1	 -30.0	 30.0;
	40841	 40840	 0.000127	 0.011287	 0.0	 1789.86	 1789.86	 1789.86	 1.04375	 0.0	 1	 -30.0	 30.0;
	40840	 40843	 8.4e-05	 0.006363	 0.0	 2106.89	 2106.89	 2106.89	 1.0	 0.0	 1	 -30.0	 30.0;
	40840	 40844	 7.5e-05	 0.005815	 0.0	 2092.36	 2092.36	 2092.36	 1.0	 0.0	 1	 -30.0	 30.0;
	40840	 40845	 0.0001	 0.008136	 0.0	 2004.92	 2004.92	 2004.92	 1.0	 0.0	 1	 -30.0	 30.0;
	40840	 40846	 0.00029	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40842	 40841	 0.000204	 0.014647	 0.0	 750.25	 750.25	 750.25	 1.00625	 0.0	 1	 -30.0	 30.0;
	40841	 40991	 5.7e-05	 0.001044	 0.12733	 2484.89	 2484.89	 2484.89	 0.0	 0.0	 1	 -30.0	 30.0;
	40841	 41003	 3.9e-05	 0.000776	 0.07912	 2486.57	 2486.57	 2486.57	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 40842	 0.004267	 0.02113	 0.03958	 200.38	 200.38	 200.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 40842	 0.004267	 0.02113	 0.03958	 200.38	 200.38	 200.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40996	 40842	 0.004267	 0.02113	 0.03958	 200.38	 200.38	 200.38	 0.0	 0.0	 1	 -30.0	 30.0;
	40846	 40898	 0.000268	 0.007414	 3.83572	 4049.42	 4049.42	 4049.42	 0.0	 0.0	 1	 -30.0	 30.0;
	40909	 40846	 6.6e-05	 0.001864	 1.01765	 4013.77	 4013.77	 4013.77	 0.0	 0.0	 1	 -30.0	 30.0;
	40846	 40956	 0.000123	 0.003314	 1.53689	 4016.9	 4016.9	 4016.9	 0.0	 0.0	 1	 -30.0	 30.0;
	40848	 40847	 0.000344	 0.020729	 0.0	 200.8	 200.8	 200.8	 1.00625	 0.0	 1	 -30.0	 30.0;
	40847	 40849	 0.000273	 0.017101	 0.0	 772.94	 772.94	 772.94	 1.0	 0.0	 1	 -30.0	 30.0;
	40847	 40850	 0.000132	 0.010131	 0.0	 772.33	 772.33	 772.33	 1.0	 0.0	 1	 -30.0	 30.0;
	40847	 40965	 0.000185	 0.003802	 0.39522	 2349.32	 2349.32	 2349.32	 0.0	 0.0	 1	 -30.0	 30.0;
	40975	 40848	 0.038593	 0.153096	 0.02494	 125.72	 125.72	 125.72	 0.0	 0.0	 1	 -30.0	 30.0;
	40848	 40990	 0.005464	 0.034252	 0.00769	 123.19	 123.19	 123.19	 0.0	 0.0	 1	 -30.0	 30.0;
	40852	 40851	 5.9e-05	 0.005271	 0.0	 1607.0	 1607.0	 1607.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	40852	 40851	 5.9e-05	 0.005271	 0.0	 1607.0	 1607.0	 1607.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	40852	 40851	 5.9e-05	 0.005271	 0.0	 1607.0	 1607.0	 1607.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	40851	 40854	 0.000134	 0.010184	 0.0	 1424.7	 1424.7	 1424.7	 1.0	 0.0	 1	 -30.0	 30.0;
	40851	 40855	 0.000162	 0.012107	 0.0	 1236.11	 1236.11	 1236.11	 1.0	 0.0	 1	 -30.0	 30.0;
	40851	 40856	 0.000132	 0.010342	 0.0	 1235.71	 1235.71	 1235.71	 1.0	 0.0	 1	 -30.0	 30.0;
	40851	 40857	 8.7e-05	 0.007875	 0.0	 1235.16	 1235.16	 1235.16	 1.0	 0.0	 1	 -30.0	 30.0;
	40851	 40858	 0.000183	 0.013043	 0.0	 954.16	 954.16	 954.16	 1.0	 0.0	 1	 -30.0	 30.0;
	40853	 40852	 0.00028	 0.01877	 0.0	 970.81	 970.81	 970.81	 1.03125	 0.0	 1	 -30.0	 30.0;
	40852	 40859	 0.000232	 0.018374	 0.0	 291.05	 291.05	 291.05	 1.04375	 0.0	 1	 -30.0	 30.0;
	40852	 40860	 0.000268	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40853	 40966	 0.002016	 0.007722	 0.00133	 260.26	 260.26	 260.26	 0.0	 0.0	 1	 -30.0	 30.0;
	40862	 40863	 0.041392	 1.04625	 0.0	 11.96	 11.96	 11.96	 1.04375	 0.0	 1	 -30.0	 30.0;
	40862	 40864	 0.000285	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40864	 40940	 0.001131	 0.005378	 0.00237	 209.14	 209.14	 209.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40864	 40940	 0.001131	 0.005378	 0.00237	 209.14	 209.14	 209.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40864	 40940	 0.001131	 0.005378	 0.00237	 209.14	 209.14	 209.14	 0.0	 0.0	 1	 -30.0	 30.0;
	40867	 40866	 0.000242	 0.017048	 0.0	 760.73	 760.73	 760.73	 1.00625	 0.0	 1	 -30.0	 30.0;
	40866	 40868	 9.1e-05	 0.005785	 0.0	 942.05	 942.05	 942.05	 1.0	 0.0	 1	 -30.0	 30.0;
	40866	 40869	 0.000197	 0.014129	 0.0	 925.46	 925.46	 925.46	 1.0	 0.0	 1	 -30.0	 30.0;
	40866	 40870	 0.0002	 0.014235	 0.0	 920.05	 920.05	 920.05	 1.0	 0.0	 1	 -30.0	 30.0;
	40866	 40890	 0.00014	 0.002616	 0.31607	 2196.97	 2196.97	 2196.97	 0.0	 0.0	 1	 -30.0	 30.0;
	40872	 40873	 0.015319	 0.343157	 0.0	 26.0	 26.0	 26.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40872	 40874	 0.000232	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40874	 40891	 0.011222	 0.054713	 0.03634	 187.83	 187.83	 187.83	 0.0	 0.0	 1	 -30.0	 30.0;
	40876	 40875	 0.000127	 0.009748	 0.0	 1503.14	 1503.14	 1503.14	 1.0	 0.0	 1	 -30.0	 30.0;
	40875	 40878	 0.000123	 0.009446	 0.0	 1769.13	 1769.13	 1769.13	 1.01875	 0.0	 1	 -30.0	 30.0;
	40875	 40879	 8.2e-05	 0.006691	 0.0	 1764.56	 1764.56	 1764.56	 1.0	 0.0	 1	 -30.0	 30.0;
	40875	 40880	 8.3e-05	 0.006501	 0.0	 1763.55	 1763.55	 1763.55	 1.01875	 0.0	 1	 -30.0	 30.0;
	40875	 40881	 0.000111	 0.008277	 0.0	 1762.46	 1762.46	 1762.46	 1.01875	 0.0	 1	 -30.0	 30.0;
	40875	 40882	 0.000249	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40877	 40876	 0.000184	 0.012522	 0.0	 686.96	 686.96	 686.96	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40884	 0.00124	 0.032337	 0.0	 268.23	 268.23	 268.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40885	 0.002132	 0.049311	 0.0	 268.23	 268.23	 268.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40886	 0.001465	 0.046605	 0.0	 268.23	 268.23	 268.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40887	 0.002333	 0.06153	 0.0	 268.23	 268.23	 268.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40888	 0.001494	 0.043889	 0.0	 268.23	 268.23	 268.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40889	 0.001752	 0.045049	 0.0	 268.23	 268.23	 268.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40883	 40958	 0.00024	 0.001115	 0.00016	 205.24	 205.24	 205.24	 0.0	 0.0	 1	 -30.0	 30.0;
	40883	 40958	 0.00024	 0.001115	 0.00016	 205.24	 205.24	 205.24	 0.0	 0.0	 1	 -30.0	 30.0;
	40883	 40958	 0.00024	 0.001115	 0.00016	 205.24	 205.24	 205.24	 0.0	 0.0	 1	 -30.0	 30.0;
	40891	 40890	 0.000122	 0.009162	 0.0	 913.72	 913.72	 913.72	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 40892	 0.000168	 0.012498	 0.0	 704.24	 704.24	 704.24	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 40893	 0.000254	 0.018961	 0.0	 697.18	 697.18	 697.18	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 40894	 0.000177	 0.013309	 0.0	 688.44	 688.44	 688.44	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 40895	 0.000147	 0.010548	 0.0	 687.28	 687.28	 687.28	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 40896	 0.000225	 0.013491	 0.0	 685.33	 685.33	 685.33	 1.0	 0.0	 1	 -30.0	 30.0;
	40890	 40897	 0.000163	 0.012026	 0.0	 684.92	 684.92	 684.92	 1.0	 0.0	 1	 -30.0	 30.0;
	40899	 40898	 0.00012	 0.009102	 0.0	 1775.27	 1775.27	 1775.27	 1.01875	 0.0	 1	 -30.0	 30.0;
	40899	 40898	 0.00012	 0.009102	 0.0	 1775.27	 1775.27	 1775.27	 1.01875	 0.0	 1	 -30.0	 30.0;
	40899	 40898	 0.00012	 0.009102	 0.0	 1775.27	 1775.27	 1775.27	 1.01875	 0.0	 1	 -30.0	 30.0;
	40898	 40903	 0.000146	 0.009959	 0.0	 1544.8	 1544.8	 1544.8	 0.9875	 0.0	 1	 -30.0	 30.0;
	40898	 40904	 6e-05	 0.004079	 0.0	 1543.4	 1543.4	 1543.4	 0.9875	 0.0	 1	 -30.0	 30.0;
	40898	 40905	 0.000111	 0.008607	 0.0	 1542.48	 1542.48	 1542.48	 0.9875	 0.0	 1	 -30.0	 30.0;
	40898	 40906	 0.000114	 0.009083	 0.0	 1540.69	 1540.69	 1540.69	 0.9875	 0.0	 1	 -30.0	 30.0;
	40898	 40907	 7.7e-05	 0.006219	 0.0	 1540.51	 1540.51	 1540.51	 0.9875	 0.0	 1	 -30.0	 30.0;
	40898	 40908	 8.8e-05	 0.007267	 0.0	 1538.19	 1538.19	 1538.19	 0.9875	 0.0	 1	 -30.0	 30.0;
	40898	 40938	 0.000537	 0.015133	 10.31353	 4170.11	 4170.11	 4170.11	 0.0	 0.0	 1	 -30.0	 30.0;
	40899	 40902	 0.000415	 0.029918	 0.0	 1083.46	 1083.46	 1083.46	 1.0	 0.0	 1	 -30.0	 30.0;
	40939	 40899	 0.000191	 0.003136	 0.30323	 2583.8	 2583.8	 2583.8	 0.0	 0.0	 1	 -30.0	 30.0;
	40900	 40902	 -0.000144	 -0.010367	 0.0	 1008.46	 1008.46	 1008.46	 1.0	 0.0	 1	 -30.0	 30.0;
	40901	 40902	 0.001515	 0.109234	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40910	 40909	 0.000118	 0.009529	 0.0	 1490.53	 1490.53	 1490.53	 1.00625	 0.0	 1	 -30.0	 30.0;
	40909	 40912	 0.000106	 0.007634	 0.0	 1536.34	 1536.34	 1536.34	 1.0625	 0.0	 1	 -30.0	 30.0;
	40909	 40913	 6.6e-05	 0.005323	 0.0	 1536.32	 1536.32	 1536.32	 1.05625	 0.0	 1	 -30.0	 30.0;
	40909	 40914	 9.5e-05	 0.008367	 0.0	 1535.89	 1535.89	 1535.89	 1.0	 0.0	 1	 -30.0	 30.0;
	40909	 40915	 5e-05	 0.004721	 0.0	 1533.61	 1533.61	 1533.61	 1.05625	 0.0	 1	 -30.0	 30.0;
	40909	 40916	 6.5e-05	 0.00534	 0.0	 1533.53	 1533.53	 1533.53	 1.05625	 0.0	 1	 -30.0	 30.0;
	40909	 40917	 6e-05	 0.005487	 0.0	 1531.93	 1531.93	 1531.93	 1.05625	 0.0	 1	 -30.0	 30.0;
	40911	 40910	 0.000274	 0.01388	 0.0	 525.0	 525.0	 525.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40910	 41003	 0.000215	 0.003994	 0.40915	 2619.42	 2619.42	 2619.42	 0.0	 0.0	 1	 -30.0	 30.0;
	41004	 40911	 0.008515	 0.031859	 0.01616	 156.12	 156.12	 156.12	 0.0	 0.0	 1	 -30.0	 30.0;
	40919	 40975	 0.00167	 0.006905	 0.00127	 135.56	 135.56	 135.56	 0.0	 0.0	 1	 -30.0	 30.0;
	40920	 40921	 0.032728	 0.696868	 0.0	 13.0	 13.0	 13.0	 1.025	 0.0	 1	 -30.0	 30.0;
	40923	 40922	 0.000173	 0.014437	 0.0	 582.53	 582.53	 582.53	 1.03125	 0.0	 1	 -30.0	 30.0;
	40922	 40924	 0.000186	 0.009891	 0.0	 999.45	 999.45	 999.45	 1.0	 0.0	 1	 -30.0	 30.0;
	40922	 40925	 0.000185	 0.01329	 0.0	 998.6	 998.6	 998.6	 1.0	 0.0	 1	 -30.0	 30.0;
	40922	 40926	 0.000176	 0.013179	 0.0	 997.77	 997.77	 997.77	 1.0	 0.0	 1	 -30.0	 30.0;
	40922	 40927	 0.000125	 0.009315	 0.0	 982.08	 982.08	 982.08	 1.0	 0.0	 1	 -30.0	 30.0;
	40922	 40928	 0.000249	 0.014804	 0.0	 981.56	 981.56	 981.56	 1.0	 0.0	 1	 -30.0	 30.0;
	40922	 40929	 0.000197	 0.015222	 0.0	 977.64	 977.64	 977.64	 1.0	 0.0	 1	 -30.0	 30.0;
	40922	 40930	 0.000242	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40922	 40930	 0.000242	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40930	 50453	 0.00156	 0.031046	 3.3028	 2985.64	 2985.64	 2985.64	 0.0	 0.0	 1	 -30.0	 30.0;
	40932	 40931	 0.000136	 0.01135	 0.0	 1437.54	 1437.54	 1437.54	 1.0	 0.0	 1	 -30.0	 30.0;
	40931	 40934	 5.3e-05	 0.004838	 0.0	 1637.52	 1637.52	 1637.52	 1.01875	 0.0	 1	 -30.0	 30.0;
	40931	 40935	 0.0001	 0.008303	 0.0	 1630.07	 1630.07	 1630.07	 1.025	 0.0	 1	 -30.0	 30.0;
	40931	 40936	 0.000103	 0.007988	 0.0	 1630.06	 1630.06	 1630.06	 1.025	 0.0	 1	 -30.0	 30.0;
	40931	 40937	 7.8e-05	 0.006253	 0.0	 1629.93	 1629.93	 1629.93	 1.01875	 0.0	 1	 -30.0	 30.0;
	40931	 40938	 0.000284	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40933	 40932	 0.000362	 0.023469	 0.0	 603.82	 603.82	 603.82	 1.0	 0.0	 1	 -30.0	 30.0;
	40932	 40947	 0.000269	 0.005515	 0.66511	 2404.76	 2404.76	 2404.76	 0.0	 0.0	 1	 -30.0	 30.0;
	40932	 40955	 0.001645	 0.02588	 3.8995	 2996.93	 2996.93	 2996.93	 0.0	 0.0	 1	 -30.0	 30.0;
	40939	 40942	 0.000389	 0.029098	 0.0	 1195.46	 1195.46	 1195.46	 1.0	 0.0	 1	 -30.0	 30.0;
	40939	 40943	 0.000178	 0.013159	 0.0	 748.13	 748.13	 748.13	 1.04375	 0.0	 1	 -30.0	 30.0;
	40939	 40944	 0.000178	 0.014223	 0.0	 748.04	 748.04	 748.04	 1.0	 0.0	 1	 -30.0	 30.0;
	40939	 40945	 0.000295	 0.022723	 0.0	 513.48	 513.48	 513.48	 1.0375	 0.0	 1	 -30.0	 30.0;
	40939	 40946	 0.000236	 0.018738	 0.0	 510.45	 510.45	 510.45	 1.0375	 0.0	 1	 -30.0	 30.0;
	40940	 40942	 -0.000235	 -0.017614	 0.0	 1070.46	 1070.46	 1070.46	 1.0	 0.0	 1	 -30.0	 30.0;
	40941	 40942	 0.000819	 0.061305	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40948	 40947	 0.000246	 0.016675	 0.0	 688.24	 688.24	 688.24	 1.0	 0.0	 1	 -30.0	 30.0;
	40949	 40954	 0.011072	 0.054697	 0.0136	 170.29	 170.29	 170.29	 0.0	 0.0	 1	 -30.0	 30.0;
	40950	 40951	 0.000246	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40950	 40952	 0.000253	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40954	 40953	 0.000115	 0.007818	 0.0	 981.68	 981.68	 981.68	 1.0125	 0.0	 1	 -30.0	 30.0;
	40953	 40955	 0.000292	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40957	 40956	 0.000101	 0.006613	 0.0	 1521.87	 1521.87	 1521.87	 1.0	 0.0	 1	 -30.0	 30.0;
	40956	 40959	 0.000137	 0.011137	 0.0	 1482.02	 1482.02	 1482.02	 1.0375	 0.0	 1	 -30.0	 30.0;
	40956	 40960	 8.2e-05	 0.006019	 0.0	 1481.93	 1481.93	 1481.93	 1.0375	 0.0	 1	 -30.0	 30.0;
	40956	 40961	 0.000119	 0.009066	 0.0	 1480.29	 1480.29	 1480.29	 1.0375	 0.0	 1	 -30.0	 30.0;
	40956	 40962	 0.000148	 0.011534	 0.0	 1477.72	 1477.72	 1477.72	 1.0	 0.0	 1	 -30.0	 30.0;
	40956	 40963	 0.000103	 0.009121	 0.0	 1477.71	 1477.71	 1477.71	 1.0375	 0.0	 1	 -30.0	 30.0;
	40956	 40964	 9.2e-05	 0.0069	 0.0	 1477.09	 1477.09	 1477.09	 1.0	 0.0	 1	 -30.0	 30.0;
	40958	 40957	 0.000143	 0.011077	 0.0	 618.51	 618.51	 618.51	 1.00625	 0.0	 1	 -30.0	 30.0;
	40957	 40965	 0.000261	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40968	 40967	 0.00033	 0.017382	 0.0	 645.55	 645.55	 645.55	 1.00625	 0.0	 1	 -30.0	 30.0;
	40967	 40969	 0.000227	 0.015816	 0.0	 867.1	 867.1	 867.1	 1.0	 0.0	 1	 -30.0	 30.0;
	40967	 40970	 0.000194	 0.016252	 0.0	 865.23	 865.23	 865.23	 1.0	 0.0	 1	 -30.0	 30.0;
	40967	 40971	 0.000186	 0.01589	 0.0	 862.53	 862.53	 862.53	 1.0	 0.0	 1	 -30.0	 30.0;
	40967	 40972	 0.000196	 0.013787	 0.0	 853.64	 853.64	 853.64	 1.0	 0.0	 1	 -30.0	 30.0;
	40967	 40973	 0.000278	 0.01868	 0.0	 841.36	 841.36	 841.36	 1.0	 0.0	 1	 -30.0	 30.0;
	40967	 40974	 0.000218	 0.015951	 0.0	 831.07	 831.07	 831.07	 1.0	 0.0	 1	 -30.0	 30.0;
	41003	 40967	 3.1e-05	 0.000554	 0.04152	 1882.01	 1882.01	 1882.01	 0.0	 0.0	 1	 -30.0	 30.0;
	40968	 40999	 0.000802	 0.003597	 0.00588	 170.49	 170.49	 170.49	 0.0	 0.0	 1	 -30.0	 30.0;
	40975	 40978	 -0.000315	 -0.008526	 0.0	 101.67	 101.67	 101.67	 1.0	 0.0	 1	 -30.0	 30.0;
	40976	 40978	 0.005795	 0.157082	 0.0	 50.83	 50.83	 50.83	 1.0	 0.0	 1	 -30.0	 30.0;
	40977	 40978	 0.005795	 0.157082	 0.0	 50.83	 50.83	 50.83	 1.0	 0.0	 1	 -30.0	 30.0;
	40980	 40979	 0.000122	 0.008513	 0.0	 1388.44	 1388.44	 1388.44	 1.00625	 0.0	 1	 -30.0	 30.0;
	40979	 40984	 8.2e-05	 0.007441	 0.0	 1409.15	 1409.15	 1409.15	 1.0	 0.0	 1	 -30.0	 30.0;
	40979	 40985	 0.000123	 0.010828	 0.0	 1408.07	 1408.07	 1408.07	 1.0	 0.0	 1	 -30.0	 30.0;
	40979	 40986	 0.000121	 0.007993	 0.0	 1406.95	 1406.95	 1406.95	 1.0	 0.0	 1	 -30.0	 30.0;
	40979	 40987	 9.7e-05	 0.007178	 0.0	 1405.04	 1405.04	 1405.04	 1.0	 0.0	 1	 -30.0	 30.0;
	40979	 40988	 0.000153	 0.01076	 0.0	 1404.34	 1404.34	 1404.34	 1.0	 0.0	 1	 -30.0	 30.0;
	40979	 40989	 6.5e-05	 0.005895	 0.0	 1404.27	 1404.27	 1404.27	 1.0	 0.0	 1	 -30.0	 30.0;
	40980	 40983	 0.000429	 0.026233	 0.0	 878.54	 878.54	 878.54	 1.0	 0.0	 1	 -30.0	 30.0;
	50453	 40980	 0.00138	 0.028123	 2.6176	 3111.74	 3111.74	 3111.74	 0.0	 0.0	 1	 -30.0	 30.0;
	40981	 40983	 -6.2e-05	 -0.00382	 0.0	 778.54	 778.54	 778.54	 1.0	 0.0	 1	 -30.0	 30.0;
	40982	 40983	 0.001743	 0.106587	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40990	 41016	 0.008631	 0.039602	 0.03841	 122.23	 122.23	 122.23	 0.0	 0.0	 1	 -30.0	 30.0;
	40992	 40991	 0.00019	 0.012097	 0.0	 677.7	 677.7	 677.7	 1.0	 0.0	 1	 -30.0	 30.0;
	40991	 40993	 8.8e-05	 0.00667	 0.0	 1087.75	 1087.75	 1087.75	 1.0	 0.0	 1	 -30.0	 30.0;
	40991	 40994	 0.000107	 0.006285	 0.0	 1078.87	 1078.87	 1078.87	 1.0	 0.0	 1	 -30.0	 30.0;
	40991	 40995	 0.000261	 0.01866	 0.0	 1077.66	 1077.66	 1077.66	 1.0	 0.0	 1	 -30.0	 30.0;
	40991	 41003	 3.4e-05	 0.000524	 0.03617	 2314.68	 2314.68	 2314.68	 0.0	 0.0	 1	 -30.0	 30.0;
	40999	 40998	 0.000164	 0.011889	 0.0	 714.89	 714.89	 714.89	 1.0125	 0.0	 1	 -30.0	 30.0;
	40998	 41000	 0.00012	 0.007461	 0.0	 1033.71	 1033.71	 1033.71	 1.0	 0.0	 1	 -30.0	 30.0;
	40998	 41001	 0.000198	 0.015273	 0.0	 1021.51	 1021.51	 1021.51	 1.0	 0.0	 1	 -30.0	 30.0;
	40998	 41002	 0.000171	 0.012907	 0.0	 1020.68	 1020.68	 1020.68	 1.0	 0.0	 1	 -30.0	 30.0;
	40998	 41003	 0.000277	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41004	 41005	 0.025954	 0.627421	 0.0	 19.5	 19.5	 19.5	 0.99375	 0.0	 1	 -30.0	 30.0;
	41007	 41006	 0.000141	 0.0099	 0.0	 744.09	 744.09	 744.09	 1.0	 0.0	 1	 -30.0	 30.0;
	41006	 41009	 0.000224	 0.014376	 0.0	 973.18	 973.18	 973.18	 1.0	 0.0	 1	 -30.0	 30.0;
	41006	 41010	 0.000192	 0.014218	 0.0	 971.79	 971.79	 971.79	 1.0	 0.0	 1	 -30.0	 30.0;
	41006	 41011	 0.000196	 0.013113	 0.0	 969.93	 969.93	 969.93	 1.0	 0.0	 1	 -30.0	 30.0;
	41006	 41012	 0.000286	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41008	 41007	 0.000333	 0.020069	 0.0	 404.75	 404.75	 404.75	 1.03125	 0.0	 1	 -30.0	 30.0;
	41008	 41017	 0.010453	 0.058477	 0.00926	 167.49	 167.49	 167.49	 0.0	 0.0	 1	 -30.0	 30.0;
	41013	 41014	 0.015826	 0.424993	 0.0	 24.7	 24.7	 24.7	 1.0	 0.0	 1	 -30.0	 30.0;
	41013	 41015	 0.000236	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50020	 50000	 0.020026	 0.113766	 0.08463	 283.78	 283.78	 283.78	 0.0	 0.0	 1	 -30.0	 30.0;
	50003	 50001	 0.002581	 0.01494	 0.02293	 281.35	 281.35	 281.35	 0.0	 0.0	 1	 -30.0	 30.0;
	50005	 50002	 0.003792	 0.024874	 0.00975	 288.56	 288.56	 288.56	 0.0	 0.0	 1	 -30.0	 30.0;
	50002	 50013	 0.004566	 0.028939	 0.03992	 294.15	 294.15	 294.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50003	 50004	 0.000283	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50013	 50003	 0.003315	 0.018744	 0.02228	 248.05	 248.05	 248.05	 0.0	 0.0	 1	 -30.0	 30.0;
	50015	 50003	 0.006786	 0.044951	 0.10759	 267.89	 267.89	 267.89	 0.0	 0.0	 1	 -30.0	 30.0;
	50003	 50016	 0.004638	 0.031418	 0.07166	 305.59	 305.59	 305.59	 0.0	 0.0	 1	 -30.0	 30.0;
	50005	 50010	 0.000706	 0.003989	 0.00249	 312.7	 312.7	 312.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50006	 50007	 0.000245	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50027	 50006	 0.015339	 0.105521	 0.09855	 219.25	 219.25	 219.25	 0.0	 0.0	 1	 -30.0	 30.0;
	50008	 50009	 0.000246	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50008	 50017	 0.007054	 0.036789	 0.06074	 202.45	 202.45	 202.45	 0.0	 0.0	 1	 -30.0	 30.0;
	50008	 50454	 0.00411	 0.023746	 0.01446	 263.32	 263.32	 263.32	 0.0	 0.0	 1	 -30.0	 30.0;
	50010	 50454	 0.001838	 0.01017	 0.03793	 337.69	 337.69	 337.69	 0.0	 0.0	 1	 -30.0	 30.0;
	50011	 50012	 0.000208	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50011	 50013	 0.000217	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50454	 50013	 0.002806	 0.017882	 0.01888	 302.7	 302.7	 302.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50014	 50015	 0.008273	 0.037295	 0.02536	 278.48	 278.48	 278.48	 0.0	 0.0	 1	 -30.0	 30.0;
	50015	 50021	 0.006233	 0.03231	 0.15401	 245.67	 245.67	 245.67	 0.0	 0.0	 1	 -30.0	 30.0;
	50015	 50039	 0.014462	 0.078517	 0.21009	 325.61	 325.61	 325.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50016	 50018	 0.005791	 0.039247	 0.1526	 311.9	 311.9	 311.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50017	 50021	 0.005133	 0.02808	 0.04003	 258.17	 258.17	 258.17	 0.0	 0.0	 1	 -30.0	 30.0;
	50020	 50018	 0.010009	 0.052796	 0.02487	 308.47	 308.47	 308.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50018	 50026	 0.00793	 0.048395	 0.04726	 301.27	 301.27	 301.27	 0.0	 0.0	 1	 -30.0	 30.0;
	50018	 50031	 0.0093	 0.065197	 0.09595	 256.64	 256.64	 256.64	 0.0	 0.0	 1	 -30.0	 30.0;
	50020	 50019	 0.000168	 0.0112	 0.0	 904.72	 904.72	 904.72	 1.0	 0.0	 1	 -30.0	 30.0;
	50019	 50388	 0.001425	 0.026986	 3.67097	 3024.12	 3024.12	 3024.12	 0.0	 0.0	 1	 -30.0	 30.0;
	50406	 50019	 0.000649	 0.012567	 1.31626	 2794.15	 2794.15	 2794.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50019	 50453	 0.000877	 0.014113	 1.41874	 3241.99	 3241.99	 3241.99	 0.0	 0.0	 1	 -30.0	 30.0;
	50026	 50020	 0.001867	 0.01207	 0.07126	 307.32	 307.32	 307.32	 0.0	 0.0	 1	 -30.0	 30.0;
	50022	 50021	 0.004478	 0.119856	 0.0	 116.4	 116.4	 116.4	 1.0	 0.0	 1	 -30.0	 30.0;
	50053	 50021	 0.018199	 0.095865	 0.17257	 275.97	 275.97	 275.97	 0.0	 0.0	 1	 -30.0	 30.0;
	50022	 50029	 0.039329	 0.177981	 0.02237	 155.8	 155.8	 155.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50023	 50024	 0.000292	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50023	 50052	 0.007425	 0.046953	 0.22402	 292.85	 292.85	 292.85	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 50023	 0.005467	 0.029792	 0.03142	 263.97	 263.97	 263.97	 0.0	 0.0	 1	 -30.0	 30.0;
	50023	 50422	 0.005926	 0.030104	 0.07045	 255.19	 255.19	 255.19	 0.0	 0.0	 1	 -30.0	 30.0;
	50025	 50026	 0.000226	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50027	 50050	 0.004829	 0.033496	 0.10036	 240.05	 240.05	 240.05	 0.0	 0.0	 1	 -30.0	 30.0;
	50451	 50027	 0.009068	 0.048871	 0.04787	 276.99	 276.99	 276.99	 0.0	 0.0	 1	 -30.0	 30.0;
	50029	 50028	 0.002888	 0.105268	 0.0	 101.18	 101.18	 101.18	 1.0	 0.0	 1	 -30.0	 30.0;
	50028	 50030	 0.000275	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50028	 50031	 0.00023	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50032	 50033	 0.000216	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50039	 50033	 0.013304	 0.088768	 0.09207	 291.89	 291.89	 291.89	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 50033	 0.005153	 0.024798	 0.02459	 298.1	 298.1	 298.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50035	 50034	 0.020222	 0.150703	 0.13417	 275.17	 275.17	 275.17	 0.0	 0.0	 1	 -30.0	 30.0;
	50384	 50034	 0.003507	 0.023062	 0.02626	 287.16	 287.16	 287.16	 0.0	 0.0	 1	 -30.0	 30.0;
	50035	 50050	 0.009427	 0.060944	 0.0458	 267.81	 267.81	 267.81	 0.0	 0.0	 1	 -30.0	 30.0;
	50047	 50036	 0.009428	 0.058794	 0.0946	 224.07	 224.07	 224.07	 0.0	 0.0	 1	 -30.0	 30.0;
	50058	 50036	 0.057597	 0.334567	 0.15127	 230.43	 230.43	 230.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50037	 50038	 0.000276	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50037	 50039	 0.000263	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50052	 50039	 0.009735	 0.052507	 0.07493	 288.96	 288.96	 288.96	 0.0	 0.0	 1	 -30.0	 30.0;
	50040	 50041	 0.000214	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50384	 50040	 0.012321	 0.064766	 0.14227	 293.22	 293.22	 293.22	 0.0	 0.0	 1	 -30.0	 30.0;
	50394	 50040	 0.010569	 0.067718	 0.10119	 284.73	 284.73	 284.73	 0.0	 0.0	 1	 -30.0	 30.0;
	50042	 50384	 0.007757	 0.042438	 0.03311	 268.66	 268.66	 268.66	 0.0	 0.0	 1	 -30.0	 30.0;
	50401	 50042	 0.008807	 0.054551	 0.18122	 267.79	 267.79	 267.79	 0.0	 0.0	 1	 -30.0	 30.0;
	50043	 50046	 0.006358	 0.167137	 0.0	 128.9	 128.9	 128.9	 1.0	 0.0	 1	 -30.0	 30.0;
	50043	 50047	 0.000278	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50043	 50048	 0.000236	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50044	 50046	 -0.00281	 -0.073871	 0.0	 78.9	 78.9	 78.9	 1.0	 0.0	 1	 -30.0	 30.0;
	74163	 50044	 0.024697	 0.115012	 0.04519	 210.08	 210.08	 210.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50045	 50046	 0.020207	 0.53118	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50047	 50378	 0.005418	 0.031151	 0.02241	 236.98	 236.98	 236.98	 0.0	 0.0	 1	 -30.0	 30.0;
	50050	 50049	 0.003515	 0.020991	 0.01596	 229.95	 229.95	 229.95	 0.0	 0.0	 1	 -30.0	 30.0;
	50067	 50049	 0.002896	 0.018507	 0.02255	 263.11	 263.11	 263.11	 0.0	 0.0	 1	 -30.0	 30.0;
	50050	 50051	 0.00025	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50070	 50053	 0.013919	 0.076328	 0.11222	 285.08	 285.08	 285.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50439	 50054	 0.00501	 0.032193	 0.01209	 261.19	 261.19	 261.19	 0.0	 0.0	 1	 -30.0	 30.0;
	50055	 50091	 0.000585	 0.003696	 0.00452	 223.23	 223.23	 223.23	 0.0	 0.0	 1	 -30.0	 30.0;
	50055	 50439	 0.002555	 0.01417	 0.00832	 264.49	 264.49	 264.49	 0.0	 0.0	 1	 -30.0	 30.0;
	50056	 50073	 0.009917	 0.052504	 0.03964	 239.79	 239.79	 239.79	 0.0	 0.0	 1	 -30.0	 30.0;
	50078	 50056	 0.00454	 0.025994	 0.01821	 221.43	 221.43	 221.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50063	 50057	 0.006454	 0.03634	 0.02378	 232.74	 232.74	 232.74	 0.0	 0.0	 1	 -30.0	 30.0;
	50057	 50394	 0.008797	 0.049869	 0.05389	 217.61	 217.61	 217.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50062	 50058	 0.001963	 0.011585	 0.00979	 235.08	 235.08	 235.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50060	 50059	 0.000197	 0.014054	 0.0	 556.78	 556.78	 556.78	 1.01875	 0.0	 1	 -30.0	 30.0;
	50059	 50068	 0.000212	 0.003599	 0.46445	 2296.44	 2296.44	 2296.44	 0.0	 0.0	 1	 -30.0	 30.0;
	50203	 50059	 0.000503	 0.008554	 0.97766	 2350.68	 2350.68	 2350.68	 0.0	 0.0	 1	 -30.0	 30.0;
	50061	 50060	 0.000223	 0.013172	 0.0	 574.93	 574.93	 574.93	 1.0125	 0.0	 1	 -30.0	 30.0;
	50061	 50060	 0.000223	 0.013172	 0.0	 574.93	 574.93	 574.93	 1.0125	 0.0	 1	 -30.0	 30.0;
	50060	 70122	 0.003585	 0.038927	 1.09964	 1288.08	 1288.08	 1288.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50081	 50061	 0.001528	 0.008175	 0.01574	 308.5	 308.5	 308.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50061	 50084	 0.002157	 0.012766	 0.00678	 269.66	 269.66	 269.66	 0.0	 0.0	 1	 -30.0	 30.0;
	50123	 50061	 0.002171	 0.013313	 0.00769	 291.19	 291.19	 291.19	 0.0	 0.0	 1	 -30.0	 30.0;
	50061	 50161	 0.002028	 0.011784	 0.02583	 292.09	 292.09	 292.09	 0.0	 0.0	 1	 -30.0	 30.0;
	50081	 50062	 0.002075	 0.011567	 0.01064	 280.81	 280.81	 280.81	 0.0	 0.0	 1	 -30.0	 30.0;
	50107	 50062	 0.002465	 0.013978	 0.00884	 240.08	 240.08	 240.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50063	 50064	 0.000208	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50063	 50248	 0.007967	 0.041522	 0.06889	 242.5	 242.5	 242.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50066	 50065	 0.000149	 0.009362	 0.0	 827.17	 827.17	 827.17	 1.00625	 0.0	 1	 -30.0	 30.0;
	50377	 50065	 0.000103	 0.001749	 0.1716	 2522.47	 2522.47	 2522.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50067	 50066	 0.000983	 0.005841	 0.00521	 283.79	 283.79	 283.79	 0.0	 0.0	 1	 -30.0	 30.0;
	50066	 50088	 0.000328	 0.001856	 0.00172	 312.27	 312.27	 312.27	 0.0	 0.0	 1	 -30.0	 30.0;
	50091	 50066	 0.001909	 0.013316	 0.0052	 260.79	 260.79	 260.79	 0.0	 0.0	 1	 -30.0	 30.0;
	50088	 50067	 0.001574	 0.009451	 0.00543	 236.46	 236.46	 236.46	 0.0	 0.0	 1	 -30.0	 30.0;
	50069	 50068	 0.00026	 0.017722	 0.0	 757.9	 757.9	 757.9	 1.0125	 0.0	 1	 -30.0	 30.0;
	50076	 50068	 0.000141	 0.002339	 0.21314	 2347.45	 2347.45	 2347.45	 0.0	 0.0	 1	 -30.0	 30.0;
	50163	 50068	 0.000175	 0.003516	 0.36427	 2491.16	 2491.16	 2491.16	 0.0	 0.0	 1	 -30.0	 30.0;
	50074	 50069	 0.003068	 0.020422	 0.01418	 257.29	 257.29	 257.29	 0.0	 0.0	 1	 -30.0	 30.0;
	50069	 50136	 0.002738	 0.019239	 0.00961	 281.24	 281.24	 281.24	 0.0	 0.0	 1	 -30.0	 30.0;
	50069	 50148	 0.001605	 0.008604	 0.01774	 239.3	 239.3	 239.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50070	 50279	 0.017488	 0.084458	 0.0494	 288.34	 288.34	 288.34	 0.0	 0.0	 1	 -30.0	 30.0;
	50071	 50072	 0.000236	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50071	 50073	 0.000284	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50197	 50073	 0.005113	 0.036524	 0.02998	 252.07	 252.07	 252.07	 0.0	 0.0	 1	 -30.0	 30.0;
	50073	 50378	 0.002719	 0.020161	 0.01188	 199.16	 199.16	 199.16	 0.0	 0.0	 1	 -30.0	 30.0;
	50074	 50075	 0.000288	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50074	 50181	 0.003366	 0.021884	 0.06336	 260.19	 260.19	 260.19	 0.0	 0.0	 1	 -30.0	 30.0;
	50077	 50076	 0.00016	 0.009785	 0.0	 912.95	 912.95	 912.95	 1.00625	 0.0	 1	 -30.0	 30.0;
	50076	 50438	 0.000447	 0.007915	 1.07103	 2359.48	 2359.48	 2359.48	 0.0	 0.0	 1	 -30.0	 30.0;
	50108	 50077	 0.000755	 0.004818	 0.00558	 301.73	 301.73	 301.73	 0.0	 0.0	 1	 -30.0	 30.0;
	50077	 50111	 0.00091	 0.005252	 0.00373	 303.48	 303.48	 303.48	 0.0	 0.0	 1	 -30.0	 30.0;
	50135	 50077	 0.001651	 0.010951	 0.01141	 279.49	 279.49	 279.49	 0.0	 0.0	 1	 -30.0	 30.0;
	50078	 50205	 0.003974	 0.02819	 0.0441	 273.29	 273.29	 273.29	 0.0	 0.0	 1	 -30.0	 30.0;
	50079	 50080	 0.000283	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50079	 50081	 0.000281	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50082	 50083	 0.000281	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50082	 50084	 0.000285	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50084	 50120	 0.001604	 0.008832	 0.01204	 205.21	 205.21	 205.21	 0.0	 0.0	 1	 -30.0	 30.0;
	50085	 50086	 0.000201	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50085	 50087	 0.000269	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50100	 50086	 0.001275	 0.008006	 0.00554	 253.46	 253.46	 253.46	 0.0	 0.0	 1	 -30.0	 30.0;
	50439	 50086	 0.002606	 0.016196	 0.02523	 288.9	 288.9	 288.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50088	 50092	 0.002503	 0.01396	 0.01062	 279.83	 279.83	 279.83	 0.0	 0.0	 1	 -30.0	 30.0;
	50089	 50090	 0.00027	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50089	 50091	 0.000227	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50092	 50130	 0.001888	 0.011188	 0.00798	 259.61	 259.61	 259.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50092	 50137	 0.000941	 0.006045	 0.01558	 271.96	 271.96	 271.96	 0.0	 0.0	 1	 -30.0	 30.0;
	50093	 50094	 0.000298	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50093	 50122	 0.00171	 0.014065	 0.00671	 229.71	 229.71	 229.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50201	 50093	 0.005735	 0.030236	 0.03834	 238.73	 238.73	 238.73	 0.0	 0.0	 1	 -30.0	 30.0;
	50097	 50095	 0.000518	 0.003894	 0.0026	 252.67	 252.67	 252.67	 0.0	 0.0	 1	 -30.0	 30.0;
	50111	 50095	 0.000804	 0.005515	 0.02722	 295.47	 295.47	 295.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50096	 50097	 0.000254	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50097	 50125	 0.000706	 0.003981	 0.00541	 267.13	 267.13	 267.13	 0.0	 0.0	 1	 -30.0	 30.0;
	50099	 50098	 0.000194	 0.013806	 0.0	 846.22	 846.22	 846.22	 1.0125	 0.0	 1	 -30.0	 30.0;
	50116	 50098	 0.000114	 0.002068	 0.20372	 2540.94	 2540.94	 2540.94	 0.0	 0.0	 1	 -30.0	 30.0;
	50099	 50100	 0.002037	 0.01197	 0.00478	 269.52	 269.52	 269.52	 0.0	 0.0	 1	 -30.0	 30.0;
	50099	 50189	 0.000397	 0.002756	 0.00191	 329.02	 329.02	 329.02	 0.0	 0.0	 1	 -30.0	 30.0;
	50100	 50101	 0.000273	 0.001113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50102	 50134	 0.002417	 0.013799	 0.017	 243.31	 243.31	 243.31	 0.0	 0.0	 1	 -30.0	 30.0;
	50102	 50444	 0.001167	 0.007105	 0.00331	 298.5	 298.5	 298.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50103	 50129	 0.001304	 0.006914	 0.02813	 280.89	 280.89	 280.89	 0.0	 0.0	 1	 -30.0	 30.0;
	50103	 50137	 0.000462	 0.003187	 0.00252	 204.2	 204.2	 204.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50104	 50226	 0.007514	 0.044282	 0.04212	 263.52	 263.52	 263.52	 0.0	 0.0	 1	 -30.0	 30.0;
	50233	 50104	 0.004756	 0.026631	 0.02569	 227.94	 227.94	 227.94	 0.0	 0.0	 1	 -30.0	 30.0;
	50105	 50106	 0.000223	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50105	 50107	 0.000208	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50123	 50107	 0.001905	 0.00958	 0.00585	 250.66	 250.66	 250.66	 0.0	 0.0	 1	 -30.0	 30.0;
	50108	 50109	 0.000282	 0.00103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50108	 50111	 0.000253	 0.001702	 0.00143	 255.96	 255.96	 255.96	 0.0	 0.0	 1	 -30.0	 30.0;
	50110	 50111	 0.000246	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50112	 50113	 0.000273	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50371	 50112	 0.001261	 0.009328	 0.00553	 260.56	 260.56	 260.56	 0.0	 0.0	 1	 -30.0	 30.0;
	50439	 50112	 0.002399	 0.013639	 0.00773	 239.11	 239.11	 239.11	 0.0	 0.0	 1	 -30.0	 30.0;
	50114	 50115	 0.000285	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50130	 50114	 0.001628	 0.010268	 0.01174	 298.34	 298.34	 298.34	 0.0	 0.0	 1	 -30.0	 30.0;
	50114	 50236	 0.005782	 0.033825	 0.32611	 286.94	 286.94	 286.94	 0.0	 0.0	 1	 -30.0	 30.0;
	50114	 50260	 0.002902	 0.01788	 0.13107	 295.86	 295.86	 295.86	 0.0	 0.0	 1	 -30.0	 30.0;
	50116	 50119	 0.000297	 0.021256	 0.0	 871.39	 871.39	 871.39	 1.0	 0.0	 1	 -30.0	 30.0;
	50116	 50176	 0.000218	 0.003819	 0.34196	 2600.23	 2600.23	 2600.23	 0.0	 0.0	 1	 -30.0	 30.0;
	50116	 50263	 0.000166	 0.002949	 0.3562	 2540.47	 2540.47	 2540.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50116	 50356	 0.000263	 0.004477	 0.62196	 2624.3	 2624.3	 2624.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50377	 50116	 9.9e-05	 0.001868	 0.29637	 2710.17	 2710.17	 2710.17	 0.0	 0.0	 1	 -30.0	 30.0;
	50117	 50119	 -6.2e-05	 -0.004451	 0.0	 821.39	 821.39	 821.39	 1.0	 0.0	 1	 -30.0	 30.0;
	50117	 50129	 0.000279	 0.001735	 0.00154	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50117	 50169	 0.000966	 0.00563	 0.004	 238.12	 238.12	 238.12	 0.0	 0.0	 1	 -30.0	 30.0;
	50117	 50437	 0.001666	 0.009603	 0.02361	 250.62	 250.62	 250.62	 0.0	 0.0	 1	 -30.0	 30.0;
	50118	 50119	 0.001251	 0.089432	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50120	 50195	 0.008207	 0.042779	 0.03696	 246.94	 246.94	 246.94	 0.0	 0.0	 1	 -30.0	 30.0;
	50121	 50122	 0.00025	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50122	 50208	 0.003317	 0.019925	 0.02328	 237.91	 237.91	 237.91	 0.0	 0.0	 1	 -30.0	 30.0;
	50123	 50124	 0.000287	 0.001178	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50136	 50125	 0.00083	 0.005099	 0.00246	 238.91	 238.91	 238.91	 0.0	 0.0	 1	 -30.0	 30.0;
	50125	 50161	 0.005057	 0.032348	 0.02618	 246.02	 246.02	 246.02	 0.0	 0.0	 1	 -30.0	 30.0;
	50126	 50139	 0.000972	 0.005964	 0.00437	 254.4	 254.4	 254.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50189	 50126	 0.000663	 0.004222	 0.00669	 303.71	 303.71	 303.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50127	 50128	 0.000296	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 50127	 0.001056	 0.005324	 0.0084	 228.83	 228.83	 228.83	 0.0	 0.0	 1	 -30.0	 30.0;
	50127	 50153	 0.001459	 0.009404	 0.00948	 291.52	 291.52	 291.52	 0.0	 0.0	 1	 -30.0	 30.0;
	50127	 50170	 0.000498	 0.002954	 0.00277	 230.65	 230.65	 230.65	 0.0	 0.0	 1	 -30.0	 30.0;
	50129	 50151	 0.000607	 0.004558	 0.00202	 291.87	 291.87	 291.87	 0.0	 0.0	 1	 -30.0	 30.0;
	50131	 50132	 0.000291	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50131	 50133	 0.000209	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50133	 50134	 0.001145	 0.006799	 0.00961	 268.55	 268.55	 268.55	 0.0	 0.0	 1	 -30.0	 30.0;
	50172	 50133	 0.000579	 0.003755	 0.00709	 288.63	 288.63	 288.63	 0.0	 0.0	 1	 -30.0	 30.0;
	50133	 50180	 0.002935	 0.017035	 0.02258	 262.23	 262.23	 262.23	 0.0	 0.0	 1	 -30.0	 30.0;
	50369	 50133	 0.000595	 0.003149	 0.00368	 279.49	 279.49	 279.49	 0.0	 0.0	 1	 -30.0	 30.0;
	50134	 50148	 0.00254	 0.013998	 0.13896	 252.3	 252.3	 252.3	 0.0	 0.0	 1	 -30.0	 30.0;
	50135	 50162	 0.00242	 0.016076	 0.02336	 236.33	 236.33	 236.33	 0.0	 0.0	 1	 -30.0	 30.0;
	50137	 50138	 0.000241	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50139	 50187	 0.001094	 0.007193	 0.02863	 262.84	 262.84	 262.84	 0.0	 0.0	 1	 -30.0	 30.0;
	50200	 50139	 0.001049	 0.005293	 0.0056	 228.72	 228.72	 228.72	 0.0	 0.0	 1	 -30.0	 30.0;
	50195	 50140	 0.005925	 0.037286	 0.02361	 239.85	 239.85	 239.85	 0.0	 0.0	 1	 -30.0	 30.0;
	50140	 50205	 0.004244	 0.018521	 0.06876	 270.31	 270.31	 270.31	 0.0	 0.0	 1	 -30.0	 30.0;
	50140	 50208	 0.00552	 0.030013	 0.01938	 241.95	 241.95	 241.95	 0.0	 0.0	 1	 -30.0	 30.0;
	50140	 50265	 0.004171	 0.025407	 0.03566	 223.41	 223.41	 223.41	 0.0	 0.0	 1	 -30.0	 30.0;
	50141	 50142	 0.000273	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50141	 50143	 0.000204	 0.001095	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50166	 50143	 0.000695	 0.004252	 0.00759	 237.29	 237.29	 237.29	 0.0	 0.0	 1	 -30.0	 30.0;
	50143	 50178	 0.003213	 0.017437	 0.01873	 284.95	 284.95	 284.95	 0.0	 0.0	 1	 -30.0	 30.0;
	50144	 50145	 0.000254	 0.001175	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50144	 50146	 0.000221	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50156	 50145	 0.001494	 0.008729	 0.03321	 253.27	 253.27	 253.27	 0.0	 0.0	 1	 -30.0	 30.0;
	50145	 50169	 0.005115	 0.0284	 0.02527	 279.38	 279.38	 279.38	 0.0	 0.0	 1	 -30.0	 30.0;
	50145	 50401	 0.005365	 0.038182	 0.31164	 334.38	 334.38	 334.38	 0.0	 0.0	 1	 -30.0	 30.0;
	50164	 50147	 0.001749	 0.011265	 0.00868	 227.11	 227.11	 227.11	 0.0	 0.0	 1	 -30.0	 30.0;
	50147	 50444	 0.003364	 0.019068	 0.01452	 239.65	 239.65	 239.65	 0.0	 0.0	 1	 -30.0	 30.0;
	50149	 50150	 0.000279	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50149	 50270	 0.003799	 0.021924	 0.02872	 258.31	 258.31	 258.31	 0.0	 0.0	 1	 -30.0	 30.0;
	50149	 50276	 0.010675	 0.051356	 0.15087	 265.85	 265.85	 265.85	 0.0	 0.0	 1	 -30.0	 30.0;
	50151	 50152	 0.000221	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50151	 50170	 0.00063	 0.003639	 0.00222	 240.99	 240.99	 240.99	 0.0	 0.0	 1	 -30.0	 30.0;
	50153	 50154	 0.000226	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50153	 50371	 0.001006	 0.006834	 0.00403	 315.36	 315.36	 315.36	 0.0	 0.0	 1	 -30.0	 30.0;
	50155	 50181	 0.001012	 0.006326	 0.0141	 248.09	 248.09	 248.09	 0.0	 0.0	 1	 -30.0	 30.0;
	50155	 50258	 0.003447	 0.018596	 0.04927	 275.81	 275.81	 275.81	 0.0	 0.0	 1	 -30.0	 30.0;
	50155	 50300	 0.007455	 0.044962	 0.14239	 285.64	 285.64	 285.64	 0.0	 0.0	 1	 -30.0	 30.0;
	50411	 50155	 0.001377	 0.00739	 0.00646	 276.8	 276.8	 276.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50156	 50159	 -0.000173	 -0.006475	 0.0	 181.02	 181.02	 181.02	 1.0	 0.0	 1	 -30.0	 30.0;
	50156	 50160	 0.000203	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50177	 50156	 0.000888	 0.005135	 0.00379	 275.5	 275.5	 275.5	 0.0	 0.0	 1	 -30.0	 30.0;
	50156	 50179	 0.003023	 0.016887	 0.01632	 266.46	 266.46	 266.46	 0.0	 0.0	 1	 -30.0	 30.0;
	50157	 50159	 0.003515	 0.131314	 0.0	 90.51	 90.51	 90.51	 1.0	 0.0	 1	 -30.0	 30.0;
	50158	 50159	 0.003515	 0.131314	 0.0	 90.51	 90.51	 90.51	 1.0	 0.0	 1	 -30.0	 30.0;
	50258	 50162	 0.00344	 0.020502	 0.04282	 243.61	 243.61	 243.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50164	 50163	 0.00022	 0.015957	 0.0	 774.07	 774.07	 774.07	 1.0125	 0.0	 1	 -30.0	 30.0;
	50239	 50163	 0.000281	 0.005215	 0.4992	 2501.61	 2501.61	 2501.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50445	 50163	 0.000202	 0.002788	 0.33491	 2402.1	 2402.1	 2402.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50164	 50171	 0.000153	 0.001055	 0.00078	 329.23	 329.23	 329.23	 0.0	 0.0	 1	 -30.0	 30.0;
	50185	 50165	 0.00164	 0.009736	 0.00453	 213.52	 213.52	 213.52	 0.0	 0.0	 1	 -30.0	 30.0;
	50165	 50245	 0.001322	 0.006848	 0.01886	 246.2	 246.2	 246.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50215	 50166	 0.001187	 0.007559	 0.00472	 233.43	 233.43	 233.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50167	 50371	 0.00322	 0.019889	 0.01347	 254.09	 254.09	 254.09	 0.0	 0.0	 1	 -30.0	 30.0;
	50444	 50167	 0.001673	 0.010415	 0.00692	 240.84	 240.84	 240.84	 0.0	 0.0	 1	 -30.0	 30.0;
	50168	 50187	 0.002013	 0.010038	 0.01682	 278.71	 278.71	 278.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50210	 50168	 0.000427	 0.002567	 0.00283	 316.67	 316.67	 316.67	 0.0	 0.0	 1	 -30.0	 30.0;
	50171	 50411	 0.000216	 0.001207	 0.00233	 307.72	 307.72	 307.72	 0.0	 0.0	 1	 -30.0	 30.0;
	50444	 50172	 0.000602	 0.004152	 0.00243	 303.97	 303.97	 303.97	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 50173	 0.002855	 0.017518	 0.01315	 239.93	 239.93	 239.93	 0.0	 0.0	 1	 -30.0	 30.0;
	50378	 50173	 0.003951	 0.023662	 0.01408	 213.97	 213.97	 213.97	 0.0	 0.0	 1	 -30.0	 30.0;
	50174	 50175	 0.000254	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50179	 50175	 0.000837	 0.004885	 0.00207	 262.15	 262.15	 262.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50175	 50264	 0.00085	 0.005975	 0.01267	 238.06	 238.06	 238.06	 0.0	 0.0	 1	 -30.0	 30.0;
	50177	 50176	 0.000195	 0.012897	 0.0	 875.91	 875.91	 875.91	 1.00625	 0.0	 1	 -30.0	 30.0;
	50176	 50356	 9.8e-05	 0.001654	 0.22013	 2402.8	 2402.8	 2402.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50176	 50428	 0.000338	 0.005877	 0.56701	 2752.94	 2752.94	 2752.94	 0.0	 0.0	 1	 -30.0	 30.0;
	50177	 50178	 0.001414	 0.009712	 0.02093	 308.72	 308.72	 308.72	 0.0	 0.0	 1	 -30.0	 30.0;
	50177	 50257	 0.003495	 0.01998	 0.02452	 283.37	 283.37	 283.37	 0.0	 0.0	 1	 -30.0	 30.0;
	50178	 50179	 0.000461	 0.003129	 0.00717	 213.37	 213.37	 213.37	 0.0	 0.0	 1	 -30.0	 30.0;
	50179	 50235	 0.00269	 0.015513	 0.0268	 274.16	 274.16	 274.16	 0.0	 0.0	 1	 -30.0	 30.0;
	50230	 50180	 0.001788	 0.010683	 0.01118	 232.14	 232.14	 232.14	 0.0	 0.0	 1	 -30.0	 30.0;
	50181	 50411	 0.001443	 0.009367	 0.00753	 282.93	 282.93	 282.93	 0.0	 0.0	 1	 -30.0	 30.0;
	50182	 50183	 0.000257	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50198	 50182	 0.005486	 0.032163	 0.02184	 246.92	 246.92	 246.92	 0.0	 0.0	 1	 -30.0	 30.0;
	50182	 50277	 0.005206	 0.030347	 0.0458	 264.71	 264.71	 264.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50187	 50184	 0.001044	 0.005821	 0.00752	 257.36	 257.36	 257.36	 0.0	 0.0	 1	 -30.0	 30.0;
	50184	 50244	 0.003337	 0.018385	 0.01986	 266.55	 266.55	 266.55	 0.0	 0.0	 1	 -30.0	 30.0;
	50184	 50293	 0.004282	 0.02683	 0.07967	 252.72	 252.72	 252.72	 0.0	 0.0	 1	 -30.0	 30.0;
	50219	 50185	 0.000774	 0.005652	 0.0025	 207.18	 207.18	 207.18	 0.0	 0.0	 1	 -30.0	 30.0;
	50437	 50185	 0.000895	 0.005495	 0.00569	 266.46	 266.46	 266.46	 0.0	 0.0	 1	 -30.0	 30.0;
	50228	 50186	 0.000472	 0.003125	 0.00461	 274.4	 274.4	 274.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50245	 50186	 0.000908	 0.005354	 0.00956	 234.14	 234.14	 234.14	 0.0	 0.0	 1	 -30.0	 30.0;
	50187	 50188	 0.000223	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50190	 50191	 0.000213	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50190	 50192	 0.000247	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50192	 50200	 0.002663	 0.014496	 0.0353	 258.66	 258.66	 258.66	 0.0	 0.0	 1	 -30.0	 30.0;
	50192	 50245	 0.000289	 0.002	 0.00151	 298.27	 298.27	 298.27	 0.0	 0.0	 1	 -30.0	 30.0;
	50193	 50194	 0.00023	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50193	 50195	 0.000279	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50275	 50195	 0.003793	 0.022567	 0.02313	 234.58	 234.58	 234.58	 0.0	 0.0	 1	 -30.0	 30.0;
	50196	 50197	 0.000239	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50197	 74320	 0.020826	 0.126629	 0.06226	 257.52	 257.52	 257.52	 0.0	 0.0	 1	 -30.0	 30.0;
	50198	 50199	 0.000271	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50198	 50226	 0.005042	 0.027295	 0.0363	 299.65	 299.65	 299.65	 0.0	 0.0	 1	 -30.0	 30.0;
	50401	 50198	 0.004258	 0.020668	 0.01606	 281.83	 281.83	 281.83	 0.0	 0.0	 1	 -30.0	 30.0;
	50201	 50202	 0.000248	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50220	 50201	 0.002199	 0.012388	 0.01615	 273.15	 273.15	 273.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 50201	 0.002794	 0.014499	 0.01876	 240.15	 240.15	 240.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50203	 50207	 0.000365	 0.024164	 0.0	 847.81	 847.81	 847.81	 1.0	 -20.0	 1	 -30.0	 30.0;
	50205	 50204	 0.000419	 0.023376	 0.0	 496.37	 496.37	 496.37	 1.0	 0.0	 1	 -30.0	 30.0;
	50204	 50207	 -5e-05	 -0.00329	 0.0	 747.81	 747.81	 747.81	 1.0	 0.0	 1	 -30.0	 30.0;
	70122	 50204	 0.003394	 0.042389	 0.71506	 1177.3	 1177.3	 1177.3	 0.0	 0.0	 1	 -30.0	 30.0;
	74317	 50204	 0.002474	 0.029929	 0.59582	 1057.89	 1057.89	 1057.89	 0.0	 0.0	 1	 -30.0	 30.0;
	50204	 74325	 0.003465	 0.040008	 2.72644	 1164.12	 1164.12	 1164.12	 0.0	 0.0	 1	 -30.0	 30.0;
	50218	 50205	 0.002233	 0.01413	 0.00731	 236.28	 236.28	 236.28	 0.0	 0.0	 1	 -30.0	 30.0;
	50227	 50205	 0.001773	 0.012726	 0.0068	 292.97	 292.97	 292.97	 0.0	 0.0	 1	 -30.0	 30.0;
	50206	 50207	 0.001617	 0.107248	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50209	 50212	 -1.8e-05	 -0.001409	 0.0	 1050.88	 1050.88	 1050.88	 1.0	 0.0	 1	 -30.0	 30.0;
	50209	 50213	 0.000202	 0.001037	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50209	 50214	 0.000201	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50210	 50212	 0.000184	 0.014479	 0.0	 900.88	 900.88	 900.88	 1.0	 0.0	 1	 -30.0	 30.0;
	50219	 50210	 0.002058	 0.01346	 0.01008	 269.78	 269.78	 269.78	 0.0	 0.0	 1	 -30.0	 30.0;
	50210	 50245	 0.000647	 0.004039	 0.00934	 320.9	 320.9	 320.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50211	 50212	 0.001063	 0.083846	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50239	 50214	 0.000207	 0.002838	 0.21393	 2003.06	 2003.06	 2003.06	 0.0	 0.0	 1	 -30.0	 30.0;
	50263	 50214	 0.000104	 0.002021	 0.25031	 2635.28	 2635.28	 2635.28	 0.0	 0.0	 1	 -30.0	 30.0;
	50215	 50264	 0.002319	 0.014802	 0.03655	 292.34	 292.34	 292.34	 0.0	 0.0	 1	 -30.0	 30.0;
	50216	 50225	 0.005728	 0.032444	 0.02178	 241.61	 241.61	 241.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50216	 50248	 0.006322	 0.040412	 0.15917	 305.43	 305.43	 305.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50216	 50303	 0.010157	 0.058561	 0.08658	 295.39	 295.39	 295.39	 0.0	 0.0	 1	 -30.0	 30.0;
	50220	 50217	 0.001821	 0.011074	 0.01921	 287.52	 287.52	 287.52	 0.0	 0.0	 1	 -30.0	 30.0;
	50265	 50217	 0.004314	 0.024247	 0.01473	 249.43	 249.43	 249.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50217	 50275	 0.009562	 0.066333	 0.05935	 239.82	 239.82	 239.82	 0.0	 0.0	 1	 -30.0	 30.0;
	50217	 70123	 0.010817	 0.061985	 0.36888	 320.47	 320.47	 320.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50221	 50218	 0.003579	 0.024919	 0.02586	 278.69	 278.69	 278.69	 0.0	 0.0	 1	 -30.0	 30.0;
	50221	 50224	 0.008937	 0.218535	 0.0	 243.0	 243.0	 243.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50297	 50221	 0.005668	 0.030655	 0.08221	 257.8	 257.8	 257.8	 0.0	 0.0	 1	 -30.0	 30.0;
	50222	 50224	 -0.003088	 -0.075506	 0.0	 83.8	 83.8	 83.8	 1.0	 0.0	 1	 -30.0	 30.0;
	74187	 50222	 0.010632	 0.065619	 0.02687	 214.4	 214.4	 214.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50223	 50224	 0.035589	 0.87024	 0.0	 159.2	 159.2	 159.2	 1.0	 0.0	 1	 -30.0	 30.0;
	50225	 50303	 0.015837	 0.106038	 0.09076	 253.36	 253.36	 253.36	 0.0	 0.0	 1	 -30.0	 30.0;
	50226	 50236	 0.003143	 0.019883	 0.01041	 233.55	 233.55	 233.55	 0.0	 0.0	 1	 -30.0	 30.0;
	50228	 50264	 0.001476	 0.010981	 0.03542	 294.34	 294.34	 294.34	 0.0	 0.0	 1	 -30.0	 30.0;
	50229	 50230	 0.000245	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50229	 50231	 0.00028	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50229	 50232	 0.000219	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50247	 50230	 0.004266	 0.024253	 0.01988	 246.26	 246.26	 246.26	 0.0	 0.0	 1	 -30.0	 30.0;
	50289	 50230	 0.005981	 0.027481	 0.02156	 254.76	 254.76	 254.76	 0.0	 0.0	 1	 -30.0	 30.0;
	50233	 50234	 0.002427	 0.013765	 0.0118	 232.49	 232.49	 232.49	 0.0	 0.0	 1	 -30.0	 30.0;
	50233	 50250	 0.003745	 0.022298	 0.02946	 252.72	 252.72	 252.72	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 50234	 0.002227	 0.010709	 0.00883	 219.47	 219.47	 219.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50357	 50234	 0.001172	 0.007025	 0.00873	 263.71	 263.71	 263.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50235	 50282	 0.002616	 0.013878	 0.03132	 293.34	 293.34	 293.34	 0.0	 0.0	 1	 -30.0	 30.0;
	50236	 50401	 0.005244	 0.036363	 0.01772	 310.55	 310.55	 310.55	 0.0	 0.0	 1	 -30.0	 30.0;
	50237	 50238	 0.000215	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50254	 50237	 0.001817	 0.012901	 0.02044	 222.44	 222.44	 222.44	 0.0	 0.0	 1	 -30.0	 30.0;
	50261	 50237	 0.003294	 0.014405	 0.00764	 261.49	 261.49	 261.49	 0.0	 0.0	 1	 -30.0	 30.0;
	50240	 50239	 0.000155	 0.013638	 0.0	 815.63	 815.63	 815.63	 1.0125	 0.0	 1	 -30.0	 30.0;
	50239	 50241	 0.000282	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50239	 50435	 0.000905	 0.015379	 1.74519	 2935.73	 2935.73	 2935.73	 0.0	 0.0	 1	 -30.0	 30.0;
	50240	 50244	 0.001567	 0.009087	 0.00865	 298.34	 298.34	 298.34	 0.0	 0.0	 1	 -30.0	 30.0;
	50240	 50247	 0.001933	 0.01364	 0.00756	 301.16	 301.16	 301.16	 0.0	 0.0	 1	 -30.0	 30.0;
	50289	 50240	 0.001789	 0.010707	 0.00942	 295.88	 295.88	 295.88	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 50242	 0.001723	 0.010238	 0.00703	 246.37	 246.37	 246.37	 0.0	 0.0	 1	 -30.0	 30.0;
	50242	 50251	 0.003944	 0.022601	 0.03207	 292.49	 292.49	 292.49	 0.0	 0.0	 1	 -30.0	 30.0;
	50243	 50282	 0.002748	 0.0154	 0.05584	 242.15	 242.15	 242.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50245	 50246	 0.000288	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50268	 50248	 0.009099	 0.063445	 0.02705	 296.71	 296.71	 296.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50248	 50270	 0.004852	 0.033834	 0.08641	 251.9	 251.9	 251.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50250	 50249	 0.000469	 0.002818	 0.00371	 246.76	 246.76	 246.76	 0.0	 0.0	 1	 -30.0	 30.0;
	50249	 50267	 0.005395	 0.03142	 0.07211	 286.73	 286.73	 286.73	 0.0	 0.0	 1	 -30.0	 30.0;
	50253	 50250	 0.002156	 0.013706	 0.00786	 265.95	 265.95	 265.95	 0.0	 0.0	 1	 -30.0	 30.0;
	50251	 50252	 0.00026	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50251	 50425	 0.000803	 0.004726	 0.00352	 319.04	 319.04	 319.04	 0.0	 0.0	 1	 -30.0	 30.0;
	50253	 50425	 0.002728	 0.015501	 0.01106	 301.64	 301.64	 301.64	 0.0	 0.0	 1	 -30.0	 30.0;
	50254	 50257	 0.001553	 0.010236	 0.04291	 274.66	 274.66	 274.66	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 50254	 0.003388	 0.022193	 0.03932	 227.08	 227.08	 227.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50255	 50256	 0.000219	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50255	 50257	 0.000224	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50257	 50261	 0.000538	 0.003547	 0.00324	 235.76	 235.76	 235.76	 0.0	 0.0	 1	 -30.0	 30.0;
	50264	 50257	 0.000552	 0.003353	 0.00296	 277.24	 277.24	 277.24	 0.0	 0.0	 1	 -30.0	 30.0;
	50258	 50259	 0.000201	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50357	 50260	 0.000137	 0.000941	 0.00105	 323.47	 323.47	 323.47	 0.0	 0.0	 1	 -30.0	 30.0;
	50261	 50262	 0.000241	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50264	 50261	 0.000649	 0.003276	 0.00759	 294.9	 294.9	 294.9	 0.0	 0.0	 1	 -30.0	 30.0;
	50264	 50263	 0.000203	 0.012501	 0.0	 936.13	 936.13	 936.13	 1.01875	 0.0	 1	 -30.0	 30.0;
	50284	 50263	 0.000179	 0.003274	 0.35046	 2548.31	 2548.31	 2548.31	 0.0	 0.0	 1	 -30.0	 30.0;
	50356	 50263	 0.00014	 0.002511	 0.34014	 2542.73	 2542.73	 2542.73	 0.0	 0.0	 1	 -30.0	 30.0;
	50263	 50428	 0.000377	 0.00695	 0.72104	 2743.2	 2743.2	 2743.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50265	 50266	 0.000255	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50267	 50272	 0.004149	 0.024137	 0.0483	 289.75	 289.75	 289.75	 0.0	 0.0	 1	 -30.0	 30.0;
	50267	 50295	 0.008397	 0.041382	 0.03055	 251.33	 251.33	 251.33	 0.0	 0.0	 1	 -30.0	 30.0;
	50296	 50267	 0.004984	 0.031256	 0.02531	 256.78	 256.78	 256.78	 0.0	 0.0	 1	 -30.0	 30.0;
	50267	 50310	 0.009978	 0.051324	 0.15476	 298.97	 298.97	 298.97	 0.0	 0.0	 1	 -30.0	 30.0;
	50268	 50269	 0.000273	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50279	 50268	 0.007926	 0.040767	 0.32752	 292.69	 292.69	 292.69	 0.0	 0.0	 1	 -30.0	 30.0;
	50270	 50271	 0.000262	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50272	 50274	 0.002077	 0.011142	 0.02146	 290.4	 290.4	 290.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50272	 50317	 0.022212	 0.108743	 0.18714	 261.27	 261.27	 261.27	 0.0	 0.0	 1	 -30.0	 30.0;
	50273	 50274	 0.000267	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50274	 50280	 0.002867	 0.016994	 0.04189	 208.08	 208.08	 208.08	 0.0	 0.0	 1	 -30.0	 30.0;
	50285	 50274	 0.001456	 0.009795	 0.00662	 244.45	 244.45	 244.45	 0.0	 0.0	 1	 -30.0	 30.0;
	50276	 50287	 0.005668	 0.031911	 0.01595	 276.81	 276.81	 276.81	 0.0	 0.0	 1	 -30.0	 30.0;
	50277	 50278	 0.000238	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50298	 50277	 0.004538	 0.024627	 0.03082	 275.98	 275.98	 275.98	 0.0	 0.0	 1	 -30.0	 30.0;
	50282	 50280	 0.000748	 0.005091	 0.00366	 277.95	 277.95	 277.95	 0.0	 0.0	 1	 -30.0	 30.0;
	50282	 50281	 0.000242	 0.016794	 0.0	 765.91	 765.91	 765.91	 1.0125	 0.0	 1	 -30.0	 30.0;
	50281	 50283	 0.00028	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50281	 50284	 0.000206	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50294	 50282	 0.003248	 0.019594	 0.00871	 247.42	 247.42	 247.42	 0.0	 0.0	 1	 -30.0	 30.0;
	50356	 50284	 0.000146	 0.00226	 0.34603	 2262.43	 2262.43	 2262.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50284	 50446	 0.000965	 0.015143	 1.96286	 2988.44	 2988.44	 2988.44	 0.0	 0.0	 1	 -30.0	 30.0;
	50285	 50286	 0.000202	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50285	 50294	 0.002702	 0.01666	 0.01242	 212.7	 212.7	 212.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50287	 50288	 0.00026	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50287	 50301	 0.004343	 0.024724	 0.06033	 293.72	 293.72	 293.72	 0.0	 0.0	 1	 -30.0	 30.0;
	50290	 50291	 0.000253	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50290	 50292	 0.000245	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50292	 50299	 0.004966	 0.030062	 0.03016	 240.03	 240.03	 240.03	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 50293	 0.004294	 0.029606	 0.0377	 276.09	 276.09	 276.09	 0.0	 0.0	 1	 -30.0	 30.0;
	50295	 50415	 0.019717	 0.088797	 0.12025	 287.48	 287.48	 287.48	 0.0	 0.0	 1	 -30.0	 30.0;
	50296	 50401	 0.003618	 0.027617	 0.12615	 264.76	 264.76	 264.76	 0.0	 0.0	 1	 -30.0	 30.0;
	70123	 50297	 0.020685	 0.118501	 0.09973	 264.64	 264.64	 264.64	 0.0	 0.0	 1	 -30.0	 30.0;
	50306	 50298	 0.008114	 0.050633	 0.10029	 281.55	 281.55	 281.55	 0.0	 0.0	 1	 -30.0	 30.0;
	50299	 50302	 0.002134	 0.015735	 0.0249	 285.7	 285.7	 285.7	 0.0	 0.0	 1	 -30.0	 30.0;
	50431	 50300	 0.019143	 0.129384	 0.09352	 295.28	 295.28	 295.28	 0.0	 0.0	 1	 -30.0	 30.0;
	50301	 50309	 0.005026	 0.028745	 0.07976	 295.87	 295.87	 295.87	 0.0	 0.0	 1	 -30.0	 30.0;
	50302	 50308	 0.007363	 0.048281	 0.0321	 319.67	 319.67	 319.67	 0.0	 0.0	 1	 -30.0	 30.0;
	50303	 50396	 0.00361	 0.020659	 0.03928	 312.87	 312.87	 312.87	 0.0	 0.0	 1	 -30.0	 30.0;
	50304	 50305	 0.000265	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50304	 50306	 0.000253	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50304	 50307	 0.000208	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50447	 50306	 0.00386	 0.023628	 0.0214	 289.87	 289.87	 289.87	 0.0	 0.0	 1	 -30.0	 30.0;
	50308	 50314	 0.005286	 0.034174	 0.14979	 264.91	 264.91	 264.91	 0.0	 0.0	 1	 -30.0	 30.0;
	50308	 50321	 0.016468	 0.114565	 0.07328	 265.26	 265.26	 265.26	 0.0	 0.0	 1	 -30.0	 30.0;
	50308	 50325	 0.016604	 0.102593	 0.13567	 275.83	 275.83	 275.83	 0.0	 0.0	 1	 -30.0	 30.0;
	50396	 50309	 0.001781	 0.00887	 0.01141	 298.39	 298.39	 298.39	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 50311	 0.000201	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50310	 50415	 0.004403	 0.030686	 0.01911	 304.86	 304.86	 304.86	 0.0	 0.0	 1	 -30.0	 30.0;
	50313	 50312	 0.005121	 0.039386	 0.02169	 228.36	 228.36	 228.36	 0.0	 0.0	 1	 -30.0	 30.0;
	50312	 50368	 0.007972	 0.042928	 0.03578	 239.02	 239.02	 239.02	 0.0	 0.0	 1	 -30.0	 30.0;
	50313	 50319	 0.003895	 0.025129	 0.03399	 212.45	 212.45	 212.45	 0.0	 0.0	 1	 -30.0	 30.0;
	50313	 50447	 0.003283	 0.022316	 0.11105	 232.71	 232.71	 232.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50315	 50314	 0.003291	 0.116875	 0.0	 87.48	 87.48	 87.48	 1.0	 0.0	 1	 -30.0	 30.0;
	50314	 50316	 0.000212	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50314	 50431	 0.009282	 0.053214	 0.02015	 273.11	 273.11	 273.11	 0.0	 0.0	 1	 -30.0	 30.0;
	50315	 70169	 0.010689	 0.048761	 0.02094	 219.1	 219.1	 219.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50317	 50318	 0.000222	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50317	 50326	 0.017389	 0.113289	 0.04355	 271.32	 271.32	 271.32	 0.0	 0.0	 1	 -30.0	 30.0;
	50319	 50368	 0.005982	 0.034538	 0.02129	 220.67	 220.67	 220.67	 0.0	 0.0	 1	 -30.0	 30.0;
	50320	 50321	 0.000282	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50321	 50324	 0.006077	 0.041227	 0.03319	 269.78	 269.78	 269.78	 0.0	 0.0	 1	 -30.0	 30.0;
	50322	 50323	 0.000295	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 50322	 0.026623	 0.157799	 0.07272	 253.81	 253.81	 253.81	 0.0	 0.0	 1	 -30.0	 30.0;
	50322	 50368	 0.015188	 0.107055	 0.07348	 260.1	 260.1	 260.1	 0.0	 0.0	 1	 -30.0	 30.0;
	50324	 50327	 0.007106	 0.049105	 0.03262	 236.39	 236.39	 236.39	 0.0	 0.0	 1	 -30.0	 30.0;
	50324	 50381	 0.017968	 0.105562	 0.12799	 279.6	 279.6	 279.6	 0.0	 0.0	 1	 -30.0	 30.0;
	50330	 50325	 0.00847	 0.04881	 0.02228	 278.43	 278.43	 278.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50326	 50327	 0.008338	 0.052081	 0.05102	 276.04	 276.04	 276.04	 0.0	 0.0	 1	 -30.0	 30.0;
	50327	 50328	 0.000284	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50327	 50341	 0.003115	 0.018111	 0.20593	 295.2	 295.2	 295.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50329	 50330	 0.000249	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50341	 50330	 0.003077	 0.021547	 0.05814	 280.25	 280.25	 280.25	 0.0	 0.0	 1	 -30.0	 30.0;
	50332	 50331	 0.003713	 0.10501	 0.0	 114.97	 114.97	 114.97	 1.0	 0.0	 1	 -30.0	 30.0;
	50331	 50333	 0.000283	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50331	 50352	 0.010902	 0.063638	 0.06091	 258.38	 258.38	 258.38	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 50334	 0.003113	 0.080479	 0.0	 71.22	 71.22	 71.22	 1.0	 0.0	 1	 -30.0	 30.0;
	50334	 50336	 0.000273	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50334	 50338	 0.027787	 0.162667	 0.09985	 276.55	 276.55	 276.55	 0.0	 0.0	 1	 -30.0	 30.0;
	50334	 50349	 0.009824	 0.062595	 0.05184	 267.43	 267.43	 267.43	 0.0	 0.0	 1	 -30.0	 30.0;
	50339	 50335	 0.080013	 0.260966	 0.08256	 144.07	 144.07	 144.07	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 50346	 0.031877	 0.165031	 0.01994	 136.89	 136.89	 136.89	 0.0	 0.0	 1	 -30.0	 30.0;
	50335	 60029	 0.068667	 0.308474	 0.06519	 133.15	 133.15	 133.15	 0.0	 0.0	 1	 -30.0	 30.0;
	50338	 50337	 0.000186	 0.011755	 0.0	 625.37	 625.37	 625.37	 1.0	 0.0	 1	 -30.0	 30.0;
	50337	 50367	 0.002255	 0.037725	 3.91429	 2177.86	 2177.86	 2177.86	 0.0	 0.0	 1	 -30.0	 30.0;
	50339	 50338	 0.00309	 0.086905	 0.0	 132.03	 132.03	 132.03	 1.0	 0.0	 1	 -30.0	 30.0;
	50340	 50343	 0.000382	 0.03325	 0.0	 888.03	 888.03	 888.03	 1.0	 0.0	 1	 -30.0	 30.0;
	50380	 50340	 0.000683	 0.009422	 0.94322	 2704.03	 2704.03	 2704.03	 0.0	 0.0	 1	 -30.0	 30.0;
	50340	 50458	 0.000288	 0.005426	 0.63129	 2487.21	 2487.21	 2487.21	 0.0	 0.0	 1	 -30.0	 30.0;
	50341	 50343	 -0.000226	 -0.019736	 0.0	 737.13	 737.13	 737.13	 1.0	 0.0	 1	 -30.0	 30.0;
	50344	 50341	 0.001841	 0.012505	 0.00553	 230.86	 230.86	 230.86	 0.0	 0.0	 1	 -30.0	 30.0;
	50341	 50354	 0.010073	 0.061772	 0.08335	 305.03	 305.03	 305.03	 0.0	 0.0	 1	 -30.0	 30.0;
	50342	 50343	 0.000854	 0.074435	 0.0	 150.9	 150.9	 150.9	 1.0	 0.0	 1	 -30.0	 30.0;
	50344	 50459	 0.006726	 0.045382	 0.0731	 236.93	 236.93	 236.93	 0.0	 0.0	 1	 -30.0	 30.0;
	50345	 50348	 -0.000759	 -0.023303	 0.0	 158.5	 158.5	 158.5	 1.0	 0.0	 1	 -30.0	 30.0;
	50345	 50349	 0.000243	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50345	 50350	 0.000244	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50345	 50351	 0.000247	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50346	 50348	 0.003787	 0.11623	 0.0	 58.5	 58.5	 58.5	 1.0	 0.0	 1	 -30.0	 30.0;
	50347	 50348	 0.015029	 0.461217	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50349	 50352	 0.008052	 0.043901	 0.12679	 267.92	 267.92	 267.92	 0.0	 0.0	 1	 -30.0	 30.0;
	50353	 50352	 0.004399	 0.146148	 0.0	 85.55	 85.55	 85.55	 1.00625	 0.0	 1	 -30.0	 30.0;
	50352	 60010	 0.017791	 0.102786	 0.0469	 214.11	 214.11	 214.11	 0.0	 0.0	 1	 -30.0	 30.0;
	50352	 60736	 0.059616	 0.326273	 0.13665	 241.38	 241.38	 241.38	 0.0	 0.0	 1	 -30.0	 30.0;
	50354	 50355	 0.000255	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50381	 50354	 0.010089	 0.047861	 0.04772	 282.99	 282.99	 282.99	 0.0	 0.0	 1	 -30.0	 30.0;
	50356	 50359	 0.000374	 0.027453	 0.0	 801.0	 801.0	 801.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50360	 0.000218	 0.015426	 0.0	 1066.62	 1066.62	 1066.62	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50361	 0.000176	 0.012078	 0.0	 1063.74	 1063.74	 1063.74	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50362	 0.000164	 0.012424	 0.0	 1060.01	 1060.01	 1060.01	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50363	 0.000127	 0.010031	 0.0	 1053.8	 1053.8	 1053.8	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50364	 0.000143	 0.009219	 0.0	 1047.95	 1047.95	 1047.95	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50365	 0.000238	 0.014909	 0.0	 1033.82	 1033.82	 1033.82	 1.0	 0.0	 1	 -30.0	 30.0;
	50356	 50366	 0.001642	 0.12274	 0.0	 82.31	 82.31	 82.31	 1.0	 0.0	 1	 -30.0	 30.0;
	50357	 50359	 -0.000108	 -0.00793	 0.0	 751.0	 751.0	 751.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50358	 50359	 0.001496	 0.109731	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50368	 50367	 0.000227	 0.019281	 0.0	 632.39	 632.39	 632.39	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 50367	 0.000648	 0.01024	 1.33007	 2436.22	 2436.22	 2436.22	 0.0	 0.0	 1	 -30.0	 30.0;
	50367	 50414	 0.000444	 0.006658	 0.70794	 2404.87	 2404.87	 2404.87	 0.0	 0.0	 1	 -30.0	 30.0;
	50444	 50369	 0.001856	 0.009624	 0.00387	 268.82	 268.82	 268.82	 0.0	 0.0	 1	 -30.0	 30.0;
	50370	 50373	 0.000501	 0.030982	 0.0	 848.1	 848.1	 848.1	 1.0	 0.0	 1	 -30.0	 30.0;
	50370	 50374	 0.000288	 0.022823	 0.0	 630.46	 630.46	 630.46	 1.01875	 0.0	 1	 -30.0	 30.0;
	50370	 50375	 0.000278	 0.017221	 0.0	 627.49	 627.49	 627.49	 1.01875	 0.0	 1	 -30.0	 30.0;
	50370	 50376	 0.000468	 0.037032	 0.0	 415.83	 415.83	 415.83	 1.01875	 0.0	 1	 -30.0	 30.0;
	50370	 50377	 0.000268	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50371	 50373	 -0.000274	 -0.016985	 0.0	 773.1	 773.1	 773.1	 1.0	 0.0	 1	 -30.0	 30.0;
	50372	 50373	 0.001148	 0.071026	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50438	 50377	 0.000102	 0.001872	 0.15413	 2317.71	 2317.71	 2317.71	 0.0	 0.0	 1	 -30.0	 30.0;
	50377	 50452	 0.000578	 0.010263	 0.98258	 1974.2	 1974.2	 1974.2	 0.0	 0.0	 1	 -30.0	 30.0;
	50378	 50379	 0.002063	 0.065974	 0.0	 132.35	 132.35	 132.35	 1.0	 0.0	 1	 -30.0	 30.0;
	50381	 50380	 0.000197	 0.014919	 0.0	 669.0	 669.0	 669.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50380	 50382	 0.000118	 0.009309	 0.0	 1161.56	 1161.56	 1161.56	 1.0	 0.0	 1	 -30.0	 30.0;
	50384	 50383	 0.000202	 0.011959	 0.0	 853.39	 853.39	 853.39	 1.0	 0.0	 1	 -30.0	 30.0;
	50383	 50385	 0.000126	 0.010193	 0.0	 1349.86	 1349.86	 1349.86	 1.0	 0.0	 1	 -30.0	 30.0;
	50383	 50386	 0.000109	 0.008045	 0.0	 1307.04	 1307.04	 1307.04	 1.0	 0.0	 1	 -30.0	 30.0;
	50383	 50388	 0.000223	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50383	 50388	 0.000223	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50384	 50387	 0.002121	 0.081679	 0.0	 77.36	 77.36	 77.36	 1.05	 0.0	 1	 -30.0	 30.0;
	50384	 50401	 0.007455	 0.047378	 0.23953	 326.14	 326.14	 326.14	 0.0	 0.0	 1	 -30.0	 30.0;
	50406	 50388	 0.001232	 0.019664	 1.51382	 2971.09	 2971.09	 2971.09	 0.0	 0.0	 1	 -30.0	 30.0;
	50389	 50390	 0.0017	 0.04616	 0.0	 145.61	 145.61	 145.61	 1.0	 0.0	 1	 -30.0	 30.0;
	50389	 50391	 0.006001	 0.198276	 0.0	 72.09	 72.09	 72.09	 1.0	 0.0	 1	 -30.0	 30.0;
	50389	 50394	 0.003933	 0.024218	 0.06021	 298.44	 298.44	 298.44	 0.0	 0.0	 1	 -30.0	 30.0;
	50392	 50393	 0.001234	 0.047129	 0.0	 123.62	 123.62	 123.62	 1.04375	 0.0	 1	 -30.0	 30.0;
	50392	 50394	 0.000231	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50396	 50395	 0.000179	 0.012376	 0.0	 780.55	 780.55	 780.55	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 50397	 6.5e-05	 0.005066	 0.0	 1190.01	 1190.01	 1190.01	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 50398	 0.00017	 0.011916	 0.0	 1186.85	 1186.85	 1186.85	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 50399	 0.00014	 0.009887	 0.0	 1169.24	 1169.24	 1169.24	 1.0	 0.0	 1	 -30.0	 30.0;
	50395	 50414	 0.000548	 0.010426	 0.96263	 2622.48	 2622.48	 2622.48	 0.0	 0.0	 1	 -30.0	 30.0;
	50395	 50446	 0.000189	 0.003151	 0.37868	 3173.4	 3173.4	 3173.4	 0.0	 0.0	 1	 -30.0	 30.0;
	50401	 50400	 0.000163	 0.014311	 0.0	 789.25	 789.25	 789.25	 1.00625	 0.0	 1	 -30.0	 30.0;
	50400	 50402	 0.000191	 0.014314	 0.0	 944.93	 944.93	 944.93	 1.01875	 0.0	 1	 -30.0	 30.0;
	50400	 50403	 0.000167	 0.011237	 0.0	 943.17	 943.17	 943.17	 1.01875	 0.0	 1	 -30.0	 30.0;
	50400	 50404	 0.000139	 0.009633	 0.0	 943.14	 943.14	 943.14	 1.01875	 0.0	 1	 -30.0	 30.0;
	50400	 50405	 0.000297	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50405	 50428	 0.000304	 0.005131	 0.4314	 2713.76	 2713.76	 2713.76	 0.0	 0.0	 1	 -30.0	 30.0;
	50407	 50406	 0.000306	 0.016983	 0.0	 576.82	 576.82	 576.82	 1.0	 0.0	 1	 -30.0	 30.0;
	50406	 50409	 0.000157	 0.011255	 0.0	 916.04	 916.04	 916.04	 1.0375	 0.0	 1	 -30.0	 30.0;
	50406	 50446	 0.001446	 0.026666	 3.51579	 2908.44	 2908.44	 2908.44	 0.0	 0.0	 1	 -30.0	 30.0;
	50406	 50453	 0.00139	 0.022177	 3.95983	 3217.61	 3217.61	 3217.61	 0.0	 0.0	 1	 -30.0	 30.0;
	50408	 50407	 0.000387	 0.025709	 0.0	 296.15	 296.15	 296.15	 0.9875	 0.0	 1	 -30.0	 30.0;
	50407	 50410	 0.000261	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50422	 50408	 0.001581	 0.010601	 0.01384	 228.58	 228.58	 228.58	 0.0	 0.0	 1	 -30.0	 30.0;
	50411	 50412	 0.0042	 0.133083	 0.0	 79.98	 79.98	 79.98	 0.9875	 0.0	 1	 -30.0	 30.0;
	50411	 50413	 0.023149	 0.652963	 0.0	 30.0	 30.0	 30.0	 0.9875	 0.0	 1	 -30.0	 30.0;
	50414	 50417	 0.000123	 0.009999	 0.0	 873.74	 873.74	 873.74	 1.0	 0.0	 1	 -30.0	 30.0;
	50414	 50418	 0.000318	 0.017473	 0.0	 724.37	 724.37	 724.37	 1.0	 0.0	 1	 -30.0	 30.0;
	50414	 50419	 0.000229	 0.017255	 0.0	 715.0	 715.0	 715.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50414	 50428	 0.000801	 0.012064	 1.44911	 2929.38	 2929.38	 2929.38	 0.0	 0.0	 1	 -30.0	 30.0;
	50415	 50417	 3.3e-05	 0.002694	 0.0	 748.74	 748.74	 748.74	 1.0	 0.0	 1	 -30.0	 30.0;
	50416	 50417	 0.000891	 0.072616	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50420	 50421	 0.001907	 0.057032	 0.0	 193.93	 193.93	 193.93	 1.0625	 0.0	 1	 -30.0	 30.0;
	50420	 50422	 0.000219	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50420	 50423	 0.000268	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50424	 50427	 0.000642	 0.05073	 0.0	 886.83	 886.83	 886.83	 1.0	 0.0	 1	 -30.0	 30.0;
	50424	 50428	 0.000286	 0.001186	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50425	 50427	 -0.000461	 -0.036408	 0.0	 786.83	 786.83	 786.83	 1.0	 0.0	 1	 -30.0	 30.0;
	50426	 50427	 0.000918	 0.072501	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50430	 50429	 0.000246	 0.016358	 0.0	 716.42	 716.42	 716.42	 1.0	 0.0	 1	 -30.0	 30.0;
	50429	 50433	 0.000139	 0.011495	 0.0	 780.56	 780.56	 780.56	 1.05	 0.0	 1	 -30.0	 30.0;
	50429	 50434	 0.000599	 0.039151	 0.0	 223.69	 223.69	 223.69	 1.0	 0.0	 1	 -30.0	 30.0;
	50429	 50435	 0.000232	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50431	 50430	 0.000537	 0.030928	 0.0	 411.38	 411.38	 411.38	 1.0	 0.0	 1	 -30.0	 30.0;
	50430	 50436	 0.000285	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50432	 50431	 0.002366	 0.084382	 0.0	 87.3	 87.3	 87.3	 1.0	 0.0	 1	 -30.0	 30.0;
	70130	 50432	 0.003629	 0.020488	 0.00599	 216.29	 216.29	 216.29	 0.0	 0.0	 1	 -30.0	 30.0;
	50458	 50435	 0.000967	 0.0159	 1.63979	 2621.93	 2621.93	 2621.93	 0.0	 0.0	 1	 -30.0	 30.0;
	70122	 50436	 0.001602	 0.019023	 0.36254	 1082.51	 1082.51	 1082.51	 0.0	 0.0	 1	 -30.0	 30.0;
	50436	 70157	 0.004278	 0.051625	 1.14108	 1257.13	 1257.13	 1257.13	 0.0	 0.0	 1	 -30.0	 30.0;
	50439	 50438	 0.000201	 0.014351	 0.0	 753.89	 753.89	 753.89	 1.0	 0.0	 1	 -30.0	 30.0;
	50438	 50440	 0.000238	 0.019672	 0.0	 649.41	 649.41	 649.41	 1.01875	 0.0	 1	 -30.0	 30.0;
	50438	 50441	 0.000234	 0.016217	 0.0	 641.16	 641.16	 641.16	 1.01875	 0.0	 1	 -30.0	 30.0;
	50438	 50442	 0.00069	 0.050761	 0.0	 299.21	 299.21	 299.21	 1.01875	 0.0	 1	 -30.0	 30.0;
	50444	 50443	 0.000179	 0.012621	 0.0	 849.19	 849.19	 849.19	 1.00625	 0.0	 1	 -30.0	 30.0;
	50443	 50445	 0.000276	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50447	 50446	 0.000229	 0.014871	 0.0	 652.35	 652.35	 652.35	 1.00625	 0.0	 1	 -30.0	 30.0;
	50446	 50448	 0.000139	 0.011943	 0.0	 1164.08	 1164.08	 1164.08	 1.025	 0.0	 1	 -30.0	 30.0;
	50446	 50449	 0.000182	 0.013408	 0.0	 1161.9	 1161.9	 1161.9	 1.0	 0.0	 1	 -30.0	 30.0;
	50451	 50450	 0.000187	 0.013312	 0.0	 359.01	 359.01	 359.01	 1.0	 0.0	 1	 -30.0	 30.0;
	50450	 50452	 0.0002	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	50453	 50456	 -7.3e-05	 -0.004929	 0.0	 1008.94	 1008.94	 1008.94	 1.0	 0.0	 1	 -30.0	 30.0;
	50453	 50457	 0.000226	 0.018653	 0.0	 612.1	 612.1	 612.1	 1.0	 0.0	 1	 -30.0	 30.0;
	50454	 50456	 0.000291	 0.019785	 0.0	 883.94	 883.94	 883.94	 1.0	 0.0	 1	 -30.0	 30.0;
	50455	 50456	 0.001284	 0.087197	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50459	 50458	 0.000133	 0.009395	 0.0	 448.54	 448.54	 448.54	 1.0	 0.0	 1	 -30.0	 30.0;
	50460	 50459	 0.004261	 0.137247	 0.0	 75.79	 75.79	 75.79	 1.0	 0.0	 1	 -30.0	 30.0;
	70017	 50460	 0.027168	 0.150596	 0.08188	 186.89	 186.89	 186.89	 0.0	 0.0	 1	 -30.0	 30.0;
	53000	 53004	 0.04553	 0.225653	 0.03495	 152.03	 152.03	 152.03	 0.0	 0.0	 1	 -30.0	 30.0;
	53013	 53000	 0.052039	 0.215506	 0.0501	 128.63	 128.63	 128.63	 0.0	 0.0	 1	 -30.0	 30.0;
	53001	 53002	 0.000214	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53006	 53001	 0.010579	 0.050367	 0.0211	 172.32	 172.32	 172.32	 0.0	 0.0	 1	 -30.0	 30.0;
	53001	 53007	 0.046773	 0.147007	 0.04766	 156.67	 156.67	 156.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60578	 53001	 0.132573	 0.434748	 0.08643	 150.89	 150.89	 150.89	 0.0	 0.0	 1	 -30.0	 30.0;
	53003	 53019	 0.034168	 0.122048	 0.05168	 139.27	 139.27	 139.27	 0.0	 0.0	 1	 -30.0	 30.0;
	53003	 53021	 0.047854	 0.215511	 0.04556	 143.4	 143.4	 143.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53004	 53020	 0.024614	 0.100708	 0.07458	 177.66	 177.66	 177.66	 0.0	 0.0	 1	 -30.0	 30.0;
	53022	 53004	 0.017799	 0.05688	 0.03381	 154.43	 154.43	 154.43	 0.0	 0.0	 1	 -30.0	 30.0;
	53005	 53006	 0.000213	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53014	 53006	 0.007837	 0.028657	 0.00639	 164.34	 164.34	 164.34	 0.0	 0.0	 1	 -30.0	 30.0;
	53020	 53006	 0.011342	 0.057735	 0.01073	 188.04	 188.04	 188.04	 0.0	 0.0	 1	 -30.0	 30.0;
	53007	 53014	 0.021551	 0.108635	 0.04016	 174.45	 174.45	 174.45	 0.0	 0.0	 1	 -30.0	 30.0;
	53007	 60155	 0.02038	 0.097919	 0.02166	 188.2	 188.2	 188.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53007	 60578	 0.095071	 0.339538	 0.08	 141.64	 141.64	 141.64	 0.0	 0.0	 1	 -30.0	 30.0;
	53008	 53009	 0.00021	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53009	 53013	 0.024787	 0.101866	 0.02981	 138.82	 138.82	 138.82	 0.0	 0.0	 1	 -30.0	 30.0;
	53009	 53030	 0.033729	 0.148713	 0.05465	 144.93	 144.93	 144.93	 0.0	 0.0	 1	 -30.0	 30.0;
	53010	 53011	 0.000253	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53010	 53012	 0.011315	 0.045557	 0.0222	 139.8	 139.8	 139.8	 0.0	 0.0	 1	 -30.0	 30.0;
	53019	 53010	 0.01093	 0.054356	 0.01161	 147.47	 147.47	 147.47	 0.0	 0.0	 1	 -30.0	 30.0;
	53027	 53012	 0.020003	 0.084194	 0.01626	 122.29	 122.29	 122.29	 0.0	 0.0	 1	 -30.0	 30.0;
	53014	 53015	 0.00027	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53016	 53017	 0.000297	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53016	 53018	 0.000221	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53019	 53017	 0.011121	 0.040557	 0.01311	 145.98	 145.98	 145.98	 0.0	 0.0	 1	 -30.0	 30.0;
	53021	 53017	 0.028365	 0.124502	 0.04515	 163.39	 163.39	 163.39	 0.0	 0.0	 1	 -30.0	 30.0;
	53033	 53017	 0.030253	 0.136216	 0.02604	 140.63	 140.63	 140.63	 0.0	 0.0	 1	 -30.0	 30.0;
	53271	 53021	 0.05438	 0.174831	 0.06268	 178.37	 178.37	 178.37	 0.0	 0.0	 1	 -30.0	 30.0;
	53023	 53022	 0.013688	 0.057303	 0.01451	 141.96	 141.96	 141.96	 0.0	 0.0	 1	 -30.0	 30.0;
	53023	 53032	 0.011822	 0.04846	 0.01025	 98.35	 98.35	 98.35	 0.0	 0.0	 1	 -30.0	 30.0;
	53048	 53023	 0.014048	 0.051671	 0.02363	 185.39	 185.39	 185.39	 0.0	 0.0	 1	 -30.0	 30.0;
	53024	 53025	 0.000298	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53024	 53026	 0.009106	 0.042508	 0.00826	 134.84	 134.84	 134.84	 0.0	 0.0	 1	 -30.0	 30.0;
	53031	 53024	 0.006992	 0.030306	 0.02431	 162.27	 162.27	 162.27	 0.0	 0.0	 1	 -30.0	 30.0;
	53048	 53026	 0.009107	 0.042235	 0.01635	 139.15	 139.15	 139.15	 0.0	 0.0	 1	 -30.0	 30.0;
	53039	 53027	 0.020124	 0.106552	 0.03384	 99.97	 99.97	 99.97	 0.0	 0.0	 1	 -30.0	 30.0;
	53028	 53030	 0.016081	 0.0644	 0.01171	 126.66	 126.66	 126.66	 0.0	 0.0	 1	 -30.0	 30.0;
	53028	 53051	 0.038916	 0.185656	 0.02384	 138.1	 138.1	 138.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53032	 53029	 0.010246	 0.039218	 0.02754	 147.6	 147.6	 147.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53029	 53040	 0.020441	 0.077017	 0.00799	 162.37	 162.37	 162.37	 0.0	 0.0	 1	 -30.0	 30.0;
	53030	 53271	 0.023851	 0.102059	 0.07679	 151.89	 151.89	 151.89	 0.0	 0.0	 1	 -30.0	 30.0;
	53031	 53045	 0.013294	 0.058102	 0.00991	 150.23	 150.23	 150.23	 0.0	 0.0	 1	 -30.0	 30.0;
	53031	 53063	 0.015131	 0.099672	 0.03187	 168.08	 168.08	 168.08	 0.0	 0.0	 1	 -30.0	 30.0;
	53033	 53034	 0.000269	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53039	 53033	 0.030216	 0.15027	 0.02935	 128.33	 128.33	 128.33	 0.0	 0.0	 1	 -30.0	 30.0;
	53035	 53037	 0.02539	 0.109811	 0.00876	 173.81	 173.81	 173.81	 0.0	 0.0	 1	 -30.0	 30.0;
	53035	 53052	 0.061912	 0.255746	 0.10091	 152.12	 152.12	 152.12	 0.0	 0.0	 1	 -30.0	 30.0;
	53037	 53036	 0.001793	 0.080812	 0.0	 164.72	 164.72	 164.72	 1.00625	 0.0	 1	 -30.0	 30.0;
	53036	 53038	 0.000288	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53036	 53272	 0.021456	 0.164223	 0.52717	 558.27	 558.27	 558.27	 0.0	 0.0	 1	 -30.0	 30.0;
	53036	 53290	 0.00713	 0.075848	 0.31876	 467.18	 467.18	 467.18	 0.0	 0.0	 1	 -30.0	 30.0;
	53039	 53037	 0.008173	 0.04093	 0.01447	 111.34	 111.34	 111.34	 0.0	 0.0	 1	 -30.0	 30.0;
	53040	 53043	 -0.000772	 -0.015214	 0.0	 126.66	 126.66	 126.66	 1.0	 0.0	 1	 -30.0	 30.0;
	53064	 53040	 0.02945	 0.139326	 0.0292	 187.55	 187.55	 187.55	 0.0	 0.0	 1	 -30.0	 30.0;
	53041	 53043	 0.009588	 0.188852	 0.0	 63.33	 63.33	 63.33	 1.0	 0.0	 1	 -30.0	 30.0;
	53042	 53043	 0.009588	 0.188852	 0.0	 63.33	 63.33	 63.33	 1.0	 0.0	 1	 -30.0	 30.0;
	53044	 53047	 0.002624	 0.145255	 0.0	 311.19	 311.19	 311.19	 1.0	 0.0	 1	 -30.0	 30.0;
	53135	 53044	 0.0048	 0.054	 0.18	 577.0	 577.0	 577.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53306	 53044	 0.004823	 0.054249	 0.18081	 577.02	 577.02	 577.02	 0.0	 0.0	 1	 -30.0	 30.0;
	53045	 53047	 -0.001676	 -0.092791	 0.0	 209.12	 209.12	 209.12	 1.0	 0.0	 1	 -30.0	 30.0;
	53048	 53045	 0.011717	 0.058107	 0.01165	 163.89	 163.89	 163.89	 0.0	 0.0	 1	 -30.0	 30.0;
	53057	 53045	 0.006819	 0.029662	 0.11808	 167.2	 167.2	 167.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53046	 53047	 0.005433	 0.300759	 0.0	 102.07	 102.07	 102.07	 1.0	 0.0	 1	 -30.0	 30.0;
	53048	 53049	 0.000206	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53048	 53057	 0.01699	 0.075394	 0.02807	 139.27	 139.27	 139.27	 0.0	 0.0	 1	 -30.0	 30.0;
	53050	 53051	 0.000272	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53062	 53051	 0.01271	 0.07091	 0.00916	 137.39	 137.39	 137.39	 0.0	 0.0	 1	 -30.0	 30.0;
	53051	 53086	 0.007492	 0.037357	 0.032	 147.79	 147.79	 147.79	 0.0	 0.0	 1	 -30.0	 30.0;
	53052	 53053	 0.000226	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53052	 53117	 0.01118	 0.048453	 0.04649	 176.17	 176.17	 176.17	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 53052	 0.010479	 0.05005	 0.09278	 158.85	 158.85	 158.85	 0.0	 0.0	 1	 -30.0	 30.0;
	53114	 53054	 0.037018	 0.175089	 0.02613	 163.65	 163.65	 163.65	 0.0	 0.0	 1	 -30.0	 30.0;
	53147	 53054	 0.028772	 0.129419	 0.0792	 162.24	 162.24	 162.24	 0.0	 0.0	 1	 -30.0	 30.0;
	53055	 53056	 0.000293	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53055	 53057	 0.00029	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53058	 53059	 0.000292	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53059	 53065	 0.010826	 0.0504	 0.01313	 149.94	 149.94	 149.94	 0.0	 0.0	 1	 -30.0	 30.0;
	53059	 53307	 0.005532	 0.025126	 0.10228	 157.02	 157.02	 157.02	 0.0	 0.0	 1	 -30.0	 30.0;
	53060	 53061	 0.000209	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53060	 53062	 0.000215	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53062	 53101	 0.006444	 0.034176	 0.02032	 154.32	 154.32	 154.32	 0.0	 0.0	 1	 -30.0	 30.0;
	53063	 53249	 0.008529	 0.041151	 0.006	 175.52	 175.52	 175.52	 0.0	 0.0	 1	 -30.0	 30.0;
	53064	 53153	 0.048739	 0.206802	 0.03871	 190.48	 190.48	 190.48	 0.0	 0.0	 1	 -30.0	 30.0;
	53065	 53249	 0.005563	 0.02998	 0.01999	 140.73	 140.73	 140.73	 0.0	 0.0	 1	 -30.0	 30.0;
	53066	 53067	 0.000281	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53066	 53070	 0.005769	 0.026838	 0.01892	 117.03	 117.03	 117.03	 0.0	 0.0	 1	 -30.0	 30.0;
	53101	 53066	 0.002653	 0.011588	 0.00194	 143.55	 143.55	 143.55	 0.0	 0.0	 1	 -30.0	 30.0;
	53066	 53267	 0.004925	 0.019034	 0.02043	 182.09	 182.09	 182.09	 0.0	 0.0	 1	 -30.0	 30.0;
	53068	 53069	 0.000222	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53068	 53070	 0.000204	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53070	 53267	 0.011001	 0.048113	 0.02408	 155.61	 155.61	 155.61	 0.0	 0.0	 1	 -30.0	 30.0;
	53072	 53071	 0.002791	 0.009381	 0.0021	 161.71	 161.71	 161.71	 0.0	 0.0	 1	 -30.0	 30.0;
	53075	 53071	 0.002853	 0.013415	 0.0046	 123.86	 123.86	 123.86	 0.0	 0.0	 1	 -30.0	 30.0;
	53072	 53088	 0.002912	 0.014738	 0.00231	 193.6	 193.6	 193.6	 0.0	 0.0	 1	 -30.0	 30.0;
	53073	 53074	 0.000212	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53075	 53073	 0.002453	 0.011728	 0.00388	 167.13	 167.13	 167.13	 0.0	 0.0	 1	 -30.0	 30.0;
	53073	 53081	 0.0033	 0.017159	 0.02198	 172.46	 172.46	 172.46	 0.0	 0.0	 1	 -30.0	 30.0;
	53073	 53082	 0.007838	 0.039217	 0.02129	 148.08	 148.08	 148.08	 0.0	 0.0	 1	 -30.0	 30.0;
	53076	 53077	 0.000213	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53076	 53078	 0.000202	 0.001049	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53078	 53083	 0.002089	 0.010242	 0.00162	 164.76	 164.76	 164.76	 0.0	 0.0	 1	 -30.0	 30.0;
	53078	 53096	 0.001222	 0.004889	 0.00965	 128.92	 128.92	 128.92	 0.0	 0.0	 1	 -30.0	 30.0;
	53079	 53080	 0.000254	 0.001038	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53080	 53106	 0.005813	 0.016054	 0.00157	 194.91	 194.91	 194.91	 0.0	 0.0	 1	 -30.0	 30.0;
	53080	 53123	 0.004709	 0.022864	 0.00641	 191.72	 191.72	 191.72	 0.0	 0.0	 1	 -30.0	 30.0;
	53080	 53307	 0.000807	 0.003492	 0.00051	 223.83	 223.83	 223.83	 0.0	 0.0	 1	 -30.0	 30.0;
	53080	 53307	 0.000807	 0.003492	 0.00051	 223.83	 223.83	 223.83	 0.0	 0.0	 1	 -30.0	 30.0;
	53106	 53081	 0.006386	 0.027334	 0.01143	 192.11	 192.11	 192.11	 0.0	 0.0	 1	 -30.0	 30.0;
	53082	 53096	 0.003052	 0.014305	 0.00704	 173.66	 173.66	 173.66	 0.0	 0.0	 1	 -30.0	 30.0;
	53083	 53084	 0.000255	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53083	 53307	 0.007433	 0.039097	 0.00641	 187.74	 187.74	 187.74	 0.0	 0.0	 1	 -30.0	 30.0;
	53103	 53085	 0.001967	 0.009438	 0.00548	 168.49	 168.49	 168.49	 0.0	 0.0	 1	 -30.0	 30.0;
	53085	 53116	 0.008693	 0.037172	 0.06413	 134.97	 134.97	 134.97	 0.0	 0.0	 1	 -30.0	 30.0;
	53267	 53085	 0.002858	 0.015104	 0.00636	 179.7	 179.7	 179.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53086	 53087	 0.00021	 0.001143	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53103	 53086	 0.004159	 0.019422	 0.00892	 173.79	 173.79	 173.79	 0.0	 0.0	 1	 -30.0	 30.0;
	53088	 53089	 0.000278	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53088	 53307	 0.007585	 0.037603	 0.00595	 199.73	 199.73	 199.73	 0.0	 0.0	 1	 -30.0	 30.0;
	53090	 53091	 0.000241	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53090	 53092	 0.000238	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53249	 53092	 0.002424	 0.013584	 0.00242	 127.57	 127.57	 127.57	 0.0	 0.0	 1	 -30.0	 30.0;
	53092	 53307	 0.022957	 0.105843	 0.01266	 147.48	 147.48	 147.48	 0.0	 0.0	 1	 -30.0	 30.0;
	53093	 53094	 0.000227	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53093	 53291	 0.00992	 0.055309	 0.0389	 196.12	 196.12	 196.12	 0.0	 0.0	 1	 -30.0	 30.0;
	80001	 53093	 0.003386	 0.011654	 0.00219	 155.43	 155.43	 155.43	 0.0	 0.0	 1	 -30.0	 30.0;
	80004	 53093	 0.001579	 0.007424	 0.0012	 163.08	 163.08	 163.08	 0.0	 0.0	 1	 -30.0	 30.0;
	53095	 53096	 0.000297	 0.001168	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53096	 53267	 0.004774	 0.021428	 0.01332	 215.47	 215.47	 215.47	 0.0	 0.0	 1	 -30.0	 30.0;
	53097	 53098	 0.000249	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53110	 53098	 0.001201	 0.005542	 0.00176	 133.52	 133.52	 133.52	 0.0	 0.0	 1	 -30.0	 30.0;
	53098	 53267	 0.002983	 0.014024	 0.00732	 141.26	 141.26	 141.26	 0.0	 0.0	 1	 -30.0	 30.0;
	53098	 53307	 0.007611	 0.043114	 0.02174	 162.73	 162.73	 162.73	 0.0	 0.0	 1	 -30.0	 30.0;
	53099	 53100	 0.000226	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53099	 80003	 0.003481	 0.018232	 0.00256	 190.25	 190.25	 190.25	 0.0	 0.0	 1	 -30.0	 30.0;
	53099	 80017	 0.005386	 0.021959	 0.04672	 187.05	 187.05	 187.05	 0.0	 0.0	 1	 -30.0	 30.0;
	53101	 53102	 0.000291	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53101	 53125	 0.009996	 0.031269	 0.00625	 154.5	 154.5	 154.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53103	 53104	 0.00025	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53119	 53103	 0.003539	 0.013172	 0.01425	 154.87	 154.87	 154.87	 0.0	 0.0	 1	 -30.0	 30.0;
	53105	 53106	 0.000292	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53107	 53108	 0.000204	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53107	 53111	 0.005682	 0.02955	 0.00538	 120.11	 120.11	 120.11	 0.0	 0.0	 1	 -30.0	 30.0;
	53123	 53107	 0.001443	 0.007895	 0.00168	 145.38	 145.38	 145.38	 0.0	 0.0	 1	 -30.0	 30.0;
	53109	 53110	 0.000243	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53133	 53110	 0.007597	 0.032487	 0.01722	 139.57	 139.57	 139.57	 0.0	 0.0	 1	 -30.0	 30.0;
	53133	 53111	 0.005254	 0.024852	 0.00761	 162.7	 162.7	 162.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53113	 53112	 0.009138	 0.04411	 0.0197	 134.35	 134.35	 134.35	 0.0	 0.0	 1	 -30.0	 30.0;
	53112	 53291	 0.019217	 0.087006	 0.03069	 159.48	 159.48	 159.48	 0.0	 0.0	 1	 -30.0	 30.0;
	53113	 53137	 0.016575	 0.071641	 0.02384	 136.72	 136.72	 136.72	 0.0	 0.0	 1	 -30.0	 30.0;
	53258	 53114	 0.00919	 0.052764	 0.02328	 169.66	 169.66	 169.66	 0.0	 0.0	 1	 -30.0	 30.0;
	53115	 53116	 0.000229	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53116	 53258	 0.017339	 0.061916	 0.01173	 169.5	 169.5	 169.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53117	 53118	 0.000266	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53142	 53117	 0.018437	 0.066339	 0.01851	 178.96	 178.96	 178.96	 0.0	 0.0	 1	 -30.0	 30.0;
	53119	 53267	 0.005166	 0.021514	 0.00951	 170.33	 170.33	 170.33	 0.0	 0.0	 1	 -30.0	 30.0;
	53240	 53120	 0.002962	 0.016038	 0.00536	 175.98	 175.98	 175.98	 0.0	 0.0	 1	 -30.0	 30.0;
	53265	 53120	 0.005611	 0.032796	 0.01902	 146.83	 146.83	 146.83	 0.0	 0.0	 1	 -30.0	 30.0;
	53120	 80005	 0.001664	 0.006294	 0.00148	 181.84	 181.84	 181.84	 0.0	 0.0	 1	 -30.0	 30.0;
	53121	 53122	 0.000265	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53123	 53121	 0.00479	 0.02156	 0.00565	 136.45	 136.45	 136.45	 0.0	 0.0	 1	 -30.0	 30.0;
	53127	 53121	 0.003714	 0.021921	 0.01489	 139.22	 139.22	 139.22	 0.0	 0.0	 1	 -30.0	 30.0;
	53128	 53121	 0.007625	 0.033382	 0.00277	 149.37	 149.37	 149.37	 0.0	 0.0	 1	 -30.0	 30.0;
	53123	 53124	 0.00024	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53125	 53126	 0.000212	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53125	 53307	 0.019516	 0.057789	 0.03526	 158.21	 158.21	 158.21	 0.0	 0.0	 1	 -30.0	 30.0;
	53127	 53129	 0.019	 0.089	 0.023	 130.0	 130.0	 130.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53127	 53140	 0.009307	 0.049129	 0.01469	 166.24	 166.24	 166.24	 0.0	 0.0	 1	 -30.0	 30.0;
	53128	 53307	 0.009046	 0.031159	 0.00912	 173.33	 173.33	 173.33	 0.0	 0.0	 1	 -30.0	 30.0;
	53129	 53130	 0.000201	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53129	 53139	 0.019592	 0.0888	 0.02309	 135.16	 135.16	 135.16	 0.0	 0.0	 1	 -30.0	 30.0;
	53129	 53167	 0.046984	 0.226198	 0.05537	 142.52	 142.52	 142.52	 0.0	 0.0	 1	 -30.0	 30.0;
	53131	 53146	 0.003862	 0.019982	 0.00494	 162.98	 162.98	 162.98	 0.0	 0.0	 1	 -30.0	 30.0;
	53131	 53291	 0.007114	 0.035239	 0.02537	 184.2	 184.2	 184.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53143	 53132	 0.002539	 0.012701	 0.00309	 138.62	 138.62	 138.62	 0.0	 0.0	 1	 -30.0	 30.0;
	53146	 53132	 0.0049	 0.02146	 0.0086	 141.24	 141.24	 141.24	 0.0	 0.0	 1	 -30.0	 30.0;
	53133	 53134	 0.000209	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53136	 53133	 0.003969	 0.021811	 0.01435	 197.7	 197.7	 197.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53136	 53135	 0.001255	 0.056757	 0.0	 235.79	 235.79	 235.79	 1.0	 0.0	 1	 -30.0	 30.0;
	53136	 53135	 0.001255	 0.056757	 0.0	 235.79	 235.79	 235.79	 1.0	 0.0	 1	 -30.0	 30.0;
	53136	 53135	 0.001255	 0.056757	 0.0	 235.79	 235.79	 235.79	 1.0	 0.0	 1	 -30.0	 30.0;
	53135	 53229	 0.015293	 0.130298	 0.19804	 558.61	 558.61	 558.61	 0.0	 0.0	 1	 -30.0	 30.0;
	53135	 53266	 0.002697	 0.024631	 0.08655	 425.11	 425.11	 425.11	 0.0	 0.0	 1	 -30.0	 30.0;
	53135	 53273	 0.005039	 0.045757	 0.13355	 559.7	 559.7	 559.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53135	 53306	 0.004016	 0.029799	 0.04529	 488.07	 488.07	 488.07	 0.0	 0.0	 1	 -30.0	 30.0;
	53136	 53140	 0.003309	 0.010816	 0.00202	 191.86	 191.86	 191.86	 0.0	 0.0	 1	 -30.0	 30.0;
	53136	 53149	 0.008152	 0.036433	 0.00405	 184.5	 184.5	 184.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53138	 53137	 0.008796	 0.042712	 0.00499	 157.34	 157.34	 157.34	 0.0	 0.0	 1	 -30.0	 30.0;
	53138	 53143	 0.015666	 0.062919	 0.01835	 159.12	 159.12	 159.12	 0.0	 0.0	 1	 -30.0	 30.0;
	53138	 53227	 0.017029	 0.068289	 0.22016	 193.71	 193.71	 193.71	 0.0	 0.0	 1	 -30.0	 30.0;
	53139	 53149	 0.012178	 0.062566	 0.01423	 156.5	 156.5	 156.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53140	 53141	 0.000211	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53291	 53142	 0.007885	 0.029541	 0.01353	 187.4	 187.4	 187.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53144	 53145	 0.000209	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53144	 53146	 0.000219	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53173	 53147	 0.070063	 0.332001	 0.06884	 143.04	 143.04	 143.04	 0.0	 0.0	 1	 -30.0	 30.0;
	53148	 53150	 0.002549	 0.013267	 0.0094	 155.22	 155.22	 155.22	 0.0	 0.0	 1	 -30.0	 30.0;
	53148	 53267	 0.006681	 0.028052	 0.03883	 137.32	 137.32	 137.32	 0.0	 0.0	 1	 -30.0	 30.0;
	53274	 53150	 0.022264	 0.120168	 0.04352	 185.23	 185.23	 185.23	 0.0	 0.0	 1	 -30.0	 30.0;
	53151	 53152	 0.000201	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53152	 53164	 0.013251	 0.084437	 0.02039	 141.79	 141.79	 141.79	 0.0	 0.0	 1	 -30.0	 30.0;
	53227	 53152	 0.018603	 0.094012	 0.07684	 149.67	 149.67	 149.67	 0.0	 0.0	 1	 -30.0	 30.0;
	53153	 60070	 0.013816	 0.059071	 0.21524	 186.97	 186.97	 186.97	 0.0	 0.0	 1	 -30.0	 30.0;
	53153	 60105	 0.049626	 0.188501	 0.06397	 141.43	 141.43	 141.43	 0.0	 0.0	 1	 -30.0	 30.0;
	53154	 53155	 0.000229	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53291	 53155	 0.017404	 0.084269	 0.02653	 174.31	 174.31	 174.31	 0.0	 0.0	 1	 -30.0	 30.0;
	53155	 80001	 0.009093	 0.033682	 0.04556	 150.72	 150.72	 150.72	 0.0	 0.0	 1	 -30.0	 30.0;
	53156	 53157	 0.000282	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53156	 53158	 0.000229	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53258	 53156	 0.0139	 0.0604	 0.02865	 160.0	 160.0	 160.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53158	 53159	 0.003392	 0.018679	 0.00224	 102.93	 102.93	 102.93	 0.0	 0.0	 1	 -30.0	 30.0;
	53158	 53171	 0.033045	 0.20135	 0.03979	 159.59	 159.59	 159.59	 0.0	 0.0	 1	 -30.0	 30.0;
	53166	 53159	 0.013887	 0.060409	 0.02865	 160.66	 160.66	 160.66	 0.0	 0.0	 1	 -30.0	 30.0;
	53160	 53161	 0.000206	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53160	 53162	 0.000215	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53160	 53163	 0.000263	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53162	 53164	 0.05714	 0.287917	 0.06843	 111.0	 111.0	 111.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53162	 53173	 0.081688	 0.397925	 0.02907	 137.54	 137.54	 137.54	 0.0	 0.0	 1	 -30.0	 30.0;
	53164	 53169	 0.012886	 0.075097	 0.04502	 117.52	 117.52	 117.52	 0.0	 0.0	 1	 -30.0	 30.0;
	53164	 53301	 0.019054	 0.071555	 0.03533	 146.11	 146.11	 146.11	 0.0	 0.0	 1	 -30.0	 30.0;
	53165	 53166	 0.000288	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53166	 53274	 0.046144	 0.15313	 0.03329	 165.31	 165.31	 165.31	 0.0	 0.0	 1	 -30.0	 30.0;
	53182	 53167	 0.065434	 0.275131	 0.03372	 155.66	 155.66	 155.66	 0.0	 0.0	 1	 -30.0	 30.0;
	53168	 53169	 0.000203	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53168	 53170	 0.000294	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53169	 53301	 0.023997	 0.112724	 0.03143	 133.91	 133.91	 133.91	 0.0	 0.0	 1	 -30.0	 30.0;
	53179	 53171	 0.024715	 0.10607	 0.02637	 162.22	 162.22	 162.22	 0.0	 0.0	 1	 -30.0	 30.0;
	53172	 53173	 0.000272	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53174	 53175	 0.047298	 0.247887	 0.04205	 97.36	 97.36	 97.36	 0.0	 0.0	 1	 -30.0	 30.0;
	53175	 53252	 0.007615	 0.031057	 0.00847	 161.14	 161.14	 161.14	 0.0	 0.0	 1	 -30.0	 30.0;
	53176	 53177	 0.000269	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53176	 53179	 0.040939	 0.144262	 0.01964	 156.87	 156.87	 156.87	 0.0	 0.0	 1	 -30.0	 30.0;
	53176	 53230	 0.027353	 0.113719	 0.02383	 164.16	 164.16	 164.16	 0.0	 0.0	 1	 -30.0	 30.0;
	53178	 53279	 0.007915	 0.041463	 0.0209	 192.81	 192.81	 192.81	 0.0	 0.0	 1	 -30.0	 30.0;
	53178	 60053	 0.02406	 0.104137	 0.01771	 174.09	 174.09	 174.09	 0.0	 0.0	 1	 -30.0	 30.0;
	53179	 53197	 0.036491	 0.146256	 0.01956	 149.22	 149.22	 149.22	 0.0	 0.0	 1	 -30.0	 30.0;
	53180	 53181	 0.000216	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53180	 53182	 0.055257	 0.230519	 0.03859	 162.4	 162.4	 162.4	 0.0	 0.0	 1	 -30.0	 30.0;
	53180	 53187	 0.020692	 0.128616	 0.01638	 180.79	 180.79	 180.79	 0.0	 0.0	 1	 -30.0	 30.0;
	53183	 53184	 0.000276	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53183	 53185	 0.000206	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53227	 53184	 0.032857	 0.146566	 0.05986	 181.13	 181.13	 181.13	 0.0	 0.0	 1	 -30.0	 30.0;
	53184	 53237	 0.024629	 0.080437	 0.0192	 174.34	 174.34	 174.34	 0.0	 0.0	 1	 -30.0	 30.0;
	53283	 53184	 0.011622	 0.033772	 0.00708	 148.86	 148.86	 148.86	 0.0	 0.0	 1	 -30.0	 30.0;
	53188	 53186	 0.006951	 0.032256	 0.01185	 156.77	 156.77	 156.77	 0.0	 0.0	 1	 -30.0	 30.0;
	53186	 53194	 0.015046	 0.066311	 0.01908	 173.03	 173.03	 173.03	 0.0	 0.0	 1	 -30.0	 30.0;
	53187	 53304	 0.002779	 0.013691	 0.00489	 196.14	 196.14	 196.14	 0.0	 0.0	 1	 -30.0	 30.0;
	53188	 53304	 0.007706	 0.043493	 0.01176	 125.17	 125.17	 125.17	 0.0	 0.0	 1	 -30.0	 30.0;
	53189	 53190	 0.000201	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53189	 53201	 0.024088	 0.121039	 0.02275	 156.36	 156.36	 156.36	 0.0	 0.0	 1	 -30.0	 30.0;
	53189	 53208	 0.027984	 0.12876	 0.04199	 145.94	 145.94	 145.94	 0.0	 0.0	 1	 -30.0	 30.0;
	53189	 53230	 0.01367	 0.059757	 0.01658	 176.38	 176.38	 176.38	 0.0	 0.0	 1	 -30.0	 30.0;
	53191	 53192	 0.00028	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53191	 53193	 0.000295	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53192	 53247	 0.030481	 0.105937	 0.06164	 177.3	 177.3	 177.3	 0.0	 0.0	 1	 -30.0	 30.0;
	53192	 53283	 0.012346	 0.062467	 0.01563	 157.68	 157.68	 157.68	 0.0	 0.0	 1	 -30.0	 30.0;
	53194	 53202	 0.027916	 0.145526	 0.09313	 181.72	 181.72	 181.72	 0.0	 0.0	 1	 -30.0	 30.0;
	53194	 53214	 0.008265	 0.039872	 0.00394	 173.35	 173.35	 173.35	 0.0	 0.0	 1	 -30.0	 30.0;
	53194	 53296	 0.004215	 0.020335	 0.01399	 188.91	 188.91	 188.91	 0.0	 0.0	 1	 -30.0	 30.0;
	53195	 53196	 0.000211	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53195	 53197	 0.000245	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53197	 53230	 0.041889	 0.21523	 0.04209	 155.14	 155.14	 155.14	 0.0	 0.0	 1	 -30.0	 30.0;
	53198	 53199	 0.000266	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53296	 53199	 0.002862	 0.013812	 0.00495	 171.63	 171.63	 171.63	 0.0	 0.0	 1	 -30.0	 30.0;
	53200	 53201	 0.000252	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53201	 53203	 0.014609	 0.07296	 0.01834	 147.14	 147.14	 147.14	 0.0	 0.0	 1	 -30.0	 30.0;
	53208	 53201	 0.012861	 0.053707	 0.01738	 142.27	 142.27	 142.27	 0.0	 0.0	 1	 -30.0	 30.0;
	53210	 53201	 0.006136	 0.032553	 0.03015	 144.21	 144.21	 144.21	 0.0	 0.0	 1	 -30.0	 30.0;
	53210	 53203	 0.013887	 0.080985	 0.01169	 136.2	 136.2	 136.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53204	 53205	 0.000254	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53206	 53207	 0.000249	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53206	 53208	 0.000279	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53214	 53211	 0.023482	 0.096311	 0.03294	 168.81	 168.81	 168.81	 0.0	 0.0	 1	 -30.0	 30.0;
	53213	 53212	 0.000238	 0.014795	 0.0	 557.3	 557.3	 557.3	 1.0	 0.0	 1	 -30.0	 30.0;
	53212	 53215	 8.4e-05	 0.007249	 0.0	 1136.3	 1136.3	 1136.3	 1.0	 0.0	 1	 -30.0	 30.0;
	53212	 53216	 0.000143	 0.009259	 0.0	 1134.54	 1134.54	 1134.54	 1.05	 0.0	 1	 -30.0	 30.0;
	53212	 53217	 0.000121	 0.009645	 0.0	 1132.84	 1132.84	 1132.84	 1.05625	 0.0	 1	 -30.0	 30.0;
	53212	 53218	 0.000129	 0.008684	 0.0	 1130.97	 1130.97	 1130.97	 1.05	 0.0	 1	 -30.0	 30.0;
	53212	 53220	 0.00024	 0.001018	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53214	 53213	 0.001082	 0.044799	 0.0	 179.46	 179.46	 179.46	 1.0	 0.0	 1	 -30.0	 30.0;
	53213	 53219	 0.000243	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53219	 53295	 0.001597	 0.012195	 0.0554	 570.0	 570.0	 570.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53299	 53220	 0.000183	 0.00308	 0.19468	 2848.2	 2848.2	 2848.2	 0.0	 0.0	 1	 -30.0	 30.0;
	53221	 53222	 0.016235	 0.428531	 0.0	 40.82	 40.82	 40.82	 1.00625	 0.0	 1	 -30.0	 30.0;
	53221	 53223	 0.010333	 0.271824	 0.0	 24.18	 24.18	 24.18	 1.0125	 0.0	 1	 -30.0	 30.0;
	53221	 53224	 0.029846	 0.692041	 0.0	 22.49	 22.49	 22.49	 1.0125	 0.0	 1	 -30.0	 30.0;
	53221	 53225	 0.000231	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53279	 53225	 0.021887	 0.08892	 0.02999	 122.82	 122.82	 122.82	 0.0	 0.0	 1	 -30.0	 30.0;
	53225	 60070	 0.036844	 0.162127	 0.01558	 179.15	 179.15	 179.15	 0.0	 0.0	 1	 -30.0	 30.0;
	53226	 53227	 0.000246	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53301	 53227	 0.003517	 0.017284	 0.00249	 165.48	 165.48	 165.48	 0.0	 0.0	 1	 -30.0	 30.0;
	53229	 53228	 0.000179	 0.014126	 0.0	 814.95	 814.95	 814.95	 1.0	 0.0	 1	 -30.0	 30.0;
	53228	 53233	 0.00013	 0.008459	 0.0	 1100.26	 1100.26	 1100.26	 1.03125	 0.0	 1	 -30.0	 30.0;
	53228	 53234	 0.0002	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53228	 53235	 0.000269	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53228	 53305	 0.00093	 0.018	 2.27	 3100.0	 3100.0	 3100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53229	 53232	 0.001926	 0.070191	 0.0	 304.94	 304.94	 304.94	 1.0	 0.0	 1	 -30.0	 30.0;
	53273	 53229	 0.008505	 0.071896	 0.11997	 568.37	 568.37	 568.37	 0.0	 0.0	 1	 -30.0	 30.0;
	53295	 53229	 0.015709	 0.138003	 0.34671	 547.58	 547.58	 547.58	 0.0	 0.0	 1	 -30.0	 30.0;
	53230	 53232	 -0.000852	 -0.031057	 0.0	 201.75	 201.75	 201.75	 1.0	 0.0	 1	 -30.0	 30.0;
	53231	 53232	 0.005728	 0.208728	 0.0	 103.19	 103.19	 103.19	 1.0	 0.0	 1	 -30.0	 30.0;
	53234	 53299	 0.0014	 0.024206	 2.18756	 2841.7	 2841.7	 2841.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53236	 53237	 0.000297	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53237	 53289	 0.037258	 0.151914	 0.03448	 164.1	 164.1	 164.1	 0.0	 0.0	 1	 -30.0	 30.0;
	53239	 53238	 0.000245	 0.016279	 0.0	 980.79	 980.79	 980.79	 1.04375	 0.0	 1	 -30.0	 30.0;
	53238	 53241	 0.000272	 0.019186	 0.0	 742.62	 742.62	 742.62	 1.01875	 0.0	 1	 -30.0	 30.0;
	53238	 53242	 0.000311	 0.015959	 0.0	 640.49	 640.49	 640.49	 1.01875	 0.0	 1	 -30.0	 30.0;
	53238	 53243	 0.000305	 0.018813	 0.0	 636.55	 636.55	 636.55	 1.01875	 0.0	 1	 -30.0	 30.0;
	53238	 53244	 0.000222	 0.016051	 0.0	 632.92	 632.92	 632.92	 1.01875	 0.0	 1	 -30.0	 30.0;
	53250	 53238	 0.001311	 0.019713	 2.30708	 2406.68	 2406.68	 2406.68	 0.0	 0.0	 1	 -30.0	 30.0;
	53238	 80048	 0.000155	 0.002707	 0.28803	 2323.7	 2323.7	 2323.7	 0.0	 0.0	 1	 -30.0	 30.0;
	53240	 53239	 0.002205	 0.064296	 0.0	 257.54	 257.54	 257.54	 1.03125	 0.0	 1	 -30.0	 30.0;
	53240	 53239	 0.002205	 0.064296	 0.0	 257.54	 257.54	 257.54	 1.1	 0.0	 1	 -30.0	 30.0;
	53240	 53239	 0.002205	 0.064296	 0.0	 257.54	 257.54	 257.54	 1.03125	 0.0	 1	 -30.0	 30.0;
	53239	 53245	 0.000291	 0.001187	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80010	 53240	 0.001415	 0.00579	 0.00129	 200.46	 200.46	 200.46	 0.0	 0.0	 1	 -30.0	 30.0;
	80013	 53240	 0.003206	 0.015956	 0.00875	 178.38	 178.38	 178.38	 0.0	 0.0	 1	 -30.0	 30.0;
	53240	 80022	 0.008146	 0.036201	 0.0196	 179.37	 179.37	 179.37	 0.0	 0.0	 1	 -30.0	 30.0;
	80006	 53245	 0.001185	 0.008945	 0.04195	 526.82	 526.82	 526.82	 0.0	 0.0	 1	 -30.0	 30.0;
	53246	 53247	 0.000278	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53248	 53249	 0.000213	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53251	 53250	 0.000213	 0.013535	 0.0	 716.18	 716.18	 716.18	 1.0	 0.0	 1	 -30.0	 30.0;
	53250	 53253	 0.00015	 0.01368	 0.0	 949.52	 949.52	 949.52	 0.99375	 0.0	 1	 -30.0	 30.0;
	53250	 53254	 8.9e-05	 0.00771	 0.0	 948.41	 948.41	 948.41	 1.0	 0.0	 1	 -30.0	 30.0;
	53250	 53255	 0.000223	 0.017121	 0.0	 947.81	 947.81	 947.81	 0.99375	 0.0	 1	 -30.0	 30.0;
	53252	 53251	 0.001016	 0.049467	 0.0	 160.1	 160.1	 160.1	 1.00625	 0.0	 1	 -30.0	 30.0;
	53251	 53256	 0.000279	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53256	 53302	 0.005813	 0.047702	 0.07951	 535.96	 535.96	 535.96	 0.0	 0.0	 1	 -30.0	 30.0;
	53257	 53260	 0.002909	 0.125967	 0.0	 276.55	 276.55	 276.55	 1.0	 0.0	 1	 -30.0	 30.0;
	53257	 53261	 0.001548	 0.065341	 0.0	 242.36	 242.36	 242.36	 1.0	 0.0	 1	 -30.0	 30.0;
	53257	 53272	 0.007788	 0.069173	 0.18538	 529.62	 529.62	 529.62	 0.0	 0.0	 1	 -30.0	 30.0;
	53257	 53306	 0.005819	 0.04806	 0.25601	 410.5	 410.5	 410.5	 0.0	 0.0	 1	 -30.0	 30.0;
	53258	 53260	 -0.001285	 -0.055654	 0.0	 176.55	 176.55	 176.55	 1.0	 0.0	 1	 -30.0	 30.0;
	53259	 53260	 0.008672	 0.37556	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53262	 53263	 0.011383	 0.293888	 0.0	 43.8	 43.8	 43.8	 1.01875	 0.0	 1	 -30.0	 30.0;
	53262	 53264	 0.016854	 0.447651	 0.0	 22.75	 22.75	 22.75	 1.01875	 0.0	 1	 -30.0	 30.0;
	53262	 53265	 0.000214	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80001	 53265	 0.004884	 0.019167	 0.01007	 133.15	 133.15	 133.15	 0.0	 0.0	 1	 -30.0	 30.0;
	53267	 53266	 0.001655	 0.071104	 0.0	 243.93	 243.93	 243.93	 1.0	 0.0	 1	 -30.0	 30.0;
	53267	 53266	 0.001655	 0.071104	 0.0	 243.93	 243.93	 243.93	 1.0	 0.0	 1	 -30.0	 30.0;
	53267	 53266	 0.001655	 0.071104	 0.0	 243.93	 243.93	 243.93	 1.0	 0.0	 1	 -30.0	 30.0;
	53266	 53268	 0.000893	 0.039124	 0.0	 239.95	 239.95	 239.95	 1.00625	 0.0	 1	 -30.0	 30.0;
	53266	 53306	 0.001752	 0.018343	 0.03917	 555.57	 555.57	 555.57	 0.0	 0.0	 1	 -30.0	 30.0;
	53267	 53269	 0.038993	 0.850759	 0.0	 17.81	 17.81	 17.81	 1.0625	 0.0	 1	 -30.0	 30.0;
	53271	 53270	 0.001431	 0.063216	 0.0	 175.08	 175.08	 175.08	 1.0	 0.0	 1	 -30.0	 30.0;
	53270	 53272	 0.000221	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53273	 53276	 0.001882	 0.079139	 0.0	 288.47	 288.47	 288.47	 1.0	 0.0	 1	 -30.0	 30.0;
	53273	 53277	 0.001011	 0.041703	 0.0	 220.07	 220.07	 220.07	 1.0	 0.0	 1	 -30.0	 30.0;
	53274	 53276	 -0.000647	 -0.027211	 0.0	 188.47	 188.47	 188.47	 1.0	 0.0	 1	 -30.0	 30.0;
	53275	 53276	 0.006779	 0.285013	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53278	 53281	 0.000868	 0.033827	 0.0	 301.26	 301.26	 301.26	 1.0	 0.0	 1	 -30.0	 30.0;
	53295	 53278	 0.005579	 0.048255	 0.12712	 476.61	 476.61	 476.61	 0.0	 0.0	 1	 -30.0	 30.0;
	53278	 60005	 0.011765	 0.092639	 0.26691	 431.09	 431.09	 431.09	 0.0	 0.0	 1	 -30.0	 30.0;
	53278	 60056	 0.007082	 0.062856	 0.2451	 340.01	 340.01	 340.01	 0.0	 0.0	 1	 -30.0	 30.0;
	53279	 53281	 0.00065	 0.025306	 0.0	 151.26	 151.26	 151.26	 1.0	 0.0	 1	 -30.0	 30.0;
	53279	 60035	 0.028871	 0.135467	 0.0695	 164.38	 164.38	 164.38	 0.0	 0.0	 1	 -30.0	 30.0;
	53280	 53281	 0.007577	 0.295159	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53283	 53282	 0.000897	 0.041996	 0.0	 145.98	 145.98	 145.98	 1.00625	 0.0	 1	 -30.0	 30.0;
	53282	 53286	 -0.000115	 -0.005467	 0.0	 440.91	 440.91	 440.91	 1.0	 0.0	 1	 -30.0	 30.0;
	53282	 53287	 0.000248	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53284	 53286	 0.001301	 0.061883	 0.0	 220.45	 220.45	 220.45	 1.0	 0.0	 1	 -30.0	 30.0;
	53285	 53286	 0.001301	 0.061883	 0.0	 220.45	 220.45	 220.45	 1.0	 0.0	 1	 -30.0	 30.0;
	53287	 53288	 0.004012	 0.038066	 0.24672	 546.83	 546.83	 546.83	 0.0	 0.0	 1	 -30.0	 30.0;
	53287	 53290	 0.006283	 0.054686	 0.86027	 619.53	 619.53	 619.53	 0.0	 0.0	 1	 -30.0	 30.0;
	53289	 53288	 0.001285	 0.05619	 0.0	 187.67	 187.67	 187.67	 1.00625	 0.0	 1	 -30.0	 30.0;
	53291	 53290	 0.000656	 0.033206	 0.0	 275.46	 275.46	 275.46	 1.0125	 0.0	 1	 -30.0	 30.0;
	53291	 53290	 0.000656	 0.033206	 0.0	 275.46	 275.46	 275.46	 1.0125	 0.0	 1	 -30.0	 30.0;
	53291	 53290	 0.000656	 0.033206	 0.0	 275.46	 275.46	 275.46	 1.0125	 0.0	 1	 -30.0	 30.0;
	53290	 53292	 0.001394	 0.054565	 0.0	 238.82	 238.82	 238.82	 1.00625	 0.0	 1	 -30.0	 30.0;
	53290	 53293	 0.000826	 0.038128	 0.0	 228.23	 228.23	 228.23	 1.00625	 0.0	 1	 -30.0	 30.0;
	53290	 80006	 0.005013	 0.033346	 0.14128	 518.44	 518.44	 518.44	 0.0	 0.0	 1	 -30.0	 30.0;
	53291	 80003	 0.011434	 0.034681	 0.05781	 210.01	 210.01	 210.01	 0.0	 0.0	 1	 -30.0	 30.0;
	53295	 53294	 0.000177	 0.010415	 0.0	 1200.0	 1200.0	 1200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	53294	 53297	 6.5e-05	 0.00451	 0.0	 1305.2	 1305.2	 1305.2	 1.00625	 0.0	 1	 -30.0	 30.0;
	53294	 53298	 0.000106	 0.007297	 0.0	 1298.56	 1298.56	 1298.56	 1.00625	 0.0	 1	 -30.0	 30.0;
	53294	 53299	 0.000238	 0.00116	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53296	 53295	 0.001022	 0.042378	 0.0	 194.47	 194.47	 194.47	 1.0	 0.0	 1	 -30.0	 30.0;
	53299	 60734	 0.001169	 0.020018	 3.47265	 2451.72	 2451.72	 2451.72	 0.0	 0.0	 1	 -30.0	 30.0;
	53301	 53300	 0.001408	 0.062115	 0.0	 162.61	 162.61	 162.61	 1.0	 0.0	 1	 -30.0	 30.0;
	53300	 53302	 0.000203	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53302	 80006	 0.007387	 0.056437	 0.80623	 541.87	 541.87	 541.87	 0.0	 0.0	 1	 -30.0	 30.0;
	53303	 53304	 0.000294	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53306	 53305	 0.000171	 0.012774	 0.0	 1118.4	 1118.4	 1118.4	 1.0	 0.0	 1	 -30.0	 30.0;
	53306	 53305	 0.000171	 0.012774	 0.0	 1118.4	 1118.4	 1118.4	 1.0	 0.0	 1	 -30.0	 30.0;
	60801	 53305	 0.002929	 0.04137	 5.57851	 3096.71	 3096.71	 3096.71	 0.0	 0.0	 1	 -30.0	 30.0;
	53307	 53306	 0.001289	 0.058351	 0.0	 279.03	 279.03	 279.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	53307	 53306	 0.001289	 0.058351	 0.0	 279.03	 279.03	 279.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	53307	 53306	 0.001289	 0.058351	 0.0	 279.03	 279.03	 279.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	53307	 53306	 0.001289	 0.058351	 0.0	 279.03	 279.03	 279.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	60007	 60000	 0.02777	 0.133596	 0.02854	 143.77	 143.77	 143.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60029	 60000	 0.042515	 0.259274	 0.03874	 150.54	 150.54	 150.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60001	 60002	 0.000226	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60001	 60003	 0.00022	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60015	 60002	 0.005036	 0.020475	 0.00669	 124.09	 124.09	 124.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60002	 60020	 0.005186	 0.02599	 0.01788	 168.65	 168.65	 168.65	 0.0	 0.0	 1	 -30.0	 30.0;
	60004	 60015	 0.013021	 0.060372	 0.01386	 162.51	 162.51	 162.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60004	 60017	 0.0127	 0.053609	 0.03147	 168.73	 168.73	 168.73	 0.0	 0.0	 1	 -30.0	 30.0;
	60006	 60005	 0.000967	 0.046567	 0.0	 154.97	 154.97	 154.97	 1.0	 0.0	 1	 -30.0	 30.0;
	60006	 60009	 0.007026	 0.261878	 0.0	 188.45	 188.45	 188.45	 1.0	 0.0	 1	 -30.0	 30.0;
	60006	 60010	 0.00024	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60007	 60009	 -0.003345	 -0.124682	 0.0	 113.45	 113.45	 113.45	 1.0	 0.0	 1	 -30.0	 30.0;
	60007	 60032	 0.019667	 0.104643	 0.02783	 125.73	 125.73	 125.73	 0.0	 0.0	 1	 -30.0	 30.0;
	60008	 60009	 0.016509	 0.615341	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60057	 60010	 0.020579	 0.130449	 0.10531	 183.9	 183.9	 183.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60011	 60014	 0.0001	 0.000277	 0.0	 99.86	 99.86	 99.86	 1.0	 0.0	 1	 -30.0	 30.0;
	60011	 60020	 0.018816	 0.081865	 0.28463	 165.18	 165.18	 165.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60011	 60044	 0.050102	 0.210769	 0.03658	 140.78	 140.78	 140.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60063	 60011	 0.049856	 0.253349	 0.07647	 163.58	 163.58	 163.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60012	 60014	 0.005926	 0.106043	 0.0	 49.93	 49.93	 49.93	 1.0	 0.0	 1	 -30.0	 30.0;
	60013	 60014	 0.005926	 0.106043	 0.0	 49.93	 49.93	 49.93	 1.0	 0.0	 1	 -30.0	 30.0;
	60017	 60016	 0.001731	 0.072576	 0.0	 250.39	 250.39	 250.39	 1.0	 0.0	 1	 -30.0	 30.0;
	60017	 60016	 0.001731	 0.072576	 0.0	 250.39	 250.39	 250.39	 1.0	 0.0	 1	 -30.0	 30.0;
	60017	 60016	 0.001731	 0.072576	 0.0	 250.39	 250.39	 250.39	 1.0	 0.0	 1	 -30.0	 30.0;
	60848	 60016	 0.004828	 0.047457	 0.31643	 587.61	 587.61	 587.61	 0.0	 0.0	 1	 -30.0	 30.0;
	60016	 60868	 0.012121	 0.111492	 0.56548	 609.37	 609.37	 609.37	 0.0	 0.0	 1	 -30.0	 30.0;
	60017	 60021	 0.015616	 0.058036	 0.00612	 163.55	 163.55	 163.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60017	 60025	 0.009418	 0.040363	 0.14893	 134.22	 134.22	 134.22	 0.0	 0.0	 1	 -30.0	 30.0;
	60028	 60017	 0.00148	 0.008286	 0.00121	 202.49	 202.49	 202.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60028	 60017	 0.00148	 0.008286	 0.00121	 202.49	 202.49	 202.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60018	 60019	 0.000289	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60018	 60026	 0.010434	 0.041076	 0.06212	 144.36	 144.36	 144.36	 0.0	 0.0	 1	 -30.0	 30.0;
	60018	 60028	 0.003724	 0.018769	 0.00467	 173.92	 173.92	 173.92	 0.0	 0.0	 1	 -30.0	 30.0;
	60031	 60018	 0.011124	 0.049214	 0.02555	 144.19	 144.19	 144.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60020	 60022	 0.003119	 0.014684	 0.02131	 161.31	 161.31	 161.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60021	 60022	 0.003593	 0.019602	 0.02155	 162.46	 162.46	 162.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60028	 60021	 0.012299	 0.046195	 0.01004	 161.03	 161.03	 161.03	 0.0	 0.0	 1	 -30.0	 30.0;
	60022	 60028	 0.011942	 0.061616	 0.00918	 163.03	 163.03	 163.03	 0.0	 0.0	 1	 -30.0	 30.0;
	60023	 60024	 0.000297	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60023	 60025	 0.000247	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60025	 60050	 0.011121	 0.059886	 0.16631	 142.51	 142.51	 142.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60026	 60031	 0.012005	 0.058274	 0.00866	 113.14	 113.14	 113.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60026	 60045	 0.041481	 0.195351	 0.04934	 155.26	 155.26	 155.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60027	 60028	 0.000242	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60029	 60030	 0.000224	 0.001119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60737	 60029	 0.013194	 0.068283	 0.01088	 150.92	 150.92	 150.92	 0.0	 0.0	 1	 -30.0	 30.0;
	60031	 60052	 0.014428	 0.07174	 0.0167	 124.03	 124.03	 124.03	 0.0	 0.0	 1	 -30.0	 30.0;
	60032	 60035	 0.012249	 0.063573	 0.00974	 160.74	 160.74	 160.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60055	 60032	 0.011334	 0.05732	 0.07748	 156.43	 156.43	 156.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60033	 60034	 0.000208	 0.001043	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60038	 60033	 0.016619	 0.055683	 0.01304	 157.96	 157.96	 157.96	 0.0	 0.0	 1	 -30.0	 30.0;
	60033	 60060	 0.018527	 0.101366	 0.01693	 168.42	 168.42	 168.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60036	 60037	 0.000299	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60036	 60038	 0.000208	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60036	 60039	 0.000243	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60038	 60049	 0.013019	 0.053102	 0.0132	 126.79	 126.79	 126.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60040	 60041	 0.000253	 0.001071	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60040	 60042	 0.000278	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60040	 60043	 0.000298	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60054	 60041	 0.008213	 0.042092	 0.02595	 144.04	 144.04	 144.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60041	 60055	 0.047089	 0.189317	 0.01976	 117.94	 117.94	 117.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60044	 60045	 0.014576	 0.065417	 0.04589	 109.86	 109.86	 109.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60849	 60044	 0.025734	 0.13155	 0.02906	 168.48	 168.48	 168.48	 0.0	 0.0	 1	 -30.0	 30.0;
	60045	 60046	 0.000284	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60045	 60064	 0.029788	 0.12704	 0.05877	 156.59	 156.59	 156.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60849	 60045	 0.01678	 0.083995	 0.01462	 180.95	 180.95	 180.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60047	 60048	 0.000236	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60047	 60049	 0.000231	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60052	 60049	 0.016348	 0.079564	 0.02676	 143.6	 143.6	 143.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60050	 60051	 0.000263	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60050	 60060	 0.007557	 0.038397	 0.01716	 154.5	 154.5	 154.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60050	 60737	 0.02198	 0.114156	 0.06058	 145.86	 145.86	 145.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60064	 60052	 0.01427	 0.071384	 0.03851	 156.85	 156.85	 156.85	 0.0	 0.0	 1	 -30.0	 30.0;
	60053	 60058	 0.014401	 0.064283	 0.04541	 134.11	 134.11	 134.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60070	 60053	 0.01888	 0.086536	 0.0341	 149.16	 149.16	 149.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60054	 60062	 0.018154	 0.107738	 0.02296	 159.04	 159.04	 159.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60055	 60058	 0.005805	 0.026575	 0.00917	 134.56	 134.56	 134.56	 0.0	 0.0	 1	 -30.0	 30.0;
	60057	 60056	 0.001374	 0.06843	 0.0	 169.06	 169.06	 169.06	 1.09375	 0.0	 1	 -30.0	 30.0;
	60056	 60061	 0.006791	 0.066001	 0.55826	 509.89	 509.89	 509.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60058	 60057	 0.003253	 0.108245	 0.0	 137.57	 137.57	 137.57	 1.04375	 0.0	 1	 -30.0	 30.0;
	60058	 60074	 0.018061	 0.061556	 0.01925	 150.74	 150.74	 150.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60060	 60059	 0.001186	 0.054498	 0.0	 181.87	 181.87	 181.87	 1.0	 0.0	 1	 -30.0	 30.0;
	60059	 60061	 0.000266	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60060	 60765	 0.011193	 0.054004	 0.02172	 163.43	 163.43	 163.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60061	 60805	 0.003229	 0.030796	 0.06746	 537.88	 537.88	 537.88	 0.0	 0.0	 1	 -30.0	 30.0;
	60061	 60848	 0.010799	 0.105044	 0.35717	 504.8	 504.8	 504.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60062	 60812	 0.042713	 0.164493	 0.04562	 166.96	 166.96	 166.96	 0.0	 0.0	 1	 -30.0	 30.0;
	60076	 60063	 0.024439	 0.106893	 0.04893	 147.36	 147.36	 147.36	 0.0	 0.0	 1	 -30.0	 30.0;
	60080	 60063	 0.024577	 0.119228	 0.06258	 146.8	 146.8	 146.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60063	 60869	 0.024157	 0.121365	 0.05058	 186.77	 186.77	 186.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60071	 60064	 0.004828	 0.025969	 0.01005	 143.14	 143.14	 143.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60065	 60066	 0.000279	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60706	 60065	 0.041387	 0.197937	 0.02906	 130.36	 130.36	 130.36	 0.0	 0.0	 1	 -30.0	 30.0;
	60869	 60065	 0.024038	 0.103137	 0.01281	 156.96	 156.96	 156.96	 0.0	 0.0	 1	 -30.0	 30.0;
	60067	 60068	 0.000261	 0.001145	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60067	 60069	 0.000264	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60073	 60069	 0.006652	 0.033123	 0.01027	 124.87	 124.87	 124.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60069	 60079	 0.028905	 0.09807	 0.06091	 169.95	 169.95	 169.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60069	 60849	 0.002629	 0.013925	 0.01415	 180.3	 180.3	 180.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60071	 60072	 0.000291	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60765	 60071	 0.044927	 0.186196	 0.02533	 152.97	 152.97	 152.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60073	 60849	 0.015594	 0.082916	 0.00849	 142.75	 142.75	 142.75	 0.0	 0.0	 1	 -30.0	 30.0;
	60074	 60075	 0.000284	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60074	 60082	 0.035589	 0.165651	 0.0256	 105.8	 105.8	 105.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60076	 60080	 0.012185	 0.050117	 0.01646	 116.28	 116.28	 116.28	 0.0	 0.0	 1	 -30.0	 30.0;
	60076	 60849	 0.010224	 0.053712	 0.07728	 152.85	 152.85	 152.85	 0.0	 0.0	 1	 -30.0	 30.0;
	60077	 60078	 0.000292	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60077	 60090	 0.016987	 0.101884	 0.02137	 178.68	 178.68	 178.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60077	 60104	 0.070252	 0.246265	 0.04138	 147.42	 147.42	 147.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60706	 60077	 0.00276	 0.012979	 0.00346	 188.86	 188.86	 188.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60079	 60088	 0.01212	 0.062087	 0.01993	 134.4	 134.4	 134.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60080	 60081	 0.000202	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60082	 60083	 0.000299	 0.0012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60082	 60102	 0.018216	 0.090643	 0.11573	 159.74	 159.74	 159.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60084	 60806	 0.061123	 0.222219	 0.0289	 143.94	 143.94	 143.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60812	 60084	 0.03638	 0.182486	 0.01754	 139.66	 139.66	 139.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60085	 60086	 0.000256	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60085	 60087	 0.00024	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60088	 60086	 0.021333	 0.085805	 0.02705	 141.71	 141.71	 141.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60086	 60829	 0.04413	 0.181621	 0.04243	 154.91	 154.91	 154.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60095	 60088	 0.021038	 0.073489	 0.03118	 141.52	 141.52	 141.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60089	 60095	 0.005717	 0.027784	 0.03986	 141.28	 141.28	 141.28	 0.0	 0.0	 1	 -30.0	 30.0;
	60089	 60100	 0.026752	 0.123522	 0.04259	 157.54	 157.54	 157.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60092	 60090	 0.029076	 0.130156	 0.02248	 149.64	 149.64	 149.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60101	 60090	 0.039493	 0.164394	 0.0311	 140.74	 140.74	 140.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60090	 60104	 0.024359	 0.120667	 0.03808	 143.03	 143.03	 143.03	 0.0	 0.0	 1	 -30.0	 30.0;
	60091	 60092	 0.000231	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60092	 60093	 0.021565	 0.109556	 0.08297	 146.57	 146.57	 146.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60092	 60101	 0.029416	 0.113275	 0.01401	 126.98	 126.98	 126.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60093	 60094	 0.000237	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60093	 60097	 0.010852	 0.050487	 0.00605	 143.68	 143.68	 143.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60100	 60093	 0.008681	 0.051334	 0.01501	 139.83	 139.83	 139.83	 0.0	 0.0	 1	 -30.0	 30.0;
	60097	 60096	 0.001072	 0.049683	 0.0	 183.87	 183.87	 183.87	 1.09375	 0.0	 1	 -30.0	 30.0;
	60096	 60184	 0.010597	 0.096241	 0.43729	 485.58	 485.58	 485.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60096	 60705	 0.00922	 0.082409	 0.37872	 595.02	 595.02	 595.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60100	 60097	 0.00618	 0.028631	 0.01496	 168.44	 168.44	 168.44	 0.0	 0.0	 1	 -30.0	 30.0;
	60097	 60109	 0.010599	 0.04768	 0.04078	 137.68	 137.68	 137.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60098	 60099	 0.000221	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60098	 60100	 0.000233	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60117	 60102	 0.018587	 0.09967	 0.0477	 166.89	 166.89	 166.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60103	 60119	 0.040111	 0.259448	 0.03367	 154.05	 154.05	 154.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60103	 60829	 0.011089	 0.048555	 0.00959	 168.82	 168.82	 168.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60105	 60116	 0.029411	 0.114344	 0.03337	 151.28	 151.28	 151.28	 0.0	 0.0	 1	 -30.0	 30.0;
	60106	 60107	 0.000297	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60106	 60108	 0.000295	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60107	 60121	 0.017071	 0.081037	 0.04267	 148.56	 148.56	 148.56	 0.0	 0.0	 1	 -30.0	 30.0;
	60829	 60107	 0.009411	 0.031239	 0.01268	 163.24	 163.24	 163.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60110	 60109	 0.010876	 0.050801	 0.01063	 135.11	 135.11	 135.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60109	 60800	 0.021612	 0.080062	 0.00841	 142.24	 142.24	 142.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60128	 60110	 0.022406	 0.075989	 0.01929	 133.03	 133.03	 133.03	 0.0	 0.0	 1	 -30.0	 30.0;
	60110	 60800	 0.020259	 0.086994	 0.01307	 145.9	 145.9	 145.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 60112	 0.000214	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 60124	 0.011869	 0.044143	 0.02446	 146.2	 146.2	 146.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 60128	 0.015591	 0.070159	 0.01482	 145.2	 145.2	 145.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60111	 60829	 0.014915	 0.040925	 0.11581	 164.99	 164.99	 164.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60113	 60114	 0.000279	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60113	 60115	 0.000233	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60115	 60116	 0.007912	 0.03092	 0.02003	 176.47	 176.47	 176.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60115	 60134	 0.007438	 0.038641	 0.02215	 157.4	 157.4	 157.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60803	 60115	 0.020217	 0.102667	 0.01413	 171.42	 171.42	 171.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60116	 60135	 0.023313	 0.085269	 0.03229	 160.52	 160.52	 160.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60803	 60117	 0.007946	 0.03953	 0.01679	 174.26	 174.26	 174.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60118	 60119	 0.000202	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60118	 60120	 0.000261	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60119	 60141	 0.045892	 0.188359	 0.03664	 123.44	 123.44	 123.44	 0.0	 0.0	 1	 -30.0	 30.0;
	60121	 60122	 0.000278	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60124	 60121	 0.005439	 0.023518	 0.01945	 134.85	 134.85	 134.85	 0.0	 0.0	 1	 -30.0	 30.0;
	60123	 60124	 0.000225	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60123	 60125	 0.000211	 0.001017	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60126	 60127	 0.000232	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60130	 60126	 0.01199	 0.058572	 0.01757	 137.17	 137.17	 137.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60136	 60126	 0.007277	 0.037432	 0.0313	 154.35	 154.35	 154.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60128	 60129	 0.000254	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60130	 60133	 0.000952	 0.023143	 0.0	 62.2	 62.2	 62.2	 1.0	 0.0	 1	 -30.0	 30.0;
	60139	 60130	 0.018086	 0.06525	 0.0353	 156.94	 156.94	 156.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60130	 60162	 0.005548	 0.02571	 0.09955	 155.22	 155.22	 155.22	 0.0	 0.0	 1	 -30.0	 30.0;
	60131	 60133	 0.016995	 0.413041	 0.0	 31.1	 31.1	 31.1	 1.0	 0.0	 1	 -30.0	 30.0;
	60132	 60133	 0.016995	 0.413041	 0.0	 31.1	 31.1	 31.1	 1.0	 0.0	 1	 -30.0	 30.0;
	60135	 60134	 0.024744	 0.120198	 0.01367	 169.37	 169.37	 169.37	 0.0	 0.0	 1	 -30.0	 30.0;
	60134	 60695	 0.008216	 0.041113	 0.00327	 194.83	 194.83	 194.83	 0.0	 0.0	 1	 -30.0	 30.0;
	60155	 60135	 0.013913	 0.070685	 0.05621	 182.78	 182.78	 182.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60136	 60137	 0.000228	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60136	 60855	 0.016242	 0.075546	 0.02713	 158.86	 158.86	 158.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60138	 60139	 0.000253	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60139	 60151	 0.017555	 0.071835	 0.02273	 163.71	 163.71	 163.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60740	 60139	 0.002723	 0.010367	 0.00233	 183.5	 183.5	 183.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60140	 60141	 0.000279	 0.001006	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 60154	 0.013015	 0.063863	 0.02115	 80.98	 80.98	 80.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60141	 60159	 0.024323	 0.107809	 0.03549	 139.27	 139.27	 139.27	 0.0	 0.0	 1	 -30.0	 30.0;
	60142	 60145	 0.014518	 0.061752	 0.01539	 163.83	 163.83	 163.83	 0.0	 0.0	 1	 -30.0	 30.0;
	60855	 60142	 0.005115	 0.030527	 0.03182	 142.9	 142.9	 142.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60143	 60144	 0.000232	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60143	 60145	 0.000299	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60145	 60163	 0.016991	 0.085765	 0.01612	 167.79	 167.79	 167.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60146	 60147	 0.000289	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60146	 60148	 0.000226	 0.001053	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60162	 60148	 0.00275	 0.014581	 0.0109	 147.59	 147.59	 147.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60148	 60212	 0.007915	 0.040783	 0.0494	 161.87	 161.87	 161.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60149	 60150	 0.000291	 0.001183	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60151	 60149	 0.020427	 0.106736	 0.0168	 145.58	 145.58	 145.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60149	 60170	 0.005063	 0.026523	 0.00614	 157.11	 157.11	 157.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60149	 60180	 0.007778	 0.045016	 0.01267	 148.63	 148.63	 148.63	 0.0	 0.0	 1	 -30.0	 30.0;
	60740	 60151	 0.019467	 0.083086	 0.01568	 166.82	 166.82	 166.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60152	 60153	 0.00021	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60152	 60154	 0.000263	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60219	 60154	 0.018332	 0.099197	 0.03812	 138.73	 138.73	 138.73	 0.0	 0.0	 1	 -30.0	 30.0;
	60156	 60157	 0.000233	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60156	 60159	 0.006566	 0.029592	 0.03125	 159.21	 159.21	 159.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60219	 60156	 0.023025	 0.097464	 0.03084	 134.99	 134.99	 134.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60159	 60158	 0.001311	 0.056843	 0.0	 193.25	 193.25	 193.25	 1.0	 0.0	 1	 -30.0	 30.0;
	60639	 60158	 0.007346	 0.068927	 0.20107	 496.46	 496.46	 496.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60802	 60158	 0.00568	 0.057384	 0.47532	 401.31	 401.31	 401.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60158	 60828	 0.007586	 0.068001	 0.34352	 501.52	 501.52	 501.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60159	 60172	 0.032164	 0.082142	 0.01922	 147.95	 147.95	 147.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60160	 60161	 0.000222	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60160	 60162	 0.007663	 0.027797	 0.00768	 115.65	 115.65	 115.65	 0.0	 0.0	 1	 -30.0	 30.0;
	60177	 60160	 0.001488	 0.007088	 0.00521	 163.5	 163.5	 163.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60163	 60199	 0.029245	 0.087016	 0.01773	 112.66	 112.66	 112.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60163	 70072	 0.022149	 0.108163	 0.03929	 170.01	 170.01	 170.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60164	 60167	 0.000916	 0.016352	 0.0	 117.78	 117.78	 117.78	 1.0	 0.0	 1	 -30.0	 30.0;
	60164	 60168	 0.000243	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60164	 60169	 0.000255	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60165	 60167	 0.010639	 0.189883	 0.0	 58.89	 58.89	 58.89	 1.0	 0.0	 1	 -30.0	 30.0;
	60166	 60167	 0.010639	 0.189883	 0.0	 58.89	 58.89	 58.89	 1.0	 0.0	 1	 -30.0	 30.0;
	60723	 60168	 0.009097	 0.043352	 0.0054	 121.07	 121.07	 121.07	 0.0	 0.0	 1	 -30.0	 30.0;
	60168	 60855	 0.011765	 0.059658	 0.01245	 146.11	 146.11	 146.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60170	 60171	 0.000209	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60170	 60202	 0.005552	 0.024297	 0.09175	 163.3	 163.3	 163.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60216	 60172	 0.008533	 0.037937	 0.01922	 135.71	 135.71	 135.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60173	 60174	 0.000288	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60182	 60173	 0.004488	 0.02159	 0.00533	 158.58	 158.58	 158.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60173	 60190	 0.003179	 0.015274	 0.00141	 147.33	 147.33	 147.33	 0.0	 0.0	 1	 -30.0	 30.0;
	60173	 60773	 0.004461	 0.019991	 0.00499	 163.35	 163.35	 163.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60175	 60176	 0.000252	 0.001023	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60177	 60176	 0.006344	 0.031236	 0.00685	 159.21	 159.21	 159.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60176	 60676	 0.003675	 0.016429	 0.01229	 178.09	 178.09	 178.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60177	 60723	 0.013506	 0.072219	 0.05963	 164.78	 164.78	 164.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60178	 60179	 0.000285	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60178	 60182	 0.005308	 0.023372	 0.03398	 172.71	 172.71	 172.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60676	 60178	 0.002288	 0.010015	 0.00295	 182.54	 182.54	 182.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60180	 60181	 0.000267	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60180	 60205	 0.005022	 0.030422	 0.00702	 118.57	 118.57	 118.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60182	 60183	 0.000245	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60182	 60851	 0.002457	 0.013038	 0.00254	 219.43	 219.43	 219.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 60184	 0.001019	 0.047932	 0.0	 276.19	 276.19	 276.19	 1.1	 0.0	 1	 -30.0	 30.0;
	60185	 60184	 0.001019	 0.047932	 0.0	 276.19	 276.19	 276.19	 1.1	 0.0	 1	 -30.0	 30.0;
	60185	 60184	 0.001019	 0.047932	 0.0	 276.19	 276.19	 276.19	 1.03125	 0.0	 1	 -30.0	 30.0;
	60185	 60184	 0.001019	 0.047932	 0.0	 276.19	 276.19	 276.19	 1.1	 0.0	 1	 -30.0	 30.0;
	60278	 60184	 0.002081	 0.017014	 0.04929	 510.01	 510.01	 510.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60184	 60675	 0.00306	 0.029789	 0.15534	 632.41	 632.41	 632.41	 0.0	 0.0	 1	 -30.0	 30.0;
	60739	 60184	 0.004049	 0.043679	 0.09591	 610.66	 610.66	 610.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60186	 60185	 0.004119	 0.022557	 0.00399	 176.88	 176.88	 176.88	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 60202	 0.000774	 0.003599	 0.00154	 184.12	 184.12	 184.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 60209	 0.006346	 0.031928	 0.0232	 181.18	 181.18	 181.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 60262	 0.006591	 0.029899	 0.01475	 181.12	 181.12	 181.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60185	 60273	 0.004632	 0.024458	 0.01804	 195.78	 195.78	 195.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60260	 60186	 0.004095	 0.017242	 0.00633	 137.68	 137.68	 137.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60187	 60188	 0.000266	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60247	 60187	 0.0067	 0.031691	 0.0096	 147.76	 147.76	 147.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60249	 60187	 0.005459	 0.030075	 0.00448	 175.46	 175.46	 175.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60189	 60247	 0.00878	 0.042895	 0.00474	 160.97	 160.97	 160.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60189	 60676	 0.008354	 0.037366	 0.01896	 182.16	 182.16	 182.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60190	 60191	 0.000201	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60190	 60254	 0.005661	 0.021983	 0.00825	 163.89	 163.89	 163.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60192	 60193	 0.000285	 0.001154	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60192	 60205	 0.007142	 0.025677	 0.10124	 165.32	 165.32	 165.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60192	 60212	 0.010682	 0.040383	 0.06934	 185.43	 185.43	 185.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60271	 60194	 0.003099	 0.013952	 0.01148	 138.33	 138.33	 138.33	 0.0	 0.0	 1	 -30.0	 30.0;
	60194	 60826	 0.004028	 0.018236	 0.00477	 188.84	 188.84	 188.84	 0.0	 0.0	 1	 -30.0	 30.0;
	60195	 60232	 0.001295	 0.006898	 0.0026	 180.26	 180.26	 180.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60851	 60195	 0.002456	 0.01247	 0.00462	 188.36	 188.36	 188.36	 0.0	 0.0	 1	 -30.0	 30.0;
	60196	 60197	 0.00026	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60196	 60198	 0.000291	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60198	 60216	 0.012472	 0.059674	 0.01214	 118.55	 118.55	 118.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60238	 60198	 0.009436	 0.038966	 0.01907	 134.43	 134.43	 134.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60199	 60290	 0.008177	 0.033715	 0.01208	 136.82	 136.82	 136.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60200	 60249	 0.004229	 0.016669	 0.01135	 140.51	 140.51	 140.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60200	 60389	 0.002985	 0.018241	 0.00804	 164.17	 164.17	 164.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60286	 60201	 0.003324	 0.014691	 0.00314	 155.56	 155.56	 155.56	 0.0	 0.0	 1	 -30.0	 30.0;
	60201	 60303	 0.007665	 0.038727	 0.04076	 154.76	 154.76	 154.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60203	 60230	 0.002245	 0.011012	 0.04776	 155.19	 155.19	 155.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60203	 60236	 0.001609	 0.005953	 0.00398	 230.4	 230.4	 230.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60255	 60203	 0.001208	 0.006885	 0.00959	 172.45	 172.45	 172.45	 0.0	 0.0	 1	 -30.0	 30.0;
	60203	 60259	 0.002774	 0.013482	 0.00375	 158.94	 158.94	 158.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60203	 60283	 0.001625	 0.007655	 0.01236	 189.82	 189.82	 189.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60203	 60326	 0.00134	 0.006298	 0.00095	 143.1	 143.1	 143.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60204	 60205	 0.000232	 0.001048	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60204	 60206	 0.000257	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60209	 60205	 0.00652	 0.027892	 0.00875	 144.71	 144.71	 144.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60207	 60208	 0.000216	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60207	 60209	 0.00022	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60210	 60211	 0.000203	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60210	 60212	 0.000261	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60676	 60212	 0.001788	 0.008519	 0.00107	 201.04	 201.04	 201.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60676	 60212	 0.001788	 0.008519	 0.00107	 201.04	 201.04	 201.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60213	 60214	 0.000206	 0.001126	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60213	 60215	 0.000205	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60407	 60215	 0.010812	 0.062656	 0.00813	 156.5	 156.5	 156.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60215	 60411	 0.014039	 0.065037	 0.0205	 145.9	 145.9	 145.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60723	 60217	 0.010338	 0.041706	 0.01428	 111.15	 111.15	 111.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60217	 60784	 0.005133	 0.024601	 0.00685	 173.25	 173.25	 173.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60218	 60288	 0.005792	 0.03063	 0.0033	 161.51	 161.51	 161.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60218	 60306	 0.005011	 0.020328	 0.00844	 152.57	 152.57	 152.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60219	 60220	 0.000283	 0.001143	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60310	 60219	 0.01549	 0.069443	 0.01261	 157.18	 157.18	 157.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60469	 60219	 0.02178	 0.088034	 0.01899	 145.15	 145.15	 145.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60221	 60222	 0.000296	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60253	 60221	 0.002727	 0.014342	 0.00202	 158.2	 158.2	 158.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60221	 60300	 0.003018	 0.011746	 0.00268	 176.24	 176.24	 176.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60223	 60224	 0.000287	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60223	 60225	 0.000268	 0.001127	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60224	 60230	 0.001336	 0.006097	 0.00254	 137.59	 137.59	 137.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60224	 60338	 0.008328	 0.037946	 0.00566	 166.58	 166.58	 166.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60226	 60227	 0.000261	 0.001034	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60227	 60228	 0.001728	 0.010238	 0.00139	 179.05	 179.05	 179.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60227	 70076	 0.025448	 0.123364	 0.06006	 193.16	 193.16	 193.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60228	 60389	 0.018535	 0.06969	 0.03951	 149.76	 149.76	 149.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60229	 60296	 0.002606	 0.011698	 0.00948	 182.4	 182.4	 182.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60229	 60338	 0.002957	 0.015839	 0.00534	 196.9	 196.9	 196.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60229	 60338	 0.002957	 0.015839	 0.00534	 196.9	 196.9	 196.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60230	 60231	 0.000236	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60300	 60230	 0.005741	 0.019447	 0.00696	 176.16	 176.16	 176.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60232	 60260	 0.006659	 0.02345	 0.00766	 150.42	 150.42	 150.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60233	 60234	 0.000294	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60233	 60235	 0.00022	 0.001096	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60235	 60296	 0.001572	 0.008542	 0.00235	 137.61	 137.61	 137.61	 0.0	 0.0	 1	 -30.0	 30.0;
	60235	 60347	 0.000999	 0.006066	 0.00213	 169.44	 169.44	 169.44	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 60237	 0.000201	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 60330	 0.002224	 0.009159	 0.00569	 171.22	 171.22	 171.22	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 60773	 0.002119	 0.009983	 0.03893	 204.17	 204.17	 204.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 60773	 0.002119	 0.009983	 0.03893	 204.17	 204.17	 204.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60236	 60773	 0.002119	 0.009983	 0.03893	 204.17	 204.17	 204.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60238	 60490	 0.004938	 0.024735	 0.06494	 165.19	 165.19	 165.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60239	 60240	 0.000231	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60239	 60241	 0.000239	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60408	 60241	 0.031199	 0.173143	 0.03192	 163.39	 163.39	 163.39	 0.0	 0.0	 1	 -30.0	 30.0;
	60241	 60518	 0.023422	 0.13136	 0.02418	 158.24	 158.24	 158.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60242	 60243	 0.00028	 0.00113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60242	 60244	 0.000278	 0.001036	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60242	 60245	 0.000268	 0.001147	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60296	 60244	 0.001438	 0.006482	 0.00421	 165.15	 165.15	 165.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60326	 60244	 0.001748	 0.006602	 0.00099	 128.21	 128.21	 128.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60249	 60246	 0.003587	 0.021019	 0.01494	 197.14	 197.14	 197.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60249	 60246	 0.003587	 0.021019	 0.01494	 197.14	 197.14	 197.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60246	 60311	 0.002196	 0.010885	 0.04239	 199.69	 199.69	 199.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60246	 60311	 0.002196	 0.010885	 0.04239	 199.69	 199.69	 199.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60246	 60413	 0.00628	 0.022133	 0.09046	 154.6	 154.6	 154.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60247	 60248	 0.00028	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60250	 60283	 0.004598	 0.016818	 0.01102	 191.08	 191.08	 191.08	 0.0	 0.0	 1	 -30.0	 30.0;
	60250	 60352	 0.004098	 0.022374	 0.00931	 166.01	 166.01	 166.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60251	 60252	 0.000231	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60251	 60253	 0.000254	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60253	 60378	 0.005227	 0.019813	 0.03028	 126.04	 126.04	 126.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60254	 60826	 0.005238	 0.026815	 0.00933	 183.04	 183.04	 183.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60255	 60256	 0.000245	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60260	 60255	 0.003473	 0.016327	 0.00262	 143.69	 143.69	 143.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60257	 60273	 0.003043	 0.010344	 0.00323	 173.92	 173.92	 173.92	 0.0	 0.0	 1	 -30.0	 30.0;
	60257	 60362	 0.000655	 0.002586	 0.00114	 147.29	 147.29	 147.29	 0.0	 0.0	 1	 -30.0	 30.0;
	60258	 60272	 0.004102	 0.019113	 0.00398	 158.59	 158.59	 158.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60258	 60365	 0.003085	 0.016262	 0.00662	 210.0	 210.0	 210.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60258	 60838	 0.006124	 0.031198	 0.00784	 176.9	 176.9	 176.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60259	 60283	 0.002891	 0.012983	 0.00322	 162.18	 162.18	 162.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60292	 60259	 0.000557	 0.002718	 0.00121	 227.95	 227.95	 227.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60259	 60308	 0.00225	 0.009548	 0.00535	 218.67	 218.67	 218.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60261	 60262	 0.000229	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60261	 60263	 0.000214	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60262	 60377	 0.004632	 0.016817	 0.01058	 170.41	 170.41	 170.41	 0.0	 0.0	 1	 -30.0	 30.0;
	60264	 60267	 0.001484	 0.064421	 0.0	 341.41	 341.41	 341.41	 1.0	 0.0	 1	 -30.0	 30.0;
	60264	 60725	 0.002807	 0.027207	 0.10689	 605.26	 605.26	 605.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60842	 60264	 0.001652	 0.015734	 0.05161	 513.56	 513.56	 513.56	 0.0	 0.0	 1	 -30.0	 30.0;
	60265	 60267	 -0.000765	 -0.033209	 0.0	 266.41	 266.41	 266.41	 1.0	 0.0	 1	 -30.0	 30.0;
	60268	 60265	 0.000802	 0.003952	 0.00201	 184.62	 184.62	 184.62	 0.0	 0.0	 1	 -30.0	 30.0;
	60284	 60265	 0.003189	 0.017618	 0.00495	 168.45	 168.45	 168.45	 0.0	 0.0	 1	 -30.0	 30.0;
	60265	 60333	 0.004591	 0.020752	 0.01597	 171.25	 171.25	 171.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60266	 60267	 0.004323	 0.187644	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60268	 60269	 0.000263	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60268	 60335	 0.004839	 0.019464	 0.02759	 160.82	 160.82	 160.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60270	 60338	 0.001607	 0.007518	 0.00249	 204.16	 204.16	 204.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60270	 60338	 0.001607	 0.007518	 0.00249	 204.16	 204.16	 204.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60270	 60338	 0.001607	 0.007518	 0.00249	 204.16	 204.16	 204.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60347	 60270	 0.002675	 0.012779	 0.0055	 183.09	 183.09	 183.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60270	 60378	 0.003763	 0.017688	 0.00471	 173.62	 173.62	 173.62	 0.0	 0.0	 1	 -30.0	 30.0;
	60271	 60676	 0.003854	 0.022908	 0.00517	 181.77	 181.77	 181.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60322	 60272	 0.001229	 0.006218	 0.00533	 260.46	 260.46	 260.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60272	 60327	 0.002189	 0.00786	 0.00121	 172.58	 172.58	 172.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60272	 60329	 0.002854	 0.013373	 0.01342	 170.97	 170.97	 170.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60390	 60272	 0.001634	 0.00652	 0.00114	 103.68	 103.68	 103.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60272	 60838	 0.0023	 0.00949	 0.00454	 296.27	 296.27	 296.27	 0.0	 0.0	 1	 -30.0	 30.0;
	60274	 60277	 0.003363	 0.148299	 0.0	 283.09	 283.09	 283.09	 1.0	 0.0	 1	 -30.0	 30.0;
	60274	 60278	 0.000252	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60275	 60277	 -0.001686	 -0.074343	 0.0	 183.09	 183.09	 183.09	 1.0	 0.0	 1	 -30.0	 30.0;
	60326	 60275	 0.001932	 0.007456	 0.00186	 160.76	 160.76	 160.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60330	 60275	 0.001004	 0.004822	 0.00103	 97.23	 97.23	 97.23	 0.0	 0.0	 1	 -30.0	 30.0;
	60276	 60277	 0.010347	 0.456213	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60278	 60307	 0.000926	 0.00772	 0.02197	 642.98	 642.98	 642.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60278	 60387	 0.001114	 0.009528	 0.10356	 525.79	 525.79	 525.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60278	 60675	 0.001554	 0.014985	 0.10349	 653.97	 653.97	 653.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60278	 60684	 0.002835	 0.028165	 0.24278	 577.66	 577.66	 577.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60278	 60842	 0.001103	 0.011437	 0.06396	 578.35	 578.35	 578.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60279	 60280	 0.000246	 0.001184	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60338	 60279	 0.003653	 0.015329	 0.00258	 188.52	 188.52	 188.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60279	 60346	 0.003664	 0.016512	 0.02252	 166.82	 166.82	 166.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60281	 60282	 0.00027	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60281	 60283	 0.000263	 0.001129	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60283	 60308	 0.000705	 0.002715	 0.00075	 216.95	 216.95	 216.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60283	 60308	 0.000705	 0.002715	 0.00075	 216.95	 216.95	 216.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60283	 60308	 0.000705	 0.002715	 0.00075	 216.95	 216.95	 216.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60283	 60309	 0.001403	 0.005831	 0.02487	 187.55	 187.55	 187.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60284	 60285	 0.000217	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60365	 60284	 0.001773	 0.008569	 0.02184	 146.9	 146.9	 146.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60288	 60286	 0.002481	 0.012728	 0.00193	 186.93	 186.93	 186.93	 0.0	 0.0	 1	 -30.0	 30.0;
	60288	 60287	 0.001831	 0.091433	 0.0	 200.12	 200.12	 200.12	 1.08125	 0.0	 1	 -30.0	 30.0;
	60287	 60289	 0.000266	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60287	 60337	 0.003701	 0.03514	 0.2835	 605.97	 605.97	 605.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60684	 60287	 0.002377	 0.021304	 0.07706	 513.89	 513.89	 513.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60783	 60287	 0.001535	 0.014241	 0.04899	 477.52	 477.52	 477.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60886	 60287	 0.005137	 0.049878	 0.14119	 642.89	 642.89	 642.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60287	 70136	 0.006653	 0.056696	 0.29025	 632.78	 632.78	 632.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60290	 60291	 0.000241	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60290	 60888	 0.00527	 0.023128	 0.01576	 160.5	 160.5	 160.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60292	 60328	 0.003069	 0.01629	 0.01878	 169.18	 169.18	 169.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60293	 60294	 0.00024	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60293	 60308	 0.003452	 0.013965	 0.01281	 286.76	 286.76	 286.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60293	 60390	 0.002814	 0.013595	 0.0134	 211.12	 211.12	 211.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60295	 60380	 0.005186	 0.020567	 0.00513	 155.57	 155.57	 155.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60295	 60386	 0.004352	 0.015647	 0.00536	 180.21	 180.21	 180.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60296	 60297	 0.000203	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60296	 60330	 0.002365	 0.008828	 0.00125	 133.08	 133.08	 133.08	 0.0	 0.0	 1	 -30.0	 30.0;
	60298	 60299	 0.000218	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60298	 60300	 0.000267	 0.001012	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60300	 60338	 0.001318	 0.005243	 0.00173	 201.87	 201.87	 201.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60300	 60338	 0.001318	 0.005243	 0.00173	 201.87	 201.87	 201.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60302	 60301	 0.001881	 0.067854	 0.0	 139.7	 139.7	 139.7	 1.0	 0.0	 1	 -30.0	 30.0;
	60301	 60482	 0.003132	 0.028416	 0.08892	 557.87	 557.87	 557.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60301	 60684	 0.001684	 0.014774	 0.21166	 605.31	 605.31	 605.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60301	 60886	 0.003271	 0.030389	 0.08505	 663.0	 663.0	 663.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60302	 60305	 0.005608	 0.170865	 0.0	 242.72	 242.72	 242.72	 1.0	 0.0	 1	 -30.0	 30.0;
	60302	 60554	 0.017228	 0.104748	 0.03723	 213.13	 213.13	 213.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60887	 60302	 0.010732	 0.063989	 0.04553	 250.5	 250.5	 250.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60303	 60305	 -0.001264	 -0.038516	 0.0	 95.0	 95.0	 95.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60564	 60303	 0.016323	 0.078962	 0.02312	 153.71	 153.71	 153.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60304	 60305	 0.022189	 0.676026	 0.0	 159.44	 159.44	 159.44	 1.0	 0.0	 1	 -30.0	 30.0;
	60306	 60784	 0.007837	 0.044014	 0.02242	 188.74	 188.74	 188.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60308	 60307	 0.000882	 0.038476	 0.0	 295.95	 295.95	 295.95	 1.0	 0.0	 1	 -30.0	 30.0;
	60308	 60307	 0.000882	 0.038476	 0.0	 295.95	 295.95	 295.95	 1.0	 0.0	 1	 -30.0	 30.0;
	60308	 60307	 0.000882	 0.038476	 0.0	 295.95	 295.95	 295.95	 1.0	 0.0	 1	 -30.0	 30.0;
	60308	 60307	 0.000882	 0.038476	 0.0	 295.95	 295.95	 295.95	 1.0	 0.0	 1	 -30.0	 30.0;
	60307	 60725	 0.000977	 0.008369	 0.02797	 694.05	 694.05	 694.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60307	 60850	 0.001507	 0.012698	 0.07393	 517.0	 517.0	 517.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60308	 60331	 0.002507	 0.012168	 0.01763	 85.42	 85.42	 85.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60308	 60810	 0.002201	 0.011122	 0.0053	 180.5	 180.5	 180.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60309	 60339	 0.001045	 0.005408	 0.00298	 130.42	 130.42	 130.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60310	 60878	 0.00519	 0.025111	 0.10663	 164.43	 164.43	 164.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60311	 60685	 0.006125	 0.032377	 0.00471	 210.0	 210.0	 210.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60311	 60685	 0.006125	 0.032377	 0.00471	 210.0	 210.0	 210.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60311	 60685	 0.006125	 0.032377	 0.00471	 210.0	 210.0	 210.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60312	 60401	 0.006966	 0.028772	 0.06565	 169.39	 169.39	 169.39	 0.0	 0.0	 1	 -30.0	 30.0;
	60312	 60860	 0.006564	 0.033108	 0.00777	 194.07	 194.07	 194.07	 0.0	 0.0	 1	 -30.0	 30.0;
	60313	 60314	 0.000217	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60313	 60315	 0.003328	 0.014892	 0.00283	 191.83	 191.83	 191.83	 0.0	 0.0	 1	 -30.0	 30.0;
	60313	 60888	 0.01148	 0.040232	 0.01796	 218.53	 218.53	 218.53	 0.0	 0.0	 1	 -30.0	 30.0;
	60315	 60413	 0.009504	 0.040959	 0.02763	 177.42	 177.42	 177.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60316	 60317	 0.000232	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60316	 60318	 0.00027	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60317	 60373	 0.003121	 0.016804	 0.00535	 162.04	 162.04	 162.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60380	 60317	 0.002428	 0.013757	 0.0076	 157.64	 157.64	 157.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60327	 60319	 0.001503	 0.007578	 0.00148	 200.86	 200.86	 200.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60327	 60319	 0.001503	 0.007578	 0.00148	 200.86	 200.86	 200.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60838	 60319	 0.001384	 0.004382	 0.00084	 203.19	 203.19	 203.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60838	 60319	 0.001384	 0.004382	 0.00084	 203.19	 203.19	 203.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60838	 60319	 0.001384	 0.004382	 0.00084	 203.19	 203.19	 203.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60320	 60321	 0.000286	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60320	 60322	 0.000241	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60320	 60323	 0.00026	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60322	 60362	 0.00206	 0.01098	 0.00316	 157.52	 157.52	 157.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60322	 60377	 0.003105	 0.016312	 0.02972	 142.13	 142.13	 142.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60324	 60325	 0.000246	 0.001128	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60324	 60350	 0.00193	 0.008243	 0.00189	 126.71	 126.71	 126.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60324	 60415	 0.003482	 0.014643	 0.00179	 170.01	 170.01	 170.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60726	 60324	 0.001628	 0.007796	 0.00248	 187.75	 187.75	 187.75	 0.0	 0.0	 1	 -30.0	 30.0;
	60327	 60393	 0.002216	 0.012831	 0.01028	 175.69	 175.69	 175.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60328	 60342	 0.00102	 0.004812	 0.00276	 139.49	 139.49	 139.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60362	 60329	 0.001804	 0.008592	 0.00843	 121.35	 121.35	 121.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60331	 60332	 0.000265	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60350	 60331	 0.000898	 0.003884	 0.00145	 160.49	 160.49	 160.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60331	 60378	 0.00349	 0.016895	 0.00298	 138.42	 138.42	 138.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60726	 60331	 0.001676	 0.007008	 0.00148	 180.64	 180.64	 180.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60333	 60411	 0.003725	 0.019903	 0.00405	 146.89	 146.89	 146.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60334	 60335	 0.000264	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60365	 60335	 0.000859	 0.003892	 0.00105	 115.93	 115.93	 115.93	 0.0	 0.0	 1	 -30.0	 30.0;
	60386	 60336	 0.004165	 0.018157	 0.00275	 160.71	 160.71	 160.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60401	 60336	 0.0042	 0.019055	 0.00516	 173.89	 173.89	 173.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60336	 60402	 0.004881	 0.023002	 0.02408	 178.6	 178.6	 178.6	 0.0	 0.0	 1	 -30.0	 30.0;
	60338	 60337	 0.000984	 0.034178	 0.0	 303.18	 303.18	 303.18	 1.0375	 0.0	 1	 -30.0	 30.0;
	60338	 60337	 0.000984	 0.034178	 0.0	 303.18	 303.18	 303.18	 1.0375	 0.0	 1	 -30.0	 30.0;
	60338	 60337	 0.000984	 0.034178	 0.0	 303.18	 303.18	 303.18	 1.0375	 0.0	 1	 -30.0	 30.0;
	60338	 60337	 0.000984	 0.034178	 0.0	 303.18	 303.18	 303.18	 1.0375	 0.0	 1	 -30.0	 30.0;
	60387	 60337	 0.001598	 0.012874	 0.03342	 498.34	 498.34	 498.34	 0.0	 0.0	 1	 -30.0	 30.0;
	60675	 60337	 0.002268	 0.019217	 0.05285	 652.15	 652.15	 652.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60337	 60725	 0.001348	 0.01204	 0.03393	 558.67	 558.67	 558.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60337	 60863	 0.002566	 0.024203	 0.08846	 558.05	 558.05	 558.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60339	 60340	 0.00025	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60339	 60350	 0.003052	 0.011702	 0.00239	 171.95	 171.95	 171.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60369	 60339	 0.001896	 0.010862	 0.00798	 150.9	 150.9	 150.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60448	 60341	 0.005043	 0.02211	 0.0314	 138.9	 138.9	 138.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60341	 60523	 0.005799	 0.026877	 0.03281	 163.23	 163.23	 163.23	 0.0	 0.0	 1	 -30.0	 30.0;
	60342	 60838	 0.006309	 0.023453	 0.00791	 162.49	 162.49	 162.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60343	 60350	 0.002105	 0.011343	 0.00965	 155.48	 155.48	 155.48	 0.0	 0.0	 1	 -30.0	 30.0;
	60452	 60343	 0.000946	 0.004555	 0.00448	 137.09	 137.09	 137.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60344	 60345	 0.000298	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60344	 60346	 0.000238	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60346	 60372	 0.001747	 0.007479	 0.00158	 168.64	 168.64	 168.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60388	 60346	 0.000944	 0.004224	 0.00049	 161.06	 161.06	 161.06	 0.0	 0.0	 1	 -30.0	 30.0;
	60346	 60401	 0.001817	 0.00879	 0.00218	 181.03	 181.03	 181.03	 0.0	 0.0	 1	 -30.0	 30.0;
	60348	 60349	 0.000235	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60348	 60350	 0.000216	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60348	 60351	 0.000232	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60350	 60726	 0.000968	 0.005952	 0.00086	 192.15	 192.15	 192.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60352	 60353	 0.000274	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60404	 60352	 0.00144	 0.006121	 0.00199	 169.66	 169.66	 169.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60352	 60426	 0.002936	 0.013233	 0.05563	 167.57	 167.57	 167.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 60354	 0.001325	 0.05953	 0.0	 264.25	 264.25	 264.25	 1.0	 0.0	 1	 -30.0	 30.0;
	60355	 60354	 0.001325	 0.05953	 0.0	 264.25	 264.25	 264.25	 1.0	 0.0	 1	 -30.0	 30.0;
	60355	 60354	 0.001325	 0.05953	 0.0	 264.25	 264.25	 264.25	 1.0	 0.0	 1	 -30.0	 30.0;
	60354	 60356	 0.000241	 0.001103	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60354	 60370	 0.001384	 0.011002	 0.05721	 525.57	 525.57	 525.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60725	 60354	 0.001839	 0.017154	 0.0599	 628.65	 628.65	 628.65	 0.0	 0.0	 1	 -30.0	 30.0;
	60354	 60753	 0.002411	 0.021407	 0.14553	 594.39	 594.39	 594.39	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 60383	 0.000549	 0.002454	 0.00089	 228.02	 228.02	 228.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 60383	 0.000549	 0.002454	 0.00089	 228.02	 228.02	 228.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 60383	 0.000549	 0.002454	 0.00089	 228.02	 228.02	 228.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60355	 60398	 0.002513	 0.010438	 0.003	 171.58	 171.58	 171.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60357	 60358	 0.00022	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60357	 60359	 0.000258	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60375	 60359	 0.002087	 0.00752	 0.00147	 155.67	 155.67	 155.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60359	 60838	 0.003937	 0.019453	 0.00363	 185.51	 185.51	 185.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60360	 60361	 0.000269	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60404	 60361	 0.001129	 0.005673	 0.00279	 167.94	 167.94	 167.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60409	 60361	 0.00344	 0.015872	 0.00625	 139.67	 139.67	 139.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60361	 60810	 0.003593	 0.016971	 0.00754	 189.67	 189.67	 189.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60363	 60364	 0.000264	 0.001041	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60369	 60363	 0.001635	 0.007651	 0.00242	 133.46	 133.46	 133.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60363	 60810	 0.000832	 0.003764	 0.00135	 170.65	 170.65	 170.65	 0.0	 0.0	 1	 -30.0	 30.0;
	60366	 60367	 0.000206	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60366	 60368	 0.00029	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60368	 60417	 0.001035	 0.00447	 0.00081	 159.0	 159.0	 159.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60368	 60433	 0.001948	 0.008719	 0.00694	 168.01	 168.01	 168.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60496	 60368	 0.001978	 0.008268	 0.01266	 179.01	 179.01	 179.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60371	 60370	 0.001994	 0.063574	 0.0	 250.9	 250.9	 250.9	 1.04375	 0.0	 1	 -30.0	 30.0;
	60371	 60370	 0.001994	 0.063574	 0.0	 250.9	 250.9	 250.9	 1.04375	 0.0	 1	 -30.0	 30.0;
	60371	 60370	 0.001994	 0.063574	 0.0	 250.9	 250.9	 250.9	 1.04375	 0.0	 1	 -30.0	 30.0;
	60725	 60370	 0.000888	 0.00749	 0.04083	 656.64	 656.64	 656.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60370	 60753	 0.001725	 0.017705	 0.05777	 561.31	 561.31	 561.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60394	 60371	 0.001309	 0.004952	 0.00114	 190.79	 190.79	 190.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60451	 60371	 0.001506	 0.005426	 0.01189	 184.61	 184.61	 184.61	 0.0	 0.0	 1	 -30.0	 30.0;
	60371	 60452	 0.002378	 0.009218	 0.00128	 175.24	 175.24	 175.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60430	 60372	 0.002974	 0.013827	 0.00227	 147.01	 147.01	 147.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60373	 60477	 0.010226	 0.051501	 0.02258	 168.18	 168.18	 168.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60374	 60375	 0.000283	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60374	 60376	 0.000277	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60375	 60382	 0.004826	 0.021353	 0.02136	 164.52	 164.52	 164.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60390	 60375	 0.003558	 0.016253	 0.00339	 156.86	 156.86	 156.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60375	 60393	 0.001506	 0.005591	 0.00113	 152.67	 152.67	 152.67	 0.0	 0.0	 1	 -30.0	 30.0;
	60378	 60379	 0.000226	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60380	 60381	 0.000293	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60419	 60380	 0.003869	 0.022236	 0.00546	 167.78	 167.78	 167.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60426	 60382	 0.002273	 0.010827	 0.0017	 131.54	 131.54	 131.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60383	 60384	 0.000221	 0.001081	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60391	 60383	 0.000434	 0.002144	 0.00103	 198.94	 198.94	 198.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60391	 60383	 0.000434	 0.002144	 0.00103	 198.94	 198.94	 198.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60383	 60396	 0.002782	 0.011994	 0.01228	 228.53	 228.53	 228.53	 0.0	 0.0	 1	 -30.0	 30.0;
	60386	 60385	 0.001713	 0.074857	 0.0	 227.71	 227.71	 227.71	 1.025	 0.0	 1	 -30.0	 30.0;
	60386	 60385	 0.001713	 0.074857	 0.0	 227.71	 227.71	 227.71	 1.1	 0.0	 1	 -30.0	 30.0;
	60386	 60385	 0.001713	 0.074857	 0.0	 227.71	 227.71	 227.71	 1.1	 0.0	 1	 -30.0	 30.0;
	60385	 60387	 0.000201	 0.001115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60386	 60419	 0.001851	 0.009466	 0.00714	 182.29	 182.29	 182.29	 0.0	 0.0	 1	 -30.0	 30.0;
	60387	 60673	 0.002369	 0.022476	 0.04353	 563.74	 563.74	 563.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60675	 60387	 0.002163	 0.019141	 0.06168	 618.3	 618.3	 618.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60863	 60387	 0.002199	 0.021268	 0.03447	 530.47	 530.47	 530.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60451	 60388	 0.002202	 0.011709	 0.00522	 156.42	 156.42	 156.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60470	 60389	 0.009655	 0.039905	 0.00962	 162.55	 162.55	 162.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60389	 60481	 0.005793	 0.030657	 0.0583	 149.08	 149.08	 149.08	 0.0	 0.0	 1	 -30.0	 30.0;
	60391	 60458	 0.001488	 0.007555	 0.00999	 189.29	 189.29	 189.29	 0.0	 0.0	 1	 -30.0	 30.0;
	60436	 60392	 0.005909	 0.029085	 0.00591	 168.01	 168.01	 168.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60440	 60392	 0.011176	 0.046117	 0.01495	 185.41	 185.41	 185.41	 0.0	 0.0	 1	 -30.0	 30.0;
	60394	 60395	 0.000208	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60420	 60394	 0.000773	 0.003779	 0.01295	 173.46	 173.46	 173.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60480	 60394	 0.009019	 0.035839	 0.0059	 140.92	 140.92	 140.92	 0.0	 0.0	 1	 -30.0	 30.0;
	60396	 60418	 0.00166	 0.00603	 0.02425	 236.97	 236.97	 236.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60396	 60456	 0.000686	 0.003351	 0.00052	 151.53	 151.53	 151.53	 0.0	 0.0	 1	 -30.0	 30.0;
	60397	 60398	 0.000291	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60457	 60398	 0.003466	 0.015988	 0.00424	 139.69	 139.69	 139.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60399	 60400	 0.00026	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60399	 60401	 0.00021	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60860	 60402	 0.005682	 0.023937	 0.01692	 191.31	 191.31	 191.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60403	 60404	 0.000213	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60404	 60415	 0.005861	 0.027973	 0.01641	 175.66	 175.66	 175.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60458	 60404	 0.002347	 0.010634	 0.00201	 156.98	 156.98	 156.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60405	 60406	 0.000253	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60432	 60405	 0.002196	 0.009809	 0.00599	 130.86	 130.86	 130.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60490	 60405	 0.0051	 0.014563	 0.00305	 164.91	 164.91	 164.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60407	 60459	 0.009442	 0.044049	 0.01574	 152.27	 152.27	 152.27	 0.0	 0.0	 1	 -30.0	 30.0;
	60460	 60407	 0.013741	 0.057859	 0.01285	 151.4	 151.4	 151.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60408	 60469	 0.01761	 0.079734	 0.01996	 145.51	 145.51	 145.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60408	 60528	 0.020766	 0.074397	 0.0193	 154.16	 154.16	 154.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60409	 60410	 0.000226	 0.001085	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60421	 60409	 0.004714	 0.022748	 0.00571	 162.47	 162.47	 162.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60411	 60414	 0.004782	 0.02392	 0.00355	 138.73	 138.73	 138.73	 0.0	 0.0	 1	 -30.0	 30.0;
	60412	 60413	 0.000284	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60436	 60414	 0.003326	 0.017185	 0.00371	 174.38	 174.38	 174.38	 0.0	 0.0	 1	 -30.0	 30.0;
	60415	 60416	 0.000266	 0.001121	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60420	 60415	 0.002973	 0.012853	 0.00557	 158.51	 158.51	 158.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60417	 60440	 0.01334	 0.061989	 0.03048	 181.81	 181.81	 181.81	 0.0	 0.0	 1	 -30.0	 30.0;
	60418	 60425	 0.001404	 0.007331	 0.00145	 133.77	 133.77	 133.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60418	 60558	 0.002425	 0.010719	 0.00625	 147.06	 147.06	 147.06	 0.0	 0.0	 1	 -30.0	 30.0;
	60421	 60487	 0.001598	 0.006819	 0.00701	 140.0	 140.0	 140.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60421	 60488	 0.002692	 0.011265	 0.00227	 179.92	 179.92	 179.92	 0.0	 0.0	 1	 -30.0	 30.0;
	60422	 60431	 0.002073	 0.008167	 0.00381	 147.56	 147.56	 147.56	 0.0	 0.0	 1	 -30.0	 30.0;
	60478	 60422	 0.002273	 0.009759	 0.00235	 142.56	 142.56	 142.56	 0.0	 0.0	 1	 -30.0	 30.0;
	60423	 60471	 0.003225	 0.015901	 0.0023	 151.58	 151.58	 151.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60423	 60500	 0.005122	 0.023767	 0.00704	 160.52	 160.52	 160.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60424	 60441	 0.002164	 0.009263	 0.00399	 133.09	 133.09	 133.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60424	 60854	 0.004048	 0.019129	 0.00658	 168.74	 168.74	 168.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60425	 60433	 0.003141	 0.012396	 0.01843	 146.63	 146.63	 146.63	 0.0	 0.0	 1	 -30.0	 30.0;
	60425	 60511	 0.001759	 0.007929	 0.00099	 152.81	 152.81	 152.81	 0.0	 0.0	 1	 -30.0	 30.0;
	60427	 60428	 0.000203	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60427	 60429	 0.00027	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60429	 60501	 0.00332	 0.011288	 0.00201	 156.62	 156.62	 156.62	 0.0	 0.0	 1	 -30.0	 30.0;
	60429	 60502	 0.002359	 0.010548	 0.00181	 159.95	 159.95	 159.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60429	 60878	 0.005847	 0.028331	 0.03262	 233.76	 233.76	 233.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60430	 60726	 0.003886	 0.01424	 0.00314	 180.2	 180.2	 180.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60431	 60520	 0.003417	 0.017294	 0.05688	 181.24	 181.24	 181.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60432	 60449	 0.002035	 0.008454	 0.00469	 134.18	 134.18	 134.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60490	 60432	 0.003686	 0.016634	 0.01183	 161.78	 161.78	 161.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60434	 60435	 0.000288	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60434	 60436	 0.000216	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60434	 60437	 0.000225	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60434	 60438	 0.000259	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60436	 60499	 0.004464	 0.019578	 0.01988	 170.1	 170.1	 170.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60440	 60439	 0.000976	 0.043249	 0.0	 237.08	 237.08	 237.08	 1.0	 0.0	 1	 -30.0	 30.0;
	60440	 60439	 0.000976	 0.043249	 0.0	 237.08	 237.08	 237.08	 1.0	 0.0	 1	 -30.0	 30.0;
	60440	 60439	 0.000976	 0.043249	 0.0	 237.08	 237.08	 237.08	 1.0	 0.0	 1	 -30.0	 30.0;
	60439	 60639	 0.004833	 0.041182	 0.42455	 536.98	 536.98	 536.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60439	 60649	 0.009858	 0.071014	 0.22773	 629.31	 629.31	 629.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60459	 60440	 0.007511	 0.040524	 0.01647	 174.89	 174.89	 174.89	 0.0	 0.0	 1	 -30.0	 30.0;
	60441	 60442	 0.000226	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60441	 60535	 0.007469	 0.034803	 0.01504	 166.82	 166.82	 166.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60854	 60441	 0.002053	 0.009721	 0.00309	 187.64	 187.64	 187.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60443	 60446	 -0.000526	 -0.01474	 0.0	 133.23	 133.23	 133.23	 1.0	 0.0	 1	 -30.0	 30.0;
	60443	 60447	 0.000201	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60444	 60446	 0.006953	 0.194688	 0.0	 66.62	 66.62	 66.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60445	 60446	 0.006953	 0.194688	 0.0	 66.62	 66.62	 66.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60466	 60447	 0.00175	 0.007539	 0.00089	 149.32	 149.32	 149.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60447	 60854	 0.007239	 0.03275	 0.00945	 172.47	 172.47	 172.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60470	 60448	 0.005907	 0.024377	 0.00565	 168.84	 168.84	 168.84	 0.0	 0.0	 1	 -30.0	 30.0;
	60448	 60483	 0.002182	 0.012539	 0.00254	 184.62	 184.62	 184.62	 0.0	 0.0	 1	 -30.0	 30.0;
	60449	 60589	 0.010238	 0.039464	 0.09838	 170.98	 170.98	 170.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60450	 60451	 0.000246	 0.001004	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60453	 60454	 0.00024	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60522	 60453	 0.003366	 0.012025	 0.00274	 106.68	 106.68	 106.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60550	 60453	 0.004493	 0.01668	 0.0038	 166.43	 166.43	 166.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60455	 60456	 0.004219	 0.017778	 0.00932	 155.09	 155.09	 155.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60455	 60488	 0.004531	 0.017534	 0.00351	 181.94	 181.94	 181.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60457	 60488	 0.004785	 0.020603	 0.0192	 169.93	 169.93	 169.93	 0.0	 0.0	 1	 -30.0	 30.0;
	60460	 60463	 0.001588	 0.043004	 0.0	 56.41	 56.41	 56.41	 1.0	 0.0	 1	 -30.0	 30.0;
	60460	 60573	 0.024179	 0.076816	 0.02677	 172.09	 172.09	 172.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60461	 60463	 0.015823	 0.428423	 0.0	 28.21	 28.21	 28.21	 1.0	 0.0	 1	 -30.0	 30.0;
	60462	 60463	 0.015823	 0.428423	 0.0	 28.21	 28.21	 28.21	 1.0	 0.0	 1	 -30.0	 30.0;
	60464	 60490	 0.005026	 0.023945	 0.00383	 159.32	 159.32	 159.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60464	 60507	 0.004799	 0.020279	 0.01983	 161.47	 161.47	 161.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60464	 60524	 0.001547	 0.006964	 0.00122	 163.58	 163.58	 163.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60465	 60466	 0.000286	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60509	 60466	 0.004196	 0.016252	 0.00288	 143.42	 143.42	 143.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60467	 60493	 0.005945	 0.028565	 0.01511	 134.34	 134.34	 134.34	 0.0	 0.0	 1	 -30.0	 30.0;
	60535	 60467	 0.001799	 0.008555	 0.00146	 151.16	 151.16	 151.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60467	 60536	 0.01382	 0.064149	 0.01314	 138.05	 138.05	 138.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60528	 60468	 0.013263	 0.0582	 0.01063	 167.21	 167.21	 167.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60468	 60566	 0.005406	 0.026636	 0.01552	 165.18	 165.18	 165.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60468	 60574	 0.009945	 0.047615	 0.02647	 166.58	 166.58	 166.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60469	 60659	 0.016026	 0.091055	 0.01982	 183.12	 183.12	 183.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60471	 60500	 0.003003	 0.015458	 0.00699	 155.93	 155.93	 155.93	 0.0	 0.0	 1	 -30.0	 30.0;
	60471	 60521	 0.00611	 0.030354	 0.00725	 157.04	 157.04	 157.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60473	 60472	 0.013286	 0.057755	 0.00958	 151.97	 151.97	 151.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60472	 60845	 0.005825	 0.02155	 0.00614	 179.3	 179.3	 179.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60473	 60476	 -0.00181	 -0.043175	 0.0	 50.35	 50.35	 50.35	 1.0	 0.0	 1	 -30.0	 30.0;
	60754	 60473	 0.006041	 0.025285	 0.01143	 149.44	 149.44	 149.44	 0.0	 0.0	 1	 -30.0	 30.0;
	60474	 60476	 0.027129	 0.647113	 0.0	 25.17	 25.17	 25.17	 1.0	 0.0	 1	 -30.0	 30.0;
	60475	 60476	 0.027129	 0.647113	 0.0	 25.17	 25.17	 25.17	 1.0	 0.0	 1	 -30.0	 30.0;
	60477	 60685	 0.008336	 0.036906	 0.00566	 183.57	 183.57	 183.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60478	 60715	 0.011965	 0.039668	 0.00705	 180.9	 180.9	 180.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60479	 60480	 0.000276	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60480	 60845	 0.007954	 0.041993	 0.04505	 180.28	 180.28	 180.28	 0.0	 0.0	 1	 -30.0	 30.0;
	60481	 60570	 0.011146	 0.052927	 0.08502	 188.77	 188.77	 188.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60483	 60482	 0.001166	 0.053936	 0.0	 236.02	 236.02	 236.02	 1.0	 0.0	 1	 -30.0	 30.0;
	60483	 60482	 0.001166	 0.053936	 0.0	 236.02	 236.02	 236.02	 1.0	 0.0	 1	 -30.0	 30.0;
	60483	 60482	 0.001166	 0.053936	 0.0	 236.02	 236.02	 236.02	 1.0	 0.0	 1	 -30.0	 30.0;
	60482	 60556	 0.002844	 0.024193	 0.03674	 608.17	 608.17	 608.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60523	 60483	 0.00059	 0.002901	 0.00102	 215.79	 215.79	 215.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60483	 60552	 0.003406	 0.014689	 0.06105	 172.06	 172.06	 172.06	 0.0	 0.0	 1	 -30.0	 30.0;
	60484	 60485	 0.000232	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60494	 60485	 0.00259	 0.011669	 0.00401	 160.44	 160.44	 160.44	 0.0	 0.0	 1	 -30.0	 30.0;
	60514	 60485	 0.002204	 0.011835	 0.00474	 163.59	 163.59	 163.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60485	 60587	 0.010643	 0.055623	 0.01801	 163.99	 163.99	 163.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60495	 60486	 0.00551	 0.022678	 0.0055	 151.0	 151.0	 151.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60486	 60557	 0.006502	 0.030721	 0.01968	 151.91	 151.91	 151.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60487	 60590	 0.009133	 0.043024	 0.09969	 176.29	 176.29	 176.29	 0.0	 0.0	 1	 -30.0	 30.0;
	60488	 60832	 0.008693	 0.037013	 0.14549	 212.59	 212.59	 212.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60488	 60832	 0.008693	 0.037013	 0.14549	 212.59	 212.59	 212.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60488	 60832	 0.008693	 0.037013	 0.14549	 212.59	 212.59	 212.59	 0.0	 0.0	 1	 -30.0	 30.0;
	60490	 60489	 0.00111	 0.043606	 0.0	 272.23	 272.23	 272.23	 1.1	 0.0	 1	 -30.0	 30.0;
	60490	 60489	 0.00111	 0.043606	 0.0	 272.23	 272.23	 272.23	 1.1	 0.0	 1	 -30.0	 30.0;
	60490	 60489	 0.00111	 0.043606	 0.0	 272.23	 272.23	 272.23	 1.1	 0.0	 1	 -30.0	 30.0;
	60489	 60796	 0.005854	 0.057793	 0.2476	 563.47	 563.47	 563.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60853	 60489	 0.002215	 0.020105	 0.03388	 536.61	 536.61	 536.61	 0.0	 0.0	 1	 -30.0	 30.0;
	60877	 60489	 0.003262	 0.029729	 0.13208	 584.57	 584.57	 584.57	 0.0	 0.0	 1	 -30.0	 30.0;
	60493	 60490	 0.003369	 0.0143	 0.00393	 179.51	 179.51	 179.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60490	 60526	 0.004132	 0.01629	 0.0059	 191.88	 191.88	 191.88	 0.0	 0.0	 1	 -30.0	 30.0;
	60490	 60543	 0.007101	 0.036371	 0.01441	 160.11	 160.11	 160.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60491	 60492	 0.000294	 0.001141	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60491	 60493	 0.000201	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60542	 60494	 0.005625	 0.024504	 0.00593	 135.78	 135.78	 135.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60494	 60549	 0.006093	 0.02639	 0.01523	 165.46	 165.46	 165.46	 0.0	 0.0	 1	 -30.0	 30.0;
	60511	 60495	 0.004905	 0.022974	 0.00288	 193.3	 193.3	 193.3	 0.0	 0.0	 1	 -30.0	 30.0;
	60495	 60715	 0.007076	 0.028735	 0.01781	 211.49	 211.49	 211.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60495	 60715	 0.007076	 0.028735	 0.01781	 211.49	 211.49	 211.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60495	 60715	 0.007076	 0.028735	 0.01781	 211.49	 211.49	 211.49	 0.0	 0.0	 1	 -30.0	 30.0;
	60496	 60497	 0.000271	 0.001063	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60496	 60499	 0.000373	 0.001893	 0.00042	 198.08	 198.08	 198.08	 0.0	 0.0	 1	 -30.0	 30.0;
	60496	 60499	 0.000373	 0.001893	 0.00042	 198.08	 198.08	 198.08	 0.0	 0.0	 1	 -30.0	 30.0;
	60499	 60498	 0.001958	 0.079408	 0.0	 234.32	 234.32	 234.32	 1.0	 0.0	 1	 -30.0	 30.0;
	60499	 60498	 0.001958	 0.079408	 0.0	 234.32	 234.32	 234.32	 1.0	 0.0	 1	 -30.0	 30.0;
	60499	 60498	 0.001958	 0.079408	 0.0	 234.32	 234.32	 234.32	 1.0	 0.0	 1	 -30.0	 30.0;
	60498	 60510	 0.00081	 0.008309	 0.01952	 511.4	 511.4	 511.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60498	 60639	 0.004393	 0.038882	 0.86038	 567.45	 567.45	 567.45	 0.0	 0.0	 1	 -30.0	 30.0;
	60498	 60842	 0.000814	 0.007424	 0.11766	 497.42	 497.42	 497.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60504	 60500	 0.003159	 0.015619	 0.00416	 154.55	 154.55	 154.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60500	 60522	 0.00338	 0.018638	 0.00594	 164.35	 164.35	 164.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60500	 60854	 0.003723	 0.016487	 0.01134	 169.15	 169.15	 169.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60500	 60878	 0.005563	 0.026686	 0.02579	 294.95	 294.95	 294.95	 0.0	 0.0	 1	 -30.0	 30.0;
	60501	 60504	 0.002422	 0.009777	 0.00166	 141.51	 141.51	 141.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60516	 60501	 0.000548	 0.002476	 0.0006	 159.34	 159.34	 159.34	 0.0	 0.0	 1	 -30.0	 30.0;
	60502	 60503	 0.000223	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60502	 60516	 0.002282	 0.012036	 0.00467	 133.92	 133.92	 133.92	 0.0	 0.0	 1	 -30.0	 30.0;
	60506	 60505	 0.004449	 0.016434	 0.00496	 124.8	 124.8	 124.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60576	 60505	 0.004163	 0.02433	 0.02604	 161.9	 161.9	 161.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60636	 60506	 0.011133	 0.049919	 0.01733	 126.36	 126.36	 126.36	 0.0	 0.0	 1	 -30.0	 30.0;
	60506	 60787	 0.010152	 0.056283	 0.0315	 169.5	 169.5	 169.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60526	 60507	 0.007404	 0.028369	 0.00554	 144.81	 144.81	 144.81	 0.0	 0.0	 1	 -30.0	 30.0;
	60508	 60509	 0.000286	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60509	 60762	 0.002958	 0.011772	 0.00295	 152.47	 152.47	 152.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60509	 60854	 0.006415	 0.031771	 0.00698	 172.35	 172.35	 172.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60510	 60513	 0.005069	 0.174752	 0.0	 253.06	 253.06	 253.06	 1.0	 0.0	 1	 -30.0	 30.0;
	60510	 60714	 0.001617	 0.016212	 0.05867	 514.02	 514.02	 514.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60511	 60513	 -0.00257	 -0.088607	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60512	 60513	 0.011905	 0.410462	 0.0	 142.6	 142.6	 142.6	 1.0	 0.0	 1	 -30.0	 30.0;
	60514	 60541	 0.004926	 0.023095	 0.04162	 199.52	 199.52	 199.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60514	 60541	 0.004926	 0.023095	 0.04162	 199.52	 199.52	 199.52	 0.0	 0.0	 1	 -30.0	 30.0;
	60514	 60557	 0.010278	 0.046547	 0.0262	 167.12	 167.12	 167.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60558	 60514	 0.00245	 0.011072	 0.00732	 174.24	 174.24	 174.24	 0.0	 0.0	 1	 -30.0	 30.0;
	60515	 60527	 0.00261	 0.012092	 0.00337	 149.68	 149.68	 149.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60515	 60548	 0.002946	 0.016259	 0.01123	 157.55	 157.55	 157.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60516	 60517	 0.000291	 0.001189	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60854	 60516	 0.002932	 0.01256	 0.00465	 184.14	 184.14	 184.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60578	 60518	 0.01857	 0.106564	 0.04348	 181.11	 181.11	 181.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60518	 60594	 0.037784	 0.196973	 0.03873	 173.05	 173.05	 173.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60519	 60520	 0.000257	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60520	 60568	 0.013804	 0.052888	 0.01708	 141.04	 141.04	 141.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60520	 60754	 0.001012	 0.005519	 0.00131	 189.51	 189.51	 189.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60521	 60551	 0.009744	 0.03956	 0.01469	 179.69	 179.69	 179.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60685	 60523	 0.005658	 0.027834	 0.01447	 144.15	 144.15	 144.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60527	 0.003276	 0.015101	 0.03	 173.33	 173.33	 173.33	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60535	 0.005405	 0.020761	 0.00462	 152.88	 152.88	 152.88	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60545	 0.004459	 0.0145	 0.00587	 164.32	 164.32	 164.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60854	 0.006967	 0.025596	 0.02635	 209.32	 209.32	 209.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60854	 0.006967	 0.025596	 0.02635	 209.32	 209.32	 209.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60524	 60854	 0.006967	 0.025596	 0.02635	 209.32	 209.32	 209.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60525	 60526	 0.000261	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60548	 60526	 0.002908	 0.014577	 0.00294	 137.71	 137.71	 137.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60528	 60529	 0.000288	 0.001051	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60528	 60530	 0.014331	 0.063493	 0.0132	 147.13	 147.13	 147.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60530	 60531	 0.000248	 0.001066	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60530	 60659	 0.01709	 0.08959	 0.00617	 172.77	 172.77	 172.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60532	 60533	 0.000295	 0.001155	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60532	 60534	 0.000295	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60534	 60542	 0.003572	 0.019885	 0.06543	 177.17	 177.17	 177.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60579	 60534	 0.008758	 0.044107	 0.01151	 182.25	 182.25	 182.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60561	 60536	 0.005828	 0.030088	 0.00838	 172.42	 172.42	 172.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60537	 60540	 0.000661	 0.01729	 0.0	 159.32	 159.32	 159.32	 1.0	 0.0	 1	 -30.0	 30.0;
	60537	 60541	 0.000283	 0.001083	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60538	 60540	 0.006569	 0.171906	 0.0	 79.66	 79.66	 79.66	 1.0	 0.0	 1	 -30.0	 30.0;
	60539	 60540	 0.006569	 0.171906	 0.0	 79.66	 79.66	 79.66	 1.0	 0.0	 1	 -30.0	 30.0;
	60549	 60541	 0.005622	 0.02066	 0.00775	 178.13	 178.13	 178.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60541	 60715	 0.005698	 0.025532	 0.00827	 214.99	 214.99	 214.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60541	 60715	 0.005698	 0.025532	 0.00827	 214.99	 214.99	 214.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60541	 60715	 0.005698	 0.025532	 0.00827	 214.99	 214.99	 214.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60543	 60544	 0.000288	 0.00118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60543	 60545	 0.004086	 0.013841	 0.00191	 123.78	 123.78	 123.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60545	 60548	 0.002122	 0.011624	 0.00267	 122.5	 122.5	 122.5	 0.0	 0.0	 1	 -30.0	 30.0;
	60546	 60547	 0.000217	 0.00111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60547	 60754	 0.001363	 0.005784	 0.00367	 148.04	 148.04	 148.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60547	 60832	 0.007411	 0.038337	 0.02009	 166.14	 166.14	 166.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60548	 60762	 0.004252	 0.018824	 0.01783	 170.68	 170.68	 170.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60550	 60878	 0.008174	 0.037331	 0.01008	 187.78	 187.78	 187.78	 0.0	 0.0	 1	 -30.0	 30.0;
	60551	 60636	 0.002977	 0.014167	 0.00298	 189.83	 189.83	 189.83	 0.0	 0.0	 1	 -30.0	 30.0;
	60777	 60551	 0.00984	 0.030788	 0.006	 165.02	 165.02	 165.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60552	 60555	 0.002815	 0.012621	 0.00193	 134.84	 134.84	 134.84	 0.0	 0.0	 1	 -30.0	 30.0;
	60554	 60553	 0.001337	 0.051766	 0.0	 170.05	 170.05	 170.05	 1.0	 0.0	 1	 -30.0	 30.0;
	60553	 60556	 0.00021	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60555	 60554	 0.005065	 0.158188	 0.0	 83.81	 83.81	 83.81	 1.0	 0.0	 1	 -30.0	 30.0;
	60555	 60554	 0.005065	 0.158188	 0.0	 83.81	 83.81	 83.81	 1.0	 0.0	 1	 -30.0	 30.0;
	60555	 60554	 0.005065	 0.158188	 0.0	 83.81	 83.81	 83.81	 1.0	 0.0	 1	 -30.0	 30.0;
	60555	 60560	 0.001187	 0.006652	 0.01199	 137.83	 137.83	 137.83	 0.0	 0.0	 1	 -30.0	 30.0;
	60586	 60555	 0.006521	 0.03559	 0.00801	 164.77	 164.77	 164.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60556	 60710	 0.006541	 0.063336	 0.2931	 561.91	 561.91	 561.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60556	 60749	 0.009064	 0.071919	 0.1851	 552.8	 552.8	 552.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60573	 60557	 0.010442	 0.043514	 0.02708	 191.58	 191.58	 191.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60558	 60559	 0.000274	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60560	 60564	 0.005916	 0.031593	 0.00479	 167.55	 167.55	 167.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60570	 60560	 0.007614	 0.036305	 0.09043	 179.54	 179.54	 179.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60561	 60562	 0.000225	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60561	 60777	 0.006436	 0.038319	 0.01575	 183.32	 183.32	 183.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60563	 60564	 0.00023	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60563	 60565	 0.000237	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60659	 60566	 0.005732	 0.031909	 0.00535	 185.66	 185.66	 185.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60567	 60576	 0.00473	 0.019691	 0.00148	 136.53	 136.53	 136.53	 0.0	 0.0	 1	 -30.0	 30.0;
	60582	 60567	 0.007607	 0.034768	 0.01614	 161.09	 161.09	 161.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60584	 60568	 0.010185	 0.046398	 0.01532	 153.62	 153.62	 153.62	 0.0	 0.0	 1	 -30.0	 30.0;
	60569	 60570	 0.000273	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60569	 60571	 0.000293	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60569	 60572	 0.000278	 0.001064	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60570	 60643	 0.033435	 0.155565	 0.03412	 183.51	 183.51	 183.51	 0.0	 0.0	 1	 -30.0	 30.0;
	70138	 60570	 0.021722	 0.120737	 0.04354	 189.64	 189.64	 189.64	 0.0	 0.0	 1	 -30.0	 30.0;
	60579	 60573	 0.007657	 0.03345	 0.00959	 186.25	 186.25	 186.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60573	 60768	 0.027787	 0.107923	 0.12268	 223.18	 223.18	 223.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60573	 60768	 0.027787	 0.107923	 0.12268	 223.18	 223.18	 223.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60573	 60768	 0.027787	 0.107923	 0.12268	 223.18	 223.18	 223.18	 0.0	 0.0	 1	 -30.0	 30.0;
	60574	 60575	 0.000236	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60659	 60574	 0.004188	 0.024672	 0.00467	 179.62	 179.62	 179.62	 0.0	 0.0	 1	 -30.0	 30.0;
	60574	 60787	 0.01106	 0.040213	 0.0051	 174.54	 174.54	 174.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60576	 60659	 0.009687	 0.045565	 0.02124	 178.91	 178.91	 178.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60577	 60578	 0.000267	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60580	 60581	 0.000231	 0.001125	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60580	 60582	 0.000212	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60787	 60582	 0.002815	 0.010516	 0.00763	 178.35	 178.35	 178.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60583	 60588	 0.015224	 0.06718	 0.0598	 145.71	 145.71	 145.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60583	 60589	 0.012777	 0.043713	 0.00507	 164.13	 164.13	 164.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60584	 60585	 0.00021	 0.001169	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60584	 60586	 0.007374	 0.036599	 0.01997	 160.54	 160.54	 160.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60587	 60832	 0.010712	 0.043478	 0.14643	 172.48	 172.48	 172.48	 0.0	 0.0	 1	 -30.0	 30.0;
	60588	 60593	 0.0291	 0.114705	 0.04368	 153.25	 153.25	 153.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60589	 60591	 0.027835	 0.08461	 0.08403	 152.38	 152.38	 152.38	 0.0	 0.0	 1	 -30.0	 30.0;
	60589	 60650	 0.024028	 0.104857	 0.1098	 197.21	 197.21	 197.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60590	 60595	 0.017684	 0.078922	 0.11331	 182.7	 182.7	 182.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60591	 60592	 0.00026	 0.0011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60591	 60596	 0.014668	 0.066738	 0.06698	 147.79	 147.79	 147.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60593	 60595	 0.021724	 0.100957	 0.06764	 161.72	 161.72	 161.72	 0.0	 0.0	 1	 -30.0	 30.0;
	60594	 60787	 0.021838	 0.097718	 0.11047	 176.99	 176.99	 176.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60595	 60597	 0.021197	 0.095054	 0.02101	 292.31	 292.31	 292.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60596	 60599	 0.008931	 0.038548	 0.00642	 138.1	 138.1	 138.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60597	 60603	 0.004374	 0.021693	 0.0193	 127.55	 127.55	 127.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60597	 60813	 0.005606	 0.027854	 0.00986	 202.7	 202.7	 202.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60597	 60813	 0.005606	 0.027854	 0.00986	 202.7	 202.7	 202.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60598	 60599	 0.046799	 0.2112	 0.03365	 110.32	 110.32	 110.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60604	 60598	 0.020531	 0.084871	 0.02213	 144.07	 144.07	 144.07	 0.0	 0.0	 1	 -30.0	 30.0;
	60600	 60601	 0.000216	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60650	 60600	 0.003144	 0.016078	 0.00415	 164.99	 164.99	 164.99	 0.0	 0.0	 1	 -30.0	 30.0;
	60600	 60779	 0.009301	 0.035986	 0.00547	 170.09	 170.09	 170.09	 0.0	 0.0	 1	 -30.0	 30.0;
	60602	 60603	 0.000251	 0.001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60606	 60603	 0.025533	 0.116293	 0.01883	 143.79	 143.79	 143.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60604	 60608	 0.017226	 0.074011	 0.02162	 166.31	 166.31	 166.31	 0.0	 0.0	 1	 -30.0	 30.0;
	60605	 60628	 0.032489	 0.129341	 0.02943	 146.26	 146.26	 146.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60605	 60866	 0.028205	 0.140479	 0.04101	 162.19	 162.19	 162.19	 0.0	 0.0	 1	 -30.0	 30.0;
	60606	 60607	 0.000293	 0.001069	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60606	 60732	 0.021381	 0.092674	 0.0326	 150.84	 150.84	 150.84	 0.0	 0.0	 1	 -30.0	 30.0;
	60608	 60609	 0.000224	 0.001075	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60608	 60615	 0.021178	 0.100911	 0.05947	 173.68	 173.68	 173.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60610	 60667	 0.025751	 0.087354	 0.05577	 146.26	 146.26	 146.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60823	 60610	 0.03741	 0.216641	 0.03739	 154.61	 154.61	 154.61	 0.0	 0.0	 1	 -30.0	 30.0;
	60611	 60612	 0.000249	 0.001015	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60611	 60622	 0.035396	 0.166535	 0.05088	 127.02	 127.02	 127.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60611	 60698	 0.017813	 0.089065	 0.02145	 140.71	 140.71	 140.71	 0.0	 0.0	 1	 -30.0	 30.0;
	60613	 60614	 0.000287	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60616	 60613	 0.024068	 0.115957	 0.06506	 146.58	 146.58	 146.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60623	 60613	 0.02399	 0.0939	 0.03665	 115.7	 115.7	 115.7	 0.0	 0.0	 1	 -30.0	 30.0;
	60615	 60625	 0.034348	 0.163085	 0.03785	 140.42	 140.42	 140.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60615	 60696	 0.012135	 0.055748	 0.01292	 182.29	 182.29	 182.29	 0.0	 0.0	 1	 -30.0	 30.0;
	60616	 60817	 0.010116	 0.052024	 0.01667	 153.82	 153.82	 153.82	 0.0	 0.0	 1	 -30.0	 30.0;
	60617	 60618	 0.000256	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60618	 60621	 0.042377	 0.195598	 0.04779	 139.98	 139.98	 139.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60618	 60823	 0.03913	 0.143936	 0.05098	 144.26	 144.26	 144.26	 0.0	 0.0	 1	 -30.0	 30.0;
	60619	 60620	 0.000251	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60623	 60619	 0.034781	 0.151893	 0.02811	 138.9	 138.9	 138.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60619	 60624	 0.027258	 0.105375	 0.02973	 146.79	 146.79	 146.79	 0.0	 0.0	 1	 -30.0	 30.0;
	60681	 60621	 0.006075	 0.025614	 0.00441	 120.65	 120.65	 120.65	 0.0	 0.0	 1	 -30.0	 30.0;
	60622	 60759	 0.05004	 0.212198	 0.05144	 115.54	 115.54	 115.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60624	 60875	 0.018219	 0.082596	 0.15246	 153.91	 153.91	 153.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60696	 60625	 0.025167	 0.129469	 0.03269	 145.94	 145.94	 145.94	 0.0	 0.0	 1	 -30.0	 30.0;
	60627	 60626	 0.000201	 0.015951	 0.0	 480.11	 480.11	 480.11	 1.0	 0.0	 1	 -30.0	 30.0;
	60626	 60629	 0.000172	 0.010655	 0.0	 915.95	 915.95	 915.95	 1.0	 0.0	 1	 -30.0	 30.0;
	60626	 60709	 0.000415	 0.006744	 0.73921	 1984.69	 1984.69	 1984.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60628	 60627	 0.00111	 0.052748	 0.0	 147.77	 147.77	 147.77	 1.0	 0.0	 1	 -30.0	 30.0;
	60627	 60630	 0.000252	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60628	 60655	 0.008037	 0.039911	 0.01735	 116.23	 116.23	 116.23	 0.0	 0.0	 1	 -30.0	 30.0;
	60630	 60632	 0.003966	 0.030047	 0.08562	 432.68	 432.68	 432.68	 0.0	 0.0	 1	 -30.0	 30.0;
	60632	 60631	 0.00032	 0.023969	 0.0	 505.42	 505.42	 505.42	 1.00625	 0.0	 1	 -30.0	 30.0;
	60631	 60653	 0.00036	 0.006822	 0.73864	 2307.2	 2307.2	 2307.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60633	 60632	 0.000931	 0.047714	 0.0	 109.55	 109.55	 109.55	 1.0	 0.0	 1	 -30.0	 30.0;
	60632	 60821	 0.002934	 0.023236	 0.09732	 424.06	 424.06	 424.06	 0.0	 0.0	 1	 -30.0	 30.0;
	60866	 60633	 0.004202	 0.02068	 0.00505	 132.66	 132.66	 132.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60635	 60634	 0.000253	 0.020621	 0.0	 860.75	 860.75	 860.75	 1.01875	 0.0	 1	 -30.0	 30.0;
	60634	 60657	 0.000462	 0.006162	 0.58916	 2762.76	 2762.76	 2762.76	 0.0	 0.0	 1	 -30.0	 30.0;
	60634	 60785	 0.000201	 0.003844	 0.71635	 2450.34	 2450.34	 2450.34	 0.0	 0.0	 1	 -30.0	 30.0;
	60876	 60634	 8.4e-05	 0.001402	 0.14879	 2701.73	 2701.73	 2701.73	 0.0	 0.0	 1	 -30.0	 30.0;
	60635	 60638	 0.001319	 0.06803	 0.0	 256.0	 256.0	 256.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60635	 60639	 0.000249	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60636	 60638	 -4.1e-05	 -0.002122	 0.0	 181.0	 181.0	 181.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60637	 60638	 0.006337	 0.326844	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60877	 60639	 0.001097	 0.010176	 0.01849	 527.91	 527.91	 527.91	 0.0	 0.0	 1	 -30.0	 30.0;
	60641	 60640	 0.000156	 0.010986	 0.0	 725.24	 725.24	 725.24	 1.00625	 0.0	 1	 -30.0	 30.0;
	60640	 60646	 0.000169	 0.011506	 0.0	 1129.49	 1129.49	 1129.49	 1.0	 0.0	 1	 -30.0	 30.0;
	60640	 60653	 0.000496	 0.007828	 1.06762	 2435.01	 2435.01	 2435.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60709	 60640	 0.000195	 0.003402	 0.29901	 2371.77	 2371.77	 2371.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60830	 60640	 0.001319	 0.014243	 1.86331	 2756.9	 2756.9	 2756.9	 0.0	 0.0	 1	 -30.0	 30.0;
	60641	 60645	 0.001864	 0.060054	 0.0	 161.78	 161.78	 161.78	 1.0	 0.0	 1	 -30.0	 30.0;
	60641	 60647	 0.000244	 0.001112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60641	 60783	 0.008555	 0.069781	 0.53013	 560.55	 560.55	 560.55	 0.0	 0.0	 1	 -30.0	 30.0;
	60643	 60642	 0.003876	 0.098463	 0.0	 82.14	 82.14	 82.14	 1.0125	 0.0	 1	 -30.0	 30.0;
	60643	 60642	 0.003876	 0.098463	 0.0	 82.14	 82.14	 82.14	 1.0125	 0.0	 1	 -30.0	 30.0;
	60642	 60645	 -0.000117	 -0.003768	 0.0	 111.78	 111.78	 111.78	 1.0	 0.0	 1	 -30.0	 30.0;
	60642	 70092	 0.01955	 0.107813	 0.0439	 229.1	 229.1	 229.1	 0.0	 0.0	 1	 -30.0	 30.0;
	60711	 60643	 0.012936	 0.067905	 0.01736	 160.21	 160.21	 160.21	 0.0	 0.0	 1	 -30.0	 30.0;
	60644	 60645	 0.010499	 0.338208	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60649	 60648	 0.000145	 0.012567	 0.0	 729.96	 729.96	 729.96	 1.0	 0.0	 1	 -30.0	 30.0;
	60648	 60651	 0.000153	 0.009759	 0.0	 1094.8	 1094.8	 1094.8	 1.0	 0.0	 1	 -30.0	 30.0;
	60648	 60652	 0.000227	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60650	 60649	 0.001781	 0.067555	 0.0	 163.27	 163.27	 163.27	 1.0	 0.0	 1	 -30.0	 30.0;
	60666	 60649	 0.001483	 0.01362	 0.02699	 524.87	 524.87	 524.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60667	 60650	 0.004672	 0.023999	 0.01505	 174.4	 174.4	 174.4	 0.0	 0.0	 1	 -30.0	 30.0;
	60652	 60669	 0.000118	 0.001679	 0.21819	 2319.97	 2319.97	 2319.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60652	 60679	 0.001104	 0.018219	 1.93193	 2146.69	 2146.69	 2146.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60652	 60766	 0.000279	 0.003565	 0.47642	 2145.39	 2145.39	 2145.39	 0.0	 0.0	 1	 -30.0	 30.0;
	60654	 60653	 0.000228	 0.018635	 0.0	 582.74	 582.74	 582.74	 1.0	 0.0	 1	 -30.0	 30.0;
	60653	 60656	 0.000217	 0.016341	 0.0	 907.94	 907.94	 907.94	 1.0	 0.0	 1	 -30.0	 30.0;
	60655	 60654	 0.001541	 0.06433	 0.0	 145.28	 145.28	 145.28	 1.0	 0.0	 1	 -30.0	 30.0;
	60654	 60710	 0.003435	 0.030721	 0.07121	 486.25	 486.25	 486.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60711	 60655	 0.023995	 0.101632	 0.02272	 144.04	 144.04	 144.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60657	 60661	 0.000451	 0.025059	 0.0	 1072.15	 1072.15	 1072.15	 1.0	 0.0	 1	 -30.0	 30.0;
	60657	 60662	 0.000201	 0.011824	 0.0	 1241.99	 1241.99	 1241.99	 1.0	 0.0	 1	 -30.0	 30.0;
	60657	 60663	 7.8e-05	 0.005789	 0.0	 1237.06	 1237.06	 1237.06	 1.0	 0.0	 1	 -30.0	 30.0;
	60657	 60664	 0.000187	 0.011859	 0.0	 1201.9	 1201.9	 1201.9	 1.0	 0.0	 1	 -30.0	 30.0;
	60657	 60785	 0.000155	 0.002439	 0.27854	 3177.74	 3177.74	 3177.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60659	 60658	 0.000896	 0.045612	 0.0	 264.06	 264.06	 264.06	 1.05625	 0.0	 1	 -30.0	 30.0;
	60659	 60658	 0.000896	 0.045612	 0.0	 264.06	 264.06	 264.06	 1.05625	 0.0	 1	 -30.0	 30.0;
	60659	 60658	 0.000896	 0.045612	 0.0	 264.06	 264.06	 264.06	 1.05625	 0.0	 1	 -30.0	 30.0;
	60658	 60661	 -0.000168	 -0.009362	 0.0	 922.15	 922.15	 922.15	 1.0	 0.0	 1	 -30.0	 30.0;
	60658	 60703	 0.012757	 0.127152	 0.45069	 514.47	 514.47	 514.47	 0.0	 0.0	 1	 -30.0	 30.0;
	60658	 60853	 0.006495	 0.070018	 0.1752	 542.88	 542.88	 542.88	 0.0	 0.0	 1	 -30.0	 30.0;
	60660	 60661	 0.000935	 0.05199	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60666	 60665	 0.000166	 0.011285	 0.0	 523.44	 523.44	 523.44	 1.0	 0.0	 1	 -30.0	 30.0;
	60665	 60668	 0.000159	 0.01087	 0.0	 915.75	 915.75	 915.75	 1.025	 0.0	 1	 -30.0	 30.0;
	60665	 60669	 0.000236	 0.00101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60667	 60666	 0.00137	 0.05866	 0.0	 164.27	 164.27	 164.27	 1.0	 0.0	 1	 -30.0	 30.0;
	60719	 60666	 0.001262	 0.012107	 0.01869	 432.34	 432.34	 432.34	 0.0	 0.0	 1	 -30.0	 30.0;
	60781	 60666	 0.000561	 0.005383	 0.01197	 501.87	 501.87	 501.87	 0.0	 0.0	 1	 -30.0	 30.0;
	60669	 60843	 0.001048	 0.016543	 2.27702	 2609.0	 2609.0	 2609.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60671	 60670	 0.000229	 0.017083	 0.0	 845.55	 845.55	 845.55	 1.025	 0.0	 1	 -30.0	 30.0;
	60670	 60724	 0.000293	 0.00517	 0.55382	 2537.06	 2537.06	 2537.06	 0.0	 0.0	 1	 -30.0	 30.0;
	60670	 60830	 0.00021	 0.003385	 0.37874	 2391.54	 2391.54	 2391.54	 0.0	 0.0	 1	 -30.0	 30.0;
	60858	 60670	 8.4e-05	 0.001554	 0.13129	 1842.04	 1842.04	 1842.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60672	 60671	 0.002802	 0.088744	 0.0	 180.57	 180.57	 180.57	 1.0375	 0.0	 1	 -30.0	 30.0;
	60671	 60673	 0.000213	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60672	 60845	 0.000747	 0.004089	 0.00403	 188.77	 188.77	 188.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60673	 60863	 0.001721	 0.014667	 0.02348	 503.8	 503.8	 503.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60675	 60674	 5.9e-05	 0.004545	 0.0	 1260.22	 1260.22	 1260.22	 1.00625	 0.0	 1	 -30.0	 30.0;
	60675	 60674	 5.9e-05	 0.004545	 0.0	 1260.22	 1260.22	 1260.22	 1.00625	 0.0	 1	 -30.0	 30.0;
	60675	 60674	 5.9e-05	 0.004545	 0.0	 1260.22	 1260.22	 1260.22	 1.00625	 0.0	 1	 -30.0	 30.0;
	60674	 60677	 0.000205	 0.015911	 0.0	 868.91	 868.91	 868.91	 1.025	 0.0	 1	 -30.0	 30.0;
	60674	 60678	 0.000249	 0.017319	 0.0	 546.76	 546.76	 546.76	 1.01875	 0.0	 1	 -30.0	 30.0;
	60682	 60674	 0.000334	 0.00588	 0.79577	 2847.43	 2847.43	 2847.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60674	 60738	 0.000668	 0.009055	 0.98419	 2593.97	 2593.97	 2593.97	 0.0	 0.0	 1	 -30.0	 30.0;
	60674	 60858	 0.000268	 0.004624	 0.41147	 2803.66	 2803.66	 2803.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60676	 60675	 0.001324	 0.064183	 0.0	 284.09	 284.09	 284.09	 1.0125	 0.0	 1	 -30.0	 30.0;
	60676	 60675	 0.001324	 0.064183	 0.0	 284.09	 284.09	 284.09	 1.0125	 0.0	 1	 -30.0	 30.0;
	60676	 60675	 0.001324	 0.064183	 0.0	 284.09	 284.09	 284.09	 1.0125	 0.0	 1	 -30.0	 30.0;
	60676	 60675	 0.001324	 0.064183	 0.0	 284.09	 284.09	 284.09	 1.0125	 0.0	 1	 -30.0	 30.0;
	60675	 60850	 0.001618	 0.015166	 0.07031	 680.98	 680.98	 680.98	 0.0	 0.0	 1	 -30.0	 30.0;
	60826	 60676	 0.000464	 0.002083	 0.00023	 180.33	 180.33	 180.33	 0.0	 0.0	 1	 -30.0	 30.0;
	60680	 60679	 0.000239	 0.016256	 0.0	 629.79	 629.79	 629.79	 0.99375	 0.0	 1	 -30.0	 30.0;
	60681	 60680	 0.001395	 0.059698	 0.0	 122.68	 122.68	 122.68	 1.0	 0.0	 1	 -30.0	 30.0;
	60680	 60714	 0.024476	 0.203754	 0.4937	 509.51	 509.51	 509.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60683	 60682	 0.000225	 0.016948	 0.0	 709.04	 709.04	 709.04	 1.04375	 0.0	 1	 -30.0	 30.0;
	60682	 60686	 0.000159	 0.008195	 0.0	 966.3	 966.3	 966.3	 1.0125	 0.0	 1	 -30.0	 30.0;
	60682	 60687	 0.000214	 0.012319	 0.0	 962.85	 962.85	 962.85	 1.0	 0.0	 1	 -30.0	 30.0;
	60682	 60688	 0.000135	 0.010663	 0.0	 950.7	 950.7	 950.7	 1.0125	 0.0	 1	 -30.0	 30.0;
	60682	 60689	 0.000178	 0.01422	 0.0	 949.62	 949.62	 949.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60682	 60690	 0.00018	 0.0128	 0.0	 777.19	 777.19	 777.19	 1.0125	 0.0	 1	 -30.0	 30.0;
	60682	 60691	 0.000302	 0.018787	 0.0	 775.68	 775.68	 775.68	 1.0	 0.0	 1	 -30.0	 30.0;
	60682	 60858	 0.000174	 0.00275	 0.29106	 2495.05	 2495.05	 2495.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60884	 60682	 0.000759	 0.011369	 1.02989	 2755.05	 2755.05	 2755.05	 0.0	 0.0	 1	 -30.0	 30.0;
	60684	 60683	 0.000686	 0.029798	 0.0	 522.65	 522.65	 522.65	 1.0625	 0.0	 1	 -30.0	 30.0;
	60683	 60692	 0.000721	 0.045669	 0.0	 318.1	 318.1	 318.1	 1.03125	 0.0	 1	 -30.0	 30.0;
	60683	 60693	 0.000294	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60685	 60684	 0.001355	 0.055079	 0.0	 247.78	 247.78	 247.78	 1.025	 0.0	 1	 -30.0	 30.0;
	60685	 60684	 0.001355	 0.055079	 0.0	 247.78	 247.78	 247.78	 1.025	 0.0	 1	 -30.0	 30.0;
	60685	 60684	 0.001355	 0.055079	 0.0	 247.78	 247.78	 247.78	 1.025	 0.0	 1	 -30.0	 30.0;
	60684	 60863	 0.00222	 0.019821	 0.03649	 491.8	 491.8	 491.8	 0.0	 0.0	 1	 -30.0	 30.0;
	60693	 60885	 0.002149	 0.02398	 0.42343	 1290.28	 1290.28	 1290.28	 0.0	 0.0	 1	 -30.0	 30.0;
	60695	 60694	 0.001015	 0.04138	 0.0	 176.27	 176.27	 176.27	 1.0	 0.0	 1	 -30.0	 30.0;
	60694	 60802	 0.004095	 0.032128	 0.05078	 519.32	 519.32	 519.32	 0.0	 0.0	 1	 -30.0	 30.0;
	60759	 60696	 0.043096	 0.170153	 0.02313	 170.65	 170.65	 170.65	 0.0	 0.0	 1	 -30.0	 30.0;
	60697	 60700	 0.002245	 0.098977	 0.0	 242.91	 242.91	 242.91	 1.0	 0.0	 1	 -30.0	 30.0;
	60697	 60701	 0.001419	 0.054104	 0.0	 205.56	 205.56	 205.56	 1.0	 0.0	 1	 -30.0	 30.0;
	60697	 60702	 0.001601	 0.072	 0.0	 148.64	 148.64	 148.64	 1.0	 0.0	 1	 -30.0	 30.0;
	60697	 60703	 0.000269	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60697	 60703	 0.000269	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60698	 60700	 -0.000582	 -0.025651	 0.0	 142.15	 142.15	 142.15	 1.0	 0.0	 1	 -30.0	 30.0;
	60699	 60700	 0.008489	 0.374311	 0.0	 100.76	 100.76	 100.76	 1.0	 0.0	 1	 -30.0	 30.0;
	60703	 60758	 0.001764	 0.016096	 0.06783	 388.12	 388.12	 388.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60705	 60704	 0.000184	 0.012188	 0.0	 758.44	 758.44	 758.44	 1.0	 0.0	 1	 -30.0	 30.0;
	60704	 60707	 0.000284	 0.018323	 0.0	 1074.75	 1074.75	 1074.75	 1.025	 0.0	 1	 -30.0	 30.0;
	60704	 60708	 0.000181	 0.012782	 0.0	 1074.28	 1074.28	 1074.28	 1.025	 0.0	 1	 -30.0	 30.0;
	60738	 60704	 0.001422	 0.0231	 2.16459	 2640.73	 2640.73	 2640.73	 0.0	 0.0	 1	 -30.0	 30.0;
	60827	 60704	 0.001337	 0.026059	 2.64047	 2710.11	 2710.11	 2710.11	 0.0	 0.0	 1	 -30.0	 30.0;
	60867	 60704	 0.000311	 0.004921	 0.53052	 2799.16	 2799.16	 2799.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60706	 60705	 0.001062	 0.057567	 0.0	 181.97	 181.97	 181.97	 1.0	 0.0	 1	 -30.0	 30.0;
	60705	 60868	 0.003245	 0.030565	 0.09332	 484.58	 484.58	 484.58	 0.0	 0.0	 1	 -30.0	 30.0;
	60710	 60709	 0.000297	 0.017279	 0.0	 653.92	 653.92	 653.92	 1.0	 0.0	 1	 -30.0	 30.0;
	60709	 60712	 0.000163	 0.009718	 0.0	 1094.64	 1094.64	 1094.64	 1.01875	 0.0	 1	 -30.0	 30.0;
	60711	 60710	 0.00117	 0.054528	 0.0	 147.14	 147.14	 147.14	 1.0	 0.0	 1	 -30.0	 30.0;
	60714	 60713	 0.000247	 0.018661	 0.0	 981.09	 981.09	 981.09	 1.0375	 0.0	 1	 -30.0	 30.0;
	60713	 60716	 0.00014	 0.009261	 0.0	 906.56	 906.56	 906.56	 1.00625	 0.0	 1	 -30.0	 30.0;
	60713	 60717	 0.000182	 0.013566	 0.0	 891.66	 891.66	 891.66	 1.00625	 0.0	 1	 -30.0	 30.0;
	60713	 60718	 0.000211	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60715	 60714	 0.000871	 0.037256	 0.0	 284.97	 284.97	 284.97	 1.01875	 0.0	 1	 -30.0	 30.0;
	60715	 60714	 0.000871	 0.037256	 0.0	 284.97	 284.97	 284.97	 1.01875	 0.0	 1	 -30.0	 30.0;
	60715	 60714	 0.000871	 0.037256	 0.0	 284.97	 284.97	 284.97	 1.01875	 0.0	 1	 -30.0	 30.0;
	60715	 60714	 0.000871	 0.037256	 0.0	 284.97	 284.97	 284.97	 1.01875	 0.0	 1	 -30.0	 30.0;
	60714	 60831	 0.00232	 0.02045	 0.17588	 580.04	 580.04	 580.04	 0.0	 0.0	 1	 -30.0	 30.0;
	60724	 60718	 0.000206	 0.003429	 0.41282	 2474.74	 2474.74	 2474.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60718	 60748	 0.000933	 0.014273	 1.51448	 2830.13	 2830.13	 2830.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60720	 60719	 0.001452	 0.062224	 0.0	 148.04	 148.04	 148.04	 1.0	 0.0	 1	 -30.0	 30.0;
	60719	 60721	 0.000836	 0.033354	 0.0	 284.47	 284.47	 284.47	 1.0	 0.0	 1	 -30.0	 30.0;
	60771	 60719	 0.002479	 0.019841	 0.0885	 521.01	 521.01	 521.01	 0.0	 0.0	 1	 -30.0	 30.0;
	60779	 60720	 0.005376	 0.023669	 0.01023	 151.16	 151.16	 151.16	 0.0	 0.0	 1	 -30.0	 30.0;
	60722	 60723	 0.000203	 0.001111	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60725	 60724	 0.000167	 0.011816	 0.0	 1181.62	 1181.62	 1181.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60725	 60724	 0.000167	 0.011816	 0.0	 1181.62	 1181.62	 1181.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60725	 60724	 0.000167	 0.011816	 0.0	 1181.62	 1181.62	 1181.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60724	 60727	 6.8e-05	 0.005178	 0.0	 1120.14	 1120.14	 1120.14	 1.0	 0.0	 1	 -30.0	 30.0;
	60724	 60728	 0.000141	 0.010523	 0.0	 1108.24	 1108.24	 1108.24	 1.0	 0.0	 1	 -30.0	 30.0;
	60752	 60724	 0.000268	 0.004243	 0.38744	 2649.53	 2649.53	 2649.53	 0.0	 0.0	 1	 -30.0	 30.0;
	60843	 60724	 0.000146	 0.002732	 0.32179	 1990.42	 1990.42	 1990.42	 0.0	 0.0	 1	 -30.0	 30.0;
	60726	 60725	 0.001596	 0.073472	 0.0	 260.71	 260.71	 260.71	 1.0	 0.0	 1	 -30.0	 30.0;
	60726	 60725	 0.001596	 0.073472	 0.0	 260.71	 260.71	 260.71	 1.0	 0.0	 1	 -30.0	 30.0;
	60726	 60725	 0.001596	 0.073472	 0.0	 260.71	 260.71	 260.71	 1.0	 0.0	 1	 -30.0	 30.0;
	60725	 60729	 0.002966	 0.092073	 0.0	 109.62	 109.62	 109.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60725	 60730	 0.002994	 0.139332	 0.0	 134.87	 134.87	 134.87	 1.0	 0.0	 1	 -30.0	 30.0;
	60842	 60725	 0.002505	 0.022709	 0.03104	 577.02	 577.02	 577.02	 0.0	 0.0	 1	 -30.0	 30.0;
	60732	 60731	 0.0013	 0.05766	 0.0	 128.5	 128.5	 128.5	 1.0	 0.0	 1	 -30.0	 30.0;
	60731	 60733	 0.000203	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60750	 60732	 0.004721	 0.022588	 0.00374	 168.74	 168.74	 168.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60732	 60813	 0.002368	 0.014187	 0.00773	 188.85	 188.85	 188.85	 0.0	 0.0	 1	 -30.0	 30.0;
	60749	 60733	 0.000474	 0.004728	 0.01662	 498.17	 498.17	 498.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60735	 60734	 0.000215	 0.016034	 0.0	 449.19	 449.19	 449.19	 1.0	 0.0	 1	 -30.0	 30.0;
	60734	 60804	 0.000759	 0.013468	 1.40586	 2373.07	 2373.07	 2373.07	 0.0	 0.0	 1	 -30.0	 30.0;
	60736	 60735	 0.00121	 0.041663	 0.0	 169.44	 169.44	 169.44	 1.0	 0.0	 1	 -30.0	 30.0;
	60735	 60805	 0.00691	 0.065228	 0.24416	 383.14	 383.14	 383.14	 0.0	 0.0	 1	 -30.0	 30.0;
	60737	 60736	 0.004822	 0.137285	 0.0	 115.51	 115.51	 115.51	 1.0	 0.0	 1	 -30.0	 30.0;
	60739	 60738	 0.000229	 0.012727	 0.0	 841.89	 841.89	 841.89	 1.0125	 0.0	 1	 -30.0	 30.0;
	60738	 60745	 0.0001	 0.000207	 0.0	 1180.1	 1180.1	 1180.1	 1.0	 0.0	 1	 -30.0	 30.0;
	60738	 60746	 0.00025	 0.018786	 0.0	 813.36	 813.36	 813.36	 1.0	 0.0	 1	 -30.0	 30.0;
	60738	 60747	 0.000269	 0.018696	 0.0	 796.24	 796.24	 796.24	 1.0	 0.0	 1	 -30.0	 30.0;
	60739	 60742	 0.00123	 0.066529	 0.0	 252.61	 252.61	 252.61	 1.0	 0.0	 1	 -30.0	 30.0;
	60740	 60742	 0.000157	 0.008513	 0.0	 202.61	 202.61	 202.61	 1.0	 0.0	 1	 -30.0	 30.0;
	60741	 60742	 0.007034	 0.380317	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60743	 60745	 0.000368	 0.023675	 0.0	 590.05	 590.05	 590.05	 1.0	 0.0	 1	 -30.0	 30.0;
	60744	 60745	 0.000368	 0.023675	 0.0	 590.05	 590.05	 590.05	 1.0	 0.0	 1	 -30.0	 30.0;
	60749	 60748	 0.000264	 0.01808	 0.0	 608.58	 608.58	 608.58	 1.0	 0.0	 1	 -30.0	 30.0;
	60748	 60751	 0.000163	 0.012879	 0.0	 1247.83	 1247.83	 1247.83	 1.025	 0.0	 1	 -30.0	 30.0;
	60750	 60749	 0.000741	 0.031798	 0.0	 161.04	 161.04	 161.04	 1.00625	 0.0	 1	 -30.0	 30.0;
	60749	 60821	 0.008929	 0.098908	 0.25149	 451.41	 451.41	 451.41	 0.0	 0.0	 1	 -30.0	 30.0;
	60813	 60750	 0.00051	 0.002455	 0.00113	 186.15	 186.15	 186.15	 0.0	 0.0	 1	 -30.0	 30.0;
	60753	 60752	 0.000363	 0.024655	 0.0	 848.55	 848.55	 848.55	 1.05	 0.0	 1	 -30.0	 30.0;
	60752	 60830	 0.000161	 0.002595	 0.32239	 2395.44	 2395.44	 2395.44	 0.0	 0.0	 1	 -30.0	 30.0;
	60752	 60884	 0.001067	 0.016606	 1.89775	 2614.17	 2614.17	 2614.17	 0.0	 0.0	 1	 -30.0	 30.0;
	60753	 60756	 0.00428	 0.151052	 0.0	 258.93	 258.93	 258.93	 1.0	 0.0	 1	 -30.0	 30.0;
	60753	 60831	 0.00107	 0.008955	 0.10627	 554.13	 554.13	 554.13	 0.0	 0.0	 1	 -30.0	 30.0;
	60754	 60756	 -0.002523	 -0.089059	 0.0	 208.93	 208.93	 208.93	 1.0	 0.0	 1	 -30.0	 30.0;
	60755	 60756	 0.010686	 0.377176	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60758	 60757	 8.9e-05	 0.00641	 0.0	 526.64	 526.64	 526.64	 1.0	 0.0	 1	 -30.0	 30.0;
	60758	 60757	 8.9e-05	 0.00641	 0.0	 526.64	 526.64	 526.64	 1.0	 0.0	 1	 -30.0	 30.0;
	60757	 60760	 0.000249	 0.016046	 0.0	 813.56	 813.56	 813.56	 1.0	 0.0	 1	 -30.0	 30.0;
	60757	 60761	 0.000292	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60757	 60761	 0.000292	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60759	 60758	 0.001355	 0.06258	 0.0	 165.74	 165.74	 165.74	 1.0	 0.0	 1	 -30.0	 30.0;
	60761	 60766	 0.001802	 0.028366	 4.16574	 2272.33	 2272.33	 2272.33	 0.0	 0.0	 1	 -30.0	 30.0;
	60762	 60763	 0.010071	 0.265824	 0.0	 51.65	 51.65	 51.65	 1.0	 0.0	 1	 -30.0	 30.0;
	60762	 60764	 0.018216	 0.49858	 0.0	 25.83	 25.83	 25.83	 1.0	 0.0	 1	 -30.0	 30.0;
	60854	 60762	 0.003929	 0.019504	 0.00831	 183.77	 183.77	 183.77	 0.0	 0.0	 1	 -30.0	 30.0;
	60806	 60765	 0.010865	 0.037314	 0.00932	 160.69	 160.69	 160.69	 0.0	 0.0	 1	 -30.0	 30.0;
	60766	 60770	 0.000337	 0.022514	 0.0	 784.78	 784.78	 784.78	 1.0	 0.0	 1	 -30.0	 30.0;
	60768	 60767	 0.000888	 0.040102	 0.0	 243.17	 243.17	 243.17	 1.0	 0.0	 1	 -30.0	 30.0;
	60768	 60767	 0.000888	 0.040102	 0.0	 243.17	 243.17	 243.17	 1.0	 0.0	 1	 -30.0	 30.0;
	60768	 60767	 0.000888	 0.040102	 0.0	 243.17	 243.17	 243.17	 1.0	 0.0	 1	 -30.0	 30.0;
	60767	 60770	 -7.2e-05	 -0.004828	 0.0	 684.78	 684.78	 684.78	 1.0	 0.0	 1	 -30.0	 30.0;
	60767	 60771	 0.000276	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60767	 60772	 0.00022	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60769	 60770	 0.001299	 0.086827	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60771	 60781	 0.00191	 0.018143	 0.04861	 521.43	 521.43	 521.43	 0.0	 0.0	 1	 -30.0	 30.0;
	60851	 60773	 0.000528	 0.001739	 0.00022	 200.35	 200.35	 200.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60851	 60773	 0.000528	 0.001739	 0.00022	 200.35	 200.35	 200.35	 0.0	 0.0	 1	 -30.0	 30.0;
	60774	 60775	 0.001714	 0.038562	 0.0	 269.1	 269.1	 269.1	 1.0	 0.0	 1	 -30.0	 30.0;
	60774	 60776	 0.005695	 0.138536	 0.0	 98.28	 98.28	 98.28	 1.0	 0.0	 1	 -30.0	 30.0;
	60774	 60777	 0.000219	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60878	 60777	 0.000644	 0.002968	 0.00092	 204.51	 204.51	 204.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60878	 60777	 0.000644	 0.002968	 0.00092	 204.51	 204.51	 204.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60878	 60777	 0.000644	 0.002968	 0.00092	 204.51	 204.51	 204.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60779	 60778	 0.001464	 0.067142	 0.0	 180.0	 180.0	 180.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60778	 60780	 0.001431	 0.052871	 0.0	 279.33	 279.33	 279.33	 0.9875	 0.0	 1	 -30.0	 30.0;
	60778	 60781	 0.000289	 0.001118	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60778	 60782	 0.000201	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60784	 60783	 0.001251	 0.074283	 0.0	 194.12	 194.12	 194.12	 1.0	 0.0	 1	 -30.0	 30.0;
	60786	 60785	 0.000225	 0.015935	 0.0	 903.98	 903.98	 903.98	 1.0625	 0.0	 1	 -30.0	 30.0;
	60785	 60790	 0.0001	 0.00135	 0.0	 1529.24	 1529.24	 1529.24	 1.0125	 0.0	 1	 -30.0	 30.0;
	60785	 60791	 0.000295	 0.020978	 0.0	 682.15	 682.15	 682.15	 1.01875	 0.0	 1	 -30.0	 30.0;
	60785	 60792	 0.000271	 0.018469	 0.0	 676.87	 676.87	 676.87	 1.01875	 0.0	 1	 -30.0	 30.0;
	60785	 60794	 0.000413	 0.035089	 0.0	 589.74	 589.74	 589.74	 1.01875	 0.0	 1	 -30.0	 30.0;
	60785	 60795	 0.000541	 0.044486	 0.0	 315.32	 315.32	 315.32	 1.0125	 0.0	 1	 -30.0	 30.0;
	60785	 60801	 0.001116	 0.016998	 2.85603	 2873.74	 2873.74	 2873.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60787	 60786	 0.001974	 0.073794	 0.0	 220.3	 220.3	 220.3	 1.0125	 0.0	 1	 -30.0	 30.0;
	60787	 60786	 0.001974	 0.073794	 0.0	 220.3	 220.3	 220.3	 1.0125	 0.0	 1	 -30.0	 30.0;
	60787	 60786	 0.001974	 0.073794	 0.0	 220.3	 220.3	 220.3	 1.0125	 0.0	 1	 -30.0	 30.0;
	60786	 60793	 0.002317	 0.089178	 0.0	 149.62	 149.62	 149.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60786	 60796	 0.000265	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60788	 60790	 0.000238	 0.015174	 0.0	 764.62	 764.62	 764.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60789	 60790	 0.000238	 0.015174	 0.0	 764.62	 764.62	 764.62	 1.0	 0.0	 1	 -30.0	 30.0;
	60797	 60798	 0.012105	 0.320348	 0.0	 38.39	 38.39	 38.39	 0.9875	 0.0	 1	 -30.0	 30.0;
	60797	 60799	 0.021816	 0.626566	 0.0	 18.72	 18.72	 18.72	 0.9875	 0.0	 1	 -30.0	 30.0;
	60797	 60800	 0.00021	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60802	 60801	 0.000337	 0.019817	 0.0	 733.27	 733.27	 733.27	 1.0	 0.0	 1	 -30.0	 30.0;
	60801	 60827	 0.001343	 0.023015	 3.00111	 2519.51	 2519.51	 2519.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60803	 60802	 0.001561	 0.061573	 0.0	 192.97	 192.97	 192.97	 1.0	 0.0	 1	 -30.0	 30.0;
	60805	 60804	 0.000251	 0.017392	 0.0	 740.43	 740.43	 740.43	 1.0	 0.0	 1	 -30.0	 30.0;
	60804	 60807	 0.00031	 0.023358	 0.0	 622.03	 622.03	 622.03	 1.0	 0.0	 1	 -30.0	 30.0;
	60804	 60808	 0.000344	 0.025632	 0.0	 619.8	 619.8	 619.8	 1.0	 0.0	 1	 -30.0	 30.0;
	60804	 60847	 0.001099	 0.020273	 1.80234	 2506.12	 2506.12	 2506.12	 0.0	 0.0	 1	 -30.0	 30.0;
	60806	 60805	 0.001514	 0.065035	 0.0	 173.88	 173.88	 173.88	 1.0	 0.0	 1	 -30.0	 30.0;
	60805	 60809	 0.002386	 0.12093	 0.0	 100.24	 100.24	 100.24	 1.0	 0.0	 1	 -30.0	 30.0;
	60812	 60806	 0.008137	 0.052276	 0.01501	 157.66	 157.66	 157.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60811	 60812	 0.000263	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60813	 60814	 0.00188	 0.055807	 0.0	 195.0	 195.0	 195.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60813	 60815	 0.001791	 0.041673	 0.0	 195.0	 195.0	 195.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60816	 60819	 0.000945	 0.044083	 0.0	 299.27	 299.27	 299.27	 1.0	 0.0	 1	 -30.0	 30.0;
	60816	 60820	 0.001459	 0.0631	 0.0	 213.84	 213.84	 213.84	 1.0	 0.0	 1	 -30.0	 30.0;
	60816	 60821	 0.000237	 0.001165	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60817	 60819	 0.000131	 0.006106	 0.0	 149.27	 149.27	 149.27	 1.0	 0.0	 1	 -30.0	 30.0;
	60818	 60819	 0.007273	 0.339242	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60822	 60823	 0.00029	 0.001094	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60822	 60824	 0.000285	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60825	 60826	 0.000229	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60828	 60827	 0.000281	 0.018186	 0.0	 785.97	 785.97	 785.97	 0.98125	 0.0	 1	 -30.0	 30.0;
	60829	 60828	 0.001071	 0.045071	 0.0	 214.07	 214.07	 214.07	 1.0	 0.0	 1	 -30.0	 30.0;
	60829	 60828	 0.001071	 0.045071	 0.0	 214.07	 214.07	 214.07	 1.0	 0.0	 1	 -30.0	 30.0;
	60831	 60830	 0.000172	 0.011192	 0.0	 1063.34	 1063.34	 1063.34	 1.0	 0.0	 1	 -30.0	 30.0;
	60830	 60833	 0.000179	 0.013015	 0.0	 1019.58	 1019.58	 1019.58	 1.0	 0.0	 1	 -30.0	 30.0;
	60830	 60834	 0.000234	 0.015969	 0.0	 1014.14	 1014.14	 1014.14	 1.0	 0.0	 1	 -30.0	 30.0;
	60830	 60835	 0.000119	 0.010101	 0.0	 1008.4	 1008.4	 1008.4	 1.0	 0.0	 1	 -30.0	 30.0;
	60832	 60831	 0.001576	 0.064774	 0.0	 267.35	 267.35	 267.35	 1.0	 0.0	 1	 -30.0	 30.0;
	60832	 60831	 0.001576	 0.064774	 0.0	 267.35	 267.35	 267.35	 1.0	 0.0	 1	 -30.0	 30.0;
	60832	 60831	 0.001576	 0.064774	 0.0	 267.35	 267.35	 267.35	 1.0	 0.0	 1	 -30.0	 30.0;
	60837	 60836	 0.000352	 0.022807	 0.0	 939.3	 939.3	 939.3	 1.0875	 0.0	 1	 -30.0	 30.0;
	60836	 60839	 0.000419	 0.028259	 0.0	 572.56	 572.56	 572.56	 1.0	 0.0	 1	 -30.0	 30.0;
	60836	 60840	 0.000274	 0.019382	 0.0	 567.77	 567.77	 567.77	 1.0	 0.0	 1	 -30.0	 30.0;
	60836	 60841	 0.000149	 0.010415	 0.0	 551.55	 551.55	 551.55	 1.0	 0.0	 1	 -30.0	 30.0;
	60836	 60843	 0.000281	 0.001156	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60838	 60837	 0.001268	 0.049953	 0.0	 284.59	 284.59	 284.59	 1.0375	 0.0	 1	 -30.0	 30.0;
	60838	 60837	 0.001268	 0.049953	 0.0	 284.59	 284.59	 284.59	 1.0375	 0.0	 1	 -30.0	 30.0;
	60838	 60837	 0.001268	 0.049953	 0.0	 284.59	 284.59	 284.59	 1.0375	 0.0	 1	 -30.0	 30.0;
	60838	 60837	 0.001268	 0.049953	 0.0	 284.59	 284.59	 284.59	 1.0375	 0.0	 1	 -30.0	 30.0;
	60837	 60842	 0.000269	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60844	 60845	 0.000251	 0.001162	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60844	 60846	 0.000203	 0.001171	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60848	 60847	 0.000192	 0.011409	 0.0	 947.36	 947.36	 947.36	 1.0	 0.0	 1	 -30.0	 30.0;
	60847	 60867	 0.00101	 0.015398	 1.44328	 2959.51	 2959.51	 2959.51	 0.0	 0.0	 1	 -30.0	 30.0;
	60849	 60848	 0.001581	 0.07591	 0.0	 222.9	 222.9	 222.9	 1.0	 0.0	 1	 -30.0	 30.0;
	60849	 60848	 0.001581	 0.07591	 0.0	 222.9	 222.9	 222.9	 1.0	 0.0	 1	 -30.0	 30.0;
	60849	 60848	 0.001581	 0.07591	 0.0	 222.9	 222.9	 222.9	 1.0	 0.0	 1	 -30.0	 30.0;
	60851	 60850	 0.001466	 0.069038	 0.0	 230.3	 230.3	 230.3	 1.025	 0.0	 1	 -30.0	 30.0;
	60851	 60850	 0.001466	 0.069038	 0.0	 230.3	 230.3	 230.3	 1.025	 0.0	 1	 -30.0	 30.0;
	60851	 60850	 0.001466	 0.069038	 0.0	 230.3	 230.3	 230.3	 1.025	 0.0	 1	 -30.0	 30.0;
	60853	 60852	 0.000239	 0.015085	 0.0	 1024.74	 1024.74	 1024.74	 1.0625	 0.0	 1	 -30.0	 30.0;
	60876	 60852	 0.00017	 0.003629	 0.39624	 2538.2	 2538.2	 2538.2	 0.0	 0.0	 1	 -30.0	 30.0;
	60854	 60853	 0.001099	 0.036302	 0.0	 317.49	 317.49	 317.49	 1.0375	 0.0	 1	 -30.0	 30.0;
	60854	 60853	 0.001099	 0.036302	 0.0	 317.49	 317.49	 317.49	 1.0375	 0.0	 1	 -30.0	 30.0;
	60854	 60853	 0.001099	 0.036302	 0.0	 317.49	 317.49	 317.49	 1.0375	 0.0	 1	 -30.0	 30.0;
	60854	 60853	 0.001099	 0.036302	 0.0	 317.49	 317.49	 317.49	 1.0375	 0.0	 1	 -30.0	 30.0;
	60877	 60853	 0.002963	 0.022364	 0.07349	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60855	 60856	 0.01413	 0.326604	 0.0	 39.72	 39.72	 39.72	 1.05625	 0.0	 1	 -30.0	 30.0;
	60855	 60857	 0.013597	 0.295757	 0.0	 37.28	 37.28	 37.28	 1.0375	 0.0	 1	 -30.0	 30.0;
	60859	 60858	 0.000365	 0.019382	 0.0	 861.41	 861.41	 861.41	 1.0	 0.0	 1	 -30.0	 30.0;
	60858	 60861	 0.000184	 0.011456	 0.0	 891.44	 891.44	 891.44	 1.0	 0.0	 1	 -30.0	 30.0;
	60858	 60862	 0.000167	 0.010692	 0.0	 888.14	 888.14	 888.14	 1.0	 0.0	 1	 -30.0	 30.0;
	60858	 60884	 0.00072	 0.011027	 1.75181	 2830.25	 2830.25	 2830.25	 0.0	 0.0	 1	 -30.0	 30.0;
	60860	 60859	 0.001572	 0.066047	 0.0	 222.39	 222.39	 222.39	 1.0	 0.0	 1	 -30.0	 30.0;
	60860	 60859	 0.001572	 0.066047	 0.0	 222.39	 222.39	 222.39	 1.0	 0.0	 1	 -30.0	 30.0;
	60860	 60859	 0.001572	 0.066047	 0.0	 222.39	 222.39	 222.39	 1.0	 0.0	 1	 -30.0	 30.0;
	60859	 60863	 0.000218	 0.001047	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60859	 60864	 0.000294	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60865	 60866	 0.000212	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60875	 60866	 0.005035	 0.023003	 0.01476	 165.74	 165.74	 165.74	 0.0	 0.0	 1	 -30.0	 30.0;
	60868	 60867	 0.000183	 0.010992	 0.0	 895.69	 895.69	 895.69	 1.0	 0.0	 1	 -30.0	 30.0;
	60867	 60872	 0.000116	 0.008146	 0.0	 1157.23	 1157.23	 1157.23	 1.03125	 0.0	 1	 -30.0	 30.0;
	60867	 60873	 0.000184	 0.010927	 0.0	 1156.27	 1156.27	 1156.27	 1.0375	 0.0	 1	 -30.0	 30.0;
	60867	 60874	 0.000122	 0.008766	 0.0	 1137.83	 1137.83	 1137.83	 1.03125	 0.0	 1	 -30.0	 30.0;
	60868	 60871	 0.000441	 0.019837	 0.0	 274.22	 274.22	 274.22	 1.0	 0.0	 1	 -30.0	 30.0;
	60869	 60871	 0.000576	 0.02589	 0.0	 199.22	 199.22	 199.22	 1.0	 0.0	 1	 -30.0	 30.0;
	60870	 60871	 0.00398	 0.179014	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60877	 60876	 0.000321	 0.021742	 0.0	 903.55	 903.55	 903.55	 1.1	 0.0	 1	 -30.0	 30.0;
	60876	 60881	 0.000111	 0.008094	 0.0	 824.05	 824.05	 824.05	 1.0	 0.0	 1	 -30.0	 30.0;
	60876	 60882	 0.000278	 0.018331	 0.0	 823.21	 823.21	 823.21	 1.0	 0.0	 1	 -30.0	 30.0;
	60876	 60883	 0.000243	 0.016718	 0.0	 814.67	 814.67	 814.67	 1.0	 0.0	 1	 -30.0	 30.0;
	60877	 60880	 0.000952	 0.041182	 0.0	 437.28	 437.28	 437.28	 1.0	 0.0	 1	 -30.0	 30.0;
	60878	 60880	 -0.0001	 -0.00433	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60879	 60880	 0.004479	 0.193742	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60890	 0.000169	 0.011683	 0.0	 1053.11	 1053.11	 1053.11	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60891	 0.000244	 0.015122	 0.0	 1126.1	 1126.1	 1126.1	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60892	 0.00027	 0.016615	 0.0	 714.23	 714.23	 714.23	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60893	 0.000129	 0.010251	 0.0	 711.72	 711.72	 711.72	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60894	 0.000284	 0.019091	 0.0	 705.6	 705.6	 705.6	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60895	 0.000155	 0.012897	 0.0	 704.83	 704.83	 704.83	 1.0	 0.0	 1	 -30.0	 30.0;
	60884	 60896	 0.000312	 0.021278	 0.0	 704.32	 704.32	 704.32	 1.0	 0.0	 1	 -30.0	 30.0;
	60886	 60885	 0.000526	 0.031049	 0.0	 587.82	 587.82	 587.82	 1.025	 0.0	 1	 -30.0	 30.0;
	60886	 60885	 0.000526	 0.031049	 0.0	 587.82	 587.82	 587.82	 1.1	 0.0	 1	 -30.0	 30.0;
	60886	 60885	 0.000526	 0.031049	 0.0	 587.82	 587.82	 587.82	 1.1	 0.0	 1	 -30.0	 30.0;
	60885	 60890	 8e-06	 0.000582	 0.0	 1003.11	 1003.11	 1003.11	 1.0	 0.0	 1	 -30.0	 30.0;
	60885	 70116	 0.003537	 0.043655	 0.79216	 1379.75	 1379.75	 1379.75	 0.0	 0.0	 1	 -30.0	 30.0;
	70135	 60885	 0.001186	 0.01299	 0.26257	 1235.86	 1235.86	 1235.86	 0.0	 0.0	 1	 -30.0	 30.0;
	60885	 70170	 0.003757	 0.042404	 1.29194	 1452.33	 1452.33	 1452.33	 0.0	 0.0	 1	 -30.0	 30.0;
	60887	 60886	 0.001118	 0.05317	 0.0	 210.44	 210.44	 210.44	 1.01875	 0.0	 1	 -30.0	 30.0;
	60887	 60886	 0.001118	 0.05317	 0.0	 210.44	 210.44	 210.44	 1.1	 0.0	 1	 -30.0	 30.0;
	70136	 60886	 0.003897	 0.03171	 0.13262	 451.06	 451.06	 451.06	 0.0	 0.0	 1	 -30.0	 30.0;
	60888	 60887	 0.003892	 0.113596	 0.0	 88.03	 88.03	 88.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	60888	 60887	 0.003892	 0.113596	 0.0	 88.03	 88.03	 88.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	60888	 60887	 0.003892	 0.113596	 0.0	 88.03	 88.03	 88.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	60888	 60887	 0.003892	 0.113596	 0.0	 88.03	 88.03	 88.03	 1.01875	 0.0	 1	 -30.0	 30.0;
	60887	 70109	 0.011412	 0.070461	 0.02881	 265.66	 265.66	 265.66	 0.0	 0.0	 1	 -30.0	 30.0;
	60889	 60890	 0.000916	 0.063495	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74191	 70000	 0.008953	 0.056347	 0.01919	 196.18	 196.18	 196.18	 0.0	 0.0	 1	 -30.0	 30.0;
	70000	 74193	 0.011931	 0.060869	 0.0176	 166.87	 166.87	 166.87	 0.0	 0.0	 1	 -30.0	 30.0;
	70004	 70001	 0.006962	 0.032932	 0.02778	 231.98	 231.98	 231.98	 0.0	 0.0	 1	 -30.0	 30.0;
	70001	 74191	 0.011548	 0.077828	 0.13484	 219.69	 219.69	 219.69	 0.0	 0.0	 1	 -30.0	 30.0;
	70002	 70003	 0.000243	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70003	 70004	 0.009836	 0.055038	 0.05028	 187.99	 187.99	 187.99	 0.0	 0.0	 1	 -30.0	 30.0;
	70003	 70009	 0.043269	 0.19699	 0.04341	 209.06	 209.06	 209.06	 0.0	 0.0	 1	 -30.0	 30.0;
	70004	 70005	 0.000238	 0.001192	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70004	 70006	 0.015187	 0.08211	 0.04365	 231.03	 231.03	 231.03	 0.0	 0.0	 1	 -30.0	 30.0;
	70011	 70006	 0.043238	 0.219077	 0.04942	 250.88	 250.88	 250.88	 0.0	 0.0	 1	 -30.0	 30.0;
	70007	 70124	 0.005684	 0.025242	 0.03942	 221.02	 221.02	 221.02	 0.0	 0.0	 1	 -30.0	 30.0;
	70007	 70190	 0.023043	 0.128396	 0.03222	 228.19	 228.19	 228.19	 0.0	 0.0	 1	 -30.0	 30.0;
	74190	 70007	 0.018251	 0.127893	 0.11565	 180.89	 180.89	 180.89	 0.0	 0.0	 1	 -30.0	 30.0;
	70008	 70130	 0.008772	 0.046554	 0.01477	 202.8	 202.8	 202.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70008	 70147	 0.018884	 0.128681	 0.05088	 218.07	 218.07	 218.07	 0.0	 0.0	 1	 -30.0	 30.0;
	70010	 70009	 0.021434	 0.128087	 0.06653	 266.65	 266.65	 266.65	 0.0	 0.0	 1	 -30.0	 30.0;
	70009	 70026	 0.027	 0.175	 0.11	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70009	 74190	 0.016221	 0.081858	 0.2093	 255.21	 255.21	 255.21	 0.0	 0.0	 1	 -30.0	 30.0;
	70010	 70011	 0.021802	 0.13575	 0.10089	 192.71	 192.71	 192.71	 0.0	 0.0	 1	 -30.0	 30.0;
	70023	 70010	 0.039576	 0.221925	 0.04517	 268.25	 268.25	 268.25	 0.0	 0.0	 1	 -30.0	 30.0;
	70011	 70012	 0.000294	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70011	 70015	 0.0381	 0.26051	 0.07471	 258.85	 258.85	 258.85	 0.0	 0.0	 1	 -30.0	 30.0;
	70013	 70014	 0.000218	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70013	 70147	 0.006833	 0.033563	 0.02279	 218.81	 218.81	 218.81	 0.0	 0.0	 1	 -30.0	 30.0;
	70190	 70013	 0.013235	 0.081962	 0.02803	 183.55	 183.55	 183.55	 0.0	 0.0	 1	 -30.0	 30.0;
	70015	 70016	 0.000265	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70015	 77038	 0.022707	 0.138652	 0.09028	 271.92	 271.92	 271.92	 0.0	 0.0	 1	 -30.0	 30.0;
	70017	 70020	 0.002403	 0.010624	 0.01132	 227.42	 227.42	 227.42	 0.0	 0.0	 1	 -30.0	 30.0;
	70017	 70152	 0.01488	 0.089423	 0.0406	 250.81	 250.81	 250.81	 0.0	 0.0	 1	 -30.0	 30.0;
	70018	 70019	 0.000222	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70018	 70020	 0.000212	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70020	 70147	 0.037463	 0.225274	 0.05255	 173.95	 173.95	 173.95	 0.0	 0.0	 1	 -30.0	 30.0;
	70021	 70022	 0.00021	 0.001143	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70021	 70023	 0.000226	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70023	 70026	 0.016618	 0.099529	 0.03998	 175.61	 175.61	 175.61	 0.0	 0.0	 1	 -30.0	 30.0;
	70023	 70028	 0.027248	 0.174551	 0.11035	 271.05	 271.05	 271.05	 0.0	 0.0	 1	 -30.0	 30.0;
	70024	 70025	 0.000224	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70032	 70024	 0.031474	 0.141391	 0.05083	 246.65	 246.65	 246.65	 0.0	 0.0	 1	 -30.0	 30.0;
	77038	 70024	 0.02786	 0.135904	 0.03597	 227.63	 227.63	 227.63	 0.0	 0.0	 1	 -30.0	 30.0;
	70030	 70026	 0.018406	 0.102113	 0.03021	 222.39	 222.39	 222.39	 0.0	 0.0	 1	 -30.0	 30.0;
	70027	 70028	 0.00028	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70027	 70029	 0.000295	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70034	 70027	 0.036	 0.234	 0.079	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70030	 70028	 0.03568	 0.234474	 0.07958	 251.43	 251.43	 251.43	 0.0	 0.0	 1	 -30.0	 30.0;
	70028	 70033	 0.028457	 0.156854	 0.02281	 190.46	 190.46	 190.46	 0.0	 0.0	 1	 -30.0	 30.0;
	70031	 70032	 0.000244	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70034	 70032	 0.024203	 0.118766	 0.48473	 275.51	 275.51	 275.51	 0.0	 0.0	 1	 -30.0	 30.0;
	70032	 77020	 0.050222	 0.335996	 0.10495	 181.36	 181.36	 181.36	 0.0	 0.0	 1	 -30.0	 30.0;
	70032	 77215	 0.017594	 0.073821	 0.09817	 279.4	 279.4	 279.4	 0.0	 0.0	 1	 -30.0	 30.0;
	70034	 70033	 0.020217	 0.123518	 0.03648	 197.94	 197.94	 197.94	 0.0	 0.0	 1	 -30.0	 30.0;
	70034	 70036	 0.028748	 0.122869	 0.04042	 205.83	 205.83	 205.83	 0.0	 0.0	 1	 -30.0	 30.0;
	70035	 70036	 0.00028	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70036	 70040	 0.022474	 0.122291	 0.05643	 218.57	 218.57	 218.57	 0.0	 0.0	 1	 -30.0	 30.0;
	70037	 70042	 0.041469	 0.234404	 0.06826	 215.67	 215.67	 215.67	 0.0	 0.0	 1	 -30.0	 30.0;
	70037	 70182	 0.050703	 0.257584	 0.03371	 239.35	 239.35	 239.35	 0.0	 0.0	 1	 -30.0	 30.0;
	70038	 70039	 0.000261	 0.001149	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77003	 70039	 0.011296	 0.08136	 0.02215	 233.2	 233.2	 233.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70039	 77005	 0.023385	 0.142763	 0.07418	 238.93	 238.93	 238.93	 0.0	 0.0	 1	 -30.0	 30.0;
	70040	 70041	 0.000209	 0.001174	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70047	 70040	 0.018585	 0.091554	 0.04977	 239.84	 239.84	 239.84	 0.0	 0.0	 1	 -30.0	 30.0;
	70040	 77003	 0.011448	 0.060408	 0.083	 254.21	 254.21	 254.21	 0.0	 0.0	 1	 -30.0	 30.0;
	70042	 70043	 0.000297	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70042	 70061	 0.041729	 0.195508	 0.06816	 237.8	 237.8	 237.8	 0.0	 0.0	 1	 -30.0	 30.0;
	70129	 70042	 0.025866	 0.153538	 0.05917	 221.59	 221.59	 221.59	 0.0	 0.0	 1	 -30.0	 30.0;
	70044	 70045	 0.000255	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70046	 70044	 0.006335	 0.042666	 0.01155	 182.51	 182.51	 182.51	 0.0	 0.0	 1	 -30.0	 30.0;
	70162	 70044	 0.005194	 0.035988	 0.04017	 217.96	 217.96	 217.96	 0.0	 0.0	 1	 -30.0	 30.0;
	70046	 70052	 0.01745	 0.077566	 0.04134	 228.92	 228.92	 228.92	 0.0	 0.0	 1	 -30.0	 30.0;
	70047	 70048	 0.000209	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70065	 70047	 0.051701	 0.263967	 0.05481	 220.52	 220.52	 220.52	 0.0	 0.0	 1	 -30.0	 30.0;
	70049	 70050	 0.000206	 0.001054	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70049	 70051	 0.000229	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70051	 70052	 0.004599	 0.024286	 0.00758	 199.33	 199.33	 199.33	 0.0	 0.0	 1	 -30.0	 30.0;
	70051	 70058	 0.012472	 0.069427	 0.04006	 238.59	 238.59	 238.59	 0.0	 0.0	 1	 -30.0	 30.0;
	70148	 70052	 0.01488	 0.083094	 0.02631	 242.97	 242.97	 242.97	 0.0	 0.0	 1	 -30.0	 30.0;
	70053	 70056	 -0.000176	 -0.005387	 0.0	 259.95	 259.95	 259.95	 1.0	 0.0	 1	 -30.0	 30.0;
	70053	 70057	 0.000285	 0.001135	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70054	 70056	 0.003811	 0.116424	 0.0	 129.98	 129.98	 129.98	 1.0	 0.0	 1	 -30.0	 30.0;
	70055	 70056	 0.003811	 0.116424	 0.0	 129.98	 129.98	 129.98	 1.0	 0.0	 1	 -30.0	 30.0;
	70057	 70058	 0.004066	 0.018725	 0.0512	 195.92	 195.92	 195.92	 0.0	 0.0	 1	 -30.0	 30.0;
	70057	 70059	 0.008679	 0.057093	 0.03053	 219.49	 219.49	 219.49	 0.0	 0.0	 1	 -30.0	 30.0;
	70058	 70103	 0.009567	 0.057773	 0.04087	 246.69	 246.69	 246.69	 0.0	 0.0	 1	 -30.0	 30.0;
	70059	 70060	 0.00024	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70096	 70059	 0.001845	 0.009536	 0.0182	 222.3	 222.3	 222.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70059	 70179	 0.005734	 0.035166	 0.04382	 248.1	 248.1	 248.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70109	 70061	 0.026166	 0.16084	 0.07639	 249.98	 249.98	 249.98	 0.0	 0.0	 1	 -30.0	 30.0;
	70061	 70113	 0.024555	 0.130334	 0.05292	 250.74	 250.74	 250.74	 0.0	 0.0	 1	 -30.0	 30.0;
	70062	 70063	 0.000226	 0.001137	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70062	 70064	 0.00021	 0.001185	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70064	 70065	 0.012208	 0.074047	 0.09981	 212.2	 212.2	 212.2	 0.0	 0.0	 1	 -30.0	 30.0;
	70118	 70064	 0.008706	 0.048668	 0.02788	 247.94	 247.94	 247.94	 0.0	 0.0	 1	 -30.0	 30.0;
	70065	 70066	 0.012077	 0.070166	 0.02461	 262.26	 262.26	 262.26	 0.0	 0.0	 1	 -30.0	 30.0;
	70065	 70175	 0.006047	 0.04292	 0.13614	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70066	 70096	 0.022664	 0.104962	 0.25099	 261.28	 261.28	 261.28	 0.0	 0.0	 1	 -30.0	 30.0;
	70067	 70082	 0.018295	 0.113891	 0.1021	 255.39	 255.39	 255.39	 0.0	 0.0	 1	 -30.0	 30.0;
	70067	 70129	 0.020997	 0.110313	 0.06154	 267.69	 267.69	 267.69	 0.0	 0.0	 1	 -30.0	 30.0;
	70068	 70103	 0.015679	 0.111721	 0.03984	 183.54	 183.54	 183.54	 0.0	 0.0	 1	 -30.0	 30.0;
	70068	 70159	 0.011437	 0.083639	 0.05427	 204.97	 204.97	 204.97	 0.0	 0.0	 1	 -30.0	 30.0;
	70069	 70070	 0.000209	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70069	 70094	 0.020255	 0.108196	 0.15988	 235.02	 235.02	 235.02	 0.0	 0.0	 1	 -30.0	 30.0;
	70069	 70171	 0.009295	 0.043357	 0.03502	 213.37	 213.37	 213.37	 0.0	 0.0	 1	 -30.0	 30.0;
	70071	 70074	 0.011374	 0.373713	 0.0	 167.33	 167.33	 167.33	 1.0	 0.0	 1	 -30.0	 30.0;
	70071	 70075	 0.000344	 0.002143	 0.00163	 252.14	 252.14	 252.14	 0.0	 0.0	 1	 -30.0	 30.0;
	70071	 70109	 0.003029	 0.016758	 0.01212	 269.45	 269.45	 269.45	 0.0	 0.0	 1	 -30.0	 30.0;
	70072	 70074	 -0.006603	 -0.216946	 0.0	 90.0	 90.0	 90.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70072	 70076	 0.000908	 0.004733	 0.00089	 171.07	 171.07	 171.07	 0.0	 0.0	 1	 -30.0	 30.0;
	70073	 70074	 0.026373	 0.866487	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70076	 70075	 0.004804	 0.135729	 0.0	 102.77	 102.77	 102.77	 1.01875	 0.0	 1	 -30.0	 30.0;
	70076	 70075	 0.004804	 0.135729	 0.0	 102.77	 102.77	 102.77	 1.025	 0.0	 1	 -30.0	 30.0;
	70076	 70075	 0.004804	 0.135729	 0.0	 102.77	 102.77	 102.77	 1.025	 0.0	 1	 -30.0	 30.0;
	70076	 70075	 0.004804	 0.135729	 0.0	 102.77	 102.77	 102.77	 1.025	 0.0	 1	 -30.0	 30.0;
	70075	 70109	 0.003497	 0.022717	 0.00737	 260.76	 260.76	 260.76	 0.0	 0.0	 1	 -30.0	 30.0;
	70076	 70138	 0.011573	 0.066691	 0.02391	 140.37	 140.37	 140.37	 0.0	 0.0	 1	 -30.0	 30.0;
	70090	 70077	 0.022107	 0.118446	 0.03314	 222.83	 222.83	 222.83	 0.0	 0.0	 1	 -30.0	 30.0;
	70077	 70185	 0.008889	 0.062531	 0.08871	 235.72	 235.72	 235.72	 0.0	 0.0	 1	 -30.0	 30.0;
	70078	 70079	 0.000224	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70078	 70080	 0.000288	 0.001011	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70078	 70081	 0.000294	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70086	 0.008922	 0.052683	 0.03318	 276.35	 276.35	 276.35	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70109	 0.004497	 0.029918	 0.06265	 276.46	 276.46	 276.46	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70109	 0.004497	 0.029918	 0.06265	 276.46	 276.46	 276.46	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70109	 0.004497	 0.029918	 0.06265	 276.46	 276.46	 276.46	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70171	 0.016523	 0.07993	 0.21032	 282.72	 282.72	 282.72	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70171	 0.016523	 0.07993	 0.21032	 282.72	 282.72	 282.72	 0.0	 0.0	 1	 -30.0	 30.0;
	70080	 70171	 0.016523	 0.07993	 0.21032	 282.72	 282.72	 282.72	 0.0	 0.0	 1	 -30.0	 30.0;
	70092	 70082	 0.019069	 0.08696	 0.04142	 236.49	 236.49	 236.49	 0.0	 0.0	 1	 -30.0	 30.0;
	70083	 70094	 0.018435	 0.14795	 0.04592	 225.31	 225.31	 225.31	 0.0	 0.0	 1	 -30.0	 30.0;
	70171	 70083	 0.005175	 0.027804	 0.01182	 216.0	 216.0	 216.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70085	 70084	 0.006402	 0.179029	 0.0	 72.89	 72.89	 72.89	 1.0	 0.0	 1	 -30.0	 30.0;
	70084	 70086	 0.000225	 0.001164	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70084	 70087	 0.000207	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70138	 70085	 0.004203	 0.020563	 0.00476	 142.0	 142.0	 142.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70086	 70109	 0.006395	 0.030337	 0.04113	 240.55	 240.55	 240.55	 0.0	 0.0	 1	 -30.0	 30.0;
	70137	 70086	 0.003294	 0.020894	 0.00495	 260.88	 260.88	 260.88	 0.0	 0.0	 1	 -30.0	 30.0;
	70088	 70089	 0.00027	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70090	 70089	 0.017677	 0.097055	 0.08731	 216.08	 216.08	 216.08	 0.0	 0.0	 1	 -30.0	 30.0;
	70089	 70093	 0.029322	 0.174881	 0.19311	 265.22	 265.22	 265.22	 0.0	 0.0	 1	 -30.0	 30.0;
	70089	 70167	 0.015586	 0.103132	 0.13002	 255.57	 255.57	 255.57	 0.0	 0.0	 1	 -30.0	 30.0;
	70090	 70091	 0.000235	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70093	 70094	 0.042487	 0.204003	 0.11544	 261.44	 261.44	 261.44	 0.0	 0.0	 1	 -30.0	 30.0;
	70096	 70095	 0.00021	 0.013784	 0.0	 520.94	 520.94	 520.94	 1.0	 0.0	 1	 -30.0	 30.0;
	70095	 70097	 0.000389	 0.024822	 0.0	 545.38	 545.38	 545.38	 1.0	 0.0	 1	 -30.0	 30.0;
	70095	 70098	 0.000266	 0.015454	 0.0	 544.36	 544.36	 544.36	 1.0	 0.0	 1	 -30.0	 30.0;
	70095	 70099	 0.000534	 0.032741	 0.0	 542.58	 542.58	 542.58	 1.0	 0.0	 1	 -30.0	 30.0;
	70095	 70100	 0.000329	 0.016991	 0.0	 541.78	 541.78	 541.78	 1.0	 0.0	 1	 -30.0	 30.0;
	70095	 70101	 0.000202	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70095	 70102	 0.000267	 0.001002	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70103	 70096	 0.00501	 0.02819	 0.00848	 260.5	 260.5	 260.5	 0.0	 0.0	 1	 -30.0	 30.0;
	70116	 70101	 0.003068	 0.038762	 0.91914	 1380.92	 1380.92	 1380.92	 0.0	 0.0	 1	 -30.0	 30.0;
	70117	 70101	 0.005693	 0.069624	 1.28171	 1370.14	 1370.14	 1370.14	 0.0	 0.0	 1	 -30.0	 30.0;
	70132	 70101	 0.004026	 0.054082	 1.32521	 1461.7	 1461.7	 1461.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70101	 70161	 0.002073	 0.025099	 0.60009	 1223.49	 1223.49	 1223.49	 0.0	 0.0	 1	 -30.0	 30.0;
	70170	 70101	 0.003214	 0.036634	 1.00973	 1378.84	 1378.84	 1378.84	 0.0	 0.0	 1	 -30.0	 30.0;
	70103	 70104	 0.000599	 0.021275	 0.0	 260.0	 260.0	 260.0	 1.0625	 0.0	 1	 -30.0	 30.0;
	70105	 70106	 0.000261	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70110	 70106	 0.000189	 0.001189	 0.00021	 212.85	 212.85	 212.85	 0.0	 0.0	 1	 -30.0	 30.0;
	70167	 70106	 0.00017	 0.001167	 0.00125	 215.12	 215.12	 215.12	 0.0	 0.0	 1	 -30.0	 30.0;
	70106	 70185	 0.000325	 0.002443	 0.0013	 225.23	 225.23	 225.23	 0.0	 0.0	 1	 -30.0	 30.0;
	70107	 70108	 0.000282	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70107	 70109	 0.000254	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70110	 70133	 0.000357	 0.001916	 0.00102	 177.1	 177.1	 177.1	 0.0	 0.0	 1	 -30.0	 30.0;
	70111	 70162	 0.005715	 0.033918	 0.01033	 243.38	 243.38	 243.38	 0.0	 0.0	 1	 -30.0	 30.0;
	70182	 70111	 0.016014	 0.111028	 0.03161	 191.7	 191.7	 191.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70113	 70112	 0.000707	 0.033904	 0.0	 266.17	 266.17	 266.17	 1.0	 0.0	 1	 -30.0	 30.0;
	70112	 70114	 0.000554	 0.036706	 0.0	 421.85	 421.85	 421.85	 1.0	 0.0	 1	 -30.0	 30.0;
	70112	 70115	 0.000645	 0.033416	 0.0	 303.35	 303.35	 303.35	 1.00625	 0.0	 1	 -30.0	 30.0;
	70112	 70116	 0.000247	 0.001186	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70113	 70178	 0.017005	 0.086488	 0.04719	 251.89	 251.89	 251.89	 0.0	 0.0	 1	 -30.0	 30.0;
	70116	 70135	 0.003025	 0.04123	 0.98232	 1371.02	 1371.02	 1371.02	 0.0	 0.0	 1	 -30.0	 30.0;
	70161	 70116	 0.003144	 0.040802	 0.83189	 1293.28	 1293.28	 1293.28	 0.0	 0.0	 1	 -30.0	 30.0;
	70117	 70120	 0.001477	 0.068419	 0.0	 518.51	 518.51	 518.51	 1.0	 0.0	 1	 -30.0	 30.0;
	70117	 70121	 0.000271	 0.017861	 0.0	 628.81	 628.81	 628.81	 1.0	 0.0	 1	 -30.0	 30.0;
	70132	 70117	 0.000425	 0.004887	 0.20046	 1077.12	 1077.12	 1077.12	 0.0	 0.0	 1	 -30.0	 30.0;
	70117	 77262	 0.006108	 0.080186	 1.0162	 1372.84	 1372.84	 1372.84	 0.0	 0.0	 1	 -30.0	 30.0;
	70118	 70120	 -0.000615	 -0.028483	 0.0	 393.05	 393.05	 393.05	 1.0	 0.0	 1	 -30.0	 30.0;
	70119	 70120	 0.006202	 0.287305	 0.0	 125.46	 125.46	 125.46	 1.0	 0.0	 1	 -30.0	 30.0;
	70123	 70122	 0.00063	 0.031347	 0.0	 445.77	 445.77	 445.77	 1.025	 0.0	 1	 -30.0	 30.0;
	70122	 70125	 0.000307	 0.019977	 0.0	 588.19	 588.19	 588.19	 1.00625	 0.0	 1	 -30.0	 30.0;
	70122	 70126	 0.000358	 0.020066	 0.0	 587.37	 587.37	 587.37	 1.00625	 0.0	 1	 -30.0	 30.0;
	70122	 70127	 0.000341	 0.019891	 0.0	 585.62	 585.62	 585.62	 1.00625	 0.0	 1	 -30.0	 30.0;
	70157	 70122	 0.004296	 0.056928	 1.3095	 1257.18	 1257.18	 1257.18	 0.0	 0.0	 1	 -30.0	 30.0;
	70124	 70123	 0.004229	 0.112697	 0.0	 92.9	 92.9	 92.9	 1.0	 0.0	 1	 -30.0	 30.0;
	70128	 70129	 0.000259	 0.001142	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70145	 70129	 0.043384	 0.126111	 0.03583	 229.6	 229.6	 229.6	 0.0	 0.0	 1	 -30.0	 30.0;
	70178	 70129	 0.018969	 0.087222	 0.02264	 230.7	 230.7	 230.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70130	 70131	 0.005939	 0.175416	 0.0	 100.34	 100.34	 100.34	 1.0	 0.0	 1	 -30.0	 30.0;
	70130	 70169	 0.00404	 0.021905	 0.00498	 219.3	 219.3	 219.3	 0.0	 0.0	 1	 -30.0	 30.0;
	70133	 70132	 0.000384	 0.023545	 0.0	 433.4	 433.4	 433.4	 1.0	 0.0	 1	 -30.0	 30.0;
	70132	 70134	 0.00032	 0.01788	 0.0	 601.3	 601.3	 601.3	 1.06875	 0.0	 1	 -30.0	 30.0;
	70132	 77262	 0.006598	 0.070618	 1.20678	 1418.83	 1418.83	 1418.83	 0.0	 0.0	 1	 -30.0	 30.0;
	70167	 70133	 0.00026	 0.001684	 0.00124	 229.97	 229.97	 229.97	 0.0	 0.0	 1	 -30.0	 30.0;
	70133	 70175	 0.000227	 0.001253	 0.00051	 252.7	 252.7	 252.7	 0.0	 0.0	 1	 -30.0	 30.0;
	70135	 70140	 0.001329	 0.076913	 0.0	 596.12	 596.12	 596.12	 1.0	 0.0	 1	 -30.0	 30.0;
	70135	 70143	 0.0001	 0.0001	 0.0	 926.3	 926.3	 926.3	 1.0	 0.0	 1	 -30.0	 30.0;
	70135	 70144	 0.00033	 0.020953	 0.0	 395.58	 395.58	 395.58	 1.0	 0.0	 1	 -30.0	 30.0;
	70137	 70136	 0.001145	 0.057771	 0.0	 122.83	 122.83	 122.83	 1.025	 0.0	 1	 -30.0	 30.0;
	70136	 70140	 -0.000702	 -0.040632	 0.0	 496.12	 496.12	 496.12	 1.0	 0.0	 1	 -30.0	 30.0;
	70138	 70137	 0.003335	 0.113043	 0.0	 83.92	 83.92	 83.92	 1.0375	 0.0	 1	 -30.0	 30.0;
	70138	 70137	 0.003335	 0.113043	 0.0	 83.92	 83.92	 83.92	 1.01875	 0.0	 1	 -30.0	 30.0;
	70138	 70137	 0.003335	 0.113043	 0.0	 83.92	 83.92	 83.92	 1.0375	 0.0	 1	 -30.0	 30.0;
	70139	 70140	 0.003719	 0.215215	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70141	 70143	 0.000501	 0.030188	 0.0	 463.15	 463.15	 463.15	 1.0	 0.0	 1	 -30.0	 30.0;
	70142	 70143	 0.000501	 0.030188	 0.0	 463.15	 463.15	 463.15	 1.0	 0.0	 1	 -30.0	 30.0;
	70145	 70146	 0.003387	 0.079656	 0.0	 150.54	 150.54	 150.54	 0.98125	 0.0	 1	 -30.0	 30.0;
	70178	 70145	 0.00936	 0.056516	 0.02364	 219.84	 219.84	 219.84	 0.0	 0.0	 1	 -30.0	 30.0;
	70147	 70152	 0.027755	 0.165418	 0.10877	 237.52	 237.52	 237.52	 0.0	 0.0	 1	 -30.0	 30.0;
	70148	 70149	 0.001767	 0.058659	 0.0	 128.7	 128.7	 128.7	 1.0	 0.0	 1	 -30.0	 30.0;
	70148	 70150	 0.01264	 0.443978	 0.0	 23.36	 23.36	 23.36	 1.0	 0.0	 1	 -30.0	 30.0;
	70179	 70148	 0.00767	 0.042739	 0.01001	 242.78	 242.78	 242.78	 0.0	 0.0	 1	 -30.0	 30.0;
	70152	 70151	 0.000463	 0.029412	 0.0	 434.23	 434.23	 434.23	 1.0	 0.0	 1	 -30.0	 30.0;
	70151	 70153	 0.000191	 0.011448	 0.0	 793.62	 793.62	 793.62	 1.0	 0.0	 1	 -30.0	 30.0;
	70151	 70154	 0.000232	 0.017629	 0.0	 793.62	 793.62	 793.62	 1.0	 0.0	 1	 -30.0	 30.0;
	70151	 70155	 0.000313	 0.016566	 0.0	 793.62	 793.62	 793.62	 1.0	 0.0	 1	 -30.0	 30.0;
	70151	 70156	 0.000216	 0.0111	 0.0	 793.62	 793.62	 793.62	 1.0	 0.0	 1	 -30.0	 30.0;
	70151	 70157	 0.000272	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70151	 70157	 0.000272	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70151	 70158	 0.000292	 0.001082	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70159	 70160	 0.005737	 0.145872	 0.0	 134.29	 134.29	 134.29	 0.9875	 0.0	 1	 -30.0	 30.0;
	70159	 70179	 0.001868	 0.012835	 0.00635	 243.92	 243.92	 243.92	 0.0	 0.0	 1	 -30.0	 30.0;
	70162	 70161	 0.000537	 0.032395	 0.0	 394.69	 394.69	 394.69	 1.0125	 0.0	 1	 -30.0	 30.0;
	70161	 70166	 0.000878	 0.052455	 0.0	 262.28	 262.28	 262.28	 1.0	 0.0	 1	 -30.0	 30.0;
	70162	 70163	 0.010736	 0.355068	 0.0	 38.93	 38.93	 38.93	 1.0	 0.0	 1	 -30.0	 30.0;
	70162	 70164	 0.004774	 0.159686	 0.0	 75.17	 75.17	 75.17	 1.0	 0.0	 1	 -30.0	 30.0;
	70162	 70165	 0.007377	 0.272902	 0.0	 65.0	 65.0	 65.0	 1.0	 0.0	 1	 -30.0	 30.0;
	70168	 70169	 0.000203	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70171	 70170	 0.000525	 0.032594	 0.0	 684.9	 684.9	 684.9	 1.0	 0.0	 1	 -30.0	 30.0;
	70170	 70172	 0.000378	 0.027228	 0.0	 741.0	 741.0	 741.0	 1.075	 0.0	 1	 -30.0	 30.0;
	70170	 70173	 0.000306	 0.019644	 0.0	 741.0	 741.0	 741.0	 1.075	 0.0	 1	 -30.0	 30.0;
	70170	 70174	 0.000458	 0.025307	 0.0	 741.0	 741.0	 741.0	 1.075	 0.0	 1	 -30.0	 30.0;
	70175	 70176	 0.001669	 0.058841	 0.0	 151.06	 151.06	 151.06	 1.0	 0.0	 1	 -30.0	 30.0;
	70185	 70175	 0.00022	 0.000838	 0.00034	 195.63	 195.63	 195.63	 0.0	 0.0	 1	 -30.0	 30.0;
	70177	 70178	 0.000256	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70179	 70180	 0.004764	 0.140672	 0.0	 106.24	 106.24	 106.24	 0.975	 0.0	 1	 -30.0	 30.0;
	70179	 70181	 0.00466	 0.134974	 0.0	 105.72	 105.72	 105.72	 1.0	 0.0	 1	 -30.0	 30.0;
	70183	 70184	 0.004785	 0.133879	 0.0	 123.5	 123.5	 123.5	 1.0	 0.0	 1	 -30.0	 30.0;
	70183	 70185	 0.00025	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70183	 70186	 0.000268	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70187	 70188	 0.003763	 0.122939	 0.0	 105.4	 105.4	 105.4	 0.99375	 0.0	 1	 -30.0	 30.0;
	70187	 70189	 0.008079	 0.198751	 0.0	 70.36	 70.36	 70.36	 0.99375	 0.0	 1	 -30.0	 30.0;
	70187	 70190	 0.000292	 0.001193	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74000	 74001	 0.013921	 0.095606	 0.03894	 242.42	 242.42	 242.42	 0.0	 0.0	 1	 -30.0	 30.0;
	74019	 74001	 0.003777	 0.026164	 0.0073	 218.81	 218.81	 218.81	 0.0	 0.0	 1	 -30.0	 30.0;
	74001	 74228	 0.011013	 0.062996	 0.1036	 200.25	 200.25	 200.25	 0.0	 0.0	 1	 -30.0	 30.0;
	74002	 74033	 0.003894	 0.019383	 0.03908	 234.09	 234.09	 234.09	 0.0	 0.0	 1	 -30.0	 30.0;
	74002	 74208	 0.001521	 0.008703	 0.00713	 243.8	 243.8	 243.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74002	 74241	 0.003079	 0.016539	 0.00828	 249.64	 249.64	 249.64	 0.0	 0.0	 1	 -30.0	 30.0;
	74003	 74208	 0.003981	 0.027026	 0.01569	 241.99	 241.99	 241.99	 0.0	 0.0	 1	 -30.0	 30.0;
	74004	 74005	 0.00022	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74251	 74004	 0.035075	 0.202296	 0.04918	 246.75	 246.75	 246.75	 0.0	 0.0	 1	 -30.0	 30.0;
	74006	 74007	 0.000214	 0.001195	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74208	 74006	 0.006049	 0.031833	 0.02275	 243.34	 243.34	 243.34	 0.0	 0.0	 1	 -30.0	 30.0;
	74008	 74009	 0.000216	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74008	 74011	 0.004085	 0.02304	 0.01563	 218.88	 218.88	 218.88	 0.0	 0.0	 1	 -30.0	 30.0;
	74008	 74022	 0.011573	 0.058672	 0.04857	 188.01	 188.01	 188.01	 0.0	 0.0	 1	 -30.0	 30.0;
	74008	 74027	 0.008287	 0.048404	 0.01159	 178.8	 178.8	 178.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74010	 74011	 0.000249	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74011	 74214	 0.007672	 0.04802	 0.08983	 234.36	 234.36	 234.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74012	 74034	 0.007135	 0.031276	 0.03831	 245.03	 245.03	 245.03	 0.0	 0.0	 1	 -30.0	 30.0;
	74013	 74214	 0.009457	 0.067636	 0.03445	 245.52	 245.52	 245.52	 0.0	 0.0	 1	 -30.0	 30.0;
	74014	 74015	 0.000219	 0.001173	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74014	 74214	 0.003962	 0.028178	 0.06432	 241.67	 241.67	 241.67	 0.0	 0.0	 1	 -30.0	 30.0;
	74016	 74040	 0.012255	 0.062905	 0.05068	 177.83	 177.83	 177.83	 0.0	 0.0	 1	 -30.0	 30.0;
	74016	 74054	 0.017916	 0.075657	 0.0268	 180.53	 180.53	 180.53	 0.0	 0.0	 1	 -30.0	 30.0;
	74017	 74029	 0.001357	 0.00857	 0.01095	 210.85	 210.85	 210.85	 0.0	 0.0	 1	 -30.0	 30.0;
	74327	 74017	 0.005037	 0.028722	 0.00543	 237.42	 237.42	 237.42	 0.0	 0.0	 1	 -30.0	 30.0;
	74018	 74056	 0.010571	 0.05234	 0.09069	 217.83	 217.83	 217.83	 0.0	 0.0	 1	 -30.0	 30.0;
	74300	 74018	 0.004201	 0.02532	 0.01225	 194.88	 194.88	 194.88	 0.0	 0.0	 1	 -30.0	 30.0;
	74019	 74049	 0.005333	 0.033561	 0.0737	 201.04	 201.04	 201.04	 0.0	 0.0	 1	 -30.0	 30.0;
	74020	 74021	 0.000239	 0.00115	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74021	 74030	 0.011521	 0.055163	 0.03599	 235.7	 235.7	 235.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74022	 74023	 0.000204	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74054	 74022	 0.004381	 0.024133	 0.1679	 199.21	 199.21	 199.21	 0.0	 0.0	 1	 -30.0	 30.0;
	74033	 74024	 0.001261	 0.006283	 0.0034	 242.21	 242.21	 242.21	 0.0	 0.0	 1	 -30.0	 30.0;
	74025	 74208	 0.003407	 0.019146	 0.03452	 244.65	 244.65	 244.65	 0.0	 0.0	 1	 -30.0	 30.0;
	74026	 74034	 0.001617	 0.008343	 0.0036	 218.33	 218.33	 218.33	 0.0	 0.0	 1	 -30.0	 30.0;
	74026	 74058	 0.004164	 0.025811	 0.01736	 206.34	 206.34	 206.34	 0.0	 0.0	 1	 -30.0	 30.0;
	74027	 74028	 0.000293	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74029	 74065	 0.005507	 0.032612	 0.07268	 242.65	 242.65	 242.65	 0.0	 0.0	 1	 -30.0	 30.0;
	74327	 74029	 0.005634	 0.026183	 0.01516	 242.14	 242.14	 242.14	 0.0	 0.0	 1	 -30.0	 30.0;
	74030	 74031	 0.000222	 0.001144	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74030	 74032	 0.000231	 0.001185	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74030	 74056	 0.005872	 0.041735	 0.0201	 242.65	 242.65	 242.65	 0.0	 0.0	 1	 -30.0	 30.0;
	74040	 74033	 0.005563	 0.029957	 0.02756	 242.66	 242.66	 242.66	 0.0	 0.0	 1	 -30.0	 30.0;
	74035	 74042	 0.002908	 0.017527	 0.00863	 196.38	 196.38	 196.38	 0.0	 0.0	 1	 -30.0	 30.0;
	74045	 74035	 0.002016	 0.012568	 0.00427	 240.23	 240.23	 240.23	 0.0	 0.0	 1	 -30.0	 30.0;
	74036	 74039	 0.0001	 -0.001979	 0.0	 279.48	 279.48	 279.48	 1.0	 0.0	 1	 -30.0	 30.0;
	74036	 74040	 0.000298	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74036	 74041	 0.000235	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74037	 74039	 0.00181	 0.063991	 0.0	 139.74	 139.74	 139.74	 1.0	 0.0	 1	 -30.0	 30.0;
	74038	 74039	 0.00181	 0.063991	 0.0	 139.74	 139.74	 139.74	 1.0	 0.0	 1	 -30.0	 30.0;
	74040	 77179	 0.013716	 0.081491	 0.29911	 266.36	 266.36	 266.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74042	 74043	 0.000254	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74058	 74042	 0.001606	 0.008846	 0.00358	 233.73	 233.73	 233.73	 0.0	 0.0	 1	 -30.0	 30.0;
	74042	 74070	 0.005731	 0.031095	 0.02883	 209.54	 209.54	 209.54	 0.0	 0.0	 1	 -30.0	 30.0;
	74044	 74045	 0.000278	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74047	 74045	 0.000922	 0.004522	 0.00192	 250.9	 250.9	 250.9	 0.0	 0.0	 1	 -30.0	 30.0;
	74047	 74046	 0.000415	 0.02812	 0.0	 451.6	 451.6	 451.6	 1.0125	 0.0	 1	 -30.0	 30.0;
	74046	 74048	 0.000222	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74083	 74046	 0.000531	 0.00673	 0.13782	 1126.2	 1126.2	 1126.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74330	 74046	 0.001164	 0.015283	 0.27005	 1284.36	 1284.36	 1284.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74049	 74047	 0.010939	 0.051734	 0.01881	 221.83	 221.83	 221.83	 0.0	 0.0	 1	 -30.0	 30.0;
	74047	 74061	 0.006623	 0.033605	 0.02339	 228.22	 228.22	 228.22	 0.0	 0.0	 1	 -30.0	 30.0;
	74050	 74051	 0.000271	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74050	 74066	 0.00287	 0.017732	 0.00551	 227.42	 227.42	 227.42	 0.0	 0.0	 1	 -30.0	 30.0;
	74050	 74327	 0.015239	 0.069641	 0.02636	 240.96	 240.96	 240.96	 0.0	 0.0	 1	 -30.0	 30.0;
	74052	 74053	 0.00023	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74052	 74063	 0.022669	 0.119943	 0.05406	 201.41	 201.41	 201.41	 0.0	 0.0	 1	 -30.0	 30.0;
	74267	 74052	 0.00788	 0.050739	 0.01511	 206.15	 206.15	 206.15	 0.0	 0.0	 1	 -30.0	 30.0;
	74052	 77174	 0.062524	 0.478049	 0.08188	 198.57	 198.57	 198.57	 0.0	 0.0	 1	 -30.0	 30.0;
	74054	 74055	 0.000225	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74111	 74054	 0.033343	 0.164769	 0.04105	 226.97	 226.97	 226.97	 0.0	 0.0	 1	 -30.0	 30.0;
	74056	 74057	 0.00029	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74056	 74063	 0.010307	 0.071706	 0.01392	 224.57	 224.57	 224.57	 0.0	 0.0	 1	 -30.0	 30.0;
	74235	 74056	 0.013183	 0.096126	 0.02803	 247.14	 247.14	 247.14	 0.0	 0.0	 1	 -30.0	 30.0;
	74058	 74327	 0.009944	 0.054804	 0.05501	 257.34	 257.34	 257.34	 0.0	 0.0	 1	 -30.0	 30.0;
	74059	 74060	 0.000212	 0.001176	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74059	 74061	 0.000223	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74059	 74062	 0.000221	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74061	 74078	 0.004761	 0.02797	 0.02341	 182.89	 182.89	 182.89	 0.0	 0.0	 1	 -30.0	 30.0;
	74235	 74063	 0.014473	 0.076837	 0.07492	 240.77	 240.77	 240.77	 0.0	 0.0	 1	 -30.0	 30.0;
	74064	 74065	 0.00021	 0.001061	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74073	 74065	 0.005171	 0.029425	 0.02439	 218.77	 218.77	 218.77	 0.0	 0.0	 1	 -30.0	 30.0;
	74073	 74066	 0.001806	 0.011306	 0.00279	 218.61	 218.61	 218.61	 0.0	 0.0	 1	 -30.0	 30.0;
	74066	 74093	 0.003475	 0.023551	 0.03634	 237.72	 237.72	 237.72	 0.0	 0.0	 1	 -30.0	 30.0;
	74067	 74068	 0.000226	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74067	 74069	 0.001113	 0.007988	 0.00503	 204.38	 204.38	 204.38	 0.0	 0.0	 1	 -30.0	 30.0;
	74075	 74067	 0.000668	 0.00388	 0.00393	 221.36	 221.36	 221.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74069	 74073	 0.004174	 0.027556	 0.0567	 244.13	 244.13	 244.13	 0.0	 0.0	 1	 -30.0	 30.0;
	74070	 74084	 0.00222	 0.0107	 0.01752	 202.14	 202.14	 202.14	 0.0	 0.0	 1	 -30.0	 30.0;
	74093	 74071	 0.00403	 0.024302	 0.00466	 185.08	 185.08	 185.08	 0.0	 0.0	 1	 -30.0	 30.0;
	74071	 74109	 0.011463	 0.065078	 0.0662	 222.11	 222.11	 222.11	 0.0	 0.0	 1	 -30.0	 30.0;
	74073	 74072	 0.000662	 0.032891	 0.0	 449.47	 449.47	 449.47	 1.01875	 0.0	 1	 -30.0	 30.0;
	74072	 74074	 0.000251	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74083	 74072	 0.000678	 0.007586	 0.28465	 1163.31	 1163.31	 1163.31	 0.0	 0.0	 1	 -30.0	 30.0;
	74072	 74330	 0.000906	 0.012021	 0.2184	 1321.35	 1321.35	 1321.35	 0.0	 0.0	 1	 -30.0	 30.0;
	74073	 74087	 0.003233	 0.018722	 0.00669	 242.47	 242.47	 242.47	 0.0	 0.0	 1	 -30.0	 30.0;
	74073	 74105	 0.008201	 0.048544	 0.02091	 213.16	 213.16	 213.16	 0.0	 0.0	 1	 -30.0	 30.0;
	74075	 74076	 0.000222	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74075	 74084	 0.000692	 0.004575	 0.00303	 242.93	 242.93	 242.93	 0.0	 0.0	 1	 -30.0	 30.0;
	74077	 74078	 0.00029	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74098	 74078	 0.002603	 0.014751	 0.00346	 199.94	 199.94	 199.94	 0.0	 0.0	 1	 -30.0	 30.0;
	74078	 74112	 0.003161	 0.018715	 0.01695	 230.15	 230.15	 230.15	 0.0	 0.0	 1	 -30.0	 30.0;
	74079	 74080	 0.000256	 0.001163	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74079	 74081	 0.000297	 0.001191	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74079	 74082	 0.000224	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74080	 74089	 0.004643	 0.025437	 0.02081	 206.2	 206.2	 206.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74228	 74080	 0.006831	 0.038272	 0.03712	 221.34	 221.34	 221.34	 0.0	 0.0	 1	 -30.0	 30.0;
	74084	 74083	 0.000804	 0.041148	 0.0	 433.52	 433.52	 433.52	 1.0125	 0.0	 1	 -30.0	 30.0;
	74218	 74083	 0.000718	 0.008796	 0.15629	 1149.93	 1149.93	 1149.93	 0.0	 0.0	 1	 -30.0	 30.0;
	74223	 74083	 0.00154	 0.017989	 0.73517	 1256.69	 1256.69	 1256.69	 0.0	 0.0	 1	 -30.0	 30.0;
	74084	 74088	 0.002346	 0.014146	 0.00769	 171.91	 171.91	 171.91	 0.0	 0.0	 1	 -30.0	 30.0;
	74085	 74086	 0.000263	 0.001114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74089	 74085	 0.000579	 0.0042	 0.00095	 197.54	 197.54	 197.54	 0.0	 0.0	 1	 -30.0	 30.0;
	74102	 74085	 0.004631	 0.020748	 0.00736	 212.94	 212.94	 212.94	 0.0	 0.0	 1	 -30.0	 30.0;
	74085	 74103	 0.004716	 0.027956	 0.01205	 231.31	 231.31	 231.31	 0.0	 0.0	 1	 -30.0	 30.0;
	74093	 74087	 0.003233	 0.017876	 0.01514	 204.37	 204.37	 204.37	 0.0	 0.0	 1	 -30.0	 30.0;
	74088	 74219	 0.007167	 0.03709	 0.01888	 235.47	 235.47	 235.47	 0.0	 0.0	 1	 -30.0	 30.0;
	74089	 74090	 0.000226	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74089	 74093	 0.00347	 0.022586	 0.03101	 212.71	 212.71	 212.71	 0.0	 0.0	 1	 -30.0	 30.0;
	74089	 74307	 0.011788	 0.074147	 0.13777	 215.19	 215.19	 215.19	 0.0	 0.0	 1	 -30.0	 30.0;
	74091	 74092	 0.000248	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74091	 74093	 0.000294	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74094	 74097	 -0.000129	 -0.004038	 0.0	 306.25	 306.25	 306.25	 1.0	 0.0	 1	 -30.0	 30.0;
	74094	 74098	 0.000207	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74094	 74099	 0.000237	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74094	 74100	 0.000249	 0.001065	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74094	 74101	 0.000296	 0.001092	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74095	 74097	 0.001926	 0.060058	 0.0	 153.13	 153.13	 153.13	 1.0	 0.0	 1	 -30.0	 30.0;
	74096	 74097	 0.001926	 0.060058	 0.0	 153.13	 153.13	 153.13	 1.0	 0.0	 1	 -30.0	 30.0;
	74098	 74219	 0.006081	 0.035821	 0.01598	 234.84	 234.84	 234.84	 0.0	 0.0	 1	 -30.0	 30.0;
	74118	 74102	 0.007988	 0.046556	 0.01726	 201.79	 201.79	 201.79	 0.0	 0.0	 1	 -30.0	 30.0;
	74219	 74102	 0.007348	 0.037283	 0.01233	 231.1	 231.1	 231.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74103	 74112	 0.000771	 0.004297	 0.01974	 247.47	 247.47	 247.47	 0.0	 0.0	 1	 -30.0	 30.0;
	74104	 74281	 0.04243	 0.260275	 0.14555	 236.7	 236.7	 236.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74112	 74105	 0.00507	 0.030211	 0.01542	 210.25	 210.25	 210.25	 0.0	 0.0	 1	 -30.0	 30.0;
	74115	 74106	 0.013144	 0.074499	 0.02802	 228.26	 228.26	 228.26	 0.0	 0.0	 1	 -30.0	 30.0;
	74273	 74106	 0.002763	 0.016077	 0.01004	 239.25	 239.25	 239.25	 0.0	 0.0	 1	 -30.0	 30.0;
	74107	 74108	 0.000225	 0.001001	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74107	 74109	 0.000256	 0.001196	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74107	 74110	 0.000274	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74111	 77170	 0.048861	 0.217511	 0.09919	 207.49	 207.49	 207.49	 0.0	 0.0	 1	 -30.0	 30.0;
	77183	 74111	 0.02008	 0.119905	 0.04895	 231.37	 231.37	 231.37	 0.0	 0.0	 1	 -30.0	 30.0;
	74112	 74114	 0.015373	 0.091025	 0.42548	 273.18	 273.18	 273.18	 0.0	 0.0	 1	 -30.0	 30.0;
	74116	 74113	 0.037411	 0.20292	 0.10044	 218.07	 218.07	 218.07	 0.0	 0.0	 1	 -30.0	 30.0;
	74114	 74121	 0.025108	 0.133114	 0.06996	 180.29	 180.29	 180.29	 0.0	 0.0	 1	 -30.0	 30.0;
	74251	 74114	 0.018711	 0.11556	 0.09506	 254.77	 254.77	 254.77	 0.0	 0.0	 1	 -30.0	 30.0;
	74121	 74116	 0.016283	 0.1103	 0.06212	 192.36	 192.36	 192.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74117	 74118	 0.00022	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74118	 74219	 0.002938	 0.015429	 0.0217	 237.23	 237.23	 237.23	 0.0	 0.0	 1	 -30.0	 30.0;
	74119	 74120	 0.000248	 0.001177	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74119	 74224	 0.010901	 0.058838	 0.01764	 209.23	 209.23	 209.23	 0.0	 0.0	 1	 -30.0	 30.0;
	74299	 74119	 0.005942	 0.032883	 0.01793	 210.0	 210.0	 210.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77155	 74122	 0.017228	 0.084469	 0.11476	 189.32	 189.32	 189.32	 0.0	 0.0	 1	 -30.0	 30.0;
	74122	 77159	 0.02855	 0.164588	 0.15785	 193.03	 193.03	 193.03	 0.0	 0.0	 1	 -30.0	 30.0;
	74122	 77160	 0.037546	 0.192324	 0.05933	 198.15	 198.15	 198.15	 0.0	 0.0	 1	 -30.0	 30.0;
	74123	 74128	 0.006787	 0.046029	 0.03617	 231.59	 231.59	 231.59	 0.0	 0.0	 1	 -30.0	 30.0;
	74123	 74227	 0.004862	 0.020529	 0.05514	 236.08	 236.08	 236.08	 0.0	 0.0	 1	 -30.0	 30.0;
	74331	 74123	 0.006126	 0.035757	 0.01237	 199.62	 199.62	 199.62	 0.0	 0.0	 1	 -30.0	 30.0;
	74134	 74124	 0.006122	 0.033748	 0.01277	 205.12	 205.12	 205.12	 0.0	 0.0	 1	 -30.0	 30.0;
	74124	 74137	 0.015107	 0.086164	 0.06388	 215.6	 215.6	 215.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74124	 74199	 0.014095	 0.065002	 0.02473	 240.26	 240.26	 240.26	 0.0	 0.0	 1	 -30.0	 30.0;
	74125	 74135	 0.016837	 0.093502	 0.02233	 203.52	 203.52	 203.52	 0.0	 0.0	 1	 -30.0	 30.0;
	74125	 74229	 0.011459	 0.052943	 0.05427	 222.26	 222.26	 222.26	 0.0	 0.0	 1	 -30.0	 30.0;
	74126	 74127	 0.000261	 0.001198	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74127	 74139	 0.022161	 0.103148	 0.02412	 177.22	 177.22	 177.22	 0.0	 0.0	 1	 -30.0	 30.0;
	74127	 74299	 0.031791	 0.170377	 0.06786	 200.24	 200.24	 200.24	 0.0	 0.0	 1	 -30.0	 30.0;
	74128	 74134	 0.009121	 0.050235	 0.02379	 216.2	 216.2	 216.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74131	 74129	 0.001755	 0.009764	 0.00359	 233.48	 233.48	 233.48	 0.0	 0.0	 1	 -30.0	 30.0;
	74129	 74270	 0.010213	 0.062067	 0.37568	 260.37	 260.37	 260.37	 0.0	 0.0	 1	 -30.0	 30.0;
	74131	 74130	 0.000432	 0.02454	 0.0	 278.12	 278.12	 278.12	 1.0	 0.0	 1	 -30.0	 30.0;
	74257	 74130	 0.001286	 0.015827	 0.59354	 1205.7	 1205.7	 1205.7	 0.0	 0.0	 1	 -30.0	 30.0;
	74130	 74325	 0.00123	 0.013729	 0.22515	 1198.91	 1198.91	 1198.91	 0.0	 0.0	 1	 -30.0	 30.0;
	74137	 74131	 0.003655	 0.018753	 0.03862	 189.2	 189.2	 189.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74132	 77126	 0.00977	 0.063474	 0.0953	 200.09	 200.09	 200.09	 0.0	 0.0	 1	 -30.0	 30.0;
	74132	 77142	 0.011903	 0.066735	 0.0242	 192.12	 192.12	 192.12	 0.0	 0.0	 1	 -30.0	 30.0;
	77159	 74132	 0.005407	 0.040503	 0.02169	 208.92	 208.92	 208.92	 0.0	 0.0	 1	 -30.0	 30.0;
	74132	 77163	 0.014272	 0.055807	 0.05161	 196.03	 196.03	 196.03	 0.0	 0.0	 1	 -30.0	 30.0;
	74132	 77177	 0.019425	 0.114057	 0.06356	 173.37	 173.37	 173.37	 0.0	 0.0	 1	 -30.0	 30.0;
	74133	 74134	 0.000255	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74135	 74136	 0.000238	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74140	 74135	 0.008545	 0.052906	 0.04642	 191.71	 191.71	 191.71	 0.0	 0.0	 1	 -30.0	 30.0;
	74139	 74138	 0.028593	 0.230206	 0.12646	 248.02	 248.02	 248.02	 0.0	 0.0	 1	 -30.0	 30.0;
	74138	 74146	 0.031993	 0.161537	 0.06257	 248.61	 248.61	 248.61	 0.0	 0.0	 1	 -30.0	 30.0;
	74140	 74139	 0.018694	 0.091801	 0.04776	 235.78	 235.78	 235.78	 0.0	 0.0	 1	 -30.0	 30.0;
	74140	 74141	 0.000256	 0.001157	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74155	 74140	 0.035947	 0.212109	 0.07722	 236.12	 236.12	 236.12	 0.0	 0.0	 1	 -30.0	 30.0;
	74142	 74143	 0.000212	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74142	 74144	 0.000294	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74142	 74145	 0.000285	 0.001151	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74144	 74149	 0.00525	 0.030148	 0.04963	 202.17	 202.17	 202.17	 0.0	 0.0	 1	 -30.0	 30.0;
	74321	 74144	 0.011367	 0.061267	 0.01325	 210.93	 210.93	 210.93	 0.0	 0.0	 1	 -30.0	 30.0;
	74146	 77114	 0.088012	 0.560612	 0.10093	 229.78	 229.78	 229.78	 0.0	 0.0	 1	 -30.0	 30.0;
	77120	 74146	 0.018769	 0.136443	 0.11885	 225.93	 225.93	 225.93	 0.0	 0.0	 1	 -30.0	 30.0;
	74146	 77160	 0.046131	 0.254847	 0.06135	 211.39	 211.39	 211.39	 0.0	 0.0	 1	 -30.0	 30.0;
	74147	 74148	 0.000202	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74147	 74149	 0.000241	 0.001019	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74149	 74152	 0.009213	 0.042945	 0.00937	 183.62	 183.62	 183.62	 0.0	 0.0	 1	 -30.0	 30.0;
	74150	 74321	 0.00619	 0.038867	 0.14093	 204.76	 204.76	 204.76	 0.0	 0.0	 1	 -30.0	 30.0;
	74150	 74336	 0.002672	 0.01415	 0.03138	 207.56	 207.56	 207.56	 0.0	 0.0	 1	 -30.0	 30.0;
	74151	 74152	 0.00025	 0.001076	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74153	 74152	 0.009752	 0.064518	 0.01074	 222.4	 222.4	 222.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74152	 74324	 0.011135	 0.063013	 0.03094	 222.74	 222.74	 222.74	 0.0	 0.0	 1	 -30.0	 30.0;
	74249	 74153	 0.00136	 0.00793	 0.0272	 186.38	 186.38	 186.38	 0.0	 0.0	 1	 -30.0	 30.0;
	74154	 74249	 0.01328	 0.066845	 0.02973	 200.13	 200.13	 200.13	 0.0	 0.0	 1	 -30.0	 30.0;
	74154	 74306	 0.00507	 0.024154	 0.18736	 186.24	 186.24	 186.24	 0.0	 0.0	 1	 -30.0	 30.0;
	74161	 74155	 0.02164	 0.131952	 0.08377	 230.16	 230.16	 230.16	 0.0	 0.0	 1	 -30.0	 30.0;
	74156	 74157	 0.000246	 0.00114	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74262	 74156	 0.003249	 0.019748	 0.00917	 209.36	 209.36	 209.36	 0.0	 0.0	 1	 -30.0	 30.0;
	74312	 74156	 0.004309	 0.023895	 0.02785	 227.03	 227.03	 227.03	 0.0	 0.0	 1	 -30.0	 30.0;
	74158	 74159	 0.000297	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74160	 74158	 0.01135	 0.065498	 0.01789	 201.72	 201.72	 201.72	 0.0	 0.0	 1	 -30.0	 30.0;
	74158	 74303	 0.004052	 0.024721	 0.08641	 211.84	 211.84	 211.84	 0.0	 0.0	 1	 -30.0	 30.0;
	74160	 74165	 0.009357	 0.059817	 0.02482	 225.75	 225.75	 225.75	 0.0	 0.0	 1	 -30.0	 30.0;
	74160	 74262	 0.0071	 0.039144	 0.06785	 208.35	 208.35	 208.35	 0.0	 0.0	 1	 -30.0	 30.0;
	74303	 74160	 0.006773	 0.045115	 0.01419	 228.43	 228.43	 228.43	 0.0	 0.0	 1	 -30.0	 30.0;
	74161	 74162	 0.000946	 0.007067	 0.0016	 195.62	 195.62	 195.62	 0.0	 0.0	 1	 -30.0	 30.0;
	74164	 74162	 0.009904	 0.056741	 0.03914	 209.89	 209.89	 209.89	 0.0	 0.0	 1	 -30.0	 30.0;
	74306	 74163	 0.034913	 0.144773	 0.11609	 221.08	 221.08	 221.08	 0.0	 0.0	 1	 -30.0	 30.0;
	74169	 74164	 0.011326	 0.059245	 0.01389	 199.07	 199.07	 199.07	 0.0	 0.0	 1	 -30.0	 30.0;
	74164	 74312	 0.016157	 0.097612	 0.06179	 237.95	 237.95	 237.95	 0.0	 0.0	 1	 -30.0	 30.0;
	74165	 74169	 0.00561	 0.039	 0.01207	 182.06	 182.06	 182.06	 0.0	 0.0	 1	 -30.0	 30.0;
	74166	 74186	 0.010501	 0.057774	 0.03472	 167.4	 167.4	 167.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74166	 74271	 0.019453	 0.12203	 0.09574	 198.72	 198.72	 198.72	 0.0	 0.0	 1	 -30.0	 30.0;
	74168	 74167	 0.000398	 0.019665	 0.0	 350.27	 350.27	 350.27	 1.0	 0.0	 1	 -30.0	 30.0;
	74167	 74308	 0.00274	 0.028727	 0.38594	 1107.68	 1107.68	 1107.68	 0.0	 0.0	 1	 -30.0	 30.0;
	74167	 74317	 0.001776	 0.022026	 0.33109	 1055.19	 1055.19	 1055.19	 0.0	 0.0	 1	 -30.0	 30.0;
	74169	 74168	 0.003005	 0.140287	 0.0	 107.0	 107.0	 107.0	 1.0875	 0.0	 1	 -30.0	 30.0;
	74320	 74168	 0.004959	 0.03016	 0.22123	 231.86	 231.86	 231.86	 0.0	 0.0	 1	 -30.0	 30.0;
	74169	 74178	 0.015284	 0.08109	 0.04497	 228.92	 228.92	 228.92	 0.0	 0.0	 1	 -30.0	 30.0;
	74170	 74176	 0.007999	 0.030018	 0.02553	 197.77	 197.77	 197.77	 0.0	 0.0	 1	 -30.0	 30.0;
	74185	 74170	 0.014647	 0.087231	 0.04994	 210.88	 210.88	 210.88	 0.0	 0.0	 1	 -30.0	 30.0;
	74172	 74171	 0.002282	 0.013847	 0.00443	 190.6	 190.6	 190.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74171	 74269	 0.005587	 0.036127	 0.00928	 206.5	 206.5	 206.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74172	 74182	 0.006825	 0.044971	 0.0466	 218.58	 218.58	 218.58	 0.0	 0.0	 1	 -30.0	 30.0;
	74177	 74173	 0.005233	 0.032007	 0.0148	 216.11	 216.11	 216.11	 0.0	 0.0	 1	 -30.0	 30.0;
	74173	 74269	 0.003099	 0.014505	 0.01519	 205.6	 205.6	 205.6	 0.0	 0.0	 1	 -30.0	 30.0;
	74174	 74175	 0.000217	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74174	 74179	 0.005363	 0.02948	 0.02575	 240.15	 240.15	 240.15	 0.0	 0.0	 1	 -30.0	 30.0;
	74174	 74181	 0.004817	 0.030944	 0.0132	 199.05	 199.05	 199.05	 0.0	 0.0	 1	 -30.0	 30.0;
	74174	 74279	 0.0075	 0.041	 0.025	 180.0	 180.0	 180.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74181	 74176	 0.00746	 0.040928	 0.02527	 183.8	 183.8	 183.8	 0.0	 0.0	 1	 -30.0	 30.0;
	74176	 74182	 0.003807	 0.025239	 0.03665	 263.27	 263.27	 263.27	 0.0	 0.0	 1	 -30.0	 30.0;
	74177	 74271	 0.005023	 0.027964	 0.04251	 224.21	 224.21	 224.21	 0.0	 0.0	 1	 -30.0	 30.0;
	74279	 74177	 0.003776	 0.024212	 0.01609	 226.04	 226.04	 226.04	 0.0	 0.0	 1	 -30.0	 30.0;
	74178	 74279	 0.008884	 0.065471	 0.06791	 235.49	 235.49	 235.49	 0.0	 0.0	 1	 -30.0	 30.0;
	74179	 74180	 0.000204	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74179	 74189	 0.013914	 0.08675	 0.03951	 258.72	 258.72	 258.72	 0.0	 0.0	 1	 -30.0	 30.0;
	74185	 74181	 0.006475	 0.03915	 0.01067	 224.76	 224.76	 224.76	 0.0	 0.0	 1	 -30.0	 30.0;
	74225	 74182	 0.001524	 0.010044	 0.00665	 209.4	 209.4	 209.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74182	 74309	 0.000694	 0.004134	 0.00305	 282.09	 282.09	 282.09	 0.0	 0.0	 1	 -30.0	 30.0;
	74183	 74184	 0.000241	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74183	 74185	 0.000201	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74189	 74185	 0.016642	 0.111784	 0.03029	 250.88	 250.88	 250.88	 0.0	 0.0	 1	 -30.0	 30.0;
	74186	 74319	 0.00384	 0.022099	 0.00679	 188.77	 188.77	 188.77	 0.0	 0.0	 1	 -30.0	 30.0;
	74187	 74286	 0.007507	 0.04052	 0.0218	 239.21	 239.21	 239.21	 0.0	 0.0	 1	 -30.0	 30.0;
	74188	 74190	 0.025276	 0.131997	 0.04937	 220.1	 220.1	 220.1	 0.0	 0.0	 1	 -30.0	 30.0;
	74319	 74188	 0.013593	 0.069607	 0.03939	 206.79	 206.79	 206.79	 0.0	 0.0	 1	 -30.0	 30.0;
	74189	 77065	 0.037337	 0.223975	 0.08358	 273.87	 273.87	 273.87	 0.0	 0.0	 1	 -30.0	 30.0;
	74286	 74190	 0.020219	 0.127836	 0.04487	 234.62	 234.62	 234.62	 0.0	 0.0	 1	 -30.0	 30.0;
	74192	 74195	 0.000523	 0.031249	 0.0	 276.78	 276.78	 276.78	 1.0	 0.0	 1	 -30.0	 30.0;
	74192	 74196	 0.000436	 0.027855	 0.0	 407.68	 407.68	 407.68	 1.0	 0.0	 1	 -30.0	 30.0;
	74192	 74197	 0.000573	 0.031389	 0.0	 404.37	 404.37	 404.37	 1.025	 0.0	 1	 -30.0	 30.0;
	74192	 74198	 0.000254	 0.001175	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74193	 74195	 -3.6e-05	 -0.002152	 0.0	 251.78	 251.78	 251.78	 1.0	 0.0	 1	 -30.0	 30.0;
	74194	 74195	 0.002768	 0.165329	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74198	 74308	 0.001804	 0.017837	 0.36191	 1098.93	 1098.93	 1098.93	 0.0	 0.0	 1	 -30.0	 30.0;
	74199	 74202	 0.000128	 0.004385	 0.0	 154.45	 154.45	 154.45	 1.0	 0.0	 1	 -30.0	 30.0;
	74199	 74293	 0.001749	 0.011862	 0.01298	 166.77	 166.77	 166.77	 0.0	 0.0	 1	 -30.0	 30.0;
	74200	 74202	 0.002479	 0.085053	 0.0	 77.23	 77.23	 77.23	 1.0	 0.0	 1	 -30.0	 30.0;
	74201	 74202	 0.002479	 0.085053	 0.0	 77.23	 77.23	 77.23	 1.0	 0.0	 1	 -30.0	 30.0;
	74203	 74204	 0.001507	 0.041297	 0.0	 224.64	 224.64	 224.64	 1.0	 0.0	 1	 -30.0	 30.0;
	74203	 74205	 0.013916	 0.373936	 0.0	 39.35	 39.35	 39.35	 1.0	 0.0	 1	 -30.0	 30.0;
	74203	 74206	 0.000247	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74206	 74224	 0.004035	 0.02452	 0.00585	 247.56	 247.56	 247.56	 0.0	 0.0	 1	 -30.0	 30.0;
	74206	 74296	 0.008168	 0.047454	 0.02186	 251.16	 251.16	 251.16	 0.0	 0.0	 1	 -30.0	 30.0;
	74299	 74206	 0.018228	 0.103849	 0.02525	 209.5	 209.5	 209.5	 0.0	 0.0	 1	 -30.0	 30.0;
	74207	 74210	 0.000493	 0.035311	 0.0	 607.73	 607.73	 607.73	 1.0	 0.0	 1	 -30.0	 30.0;
	74207	 74211	 0.000464	 0.028605	 0.0	 489.14	 489.14	 489.14	 0.98125	 0.0	 1	 -30.0	 30.0;
	74207	 74212	 0.000434	 0.028309	 0.0	 488.13	 488.13	 488.13	 0.98125	 0.0	 1	 -30.0	 30.0;
	74208	 74210	 -0.000199	 -0.01425	 0.0	 532.73	 532.73	 532.73	 1.0	 0.0	 1	 -30.0	 30.0;
	74209	 74210	 0.00166	 0.118988	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74213	 74216	 0.001005	 0.051724	 0.0	 529.88	 529.88	 529.88	 1.0	 0.0	 1	 -30.0	 30.0;
	74213	 74217	 0.000285	 0.001028	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74214	 74216	 -0.000506	 -0.026056	 0.0	 427.05	 427.05	 427.05	 1.0	 0.0	 1	 -30.0	 30.0;
	74215	 74216	 0.00247	 0.127122	 0.0	 102.83	 102.83	 102.83	 1.0	 0.0	 1	 -30.0	 30.0;
	74217	 74272	 0.001205	 0.015873	 0.43436	 1151.02	 1151.02	 1151.02	 0.0	 0.0	 1	 -30.0	 30.0;
	74219	 74218	 0.000525	 0.028489	 0.0	 467.85	 467.85	 467.85	 1.0	 0.0	 1	 -30.0	 30.0;
	74218	 74220	 0.000357	 0.021015	 0.0	 383.93	 383.93	 383.93	 1.04375	 0.0	 1	 -30.0	 30.0;
	74218	 74221	 0.000809	 0.042031	 0.0	 325.43	 325.43	 325.43	 1.04375	 0.0	 1	 -30.0	 30.0;
	74218	 74222	 0.001856	 0.075999	 0.0	 121.43	 121.43	 121.43	 1.04375	 0.0	 1	 -30.0	 30.0;
	74224	 74223	 0.0007	 0.032852	 0.0	 347.21	 347.21	 347.21	 1.0	 0.0	 1	 -30.0	 30.0;
	74295	 74223	 0.00087	 0.010286	 0.16408	 1127.56	 1127.56	 1127.56	 0.0	 0.0	 1	 -30.0	 30.0;
	74225	 74269	 0.005292	 0.031073	 0.03155	 217.06	 217.06	 217.06	 0.0	 0.0	 1	 -30.0	 30.0;
	74226	 74227	 0.000236	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74258	 74227	 0.003718	 0.012885	 0.01	 180.86	 180.86	 180.86	 0.0	 0.0	 1	 -30.0	 30.0;
	74227	 74334	 0.000604	 0.003839	 0.00286	 224.96	 224.96	 224.96	 0.0	 0.0	 1	 -30.0	 30.0;
	74229	 74232	 -0.000485	 -0.0126	 0.0	 204.47	 204.47	 204.47	 1.05	 0.0	 1	 -30.0	 30.0;
	74229	 74233	 0.008425	 0.276315	 0.0	 40.21	 40.21	 40.21	 1.0	 0.0	 1	 -30.0	 30.0;
	74229	 74331	 0.002744	 0.016593	 0.00577	 191.83	 191.83	 191.83	 0.0	 0.0	 1	 -30.0	 30.0;
	74230	 74232	 0.005654	 0.146819	 0.0	 102.24	 102.24	 102.24	 1.0	 0.0	 1	 -30.0	 30.0;
	74231	 74232	 0.005654	 0.146819	 0.0	 102.24	 102.24	 102.24	 1.0	 0.0	 1	 -30.0	 30.0;
	74235	 74234	 0.000472	 0.0289	 0.0	 432.27	 432.27	 432.27	 1.0	 0.0	 1	 -30.0	 30.0;
	74234	 74236	 0.000542	 0.033463	 0.0	 382.75	 382.75	 382.75	 1.0	 0.0	 1	 -30.0	 30.0;
	74234	 74237	 0.000532	 0.031947	 0.0	 381.0	 381.0	 381.0	 1.0	 0.0	 1	 -30.0	 30.0;
	74234	 74238	 0.000391	 0.0236	 0.0	 380.07	 380.07	 380.07	 1.0	 0.0	 1	 -30.0	 30.0;
	74234	 74239	 0.000569	 0.028021	 0.0	 379.79	 379.79	 379.79	 1.0	 0.0	 1	 -30.0	 30.0;
	77192	 74234	 0.002101	 0.024249	 0.36445	 1240.59	 1240.59	 1240.59	 0.0	 0.0	 1	 -30.0	 30.0;
	77272	 74234	 0.000664	 0.008403	 0.20079	 1142.46	 1142.46	 1142.46	 0.0	 0.0	 1	 -30.0	 30.0;
	74235	 77168	 0.059958	 0.300179	 0.13344	 180.2	 180.2	 180.2	 0.0	 0.0	 1	 -30.0	 30.0;
	74235	 77169	 0.032724	 0.230437	 0.14613	 199.48	 199.48	 199.48	 0.0	 0.0	 1	 -30.0	 30.0;
	74235	 77180	 0.025037	 0.195373	 0.04315	 204.16	 204.16	 204.16	 0.0	 0.0	 1	 -30.0	 30.0;
	74240	 74241	 0.000243	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74240	 74242	 0.000234	 0.001031	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74240	 74243	 0.000236	 0.001194	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74244	 74247	 0.000493	 0.014261	 0.0	 127.82	 127.82	 127.82	 1.0	 0.0	 1	 -30.0	 30.0;
	74244	 74248	 0.020667	 0.621194	 0.0	 18.01	 18.01	 18.01	 1.0	 0.0	 1	 -30.0	 30.0;
	74244	 74249	 0.000244	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74245	 74247	 0.004714	 0.136496	 0.0	 63.91	 63.91	 63.91	 1.0	 0.0	 1	 -30.0	 30.0;
	74246	 74247	 0.004714	 0.136496	 0.0	 63.91	 63.91	 63.91	 1.0	 0.0	 1	 -30.0	 30.0;
	74251	 74250	 0.000404	 0.026002	 0.0	 405.27	 405.27	 405.27	 1.0	 0.0	 1	 -30.0	 30.0;
	74250	 74252	 0.000552	 0.03425	 0.0	 455.8	 455.8	 455.8	 1.0	 0.0	 1	 -30.0	 30.0;
	74250	 74253	 0.000365	 0.029243	 0.0	 454.74	 454.74	 454.74	 1.0	 0.0	 1	 -30.0	 30.0;
	74250	 74254	 0.000859	 0.031721	 0.0	 453.63	 453.63	 453.63	 1.0	 0.0	 1	 -30.0	 30.0;
	74250	 74255	 0.000495	 0.027163	 0.0	 451.78	 451.78	 451.78	 1.0	 0.0	 1	 -30.0	 30.0;
	74250	 74256	 0.000464	 0.028792	 0.0	 451.2	 451.2	 451.2	 1.0	 0.0	 1	 -30.0	 30.0;
	74258	 74257	 0.000475	 0.034829	 0.0	 380.77	 380.77	 380.77	 1.075	 0.0	 1	 -30.0	 30.0;
	74257	 74260	 0.001104	 0.061723	 0.0	 230.1	 230.1	 230.1	 1.0	 0.0	 1	 -30.0	 30.0;
	74295	 74257	 0.001582	 0.019056	 0.27352	 1157.4	 1157.4	 1157.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74258	 74259	 0.004471	 0.159293	 0.0	 77.18	 77.18	 77.18	 1.04375	 0.0	 1	 -30.0	 30.0;
	74258	 74293	 0.001546	 0.009736	 0.00305	 207.04	 207.04	 207.04	 0.0	 0.0	 1	 -30.0	 30.0;
	74261	 74334	 0.002807	 0.015902	 0.00556	 190.86	 190.86	 190.86	 0.0	 0.0	 1	 -30.0	 30.0;
	74262	 74263	 0.002757	 0.07264	 0.0	 109.49	 109.49	 109.49	 1.0	 0.0	 1	 -30.0	 30.0;
	74264	 74265	 0.024323	 0.790719	 0.0	 16.51	 16.51	 16.51	 1.0	 0.0	 1	 -30.0	 30.0;
	74264	 74266	 0.004654	 0.160605	 0.0	 59.87	 59.87	 59.87	 1.0	 0.0	 1	 -30.0	 30.0;
	74264	 74267	 0.000209	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74268	 74269	 0.000273	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74270	 74281	 0.00206	 0.013554	 0.00624	 166.4	 166.4	 166.4	 0.0	 0.0	 1	 -30.0	 30.0;
	74296	 74270	 0.002321	 0.011273	 0.02214	 235.21	 235.21	 235.21	 0.0	 0.0	 1	 -30.0	 30.0;
	74272	 74275	 0.000646	 0.043529	 0.0	 436.78	 436.78	 436.78	 1.0	 0.0	 1	 -30.0	 30.0;
	74272	 74276	 0.000761	 0.038751	 0.0	 463.08	 463.08	 463.08	 1.0	 0.0	 1	 -30.0	 30.0;
	74272	 74277	 0.000274	 0.021268	 0.0	 462.78	 462.78	 462.78	 1.0	 0.0	 1	 -30.0	 30.0;
	74272	 74278	 0.000517	 0.034667	 0.0	 461.18	 461.18	 461.18	 1.0	 0.0	 1	 -30.0	 30.0;
	74273	 74275	 -8.7e-05	 -0.005862	 0.0	 378.85	 378.85	 378.85	 1.0	 0.0	 1	 -30.0	 30.0;
	74274	 74275	 0.002721	 0.183311	 0.0	 57.93	 57.93	 57.93	 1.0	 0.0	 1	 -30.0	 30.0;
	74279	 74280	 0.003834	 0.103195	 0.0	 155.61	 155.61	 155.61	 1.05625	 0.0	 1	 -30.0	 30.0;
	74309	 74279	 0.005209	 0.021466	 0.00912	 204.73	 204.73	 204.73	 0.0	 0.0	 1	 -30.0	 30.0;
	74281	 74282	 0.009031	 0.310547	 0.0	 43.38	 43.38	 43.38	 1.0	 0.0	 1	 -30.0	 30.0;
	74281	 74283	 0.00697	 0.210387	 0.0	 43.33	 43.33	 43.33	 1.0	 0.0	 1	 -30.0	 30.0;
	74281	 74296	 0.001558	 0.01005	 0.00432	 238.07	 238.07	 238.07	 0.0	 0.0	 1	 -30.0	 30.0;
	74284	 74285	 0.000206	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74284	 74286	 0.000218	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74287	 74290	 -0.00018	 -0.004382	 0.0	 152.33	 152.33	 152.33	 1.0	 0.0	 1	 -30.0	 30.0;
	74287	 74291	 0.017569	 0.530748	 0.0	 17.55	 17.55	 17.55	 1.0	 0.0	 1	 -30.0	 30.0;
	74287	 74292	 0.021531	 0.675089	 0.0	 15.6	 15.6	 15.6	 1.0	 0.0	 1	 -30.0	 30.0;
	74287	 74293	 0.000213	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74287	 74294	 0.000265	 0.001117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74288	 74290	 0.006292	 0.153527	 0.0	 76.17	 76.17	 76.17	 1.0	 0.0	 1	 -30.0	 30.0;
	74289	 74290	 0.006292	 0.153527	 0.0	 76.17	 76.17	 76.17	 1.0	 0.0	 1	 -30.0	 30.0;
	74296	 74295	 0.000287	 0.017837	 0.0	 315.63	 315.63	 315.63	 1.05	 0.0	 1	 -30.0	 30.0;
	74297	 74298	 0.005065	 0.168197	 0.0	 75.59	 75.59	 75.59	 1.01875	 0.0	 1	 -30.0	 30.0;
	74297	 74299	 0.000294	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74300	 74301	 0.016374	 0.486663	 0.0	 18.2	 18.2	 18.2	 1.04375	 0.0	 1	 -30.0	 30.0;
	74300	 74302	 0.002214	 0.077993	 0.0	 64.36	 64.36	 64.36	 1.025	 0.0	 1	 -30.0	 30.0;
	74303	 74312	 0.004004	 0.017545	 0.02736	 215.84	 215.84	 215.84	 0.0	 0.0	 1	 -30.0	 30.0;
	74304	 74305	 0.005065	 0.172932	 0.0	 66.07	 66.07	 66.07	 1.0375	 0.0	 1	 -30.0	 30.0;
	74304	 74306	 0.000206	 0.00108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74309	 74308	 0.000527	 0.021146	 0.0	 392.87	 392.87	 392.87	 1.0625	 0.0	 1	 -30.0	 30.0;
	74308	 74310	 0.000649	 0.041036	 0.0	 457.72	 457.72	 457.72	 1.0125	 0.0	 1	 -30.0	 30.0;
	74312	 74311	 0.000348	 0.023101	 0.0	 406.31	 406.31	 406.31	 1.0	 0.0	 1	 -30.0	 30.0;
	74311	 74315	 0.0001	 0.0001	 0.0	 914.82	 914.82	 914.82	 1.0	 0.0	 1	 -30.0	 30.0;
	74325	 74311	 0.003446	 0.041552	 0.71124	 1062.75	 1062.75	 1062.75	 0.0	 0.0	 1	 -30.0	 30.0;
	74312	 74316	 0.005372	 0.180146	 0.0	 65.34	 65.34	 65.34	 1.0	 0.0	 1	 -30.0	 30.0;
	74313	 74315	 0.00055	 0.030369	 0.0	 457.41	 457.41	 457.41	 1.0	 0.0	 1	 -30.0	 30.0;
	74314	 74315	 0.00055	 0.030369	 0.0	 457.41	 457.41	 457.41	 1.0	 0.0	 1	 -30.0	 30.0;
	74318	 74317	 0.000692	 0.035513	 0.0	 275.05	 275.05	 275.05	 1.0	 0.0	 1	 -30.0	 30.0;
	74319	 74318	 0.002788	 0.088801	 0.0	 81.15	 81.15	 81.15	 1.0	 0.0	 1	 -30.0	 30.0;
	74318	 74320	 0.000226	 0.001186	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74321	 74322	 0.003339	 0.101996	 0.0	 93.8	 93.8	 93.8	 1.0	 0.0	 1	 -30.0	 30.0;
	74324	 74323	 0.000304	 0.02467	 0.0	 238.62	 238.62	 238.62	 1.0	 0.0	 1	 -30.0	 30.0;
	74323	 74325	 0.000209	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74323	 74325	 0.000209	 0.001124	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74327	 74326	 0.000717	 0.031889	 0.0	 461.62	 461.62	 461.62	 1.0125	 0.0	 1	 -30.0	 30.0;
	74326	 74328	 0.000345	 0.027075	 0.0	 502.71	 502.71	 502.71	 1.0	 0.0	 1	 -30.0	 30.0;
	74326	 74329	 0.000414	 0.026165	 0.0	 502.59	 502.59	 502.59	 1.0	 0.0	 1	 -30.0	 30.0;
	74326	 74330	 0.000219	 0.001014	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74331	 74332	 0.013158	 0.396474	 0.0	 26.02	 26.02	 26.02	 1.04375	 0.0	 1	 -30.0	 30.0;
	74331	 74333	 0.021693	 0.60009	 0.0	 21.45	 21.45	 21.45	 1.0375	 0.0	 1	 -30.0	 30.0;
	74335	 74336	 0.000284	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77003	 77000	 0.028984	 0.18656	 0.06264	 269.3	 269.3	 269.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77000	 77255	 0.012536	 0.068885	 0.04324	 274.54	 274.54	 274.54	 0.0	 0.0	 1	 -30.0	 30.0;
	77001	 77198	 0.033491	 0.131955	 0.02562	 193.0	 193.0	 193.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77240	 77001	 0.13	 0.74	 0.16	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77240	 77001	 0.13	 0.74	 0.16	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77255	 77001	 0.013385	 0.082322	 0.05944	 205.39	 205.39	 205.39	 0.0	 0.0	 1	 -30.0	 30.0;
	77002	 77003	 0.000266	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77004	 77009	 0.036014	 0.196552	 0.05293	 249.17	 249.17	 249.17	 0.0	 0.0	 1	 -30.0	 30.0;
	77240	 77004	 0.022927	 0.080035	 0.03642	 252.75	 252.75	 252.75	 0.0	 0.0	 1	 -30.0	 30.0;
	77005	 77006	 0.000273	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77005	 77008	 0.014167	 0.081655	 0.04214	 214.18	 214.18	 214.18	 0.0	 0.0	 1	 -30.0	 30.0;
	77198	 77005	 0.019331	 0.115419	 0.1075	 265.27	 265.27	 265.27	 0.0	 0.0	 1	 -30.0	 30.0;
	77007	 77017	 0.019673	 0.095055	 0.10729	 238.63	 238.63	 238.63	 0.0	 0.0	 1	 -30.0	 30.0;
	77007	 77283	 0.015883	 0.088104	 0.09258	 242.26	 242.26	 242.26	 0.0	 0.0	 1	 -30.0	 30.0;
	77017	 77008	 0.018674	 0.076392	 0.07926	 265.89	 265.89	 265.89	 0.0	 0.0	 1	 -30.0	 30.0;
	77283	 77008	 0.006035	 0.03081	 0.01136	 255.29	 255.29	 255.29	 0.0	 0.0	 1	 -30.0	 30.0;
	77009	 77028	 0.039103	 0.226869	 0.05	 241.46	 241.46	 241.46	 0.0	 0.0	 1	 -30.0	 30.0;
	77010	 77013	 0.008883	 0.069885	 0.01717	 209.98	 209.98	 209.98	 0.0	 0.0	 1	 -30.0	 30.0;
	77010	 77018	 0.01038	 0.053319	 0.03466	 238.47	 238.47	 238.47	 0.0	 0.0	 1	 -30.0	 30.0;
	77283	 77010	 0.015602	 0.107337	 0.05832	 260.3	 260.3	 260.3	 0.0	 0.0	 1	 -30.0	 30.0;
	77011	 77012	 0.000222	 0.001123	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77011	 77013	 0.000297	 0.00113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77013	 77018	 0.010123	 0.05531	 0.01909	 200.41	 200.41	 200.41	 0.0	 0.0	 1	 -30.0	 30.0;
	77017	 77014	 0.00758	 0.038323	 0.01027	 248.46	 248.46	 248.46	 0.0	 0.0	 1	 -30.0	 30.0;
	77014	 77031	 0.012795	 0.07348	 0.08425	 251.43	 251.43	 251.43	 0.0	 0.0	 1	 -30.0	 30.0;
	77014	 77210	 0.00406	 0.028556	 0.02182	 238.76	 238.76	 238.76	 0.0	 0.0	 1	 -30.0	 30.0;
	77015	 77016	 0.0002	 0.001021	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77015	 77017	 0.000297	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 77017	 0.011405	 0.064358	 0.02273	 235.09	 235.09	 235.09	 0.0	 0.0	 1	 -30.0	 30.0;
	77018	 77019	 0.000294	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77018	 77024	 0.00667	 0.032335	 0.0256	 227.23	 227.23	 227.23	 0.0	 0.0	 1	 -30.0	 30.0;
	77247	 77020	 0.003008	 0.015013	 0.04942	 225.33	 225.33	 225.33	 0.0	 0.0	 1	 -30.0	 30.0;
	77021	 77210	 0.01555	 0.073681	 0.22553	 247.93	 247.93	 247.93	 0.0	 0.0	 1	 -30.0	 30.0;
	77021	 77249	 0.02295	 0.157551	 0.07844	 237.94	 237.94	 237.94	 0.0	 0.0	 1	 -30.0	 30.0;
	77022	 77023	 0.003604	 0.019527	 0.00817	 210.63	 210.63	 210.63	 0.0	 0.0	 1	 -30.0	 30.0;
	77022	 77032	 0.017407	 0.085443	 0.08734	 241.89	 241.89	 241.89	 0.0	 0.0	 1	 -30.0	 30.0;
	77210	 77022	 0.002981	 0.022361	 0.00849	 259.42	 259.42	 259.42	 0.0	 0.0	 1	 -30.0	 30.0;
	77247	 77022	 0.004876	 0.029148	 0.01178	 237.85	 237.85	 237.85	 0.0	 0.0	 1	 -30.0	 30.0;
	77024	 77023	 0.004528	 0.025026	 0.01299	 191.18	 191.18	 191.18	 0.0	 0.0	 1	 -30.0	 30.0;
	77023	 77032	 0.010206	 0.066385	 0.08479	 249.61	 249.61	 249.61	 0.0	 0.0	 1	 -30.0	 30.0;
	77023	 77210	 0.006268	 0.032377	 0.01442	 253.15	 253.15	 253.15	 0.0	 0.0	 1	 -30.0	 30.0;
	77028	 77025	 0.016955	 0.096582	 0.05769	 238.14	 238.14	 238.14	 0.0	 0.0	 1	 -30.0	 30.0;
	77025	 77033	 0.014058	 0.095392	 0.03455	 232.49	 232.49	 232.49	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 77027	 0.000226	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 77030	 0.014198	 0.080171	 0.0406	 221.19	 221.19	 221.19	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 77031	 0.015134	 0.068846	 0.01908	 245.37	 245.37	 245.37	 0.0	 0.0	 1	 -30.0	 30.0;
	77026	 77247	 0.004439	 0.029681	 0.08523	 251.4	 251.4	 251.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77031	 77029	 0.007654	 0.037565	 0.11732	 284.0	 284.0	 284.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77029	 77038	 0.011687	 0.064459	 0.10587	 280.97	 280.97	 280.97	 0.0	 0.0	 1	 -30.0	 30.0;
	77030	 77032	 0.01081	 0.055448	 0.02047	 211.07	 211.07	 211.07	 0.0	 0.0	 1	 -30.0	 30.0;
	77039	 77032	 0.011704	 0.060534	 0.01868	 250.67	 250.67	 250.67	 0.0	 0.0	 1	 -30.0	 30.0;
	77032	 77044	 0.019211	 0.119667	 0.07134	 253.75	 253.75	 253.75	 0.0	 0.0	 1	 -30.0	 30.0;
	77033	 77040	 0.02055	 0.092665	 0.04247	 228.53	 228.53	 228.53	 0.0	 0.0	 1	 -30.0	 30.0;
	77034	 77035	 0.000203	 0.001074	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77035	 77043	 0.059091	 0.219029	 0.0538	 174.48	 174.48	 174.48	 0.0	 0.0	 1	 -30.0	 30.0;
	77249	 77035	 0.030762	 0.172173	 0.13931	 202.54	 202.54	 202.54	 0.0	 0.0	 1	 -30.0	 30.0;
	77036	 77037	 0.000252	 0.001187	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77036	 77038	 0.000226	 0.001091	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77039	 77208	 0.01138	 0.077877	 0.40762	 249.97	 249.97	 249.97	 0.0	 0.0	 1	 -30.0	 30.0;
	77040	 77041	 0.000299	 0.001046	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77040	 77042	 0.017813	 0.090735	 0.03169	 191.78	 191.78	 191.78	 0.0	 0.0	 1	 -30.0	 30.0;
	77042	 77049	 0.017851	 0.092033	 0.13452	 178.77	 178.77	 178.77	 0.0	 0.0	 1	 -30.0	 30.0;
	77043	 77208	 0.009848	 0.059734	 0.01696	 191.15	 191.15	 191.15	 0.0	 0.0	 1	 -30.0	 30.0;
	77249	 77043	 0.024772	 0.127416	 0.03741	 205.67	 205.67	 205.67	 0.0	 0.0	 1	 -30.0	 30.0;
	77044	 77045	 0.000266	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77044	 77046	 0.025483	 0.151189	 0.17329	 262.37	 262.37	 262.37	 0.0	 0.0	 1	 -30.0	 30.0;
	77249	 77044	 0.022243	 0.129827	 0.06319	 206.04	 206.04	 206.04	 0.0	 0.0	 1	 -30.0	 30.0;
	77046	 77047	 0.000282	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77065	 77046	 0.029614	 0.160065	 0.08257	 259.84	 259.84	 259.84	 0.0	 0.0	 1	 -30.0	 30.0;
	77048	 77052	 0.012187	 0.082262	 0.03717	 233.46	 233.46	 233.46	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 77048	 0.015124	 0.072853	 0.04493	 204.44	 204.44	 204.44	 0.0	 0.0	 1	 -30.0	 30.0;
	77049	 77267	 0.013035	 0.076342	 0.12447	 174.34	 174.34	 174.34	 0.0	 0.0	 1	 -30.0	 30.0;
	77069	 77050	 0.011642	 0.062361	 0.03426	 189.67	 189.67	 189.67	 0.0	 0.0	 1	 -30.0	 30.0;
	77050	 77201	 0.015458	 0.079638	 0.04686	 200.87	 200.87	 200.87	 0.0	 0.0	 1	 -30.0	 30.0;
	77052	 77051	 0.000634	 0.033657	 0.0	 493.71	 493.71	 493.71	 1.0	 0.0	 1	 -30.0	 30.0;
	77051	 77053	 0.000205	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77209	 77051	 0.004975	 0.064395	 1.1819	 1331.96	 1331.96	 1331.96	 0.0	 0.0	 1	 -30.0	 30.0;
	77051	 77230	 0.003351	 0.040246	 0.7822	 1135.51	 1135.51	 1135.51	 0.0	 0.0	 1	 -30.0	 30.0;
	77052	 77055	 0.001926	 0.011259	 0.01577	 264.8	 264.8	 264.8	 0.0	 0.0	 1	 -30.0	 30.0;
	77052	 77064	 0.020644	 0.102805	 0.06913	 250.16	 250.16	 250.16	 0.0	 0.0	 1	 -30.0	 30.0;
	77052	 77083	 0.016248	 0.098837	 0.0726	 203.85	 203.85	 203.85	 0.0	 0.0	 1	 -30.0	 30.0;
	77054	 77055	 0.000297	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77055	 77058	 0.008264	 0.056019	 0.02606	 246.81	 246.81	 246.81	 0.0	 0.0	 1	 -30.0	 30.0;
	77056	 77093	 0.020025	 0.106936	 0.04084	 163.54	 163.54	 163.54	 0.0	 0.0	 1	 -30.0	 30.0;
	77056	 77203	 0.014638	 0.078382	 0.17629	 185.42	 185.42	 185.42	 0.0	 0.0	 1	 -30.0	 30.0;
	77081	 77057	 0.011158	 0.064296	 0.04268	 219.73	 219.73	 219.73	 0.0	 0.0	 1	 -30.0	 30.0;
	77057	 77201	 0.013584	 0.087839	 0.27045	 223.38	 223.38	 223.38	 0.0	 0.0	 1	 -30.0	 30.0;
	77058	 77059	 0.000248	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 77058	 0.007126	 0.037107	 0.02295	 215.75	 215.75	 215.75	 0.0	 0.0	 1	 -30.0	 30.0;
	77060	 77061	 0.00028	 0.001134	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77060	 77062	 0.000267	 0.001007	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 77078	 0.01379	 0.065627	 0.0742	 231.92	 231.92	 231.92	 0.0	 0.0	 1	 -30.0	 30.0;
	77061	 77091	 0.013878	 0.095599	 0.06883	 253.06	 253.06	 253.06	 0.0	 0.0	 1	 -30.0	 30.0;
	77063	 77078	 0.013744	 0.068929	 0.07965	 229.61	 229.61	 229.61	 0.0	 0.0	 1	 -30.0	 30.0;
	77208	 77063	 0.018206	 0.1055	 0.19148	 258.51	 258.51	 258.51	 0.0	 0.0	 1	 -30.0	 30.0;
	77065	 77064	 0.033702	 0.169569	 0.05677	 247.69	 247.69	 247.69	 0.0	 0.0	 1	 -30.0	 30.0;
	77065	 77066	 0.000294	 0.001167	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77065	 77091	 0.013501	 0.085893	 0.10118	 244.24	 244.24	 244.24	 0.0	 0.0	 1	 -30.0	 30.0;
	77067	 77068	 0.000229	 0.00107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77067	 77069	 0.006168	 0.038106	 0.05562	 239.63	 239.63	 239.63	 0.0	 0.0	 1	 -30.0	 30.0;
	77067	 77086	 0.007705	 0.046164	 0.06193	 166.48	 166.48	 166.48	 0.0	 0.0	 1	 -30.0	 30.0;
	77267	 77067	 0.002607	 0.017269	 0.00364	 232.72	 232.72	 232.72	 0.0	 0.0	 1	 -30.0	 30.0;
	77067	 77292	 0.004581	 0.029949	 0.01191	 225.35	 225.35	 225.35	 0.0	 0.0	 1	 -30.0	 30.0;
	77069	 77096	 0.014502	 0.062714	 0.09323	 219.02	 219.02	 219.02	 0.0	 0.0	 1	 -30.0	 30.0;
	77070	 77071	 0.000222	 0.001058	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77070	 77269	 0.009761	 0.059465	 0.02041	 193.9	 193.9	 193.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77070	 77292	 0.009139	 0.052853	 0.03279	 201.49	 201.49	 201.49	 0.0	 0.0	 1	 -30.0	 30.0;
	77072	 77075	 0.000175	 0.006116	 0.0	 87.24	 87.24	 87.24	 1.0	 0.0	 1	 -30.0	 30.0;
	77072	 77076	 0.000295	 0.001013	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77073	 77075	 0.00598	 0.209434	 0.0	 43.62	 43.62	 43.62	 1.0	 0.0	 1	 -30.0	 30.0;
	77074	 77075	 0.00598	 0.209434	 0.0	 43.62	 43.62	 43.62	 1.0	 0.0	 1	 -30.0	 30.0;
	77076	 77267	 0.005828	 0.036104	 0.01915	 191.94	 191.94	 191.94	 0.0	 0.0	 1	 -30.0	 30.0;
	77292	 77076	 0.008812	 0.04613	 0.02396	 198.52	 198.52	 198.52	 0.0	 0.0	 1	 -30.0	 30.0;
	77077	 77201	 0.002427	 0.017198	 0.00857	 179.31	 179.31	 179.31	 0.0	 0.0	 1	 -30.0	 30.0;
	77077	 77290	 0.005412	 0.034314	 0.03676	 223.86	 223.86	 223.86	 0.0	 0.0	 1	 -30.0	 30.0;
	77078	 77079	 0.000297	 0.001146	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77078	 77083	 0.004592	 0.026244	 0.0251	 195.45	 195.45	 195.45	 0.0	 0.0	 1	 -30.0	 30.0;
	77080	 77081	 0.000203	 0.001097	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77080	 77082	 0.000228	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 77081	 0.012177	 0.073394	 0.03536	 205.65	 205.65	 205.65	 0.0	 0.0	 1	 -30.0	 30.0;
	77084	 77085	 0.000254	 0.001132	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77084	 77086	 0.000282	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77086	 77231	 0.009988	 0.057917	 0.02822	 185.97	 185.97	 185.97	 0.0	 0.0	 1	 -30.0	 30.0;
	77087	 77090	 -0.000228	 -0.007078	 0.0	 153.38	 153.38	 153.38	 1.0	 0.0	 1	 -30.0	 30.0;
	77087	 77091	 0.000202	 0.001067	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77087	 77092	 0.00022	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77088	 77090	 0.0035	 0.108738	 0.0	 76.69	 76.69	 76.69	 1.0	 0.0	 1	 -30.0	 30.0;
	77089	 77090	 0.0035	 0.108738	 0.0	 76.69	 76.69	 76.69	 1.0	 0.0	 1	 -30.0	 30.0;
	77104	 77091	 0.010906	 0.067233	 0.07918	 170.77	 170.77	 170.77	 0.0	 0.0	 1	 -30.0	 30.0;
	77093	 77094	 0.00028	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77203	 77093	 0.011193	 0.067371	 0.03588	 181.85	 181.85	 181.85	 0.0	 0.0	 1	 -30.0	 30.0;
	77093	 77281	 0.014473	 0.079806	 0.0507	 180.7	 180.7	 180.7	 0.0	 0.0	 1	 -30.0	 30.0;
	77095	 77096	 0.000232	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77095	 77097	 0.000241	 0.001139	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77095	 77098	 0.000209	 0.00112	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77096	 77271	 0.013693	 0.081536	 0.02472	 208.93	 208.93	 208.93	 0.0	 0.0	 1	 -30.0	 30.0;
	77099	 77101	 0.003851	 0.020677	 0.00944	 222.08	 222.08	 222.08	 0.0	 0.0	 1	 -30.0	 30.0;
	77229	 77099	 0.001864	 0.007204	 0.01121	 234.23	 234.23	 234.23	 0.0	 0.0	 1	 -30.0	 30.0;
	77112	 77100	 0.016924	 0.065168	 0.03613	 197.92	 197.92	 197.92	 0.0	 0.0	 1	 -30.0	 30.0;
	77100	 77281	 0.008427	 0.04616	 0.08943	 208.89	 208.89	 208.89	 0.0	 0.0	 1	 -30.0	 30.0;
	77101	 77110	 0.008062	 0.047035	 0.03667	 218.31	 218.31	 218.31	 0.0	 0.0	 1	 -30.0	 30.0;
	77229	 77101	 0.004414	 0.023912	 0.0098	 230.62	 230.62	 230.62	 0.0	 0.0	 1	 -30.0	 30.0;
	77102	 77103	 0.000269	 0.001107	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77110	 77102	 0.016526	 0.081016	 0.02707	 186.35	 186.35	 186.35	 0.0	 0.0	 1	 -30.0	 30.0;
	77104	 77105	 0.000289	 0.001181	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77108	 77104	 0.020492	 0.111688	 0.05495	 243.66	 243.66	 243.66	 0.0	 0.0	 1	 -30.0	 30.0;
	77104	 77120	 0.040774	 0.206086	 0.04479	 238.83	 238.83	 238.83	 0.0	 0.0	 1	 -30.0	 30.0;
	77106	 77107	 0.000289	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77106	 77108	 0.000201	 0.00104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77115	 77108	 0.006807	 0.040737	 0.04186	 210.19	 210.19	 210.19	 0.0	 0.0	 1	 -30.0	 30.0;
	77108	 77264	 0.014351	 0.072242	 0.02989	 229.59	 229.59	 229.59	 0.0	 0.0	 1	 -30.0	 30.0;
	77110	 77109	 0.001157	 0.007137	 0.012	 186.89	 186.89	 186.89	 0.0	 0.0	 1	 -30.0	 30.0;
	77109	 77229	 0.013931	 0.100754	 0.03841	 210.14	 210.14	 210.14	 0.0	 0.0	 1	 -30.0	 30.0;
	77110	 77111	 0.000252	 0.001024	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77113	 77112	 0.009583	 0.073842	 0.05019	 189.37	 189.37	 189.37	 0.0	 0.0	 1	 -30.0	 30.0;
	77231	 77113	 0.014891	 0.084336	 0.03893	 181.71	 181.71	 181.71	 0.0	 0.0	 1	 -30.0	 30.0;
	77115	 77114	 0.009171	 0.037993	 0.01294	 198.78	 198.78	 198.78	 0.0	 0.0	 1	 -30.0	 30.0;
	77114	 77119	 0.021329	 0.109492	 0.02344	 198.32	 198.32	 198.32	 0.0	 0.0	 1	 -30.0	 30.0;
	77194	 77114	 0.013586	 0.079285	 0.02139	 229.85	 229.85	 229.85	 0.0	 0.0	 1	 -30.0	 30.0;
	77115	 77264	 0.003504	 0.025206	 0.01252	 253.77	 253.77	 253.77	 0.0	 0.0	 1	 -30.0	 30.0;
	77116	 77117	 0.000251	 0.001032	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77281	 77116	 0.010928	 0.060787	 0.05136	 168.85	 168.85	 168.85	 0.0	 0.0	 1	 -30.0	 30.0;
	77288	 77116	 0.015891	 0.088491	 0.02877	 188.49	 188.49	 188.49	 0.0	 0.0	 1	 -30.0	 30.0;
	77118	 77125	 0.018933	 0.128729	 0.13328	 240.23	 240.23	 240.23	 0.0	 0.0	 1	 -30.0	 30.0;
	77118	 77271	 0.007331	 0.04475	 0.12982	 244.47	 244.47	 244.47	 0.0	 0.0	 1	 -30.0	 30.0;
	77119	 77194	 0.012419	 0.0617	 0.03141	 212.43	 212.43	 212.43	 0.0	 0.0	 1	 -30.0	 30.0;
	77121	 77222	 0.037413	 0.208199	 0.06675	 220.84	 220.84	 220.84	 0.0	 0.0	 1	 -30.0	 30.0;
	77121	 77281	 0.018425	 0.086989	 0.14861	 237.09	 237.09	 237.09	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 77123	 0.011829	 0.062653	 0.02125	 247.36	 247.36	 247.36	 0.0	 0.0	 1	 -30.0	 30.0;
	77122	 77194	 0.009289	 0.058028	 0.02138	 254.13	 254.13	 254.13	 0.0	 0.0	 1	 -30.0	 30.0;
	77123	 77124	 0.000253	 0.001087	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77123	 77163	 0.016236	 0.098257	 0.13552	 243.51	 243.51	 243.51	 0.0	 0.0	 1	 -30.0	 30.0;
	77125	 77128	 0.00502	 0.027434	 0.14284	 176.19	 176.19	 176.19	 0.0	 0.0	 1	 -30.0	 30.0;
	77125	 77141	 0.014139	 0.060791	 0.10729	 232.72	 232.72	 232.72	 0.0	 0.0	 1	 -30.0	 30.0;
	77126	 77134	 0.00834	 0.052357	 0.02905	 206.88	 206.88	 206.88	 0.0	 0.0	 1	 -30.0	 30.0;
	77127	 77128	 0.000287	 0.001179	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77128	 77165	 0.036749	 0.272671	 0.0614	 197.4	 197.4	 197.4	 0.0	 0.0	 1	 -30.0	 30.0;
	77129	 77130	 0.000266	 0.001093	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77129	 77131	 0.000247	 0.001022	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77129	 77132	 0.000276	 0.00106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77131	 77140	 0.003286	 0.022926	 0.03525	 190.06	 190.06	 190.06	 0.0	 0.0	 1	 -30.0	 30.0;
	77131	 77141	 0.00564	 0.030776	 0.01515	 196.87	 196.87	 196.87	 0.0	 0.0	 1	 -30.0	 30.0;
	77131	 77142	 0.009128	 0.048075	 0.04572	 197.78	 197.78	 197.78	 0.0	 0.0	 1	 -30.0	 30.0;
	77134	 77133	 0.000512	 0.027607	 0.0	 476.74	 476.74	 476.74	 1.075	 0.0	 1	 -30.0	 30.0;
	77133	 77227	 0.003491	 0.039857	 1.80115	 1183.97	 1183.97	 1183.97	 0.0	 0.0	 1	 -30.0	 30.0;
	77140	 77134	 0.006129	 0.035735	 0.02827	 241.79	 241.79	 241.79	 0.0	 0.0	 1	 -30.0	 30.0;
	77142	 77134	 0.00689	 0.044435	 0.0106	 223.73	 223.73	 223.73	 0.0	 0.0	 1	 -30.0	 30.0;
	77144	 77134	 0.007094	 0.045677	 0.02215	 235.26	 235.26	 235.26	 0.0	 0.0	 1	 -30.0	 30.0;
	77135	 77136	 0.000216	 0.001078	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77155	 77135	 0.008626	 0.046219	 0.01719	 213.26	 213.26	 213.26	 0.0	 0.0	 1	 -30.0	 30.0;
	77160	 77135	 0.017336	 0.112442	 0.12283	 200.41	 200.41	 200.41	 0.0	 0.0	 1	 -30.0	 30.0;
	77137	 77138	 0.000204	 0.00119	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77137	 77139	 0.000246	 0.001055	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77146	 77139	 0.004806	 0.033006	 0.01903	 212.79	 212.79	 212.79	 0.0	 0.0	 1	 -30.0	 30.0;
	77139	 77148	 0.005261	 0.035796	 0.02339	 225.22	 225.22	 225.22	 0.0	 0.0	 1	 -30.0	 30.0;
	77147	 77140	 0.00887	 0.04464	 0.01574	 193.03	 193.03	 193.03	 0.0	 0.0	 1	 -30.0	 30.0;
	77142	 77143	 0.000237	 0.001136	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77144	 77155	 0.008565	 0.054717	 0.06761	 218.49	 218.49	 218.49	 0.0	 0.0	 1	 -30.0	 30.0;
	77145	 77146	 0.000266	 0.001182	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77146	 77147	 0.005797	 0.034276	 0.01995	 208.66	 208.66	 208.66	 0.0	 0.0	 1	 -30.0	 30.0;
	77148	 77149	 0.000221	 0.001027	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77152	 77148	 0.008695	 0.053226	 0.07086	 220.01	 220.01	 220.01	 0.0	 0.0	 1	 -30.0	 30.0;
	77148	 77157	 0.010191	 0.056119	 0.07342	 202.52	 202.52	 202.52	 0.0	 0.0	 1	 -30.0	 30.0;
	77233	 77148	 0.010928	 0.064661	 0.0366	 230.11	 230.11	 230.11	 0.0	 0.0	 1	 -30.0	 30.0;
	77150	 77151	 0.000274	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77150	 77164	 0.006042	 0.032823	 0.03253	 226.1	 226.1	 226.1	 0.0	 0.0	 1	 -30.0	 30.0;
	77222	 77150	 0.008963	 0.051734	 0.01403	 249.28	 249.28	 249.28	 0.0	 0.0	 1	 -30.0	 30.0;
	77152	 77153	 0.00022	 0.001057	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77154	 77152	 0.004143	 0.024172	 0.06102	 171.99	 171.99	 171.99	 0.0	 0.0	 1	 -30.0	 30.0;
	77233	 77152	 0.003261	 0.023009	 0.02052	 240.16	 240.16	 240.16	 0.0	 0.0	 1	 -30.0	 30.0;
	77169	 77154	 0.009306	 0.06586	 0.03528	 187.85	 187.85	 187.85	 0.0	 0.0	 1	 -30.0	 30.0;
	77155	 77156	 0.000283	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77163	 77155	 0.013684	 0.06286	 0.02768	 226.44	 226.44	 226.44	 0.0	 0.0	 1	 -30.0	 30.0;
	77157	 77167	 0.014168	 0.050385	 0.01894	 196.36	 196.36	 196.36	 0.0	 0.0	 1	 -30.0	 30.0;
	77158	 77159	 0.000277	 0.001089	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77161	 77162	 0.000286	 0.001008	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77161	 77163	 0.00028	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 77164	 0.004089	 0.029314	 0.02189	 196.44	 196.44	 196.44	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 77166	 0.000256	 0.00113	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77165	 77222	 0.00818	 0.051763	 0.01916	 255.97	 255.97	 255.97	 0.0	 0.0	 1	 -30.0	 30.0;
	77167	 77177	 0.012016	 0.074469	 0.0256	 186.93	 186.93	 186.93	 0.0	 0.0	 1	 -30.0	 30.0;
	77222	 77168	 0.014478	 0.075447	 0.06075	 214.9	 214.9	 214.9	 0.0	 0.0	 1	 -30.0	 30.0;
	77170	 77171	 0.000235	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77253	 77170	 0.005583	 0.042387	 0.08952	 220.94	 220.94	 220.94	 0.0	 0.0	 1	 -30.0	 30.0;
	77172	 77173	 0.00027	 0.001029	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77172	 77174	 0.000231	 0.001148	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77186	 77174	 0.018681	 0.11314	 0.09991	 210.57	 210.57	 210.57	 0.0	 0.0	 1	 -30.0	 30.0;
	77175	 77176	 0.000224	 0.001143	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77175	 77177	 0.00027	 0.001005	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77175	 77178	 0.000201	 0.001122	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77253	 77179	 0.003616	 0.019006	 0.00565	 296.65	 296.65	 296.65	 0.0	 0.0	 1	 -30.0	 30.0;
	77180	 77181	 0.000235	 0.00117	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77184	 77180	 0.00949	 0.056897	 0.07977	 248.91	 248.91	 248.91	 0.0	 0.0	 1	 -30.0	 30.0;
	77180	 77186	 0.005663	 0.034184	 0.01171	 408.31	 408.31	 408.31	 0.0	 0.0	 1	 -30.0	 30.0;
	77182	 77183	 0.000247	 0.00105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77273	 77183	 0.00661	 0.041382	 0.01609	 238.43	 238.43	 238.43	 0.0	 0.0	 1	 -30.0	 30.0;
	77186	 77185	 0.000486	 0.033516	 0.0	 426.67	 426.67	 426.67	 0.975	 0.0	 1	 -30.0	 30.0;
	77185	 77187	 0.000468	 0.032343	 0.0	 431.37	 431.37	 431.37	 1.04375	 0.0	 1	 -30.0	 30.0;
	77185	 77188	 0.000409	 0.028811	 0.0	 425.28	 425.28	 425.28	 1.04375	 0.0	 1	 -30.0	 30.0;
	77185	 77189	 0.000597	 0.033801	 0.0	 423.52	 423.52	 423.52	 1.04375	 0.0	 1	 -30.0	 30.0;
	77185	 77190	 0.000474	 0.029025	 0.0	 423.11	 423.11	 423.11	 1.04375	 0.0	 1	 -30.0	 30.0;
	77185	 77191	 0.000572	 0.027078	 0.0	 422.71	 422.71	 422.71	 1.04375	 0.0	 1	 -30.0	 30.0;
	77185	 77192	 0.000209	 0.001099	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77194	 77193	 0.000363	 0.024193	 0.0	 447.9	 447.9	 447.9	 1.00625	 0.0	 1	 -30.0	 30.0;
	77193	 77195	 0.000363	 0.019386	 0.0	 386.79	 386.79	 386.79	 1.0	 0.0	 1	 -30.0	 30.0;
	77193	 77196	 0.000551	 0.029839	 0.0	 386.61	 386.61	 386.61	 1.0	 0.0	 1	 -30.0	 30.0;
	77193	 77197	 0.000786	 0.035157	 0.0	 386.32	 386.32	 386.32	 1.0	 0.0	 1	 -30.0	 30.0;
	77230	 77193	 0.002688	 0.029118	 0.9352	 994.38	 994.38	 994.38	 0.0	 0.0	 1	 -30.0	 30.0;
	77198	 77199	 0.008098	 0.206059	 0.0	 80.58	 80.58	 80.58	 1.0	 0.0	 1	 -30.0	 30.0;
	77255	 77198	 0.00858	 0.042808	 0.01277	 256.54	 256.54	 256.54	 0.0	 0.0	 1	 -30.0	 30.0;
	77200	 77201	 0.000295	 0.001159	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77201	 77269	 0.004212	 0.016975	 0.00498	 226.83	 226.83	 226.83	 0.0	 0.0	 1	 -30.0	 30.0;
	77203	 77202	 0.000684	 0.033461	 0.0	 286.09	 286.09	 286.09	 1.0125	 0.0	 1	 -30.0	 30.0;
	77202	 77204	 0.000217	 0.014423	 0.0	 436.07	 436.07	 436.07	 1.0	 0.0	 1	 -30.0	 30.0;
	77202	 77205	 0.000244	 0.00102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77268	 77202	 0.004627	 0.05236	 0.8671	 1057.28	 1057.28	 1057.28	 0.0	 0.0	 1	 -30.0	 30.0;
	77202	 77287	 0.000871	 0.010494	 0.26026	 1066.18	 1066.18	 1066.18	 0.0	 0.0	 1	 -30.0	 30.0;
	77281	 77203	 0.004805	 0.024528	 0.00586	 161.66	 161.66	 161.66	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 77207	 0.01182	 0.37164	 0.0	 32.18	 32.18	 32.18	 0.9875	 0.0	 1	 -30.0	 30.0;
	77206	 77208	 0.000207	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77206	 77208	 0.000207	 0.001086	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77209	 77212	 0.000563	 0.033314	 0.0	 668.47	 668.47	 668.47	 1.0	 0.0	 1	 -30.0	 30.0;
	77209	 77213	 0.000169	 0.013693	 0.0	 506.74	 506.74	 506.74	 1.03125	 0.0	 1	 -30.0	 30.0;
	77209	 77220	 0.002159	 0.025762	 0.53735	 1198.99	 1198.99	 1198.99	 0.0	 0.0	 1	 -30.0	 30.0;
	77282	 77209	 0.00175	 0.024733	 0.42357	 1288.28	 1288.28	 1288.28	 0.0	 0.0	 1	 -30.0	 30.0;
	77210	 77212	 -0.000178	 -0.010528	 0.0	 568.47	 568.47	 568.47	 1.0	 0.0	 1	 -30.0	 30.0;
	77247	 77210	 0.00102	 0.004365	 0.02159	 258.68	 258.68	 258.68	 0.0	 0.0	 1	 -30.0	 30.0;
	77211	 77212	 0.001846	 0.109144	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77215	 77214	 0.000401	 0.023471	 0.0	 562.43	 562.43	 562.43	 1.0	 0.0	 1	 -30.0	 30.0;
	77214	 77216	 0.000835	 0.040126	 0.0	 375.93	 375.93	 375.93	 1.0	 0.0	 1	 -30.0	 30.0;
	77214	 77217	 0.000444	 0.028722	 0.0	 374.67	 374.67	 374.67	 0.99375	 0.0	 1	 -30.0	 30.0;
	77214	 77218	 0.00062	 0.036735	 0.0	 373.59	 373.59	 373.59	 0.99375	 0.0	 1	 -30.0	 30.0;
	77214	 77219	 0.000732	 0.029119	 0.0	 373.39	 373.39	 373.39	 0.99375	 0.0	 1	 -30.0	 30.0;
	77214	 77220	 0.000284	 0.001106	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77220	 77254	 0.002834	 0.032528	 1.31408	 1348.35	 1348.35	 1348.35	 0.0	 0.0	 1	 -30.0	 30.0;
	77222	 77221	 0.000518	 0.031099	 0.0	 439.99	 439.99	 439.99	 1.0125	 0.0	 1	 -30.0	 30.0;
	77221	 77223	 0.000483	 0.03052	 0.0	 439.3	 439.3	 439.3	 1.0	 0.0	 1	 -30.0	 30.0;
	77221	 77224	 0.000413	 0.026706	 0.0	 437.49	 437.49	 437.49	 1.0	 0.0	 1	 -30.0	 30.0;
	77221	 77225	 0.000649	 0.035787	 0.0	 436.7	 436.7	 436.7	 1.0	 0.0	 1	 -30.0	 30.0;
	77221	 77226	 0.000476	 0.036551	 0.0	 436.53	 436.53	 436.53	 1.0	 0.0	 1	 -30.0	 30.0;
	77221	 77227	 0.000281	 0.001188	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77227	 77252	 0.003982	 0.048678	 0.94023	 1075.67	 1075.67	 1075.67	 0.0	 0.0	 1	 -30.0	 30.0;
	77227	 77287	 0.006696	 0.068679	 0.82543	 1124.28	 1124.28	 1124.28	 0.0	 0.0	 1	 -30.0	 30.0;
	77229	 77228	 0.000588	 0.043486	 0.0	 403.96	 403.96	 403.96	 1.0	 0.0	 1	 -30.0	 30.0;
	77228	 77230	 0.000259	 0.001079	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77230	 77263	 0.003039	 0.039164	 0.65117	 1085.2	 1085.2	 1085.2	 0.0	 0.0	 1	 -30.0	 30.0;
	77268	 77230	 0.003647	 0.042866	 0.68722	 1046.22	 1046.22	 1046.22	 0.0	 0.0	 1	 -30.0	 30.0;
	77232	 77235	 0.000862	 0.05432	 0.0	 529.83	 529.83	 529.83	 1.0	 0.0	 1	 -30.0	 30.0;
	77232	 77236	 0.000541	 0.032773	 0.0	 393.26	 393.26	 393.26	 1.025	 0.0	 1	 -30.0	 30.0;
	77232	 77237	 0.00056	 0.036667	 0.0	 393.05	 393.05	 393.05	 1.025	 0.0	 1	 -30.0	 30.0;
	77232	 77238	 0.000724	 0.042178	 0.0	 392.7	 392.7	 392.7	 1.025	 0.0	 1	 -30.0	 30.0;
	77252	 77232	 0.005782	 0.072556	 1.4836	 1079.28	 1079.28	 1079.28	 0.0	 0.0	 1	 -30.0	 30.0;
	77233	 77235	 -0.000445	 -0.028043	 0.0	 404.83	 404.83	 404.83	 1.0	 0.0	 1	 -30.0	 30.0;
	77234	 77235	 0.002353	 0.148373	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77239	 77242	 0.000358	 0.023832	 0.0	 515.29	 515.29	 515.29	 1.0	 0.0	 1	 -30.0	 30.0;
	77239	 77243	 0.000506	 0.037338	 0.0	 396.26	 396.26	 396.26	 1.04375	 0.0	 1	 -30.0	 30.0;
	77239	 77244	 0.000374	 0.023462	 0.0	 395.94	 395.94	 395.94	 1.04375	 0.0	 1	 -30.0	 30.0;
	77239	 77245	 0.000713	 0.037766	 0.0	 318.44	 318.44	 318.44	 1.04375	 0.0	 1	 -30.0	 30.0;
	77239	 77246	 0.000215	 0.001068	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77240	 77242	 -0.00012	 -0.008003	 0.0	 390.29	 390.29	 390.29	 1.0	 0.0	 1	 -30.0	 30.0;
	77241	 77242	 0.001253	 0.083279	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77247	 77248	 0.00446	 0.121233	 0.0	 103.93	 103.93	 103.93	 1.0	 0.0	 1	 -30.0	 30.0;
	77249	 77250	 0.034001	 1.220747	 0.0	 13.0	 13.0	 13.0	 1.0125	 0.0	 1	 -30.0	 30.0;
	77249	 77251	 0.026768	 0.910915	 0.0	 13.0	 13.0	 13.0	 1.01875	 0.0	 1	 -30.0	 30.0;
	77253	 77252	 0.00034	 0.01506	 0.0	 408.5	 408.5	 408.5	 1.0	 0.0	 1	 -30.0	 30.0;
	77252	 77272	 0.001421	 0.018127	 0.30622	 1036.92	 1036.92	 1036.92	 0.0	 0.0	 1	 -30.0	 30.0;
	77254	 77257	 0.00061	 0.029286	 0.0	 583.2	 583.2	 583.2	 1.0	 0.0	 1	 -30.0	 30.0;
	77254	 77258	 0.000173	 0.010892	 0.0	 738.4	 738.4	 738.4	 1.025	 0.0	 1	 -30.0	 30.0;
	77254	 77259	 0.000291	 0.016655	 0.0	 738.4	 738.4	 738.4	 1.025	 0.0	 1	 -30.0	 30.0;
	77254	 77260	 0.000275	 0.018838	 0.0	 738.4	 738.4	 738.4	 1.025	 0.0	 1	 -30.0	 30.0;
	77254	 77261	 0.00019	 0.012668	 0.0	 738.4	 738.4	 738.4	 1.025	 0.0	 1	 -30.0	 30.0;
	77254	 77262	 0.000341	 0.001237	 0.0	 0.0	 0.0	 0.0	 1.0	 -26.0	 1	 -30.0	 30.0;
	77254	 77262	 0.000341	 0.001237	 0.0	 0.0	 0.0	 0.0	 1.0	 -26.0	 1	 -30.0	 30.0;
	77254	 77282	 0.002677	 0.030442	 0.4289	 1310.31	 1310.31	 1310.31	 0.0	 0.0	 1	 -30.0	 30.0;
	77255	 77257	 -8.3e-05	 -0.003975	 0.0	 483.2	 483.2	 483.2	 1.0	 0.0	 1	 -30.0	 30.0;
	77256	 77257	 0.003298	 0.158368	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77263	 77266	 -0.000145	 -0.009632	 0.0	 433.25	 433.25	 433.25	 1.0	 0.0	 1	 -30.0	 30.0;
	77264	 77266	 0.000656	 0.043453	 0.0	 383.25	 383.25	 383.25	 1.0	 0.0	 1	 -30.0	 30.0;
	77265	 77266	 0.003232	 0.214073	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77269	 77267	 0.00055	 0.003842	 0.00098	 174.02	 174.02	 174.02	 0.0	 0.0	 1	 -30.0	 30.0;
	77269	 77268	 0.000342	 0.023657	 0.0	 339.01	 339.01	 339.01	 0.9875	 0.0	 1	 -30.0	 30.0;
	77270	 77271	 0.000297	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77273	 77272	 0.000301	 0.018051	 0.0	 364.4	 364.4	 364.4	 1.03125	 0.0	 1	 -30.0	 30.0;
	77272	 77274	 0.000608	 0.033698	 0.0	 435.22	 435.22	 435.22	 1.0	 0.0	 1	 -30.0	 30.0;
	77272	 77275	 0.000283	 0.017002	 0.0	 435.05	 435.05	 435.05	 1.0	 0.0	 1	 -30.0	 30.0;
	77272	 77276	 0.000582	 0.039513	 0.0	 434.95	 434.95	 434.95	 1.0	 0.0	 1	 -30.0	 30.0;
	77272	 77277	 0.00041	 0.02641	 0.0	 434.5	 434.5	 434.5	 1.0	 0.0	 1	 -30.0	 30.0;
	77272	 77278	 0.000418	 0.030967	 0.0	 434.25	 434.25	 434.25	 1.0	 0.0	 1	 -30.0	 30.0;
	77279	 77280	 0.001881	 0.063729	 0.0	 134.55	 134.55	 134.55	 1.0625	 0.0	 1	 -30.0	 30.0;
	77279	 77281	 0.000284	 0.001042	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77282	 77285	 0.000686	 0.043368	 0.0	 567.7	 567.7	 567.7	 1.0	 0.0	 1	 -30.0	 30.0;
	77282	 77286	 0.000505	 0.029653	 0.0	 450.47	 450.47	 450.47	 0.99375	 0.0	 1	 -30.0	 30.0;
	77283	 77285	 -0.000276	 -0.017424	 0.0	 492.7	 492.7	 492.7	 1.0	 0.0	 1	 -30.0	 30.0;
	77284	 77285	 0.002879	 0.182009	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	77288	 77287	 0.000592	 0.037436	 0.0	 279.82	 279.82	 279.82	 1.0	 0.0	 1	 -30.0	 30.0;
	77287	 77289	 0.000442	 0.024052	 0.0	 516.95	 516.95	 516.95	 1.00625	 0.0	 1	 -30.0	 30.0;
	77290	 77295	 0.002223	 0.013667	 0.00291	 188.83	 188.83	 188.83	 0.0	 0.0	 1	 -30.0	 30.0;
	77291	 77292	 0.000253	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77291	 77293	 0.000229	 0.001088	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77295	 77292	 0.001166	 0.008171	 0.0112	 220.52	 220.52	 220.52	 0.0	 0.0	 1	 -30.0	 30.0;
	77294	 77295	 0.000242	 0.001152	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80000	 80001	 0.00025	 0.001161	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80000	 80002	 0.000217	 0.001127	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80021	 80003	 0.004593	 0.020761	 0.00493	 162.7	 162.7	 162.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80012	 80004	 0.004894	 0.017766	 0.02057	 115.35	 115.35	 115.35	 0.0	 0.0	 1	 -30.0	 30.0;
	80005	 80085	 0.006997	 0.034772	 0.01194	 168.55	 168.55	 168.55	 0.0	 0.0	 1	 -30.0	 30.0;
	80007	 80006	 0.001326	 0.051921	 0.0	 261.1	 261.1	 261.1	 1.1	 0.0	 1	 -30.0	 30.0;
	80007	 80006	 0.001326	 0.051921	 0.0	 261.1	 261.1	 261.1	 1.1	 0.0	 1	 -30.0	 30.0;
	80007	 80006	 0.001326	 0.051921	 0.0	 261.1	 261.1	 261.1	 1.025	 0.0	 1	 -30.0	 30.0;
	80087	 80006	 0.00109	 0.009958	 0.04927	 509.43	 509.43	 509.43	 0.0	 0.0	 1	 -30.0	 30.0;
	80007	 80011	 0.001545	 0.007811	 0.00164	 205.73	 205.73	 205.73	 0.0	 0.0	 1	 -30.0	 30.0;
	80012	 80007	 0.006113	 0.028517	 0.00518	 158.34	 158.34	 158.34	 0.0	 0.0	 1	 -30.0	 30.0;
	80007	 80025	 0.003529	 0.010292	 0.00176	 183.24	 183.24	 183.24	 0.0	 0.0	 1	 -30.0	 30.0;
	80007	 80030	 0.006632	 0.033187	 0.02241	 191.24	 191.24	 191.24	 0.0	 0.0	 1	 -30.0	 30.0;
	80008	 80009	 0.000253	 0.001072	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80008	 80010	 0.002828	 0.014452	 0.00512	 169.05	 169.05	 169.05	 0.0	 0.0	 1	 -30.0	 30.0;
	80008	 80025	 0.003967	 0.019431	 0.00238	 174.72	 174.72	 174.72	 0.0	 0.0	 1	 -30.0	 30.0;
	80008	 80032	 0.00287	 0.016036	 0.00337	 160.13	 160.13	 160.13	 0.0	 0.0	 1	 -30.0	 30.0;
	80011	 80036	 0.004308	 0.024677	 0.0088	 180.88	 180.88	 180.88	 0.0	 0.0	 1	 -30.0	 30.0;
	80013	 80032	 0.006559	 0.033487	 0.01417	 154.0	 154.0	 154.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80014	 80015	 0.000287	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80014	 80016	 0.000222	 0.001062	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80016	 80024	 0.000699	 0.002021	 0.00064	 140.14	 140.14	 140.14	 0.0	 0.0	 1	 -30.0	 30.0;
	80016	 80085	 0.004373	 0.016747	 0.01086	 167.16	 167.16	 167.16	 0.0	 0.0	 1	 -30.0	 30.0;
	80026	 80017	 0.002644	 0.008683	 0.00216	 115.31	 115.31	 115.31	 0.0	 0.0	 1	 -30.0	 30.0;
	80037	 80017	 0.004898	 0.022903	 0.00559	 151.68	 151.68	 151.68	 0.0	 0.0	 1	 -30.0	 30.0;
	80018	 80019	 0.000254	 0.001138	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80036	 80018	 0.00043	 0.001581	 0.00091	 157.07	 157.07	 157.07	 0.0	 0.0	 1	 -30.0	 30.0;
	80018	 80100	 0.005023	 0.029035	 0.01836	 191.25	 191.25	 191.25	 0.0	 0.0	 1	 -30.0	 30.0;
	80020	 80030	 0.002656	 0.015332	 0.00484	 181.24	 181.24	 181.24	 0.0	 0.0	 1	 -30.0	 30.0;
	80020	 80033	 0.005966	 0.018509	 0.00673	 172.04	 172.04	 172.04	 0.0	 0.0	 1	 -30.0	 30.0;
	80020	 80050	 0.004535	 0.020026	 0.01038	 157.63	 157.63	 157.63	 0.0	 0.0	 1	 -30.0	 30.0;
	80021	 80025	 0.005394	 0.023212	 0.03949	 135.93	 135.93	 135.93	 0.0	 0.0	 1	 -30.0	 30.0;
	80022	 80023	 0.000232	 0.001066	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80022	 80037	 0.00584	 0.030399	 0.00662	 155.21	 155.21	 155.21	 0.0	 0.0	 1	 -30.0	 30.0;
	80050	 80022	 0.000899	 0.005483	 0.00187	 116.14	 116.14	 116.14	 0.0	 0.0	 1	 -30.0	 30.0;
	80024	 80054	 0.00105	 0.004247	 0.00181	 154.81	 154.81	 154.81	 0.0	 0.0	 1	 -30.0	 30.0;
	80024	 80058	 0.001006	 0.005408	 0.02259	 134.54	 134.54	 134.54	 0.0	 0.0	 1	 -30.0	 30.0;
	80026	 80027	 0.000288	 0.001056	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80026	 80028	 0.004335	 0.024473	 0.00454	 155.75	 155.75	 155.75	 0.0	 0.0	 1	 -30.0	 30.0;
	80026	 80036	 0.00351	 0.014742	 0.01554	 167.48	 167.48	 167.48	 0.0	 0.0	 1	 -30.0	 30.0;
	80028	 80029	 0.000226	 0.001073	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80028	 80088	 0.004681	 0.024264	 0.00281	 198.24	 198.24	 198.24	 0.0	 0.0	 1	 -30.0	 30.0;
	80030	 80031	 0.0003	 0.001131	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80032	 80043	 0.007076	 0.039145	 0.02737	 173.37	 173.37	 173.37	 0.0	 0.0	 1	 -30.0	 30.0;
	80033	 80034	 0.000234	 0.001197	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80035	 80033	 0.005729	 0.022305	 0.00704	 158.77	 158.77	 158.77	 0.0	 0.0	 1	 -30.0	 30.0;
	80033	 80044	 0.005528	 0.021087	 0.03803	 157.77	 157.77	 157.77	 0.0	 0.0	 1	 -30.0	 30.0;
	80035	 80046	 0.008104	 0.028288	 0.01019	 192.75	 192.75	 192.75	 0.0	 0.0	 1	 -30.0	 30.0;
	80038	 80039	 0.000264	 0.001033	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80038	 80040	 0.000275	 0.001102	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80038	 80041	 0.000209	 0.001166	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80038	 80042	 0.000283	 0.001039	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80040	 80046	 0.003329	 0.011215	 0.00305	 203.29	 203.29	 203.29	 0.0	 0.0	 1	 -30.0	 30.0;
	80047	 80040	 0.004644	 0.021243	 0.00327	 183.76	 183.76	 183.76	 0.0	 0.0	 1	 -30.0	 30.0;
	80054	 80043	 0.003075	 0.012999	 0.00362	 145.79	 145.79	 145.79	 0.0	 0.0	 1	 -30.0	 30.0;
	80058	 80044	 0.007289	 0.026414	 0.00248	 159.2	 159.2	 159.2	 0.0	 0.0	 1	 -30.0	 30.0;
	80044	 80073	 0.008922	 0.049991	 0.07962	 114.85	 114.85	 114.85	 0.0	 0.0	 1	 -30.0	 30.0;
	80046	 80045	 0.001674	 0.049819	 0.0	 255.54	 255.54	 255.54	 1.06875	 0.0	 1	 -30.0	 30.0;
	80046	 80045	 0.001674	 0.049819	 0.0	 255.54	 255.54	 255.54	 1.06875	 0.0	 1	 -30.0	 30.0;
	80046	 80045	 0.001674	 0.049819	 0.0	 255.54	 255.54	 255.54	 1.06875	 0.0	 1	 -30.0	 30.0;
	80049	 80045	 0.001245	 0.009447	 0.02918	 644.61	 644.61	 644.61	 0.0	 0.0	 1	 -30.0	 30.0;
	80045	 80087	 0.002272	 0.020438	 0.0773	 557.93	 557.93	 557.93	 0.0	 0.0	 1	 -30.0	 30.0;
	80046	 80062	 0.011306	 0.052547	 0.02427	 175.67	 175.67	 175.67	 0.0	 0.0	 1	 -30.0	 30.0;
	80047	 80058	 0.009476	 0.050266	 0.03674	 189.25	 189.25	 189.25	 0.0	 0.0	 1	 -30.0	 30.0;
	80049	 80048	 0.000181	 0.012786	 0.0	 1028.67	 1028.67	 1028.67	 1.025	 0.0	 1	 -30.0	 30.0;
	80048	 80086	 0.000146	 0.002769	 0.40145	 2701.0	 2701.0	 2701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80049	 80052	 0.001727	 0.089865	 0.0	 273.39	 273.39	 273.39	 1.0	 0.0	 1	 -30.0	 30.0;
	80049	 80057	 0.00133	 0.012952	 0.04729	 582.42	 582.42	 582.42	 0.0	 0.0	 1	 -30.0	 30.0;
	80049	 80071	 0.003548	 0.034101	 0.08315	 529.41	 529.41	 529.41	 0.0	 0.0	 1	 -30.0	 30.0;
	80050	 80052	 -0.000251	 -0.013039	 0.0	 198.39	 198.39	 198.39	 1.0	 0.0	 1	 -30.0	 30.0;
	80051	 80052	 0.007301	 0.379808	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80053	 80056	 0.003225	 0.121682	 0.0	 288.93	 288.93	 288.93	 1.0	 0.0	 1	 -30.0	 30.0;
	80053	 80057	 0.000213	 0.001105	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80054	 80056	 -0.001804	 -0.068077	 0.0	 180.6	 180.6	 180.6	 1.0	 0.0	 1	 -30.0	 30.0;
	80055	 80056	 0.008102	 0.30576	 0.0	 108.33	 108.33	 108.33	 1.0	 0.0	 1	 -30.0	 30.0;
	80057	 80071	 0.002652	 0.023337	 0.06009	 492.28	 492.28	 492.28	 0.0	 0.0	 1	 -30.0	 30.0;
	80058	 80059	 0.000295	 0.001003	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80060	 80061	 0.000275	 0.001153	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80060	 80062	 0.000293	 0.001052	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80060	 80063	 0.000278	 0.001077	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80060	 80064	 0.000266	 0.001133	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80072	 80062	 0.004264	 0.017787	 0.00943	 148.11	 148.11	 148.11	 0.0	 0.0	 1	 -30.0	 30.0;
	80065	 80066	 0.000215	 0.001108	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80065	 80067	 0.005658	 0.029782	 0.00777	 127.1	 127.1	 127.1	 0.0	 0.0	 1	 -30.0	 30.0;
	80065	 80069	 0.009727	 0.050154	 0.00846	 129.37	 129.37	 129.37	 0.0	 0.0	 1	 -30.0	 30.0;
	80067	 80069	 0.001032	 0.004107	 0.00208	 182.59	 182.59	 182.59	 0.0	 0.0	 1	 -30.0	 30.0;
	80067	 80072	 0.003493	 0.020005	 0.00558	 163.49	 163.49	 163.49	 0.0	 0.0	 1	 -30.0	 30.0;
	80069	 80068	 0.001458	 0.069997	 0.0	 177.75	 177.75	 177.75	 1.0	 0.0	 1	 -30.0	 30.0;
	80068	 80070	 0.000254	 0.001104	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80068	 80071	 0.00023	 0.001035	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80069	 80082	 0.016474	 0.072398	 0.01871	 142.37	 142.37	 142.37	 0.0	 0.0	 1	 -30.0	 30.0;
	80082	 80073	 0.002437	 0.012911	 0.00325	 137.5	 137.5	 137.5	 0.0	 0.0	 1	 -30.0	 30.0;
	80073	 80083	 0.070212	 0.347293	 0.05054	 100.36	 100.36	 100.36	 0.0	 0.0	 1	 -30.0	 30.0;
	80074	 80075	 0.000206	 0.001101	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80077	 80074	 0.004678	 0.023816	 0.0034	 160.44	 160.44	 160.44	 0.0	 0.0	 1	 -30.0	 30.0;
	80076	 80079	 0.00264	 0.107478	 0.0	 386.51	 386.51	 386.51	 1.0	 0.0	 1	 -30.0	 30.0;
	80076	 80080	 0.000247	 0.001109	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80077	 80079	 -0.001363	 -0.055478	 0.0	 181.5	 181.5	 181.5	 1.0	 0.0	 1	 -30.0	 30.0;
	80078	 80079	 0.005926	 0.241215	 0.0	 205.01	 205.01	 205.01	 1.0	 0.0	 1	 -30.0	 30.0;
	80080	 80087	 0.004037	 0.034681	 0.12316	 536.51	 536.51	 536.51	 0.0	 0.0	 1	 -30.0	 30.0;
	80081	 80082	 0.000249	 0.001026	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80082	 80083	 0.041193	 0.218508	 0.05732	 103.08	 103.08	 103.08	 0.0	 0.0	 1	 -30.0	 30.0;
	80083	 80084	 0.00025	 0.001172	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	80087	 80086	 0.000247	 0.017975	 0.0	 995.95	 995.95	 995.95	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80091	 0.000221	 0.017436	 0.0	 740.7	 740.7	 740.7	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80092	 0.000171	 0.010813	 0.0	 739.74	 739.74	 739.74	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80093	 0.000146	 0.009467	 0.0	 739.0	 739.0	 739.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80094	 0.000271	 0.015312	 0.0	 736.7	 736.7	 736.7	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80095	 0.000205	 0.014872	 0.0	 731.63	 731.63	 731.63	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80096	 0.00017	 0.013038	 0.0	 726.09	 726.09	 726.09	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80097	 0.000255	 0.019839	 0.0	 665.03	 665.03	 665.03	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80098	 0.000209	 0.015252	 0.0	 664.84	 664.84	 664.84	 1.0	 0.0	 1	 -30.0	 30.0;
	80086	 80099	 0.000368	 0.026912	 0.0	 660.89	 660.89	 660.89	 1.0	 0.0	 1	 -30.0	 30.0;
	80087	 80090	 0.000619	 0.030031	 0.0	 266.35	 266.35	 266.35	 1.0	 0.0	 1	 -30.0	 30.0;
	80088	 80090	 0.00022	 0.010692	 0.0	 216.35	 216.35	 216.35	 1.0	 0.0	 1	 -30.0	 30.0;
	80088	 80100	 0.000886	 0.003872	 0.00101	 184.7	 184.7	 184.7	 0.0	 0.0	 1	 -30.0	 30.0;
	80089	 80090	 0.004514	 0.218925	 0.0	 50.0	 50.0	 50.0	 1.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : Updated Thermal Rating: on line 10002-10001 : Rate B, Rate C - 0.0, 0.0 -> 185.33, 185.33
% INFO    : Updated Thermal Rating: on line 10011-10001 : Rate B, Rate C - 0.0, 0.0 -> 167.88, 167.88
% INFO    : Updated Thermal Rating: on line 10014-10002 : Rate B, Rate C - 0.0, 0.0 -> 207.43, 207.43
% INFO    : Updated Thermal Rating: on line 10004-10003 : Rate B, Rate C - 0.0, 0.0 -> 170.67, 170.67
% INFO    : Updated Thermal Rating: on line 10003-10010 : Rate B, Rate C - 0.0, 0.0 -> 201.54, 201.54
% INFO    : Updated Thermal Rating: on line 10937-10003 : Rate B, Rate C - 0.0, 0.0 -> 211.8, 211.8
% INFO    : Updated Thermal Rating: on line 10004-10937 : Rate B, Rate C - 0.0, 0.0 -> 195.1, 195.1
% INFO    : Updated Thermal Rating: on line 10008-10007 : Rate B, Rate C - 0.0, 0.0 -> 212.34, 212.34
% INFO    : Updated Thermal Rating: on line 10007-13019 : Rate B, Rate C - 0.0, 0.0 -> 218.55, 218.55
% INFO    : Updated Thermal Rating: on line 10007-13028 : Rate B, Rate C - 0.0, 0.0 -> 231.63, 231.63
% INFO    : Updated Thermal Rating: on line 10016-10008 : Rate B, Rate C - 0.0, 0.0 -> 229.92, 229.92
% INFO    : Updated Thermal Rating: on line 13019-10008 : Rate B, Rate C - 0.0, 0.0 -> 184.78, 184.78
% INFO    : Updated Thermal Rating: on line 10014-10010 : Rate B, Rate C - 0.0, 0.0 -> 197.37, 197.37
% INFO    : Updated Thermal Rating: on line 10011-10020 : Rate B, Rate C - 0.0, 0.0 -> 214.06, 214.06
% INFO    : Updated Thermal Rating: on transformer 10013-10012 : Rate B, Rate C - 0.0, 0.0 -> 473.63, 473.63
% INFO    : Updated Thermal Rating: on line 10012-10023 : Rate B, Rate C - 0.0, 0.0 -> 1105.1, 1105.1
% INFO    : Updated Thermal Rating: on line 10012-10987 : Rate B, Rate C - 0.0, 0.0 -> 1237.08, 1237.08
% INFO    : Updated Thermal Rating: on line 10014-10013 : Rate B, Rate C - 0.0, 0.0 -> 236.46, 236.46
% INFO    : Updated Thermal Rating: on line 10013-10076 : Rate B, Rate C - 0.0, 0.0 -> 239.71, 239.71
% INFO    : Updated Thermal Rating: on line 10016-13463 : Rate B, Rate C - 0.0, 0.0 -> 245.26, 245.26
% INFO    : Updated Thermal Rating: on line 10018-10032 : Rate B, Rate C - 0.0, 0.0 -> 250.62, 250.62
% INFO    : Updated Thermal Rating: on line 10018-10988 : Rate B, Rate C - 0.0, 0.0 -> 263.59, 263.59
% INFO    : Updated Thermal Rating: on transformer 10020-10019 : Rate B, Rate C - 0.0, 0.0 -> 445.05, 445.05
% INFO    : Updated Thermal Rating: on line 10730-10019 : Rate B, Rate C - 0.0, 0.0 -> 1150.4, 1150.4
% INFO    : Updated Thermal Rating: on line 10020-10029 : Rate B, Rate C - 0.0, 0.0 -> 233.76, 233.76
% INFO    : Updated Thermal Rating: on line 10021-13074 : Rate B, Rate C - 0.0, 0.0 -> 251.36, 251.36
% INFO    : Updated Thermal Rating: on line 10021-13512 : Rate B, Rate C - 0.0, 0.0 -> 201.56, 201.56
% INFO    : Updated Thermal Rating: on line 13690-10021 : Rate B, Rate C - 0.0, 0.0 -> 247.31, 247.31
% INFO    : Updated Thermal Rating: on line 10022-10024 : Rate B, Rate C - 0.0, 0.0 -> 204.48, 204.48
% INFO    : Updated Thermal Rating: on line 10022-10030 : Rate B, Rate C - 0.0, 0.0 -> 210.69, 210.69
% INFO    : Updated Thermal Rating: on transformer 10024-10023 : Rate B, Rate C - 0.0, 0.0 -> 465.77, 465.77
% INFO    : Updated Thermal Rating: on line 10730-10023 : Rate B, Rate C - 0.0, 0.0 -> 1205.73, 1205.73
% INFO    : Updated Thermal Rating: on line 10987-10023 : Rate B, Rate C - 0.0, 0.0 -> 1271.34, 1271.34
% INFO    : Updated Thermal Rating: on line 10024-10039 : Rate B, Rate C - 0.0, 0.0 -> 261.21, 261.21
% INFO    : Updated Thermal Rating: on line 10025-10858 : Rate B, Rate C - 0.0, 0.0 -> 188.02, 188.02
% INFO    : Updated Thermal Rating: on line 10025-10929 : Rate B, Rate C - 0.0, 0.0 -> 219.05, 219.05
% INFO    : Updated Thermal Rating: on line 10051-10026 : Rate B, Rate C - 0.0, 0.0 -> 220.77, 220.77
% INFO    : Updated Thermal Rating: on line 10027-10029 : Rate B, Rate C - 0.0, 0.0 -> 209.69, 209.69
% INFO    : Updated Thermal Rating: on line 10054-10027 : Rate B, Rate C - 0.0, 0.0 -> 199.0, 199.0
% INFO    : Updated Thermal Rating: on line 10030-10988 : Rate B, Rate C - 0.0, 0.0 -> 237.68, 237.68
% INFO    : Updated Thermal Rating: on line 10032-10040 : Rate B, Rate C - 0.0, 0.0 -> 226.1, 226.1
% INFO    : Updated Thermal Rating: on line 10036-10033 : Rate B, Rate C - 0.0, 0.0 -> 216.72, 216.72
% INFO    : Updated Thermal Rating: on line 10033-10045 : Rate B, Rate C - 0.0, 0.0 -> 216.4, 216.4
% INFO    : Updated Thermal Rating: on line 10033-11071 : Rate B, Rate C - 0.0, 0.0 -> 237.01, 237.01
% INFO    : Updated Thermal Rating: on line 10033-13147 : Rate B, Rate C - 0.0, 0.0 -> 246.79, 246.79
% INFO    : Updated Thermal Rating: on line 11071-10036 : Rate B, Rate C - 0.0, 0.0 -> 254.33, 254.33
% INFO    : Updated Thermal Rating: on line 10037-10041 : Rate B, Rate C - 0.0, 0.0 -> 230.13, 230.13
% INFO    : Updated Thermal Rating: on line 10037-10053 : Rate B, Rate C - 0.0, 0.0 -> 255.03, 255.03
% INFO    : Updated Thermal Rating: on line 10929-10037 : Rate B, Rate C - 0.0, 0.0 -> 255.57, 255.57
% INFO    : Updated Thermal Rating: on line 10040-10039 : Rate B, Rate C - 0.0, 0.0 -> 243.11, 243.11
% INFO    : Updated Thermal Rating: on line 10040-10061 : Rate B, Rate C - 0.0, 0.0 -> 245.08, 245.08
% INFO    : Updated Thermal Rating: on line 10045-10041 : Rate B, Rate C - 0.0, 0.0 -> 236.56, 236.56
% INFO    : Updated Thermal Rating: on line 10041-10757 : Rate B, Rate C - 0.0, 0.0 -> 270.97, 270.97
% INFO    : Updated Thermal Rating: on line 10112-10042 : Rate B, Rate C - 0.0, 0.0 -> 241.87, 241.87
% INFO    : Updated Thermal Rating: on line 10042-10858 : Rate B, Rate C - 0.0, 0.0 -> 265.85, 265.85
% INFO    : Updated Thermal Rating: on line 10065-10043 : Rate B, Rate C - 0.0, 0.0 -> 234.78, 234.78
% INFO    : Updated Thermal Rating: on line 10043-10731 : Rate B, Rate C - 0.0, 0.0 -> 254.45, 254.45
% INFO    : Updated Thermal Rating: on line 10049-10046 : Rate B, Rate C - 0.0, 0.0 -> 199.81, 199.81
% INFO    : Updated Thermal Rating: on line 10046-10053 : Rate B, Rate C - 0.0, 0.0 -> 230.09, 230.09
% INFO    : Updated Thermal Rating: on line 10046-10060 : Rate B, Rate C - 0.0, 0.0 -> 209.43, 209.43
% INFO    : Updated Thermal Rating: on line 10049-10858 : Rate B, Rate C - 0.0, 0.0 -> 236.41, 236.41
% INFO    : Updated Thermal Rating: on line 10051-10106 : Rate B, Rate C - 0.0, 0.0 -> 232.86, 232.86
% INFO    : Updated Thermal Rating: on line 10054-10087 : Rate B, Rate C - 0.0, 0.0 -> 227.67, 227.67
% INFO    : Updated Thermal Rating: on line 10071-10056 : Rate B, Rate C - 0.0, 0.0 -> 213.54, 213.54
% INFO    : Updated Thermal Rating: on line 10056-10111 : Rate B, Rate C - 0.0, 0.0 -> 227.01, 227.01
% INFO    : Updated Thermal Rating: on transformer 10058-10057 : Rate B, Rate C - 0.0, 0.0 -> 466.21, 466.21
% INFO    : Updated Thermal Rating: on line 10060-10058 : Rate B, Rate C - 0.0, 0.0 -> 201.84, 201.84
% INFO    : Updated Thermal Rating: on line 10058-10072 : Rate B, Rate C - 0.0, 0.0 -> 235.48, 235.48
% INFO    : Updated Thermal Rating: on line 10058-10099 : Rate B, Rate C - 0.0, 0.0 -> 230.02, 230.02
% INFO    : Updated Thermal Rating: on line 10059-10462 : Rate B, Rate C - 0.0, 0.0 -> 1228.28, 1228.28
% INFO    : Updated Thermal Rating: on line 10857-10059 : Rate B, Rate C - 0.0, 0.0 -> 1358.91, 1358.91
% INFO    : Updated Thermal Rating: on line 10061-10133 : Rate B, Rate C - 0.0, 0.0 -> 211.25, 211.25
% INFO    : Updated Thermal Rating: on line 10065-10063 : Rate B, Rate C - 0.0, 0.0 -> 196.02, 196.02
% INFO    : Updated Thermal Rating: on line 10063-10149 : Rate B, Rate C - 0.0, 0.0 -> 206.38, 206.38
% INFO    : Updated Thermal Rating: on transformer 10065-10068 : Rate B, Rate C - 0.0, 0.0 -> 108.63, 108.63
% INFO    : Updated Thermal Rating: on transformer 10066-10068 : Rate B, Rate C - 0.0, 0.0 -> 54.31, 54.31
% INFO    : Updated Thermal Rating: on transformer 10067-10068 : Rate B, Rate C - 0.0, 0.0 -> 54.31, 54.31
% INFO    : Updated Thermal Rating: on line 10069-10074 : Rate B, Rate C - 0.0, 0.0 -> 203.82, 203.82
% INFO    : Updated Thermal Rating: on line 10781-10069 : Rate B, Rate C - 0.0, 0.0 -> 244.58, 244.58
% INFO    : Updated Thermal Rating: on line 10070-10090 : Rate B, Rate C - 0.0, 0.0 -> 221.92, 221.92
% INFO    : Updated Thermal Rating: on line 10095-10070 : Rate B, Rate C - 0.0, 0.0 -> 229.14, 229.14
% INFO    : Updated Thermal Rating: on line 10112-10071 : Rate B, Rate C - 0.0, 0.0 -> 236.16, 236.16
% INFO    : Updated Thermal Rating: on line 10071-10153 : Rate B, Rate C - 0.0, 0.0 -> 232.27, 232.27
% INFO    : Updated Thermal Rating: on line 10072-10155 : Rate B, Rate C - 0.0, 0.0 -> 205.7, 205.7
% INFO    : Updated Thermal Rating: on line 13154-10074 : Rate B, Rate C - 0.0, 0.0 -> 181.22, 181.22
% INFO    : Updated Thermal Rating: on line 10076-10133 : Rate B, Rate C - 0.0, 0.0 -> 218.87, 218.87
% INFO    : Updated Thermal Rating: on line 10077-10092 : Rate B, Rate C - 0.0, 0.0 -> 205.12, 205.12
% INFO    : Updated Thermal Rating: on line 10077-10097 : Rate B, Rate C - 0.0, 0.0 -> 216.78, 216.78
% INFO    : Updated Thermal Rating: on line 10077-10137 : Rate B, Rate C - 0.0, 0.0 -> 236.35, 236.35
% INFO    : Updated Thermal Rating: on line 10077-13292 : Rate B, Rate C - 0.0, 0.0 -> 229.46, 229.46
% INFO    : Updated Thermal Rating: on transformer 10078-10081 : Rate B, Rate C - 0.0, 0.0 -> 616.81, 616.81
% INFO    : Updated Thermal Rating: on line 10078-10838 : Rate B, Rate C - 0.0, 0.0 -> 1170.64, 1170.64
% INFO    : Updated Thermal Rating: on transformer 10079-10081 : Rate B, Rate C - 0.0, 0.0 -> 466.81, 466.81
% INFO    : Updated Thermal Rating: on line 10079-10124 : Rate B, Rate C - 0.0, 0.0 -> 219.64, 219.64
% INFO    : Updated Thermal Rating: on line 10140-10079 : Rate B, Rate C - 0.0, 0.0 -> 246.83, 246.83
% INFO    : Updated Thermal Rating: on transformer 10080-10081 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 10113-10082 : Rate B, Rate C - 0.0, 0.0 -> 182.93, 182.93
% INFO    : Updated Thermal Rating: on line 10082-10121 : Rate B, Rate C - 0.0, 0.0 -> 198.55, 198.55
% INFO    : Updated Thermal Rating: on line 10086-10136 : Rate B, Rate C - 0.0, 0.0 -> 216.7, 216.7
% INFO    : Updated Thermal Rating: on line 10086-10216 : Rate B, Rate C - 0.0, 0.0 -> 176.23, 176.23
% INFO    : Updated Thermal Rating: on line 10087-10121 : Rate B, Rate C - 0.0, 0.0 -> 206.89, 206.89
% INFO    : Updated Thermal Rating: on line 10203-10087 : Rate B, Rate C - 0.0, 0.0 -> 214.83, 214.83
% INFO    : Updated Thermal Rating: on line 10088-10128 : Rate B, Rate C - 0.0, 0.0 -> 258.98, 258.98
% INFO    : Updated Thermal Rating: on line 10088-10149 : Rate B, Rate C - 0.0, 0.0 -> 223.8, 223.8
% INFO    : Updated Thermal Rating: on line 10088-10227 : Rate B, Rate C - 0.0, 0.0 -> 212.33, 212.33
% INFO    : Updated Thermal Rating: on line 10090-10138 : Rate B, Rate C - 0.0, 0.0 -> 189.9, 189.9
% INFO    : Updated Thermal Rating: on line 10090-10149 : Rate B, Rate C - 0.0, 0.0 -> 172.91, 172.91
% INFO    : Updated Thermal Rating: on line 10137-10091 : Rate B, Rate C - 0.0, 0.0 -> 248.05, 248.05
% INFO    : Updated Thermal Rating: on line 10091-10176 : Rate B, Rate C - 0.0, 0.0 -> 214.01, 214.01
% INFO    : Updated Thermal Rating: on line 10091-10954 : Rate B, Rate C - 0.0, 0.0 -> 249.45, 249.45
% INFO    : Updated Thermal Rating: on line 10092-10148 : Rate B, Rate C - 0.0, 0.0 -> 229.01, 229.01
% INFO    : Updated Thermal Rating: on line 10092-10173 : Rate B, Rate C - 0.0, 0.0 -> 235.88, 235.88
% INFO    : Updated Thermal Rating: on line 10093-13144 : Rate B, Rate C - 0.0, 0.0 -> 218.69, 218.69
% INFO    : Updated Thermal Rating: on line 10093-13147 : Rate B, Rate C - 0.0, 0.0 -> 258.14, 258.14
% INFO    : Updated Thermal Rating: on line 10093-13182 : Rate B, Rate C - 0.0, 0.0 -> 234.34, 234.34
% INFO    : Updated Thermal Rating: on line 10093-13204 : Rate B, Rate C - 0.0, 0.0 -> 217.58, 217.58
% INFO    : Updated Thermal Rating: on line 13292-10093 : Rate B, Rate C - 0.0, 0.0 -> 233.12, 233.12
% INFO    : Updated Thermal Rating: on line 10133-10095 : Rate B, Rate C - 0.0, 0.0 -> 168.25, 168.25
% INFO    : Updated Thermal Rating: on line 10095-11010 : Rate B, Rate C - 0.0, 0.0 -> 241.84, 241.84
% INFO    : Updated Thermal Rating: on line 10097-10954 : Rate B, Rate C - 0.0, 0.0 -> 240.32, 240.32
% INFO    : Updated Thermal Rating: on line 10155-10099 : Rate B, Rate C - 0.0, 0.0 -> 214.82, 214.82
% INFO    : Updated Thermal Rating: on line 13260-10101 : Rate B, Rate C - 0.0, 0.0 -> 194.26, 194.26
% INFO    : Updated Thermal Rating: on line 13301-10101 : Rate B, Rate C - 0.0, 0.0 -> 212.88, 212.88
% INFO    : Updated Thermal Rating: on line 13314-10101 : Rate B, Rate C - 0.0, 0.0 -> 194.85, 194.85
% INFO    : Updated Thermal Rating: on line 10131-10105 : Rate B, Rate C - 0.0, 0.0 -> 209.77, 209.77
% INFO    : Updated Thermal Rating: on line 10148-10105 : Rate B, Rate C - 0.0, 0.0 -> 143.75, 143.75
% INFO    : Updated Thermal Rating: on line 13285-10105 : Rate B, Rate C - 0.0, 0.0 -> 211.98, 211.98
% INFO    : Updated Thermal Rating: on line 10106-10215 : Rate B, Rate C - 0.0, 0.0 -> 212.58, 212.58
% INFO    : Updated Thermal Rating: on line 10108-10186 : Rate B, Rate C - 0.0, 0.0 -> 249.27, 249.27
% INFO    : Updated Thermal Rating: on line 10203-10108 : Rate B, Rate C - 0.0, 0.0 -> 235.31, 235.31
% INFO    : Updated Thermal Rating: on line 10111-10213 : Rate B, Rate C - 0.0, 0.0 -> 236.86, 236.86
% INFO    : Updated Thermal Rating: on line 10113-10128 : Rate B, Rate C - 0.0, 0.0 -> 216.3, 216.3
% INFO    : Updated Thermal Rating: on line 10128-10115 : Rate B, Rate C - 0.0, 0.0 -> 234.53, 234.53
% INFO    : Updated Thermal Rating: on line 10140-10115 : Rate B, Rate C - 0.0, 0.0 -> 212.47, 212.47
% INFO    : Updated Thermal Rating: on line 10118-10116 : Rate B, Rate C - 0.0, 0.0 -> 188.83, 188.83
% INFO    : Updated Thermal Rating: on line 10116-10397 : Rate B, Rate C - 0.0, 0.0 -> 221.58, 221.58
% INFO    : Updated Thermal Rating: on line 10116-10795 : Rate B, Rate C - 0.0, 0.0 -> 245.76, 245.76
% INFO    : Updated Thermal Rating: on transformer 10117-10120 : Rate B, Rate C - 0.0, 0.0 -> 577.61, 577.61
% INFO    : Updated Thermal Rating: on line 10275-10117 : Rate B, Rate C - 0.0, 0.0 -> 1345.52, 1345.52
% INFO    : Updated Thermal Rating: on line 10799-10117 : Rate B, Rate C - 0.0, 0.0 -> 1180.81, 1180.81
% INFO    : Updated Thermal Rating: on line 10893-10117 : Rate B, Rate C - 0.0, 0.0 -> 1332.36, 1332.36
% INFO    : Updated Thermal Rating: on transformer 10118-10120 : Rate B, Rate C - 0.0, 0.0 -> 452.61, 452.61
% INFO    : Updated Thermal Rating: on line 10118-10186 : Rate B, Rate C - 0.0, 0.0 -> 266.6, 266.6
% INFO    : Updated Thermal Rating: on line 10118-10244 : Rate B, Rate C - 0.0, 0.0 -> 246.49, 246.49
% INFO    : Updated Thermal Rating: on line 10118-10300 : Rate B, Rate C - 0.0, 0.0 -> 238.95, 238.95
% INFO    : Updated Thermal Rating: on transformer 10119-10120 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 10121-10124 : Rate B, Rate C - 0.0, 0.0 -> 179.57, 179.57
% INFO    : Updated Thermal Rating: on line 10121-10325 : Rate B, Rate C - 0.0, 0.0 -> 208.42, 208.42
% INFO    : Updated Thermal Rating: on transformer 10128-10127 : Rate B, Rate C - 0.0, 0.0 -> 562.17, 562.17
% INFO    : Updated Thermal Rating: on line 10127-10730 : Rate B, Rate C - 0.0, 0.0 -> 1116.83, 1116.83
% INFO    : Updated Thermal Rating: on line 10838-10127 : Rate B, Rate C - 0.0, 0.0 -> 1195.62, 1195.62
% INFO    : Updated Thermal Rating: on line 10128-10138 : Rate B, Rate C - 0.0, 0.0 -> 239.6, 239.6
% INFO    : Updated Thermal Rating: on line 10129-13285 : Rate B, Rate C - 0.0, 0.0 -> 221.18, 221.18
% INFO    : Updated Thermal Rating: on line 10129-13310 : Rate B, Rate C - 0.0, 0.0 -> 239.02, 239.02
% INFO    : Updated Thermal Rating: on line 13314-10129 : Rate B, Rate C - 0.0, 0.0 -> 231.06, 231.06
% INFO    : Updated Thermal Rating: on line 10130-10147 : Rate B, Rate C - 0.0, 0.0 -> 223.05, 223.05
% INFO    : Updated Thermal Rating: on line 13312-10130 : Rate B, Rate C - 0.0, 0.0 -> 182.98, 182.98
% INFO    : Updated Thermal Rating: on line 10178-10131 : Rate B, Rate C - 0.0, 0.0 -> 203.57, 203.57
% INFO    : Updated Thermal Rating: on line 10131-13300 : Rate B, Rate C - 0.0, 0.0 -> 225.61, 225.61
% INFO    : Updated Thermal Rating: on line 10136-10210 : Rate B, Rate C - 0.0, 0.0 -> 202.01, 202.01
% INFO    : Updated Thermal Rating: on line 10136-11028 : Rate B, Rate C - 0.0, 0.0 -> 264.49, 264.49
% INFO    : Updated Thermal Rating: on line 10138-10199 : Rate B, Rate C - 0.0, 0.0 -> 220.87, 220.87
% INFO    : Updated Thermal Rating: on line 10139-10154 : Rate B, Rate C - 0.0, 0.0 -> 278.91, 278.91
% INFO    : Updated Thermal Rating: on line 10139-10154 : Rate B, Rate C - 0.0, 0.0 -> 278.91, 278.91
% INFO    : Updated Thermal Rating: on line 10197-10139 : Rate B, Rate C - 0.0, 0.0 -> 280.99, 280.99
% INFO    : Updated Thermal Rating: on line 10197-10139 : Rate B, Rate C - 0.0, 0.0 -> 280.99, 280.99
% INFO    : Updated Thermal Rating: on line 10140-10143 : Rate B, Rate C - 0.0, 0.0 -> 232.49, 232.49
% INFO    : Updated Thermal Rating: on line 10160-10143 : Rate B, Rate C - 0.0, 0.0 -> 198.54, 198.54
% INFO    : Updated Thermal Rating: on line 10145-10190 : Rate B, Rate C - 0.0, 0.0 -> 242.1, 242.1
% INFO    : Updated Thermal Rating: on line 10145-10193 : Rate B, Rate C - 0.0, 0.0 -> 214.7, 214.7
% INFO    : Updated Thermal Rating: on line 10193-10147 : Rate B, Rate C - 0.0, 0.0 -> 246.47, 246.47
% INFO    : Updated Thermal Rating: on transformer 10149-10152 : Rate B, Rate C - 0.0, 0.0 -> 203.15, 203.15
% INFO    : Updated Thermal Rating: on transformer 10150-10152 : Rate B, Rate C - 0.0, 0.0 -> 101.57, 101.57
% INFO    : Updated Thermal Rating: on transformer 10151-10152 : Rate B, Rate C - 0.0, 0.0 -> 101.57, 101.57
% INFO    : Updated Thermal Rating: on line 10153-10164 : Rate B, Rate C - 0.0, 0.0 -> 204.81, 204.81
% INFO    : Updated Thermal Rating: on line 10154-10184 : Rate B, Rate C - 0.0, 0.0 -> 274.37, 274.37
% INFO    : Updated Thermal Rating: on line 10155-10164 : Rate B, Rate C - 0.0, 0.0 -> 205.94, 205.94
% INFO    : Updated Thermal Rating: on line 10158-10159 : Rate B, Rate C - 0.0, 0.0 -> 155.28, 155.28
% INFO    : Updated Thermal Rating: on line 10158-10184 : Rate B, Rate C - 0.0, 0.0 -> 249.59, 249.59
% INFO    : Updated Thermal Rating: on line 10220-10158 : Rate B, Rate C - 0.0, 0.0 -> 232.9, 232.9
% INFO    : Updated Thermal Rating: on line 10208-10159 : Rate B, Rate C - 0.0, 0.0 -> 198.66, 198.66
% INFO    : Updated Thermal Rating: on line 10160-10272 : Rate B, Rate C - 0.0, 0.0 -> 218.11, 218.11
% INFO    : Updated Thermal Rating: on line 10235-10163 : Rate B, Rate C - 0.0, 0.0 -> 209.35, 209.35
% INFO    : Updated Thermal Rating: on line 10164-10169 : Rate B, Rate C - 0.0, 0.0 -> 200.65, 200.65
% INFO    : Updated Thermal Rating: on line 10199-10165 : Rate B, Rate C - 0.0, 0.0 -> 198.41, 198.41
% INFO    : Updated Thermal Rating: on line 10165-10250 : Rate B, Rate C - 0.0, 0.0 -> 212.61, 212.61
% INFO    : Updated Thermal Rating: on line 10167-11049 : Rate B, Rate C - 0.0, 0.0 -> 192.01, 192.01
% INFO    : Updated Thermal Rating: on line 10167-13301 : Rate B, Rate C - 0.0, 0.0 -> 233.51, 233.51
% INFO    : Updated Thermal Rating: on line 10167-13303 : Rate B, Rate C - 0.0, 0.0 -> 317.46, 317.46
% INFO    : Updated Thermal Rating: on line 10167-13304 : Rate B, Rate C - 0.0, 0.0 -> 328.09, 328.09
% INFO    : Updated Thermal Rating: on line 10168-10761 : Rate B, Rate C - 0.0, 0.0 -> 216.0, 216.0
% INFO    : Updated Thermal Rating: on line 10168-13337 : Rate B, Rate C - 0.0, 0.0 -> 183.11, 183.11
% INFO    : Updated Thermal Rating: on line 10168-13347 : Rate B, Rate C - 0.0, 0.0 -> 190.92, 190.92
% INFO    : Updated Thermal Rating: on line 10169-10837 : Rate B, Rate C - 0.0, 0.0 -> 175.4, 175.4
% INFO    : Updated Thermal Rating: on line 10250-10171 : Rate B, Rate C - 0.0, 0.0 -> 250.33, 250.33
% INFO    : Updated Thermal Rating: on line 10258-10171 : Rate B, Rate C - 0.0, 0.0 -> 196.79, 196.79
% INFO    : Updated Thermal Rating: on line 10171-10298 : Rate B, Rate C - 0.0, 0.0 -> 208.89, 208.89
% INFO    : Updated Thermal Rating: on line 10171-10839 : Rate B, Rate C - 0.0, 0.0 -> 267.61, 267.61
% INFO    : Updated Thermal Rating: on line 10190-10173 : Rate B, Rate C - 0.0, 0.0 -> 217.23, 217.23
% INFO    : Updated Thermal Rating: on line 10173-10935 : Rate B, Rate C - 0.0, 0.0 -> 271.37, 271.37
% INFO    : Updated Thermal Rating: on line 10176-10741 : Rate B, Rate C - 0.0, 0.0 -> 243.05, 243.05
% INFO    : Updated Thermal Rating: on line 10177-13289 : Rate B, Rate C - 0.0, 0.0 -> 214.87, 214.87
% INFO    : Updated Thermal Rating: on line 10177-13300 : Rate B, Rate C - 0.0, 0.0 -> 246.31, 246.31
% INFO    : Updated Thermal Rating: on line 13303-10177 : Rate B, Rate C - 0.0, 0.0 -> 272.58, 272.58
% INFO    : Updated Thermal Rating: on line 10193-10178 : Rate B, Rate C - 0.0, 0.0 -> 233.36, 233.36
% INFO    : Updated Thermal Rating: on line 10210-10179 : Rate B, Rate C - 0.0, 0.0 -> 189.73, 189.73
% INFO    : Updated Thermal Rating: on line 10923-10179 : Rate B, Rate C - 0.0, 0.0 -> 237.41, 237.41
% INFO    : Updated Thermal Rating: on line 10181-10785 : Rate B, Rate C - 0.0, 0.0 -> 204.3, 204.3
% INFO    : Updated Thermal Rating: on line 11028-10181 : Rate B, Rate C - 0.0, 0.0 -> 215.84, 215.84
% INFO    : Updated Thermal Rating: on line 10251-10183 : Rate B, Rate C - 0.0, 0.0 -> 192.21, 192.21
% INFO    : Updated Thermal Rating: on line 10183-10839 : Rate B, Rate C - 0.0, 0.0 -> 235.12, 235.12
% INFO    : Updated Thermal Rating: on line 10189-10213 : Rate B, Rate C - 0.0, 0.0 -> 226.53, 226.53
% INFO    : Updated Thermal Rating: on line 10189-10843 : Rate B, Rate C - 0.0, 0.0 -> 174.23, 174.23
% INFO    : Updated Thermal Rating: on line 10190-10476 : Rate B, Rate C - 0.0, 0.0 -> 256.51, 256.51
% INFO    : Updated Thermal Rating: on transformer 10192-10195 : Rate B, Rate C - 0.0, 0.0 -> 556.65, 556.65
% INFO    : Updated Thermal Rating: on line 10192-10813 : Rate B, Rate C - 0.0, 0.0 -> 1215.9, 1215.9
% INFO    : Updated Thermal Rating: on line 10192-11001 : Rate B, Rate C - 0.0, 0.0 -> 1396.92, 1396.92
% INFO    : Updated Thermal Rating: on line 10192-13180 : Rate B, Rate C - 0.0, 0.0 -> 1182.41, 1182.41
% INFO    : Updated Thermal Rating: on line 13302-10192 : Rate B, Rate C - 0.0, 0.0 -> 1341.36, 1341.36
% INFO    : Updated Thermal Rating: on transformer 10193-10195 : Rate B, Rate C - 0.0, 0.0 -> 456.65, 456.65
% INFO    : Updated Thermal Rating: on transformer 10194-10195 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 10197-10196 : Rate B, Rate C - 0.0, 0.0 -> 499.64, 499.64
% INFO    : Updated Thermal Rating: on line 10196-10735 : Rate B, Rate C - 0.0, 0.0 -> 1224.4, 1224.4
% INFO    : Updated Thermal Rating: on line 10838-10196 : Rate B, Rate C - 0.0, 0.0 -> 1215.99, 1215.99
% INFO    : Updated Thermal Rating: on line 10196-10857 : Rate B, Rate C - 0.0, 0.0 -> 1224.13, 1224.13
% INFO    : Updated Thermal Rating: on line 10200-10207 : Rate B, Rate C - 0.0, 0.0 -> 207.09, 207.09
% INFO    : Updated Thermal Rating: on line 10200-10251 : Rate B, Rate C - 0.0, 0.0 -> 243.71, 243.71
% INFO    : Updated Thermal Rating: on line 10280-10201 : Rate B, Rate C - 0.0, 0.0 -> 194.09, 194.09
% INFO    : Updated Thermal Rating: on line 10888-10201 : Rate B, Rate C - 0.0, 0.0 -> 233.17, 233.17
% INFO    : Updated Thermal Rating: on line 10238-10202 : Rate B, Rate C - 0.0, 0.0 -> 221.12, 221.12
% INFO    : Updated Thermal Rating: on line 10202-10761 : Rate B, Rate C - 0.0, 0.0 -> 236.99, 236.99
% INFO    : Updated Thermal Rating: on line 10218-10203 : Rate B, Rate C - 0.0, 0.0 -> 225.99, 225.99
% INFO    : Updated Thermal Rating: on line 10248-10203 : Rate B, Rate C - 0.0, 0.0 -> 230.26, 230.26
% INFO    : Updated Thermal Rating: on line 10205-10226 : Rate B, Rate C - 0.0, 0.0 -> 203.06, 203.06
% INFO    : Updated Thermal Rating: on line 10205-10365 : Rate B, Rate C - 0.0, 0.0 -> 235.4, 235.4
% INFO    : Updated Thermal Rating: on line 10207-10220 : Rate B, Rate C - 0.0, 0.0 -> 201.79, 201.79
% INFO    : Updated Thermal Rating: on line 10208-10839 : Rate B, Rate C - 0.0, 0.0 -> 220.1, 220.1
% INFO    : Updated Thermal Rating: on line 10224-10209 : Rate B, Rate C - 0.0, 0.0 -> 236.08, 236.08
% INFO    : Updated Thermal Rating: on line 10209-10290 : Rate B, Rate C - 0.0, 0.0 -> 203.02, 203.02
% INFO    : Updated Thermal Rating: on line 10212-10210 : Rate B, Rate C - 0.0, 0.0 -> 203.4, 203.4
% INFO    : Updated Thermal Rating: on line 10785-10212 : Rate B, Rate C - 0.0, 0.0 -> 240.36, 240.36
% INFO    : Updated Thermal Rating: on line 10693-10213 : Rate B, Rate C - 0.0, 0.0 -> 223.19, 223.19
% INFO    : Updated Thermal Rating: on line 10213-10863 : Rate B, Rate C - 0.0, 0.0 -> 249.12, 249.12
% INFO    : Updated Thermal Rating: on line 10215-10216 : Rate B, Rate C - 0.0, 0.0 -> 254.06, 254.06
% INFO    : Updated Thermal Rating: on line 10894-10215 : Rate B, Rate C - 0.0, 0.0 -> 250.76, 250.76
% INFO    : Updated Thermal Rating: on line 10216-10222 : Rate B, Rate C - 0.0, 0.0 -> 214.35, 214.35
% INFO    : Updated Thermal Rating: on line 10785-10216 : Rate B, Rate C - 0.0, 0.0 -> 275.02, 275.02
% INFO    : Updated Thermal Rating: on line 10218-10235 : Rate B, Rate C - 0.0, 0.0 -> 211.45, 211.45
% INFO    : Updated Thermal Rating: on line 10248-10218 : Rate B, Rate C - 0.0, 0.0 -> 194.39, 194.39
% INFO    : Updated Thermal Rating: on line 10286-10221 : Rate B, Rate C - 0.0, 0.0 -> 224.79, 224.79
% INFO    : Updated Thermal Rating: on line 10221-10295 : Rate B, Rate C - 0.0, 0.0 -> 252.74, 252.74
% INFO    : Updated Thermal Rating: on line 10365-10221 : Rate B, Rate C - 0.0, 0.0 -> 298.73, 298.73
% INFO    : Updated Thermal Rating: on line 10222-10888 : Rate B, Rate C - 0.0, 0.0 -> 221.33, 221.33
% INFO    : Updated Thermal Rating: on line 10224-10837 : Rate B, Rate C - 0.0, 0.0 -> 254.38, 254.38
% INFO    : Updated Thermal Rating: on line 10226-10247 : Rate B, Rate C - 0.0, 0.0 -> 197.96, 197.96
% INFO    : Updated Thermal Rating: on line 10235-10227 : Rate B, Rate C - 0.0, 0.0 -> 201.11, 201.11
% INFO    : Updated Thermal Rating: on line 10319-10228 : Rate B, Rate C - 0.0, 0.0 -> 222.9, 222.9
% INFO    : Updated Thermal Rating: on line 10228-10383 : Rate B, Rate C - 0.0, 0.0 -> 255.14, 255.14
% INFO    : Updated Thermal Rating: on line 10229-10284 : Rate B, Rate C - 0.0, 0.0 -> 234.23, 234.23
% INFO    : Updated Thermal Rating: on line 10229-10374 : Rate B, Rate C - 0.0, 0.0 -> 208.28, 208.28
% INFO    : Updated Thermal Rating: on line 10365-10230 : Rate B, Rate C - 0.0, 0.0 -> 178.77, 178.77
% INFO    : Updated Thermal Rating: on line 10230-10736 : Rate B, Rate C - 0.0, 0.0 -> 231.05, 231.05
% INFO    : Updated Thermal Rating: on line 10231-10251 : Rate B, Rate C - 0.0, 0.0 -> 269.59, 269.59
% INFO    : Updated Thermal Rating: on line 10231-10736 : Rate B, Rate C - 0.0, 0.0 -> 278.29, 278.29
% INFO    : Updated Thermal Rating: on line 10231-10736 : Rate B, Rate C - 0.0, 0.0 -> 278.29, 278.29
% INFO    : Updated Thermal Rating: on line 10298-10232 : Rate B, Rate C - 0.0, 0.0 -> 237.87, 237.87
% INFO    : Updated Thermal Rating: on line 10364-10232 : Rate B, Rate C - 0.0, 0.0 -> 264.24, 264.24
% INFO    : Updated Thermal Rating: on line 10233-10242 : Rate B, Rate C - 0.0, 0.0 -> 188.65, 188.65
% INFO    : Updated Thermal Rating: on line 10233-10309 : Rate B, Rate C - 0.0, 0.0 -> 226.47, 226.47
% INFO    : Updated Thermal Rating: on line 10315-10233 : Rate B, Rate C - 0.0, 0.0 -> 205.35, 205.35
% INFO    : Updated Thermal Rating: on line 10238-10237 : Rate B, Rate C - 0.0, 0.0 -> 187.93, 187.93
% INFO    : Updated Thermal Rating: on line 10237-13350 : Rate B, Rate C - 0.0, 0.0 -> 209.4, 209.4
% INFO    : Updated Thermal Rating: on line 10284-10240 : Rate B, Rate C - 0.0, 0.0 -> 184.59, 184.59
% INFO    : Updated Thermal Rating: on line 10240-10306 : Rate B, Rate C - 0.0, 0.0 -> 222.27, 222.27
% INFO    : Updated Thermal Rating: on line 10260-10241 : Rate B, Rate C - 0.0, 0.0 -> 190.4, 190.4
% INFO    : Updated Thermal Rating: on line 10241-10322 : Rate B, Rate C - 0.0, 0.0 -> 216.88, 216.88
% INFO    : Updated Thermal Rating: on line 10270-10242 : Rate B, Rate C - 0.0, 0.0 -> 229.88, 229.88
% INFO    : Updated Thermal Rating: on line 10244-10246 : Rate B, Rate C - 0.0, 0.0 -> 213.28, 213.28
% INFO    : Updated Thermal Rating: on line 10777-10244 : Rate B, Rate C - 0.0, 0.0 -> 246.44, 246.44
% INFO    : Updated Thermal Rating: on line 10246-10894 : Rate B, Rate C - 0.0, 0.0 -> 238.67, 238.67
% INFO    : Updated Thermal Rating: on line 10247-10367 : Rate B, Rate C - 0.0, 0.0 -> 247.88, 247.88
% INFO    : Updated Thermal Rating: on line 10247-10843 : Rate B, Rate C - 0.0, 0.0 -> 271.29, 271.29
% INFO    : Updated Thermal Rating: on line 10249-10291 : Rate B, Rate C - 0.0, 0.0 -> 192.75, 192.75
% INFO    : Updated Thermal Rating: on line 10315-10249 : Rate B, Rate C - 0.0, 0.0 -> 222.2, 222.2
% INFO    : Updated Thermal Rating: on line 10321-10249 : Rate B, Rate C - 0.0, 0.0 -> 175.98, 175.98
% INFO    : Updated Thermal Rating: on line 10251-10258 : Rate B, Rate C - 0.0, 0.0 -> 188.91, 188.91
% INFO    : Updated Thermal Rating: on line 10253-10314 : Rate B, Rate C - 0.0, 0.0 -> 213.67, 213.67
% INFO    : Updated Thermal Rating: on line 10253-10415 : Rate B, Rate C - 0.0, 0.0 -> 237.0, 237.0
% INFO    : Updated Thermal Rating: on line 10313-10255 : Rate B, Rate C - 0.0, 0.0 -> 197.88, 197.88
% INFO    : Updated Thermal Rating: on line 10255-10374 : Rate B, Rate C - 0.0, 0.0 -> 198.63, 198.63
% INFO    : Updated Thermal Rating: on line 10373-10259 : Rate B, Rate C - 0.0, 0.0 -> 205.47, 205.47
% INFO    : Updated Thermal Rating: on line 10259-10839 : Rate B, Rate C - 0.0, 0.0 -> 209.97, 209.97
% INFO    : Updated Thermal Rating: on line 10318-10260 : Rate B, Rate C - 0.0, 0.0 -> 221.51, 221.51
% INFO    : Updated Thermal Rating: on line 10261-10270 : Rate B, Rate C - 0.0, 0.0 -> 234.19, 234.19
% INFO    : Updated Thermal Rating: on line 10261-10272 : Rate B, Rate C - 0.0, 0.0 -> 179.66, 179.66
% INFO    : Updated Thermal Rating: on line 10777-10263 : Rate B, Rate C - 0.0, 0.0 -> 195.36, 195.36
% INFO    : Updated Thermal Rating: on line 10263-10795 : Rate B, Rate C - 0.0, 0.0 -> 225.99, 225.99
% INFO    : Updated Thermal Rating: on line 10319-10265 : Rate B, Rate C - 0.0, 0.0 -> 180.99, 180.99
% INFO    : Updated Thermal Rating: on line 10265-10323 : Rate B, Rate C - 0.0, 0.0 -> 223.06, 223.06
% INFO    : Updated Thermal Rating: on line 10378-10267 : Rate B, Rate C - 0.0, 0.0 -> 248.14, 248.14
% INFO    : Updated Thermal Rating: on line 10267-10814 : Rate B, Rate C - 0.0, 0.0 -> 258.79, 258.79
% INFO    : Updated Thermal Rating: on line 10326-10268 : Rate B, Rate C - 0.0, 0.0 -> 212.27, 212.27
% INFO    : Updated Thermal Rating: on line 10268-10341 : Rate B, Rate C - 0.0, 0.0 -> 219.74, 219.74
% INFO    : Updated Thermal Rating: on line 10268-10368 : Rate B, Rate C - 0.0, 0.0 -> 224.03, 224.03
% INFO    : Updated Thermal Rating: on line 10401-10268 : Rate B, Rate C - 0.0, 0.0 -> 165.81, 165.81
% INFO    : Updated Thermal Rating: on line 10270-10409 : Rate B, Rate C - 0.0, 0.0 -> 275.36, 275.36
% INFO    : Updated Thermal Rating: on line 10270-10409 : Rate B, Rate C - 0.0, 0.0 -> 275.36, 275.36
% INFO    : Updated Thermal Rating: on line 10272-10334 : Rate B, Rate C - 0.0, 0.0 -> 249.79, 249.79
% INFO    : Updated Thermal Rating: on line 10273-10291 : Rate B, Rate C - 0.0, 0.0 -> 235.4, 235.4
% INFO    : Updated Thermal Rating: on line 10334-10273 : Rate B, Rate C - 0.0, 0.0 -> 264.84, 264.84
% INFO    : Updated Thermal Rating: on line 10329-10274 : Rate B, Rate C - 0.0, 0.0 -> 231.76, 231.76
% INFO    : Updated Thermal Rating: on line 10274-10408 : Rate B, Rate C - 0.0, 0.0 -> 246.0, 246.0
% INFO    : Updated Thermal Rating: on transformer 10276-10275 : Rate B, Rate C - 0.0, 0.0 -> 614.72, 614.72
% INFO    : Updated Thermal Rating: on transformer 10276-10275 : Rate B, Rate C - 0.0, 0.0 -> 614.72, 614.72
% INFO    : Updated Thermal Rating: on transformer 10276-10275 : Rate B, Rate C - 0.0, 0.0 -> 614.72, 614.72
% INFO    : Updated Thermal Rating: on line 10275-10330 : Rate B, Rate C - 0.0, 0.0 -> 1189.39, 1189.39
% INFO    : Updated Thermal Rating: on line 10369-10275 : Rate B, Rate C - 0.0, 0.0 -> 1199.54, 1199.54
% INFO    : Updated Thermal Rating: on line 10427-10275 : Rate B, Rate C - 0.0, 0.0 -> 1106.35, 1106.35
% INFO    : Updated Thermal Rating: on line 10275-10758 : Rate B, Rate C - 0.0, 0.0 -> 1303.32, 1303.32
% INFO    : Updated Thermal Rating: on line 10276-10308 : Rate B, Rate C - 0.0, 0.0 -> 250.53, 250.53
% INFO    : Updated Thermal Rating: on line 10357-10276 : Rate B, Rate C - 0.0, 0.0 -> 286.52, 286.52
% INFO    : Updated Thermal Rating: on line 10357-10276 : Rate B, Rate C - 0.0, 0.0 -> 286.52, 286.52
% INFO    : Updated Thermal Rating: on line 10357-10276 : Rate B, Rate C - 0.0, 0.0 -> 286.52, 286.52
% INFO    : Updated Thermal Rating: on line 10276-10386 : Rate B, Rate C - 0.0, 0.0 -> 258.9, 258.9
% INFO    : Updated Thermal Rating: on line 10403-10276 : Rate B, Rate C - 0.0, 0.0 -> 269.72, 269.72
% INFO    : Updated Thermal Rating: on line 10276-10489 : Rate B, Rate C - 0.0, 0.0 -> 242.43, 242.43
% INFO    : Updated Thermal Rating: on line 10325-10277 : Rate B, Rate C - 0.0, 0.0 -> 231.69, 231.69
% INFO    : Updated Thermal Rating: on line 10386-10277 : Rate B, Rate C - 0.0, 0.0 -> 239.04, 239.04
% INFO    : Updated Thermal Rating: on line 10388-10277 : Rate B, Rate C - 0.0, 0.0 -> 214.02, 214.02
% INFO    : Updated Thermal Rating: on line 10457-10280 : Rate B, Rate C - 0.0, 0.0 -> 196.81, 196.81
% INFO    : Updated Thermal Rating: on line 10280-10785 : Rate B, Rate C - 0.0, 0.0 -> 159.86, 159.86
% INFO    : Updated Thermal Rating: on line 10284-10331 : Rate B, Rate C - 0.0, 0.0 -> 256.9, 256.9
% INFO    : Updated Thermal Rating: on line 10422-10285 : Rate B, Rate C - 0.0, 0.0 -> 180.38, 180.38
% INFO    : Updated Thermal Rating: on line 10285-10424 : Rate B, Rate C - 0.0, 0.0 -> 235.43, 235.43
% INFO    : Updated Thermal Rating: on line 10454-10285 : Rate B, Rate C - 0.0, 0.0 -> 223.7, 223.7
% INFO    : Updated Thermal Rating: on line 10286-10287 : Rate B, Rate C - 0.0, 0.0 -> 250.61, 250.61
% INFO    : Updated Thermal Rating: on line 10361-10286 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 10286-10736 : Rate B, Rate C - 0.0, 0.0 -> 293.02, 293.02
% INFO    : Updated Thermal Rating: on line 10286-10736 : Rate B, Rate C - 0.0, 0.0 -> 293.02, 293.02
% INFO    : Updated Thermal Rating: on line 10286-10736 : Rate B, Rate C - 0.0, 0.0 -> 293.02, 293.02
% INFO    : Updated Thermal Rating: on line 10287-10297 : Rate B, Rate C - 0.0, 0.0 -> 219.89, 219.89
% INFO    : Updated Thermal Rating: on line 10289-10345 : Rate B, Rate C - 0.0, 0.0 -> 210.64, 210.64
% INFO    : Updated Thermal Rating: on line 10289-10837 : Rate B, Rate C - 0.0, 0.0 -> 233.49, 233.49
% INFO    : Updated Thermal Rating: on line 10361-10290 : Rate B, Rate C - 0.0, 0.0 -> 228.59, 228.59
% INFO    : Updated Thermal Rating: on line 10293-10416 : Rate B, Rate C - 0.0, 0.0 -> 196.42, 196.42
% INFO    : Updated Thermal Rating: on line 10293-10475 : Rate B, Rate C - 0.0, 0.0 -> 219.06, 219.06
% INFO    : Updated Thermal Rating: on line 10364-10295 : Rate B, Rate C - 0.0, 0.0 -> 219.16, 219.16
% INFO    : Updated Thermal Rating: on line 10297-10373 : Rate B, Rate C - 0.0, 0.0 -> 213.39, 213.39
% INFO    : Updated Thermal Rating: on line 10297-10417 : Rate B, Rate C - 0.0, 0.0 -> 226.81, 226.81
% INFO    : Updated Thermal Rating: on line 10380-10300 : Rate B, Rate C - 0.0, 0.0 -> 205.95, 205.95
% INFO    : Updated Thermal Rating: on line 10397-10300 : Rate B, Rate C - 0.0, 0.0 -> 183.06, 183.06
% INFO    : Updated Thermal Rating: on line 10303-10356 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 10303-10403 : Rate B, Rate C - 0.0, 0.0 -> 257.81, 257.81
% INFO    : Updated Thermal Rating: on line 10303-10467 : Rate B, Rate C - 0.0, 0.0 -> 256.77, 256.77
% INFO    : Updated Thermal Rating: on line 10306-10317 : Rate B, Rate C - 0.0, 0.0 -> 257.55, 257.55
% INFO    : Updated Thermal Rating: on line 10308-10356 : Rate B, Rate C - 0.0, 0.0 -> 221.36, 221.36
% INFO    : Updated Thermal Rating: on line 10318-10309 : Rate B, Rate C - 0.0, 0.0 -> 280.86, 280.86
% INFO    : Updated Thermal Rating: on line 10318-10309 : Rate B, Rate C - 0.0, 0.0 -> 280.86, 280.86
% INFO    : Updated Thermal Rating: on line 10309-10323 : Rate B, Rate C - 0.0, 0.0 -> 266.32, 266.32
% INFO    : Updated Thermal Rating: on line 10310-10326 : Rate B, Rate C - 0.0, 0.0 -> 166.03, 166.03
% INFO    : Updated Thermal Rating: on line 10375-10310 : Rate B, Rate C - 0.0, 0.0 -> 218.27, 218.27
% INFO    : Updated Thermal Rating: on line 10313-10362 : Rate B, Rate C - 0.0, 0.0 -> 231.94, 231.94
% INFO    : Updated Thermal Rating: on line 10314-10418 : Rate B, Rate C - 0.0, 0.0 -> 183.16, 183.16
% INFO    : Updated Thermal Rating: on line 10315-10467 : Rate B, Rate C - 0.0, 0.0 -> 237.1, 237.1
% INFO    : Updated Thermal Rating: on line 10331-10317 : Rate B, Rate C - 0.0, 0.0 -> 274.18, 274.18
% INFO    : Updated Thermal Rating: on line 10409-10318 : Rate B, Rate C - 0.0, 0.0 -> 287.44, 287.44
% INFO    : Updated Thermal Rating: on line 10409-10318 : Rate B, Rate C - 0.0, 0.0 -> 287.44, 287.44
% INFO    : Updated Thermal Rating: on line 10409-10318 : Rate B, Rate C - 0.0, 0.0 -> 287.44, 287.44
% INFO    : Updated Thermal Rating: on line 10323-10321 : Rate B, Rate C - 0.0, 0.0 -> 211.07, 211.07
% INFO    : Updated Thermal Rating: on line 10322-10331 : Rate B, Rate C - 0.0, 0.0 -> 265.31, 265.31
% INFO    : Updated Thermal Rating: on line 10329-10338 : Rate B, Rate C - 0.0, 0.0 -> 176.01, 176.01
% INFO    : Updated Thermal Rating: on transformer 10331-10330 : Rate B, Rate C - 0.0, 0.0 -> 594.3, 594.3
% INFO    : Updated Thermal Rating: on transformer 10331-10330 : Rate B, Rate C - 0.0, 0.0 -> 594.3, 594.3
% INFO    : Updated Thermal Rating: on transformer 10331-10330 : Rate B, Rate C - 0.0, 0.0 -> 594.3, 594.3
% INFO    : Updated Thermal Rating: on line 10353-10330 : Rate B, Rate C - 0.0, 0.0 -> 1192.38, 1192.38
% INFO    : Updated Thermal Rating: on line 10468-10330 : Rate B, Rate C - 0.0, 0.0 -> 1204.83, 1204.83
% INFO    : Updated Thermal Rating: on line 10383-10331 : Rate B, Rate C - 0.0, 0.0 -> 285.46, 285.46
% INFO    : Updated Thermal Rating: on line 10383-10331 : Rate B, Rate C - 0.0, 0.0 -> 285.46, 285.46
% INFO    : Updated Thermal Rating: on line 10383-10331 : Rate B, Rate C - 0.0, 0.0 -> 285.46, 285.46
% INFO    : Updated Thermal Rating: on transformer 10334-10333 : Rate B, Rate C - 0.0, 0.0 -> 509.39, 509.39
% INFO    : Updated Thermal Rating: on line 10333-10427 : Rate B, Rate C - 0.0, 0.0 -> 1137.85, 1137.85
% INFO    : Updated Thermal Rating: on line 10459-10333 : Rate B, Rate C - 0.0, 0.0 -> 1110.9, 1110.9
% INFO    : Updated Thermal Rating: on transformer 10334-10337 : Rate B, Rate C - 0.0, 0.0 -> 108.33, 108.33
% INFO    : Updated Thermal Rating: on line 10334-10339 : Rate B, Rate C - 0.0, 0.0 -> 207.73, 207.73
% INFO    : Updated Thermal Rating: on transformer 10335-10337 : Rate B, Rate C - 0.0, 0.0 -> 54.16, 54.16
% INFO    : Updated Thermal Rating: on transformer 10336-10337 : Rate B, Rate C - 0.0, 0.0 -> 54.16, 54.16
% INFO    : Updated Thermal Rating: on line 10338-10431 : Rate B, Rate C - 0.0, 0.0 -> 242.22, 242.22
% INFO    : Updated Thermal Rating: on line 10446-10338 : Rate B, Rate C - 0.0, 0.0 -> 266.69, 266.69
% INFO    : Updated Thermal Rating: on line 10339-10401 : Rate B, Rate C - 0.0, 0.0 -> 238.41, 238.41
% INFO    : Updated Thermal Rating: on line 10357-10341 : Rate B, Rate C - 0.0, 0.0 -> 247.72, 247.72
% INFO    : Updated Thermal Rating: on line 10345-10435 : Rate B, Rate C - 0.0, 0.0 -> 235.04, 235.04
% INFO    : Updated Thermal Rating: on transformer 10346-10349 : Rate B, Rate C - 0.0, 0.0 -> 589.75, 589.75
% INFO    : Updated Thermal Rating: on transformer 10347-10349 : Rate B, Rate C - 0.0, 0.0 -> 467.64, 467.64
% INFO    : Updated Thermal Rating: on transformer 10347-10352 : Rate B, Rate C - 0.0, 0.0 -> 108.26, 108.26
% INFO    : Updated Thermal Rating: on line 10347-10422 : Rate B, Rate C - 0.0, 0.0 -> 223.13, 223.13
% INFO    : Updated Thermal Rating: on line 10347-10436 : Rate B, Rate C - 0.0, 0.0 -> 245.79, 245.79
% INFO    : Updated Thermal Rating: on transformer 10348-10349 : Rate B, Rate C - 0.0, 0.0 -> 122.11, 122.11
% INFO    : Updated Thermal Rating: on transformer 10350-10352 : Rate B, Rate C - 0.0, 0.0 -> 54.13, 54.13
% INFO    : Updated Thermal Rating: on transformer 10351-10352 : Rate B, Rate C - 0.0, 0.0 -> 54.13, 54.13
% INFO    : Updated Thermal Rating: on line 10414-10353 : Rate B, Rate C - 0.0, 0.0 -> 1237.11, 1237.11
% INFO    : Updated Thermal Rating: on line 10353-10468 : Rate B, Rate C - 0.0, 0.0 -> 1118.63, 1118.63
% INFO    : Updated Thermal Rating: on line 10354-10452 : Rate B, Rate C - 0.0, 0.0 -> 210.0, 210.0
% INFO    : Updated Thermal Rating: on line 10354-10461 : Rate B, Rate C - 0.0, 0.0 -> 219.79, 219.79
% INFO    : Updated Thermal Rating: on line 10391-10355 : Rate B, Rate C - 0.0, 0.0 -> 201.85, 201.85
% INFO    : Updated Thermal Rating: on line 10355-10454 : Rate B, Rate C - 0.0, 0.0 -> 213.37, 213.37
% INFO    : Updated Thermal Rating: on line 10411-10356 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on transformer 10357-10360 : Rate B, Rate C - 0.0, 0.0 -> 231.62, 231.62
% INFO    : Updated Thermal Rating: on line 10357-10368 : Rate B, Rate C - 0.0, 0.0 -> 253.22, 253.22
% INFO    : Updated Thermal Rating: on line 10357-10401 : Rate B, Rate C - 0.0, 0.0 -> 255.16, 255.16
% INFO    : Updated Thermal Rating: on line 10357-10473 : Rate B, Rate C - 0.0, 0.0 -> 226.1, 226.1
% INFO    : Updated Thermal Rating: on transformer 10358-10360 : Rate B, Rate C - 0.0, 0.0 -> 115.81, 115.81
% INFO    : Updated Thermal Rating: on transformer 10359-10360 : Rate B, Rate C - 0.0, 0.0 -> 115.81, 115.81
% INFO    : Updated Thermal Rating: on line 10361-10364 : Rate B, Rate C - 0.0, 0.0 -> 241.83, 241.83
% INFO    : Updated Thermal Rating: on line 10415-10362 : Rate B, Rate C - 0.0, 0.0 -> 251.79, 251.79
% INFO    : Updated Thermal Rating: on line 10367-10364 : Rate B, Rate C - 0.0, 0.0 -> 220.13, 220.13
% INFO    : Updated Thermal Rating: on line 10736-10365 : Rate B, Rate C - 0.0, 0.0 -> 277.36, 277.36
% INFO    : Updated Thermal Rating: on line 10736-10365 : Rate B, Rate C - 0.0, 0.0 -> 277.36, 277.36
% INFO    : Updated Thermal Rating: on transformer 10370-10369 : Rate B, Rate C - 0.0, 0.0 -> 552.87, 552.87
% INFO    : Updated Thermal Rating: on line 10728-10369 : Rate B, Rate C - 0.0, 0.0 -> 1145.78, 1145.78
% INFO    : Updated Thermal Rating: on line 10369-10893 : Rate B, Rate C - 0.0, 0.0 -> 1319.14, 1319.14
% INFO    : Updated Thermal Rating: on line 10398-10370 : Rate B, Rate C - 0.0, 0.0 -> 261.64, 261.64
% INFO    : Updated Thermal Rating: on line 10370-10439 : Rate B, Rate C - 0.0, 0.0 -> 234.09, 234.09
% INFO    : Updated Thermal Rating: on line 10473-10370 : Rate B, Rate C - 0.0, 0.0 -> 248.06, 248.06
% INFO    : Updated Thermal Rating: on line 10373-10415 : Rate B, Rate C - 0.0, 0.0 -> 211.47, 211.47
% INFO    : Updated Thermal Rating: on line 10374-10407 : Rate B, Rate C - 0.0, 0.0 -> 212.97, 212.97
% INFO    : Updated Thermal Rating: on line 10409-10375 : Rate B, Rate C - 0.0, 0.0 -> 213.52, 213.52
% INFO    : Updated Thermal Rating: on line 10375-10447 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on line 10377-10406 : Rate B, Rate C - 0.0, 0.0 -> 159.62, 159.62
% INFO    : Updated Thermal Rating: on line 10377-10464 : Rate B, Rate C - 0.0, 0.0 -> 233.6, 233.6
% INFO    : Updated Thermal Rating: on line 13359-10378 : Rate B, Rate C - 0.0, 0.0 -> 213.38, 213.38
% INFO    : Updated Thermal Rating: on line 10380-10471 : Rate B, Rate C - 0.0, 0.0 -> 189.03, 189.03
% INFO    : Updated Thermal Rating: on line 10439-10382 : Rate B, Rate C - 0.0, 0.0 -> 212.28, 212.28
% INFO    : Updated Thermal Rating: on line 10441-10382 : Rate B, Rate C - 0.0, 0.0 -> 174.7, 174.7
% INFO    : Updated Thermal Rating: on line 10383-10436 : Rate B, Rate C - 0.0, 0.0 -> 288.47, 288.47
% INFO    : Updated Thermal Rating: on line 10398-10388 : Rate B, Rate C - 0.0, 0.0 -> 243.35, 243.35
% INFO    : Updated Thermal Rating: on line 10390-10449 : Rate B, Rate C - 0.0, 0.0 -> 188.23, 188.23
% INFO    : Updated Thermal Rating: on line 10390-10463 : Rate B, Rate C - 0.0, 0.0 -> 214.33, 214.33
% INFO    : Updated Thermal Rating: on line 10410-10391 : Rate B, Rate C - 0.0, 0.0 -> 199.13, 199.13
% INFO    : Updated Thermal Rating: on line 10391-10465 : Rate B, Rate C - 0.0, 0.0 -> 210.8, 210.8
% INFO    : Updated Thermal Rating: on line 10415-10393 : Rate B, Rate C - 0.0, 0.0 -> 270.32, 270.32
% INFO    : Updated Thermal Rating: on line 10416-10393 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on line 10449-10394 : Rate B, Rate C - 0.0, 0.0 -> 267.11, 267.11
% INFO    : Updated Thermal Rating: on line 10394-10461 : Rate B, Rate C - 0.0, 0.0 -> 251.44, 251.44
% INFO    : Updated Thermal Rating: on line 10395-10420 : Rate B, Rate C - 0.0, 0.0 -> 229.47, 229.47
% INFO    : Updated Thermal Rating: on line 10395-10428 : Rate B, Rate C - 0.0, 0.0 -> 270.74, 270.74
% INFO    : Updated Thermal Rating: on line 10396-10409 : Rate B, Rate C - 0.0, 0.0 -> 293.55, 293.55
% INFO    : Updated Thermal Rating: on line 10396-10409 : Rate B, Rate C - 0.0, 0.0 -> 293.55, 293.55
% INFO    : Updated Thermal Rating: on line 10396-10409 : Rate B, Rate C - 0.0, 0.0 -> 293.55, 293.55
% INFO    : Updated Thermal Rating: on line 10396-10409 : Rate B, Rate C - 0.0, 0.0 -> 293.55, 293.55
% INFO    : Updated Thermal Rating: on line 10460-10396 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on line 10460-10396 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on line 10460-10396 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on line 10460-10396 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on line 10406-10431 : Rate B, Rate C - 0.0, 0.0 -> 213.5, 213.5
% INFO    : Updated Thermal Rating: on line 10407-10437 : Rate B, Rate C - 0.0, 0.0 -> 237.17, 237.17
% INFO    : Updated Thermal Rating: on line 10408-10409 : Rate B, Rate C - 0.0, 0.0 -> 290.78, 290.78
% INFO    : Updated Thermal Rating: on line 10410-10452 : Rate B, Rate C - 0.0, 0.0 -> 239.94, 239.94
% INFO    : Updated Thermal Rating: on line 10411-10428 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on line 10466-10412 : Rate B, Rate C - 0.0, 0.0 -> 219.92, 219.92
% INFO    : Updated Thermal Rating: on line 10412-10729 : Rate B, Rate C - 0.0, 0.0 -> 257.34, 257.34
% INFO    : Updated Thermal Rating: on transformer 10415-10414 : Rate B, Rate C - 0.0, 0.0 -> 537.76, 537.76
% INFO    : Updated Thermal Rating: on line 10735-10414 : Rate B, Rate C - 0.0, 0.0 -> 1312.55, 1312.55
% INFO    : Updated Thermal Rating: on line 10414-10838 : Rate B, Rate C - 0.0, 0.0 -> 1170.38, 1170.38
% INFO    : Updated Thermal Rating: on line 10416-10475 : Rate B, Rate C - 0.0, 0.0 -> 224.59, 224.59
% INFO    : Updated Thermal Rating: on line 10417-10463 : Rate B, Rate C - 0.0, 0.0 -> 253.18, 253.18
% INFO    : Updated Thermal Rating: on line 10418-10490 : Rate B, Rate C - 0.0, 0.0 -> 226.92, 226.92
% INFO    : Updated Thermal Rating: on line 10421-10420 : Rate B, Rate C - 0.0, 0.0 -> 243.2, 243.2
% INFO    : Updated Thermal Rating: on line 10420-10460 : Rate B, Rate C - 0.0, 0.0 -> 413.86, 413.86
% INFO    : Updated Thermal Rating: on line 10477-10421 : Rate B, Rate C - 0.0, 0.0 -> 215.31, 215.31
% INFO    : Updated Thermal Rating: on line 10450-10424 : Rate B, Rate C - 0.0, 0.0 -> 280.44, 280.44
% INFO    : Updated Thermal Rating: on line 10450-10424 : Rate B, Rate C - 0.0, 0.0 -> 280.44, 280.44
% INFO    : Updated Thermal Rating: on line 10424-10452 : Rate B, Rate C - 0.0, 0.0 -> 257.24, 257.24
% INFO    : Updated Thermal Rating: on line 10488-10426 : Rate B, Rate C - 0.0, 0.0 -> 210.89, 210.89
% INFO    : Updated Thermal Rating: on line 10426-10489 : Rate B, Rate C - 0.0, 0.0 -> 215.36, 215.36
% INFO    : Updated Thermal Rating: on transformer 10428-10427 : Rate B, Rate C - 0.0, 0.0 -> 483.76, 483.76
% INFO    : Updated Thermal Rating: on line 10427-10728 : Rate B, Rate C - 0.0, 0.0 -> 1263.14, 1263.14
% INFO    : Updated Thermal Rating: on line 10428-10447 : Rate B, Rate C - 0.0, 0.0 -> 316.94, 316.94
% INFO    : Updated Thermal Rating: on transformer 10433-10432 : Rate B, Rate C - 0.0, 0.0 -> 509.57, 509.57
% INFO    : Updated Thermal Rating: on line 10432-10462 : Rate B, Rate C - 0.0, 0.0 -> 1372.69, 1372.69
% INFO    : Updated Thermal Rating: on line 10432-10701 : Rate B, Rate C - 0.0, 0.0 -> 1337.31, 1337.31
% INFO    : Updated Thermal Rating: on line 10432-10735 : Rate B, Rate C - 0.0, 0.0 -> 1263.59, 1263.59
% INFO    : Updated Thermal Rating: on line 10434-10433 : Rate B, Rate C - 0.0, 0.0 -> 276.83, 276.83
% INFO    : Updated Thermal Rating: on line 10498-10433 : Rate B, Rate C - 0.0, 0.0 -> 188.28, 188.28
% INFO    : Updated Thermal Rating: on line 10434-10475 : Rate B, Rate C - 0.0, 0.0 -> 265.37, 265.37
% INFO    : Updated Thermal Rating: on line 10999-10435 : Rate B, Rate C - 0.0, 0.0 -> 249.99, 249.99
% INFO    : Updated Thermal Rating: on line 10436-10437 : Rate B, Rate C - 0.0, 0.0 -> 301.41, 301.41
% INFO    : Updated Thermal Rating: on line 10437-10454 : Rate B, Rate C - 0.0, 0.0 -> 219.74, 219.74
% INFO    : Updated Thermal Rating: on line 10441-10440 : Rate B, Rate C - 0.0, 0.0 -> 216.15, 216.15
% INFO    : Updated Thermal Rating: on line 10471-10440 : Rate B, Rate C - 0.0, 0.0 -> 252.43, 252.43
% INFO    : Updated Thermal Rating: on line 10441-10495 : Rate B, Rate C - 0.0, 0.0 -> 203.9, 203.9
% INFO    : Updated Thermal Rating: on line 10456-10443 : Rate B, Rate C - 0.0, 0.0 -> 208.97, 208.97
% INFO    : Updated Thermal Rating: on line 10443-10471 : Rate B, Rate C - 0.0, 0.0 -> 226.18, 226.18
% INFO    : Updated Thermal Rating: on line 10495-10443 : Rate B, Rate C - 0.0, 0.0 -> 239.91, 239.91
% INFO    : Updated Thermal Rating: on line 10443-10759 : Rate B, Rate C - 0.0, 0.0 -> 269.11, 269.11
% INFO    : Updated Thermal Rating: on line 10446-10458 : Rate B, Rate C - 0.0, 0.0 -> 336.64, 336.64
% INFO    : Updated Thermal Rating: on line 10449-10463 : Rate B, Rate C - 0.0, 0.0 -> 275.82, 275.82
% INFO    : Updated Thermal Rating: on line 10463-10450 : Rate B, Rate C - 0.0, 0.0 -> 292.48, 292.48
% INFO    : Updated Thermal Rating: on line 10463-10450 : Rate B, Rate C - 0.0, 0.0 -> 292.48, 292.48
% INFO    : Updated Thermal Rating: on line 10463-10450 : Rate B, Rate C - 0.0, 0.0 -> 292.48, 292.48
% INFO    : Updated Thermal Rating: on line 10490-10450 : Rate B, Rate C - 0.0, 0.0 -> 254.2, 254.2
% INFO    : Updated Thermal Rating: on line 10452-10483 : Rate B, Rate C - 0.0, 0.0 -> 212.55, 212.55
% INFO    : Updated Thermal Rating: on line 10456-11037 : Rate B, Rate C - 0.0, 0.0 -> 247.61, 247.61
% INFO    : Updated Thermal Rating: on line 11037-10457 : Rate B, Rate C - 0.0, 0.0 -> 213.66, 213.66
% INFO    : Updated Thermal Rating: on line 10458-10460 : Rate B, Rate C - 0.0, 0.0 -> 283.12, 283.12
% INFO    : Updated Thermal Rating: on line 10458-10460 : Rate B, Rate C - 0.0, 0.0 -> 283.12, 283.12
% INFO    : Updated Thermal Rating: on line 10458-10460 : Rate B, Rate C - 0.0, 0.0 -> 283.12, 283.12
% INFO    : Updated Thermal Rating: on transformer 10460-10459 : Rate B, Rate C - 0.0, 0.0 -> 650.11, 650.11
% INFO    : Updated Thermal Rating: on transformer 10460-10459 : Rate B, Rate C - 0.0, 0.0 -> 650.11, 650.11
% INFO    : Updated Thermal Rating: on transformer 10460-10459 : Rate B, Rate C - 0.0, 0.0 -> 800.0, 800.0
% INFO    : Updated Thermal Rating: on transformer 10460-10459 : Rate B, Rate C - 0.0, 0.0 -> 650.11, 650.11
% INFO    : Updated Thermal Rating: on line 10468-10459 : Rate B, Rate C - 0.0, 0.0 -> 1031.53, 1031.53
% INFO    : Updated Thermal Rating: on line 10459-10728 : Rate B, Rate C - 0.0, 0.0 -> 1226.5, 1226.5
% INFO    : Updated Thermal Rating: on line 10459-10893 : Rate B, Rate C - 0.0, 0.0 -> 1337.32, 1337.32
% INFO    : Updated Thermal Rating: on line 10459-11075 : Rate B, Rate C - 0.0, 0.0 -> 1472.07, 1472.07
% INFO    : Updated Thermal Rating: on transformer 10463-10462 : Rate B, Rate C - 0.0, 0.0 -> 641.96, 641.96
% INFO    : Updated Thermal Rating: on transformer 10463-10462 : Rate B, Rate C - 0.0, 0.0 -> 641.96, 641.96
% INFO    : Updated Thermal Rating: on transformer 10463-10462 : Rate B, Rate C - 0.0, 0.0 -> 641.96, 641.96
% INFO    : Updated Thermal Rating: on line 10462-10468 : Rate B, Rate C - 0.0, 0.0 -> 1062.79, 1062.79
% INFO    : Updated Thermal Rating: on line 10463-10486 : Rate B, Rate C - 0.0, 0.0 -> 250.94, 250.94
% INFO    : Updated Thermal Rating: on line 10464-10469 : Rate B, Rate C - 0.0, 0.0 -> 255.34, 255.34
% INFO    : Updated Thermal Rating: on line 10469-10465 : Rate B, Rate C - 0.0, 0.0 -> 240.18, 240.18
% INFO    : Updated Thermal Rating: on line 10466-10502 : Rate B, Rate C - 0.0, 0.0 -> 185.2, 185.2
% INFO    : Updated Thermal Rating: on transformer 10469-10468 : Rate B, Rate C - 0.0, 0.0 -> 501.69, 501.69
% INFO    : Updated Thermal Rating: on line 10468-10708 : Rate B, Rate C - 0.0, 0.0 -> 1533.44, 1533.44
% INFO    : Updated Thermal Rating: on line 10496-10471 : Rate B, Rate C - 0.0, 0.0 -> 250.2, 250.2
% INFO    : Updated Thermal Rating: on line 13668-10476 : Rate B, Rate C - 0.0, 0.0 -> 257.31, 257.31
% INFO    : Updated Thermal Rating: on line 10484-10477 : Rate B, Rate C - 0.0, 0.0 -> 207.63, 207.63
% INFO    : Updated Thermal Rating: on line 10505-10477 : Rate B, Rate C - 0.0, 0.0 -> 204.89, 204.89
% INFO    : Updated Thermal Rating: on line 10480-10481 : Rate B, Rate C - 0.0, 0.0 -> 227.98, 227.98
% INFO    : Updated Thermal Rating: on line 10480-10952 : Rate B, Rate C - 0.0, 0.0 -> 246.69, 246.69
% INFO    : Updated Thermal Rating: on line 10484-10481 : Rate B, Rate C - 0.0, 0.0 -> 204.16, 204.16
% INFO    : Updated Thermal Rating: on line 10483-10485 : Rate B, Rate C - 0.0, 0.0 -> 193.95, 193.95
% INFO    : Updated Thermal Rating: on line 10483-10866 : Rate B, Rate C - 0.0, 0.0 -> 239.25, 239.25
% INFO    : Updated Thermal Rating: on line 10486-10485 : Rate B, Rate C - 0.0, 0.0 -> 235.51, 235.51
% INFO    : Updated Thermal Rating: on line 10485-10492 : Rate B, Rate C - 0.0, 0.0 -> 189.37, 189.37
% INFO    : Updated Thermal Rating: on line 10487-10492 : Rate B, Rate C - 0.0, 0.0 -> 225.53, 225.53
% INFO    : Updated Thermal Rating: on line 10487-10502 : Rate B, Rate C - 0.0, 0.0 -> 181.39, 181.39
% INFO    : Updated Thermal Rating: on line 10487-10801 : Rate B, Rate C - 0.0, 0.0 -> 248.32, 248.32
% INFO    : Updated Thermal Rating: on line 10504-10488 : Rate B, Rate C - 0.0, 0.0 -> 238.95, 238.95
% INFO    : Updated Thermal Rating: on line 10493-13368 : Rate B, Rate C - 0.0, 0.0 -> 189.6, 189.6
% INFO    : Updated Thermal Rating: on line 10493-13376 : Rate B, Rate C - 0.0, 0.0 -> 231.36, 231.36
% INFO    : Updated Thermal Rating: on line 13664-10493 : Rate B, Rate C - 0.0, 0.0 -> 216.25, 216.25
% INFO    : Updated Thermal Rating: on line 10496-10805 : Rate B, Rate C - 0.0, 0.0 -> 268.95, 268.95
% INFO    : Updated Thermal Rating: on transformer 10498-10501 : Rate B, Rate C - 0.0, 0.0 -> 275.23, 275.23
% INFO    : Updated Thermal Rating: on line 10967-10498 : Rate B, Rate C - 0.0, 0.0 -> 222.53, 222.53
% INFO    : Updated Thermal Rating: on transformer 10499-10501 : Rate B, Rate C - 0.0, 0.0 -> 137.62, 137.62
% INFO    : Updated Thermal Rating: on transformer 10500-10501 : Rate B, Rate C - 0.0, 0.0 -> 137.62, 137.62
% INFO    : Updated Thermal Rating: on line 10503-10510 : Rate B, Rate C - 0.0, 0.0 -> 180.63, 180.63
% INFO    : Updated Thermal Rating: on line 10503-10512 : Rate B, Rate C - 0.0, 0.0 -> 218.71, 218.71
% INFO    : Updated Thermal Rating: on line 10512-10504 : Rate B, Rate C - 0.0, 0.0 -> 186.12, 186.12
% INFO    : Updated Thermal Rating: on line 10504-10729 : Rate B, Rate C - 0.0, 0.0 -> 259.97, 259.97
% INFO    : Updated Thermal Rating: on line 10926-10505 : Rate B, Rate C - 0.0, 0.0 -> 218.02, 218.02
% INFO    : Updated Thermal Rating: on line 10506-10525 : Rate B, Rate C - 0.0, 0.0 -> 237.64, 237.64
% INFO    : Updated Thermal Rating: on line 10926-10506 : Rate B, Rate C - 0.0, 0.0 -> 220.32, 220.32
% INFO    : Updated Thermal Rating: on line 10510-10926 : Rate B, Rate C - 0.0, 0.0 -> 209.48, 209.48
% INFO    : Updated Thermal Rating: on line 10516-10512 : Rate B, Rate C - 0.0, 0.0 -> 225.3, 225.3
% INFO    : Updated Thermal Rating: on line 10516-10514 : Rate B, Rate C - 0.0, 0.0 -> 233.73, 233.73
% INFO    : Updated Thermal Rating: on line 10514-10518 : Rate B, Rate C - 0.0, 0.0 -> 245.73, 245.73
% INFO    : Updated Thermal Rating: on line 10515-10538 : Rate B, Rate C - 0.0, 0.0 -> 271.66, 271.66
% INFO    : Updated Thermal Rating: on line 10515-10801 : Rate B, Rate C - 0.0, 0.0 -> 260.02, 260.02
% INFO    : Updated Thermal Rating: on line 10517-13380 : Rate B, Rate C - 0.0, 0.0 -> 188.17, 188.17
% INFO    : Updated Thermal Rating: on line 13401-10517 : Rate B, Rate C - 0.0, 0.0 -> 192.03, 192.03
% INFO    : Updated Thermal Rating: on line 10518-10556 : Rate B, Rate C - 0.0, 0.0 -> 248.7, 248.7
% INFO    : Updated Thermal Rating: on line 10531-10519 : Rate B, Rate C - 0.0, 0.0 -> 197.19, 197.19
% INFO    : Updated Thermal Rating: on line 10519-10967 : Rate B, Rate C - 0.0, 0.0 -> 171.91, 171.91
% INFO    : Updated Thermal Rating: on line 13401-10522 : Rate B, Rate C - 0.0, 0.0 -> 256.77, 256.77
% INFO    : Updated Thermal Rating: on line 10522-13517 : Rate B, Rate C - 0.0, 0.0 -> 261.54, 261.54
% INFO    : Updated Thermal Rating: on line 10523-10527 : Rate B, Rate C - 0.0, 0.0 -> 226.46, 226.46
% INFO    : Updated Thermal Rating: on line 10523-10967 : Rate B, Rate C - 0.0, 0.0 -> 198.54, 198.54
% INFO    : Updated Thermal Rating: on line 10698-10524 : Rate B, Rate C - 0.0, 0.0 -> 257.98, 257.98
% INFO    : Updated Thermal Rating: on line 10524-10952 : Rate B, Rate C - 0.0, 0.0 -> 248.53, 248.53
% INFO    : Updated Thermal Rating: on line 10525-10538 : Rate B, Rate C - 0.0, 0.0 -> 249.68, 249.68
% INFO    : Updated Thermal Rating: on line 10526-10705 : Rate B, Rate C - 0.0, 0.0 -> 191.67, 191.67
% INFO    : Updated Thermal Rating: on line 13498-10526 : Rate B, Rate C - 0.0, 0.0 -> 179.1, 179.1
% INFO    : Updated Thermal Rating: on line 10527-10566 : Rate B, Rate C - 0.0, 0.0 -> 230.66, 230.66
% INFO    : Updated Thermal Rating: on line 10529-10535 : Rate B, Rate C - 0.0, 0.0 -> 202.44, 202.44
% INFO    : Updated Thermal Rating: on line 10529-10745 : Rate B, Rate C - 0.0, 0.0 -> 241.67, 241.67
% INFO    : Updated Thermal Rating: on line 10531-10530 : Rate B, Rate C - 0.0, 0.0 -> 230.97, 230.97
% INFO    : Updated Thermal Rating: on line 10535-10530 : Rate B, Rate C - 0.0, 0.0 -> 249.58, 249.58
% INFO    : Updated Thermal Rating: on line 10530-10542 : Rate B, Rate C - 0.0, 0.0 -> 193.11, 193.11
% INFO    : Updated Thermal Rating: on line 10535-10532 : Rate B, Rate C - 0.0, 0.0 -> 228.47, 228.47
% INFO    : Updated Thermal Rating: on line 10536-10532 : Rate B, Rate C - 0.0, 0.0 -> 180.15, 180.15
% INFO    : Updated Thermal Rating: on transformer 10535-10534 : Rate B, Rate C - 0.0, 0.0 -> 462.35, 462.35
% INFO    : Updated Thermal Rating: on line 10534-10681 : Rate B, Rate C - 0.0, 0.0 -> 1167.28, 1167.28
% INFO    : Updated Thermal Rating: on line 10536-10557 : Rate B, Rate C - 0.0, 0.0 -> 221.46, 221.46
% INFO    : Updated Thermal Rating: on line 10709-10538 : Rate B, Rate C - 0.0, 0.0 -> 281.93, 281.93
% INFO    : Updated Thermal Rating: on line 10709-10538 : Rate B, Rate C - 0.0, 0.0 -> 281.93, 281.93
% INFO    : Updated Thermal Rating: on line 10709-10538 : Rate B, Rate C - 0.0, 0.0 -> 281.93, 281.93
% INFO    : Updated Thermal Rating: on line 10541-10540 : Rate B, Rate C - 0.0, 0.0 -> 228.74, 228.74
% INFO    : Updated Thermal Rating: on line 10540-10544 : Rate B, Rate C - 0.0, 0.0 -> 197.75, 197.75
% INFO    : Updated Thermal Rating: on line 10980-10541 : Rate B, Rate C - 0.0, 0.0 -> 250.19, 250.19
% INFO    : Updated Thermal Rating: on line 10542-10544 : Rate B, Rate C - 0.0, 0.0 -> 225.99, 225.99
% INFO    : Updated Thermal Rating: on line 10544-10569 : Rate B, Rate C - 0.0, 0.0 -> 239.53, 239.53
% INFO    : Updated Thermal Rating: on line 10556-10546 : Rate B, Rate C - 0.0, 0.0 -> 236.62, 236.62
% INFO    : Updated Thermal Rating: on line 10546-10873 : Rate B, Rate C - 0.0, 0.0 -> 245.52, 245.52
% INFO    : Updated Thermal Rating: on line 10550-10548 : Rate B, Rate C - 0.0, 0.0 -> 179.67, 179.67
% INFO    : Updated Thermal Rating: on line 10548-10562 : Rate B, Rate C - 0.0, 0.0 -> 223.84, 223.84
% INFO    : Updated Thermal Rating: on line 10550-10980 : Rate B, Rate C - 0.0, 0.0 -> 229.01, 229.01
% INFO    : Updated Thermal Rating: on line 10553-10556 : Rate B, Rate C - 0.0, 0.0 -> 212.23, 212.23
% INFO    : Updated Thermal Rating: on line 10579-10553 : Rate B, Rate C - 0.0, 0.0 -> 215.42, 215.42
% INFO    : Updated Thermal Rating: on line 10554-10566 : Rate B, Rate C - 0.0, 0.0 -> 199.59, 199.59
% INFO    : Updated Thermal Rating: on line 10554-11068 : Rate B, Rate C - 0.0, 0.0 -> 225.23, 225.23
% INFO    : Updated Thermal Rating: on line 10557-10682 : Rate B, Rate C - 0.0, 0.0 -> 249.72, 249.72
% INFO    : Updated Thermal Rating: on line 10559-10558 : Rate B, Rate C - 0.0, 0.0 -> 199.61, 199.61
% INFO    : Updated Thermal Rating: on line 10719-10558 : Rate B, Rate C - 0.0, 0.0 -> 205.66, 205.66
% INFO    : Updated Thermal Rating: on line 10559-10578 : Rate B, Rate C - 0.0, 0.0 -> 227.41, 227.41
% INFO    : Updated Thermal Rating: on line 10562-10719 : Rate B, Rate C - 0.0, 0.0 -> 228.91, 228.91
% INFO    : Updated Thermal Rating: on line 10873-10565 : Rate B, Rate C - 0.0, 0.0 -> 232.48, 232.48
% INFO    : Updated Thermal Rating: on line 11076-10565 : Rate B, Rate C - 0.0, 0.0 -> 242.6, 242.6
% INFO    : Updated Thermal Rating: on line 10566-13410 : Rate B, Rate C - 0.0, 0.0 -> 226.99, 226.99
% INFO    : Updated Thermal Rating: on line 10575-10568 : Rate B, Rate C - 0.0, 0.0 -> 215.41, 215.41
% INFO    : Updated Thermal Rating: on line 13410-10568 : Rate B, Rate C - 0.0, 0.0 -> 148.07, 148.07
% INFO    : Updated Thermal Rating: on line 10576-10569 : Rate B, Rate C - 0.0, 0.0 -> 207.04, 207.04
% INFO    : Updated Thermal Rating: on line 10569-10587 : Rate B, Rate C - 0.0, 0.0 -> 242.02, 242.02
% INFO    : Updated Thermal Rating: on line 10571-10579 : Rate B, Rate C - 0.0, 0.0 -> 225.44, 225.44
% INFO    : Updated Thermal Rating: on line 10749-10571 : Rate B, Rate C - 0.0, 0.0 -> 234.44, 234.44
% INFO    : Updated Thermal Rating: on line 10572-10577 : Rate B, Rate C - 0.0, 0.0 -> 179.11, 179.11
% INFO    : Updated Thermal Rating: on line 10572-10907 : Rate B, Rate C - 0.0, 0.0 -> 199.07, 199.07
% INFO    : Updated Thermal Rating: on line 10575-10581 : Rate B, Rate C - 0.0, 0.0 -> 188.88, 188.88
% INFO    : Updated Thermal Rating: on line 10575-13676 : Rate B, Rate C - 0.0, 0.0 -> 243.34, 243.34
% INFO    : Updated Thermal Rating: on line 10576-10682 : Rate B, Rate C - 0.0, 0.0 -> 214.87, 214.87
% INFO    : Updated Thermal Rating: on line 10810-10577 : Rate B, Rate C - 0.0, 0.0 -> 231.53, 231.53
% INFO    : Updated Thermal Rating: on line 10578-10582 : Rate B, Rate C - 0.0, 0.0 -> 213.48, 213.48
% INFO    : Updated Thermal Rating: on line 10578-11047 : Rate B, Rate C - 0.0, 0.0 -> 223.29, 223.29
% INFO    : Updated Thermal Rating: on line 10589-10581 : Rate B, Rate C - 0.0, 0.0 -> 195.21, 195.21
% INFO    : Updated Thermal Rating: on line 10900-10582 : Rate B, Rate C - 0.0, 0.0 -> 225.0, 225.0
% INFO    : Updated Thermal Rating: on line 10583-10589 : Rate B, Rate C - 0.0, 0.0 -> 202.33, 202.33
% INFO    : Updated Thermal Rating: on line 10583-10810 : Rate B, Rate C - 0.0, 0.0 -> 227.1, 227.1
% INFO    : Updated Thermal Rating: on line 10587-10585 : Rate B, Rate C - 0.0, 0.0 -> 224.48, 224.48
% INFO    : Updated Thermal Rating: on line 10585-10606 : Rate B, Rate C - 0.0, 0.0 -> 168.26, 168.26
% INFO    : Updated Thermal Rating: on transformer 10587-10586 : Rate B, Rate C - 0.0, 0.0 -> 424.51, 424.51
% INFO    : Updated Thermal Rating: on line 10586-10899 : Rate B, Rate C - 0.0, 0.0 -> 1161.1, 1161.1
% INFO    : Updated Thermal Rating: on line 10590-10589 : Rate B, Rate C - 0.0, 0.0 -> 182.62, 182.62
% INFO    : Updated Thermal Rating: on line 10589-11062 : Rate B, Rate C - 0.0, 0.0 -> 159.54, 159.54
% INFO    : Updated Thermal Rating: on line 10589-13472 : Rate B, Rate C - 0.0, 0.0 -> 227.71, 227.71
% INFO    : Updated Thermal Rating: on line 10590-10810 : Rate B, Rate C - 0.0, 0.0 -> 209.51, 209.51
% INFO    : Updated Thermal Rating: on line 10593-10605 : Rate B, Rate C - 0.0, 0.0 -> 155.0, 155.0
% INFO    : Updated Thermal Rating: on line 13414-10593 : Rate B, Rate C - 0.0, 0.0 -> 194.15, 194.15
% INFO    : Updated Thermal Rating: on line 10593-13418 : Rate B, Rate C - 0.0, 0.0 -> 201.51, 201.51
% INFO    : Updated Thermal Rating: on line 10594-10601 : Rate B, Rate C - 0.0, 0.0 -> 219.42, 219.42
% INFO    : Updated Thermal Rating: on line 10594-10975 : Rate B, Rate C - 0.0, 0.0 -> 237.63, 237.63
% INFO    : Updated Thermal Rating: on line 10595-10597 : Rate B, Rate C - 0.0, 0.0 -> 195.22, 195.22
% INFO    : Updated Thermal Rating: on line 10611-10595 : Rate B, Rate C - 0.0, 0.0 -> 211.85, 211.85
% INFO    : Updated Thermal Rating: on line 10595-10900 : Rate B, Rate C - 0.0, 0.0 -> 187.16, 187.16
% INFO    : Updated Thermal Rating: on line 10597-10598 : Rate B, Rate C - 0.0, 0.0 -> 168.35, 168.35
% INFO    : Updated Thermal Rating: on line 10615-10598 : Rate B, Rate C - 0.0, 0.0 -> 196.65, 196.65
% INFO    : Updated Thermal Rating: on line 10599-10600 : Rate B, Rate C - 0.0, 0.0 -> 208.57, 208.57
% INFO    : Updated Thermal Rating: on line 10810-10599 : Rate B, Rate C - 0.0, 0.0 -> 212.97, 212.97
% INFO    : Updated Thermal Rating: on line 10600-10606 : Rate B, Rate C - 0.0, 0.0 -> 193.31, 193.31
% INFO    : Updated Thermal Rating: on line 10614-10600 : Rate B, Rate C - 0.0, 0.0 -> 210.89, 210.89
% INFO    : Updated Thermal Rating: on line 10601-10846 : Rate B, Rate C - 0.0, 0.0 -> 201.86, 201.86
% INFO    : Updated Thermal Rating: on line 10603-10613 : Rate B, Rate C - 0.0, 0.0 -> 225.51, 225.51
% INFO    : Updated Thermal Rating: on line 10603-11062 : Rate B, Rate C - 0.0, 0.0 -> 189.83, 189.83
% INFO    : Updated Thermal Rating: on line 10604-10605 : Rate B, Rate C - 0.0, 0.0 -> 215.72, 215.72
% INFO    : Updated Thermal Rating: on line 11064-10604 : Rate B, Rate C - 0.0, 0.0 -> 241.75, 241.75
% INFO    : Updated Thermal Rating: on line 10846-10608 : Rate B, Rate C - 0.0, 0.0 -> 222.06, 222.06
% INFO    : Updated Thermal Rating: on line 10608-10943 : Rate B, Rate C - 0.0, 0.0 -> 220.77, 220.77
% INFO    : Updated Thermal Rating: on line 10609-10810 : Rate B, Rate C - 0.0, 0.0 -> 225.27, 225.27
% INFO    : Updated Thermal Rating: on line 10609-10846 : Rate B, Rate C - 0.0, 0.0 -> 216.54, 216.54
% INFO    : Updated Thermal Rating: on line 11013-10611 : Rate B, Rate C - 0.0, 0.0 -> 226.12, 226.12
% INFO    : Updated Thermal Rating: on line 10846-10613 : Rate B, Rate C - 0.0, 0.0 -> 231.8, 231.8
% INFO    : Updated Thermal Rating: on line 10614-10943 : Rate B, Rate C - 0.0, 0.0 -> 222.23, 222.23
% INFO    : Updated Thermal Rating: on line 10615-11013 : Rate B, Rate C - 0.0, 0.0 -> 208.64, 208.64
% INFO    : Updated Thermal Rating: on line 10617-13439 : Rate B, Rate C - 0.0, 0.0 -> 200.58, 200.58
% INFO    : Updated Thermal Rating: on line 10617-13573 : Rate B, Rate C - 0.0, 0.0 -> 222.13, 222.13
% INFO    : Updated Thermal Rating: on line 10618-10876 : Rate B, Rate C - 0.0, 0.0 -> 213.56, 213.56
% INFO    : Updated Thermal Rating: on line 10618-10968 : Rate B, Rate C - 0.0, 0.0 -> 208.44, 208.44
% INFO    : Updated Thermal Rating: on line 11013-10619 : Rate B, Rate C - 0.0, 0.0 -> 183.06, 183.06
% INFO    : Updated Thermal Rating: on line 10619-11055 : Rate B, Rate C - 0.0, 0.0 -> 192.41, 192.41
% INFO    : Updated Thermal Rating: on line 10627-10623 : Rate B, Rate C - 0.0, 0.0 -> 229.78, 229.78
% INFO    : Updated Thermal Rating: on line 10623-10818 : Rate B, Rate C - 0.0, 0.0 -> 241.53, 241.53
% INFO    : Updated Thermal Rating: on line 10624-10659 : Rate B, Rate C - 0.0, 0.0 -> 218.06, 218.06
% INFO    : Updated Thermal Rating: on line 10624-11057 : Rate B, Rate C - 0.0, 0.0 -> 228.84, 228.84
% INFO    : Updated Thermal Rating: on line 10626-10868 : Rate B, Rate C - 0.0, 0.0 -> 215.11, 215.11
% INFO    : Updated Thermal Rating: on line 10626-11055 : Rate B, Rate C - 0.0, 0.0 -> 225.19, 225.19
% INFO    : Updated Thermal Rating: on line 10627-10629 : Rate B, Rate C - 0.0, 0.0 -> 203.44, 203.44
% INFO    : Updated Thermal Rating: on line 10628-10630 : Rate B, Rate C - 0.0, 0.0 -> 161.72, 161.72
% INFO    : Updated Thermal Rating: on line 10633-10628 : Rate B, Rate C - 0.0, 0.0 -> 154.34, 154.34
% INFO    : Updated Thermal Rating: on line 10628-10676 : Rate B, Rate C - 0.0, 0.0 -> 224.09, 224.09
% INFO    : Updated Thermal Rating: on line 10629-10634 : Rate B, Rate C - 0.0, 0.0 -> 161.58, 161.58
% INFO    : Updated Thermal Rating: on line 10630-10790 : Rate B, Rate C - 0.0, 0.0 -> 222.08, 222.08
% INFO    : Updated Thermal Rating: on line 10632-10636 : Rate B, Rate C - 0.0, 0.0 -> 234.7, 234.7
% INFO    : Updated Thermal Rating: on line 10971-10632 : Rate B, Rate C - 0.0, 0.0 -> 249.65, 249.65
% INFO    : Updated Thermal Rating: on line 10633-10868 : Rate B, Rate C - 0.0, 0.0 -> 222.8, 222.8
% INFO    : Updated Thermal Rating: on line 10971-10634 : Rate B, Rate C - 0.0, 0.0 -> 219.13, 219.13
% INFO    : Updated Thermal Rating: on line 10636-10635 : Rate B, Rate C - 0.0, 0.0 -> 219.58, 219.58
% INFO    : Updated Thermal Rating: on line 10635-10647 : Rate B, Rate C - 0.0, 0.0 -> 202.37, 202.37
% INFO    : Updated Thermal Rating: on line 10650-10636 : Rate B, Rate C - 0.0, 0.0 -> 218.25, 218.25
% INFO    : Updated Thermal Rating: on line 10644-10638 : Rate B, Rate C - 0.0, 0.0 -> 186.01, 186.01
% INFO    : Updated Thermal Rating: on line 10638-10648 : Rate B, Rate C - 0.0, 0.0 -> 221.81, 221.81
% INFO    : Updated Thermal Rating: on line 10779-10638 : Rate B, Rate C - 0.0, 0.0 -> 166.25, 166.25
% INFO    : Updated Thermal Rating: on line 10640-10641 : Rate B, Rate C - 0.0, 0.0 -> 224.01, 224.01
% INFO    : Updated Thermal Rating: on line 10640-10665 : Rate B, Rate C - 0.0, 0.0 -> 181.15, 181.15
% INFO    : Updated Thermal Rating: on line 10641-10665 : Rate B, Rate C - 0.0, 0.0 -> 228.3, 228.3
% INFO    : Updated Thermal Rating: on line 10871-10641 : Rate B, Rate C - 0.0, 0.0 -> 266.99, 266.99
% INFO    : Updated Thermal Rating: on line 10968-10644 : Rate B, Rate C - 0.0, 0.0 -> 207.62, 207.62
% INFO    : Updated Thermal Rating: on line 10645-10826 : Rate B, Rate C - 0.0, 0.0 -> 209.27, 209.27
% INFO    : Updated Thermal Rating: on line 74011-10645 : Rate B, Rate C - 0.0, 0.0 -> 197.52, 197.52
% INFO    : Updated Thermal Rating: on line 10652-10647 : Rate B, Rate C - 0.0, 0.0 -> 232.33, 232.33
% INFO    : Updated Thermal Rating: on line 10656-10648 : Rate B, Rate C - 0.0, 0.0 -> 180.89, 180.89
% INFO    : Updated Thermal Rating: on line 10648-10662 : Rate B, Rate C - 0.0, 0.0 -> 253.87, 253.87
% INFO    : Updated Thermal Rating: on line 10651-10649 : Rate B, Rate C - 0.0, 0.0 -> 212.48, 212.48
% INFO    : Updated Thermal Rating: on line 10649-10662 : Rate B, Rate C - 0.0, 0.0 -> 239.14, 239.14
% INFO    : Updated Thermal Rating: on line 10871-10650 : Rate B, Rate C - 0.0, 0.0 -> 243.49, 243.49
% INFO    : Updated Thermal Rating: on line 10651-10779 : Rate B, Rate C - 0.0, 0.0 -> 203.6, 203.6
% INFO    : Updated Thermal Rating: on line 10652-10658 : Rate B, Rate C - 0.0, 0.0 -> 222.38, 222.38
% INFO    : Updated Thermal Rating: on line 10652-74021 : Rate B, Rate C - 0.0, 0.0 -> 214.61, 214.61
% INFO    : Updated Thermal Rating: on line 10662-10654 : Rate B, Rate C - 0.0, 0.0 -> 275.94, 275.94
% INFO    : Updated Thermal Rating: on line 10654-10671 : Rate B, Rate C - 0.0, 0.0 -> 217.98, 217.98
% INFO    : Updated Thermal Rating: on line 10654-74002 : Rate B, Rate C - 0.0, 0.0 -> 238.21, 238.21
% INFO    : Updated Thermal Rating: on line 10656-10662 : Rate B, Rate C - 0.0, 0.0 -> 216.62, 216.62
% INFO    : Updated Thermal Rating: on line 10657-10665 : Rate B, Rate C - 0.0, 0.0 -> 171.41, 171.41
% INFO    : Updated Thermal Rating: on line 10657-10671 : Rate B, Rate C - 0.0, 0.0 -> 222.5, 222.5
% INFO    : Updated Thermal Rating: on line 10666-10658 : Rate B, Rate C - 0.0, 0.0 -> 229.88, 229.88
% INFO    : Updated Thermal Rating: on line 10659-74014 : Rate B, Rate C - 0.0, 0.0 -> 195.82, 195.82
% INFO    : Updated Thermal Rating: on line 10660-10679 : Rate B, Rate C - 0.0, 0.0 -> 202.59, 202.59
% INFO    : Updated Thermal Rating: on line 10660-10871 : Rate B, Rate C - 0.0, 0.0 -> 205.79, 205.79
% INFO    : Updated Thermal Rating: on transformer 10662-10661 : Rate B, Rate C - 0.0, 0.0 -> 521.12, 521.12
% INFO    : Updated Thermal Rating: on line 10970-10661 : Rate B, Rate C - 0.0, 0.0 -> 1100.0, 1100.0
% INFO    : Updated Thermal Rating: on line 10793-10663 : Rate B, Rate C - 0.0, 0.0 -> 1038.29, 1038.29
% INFO    : Updated Thermal Rating: on line 10663-74234 : Rate B, Rate C - 0.0, 0.0 -> 1220.24, 1220.24
% INFO    : Updated Thermal Rating: on line 10666-74300 : Rate B, Rate C - 0.0, 0.0 -> 236.89, 236.89
% INFO    : Updated Thermal Rating: on line 10674-10668 : Rate B, Rate C - 0.0, 0.0 -> 179.21, 179.21
% INFO    : Updated Thermal Rating: on line 10668-10678 : Rate B, Rate C - 0.0, 0.0 -> 236.5, 236.5
% INFO    : Updated Thermal Rating: on line 10669-10826 : Rate B, Rate C - 0.0, 0.0 -> 223.36, 223.36
% INFO    : Updated Thermal Rating: on line 74011-10669 : Rate B, Rate C - 0.0, 0.0 -> 182.95, 182.95
% INFO    : Updated Thermal Rating: on line 10670-10826 : Rate B, Rate C - 0.0, 0.0 -> 229.65, 229.65
% INFO    : Updated Thermal Rating: on line 10670-74027 : Rate B, Rate C - 0.0, 0.0 -> 189.01, 189.01
% INFO    : Updated Thermal Rating: on line 10671-74025 : Rate B, Rate C - 0.0, 0.0 -> 216.0, 216.0
% INFO    : Updated Thermal Rating: on line 10672-74300 : Rate B, Rate C - 0.0, 0.0 -> 212.82, 212.82
% INFO    : Updated Thermal Rating: on line 10672-77184 : Rate B, Rate C - 0.0, 0.0 -> 229.49, 229.49
% INFO    : Updated Thermal Rating: on line 10679-10673 : Rate B, Rate C - 0.0, 0.0 -> 196.17, 196.17
% INFO    : Updated Thermal Rating: on line 74006-10673 : Rate B, Rate C - 0.0, 0.0 -> 226.13, 226.13
% INFO    : Updated Thermal Rating: on line 10674-10679 : Rate B, Rate C - 0.0, 0.0 -> 189.78, 189.78
% INFO    : Updated Thermal Rating: on line 10676-10790 : Rate B, Rate C - 0.0, 0.0 -> 234.74, 234.74
% INFO    : Updated Thermal Rating: on line 10676-74003 : Rate B, Rate C - 0.0, 0.0 -> 201.11, 201.11
% INFO    : Updated Thermal Rating: on line 10678-74241 : Rate B, Rate C - 0.0, 0.0 -> 248.71, 248.71
% INFO    : Updated Thermal Rating: on line 10679-74024 : Rate B, Rate C - 0.0, 0.0 -> 211.06, 211.06
% INFO    : Updated Thermal Rating: on transformer 10681-10680 : Rate B, Rate C - 0.0, 0.0 -> 1409.3, 1409.3
% INFO    : Updated Thermal Rating: on transformer 10680-10683 : Rate B, Rate C - 0.0, 0.0 -> 1374.96, 1374.96
% INFO    : Updated Thermal Rating: on transformer 10680-10684 : Rate B, Rate C - 0.0, 0.0 -> 1371.62, 1371.62
% INFO    : Updated Thermal Rating: on transformer 10680-10685 : Rate B, Rate C - 0.0, 0.0 -> 1369.65, 1369.65
% INFO    : Updated Thermal Rating: on transformer 10680-10686 : Rate B, Rate C - 0.0, 0.0 -> 1369.55, 1369.55
% INFO    : Updated Thermal Rating: on transformer 10680-10687 : Rate B, Rate C - 0.0, 0.0 -> 1369.41, 1369.41
% INFO    : Updated Thermal Rating: on transformer 10680-10688 : Rate B, Rate C - 0.0, 0.0 -> 1368.2, 1368.2
% INFO    : Updated Thermal Rating: on line 10680-10812 : Rate B, Rate C - 0.0, 0.0 -> 4069.09, 4069.09
% INFO    : Updated Thermal Rating: on line 10680-10905 : Rate B, Rate C - 0.0, 0.0 -> 3916.79, 3916.79
% INFO    : Updated Thermal Rating: on line 11000-10680 : Rate B, Rate C - 0.0, 0.0 -> 4131.05, 4131.05
% INFO    : Updated Thermal Rating: on transformer 10682-10681 : Rate B, Rate C - 0.0, 0.0 -> 427.61, 427.61
% INFO    : Updated Thermal Rating: on transformer 10681-10689 : Rate B, Rate C - 0.0, 0.0 -> 246.76, 246.76
% INFO    : Updated Thermal Rating: on line 10681-10915 : Rate B, Rate C - 0.0, 0.0 -> 1037.07, 1037.07
% INFO    : Updated Thermal Rating: on transformer 10690-10691 : Rate B, Rate C - 0.0, 0.0 -> 128.57, 128.57
% INFO    : Updated Thermal Rating: on line 10690-10984 : Rate B, Rate C - 0.0, 0.0 -> 207.33, 207.33
% INFO    : Updated Thermal Rating: on line 10690-11068 : Rate B, Rate C - 0.0, 0.0 -> 215.94, 215.94
% INFO    : Updated Thermal Rating: on transformer 10693-10696 : Rate B, Rate C - 0.0, 0.0 -> 305.93, 305.93
% INFO    : Updated Thermal Rating: on line 10693-10863 : Rate B, Rate C - 0.0, 0.0 -> 167.02, 167.02
% INFO    : Updated Thermal Rating: on transformer 10694-10696 : Rate B, Rate C - 0.0, 0.0 -> 152.97, 152.97
% INFO    : Updated Thermal Rating: on transformer 10695-10696 : Rate B, Rate C - 0.0, 0.0 -> 152.97, 152.97
% INFO    : Updated Thermal Rating: on transformer 10698-10697 : Rate B, Rate C - 0.0, 0.0 -> 411.67, 411.67
% INFO    : Updated Thermal Rating: on transformer 10697-10699 : Rate B, Rate C - 0.0, 0.0 -> 420.33, 420.33
% INFO    : Updated Thermal Rating: on line 10701-10718 : Rate B, Rate C - 0.0, 0.0 -> 1199.55, 1199.55
% INFO    : Updated Thermal Rating: on line 10701-10979 : Rate B, Rate C - 0.0, 0.0 -> 1197.59, 1197.59
% INFO    : Updated Thermal Rating: on transformer 10702-10703 : Rate B, Rate C - 0.0, 0.0 -> 177.19, 177.19
% INFO    : Updated Thermal Rating: on line 10705-11002 : Rate B, Rate C - 0.0, 0.0 -> 138.48, 138.48
% INFO    : Updated Thermal Rating: on line 10705-13380 : Rate B, Rate C - 0.0, 0.0 -> 266.68, 266.68
% INFO    : Updated Thermal Rating: on transformer 10708-10707 : Rate B, Rate C - 0.0, 0.0 -> 1500.23, 1500.23
% INFO    : Updated Thermal Rating: on transformer 10707-10710 : Rate B, Rate C - 0.0, 0.0 -> 1518.59, 1518.59
% INFO    : Updated Thermal Rating: on transformer 10707-10711 : Rate B, Rate C - 0.0, 0.0 -> 1517.03, 1517.03
% INFO    : Updated Thermal Rating: on transformer 10707-10712 : Rate B, Rate C - 0.0, 0.0 -> 1515.27, 1515.27
% INFO    : Updated Thermal Rating: on transformer 10707-10713 : Rate B, Rate C - 0.0, 0.0 -> 1513.23, 1513.23
% INFO    : Updated Thermal Rating: on transformer 10707-10714 : Rate B, Rate C - 0.0, 0.0 -> 1509.97, 1509.97
% INFO    : Updated Thermal Rating: on transformer 10707-10715 : Rate B, Rate C - 0.0, 0.0 -> 1505.34, 1505.34
% INFO    : Updated Thermal Rating: on transformer 10709-10708 : Rate B, Rate C - 0.0, 0.0 -> 522.31, 522.31
% INFO    : Updated Thermal Rating: on line 10718-10708 : Rate B, Rate C - 0.0, 0.0 -> 1094.29, 1094.29
% INFO    : Updated Thermal Rating: on line 11075-10708 : Rate B, Rate C - 0.0, 0.0 -> 1258.58, 1258.58
% INFO    : Updated Thermal Rating: on line 10716-10717 : Rate B, Rate C - 0.0, 0.0 -> 4009.72, 4009.72
% INFO    : Updated Thermal Rating: on line 10716-10734 : Rate B, Rate C - 0.0, 0.0 -> 4230.58, 4230.58
% INFO    : Updated Thermal Rating: on line 10716-11011 : Rate B, Rate C - 0.0, 0.0 -> 4243.33, 4243.33
% INFO    : Updated Thermal Rating: on transformer 10718-10717 : Rate B, Rate C - 0.0, 0.0 -> 1453.13, 1453.13
% INFO    : Updated Thermal Rating: on transformer 10717-10722 : Rate B, Rate C - 0.0, 0.0 -> 1223.71, 1223.71
% INFO    : Updated Thermal Rating: on transformer 10717-10723 : Rate B, Rate C - 0.0, 0.0 -> 1223.22, 1223.22
% INFO    : Updated Thermal Rating: on transformer 10717-10724 : Rate B, Rate C - 0.0, 0.0 -> 1221.95, 1221.95
% INFO    : Updated Thermal Rating: on transformer 10717-10725 : Rate B, Rate C - 0.0, 0.0 -> 1216.91, 1216.91
% INFO    : Updated Thermal Rating: on transformer 10717-10726 : Rate B, Rate C - 0.0, 0.0 -> 1216.82, 1216.82
% INFO    : Updated Thermal Rating: on transformer 10717-10727 : Rate B, Rate C - 0.0, 0.0 -> 1216.07, 1216.07
% INFO    : Updated Thermal Rating: on line 10717-10861 : Rate B, Rate C - 0.0, 0.0 -> 4141.28, 4141.28
% INFO    : Updated Thermal Rating: on line 10717-10892 : Rate B, Rate C - 0.0, 0.0 -> 4081.31, 4081.31
% INFO    : Updated Thermal Rating: on line 10905-10717 : Rate B, Rate C - 0.0, 0.0 -> 3936.47, 3936.47
% INFO    : Updated Thermal Rating: on line 10717-11074 : Rate B, Rate C - 0.0, 0.0 -> 4192.26, 4192.26
% INFO    : Updated Thermal Rating: on transformer 10718-10721 : Rate B, Rate C - 0.0, 0.0 -> 468.05, 468.05
% INFO    : Updated Thermal Rating: on transformer 10719-10721 : Rate B, Rate C - 0.0, 0.0 -> 393.05, 393.05
% INFO    : Updated Thermal Rating: on transformer 10720-10721 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 10729-10728 : Rate B, Rate C - 0.0, 0.0 -> 472.2, 472.2
% INFO    : Updated Thermal Rating: on line 10728-10748 : Rate B, Rate C - 0.0, 0.0 -> 1373.72, 1373.72
% INFO    : Updated Thermal Rating: on line 10769-10728 : Rate B, Rate C - 0.0, 0.0 -> 1335.66, 1335.66
% INFO    : Updated Thermal Rating: on transformer 10730-10733 : Rate B, Rate C - 0.0, 0.0 -> 547.05, 547.05
% INFO    : Updated Thermal Rating: on transformer 10731-10733 : Rate B, Rate C - 0.0, 0.0 -> 422.05, 422.05
% INFO    : Updated Thermal Rating: on line 11010-10731 : Rate B, Rate C - 0.0, 0.0 -> 210.97, 210.97
% INFO    : Updated Thermal Rating: on transformer 10732-10733 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 10735-10734 : Rate B, Rate C - 0.0, 0.0 -> 1777.25, 1777.25
% INFO    : Updated Thermal Rating: on transformer 10735-10734 : Rate B, Rate C - 0.0, 0.0 -> 1777.25, 1777.25
% INFO    : Updated Thermal Rating: on transformer 10735-10734 : Rate B, Rate C - 0.0, 0.0 -> 1777.25, 1777.25
% INFO    : Updated Thermal Rating: on transformer 10734-10737 : Rate B, Rate C - 0.0, 0.0 -> 1367.63, 1367.63
% INFO    : Updated Thermal Rating: on transformer 10734-10738 : Rate B, Rate C - 0.0, 0.0 -> 1366.92, 1366.92
% INFO    : Updated Thermal Rating: on line 10734-10861 : Rate B, Rate C - 0.0, 0.0 -> 4058.84, 4058.84
% INFO    : Updated Thermal Rating: on transformer 10736-10735 : Rate B, Rate C - 0.0, 0.0 -> 635.96, 635.96
% INFO    : Updated Thermal Rating: on transformer 10736-10735 : Rate B, Rate C - 0.0, 0.0 -> 635.96, 635.96
% INFO    : Updated Thermal Rating: on transformer 10736-10735 : Rate B, Rate C - 0.0, 0.0 -> 635.96, 635.96
% INFO    : Updated Thermal Rating: on line 10735-10838 : Rate B, Rate C - 0.0, 0.0 -> 1391.4, 1391.4
% INFO    : Updated Thermal Rating: on line 10837-10736 : Rate B, Rate C - 0.0, 0.0 -> 313.07, 313.07
% INFO    : Updated Thermal Rating: on transformer 10740-10739 : Rate B, Rate C - 0.0, 0.0 -> 1461.79, 1461.79
% INFO    : Updated Thermal Rating: on transformer 10739-10742 : Rate B, Rate C - 0.0, 0.0 -> 1100.75, 1100.75
% INFO    : Updated Thermal Rating: on transformer 10739-10743 : Rate B, Rate C - 0.0, 0.0 -> 1092.82, 1092.82
% INFO    : Updated Thermal Rating: on transformer 10739-10744 : Rate B, Rate C - 0.0, 0.0 -> 1088.73, 1088.73
% INFO    : Updated Thermal Rating: on line 13666-10739 : Rate B, Rate C - 0.0, 0.0 -> 3975.91, 3975.91
% INFO    : Updated Thermal Rating: on transformer 10741-10740 : Rate B, Rate C - 0.0, 0.0 -> 443.91, 443.91
% INFO    : Updated Thermal Rating: on line 10813-10740 : Rate B, Rate C - 0.0, 0.0 -> 1330.97, 1330.97
% INFO    : Updated Thermal Rating: on line 10862-10740 : Rate B, Rate C - 0.0, 0.0 -> 1129.14, 1129.14
% INFO    : Updated Thermal Rating: on line 10741-10935 : Rate B, Rate C - 0.0, 0.0 -> 239.1, 239.1
% INFO    : Updated Thermal Rating: on transformer 10745-10746 : Rate B, Rate C - 0.0, 0.0 -> 117.0, 117.0
% INFO    : Updated Thermal Rating: on line 10907-10745 : Rate B, Rate C - 0.0, 0.0 -> 182.56, 182.56
% INFO    : Updated Thermal Rating: on transformer 10748-10747 : Rate B, Rate C - 0.0, 0.0 -> 1568.88, 1568.88
% INFO    : Updated Thermal Rating: on transformer 10747-10750 : Rate B, Rate C - 0.0, 0.0 -> 1751.97, 1751.97
% INFO    : Updated Thermal Rating: on transformer 10747-10751 : Rate B, Rate C - 0.0, 0.0 -> 1746.69, 1746.69
% INFO    : Updated Thermal Rating: on transformer 10747-10752 : Rate B, Rate C - 0.0, 0.0 -> 1744.98, 1744.98
% INFO    : Updated Thermal Rating: on transformer 10747-10753 : Rate B, Rate C - 0.0, 0.0 -> 1744.39, 1744.39
% INFO    : Updated Thermal Rating: on transformer 10747-10754 : Rate B, Rate C - 0.0, 0.0 -> 1741.07, 1741.07
% INFO    : Updated Thermal Rating: on transformer 10747-10755 : Rate B, Rate C - 0.0, 0.0 -> 1741.0, 1741.0
% INFO    : Updated Thermal Rating: on line 10747-10916 : Rate B, Rate C - 0.0, 0.0 -> 4211.49, 4211.49
% INFO    : Updated Thermal Rating: on line 11011-10747 : Rate B, Rate C - 0.0, 0.0 -> 4182.56, 4182.56
% INFO    : Updated Thermal Rating: on line 10747-11074 : Rate B, Rate C - 0.0, 0.0 -> 3989.97, 3989.97
% INFO    : Updated Thermal Rating: on transformer 10749-10748 : Rate B, Rate C - 0.0, 0.0 -> 383.66, 383.66
% INFO    : Updated Thermal Rating: on line 10748-11075 : Rate B, Rate C - 0.0, 0.0 -> 1221.53, 1221.53
% INFO    : Updated Thermal Rating: on transformer 10757-10756 : Rate B, Rate C - 0.0, 0.0 -> 342.9, 342.9
% INFO    : Updated Thermal Rating: on line 10862-10756 : Rate B, Rate C - 0.0, 0.0 -> 1149.78, 1149.78
% INFO    : Updated Thermal Rating: on line 10928-10756 : Rate B, Rate C - 0.0, 0.0 -> 1177.14, 1177.14
% INFO    : Updated Thermal Rating: on transformer 10759-10758 : Rate B, Rate C - 0.0, 0.0 -> 445.0, 445.0
% INFO    : Updated Thermal Rating: on line 10769-10758 : Rate B, Rate C - 0.0, 0.0 -> 1170.86, 1170.86
% INFO    : Updated Thermal Rating: on line 10758-10917 : Rate B, Rate C - 0.0, 0.0 -> 1235.83, 1235.83
% INFO    : Updated Thermal Rating: on transformer 10761-10760 : Rate B, Rate C - 0.0, 0.0 -> 492.83, 492.83
% INFO    : Updated Thermal Rating: on line 10761-13335 : Rate B, Rate C - 0.0, 0.0 -> 222.55, 222.55
% INFO    : Updated Thermal Rating: on line 10761-13350 : Rate B, Rate C - 0.0, 0.0 -> 242.12, 242.12
% INFO    : Updated Thermal Rating: on line 13302-10762 : Rate B, Rate C - 0.0, 0.0 -> 1369.2, 1369.2
% INFO    : Updated Thermal Rating: on line 13340-10762 : Rate B, Rate C - 0.0, 0.0 -> 1198.32, 1198.32
% INFO    : Updated Thermal Rating: on line 10762-13621 : Rate B, Rate C - 0.0, 0.0 -> 1390.95, 1390.95
% INFO    : Updated Thermal Rating: on line 10762-13667 : Rate B, Rate C - 0.0, 0.0 -> 1305.33, 1305.33
% INFO    : Updated Thermal Rating: on transformer 10767-10766 : Rate B, Rate C - 0.0, 0.0 -> 349.08, 349.08
% INFO    : Updated Thermal Rating: on transformer 10766-10768 : Rate B, Rate C - 0.0, 0.0 -> 582.49, 582.49
% INFO    : Updated Thermal Rating: on line 10766-11056 : Rate B, Rate C - 0.0, 0.0 -> 1103.19, 1103.19
% INFO    : Updated Thermal Rating: on line 13438-10766 : Rate B, Rate C - 0.0, 0.0 -> 1221.54, 1221.54
% INFO    : Updated Thermal Rating: on line 13432-10767 : Rate B, Rate C - 0.0, 0.0 -> 216.62, 216.62
% INFO    : Updated Thermal Rating: on transformer 10770-10769 : Rate B, Rate C - 0.0, 0.0 -> 387.62, 387.62
% INFO    : Updated Thermal Rating: on transformer 10769-10771 : Rate B, Rate C - 0.0, 0.0 -> 338.29, 338.29
% INFO    : Updated Thermal Rating: on transformer 10769-10772 : Rate B, Rate C - 0.0, 0.0 -> 336.68, 336.68
% INFO    : Updated Thermal Rating: on transformer 10769-10773 : Rate B, Rate C - 0.0, 0.0 -> 335.58, 335.58
% INFO    : Updated Thermal Rating: on transformer 10769-10774 : Rate B, Rate C - 0.0, 0.0 -> 332.79, 332.79
% INFO    : Updated Thermal Rating: on line 10917-10769 : Rate B, Rate C - 0.0, 0.0 -> 1376.23, 1376.23
% INFO    : Updated Thermal Rating: on line 11037-10770 : Rate B, Rate C - 0.0, 0.0 -> 239.88, 239.88
% INFO    : Updated Thermal Rating: on transformer 10775-10776 : Rate B, Rate C - 0.0, 0.0 -> 84.98, 84.98
% INFO    : Updated Thermal Rating: on line 10777-10894 : Rate B, Rate C - 0.0, 0.0 -> 231.68, 231.68
% INFO    : Updated Thermal Rating: on transformer 10781-10782 : Rate B, Rate C - 0.0, 0.0 -> 70.82, 70.82
% INFO    : Updated Thermal Rating: on transformer 10781-10783 : Rate B, Rate C - 0.0, 0.0 -> 29.87, 29.87
% INFO    : Updated Thermal Rating: on line 11036-10781 : Rate B, Rate C - 0.0, 0.0 -> 217.96, 217.96
% INFO    : Updated Thermal Rating: on transformer 10785-10784 : Rate B, Rate C - 0.0, 0.0 -> 469.32, 469.32
% INFO    : Updated Thermal Rating: on line 10786-11034 : Rate B, Rate C - 0.0, 0.0 -> 1127.73, 1127.73
% INFO    : Updated Thermal Rating: on line 10893-10788 : Rate B, Rate C - 0.0, 0.0 -> 995.83, 995.83
% INFO    : Updated Thermal Rating: on transformer 10790-10789 : Rate B, Rate C - 0.0, 0.0 -> 409.3, 409.3
% INFO    : Updated Thermal Rating: on transformer 10789-10791 : Rate B, Rate C - 0.0, 0.0 -> 432.39, 432.39
% INFO    : Updated Thermal Rating: on line 10825-10793 : Rate B, Rate C - 0.0, 0.0 -> 1030.17, 1030.17
% INFO    : Updated Thermal Rating: on transformer 10795-10794 : Rate B, Rate C - 0.0, 0.0 -> 400.14, 400.14
% INFO    : Updated Thermal Rating: on transformer 10794-10796 : Rate B, Rate C - 0.0, 0.0 -> 325.83, 325.83
% INFO    : Updated Thermal Rating: on transformer 10794-10797 : Rate B, Rate C - 0.0, 0.0 -> 403.19, 403.19
% INFO    : Updated Thermal Rating: on transformer 10795-10798 : Rate B, Rate C - 0.0, 0.0 -> 75.8, 75.8
% INFO    : Updated Thermal Rating: on line 10893-10799 : Rate B, Rate C - 0.0, 0.0 -> 1295.51, 1295.51
% INFO    : Updated Thermal Rating: on line 10800-10933 : Rate B, Rate C - 0.0, 0.0 -> 241.12, 241.12
% INFO    : Updated Thermal Rating: on line 10800-13458 : Rate B, Rate C - 0.0, 0.0 -> 219.01, 219.01
% INFO    : Updated Thermal Rating: on line 13517-10800 : Rate B, Rate C - 0.0, 0.0 -> 227.08, 227.08
% INFO    : Updated Thermal Rating: on transformer 10801-10804 : Rate B, Rate C - 0.0, 0.0 -> 166.94, 166.94
% INFO    : Updated Thermal Rating: on line 10801-10866 : Rate B, Rate C - 0.0, 0.0 -> 224.39, 224.39
% INFO    : Updated Thermal Rating: on transformer 10802-10804 : Rate B, Rate C - 0.0, 0.0 -> 83.47, 83.47
% INFO    : Updated Thermal Rating: on transformer 10803-10804 : Rate B, Rate C - 0.0, 0.0 -> 83.47, 83.47
% INFO    : Updated Thermal Rating: on transformer 10805-10806 : Rate B, Rate C - 0.0, 0.0 -> 118.56, 118.56
% INFO    : Updated Thermal Rating: on transformer 10805-10807 : Rate B, Rate C - 0.0, 0.0 -> 118.56, 118.56
% INFO    : Updated Thermal Rating: on line 10918-10805 : Rate B, Rate C - 0.0, 0.0 -> 212.05, 212.05
% INFO    : Updated Thermal Rating: on transformer 10809-10808 : Rate B, Rate C - 0.0, 0.0 -> 1314.67, 1314.67
% INFO    : Updated Thermal Rating: on transformer 10808-10811 : Rate B, Rate C - 0.0, 0.0 -> 1955.01, 1955.01
% INFO    : Updated Thermal Rating: on transformer 10810-10809 : Rate B, Rate C - 0.0, 0.0 -> 470.0, 470.0
% INFO    : Updated Thermal Rating: on line 10809-10974 : Rate B, Rate C - 0.0, 0.0 -> 1061.96, 1061.96
% INFO    : Updated Thermal Rating: on line 10810-10943 : Rate B, Rate C - 0.0, 0.0 -> 236.49, 236.49
% INFO    : Updated Thermal Rating: on line 10812-13470 : Rate B, Rate C - 0.0, 0.0 -> 4021.34, 4021.34
% INFO    : Updated Thermal Rating: on transformer 10813-10816 : Rate B, Rate C - 0.0, 0.0 -> 568.17, 568.17
% INFO    : Updated Thermal Rating: on line 10813-10953 : Rate B, Rate C - 0.0, 0.0 -> 1108.81, 1108.81
% INFO    : Updated Thermal Rating: on transformer 10814-10816 : Rate B, Rate C - 0.0, 0.0 -> 415.0, 415.0
% INFO    : Updated Thermal Rating: on transformer 10815-10816 : Rate B, Rate C - 0.0, 0.0 -> 153.17, 153.17
% INFO    : Updated Thermal Rating: on transformer 10818-10817 : Rate B, Rate C - 0.0, 0.0 -> 387.51, 387.51
% INFO    : Updated Thermal Rating: on line 10819-11026 : Rate B, Rate C - 0.0, 0.0 -> 1092.86, 1092.86
% INFO    : Updated Thermal Rating: on line 11039-10819 : Rate B, Rate C - 0.0, 0.0 -> 1108.55, 1108.55
% INFO    : Updated Thermal Rating: on transformer 10820-10821 : Rate B, Rate C - 0.0, 0.0 -> 196.56, 196.56
% INFO    : Updated Thermal Rating: on line 13410-10823 : Rate B, Rate C - 0.0, 0.0 -> 194.47, 194.47
% INFO    : Updated Thermal Rating: on line 13591-10823 : Rate B, Rate C - 0.0, 0.0 -> 194.39, 194.39
% INFO    : Updated Thermal Rating: on transformer 10824-10828 : Rate B, Rate C - 0.0, 0.0 -> 1306.5, 1306.5
% INFO    : Updated Thermal Rating: on transformer 10824-10829 : Rate B, Rate C - 0.0, 0.0 -> 1343.94, 1343.94
% INFO    : Updated Thermal Rating: on transformer 10824-10830 : Rate B, Rate C - 0.0, 0.0 -> 1343.06, 1343.06
% INFO    : Updated Thermal Rating: on transformer 10824-10831 : Rate B, Rate C - 0.0, 0.0 -> 1342.71, 1342.71
% INFO    : Updated Thermal Rating: on transformer 10824-10832 : Rate B, Rate C - 0.0, 0.0 -> 1342.43, 1342.43
% INFO    : Updated Thermal Rating: on transformer 10824-10833 : Rate B, Rate C - 0.0, 0.0 -> 1340.6, 1340.6
% INFO    : Updated Thermal Rating: on transformer 10824-10834 : Rate B, Rate C - 0.0, 0.0 -> 1339.14, 1339.14
% INFO    : Updated Thermal Rating: on transformer 10826-10825 : Rate B, Rate C - 0.0, 0.0 -> 426.83, 426.83
% INFO    : Updated Thermal Rating: on transformer 10825-10828 : Rate B, Rate C - 0.0, 0.0 -> 1274.35, 1274.35
% INFO    : Updated Thermal Rating: on line 10961-10825 : Rate B, Rate C - 0.0, 0.0 -> 1037.31, 1037.31
% INFO    : Updated Thermal Rating: on line 10825-74217 : Rate B, Rate C - 0.0, 0.0 -> 1077.54, 1077.54
% INFO    : Updated Thermal Rating: on transformer 10827-10828 : Rate B, Rate C - 0.0, 0.0 -> 32.15, 32.15
% INFO    : Updated Thermal Rating: on line 10885-10835 : Rate B, Rate C - 0.0, 0.0 -> 3955.79, 3955.79
% INFO    : Updated Thermal Rating: on line 13594-10835 : Rate B, Rate C - 0.0, 0.0 -> 4016.61, 4016.61
% INFO    : Updated Thermal Rating: on transformer 10838-10841 : Rate B, Rate C - 0.0, 0.0 -> 574.02, 574.02
% INFO    : Updated Thermal Rating: on transformer 10839-10841 : Rate B, Rate C - 0.0, 0.0 -> 524.02, 524.02
% INFO    : Updated Thermal Rating: on transformer 10840-10841 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 10843-10842 : Rate B, Rate C - 0.0, 0.0 -> 455.96, 455.96
% INFO    : Updated Thermal Rating: on line 10842-10862 : Rate B, Rate C - 0.0, 0.0 -> 1150.68, 1150.68
% INFO    : Updated Thermal Rating: on line 10999-10843 : Rate B, Rate C - 0.0, 0.0 -> 225.37, 225.37
% INFO    : Updated Thermal Rating: on transformer 10845-10844 : Rate B, Rate C - 0.0, 0.0 -> 1315.28, 1315.28
% INFO    : Updated Thermal Rating: on transformer 10844-10847 : Rate B, Rate C - 0.0, 0.0 -> 1213.67, 1213.67
% INFO    : Updated Thermal Rating: on transformer 10844-10848 : Rate B, Rate C - 0.0, 0.0 -> 1213.15, 1213.15
% INFO    : Updated Thermal Rating: on transformer 10844-10849 : Rate B, Rate C - 0.0, 0.0 -> 1212.68, 1212.68
% INFO    : Updated Thermal Rating: on transformer 10844-10850 : Rate B, Rate C - 0.0, 0.0 -> 1207.77, 1207.77
% INFO    : Updated Thermal Rating: on transformer 10844-10851 : Rate B, Rate C - 0.0, 0.0 -> 1207.05, 1207.05
% INFO    : Updated Thermal Rating: on transformer 10844-10852 : Rate B, Rate C - 0.0, 0.0 -> 1206.24, 1206.24
% INFO    : Updated Thermal Rating: on transformer 10844-10853 : Rate B, Rate C - 0.0, 0.0 -> 830.92, 830.92
% INFO    : Updated Thermal Rating: on transformer 10846-10845 : Rate B, Rate C - 0.0, 0.0 -> 415.43, 415.43
% INFO    : Updated Thermal Rating: on line 13465-10846 : Rate B, Rate C - 0.0, 0.0 -> 219.1, 219.1
% INFO    : Updated Thermal Rating: on line 10942-10854 : Rate B, Rate C - 0.0, 0.0 -> 1113.29, 1113.29
% INFO    : Updated Thermal Rating: on line 10854-10974 : Rate B, Rate C - 0.0, 0.0 -> 1107.82, 1107.82
% INFO    : Updated Thermal Rating: on line 10855-10941 : Rate B, Rate C - 0.0, 0.0 -> 4116.08, 4116.08
% INFO    : Updated Thermal Rating: on line 13470-10855 : Rate B, Rate C - 0.0, 0.0 -> 4200.91, 4200.91
% INFO    : Updated Thermal Rating: on transformer 10857-10856 : Rate B, Rate C - 0.0, 0.0 -> 1492.63, 1492.63
% INFO    : Updated Thermal Rating: on transformer 10856-10859 : Rate B, Rate C - 0.0, 0.0 -> 1823.06, 1823.06
% INFO    : Updated Thermal Rating: on transformer 10856-10860 : Rate B, Rate C - 0.0, 0.0 -> 1808.93, 1808.93
% INFO    : Updated Thermal Rating: on transformer 10858-10857 : Rate B, Rate C - 0.0, 0.0 -> 470.04, 470.04
% INFO    : Updated Thermal Rating: on line 10857-10928 : Rate B, Rate C - 0.0, 0.0 -> 1312.36, 1312.36
% INFO    : Updated Thermal Rating: on line 10986-10861 : Rate B, Rate C - 0.0, 0.0 -> 3963.52, 3963.52
% INFO    : Updated Thermal Rating: on transformer 10863-10862 : Rate B, Rate C - 0.0, 0.0 -> 400.2, 400.2
% INFO    : Updated Thermal Rating: on transformer 10862-10864 : Rate B, Rate C - 0.0, 0.0 -> 487.52, 487.52
% INFO    : Updated Thermal Rating: on transformer 10862-10865 : Rate B, Rate C - 0.0, 0.0 -> 486.71, 486.71
% INFO    : Updated Thermal Rating: on transformer 10866-10867 : Rate B, Rate C - 0.0, 0.0 -> 65.04, 65.04
% INFO    : Updated Thermal Rating: on transformer 10868-10869 : Rate B, Rate C - 0.0, 0.0 -> 37.34, 37.34
% INFO    : Updated Thermal Rating: on transformer 10871-10870 : Rate B, Rate C - 0.0, 0.0 -> 500.55, 500.55
% INFO    : Updated Thermal Rating: on transformer 10870-10872 : Rate B, Rate C - 0.0, 0.0 -> 372.8, 372.8
% INFO    : Updated Thermal Rating: on line 10970-10870 : Rate B, Rate C - 0.0, 0.0 -> 1109.68, 1109.68
% INFO    : Updated Thermal Rating: on line 10870-74207 : Rate B, Rate C - 0.0, 0.0 -> 1074.88, 1074.88
% INFO    : Updated Thermal Rating: on transformer 10874-10878 : Rate B, Rate C - 0.0, 0.0 -> 1382.94, 1382.94
% INFO    : Updated Thermal Rating: on transformer 10874-10879 : Rate B, Rate C - 0.0, 0.0 -> 1338.48, 1338.48
% INFO    : Updated Thermal Rating: on transformer 10874-10880 : Rate B, Rate C - 0.0, 0.0 -> 1336.22, 1336.22
% INFO    : Updated Thermal Rating: on transformer 10874-10881 : Rate B, Rate C - 0.0, 0.0 -> 1335.83, 1335.83
% INFO    : Updated Thermal Rating: on transformer 10874-10882 : Rate B, Rate C - 0.0, 0.0 -> 1333.57, 1333.57
% INFO    : Updated Thermal Rating: on transformer 10874-10883 : Rate B, Rate C - 0.0, 0.0 -> 1332.77, 1332.77
% INFO    : Updated Thermal Rating: on transformer 10874-10884 : Rate B, Rate C - 0.0, 0.0 -> 1332.61, 1332.61
% INFO    : Updated Thermal Rating: on transformer 10876-10875 : Rate B, Rate C - 0.0, 0.0 -> 296.78, 296.78
% INFO    : Updated Thermal Rating: on transformer 10875-10878 : Rate B, Rate C - 0.0, 0.0 -> 1357.94, 1357.94
% INFO    : Updated Thermal Rating: on line 10942-10875 : Rate B, Rate C - 0.0, 0.0 -> 1123.87, 1123.87
% INFO    : Updated Thermal Rating: on line 10876-10962 : Rate B, Rate C - 0.0, 0.0 -> 206.72, 206.72
% INFO    : Updated Thermal Rating: on transformer 10877-10878 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 10885-10941 : Rate B, Rate C - 0.0, 0.0 -> 3996.81, 3996.81
% INFO    : Updated Thermal Rating: on transformer 10888-10887 : Rate B, Rate C - 0.0, 0.0 -> 407.69, 407.69
% INFO    : Updated Thermal Rating: on transformer 10887-10889 : Rate B, Rate C - 0.0, 0.0 -> 403.35, 403.35
% INFO    : Updated Thermal Rating: on transformer 10887-10890 : Rate B, Rate C - 0.0, 0.0 -> 320.01, 320.01
% INFO    : Updated Thermal Rating: on line 11034-10891 : Rate B, Rate C - 0.0, 0.0 -> 993.89, 993.89
% INFO    : Updated Thermal Rating: on transformer 10893-10892 : Rate B, Rate C - 0.0, 0.0 -> 1618.31, 1618.31
% INFO    : Updated Thermal Rating: on transformer 10893-10892 : Rate B, Rate C - 0.0, 0.0 -> 1618.31, 1618.31
% INFO    : Updated Thermal Rating: on transformer 10893-10892 : Rate B, Rate C - 0.0, 0.0 -> 1618.31, 1618.31
% INFO    : Updated Thermal Rating: on transformer 10892-10895 : Rate B, Rate C - 0.0, 0.0 -> 1150.24, 1150.24
% INFO    : Updated Thermal Rating: on transformer 10892-10896 : Rate B, Rate C - 0.0, 0.0 -> 1147.62, 1147.62
% INFO    : Updated Thermal Rating: on transformer 10892-10897 : Rate B, Rate C - 0.0, 0.0 -> 1144.94, 1144.94
% INFO    : Updated Thermal Rating: on transformer 10892-10898 : Rate B, Rate C - 0.0, 0.0 -> 1143.44, 1143.44
% INFO    : Updated Thermal Rating: on line 10892-10916 : Rate B, Rate C - 0.0, 0.0 -> 4073.52, 4073.52
% INFO    : Updated Thermal Rating: on transformer 10894-10893 : Rate B, Rate C - 0.0, 0.0 -> 483.05, 483.05
% INFO    : Updated Thermal Rating: on transformer 10900-10899 : Rate B, Rate C - 0.0, 0.0 -> 346.8, 346.8
% INFO    : Updated Thermal Rating: on transformer 10899-10902 : Rate B, Rate C - 0.0, 0.0 -> 325.84, 325.84
% INFO    : Updated Thermal Rating: on line 11026-10899 : Rate B, Rate C - 0.0, 0.0 -> 1193.39, 1193.39
% INFO    : Updated Thermal Rating: on transformer 10900-10901 : Rate B, Rate C - 0.0, 0.0 -> 80.12, 80.12
% INFO    : Updated Thermal Rating: on line 10900-11047 : Rate B, Rate C - 0.0, 0.0 -> 204.75, 204.75
% INFO    : Updated Thermal Rating: on transformer 10903-10904 : Rate B, Rate C - 0.0, 0.0 -> 91.9, 91.9
% INFO    : Updated Thermal Rating: on line 10903-10933 : Rate B, Rate C - 0.0, 0.0 -> 228.35, 228.35
% INFO    : Updated Thermal Rating: on line 10903-10984 : Rate B, Rate C - 0.0, 0.0 -> 195.96, 195.96
% INFO    : Updated Thermal Rating: on transformer 10906-10905 : Rate B, Rate C - 0.0, 0.0 -> 1400.45, 1400.45
% INFO    : Updated Thermal Rating: on transformer 10905-10908 : Rate B, Rate C - 0.0, 0.0 -> 1393.06, 1393.06
% INFO    : Updated Thermal Rating: on transformer 10905-10909 : Rate B, Rate C - 0.0, 0.0 -> 1390.94, 1390.94
% INFO    : Updated Thermal Rating: on transformer 10905-10910 : Rate B, Rate C - 0.0, 0.0 -> 1389.36, 1389.36
% INFO    : Updated Thermal Rating: on transformer 10905-10911 : Rate B, Rate C - 0.0, 0.0 -> 1388.65, 1388.65
% INFO    : Updated Thermal Rating: on transformer 10905-10912 : Rate B, Rate C - 0.0, 0.0 -> 1385.24, 1385.24
% INFO    : Updated Thermal Rating: on transformer 10905-10913 : Rate B, Rate C - 0.0, 0.0 -> 1384.0, 1384.0
% INFO    : Updated Thermal Rating: on transformer 10905-10914 : Rate B, Rate C - 0.0, 0.0 -> 826.69, 826.69
% INFO    : Updated Thermal Rating: on transformer 10907-10906 : Rate B, Rate C - 0.0, 0.0 -> 322.59, 322.59
% INFO    : Updated Thermal Rating: on line 10915-10979 : Rate B, Rate C - 0.0, 0.0 -> 1161.73, 1161.73
% INFO    : Updated Thermal Rating: on transformer 10917-10916 : Rate B, Rate C - 0.0, 0.0 -> 1569.35, 1569.35
% INFO    : Updated Thermal Rating: on transformer 10916-10919 : Rate B, Rate C - 0.0, 0.0 -> 1241.69, 1241.69
% INFO    : Updated Thermal Rating: on transformer 10916-10920 : Rate B, Rate C - 0.0, 0.0 -> 1238.06, 1238.06
% INFO    : Updated Thermal Rating: on transformer 10916-10921 : Rate B, Rate C - 0.0, 0.0 -> 1237.33, 1237.33
% INFO    : Updated Thermal Rating: on transformer 10916-10922 : Rate B, Rate C - 0.0, 0.0 -> 1236.84, 1236.84
% INFO    : Updated Thermal Rating: on transformer 10918-10917 : Rate B, Rate C - 0.0, 0.0 -> 338.72, 338.72
% INFO    : Updated Thermal Rating: on line 11028-10923 : Rate B, Rate C - 0.0, 0.0 -> 203.83, 203.83
% INFO    : Updated Thermal Rating: on transformer 10924-10925 : Rate B, Rate C - 0.0, 0.0 -> 58.96, 58.96
% INFO    : Updated Thermal Rating: on transformer 10929-10928 : Rate B, Rate C - 0.0, 0.0 -> 439.89, 439.89
% INFO    : Updated Thermal Rating: on transformer 10928-10930 : Rate B, Rate C - 0.0, 0.0 -> 552.45, 552.45
% INFO    : Updated Thermal Rating: on transformer 10928-10931 : Rate B, Rate C - 0.0, 0.0 -> 549.1, 549.1
% INFO    : Updated Thermal Rating: on transformer 10928-10932 : Rate B, Rate C - 0.0, 0.0 -> 548.58, 548.58
% INFO    : Updated Thermal Rating: on line 10958-10933 : Rate B, Rate C - 0.0, 0.0 -> 336.31, 336.31
% INFO    : Updated Thermal Rating: on line 13498-10933 : Rate B, Rate C - 0.0, 0.0 -> 207.26, 207.26
% INFO    : Updated Thermal Rating: on transformer 10937-10938 : Rate B, Rate C - 0.0, 0.0 -> 27.49, 27.49
% INFO    : Updated Thermal Rating: on transformer 10937-10939 : Rate B, Rate C - 0.0, 0.0 -> 9.75, 9.75
% INFO    : Updated Thermal Rating: on transformer 10937-10940 : Rate B, Rate C - 0.0, 0.0 -> 9.75, 9.75
% INFO    : Updated Thermal Rating: on line 10937-10988 : Rate B, Rate C - 0.0, 0.0 -> 195.02, 195.02
% INFO    : Updated Thermal Rating: on transformer 10942-10941 : Rate B, Rate C - 0.0, 0.0 -> 1347.89, 1347.89
% INFO    : Updated Thermal Rating: on transformer 10941-10944 : Rate B, Rate C - 0.0, 0.0 -> 1330.72, 1330.72
% INFO    : Updated Thermal Rating: on transformer 10941-10945 : Rate B, Rate C - 0.0, 0.0 -> 1327.92, 1327.92
% INFO    : Updated Thermal Rating: on transformer 10941-10946 : Rate B, Rate C - 0.0, 0.0 -> 1324.1, 1324.1
% INFO    : Updated Thermal Rating: on transformer 10941-10947 : Rate B, Rate C - 0.0, 0.0 -> 1322.94, 1322.94
% INFO    : Updated Thermal Rating: on transformer 10941-10948 : Rate B, Rate C - 0.0, 0.0 -> 1322.62, 1322.62
% INFO    : Updated Thermal Rating: on transformer 10941-10949 : Rate B, Rate C - 0.0, 0.0 -> 1322.61, 1322.61
% INFO    : Updated Thermal Rating: on transformer 10943-10942 : Rate B, Rate C - 0.0, 0.0 -> 432.54, 432.54
% INFO    : Updated Thermal Rating: on line 13430-10943 : Rate B, Rate C - 0.0, 0.0 -> 194.64, 194.64
% INFO    : Updated Thermal Rating: on transformer 10950-10951 : Rate B, Rate C - 0.0, 0.0 -> 72.95, 72.95
% INFO    : Updated Thermal Rating: on transformer 10954-10953 : Rate B, Rate C - 0.0, 0.0 -> 450.63, 450.63
% INFO    : Updated Thermal Rating: on transformer 10953-10955 : Rate B, Rate C - 0.0, 0.0 -> 390.0, 390.0
% INFO    : Updated Thermal Rating: on transformer 10953-10956 : Rate B, Rate C - 0.0, 0.0 -> 388.47, 388.47
% INFO    : Updated Thermal Rating: on line 10953-11048 : Rate B, Rate C - 0.0, 0.0 -> 1221.08, 1221.08
% INFO    : Updated Thermal Rating: on line 10953-11070 : Rate B, Rate C - 0.0, 0.0 -> 1225.38, 1225.38
% INFO    : Updated Thermal Rating: on transformer 10958-10957 : Rate B, Rate C - 0.0, 0.0 -> 437.61, 437.61
% INFO    : Updated Thermal Rating: on transformer 10957-10959 : Rate B, Rate C - 0.0, 0.0 -> 577.8, 577.8
% INFO    : Updated Thermal Rating: on line 10958-13401 : Rate B, Rate C - 0.0, 0.0 -> 300.89, 300.89
% INFO    : Updated Thermal Rating: on line 10958-13401 : Rate B, Rate C - 0.0, 0.0 -> 300.89, 300.89
% INFO    : Updated Thermal Rating: on line 10958-13401 : Rate B, Rate C - 0.0, 0.0 -> 300.89, 300.89
% INFO    : Updated Thermal Rating: on line 10958-13401 : Rate B, Rate C - 0.0, 0.0 -> 300.89, 300.89
% INFO    : Updated Thermal Rating: on line 10958-13485 : Rate B, Rate C - 0.0, 0.0 -> 291.38, 291.38
% INFO    : Updated Thermal Rating: on line 10958-13485 : Rate B, Rate C - 0.0, 0.0 -> 291.38, 291.38
% INFO    : Updated Thermal Rating: on line 10958-13485 : Rate B, Rate C - 0.0, 0.0 -> 291.38, 291.38
% INFO    : Updated Thermal Rating: on line 10960-11067 : Rate B, Rate C - 0.0, 0.0 -> 1194.55, 1194.55
% INFO    : Updated Thermal Rating: on line 10960-13516 : Rate B, Rate C - 0.0, 0.0 -> 1235.08, 1235.08
% INFO    : Updated Thermal Rating: on line 10960-13667 : Rate B, Rate C - 0.0, 0.0 -> 1433.54, 1433.54
% INFO    : Updated Thermal Rating: on transformer 10961-10964 : Rate B, Rate C - 0.0, 0.0 -> 496.51, 496.51
% INFO    : Updated Thermal Rating: on transformer 10961-10965 : Rate B, Rate C - 0.0, 0.0 -> 597.63, 597.63
% INFO    : Updated Thermal Rating: on line 10961-11056 : Rate B, Rate C - 0.0, 0.0 -> 1094.35, 1094.35
% INFO    : Updated Thermal Rating: on transformer 10962-10964 : Rate B, Rate C - 0.0, 0.0 -> 346.51, 346.51
% INFO    : Updated Thermal Rating: on line 11051-10962 : Rate B, Rate C - 0.0, 0.0 -> 200.58, 200.58
% INFO    : Updated Thermal Rating: on transformer 10963-10964 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 10968-10969 : Rate B, Rate C - 0.0, 0.0 -> 60.49, 60.49
% INFO    : Updated Thermal Rating: on transformer 10971-10970 : Rate B, Rate C - 0.0, 0.0 -> 421.32, 421.32
% INFO    : Updated Thermal Rating: on line 11012-10970 : Rate B, Rate C - 0.0, 0.0 -> 1100.0, 1100.0
% INFO    : Updated Thermal Rating: on line 10970-74234 : Rate B, Rate C - 0.0, 0.0 -> 1201.43, 1201.43
% INFO    : Updated Thermal Rating: on transformer 10971-10972 : Rate B, Rate C - 0.0, 0.0 -> 68.55, 68.55
% INFO    : Updated Thermal Rating: on transformer 10971-10973 : Rate B, Rate C - 0.0, 0.0 -> 68.52, 68.52
% INFO    : Updated Thermal Rating: on line 11055-10971 : Rate B, Rate C - 0.0, 0.0 -> 218.62, 218.62
% INFO    : Updated Thermal Rating: on transformer 10974-10977 : Rate B, Rate C - 0.0, 0.0 -> 483.1, 483.1
% INFO    : Updated Thermal Rating: on transformer 10974-10978 : Rate B, Rate C - 0.0, 0.0 -> 412.78, 412.78
% INFO    : Updated Thermal Rating: on line 11066-10974 : Rate B, Rate C - 0.0, 0.0 -> 1128.81, 1128.81
% INFO    : Updated Thermal Rating: on line 10974-13507 : Rate B, Rate C - 0.0, 0.0 -> 1178.54, 1178.54
% INFO    : Updated Thermal Rating: on transformer 10975-10977 : Rate B, Rate C - 0.0, 0.0 -> 383.1, 383.1
% INFO    : Updated Thermal Rating: on transformer 10976-10977 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 10980-10979 : Rate B, Rate C - 0.0, 0.0 -> 444.75, 444.75
% INFO    : Updated Thermal Rating: on transformer 10979-10981 : Rate B, Rate C - 0.0, 0.0 -> 471.1, 471.1
% INFO    : Updated Thermal Rating: on transformer 10979-10982 : Rate B, Rate C - 0.0, 0.0 -> 470.55, 470.55
% INFO    : Updated Thermal Rating: on transformer 10984-10983 : Rate B, Rate C - 0.0, 0.0 -> 281.19, 281.19
% INFO    : Updated Thermal Rating: on transformer 10983-10985 : Rate B, Rate C - 0.0, 0.0 -> 519.94, 519.94
% INFO    : Updated Thermal Rating: on line 11067-10983 : Rate B, Rate C - 0.0, 0.0 -> 1014.8, 1014.8
% INFO    : Updated Thermal Rating: on line 10983-13505 : Rate B, Rate C - 0.0, 0.0 -> 1208.24, 1208.24
% INFO    : Updated Thermal Rating: on transformer 10987-10986 : Rate B, Rate C - 0.0, 0.0 -> 1559.03, 1559.03
% INFO    : Updated Thermal Rating: on transformer 10986-10989 : Rate B, Rate C - 0.0, 0.0 -> 1521.68, 1521.68
% INFO    : Updated Thermal Rating: on transformer 10986-10990 : Rate B, Rate C - 0.0, 0.0 -> 1521.48, 1521.48
% INFO    : Updated Thermal Rating: on transformer 10986-10991 : Rate B, Rate C - 0.0, 0.0 -> 1520.0, 1520.0
% INFO    : Updated Thermal Rating: on transformer 10988-10987 : Rate B, Rate C - 0.0, 0.0 -> 478.1, 478.1
% INFO    : Updated Thermal Rating: on transformer 10992-10993 : Rate B, Rate C - 0.0, 0.0 -> 75.63, 75.63
% INFO    : Updated Thermal Rating: on transformer 10992-10994 : Rate B, Rate C - 0.0, 0.0 -> 38.68, 38.68
% INFO    : Updated Thermal Rating: on transformer 10992-10995 : Rate B, Rate C - 0.0, 0.0 -> 38.58, 38.58
% INFO    : Updated Thermal Rating: on line 11040-10996 : Rate B, Rate C - 0.0, 0.0 -> 194.61, 194.61
% INFO    : Updated Thermal Rating: on line 10996-74052 : Rate B, Rate C - 0.0, 0.0 -> 187.25, 187.25
% INFO    : Updated Thermal Rating: on transformer 10997-10998 : Rate B, Rate C - 0.0, 0.0 -> 90.96, 90.96
% INFO    : Updated Thermal Rating: on transformer 11001-11000 : Rate B, Rate C - 0.0, 0.0 -> 1321.68, 1321.68
% INFO    : Updated Thermal Rating: on transformer 11000-11005 : Rate B, Rate C - 0.0, 0.0 -> 1348.47, 1348.47
% INFO    : Updated Thermal Rating: on transformer 11000-11006 : Rate B, Rate C - 0.0, 0.0 -> 1347.93, 1347.93
% INFO    : Updated Thermal Rating: on line 11000-13470 : Rate B, Rate C - 0.0, 0.0 -> 4166.28, 4166.28
% INFO    : Updated Thermal Rating: on line 11000-13631 : Rate B, Rate C - 0.0, 0.0 -> 4171.2, 4171.2
% INFO    : Updated Thermal Rating: on line 11000-13666 : Rate B, Rate C - 0.0, 0.0 -> 4163.81, 4163.81
% INFO    : Updated Thermal Rating: on transformer 11001-11004 : Rate B, Rate C - 0.0, 0.0 -> 308.29, 308.29
% INFO    : Updated Thermal Rating: on line 11001-13484 : Rate B, Rate C - 0.0, 0.0 -> 1205.62, 1205.62
% INFO    : Updated Thermal Rating: on line 13505-11001 : Rate B, Rate C - 0.0, 0.0 -> 1187.05, 1187.05
% INFO    : Updated Thermal Rating: on transformer 11002-11004 : Rate B, Rate C - 0.0, 0.0 -> 183.29, 183.29
% INFO    : Updated Thermal Rating: on transformer 11003-11004 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 11007-11008 : Rate B, Rate C - 0.0, 0.0 -> 41.36, 41.36
% INFO    : Updated Thermal Rating: on transformer 11007-11009 : Rate B, Rate C - 0.0, 0.0 -> 67.92, 67.92
% INFO    : Updated Thermal Rating: on transformer 11012-11011 : Rate B, Rate C - 0.0, 0.0 -> 1456.46, 1456.46
% INFO    : Updated Thermal Rating: on transformer 11011-11014 : Rate B, Rate C - 0.0, 0.0 -> 1896.11, 1896.11
% INFO    : Updated Thermal Rating: on transformer 11011-11015 : Rate B, Rate C - 0.0, 0.0 -> 1867.48, 1867.48
% INFO    : Updated Thermal Rating: on transformer 11011-11016 : Rate B, Rate C - 0.0, 0.0 -> 1864.62, 1864.62
% INFO    : Updated Thermal Rating: on transformer 11011-11017 : Rate B, Rate C - 0.0, 0.0 -> 1862.67, 1862.67
% INFO    : Updated Thermal Rating: on transformer 11011-11018 : Rate B, Rate C - 0.0, 0.0 -> 1860.99, 1860.99
% INFO    : Updated Thermal Rating: on transformer 11011-11019 : Rate B, Rate C - 0.0, 0.0 -> 1858.12, 1858.12
% INFO    : Updated Thermal Rating: on transformer 11011-11020 : Rate B, Rate C - 0.0, 0.0 -> 1056.86, 1056.86
% INFO    : Updated Thermal Rating: on transformer 11011-11021 : Rate B, Rate C - 0.0, 0.0 -> 1045.97, 1045.97
% INFO    : Updated Thermal Rating: on transformer 11011-11022 : Rate B, Rate C - 0.0, 0.0 -> 1045.58, 1045.58
% INFO    : Updated Thermal Rating: on transformer 11011-11023 : Rate B, Rate C - 0.0, 0.0 -> 1041.64, 1041.64
% INFO    : Updated Thermal Rating: on transformer 11011-11024 : Rate B, Rate C - 0.0, 0.0 -> 1041.17, 1041.17
% INFO    : Updated Thermal Rating: on transformer 11011-11025 : Rate B, Rate C - 0.0, 0.0 -> 1036.0, 1036.0
% INFO    : Updated Thermal Rating: on line 11011-11038 : Rate B, Rate C - 0.0, 0.0 -> 3971.97, 3971.97
% INFO    : Updated Thermal Rating: on line 11011-11074 : Rate B, Rate C - 0.0, 0.0 -> 4161.76, 4161.76
% INFO    : Updated Thermal Rating: on transformer 11013-11012 : Rate B, Rate C - 0.0, 0.0 -> 395.62, 395.62
% INFO    : Updated Thermal Rating: on line 11026-11075 : Rate B, Rate C - 0.0, 0.0 -> 1158.65, 1158.65
% INFO    : Updated Thermal Rating: on transformer 11027-11030 : Rate B, Rate C - 0.0, 0.0 -> 583.46, 583.46
% INFO    : Updated Thermal Rating: on transformer 11027-11031 : Rate B, Rate C - 0.0, 0.0 -> 412.25, 412.25
% INFO    : Updated Thermal Rating: on transformer 11027-11032 : Rate B, Rate C - 0.0, 0.0 -> 411.78, 411.78
% INFO    : Updated Thermal Rating: on transformer 11027-11033 : Rate B, Rate C - 0.0, 0.0 -> 410.47, 410.47
% INFO    : Updated Thermal Rating: on transformer 11028-11030 : Rate B, Rate C - 0.0, 0.0 -> 433.46, 433.46
% INFO    : Updated Thermal Rating: on transformer 11029-11030 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 11036-11071 : Rate B, Rate C - 0.0, 0.0 -> 198.6, 198.6
% INFO    : Updated Thermal Rating: on transformer 11039-11038 : Rate B, Rate C - 0.0, 0.0 -> 1284.87, 1284.87
% INFO    : Updated Thermal Rating: on transformer 11038-11041 : Rate B, Rate C - 0.0, 0.0 -> 1420.29, 1420.29
% INFO    : Updated Thermal Rating: on transformer 11038-11042 : Rate B, Rate C - 0.0, 0.0 -> 1419.73, 1419.73
% INFO    : Updated Thermal Rating: on transformer 11038-11043 : Rate B, Rate C - 0.0, 0.0 -> 1417.37, 1417.37
% INFO    : Updated Thermal Rating: on transformer 11038-11044 : Rate B, Rate C - 0.0, 0.0 -> 1412.36, 1412.36
% INFO    : Updated Thermal Rating: on transformer 11038-11045 : Rate B, Rate C - 0.0, 0.0 -> 1410.91, 1410.91
% INFO    : Updated Thermal Rating: on transformer 11038-11046 : Rate B, Rate C - 0.0, 0.0 -> 1409.22, 1409.22
% INFO    : Updated Thermal Rating: on transformer 11040-11039 : Rate B, Rate C - 0.0, 0.0 -> 293.86, 293.86
% INFO    : Updated Thermal Rating: on line 74267-11040 : Rate B, Rate C - 0.0, 0.0 -> 156.94, 156.94
% INFO    : Updated Thermal Rating: on transformer 11049-11048 : Rate B, Rate C - 0.0, 0.0 -> 582.29, 582.29
% INFO    : Updated Thermal Rating: on transformer 11049-11048 : Rate B, Rate C - 0.0, 0.0 -> 582.29, 582.29
% INFO    : Updated Thermal Rating: on transformer 11048-11050 : Rate B, Rate C - 0.0, 0.0 -> 574.96, 574.96
% INFO    : Updated Thermal Rating: on line 13180-11048 : Rate B, Rate C - 0.0, 0.0 -> 1129.8, 1129.8
% INFO    : Updated Thermal Rating: on line 11048-13302 : Rate B, Rate C - 0.0, 0.0 -> 1217.22, 1217.22
% INFO    : Updated Thermal Rating: on line 11048-13648 : Rate B, Rate C - 0.0, 0.0 -> 1256.23, 1256.23
% INFO    : Updated Thermal Rating: on line 11049-13123 : Rate B, Rate C - 0.0, 0.0 -> 221.35, 221.35
% INFO    : Updated Thermal Rating: on line 11049-13155 : Rate B, Rate C - 0.0, 0.0 -> 244.29, 244.29
% INFO    : Updated Thermal Rating: on line 13249-11049 : Rate B, Rate C - 0.0, 0.0 -> 275.1, 275.1
% INFO    : Updated Thermal Rating: on line 13249-11049 : Rate B, Rate C - 0.0, 0.0 -> 275.1, 275.1
% INFO    : Updated Thermal Rating: on line 13249-11049 : Rate B, Rate C - 0.0, 0.0 -> 275.1, 275.1
% INFO    : Updated Thermal Rating: on line 13292-11049 : Rate B, Rate C - 0.0, 0.0 -> 230.24, 230.24
% INFO    : Updated Thermal Rating: on transformer 11051-11052 : Rate B, Rate C - 0.0, 0.0 -> 108.17, 108.17
% INFO    : Updated Thermal Rating: on transformer 11051-11053 : Rate B, Rate C - 0.0, 0.0 -> 107.69, 107.69
% INFO    : Updated Thermal Rating: on line 11051-13427 : Rate B, Rate C - 0.0, 0.0 -> 262.91, 262.91
% INFO    : Updated Thermal Rating: on transformer 11056-11059 : Rate B, Rate C - 0.0, 0.0 -> 396.24, 396.24
% INFO    : Updated Thermal Rating: on transformer 11056-11060 : Rate B, Rate C - 0.0, 0.0 -> 431.96, 431.96
% INFO    : Updated Thermal Rating: on transformer 11056-11061 : Rate B, Rate C - 0.0, 0.0 -> 431.59, 431.59
% INFO    : Updated Thermal Rating: on transformer 11057-11059 : Rate B, Rate C - 0.0, 0.0 -> 371.24, 371.24
% INFO    : Updated Thermal Rating: on transformer 11058-11059 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 11064-11063 : Rate B, Rate C - 0.0, 0.0 -> 388.31, 388.31
% INFO    : Updated Thermal Rating: on transformer 11063-11065 : Rate B, Rate C - 0.0, 0.0 -> 511.97, 511.97
% INFO    : Updated Thermal Rating: on line 13464-11066 : Rate B, Rate C - 0.0, 0.0 -> 1077.46, 1077.46
% INFO    : Updated Thermal Rating: on transformer 11068-11067 : Rate B, Rate C - 0.0, 0.0 -> 328.7, 328.7
% INFO    : Updated Thermal Rating: on transformer 11067-11069 : Rate B, Rate C - 0.0, 0.0 -> 527.31, 527.31
% INFO    : Updated Thermal Rating: on line 11068-13467 : Rate B, Rate C - 0.0, 0.0 -> 196.66, 196.66
% INFO    : Updated Thermal Rating: on line 13569-11068 : Rate B, Rate C - 0.0, 0.0 -> 202.24, 202.24
% INFO    : Updated Thermal Rating: on transformer 11071-11070 : Rate B, Rate C - 0.0, 0.0 -> 467.15, 467.15
% INFO    : Updated Thermal Rating: on transformer 11070-11072 : Rate B, Rate C - 0.0, 0.0 -> 503.43, 503.43
% INFO    : Updated Thermal Rating: on transformer 11070-11073 : Rate B, Rate C - 0.0, 0.0 -> 503.35, 503.35
% INFO    : Updated Thermal Rating: on line 13648-11070 : Rate B, Rate C - 0.0, 0.0 -> 1062.35, 1062.35
% INFO    : Updated Thermal Rating: on line 13689-11070 : Rate B, Rate C - 0.0, 0.0 -> 1079.4, 1079.4
% INFO    : Updated Thermal Rating: on transformer 11075-11074 : Rate B, Rate C - 0.0, 0.0 -> 1511.36, 1511.36
% INFO    : Updated Thermal Rating: on transformer 11074-11077 : Rate B, Rate C - 0.0, 0.0 -> 1290.81, 1290.81
% INFO    : Updated Thermal Rating: on transformer 11074-11078 : Rate B, Rate C - 0.0, 0.0 -> 1287.52, 1287.52
% INFO    : Updated Thermal Rating: on transformer 11074-11079 : Rate B, Rate C - 0.0, 0.0 -> 1285.45, 1285.45
% INFO    : Updated Thermal Rating: on transformer 11074-11080 : Rate B, Rate C - 0.0, 0.0 -> 1283.99, 1283.99
% INFO    : Updated Thermal Rating: on transformer 11074-11081 : Rate B, Rate C - 0.0, 0.0 -> 1282.85, 1282.85
% INFO    : Updated Thermal Rating: on transformer 11074-11082 : Rate B, Rate C - 0.0, 0.0 -> 1282.3, 1282.3
% INFO    : Updated Thermal Rating: on transformer 11076-11075 : Rate B, Rate C - 0.0, 0.0 -> 392.58, 392.58
% INFO    : Updated Thermal Rating: on line 13001-13000 : Rate B, Rate C - 0.0, 0.0 -> 223.41, 223.41
% INFO    : Updated Thermal Rating: on line 13000-13007 : Rate B, Rate C - 0.0, 0.0 -> 234.99, 234.99
% INFO    : Updated Thermal Rating: on line 13001-13002 : Rate B, Rate C - 0.0, 0.0 -> 218.76, 218.76
% INFO    : Updated Thermal Rating: on line 13002-13005 : Rate B, Rate C - 0.0, 0.0 -> 209.42, 209.42
% INFO    : Updated Thermal Rating: on line 13011-13004 : Rate B, Rate C - 0.0, 0.0 -> 193.53, 193.53
% INFO    : Updated Thermal Rating: on line 13024-13004 : Rate B, Rate C - 0.0, 0.0 -> 197.54, 197.54
% INFO    : Updated Thermal Rating: on line 13005-20006 : Rate B, Rate C - 0.0, 0.0 -> 228.45, 228.45
% INFO    : Updated Thermal Rating: on line 13005-20008 : Rate B, Rate C - 0.0, 0.0 -> 222.76, 222.76
% INFO    : Updated Thermal Rating: on line 13007-13010 : Rate B, Rate C - 0.0, 0.0 -> 260.87, 260.87
% INFO    : Updated Thermal Rating: on line 13007-13016 : Rate B, Rate C - 0.0, 0.0 -> 211.45, 211.45
% INFO    : Updated Thermal Rating: on transformer 13010-13009 : Rate B, Rate C - 0.0, 0.0 -> 482.03, 482.03
% INFO    : Updated Thermal Rating: on line 13076-13009 : Rate B, Rate C - 0.0, 0.0 -> 1184.78, 1184.78
% INFO    : Updated Thermal Rating: on line 13011-13010 : Rate B, Rate C - 0.0, 0.0 -> 228.33, 228.33
% INFO    : Updated Thermal Rating: on line 13013-13020 : Rate B, Rate C - 0.0, 0.0 -> 240.45, 240.45
% INFO    : Updated Thermal Rating: on line 13013-13024 : Rate B, Rate C - 0.0, 0.0 -> 216.52, 216.52
% INFO    : Updated Thermal Rating: on line 13022-13015 : Rate B, Rate C - 0.0, 0.0 -> 187.21, 187.21
% INFO    : Updated Thermal Rating: on line 13015-13034 : Rate B, Rate C - 0.0, 0.0 -> 215.45, 215.45
% INFO    : Updated Thermal Rating: on line 13016-13038 : Rate B, Rate C - 0.0, 0.0 -> 194.43, 194.43
% INFO    : Updated Thermal Rating: on line 13021-13017 : Rate B, Rate C - 0.0, 0.0 -> 213.66, 213.66
% INFO    : Updated Thermal Rating: on line 13017-13022 : Rate B, Rate C - 0.0, 0.0 -> 170.17, 170.17
% INFO    : Updated Thermal Rating: on line 13019-13029 : Rate B, Rate C - 0.0, 0.0 -> 225.1, 225.1
% INFO    : Updated Thermal Rating: on line 13572-13020 : Rate B, Rate C - 0.0, 0.0 -> 250.98, 250.98
% INFO    : Updated Thermal Rating: on line 13026-13021 : Rate B, Rate C - 0.0, 0.0 -> 222.81, 222.81
% INFO    : Updated Thermal Rating: on line 13022-13572 : Rate B, Rate C - 0.0, 0.0 -> 186.14, 186.14
% INFO    : Updated Thermal Rating: on line 13034-13023 : Rate B, Rate C - 0.0, 0.0 -> 221.55, 221.55
% INFO    : Updated Thermal Rating: on line 13023-13115 : Rate B, Rate C - 0.0, 0.0 -> 228.03, 228.03
% INFO    : Updated Thermal Rating: on line 13028-13026 : Rate B, Rate C - 0.0, 0.0 -> 234.63, 234.63
% INFO    : Updated Thermal Rating: on line 13081-13028 : Rate B, Rate C - 0.0, 0.0 -> 221.31, 221.31
% INFO    : Updated Thermal Rating: on line 13512-13029 : Rate B, Rate C - 0.0, 0.0 -> 250.06, 250.06
% INFO    : Updated Thermal Rating: on line 13030-13154 : Rate B, Rate C - 0.0, 0.0 -> 222.17, 222.17
% INFO    : Updated Thermal Rating: on line 13030-13647 : Rate B, Rate C - 0.0, 0.0 -> 236.56, 236.56
% INFO    : Updated Thermal Rating: on line 13033-13048 : Rate B, Rate C - 0.0, 0.0 -> 223.66, 223.66
% INFO    : Updated Thermal Rating: on line 13033-13110 : Rate B, Rate C - 0.0, 0.0 -> 187.63, 187.63
% INFO    : Updated Thermal Rating: on line 13033-20015 : Rate B, Rate C - 0.0, 0.0 -> 214.78, 214.78
% INFO    : Updated Thermal Rating: on line 13034-13046 : Rate B, Rate C - 0.0, 0.0 -> 177.3, 177.3
% INFO    : Updated Thermal Rating: on line 13035-13059 : Rate B, Rate C - 0.0, 0.0 -> 219.39, 219.39
% INFO    : Updated Thermal Rating: on line 13035-13549 : Rate B, Rate C - 0.0, 0.0 -> 226.27, 226.27
% INFO    : Updated Thermal Rating: on line 13038-13036 : Rate B, Rate C - 0.0, 0.0 -> 195.4, 195.4
% INFO    : Updated Thermal Rating: on line 13070-13036 : Rate B, Rate C - 0.0, 0.0 -> 231.41, 231.41
% INFO    : Updated Thermal Rating: on line 13039-13079 : Rate B, Rate C - 0.0, 0.0 -> 200.36, 200.36
% INFO    : Updated Thermal Rating: on line 13039-13549 : Rate B, Rate C - 0.0, 0.0 -> 222.42, 222.42
% INFO    : Updated Thermal Rating: on line 13042-13062 : Rate B, Rate C - 0.0, 0.0 -> 203.02, 203.02
% INFO    : Updated Thermal Rating: on line 13572-13042 : Rate B, Rate C - 0.0, 0.0 -> 222.56, 222.56
% INFO    : Updated Thermal Rating: on line 13045-13060 : Rate B, Rate C - 0.0, 0.0 -> 210.52, 210.52
% INFO    : Updated Thermal Rating: on line 13079-13045 : Rate B, Rate C - 0.0, 0.0 -> 223.71, 223.71
% INFO    : Updated Thermal Rating: on line 13046-13138 : Rate B, Rate C - 0.0, 0.0 -> 204.63, 204.63
% INFO    : Updated Thermal Rating: on line 13048-13051 : Rate B, Rate C - 0.0, 0.0 -> 198.06, 198.06
% INFO    : Updated Thermal Rating: on line 13048-13059 : Rate B, Rate C - 0.0, 0.0 -> 235.16, 235.16
% INFO    : Updated Thermal Rating: on line 13051-13059 : Rate B, Rate C - 0.0, 0.0 -> 233.39, 233.39
% INFO    : Updated Thermal Rating: on line 13054-13052 : Rate B, Rate C - 0.0, 0.0 -> 208.44, 208.44
% INFO    : Updated Thermal Rating: on line 13083-13052 : Rate B, Rate C - 0.0, 0.0 -> 178.87, 178.87
% INFO    : Updated Thermal Rating: on line 13054-13162 : Rate B, Rate C - 0.0, 0.0 -> 218.48, 218.48
% INFO    : Updated Thermal Rating: on line 13068-13055 : Rate B, Rate C - 0.0, 0.0 -> 207.32, 207.32
% INFO    : Updated Thermal Rating: on line 13055-13092 : Rate B, Rate C - 0.0, 0.0 -> 241.18, 241.18
% INFO    : Updated Thermal Rating: on line 13057-13068 : Rate B, Rate C - 0.0, 0.0 -> 210.9, 210.9
% INFO    : Updated Thermal Rating: on line 13057-13087 : Rate B, Rate C - 0.0, 0.0 -> 231.24, 231.24
% INFO    : Updated Thermal Rating: on transformer 13059-13058 : Rate B, Rate C - 0.0, 0.0 -> 432.62, 432.62
% INFO    : Updated Thermal Rating: on line 13171-13058 : Rate B, Rate C - 0.0, 0.0 -> 1121.38, 1121.38
% INFO    : Updated Thermal Rating: on line 13058-13548 : Rate B, Rate C - 0.0, 0.0 -> 1300.81, 1300.81
% INFO    : Updated Thermal Rating: on line 13058-20005 : Rate B, Rate C - 0.0, 0.0 -> 1125.15, 1125.15
% INFO    : Updated Thermal Rating: on line 13059-13060 : Rate B, Rate C - 0.0, 0.0 -> 190.32, 190.32
% INFO    : Updated Thermal Rating: on line 13090-13059 : Rate B, Rate C - 0.0, 0.0 -> 185.93, 185.93
% INFO    : Updated Thermal Rating: on line 13080-13061 : Rate B, Rate C - 0.0, 0.0 -> 213.79, 213.79
% INFO    : Updated Thermal Rating: on line 13082-13061 : Rate B, Rate C - 0.0, 0.0 -> 222.88, 222.88
% INFO    : Updated Thermal Rating: on line 13069-13062 : Rate B, Rate C - 0.0, 0.0 -> 208.98, 208.98
% INFO    : Updated Thermal Rating: on line 13104-13064 : Rate B, Rate C - 0.0, 0.0 -> 176.52, 176.52
% INFO    : Updated Thermal Rating: on line 13064-13218 : Rate B, Rate C - 0.0, 0.0 -> 223.63, 223.63
% INFO    : Updated Thermal Rating: on line 13065-13104 : Rate B, Rate C - 0.0, 0.0 -> 220.45, 220.45
% INFO    : Updated Thermal Rating: on line 13065-13118 : Rate B, Rate C - 0.0, 0.0 -> 189.27, 189.27
% INFO    : Updated Thermal Rating: on line 13066-13075 : Rate B, Rate C - 0.0, 0.0 -> 197.34, 197.34
% INFO    : Updated Thermal Rating: on line 13066-13109 : Rate B, Rate C - 0.0, 0.0 -> 226.24, 226.24
% INFO    : Updated Thermal Rating: on line 13067-13143 : Rate B, Rate C - 0.0, 0.0 -> 239.21, 239.21
% INFO    : Updated Thermal Rating: on line 13647-13067 : Rate B, Rate C - 0.0, 0.0 -> 249.53, 249.53
% INFO    : Updated Thermal Rating: on line 13069-13099 : Rate B, Rate C - 0.0, 0.0 -> 245.9, 245.9
% INFO    : Updated Thermal Rating: on transformer 13070-13073 : Rate B, Rate C - 0.0, 0.0 -> 107.9, 107.9
% INFO    : Updated Thermal Rating: on line 13070-13080 : Rate B, Rate C - 0.0, 0.0 -> 171.96, 171.96
% INFO    : Updated Thermal Rating: on line 13070-13129 : Rate B, Rate C - 0.0, 0.0 -> 257.25, 257.25
% INFO    : Updated Thermal Rating: on transformer 13071-13073 : Rate B, Rate C - 0.0, 0.0 -> 53.95, 53.95
% INFO    : Updated Thermal Rating: on transformer 13072-13073 : Rate B, Rate C - 0.0, 0.0 -> 53.95, 53.95
% INFO    : Updated Thermal Rating: on line 13074-13096 : Rate B, Rate C - 0.0, 0.0 -> 247.03, 247.03
% INFO    : Updated Thermal Rating: on line 13075-13103 : Rate B, Rate C - 0.0, 0.0 -> 224.49, 224.49
% INFO    : Updated Thermal Rating: on transformer 13077-13076 : Rate B, Rate C - 0.0, 0.0 -> 409.62, 409.62
% INFO    : Updated Thermal Rating: on line 13562-13076 : Rate B, Rate C - 0.0, 0.0 -> 1255.28, 1255.28
% INFO    : Updated Thermal Rating: on line 13083-13077 : Rate B, Rate C - 0.0, 0.0 -> 220.3, 220.3
% INFO    : Updated Thermal Rating: on line 13549-13079 : Rate B, Rate C - 0.0, 0.0 -> 230.89, 230.89
% INFO    : Updated Thermal Rating: on line 13081-13157 : Rate B, Rate C - 0.0, 0.0 -> 233.42, 233.42
% INFO    : Updated Thermal Rating: on line 13082-13582 : Rate B, Rate C - 0.0, 0.0 -> 253.12, 253.12
% INFO    : Updated Thermal Rating: on line 13083-13113 : Rate B, Rate C - 0.0, 0.0 -> 177.38, 177.38
% INFO    : Updated Thermal Rating: on line 13096-13084 : Rate B, Rate C - 0.0, 0.0 -> 235.76, 235.76
% INFO    : Updated Thermal Rating: on line 13084-13115 : Rate B, Rate C - 0.0, 0.0 -> 190.24, 190.24
% INFO    : Updated Thermal Rating: on transformer 13086-13089 : Rate B, Rate C - 0.0, 0.0 -> 602.26, 602.26
% INFO    : Updated Thermal Rating: on line 13086-13136 : Rate B, Rate C - 0.0, 0.0 -> 1352.56, 1352.56
% INFO    : Updated Thermal Rating: on line 13571-13086 : Rate B, Rate C - 0.0, 0.0 -> 1135.36, 1135.36
% INFO    : Updated Thermal Rating: on transformer 13087-13089 : Rate B, Rate C - 0.0, 0.0 -> 552.26, 552.26
% INFO    : Updated Thermal Rating: on line 13099-13087 : Rate B, Rate C - 0.0, 0.0 -> 328.56, 328.56
% INFO    : Updated Thermal Rating: on transformer 13088-13089 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 13107-13090 : Rate B, Rate C - 0.0, 0.0 -> 205.24, 205.24
% INFO    : Updated Thermal Rating: on line 13106-13092 : Rate B, Rate C - 0.0, 0.0 -> 254.09, 254.09
% INFO    : Updated Thermal Rating: on line 13093-13095 : Rate B, Rate C - 0.0, 0.0 -> 217.76, 217.76
% INFO    : Updated Thermal Rating: on line 13111-13093 : Rate B, Rate C - 0.0, 0.0 -> 241.66, 241.66
% INFO    : Updated Thermal Rating: on line 13095-13109 : Rate B, Rate C - 0.0, 0.0 -> 149.55, 149.55
% INFO    : Updated Thermal Rating: on line 13097-13098 : Rate B, Rate C - 0.0, 0.0 -> 190.01, 190.01
% INFO    : Updated Thermal Rating: on line 13097-13196 : Rate B, Rate C - 0.0, 0.0 -> 222.8, 222.8
% INFO    : Updated Thermal Rating: on line 13118-13098 : Rate B, Rate C - 0.0, 0.0 -> 202.0, 202.0
% INFO    : Updated Thermal Rating: on line 13099-13100 : Rate B, Rate C - 0.0, 0.0 -> 235.68, 235.68
% INFO    : Updated Thermal Rating: on line 13100-13117 : Rate B, Rate C - 0.0, 0.0 -> 206.07, 206.07
% INFO    : Updated Thermal Rating: on line 13100-13198 : Rate B, Rate C - 0.0, 0.0 -> 187.57, 187.57
% INFO    : Updated Thermal Rating: on line 13131-13101 : Rate B, Rate C - 0.0, 0.0 -> 195.24, 195.24
% INFO    : Updated Thermal Rating: on line 13563-13101 : Rate B, Rate C - 0.0, 0.0 -> 235.76, 235.76
% INFO    : Updated Thermal Rating: on line 13103-13563 : Rate B, Rate C - 0.0, 0.0 -> 251.84, 251.84
% INFO    : Updated Thermal Rating: on line 13104-13175 : Rate B, Rate C - 0.0, 0.0 -> 232.35, 232.35
% INFO    : Updated Thermal Rating: on line 13137-13105 : Rate B, Rate C - 0.0, 0.0 -> 234.77, 234.77
% INFO    : Updated Thermal Rating: on line 13105-13138 : Rate B, Rate C - 0.0, 0.0 -> 198.77, 198.77
% INFO    : Updated Thermal Rating: on line 13106-13121 : Rate B, Rate C - 0.0, 0.0 -> 237.24, 237.24
% INFO    : Updated Thermal Rating: on line 13106-13148 : Rate B, Rate C - 0.0, 0.0 -> 243.55, 243.55
% INFO    : Updated Thermal Rating: on line 13152-13107 : Rate B, Rate C - 0.0, 0.0 -> 215.93, 215.93
% INFO    : Updated Thermal Rating: on line 13131-13109 : Rate B, Rate C - 0.0, 0.0 -> 217.78, 217.78
% INFO    : Updated Thermal Rating: on line 13109-13189 : Rate B, Rate C - 0.0, 0.0 -> 218.48, 218.48
% INFO    : Updated Thermal Rating: on line 13110-13173 : Rate B, Rate C - 0.0, 0.0 -> 212.33, 212.33
% INFO    : Updated Thermal Rating: on line 13110-20028 : Rate B, Rate C - 0.0, 0.0 -> 133.25, 133.25
% INFO    : Updated Thermal Rating: on line 13111-13651 : Rate B, Rate C - 0.0, 0.0 -> 248.22, 248.22
% INFO    : Updated Thermal Rating: on line 13113-13135 : Rate B, Rate C - 0.0, 0.0 -> 212.75, 212.75
% INFO    : Updated Thermal Rating: on line 13115-13157 : Rate B, Rate C - 0.0, 0.0 -> 239.71, 239.71
% INFO    : Updated Thermal Rating: on line 13116-13130 : Rate B, Rate C - 0.0, 0.0 -> 190.92, 190.92
% INFO    : Updated Thermal Rating: on line 13116-13190 : Rate B, Rate C - 0.0, 0.0 -> 215.6, 215.6
% INFO    : Updated Thermal Rating: on line 13117-13128 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 13165-13118 : Rate B, Rate C - 0.0, 0.0 -> 244.84, 244.84
% INFO    : Updated Thermal Rating: on line 13121-13137 : Rate B, Rate C - 0.0, 0.0 -> 262.06, 262.06
% INFO    : Updated Thermal Rating: on line 13204-13123 : Rate B, Rate C - 0.0, 0.0 -> 211.15, 211.15
% INFO    : Updated Thermal Rating: on transformer 13124-13127 : Rate B, Rate C - 0.0, 0.0 -> 259.38, 259.38
% INFO    : Updated Thermal Rating: on line 13124-13128 : Rate B, Rate C - 0.0, 0.0 -> 210.27, 210.27
% INFO    : Updated Thermal Rating: on line 13124-13163 : Rate B, Rate C - 0.0, 0.0 -> 199.27, 199.27
% INFO    : Updated Thermal Rating: on line 13124-13257 : Rate B, Rate C - 0.0, 0.0 -> 224.54, 224.54
% INFO    : Updated Thermal Rating: on transformer 13125-13127 : Rate B, Rate C - 0.0, 0.0 -> 129.69, 129.69
% INFO    : Updated Thermal Rating: on transformer 13126-13127 : Rate B, Rate C - 0.0, 0.0 -> 129.69, 129.69
% INFO    : Updated Thermal Rating: on line 13129-13657 : Rate B, Rate C - 0.0, 0.0 -> 260.08, 260.08
% INFO    : Updated Thermal Rating: on line 13130-13563 : Rate B, Rate C - 0.0, 0.0 -> 213.42, 213.42
% INFO    : Updated Thermal Rating: on transformer 13131-13134 : Rate B, Rate C - 0.0, 0.0 -> 107.59, 107.59
% INFO    : Updated Thermal Rating: on line 13563-13131 : Rate B, Rate C - 0.0, 0.0 -> 233.57, 233.57
% INFO    : Updated Thermal Rating: on transformer 13132-13134 : Rate B, Rate C - 0.0, 0.0 -> 53.8, 53.8
% INFO    : Updated Thermal Rating: on transformer 13133-13134 : Rate B, Rate C - 0.0, 0.0 -> 53.8, 53.8
% INFO    : Updated Thermal Rating: on line 13135-13563 : Rate B, Rate C - 0.0, 0.0 -> 201.94, 201.94
% INFO    : Updated Thermal Rating: on line 13135-13582 : Rate B, Rate C - 0.0, 0.0 -> 232.28, 232.28
% INFO    : Updated Thermal Rating: on transformer 13137-13136 : Rate B, Rate C - 0.0, 0.0 -> 518.21, 518.21
% INFO    : Updated Thermal Rating: on line 13136-13174 : Rate B, Rate C - 0.0, 0.0 -> 1261.13, 1261.13
% INFO    : Updated Thermal Rating: on line 13136-13264 : Rate B, Rate C - 0.0, 0.0 -> 1308.25, 1308.25
% INFO    : Updated Thermal Rating: on line 13184-13138 : Rate B, Rate C - 0.0, 0.0 -> 235.47, 235.47
% INFO    : Updated Thermal Rating: on line 13140-13141 : Rate B, Rate C - 0.0, 0.0 -> 206.79, 206.79
% INFO    : Updated Thermal Rating: on line 13146-13140 : Rate B, Rate C - 0.0, 0.0 -> 207.73, 207.73
% INFO    : Updated Thermal Rating: on line 13141-13244 : Rate B, Rate C - 0.0, 0.0 -> 232.48, 232.48
% INFO    : Updated Thermal Rating: on line 13143-13154 : Rate B, Rate C - 0.0, 0.0 -> 230.2, 230.2
% INFO    : Updated Thermal Rating: on line 13144-13157 : Rate B, Rate C - 0.0, 0.0 -> 192.11, 192.11
% INFO    : Updated Thermal Rating: on line 13175-13146 : Rate B, Rate C - 0.0, 0.0 -> 244.42, 244.42
% INFO    : Updated Thermal Rating: on line 13154-13147 : Rate B, Rate C - 0.0, 0.0 -> 234.3, 234.3
% INFO    : Updated Thermal Rating: on line 13148-13196 : Rate B, Rate C - 0.0, 0.0 -> 250.32, 250.32
% INFO    : Updated Thermal Rating: on line 13150-13172 : Rate B, Rate C - 0.0, 0.0 -> 262.63, 262.63
% INFO    : Updated Thermal Rating: on line 13173-13150 : Rate B, Rate C - 0.0, 0.0 -> 245.64, 245.64
% INFO    : Updated Thermal Rating: on line 13152-13632 : Rate B, Rate C - 0.0, 0.0 -> 237.26, 237.26
% INFO    : Updated Thermal Rating: on line 13157-13155 : Rate B, Rate C - 0.0, 0.0 -> 196.6, 196.6
% INFO    : Updated Thermal Rating: on transformer 13156-13159 : Rate B, Rate C - 0.0, 0.0 -> 633.74, 633.74
% INFO    : Updated Thermal Rating: on transformer 13157-13159 : Rate B, Rate C - 0.0, 0.0 -> 433.31, 433.31
% INFO    : Updated Thermal Rating: on line 13157-13182 : Rate B, Rate C - 0.0, 0.0 -> 231.45, 231.45
% INFO    : Updated Thermal Rating: on transformer 13158-13159 : Rate B, Rate C - 0.0, 0.0 -> 200.42, 200.42
% INFO    : Updated Thermal Rating: on line 13160-13180 : Rate B, Rate C - 0.0, 0.0 -> 1134.89, 1134.89
% INFO    : Updated Thermal Rating: on line 13162-13198 : Rate B, Rate C - 0.0, 0.0 -> 173.36, 173.36
% INFO    : Updated Thermal Rating: on line 13162-13651 : Rate B, Rate C - 0.0, 0.0 -> 230.03, 230.03
% INFO    : Updated Thermal Rating: on line 13163-13259 : Rate B, Rate C - 0.0, 0.0 -> 214.15, 214.15
% INFO    : Updated Thermal Rating: on line 13165-13227 : Rate B, Rate C - 0.0, 0.0 -> 265.29, 265.29
% INFO    : Updated Thermal Rating: on line 13170-13167 : Rate B, Rate C - 0.0, 0.0 -> 233.48, 233.48
% INFO    : Updated Thermal Rating: on line 13167-13227 : Rate B, Rate C - 0.0, 0.0 -> 260.02, 260.02
% INFO    : Updated Thermal Rating: on line 13168-13632 : Rate B, Rate C - 0.0, 0.0 -> 239.15, 239.15
% INFO    : Updated Thermal Rating: on line 13655-13168 : Rate B, Rate C - 0.0, 0.0 -> 252.53, 252.53
% INFO    : Updated Thermal Rating: on line 13184-13170 : Rate B, Rate C - 0.0, 0.0 -> 181.1, 181.1
% INFO    : Updated Thermal Rating: on transformer 13172-13171 : Rate B, Rate C - 0.0, 0.0 -> 417.02, 417.02
% INFO    : Updated Thermal Rating: on line 13171-20415 : Rate B, Rate C - 0.0, 0.0 -> 1100.0, 1100.0
% INFO    : Updated Thermal Rating: on line 13213-13172 : Rate B, Rate C - 0.0, 0.0 -> 342.8, 342.8
% INFO    : Updated Thermal Rating: on transformer 13175-13174 : Rate B, Rate C - 0.0, 0.0 -> 507.15, 507.15
% INFO    : Updated Thermal Rating: on line 13174-13233 : Rate B, Rate C - 0.0, 0.0 -> 1163.27, 1163.27
% INFO    : Updated Thermal Rating: on line 13174-13264 : Rate B, Rate C - 0.0, 0.0 -> 1310.5, 1310.5
% INFO    : Updated Thermal Rating: on line 13176-13218 : Rate B, Rate C - 0.0, 0.0 -> 204.46, 204.46
% INFO    : Updated Thermal Rating: on line 13221-13176 : Rate B, Rate C - 0.0, 0.0 -> 256.36, 256.36
% INFO    : Updated Thermal Rating: on line 13178-13230 : Rate B, Rate C - 0.0, 0.0 -> 241.68, 241.68
% INFO    : Updated Thermal Rating: on line 13178-13492 : Rate B, Rate C - 0.0, 0.0 -> 199.16, 199.16
% INFO    : Updated Thermal Rating: on transformer 13181-13180 : Rate B, Rate C - 0.0, 0.0 -> 472.58, 472.58
% INFO    : Updated Thermal Rating: on line 13181-13182 : Rate B, Rate C - 0.0, 0.0 -> 240.06, 240.06
% INFO    : Updated Thermal Rating: on line 13261-13181 : Rate B, Rate C - 0.0, 0.0 -> 218.18, 218.18
% INFO    : Updated Thermal Rating: on line 13184-13239 : Rate B, Rate C - 0.0, 0.0 -> 242.16, 242.16
% INFO    : Updated Thermal Rating: on line 13252-13187 : Rate B, Rate C - 0.0, 0.0 -> 228.47, 228.47
% INFO    : Updated Thermal Rating: on line 13187-13563 : Rate B, Rate C - 0.0, 0.0 -> 185.7, 185.7
% INFO    : Updated Thermal Rating: on line 13189-13532 : Rate B, Rate C - 0.0, 0.0 -> 248.69, 248.69
% INFO    : Updated Thermal Rating: on line 13190-13582 : Rate B, Rate C - 0.0, 0.0 -> 221.49, 221.49
% INFO    : Updated Thermal Rating: on line 13194-13196 : Rate B, Rate C - 0.0, 0.0 -> 259.38, 259.38
% INFO    : Updated Thermal Rating: on line 13227-13194 : Rate B, Rate C - 0.0, 0.0 -> 275.31, 275.31
% INFO    : Updated Thermal Rating: on line 13227-13194 : Rate B, Rate C - 0.0, 0.0 -> 275.31, 275.31
% INFO    : Updated Thermal Rating: on line 13227-13194 : Rate B, Rate C - 0.0, 0.0 -> 275.31, 275.31
% INFO    : Updated Thermal Rating: on line 13194-13237 : Rate B, Rate C - 0.0, 0.0 -> 228.56, 228.56
% INFO    : Updated Thermal Rating: on line 13194-13296 : Rate B, Rate C - 0.0, 0.0 -> 283.23, 283.23
% INFO    : Updated Thermal Rating: on line 13194-13296 : Rate B, Rate C - 0.0, 0.0 -> 283.23, 283.23
% INFO    : Updated Thermal Rating: on line 13194-13296 : Rate B, Rate C - 0.0, 0.0 -> 283.23, 283.23
% INFO    : Updated Thermal Rating: on line 13492-13196 : Rate B, Rate C - 0.0, 0.0 -> 233.39, 233.39
% INFO    : Updated Thermal Rating: on line 13198-13197 : Rate B, Rate C - 0.0, 0.0 -> 200.48, 200.48
% INFO    : Updated Thermal Rating: on line 13197-13252 : Rate B, Rate C - 0.0, 0.0 -> 180.82, 180.82
% INFO    : Updated Thermal Rating: on line 13651-13197 : Rate B, Rate C - 0.0, 0.0 -> 227.95, 227.95
% INFO    : Updated Thermal Rating: on line 13200-13201 : Rate B, Rate C - 0.0, 0.0 -> 250.31, 250.31
% INFO    : Updated Thermal Rating: on line 20416-13200 : Rate B, Rate C - 0.0, 0.0 -> 264.2, 264.2
% INFO    : Updated Thermal Rating: on line 13201-13213 : Rate B, Rate C - 0.0, 0.0 -> 243.0, 243.0
% INFO    : Updated Thermal Rating: on line 13202-13210 : Rate B, Rate C - 0.0, 0.0 -> 236.69, 236.69
% INFO    : Updated Thermal Rating: on line 13212-13202 : Rate B, Rate C - 0.0, 0.0 -> 232.88, 232.88
% INFO    : Updated Thermal Rating: on line 13202-13218 : Rate B, Rate C - 0.0, 0.0 -> 232.69, 232.69
% INFO    : Updated Thermal Rating: on line 13207-13242 : Rate B, Rate C - 0.0, 0.0 -> 233.19, 233.19
% INFO    : Updated Thermal Rating: on line 13256-13207 : Rate B, Rate C - 0.0, 0.0 -> 208.82, 208.82
% INFO    : Updated Thermal Rating: on line 13210-13260 : Rate B, Rate C - 0.0, 0.0 -> 255.39, 255.39
% INFO    : Updated Thermal Rating: on line 13212-13272 : Rate B, Rate C - 0.0, 0.0 -> 263.62, 263.62
% INFO    : Updated Thermal Rating: on line 13307-13213 : Rate B, Rate C - 0.0, 0.0 -> 208.6, 208.6
% INFO    : Updated Thermal Rating: on line 13214-13224 : Rate B, Rate C - 0.0, 0.0 -> 237.39, 237.39
% INFO    : Updated Thermal Rating: on line 13279-13214 : Rate B, Rate C - 0.0, 0.0 -> 217.85, 217.85
% INFO    : Updated Thermal Rating: on line 13632-13214 : Rate B, Rate C - 0.0, 0.0 -> 201.01, 201.01
% INFO    : Updated Thermal Rating: on line 13221-13241 : Rate B, Rate C - 0.0, 0.0 -> 263.5, 263.5
% INFO    : Updated Thermal Rating: on line 13221-13268 : Rate B, Rate C - 0.0, 0.0 -> 205.69, 205.69
% INFO    : Updated Thermal Rating: on line 13224-13655 : Rate B, Rate C - 0.0, 0.0 -> 246.86, 246.86
% INFO    : Updated Thermal Rating: on transformer 13229-13232 : Rate B, Rate C - 0.0, 0.0 -> 593.64, 593.64
% INFO    : Updated Thermal Rating: on transformer 13230-13232 : Rate B, Rate C - 0.0, 0.0 -> 420.79, 420.79
% INFO    : Updated Thermal Rating: on line 13230-13236 : Rate B, Rate C - 0.0, 0.0 -> 240.12, 240.12
% INFO    : Updated Thermal Rating: on line 13230-13250 : Rate B, Rate C - 0.0, 0.0 -> 250.88, 250.88
% INFO    : Updated Thermal Rating: on transformer 13231-13232 : Rate B, Rate C - 0.0, 0.0 -> 172.85, 172.85
% INFO    : Updated Thermal Rating: on line 13233-13264 : Rate B, Rate C - 0.0, 0.0 -> 1242.89, 1242.89
% INFO    : Updated Thermal Rating: on line 13244-13236 : Rate B, Rate C - 0.0, 0.0 -> 196.58, 196.58
% INFO    : Updated Thermal Rating: on line 13277-13237 : Rate B, Rate C - 0.0, 0.0 -> 190.75, 190.75
% INFO    : Updated Thermal Rating: on line 13237-13293 : Rate B, Rate C - 0.0, 0.0 -> 235.31, 235.31
% INFO    : Updated Thermal Rating: on line 13239-13344 : Rate B, Rate C - 0.0, 0.0 -> 249.95, 249.95
% INFO    : Updated Thermal Rating: on line 13241-13246 : Rate B, Rate C - 0.0, 0.0 -> 255.02, 255.02
% INFO    : Updated Thermal Rating: on line 13253-13241 : Rate B, Rate C - 0.0, 0.0 -> 239.07, 239.07
% INFO    : Updated Thermal Rating: on line 13242-13294 : Rate B, Rate C - 0.0, 0.0 -> 251.38, 251.38
% INFO    : Updated Thermal Rating: on line 13244-13262 : Rate B, Rate C - 0.0, 0.0 -> 239.62, 239.62
% INFO    : Updated Thermal Rating: on line 13246-13304 : Rate B, Rate C - 0.0, 0.0 -> 271.33, 271.33
% INFO    : Updated Thermal Rating: on line 13249-13253 : Rate B, Rate C - 0.0, 0.0 -> 262.88, 262.88
% INFO    : Updated Thermal Rating: on line 13260-13249 : Rate B, Rate C - 0.0, 0.0 -> 375.19, 375.19
% INFO    : Updated Thermal Rating: on line 13272-13250 : Rate B, Rate C - 0.0, 0.0 -> 275.71, 275.71
% INFO    : Updated Thermal Rating: on line 13272-13250 : Rate B, Rate C - 0.0, 0.0 -> 275.71, 275.71
% INFO    : Updated Thermal Rating: on line 13272-13250 : Rate B, Rate C - 0.0, 0.0 -> 275.71, 275.71
% INFO    : Updated Thermal Rating: on line 13250-13274 : Rate B, Rate C - 0.0, 0.0 -> 268.46, 268.46
% INFO    : Updated Thermal Rating: on line 13252-13651 : Rate B, Rate C - 0.0, 0.0 -> 252.19, 252.19
% INFO    : Updated Thermal Rating: on line 13261-13253 : Rate B, Rate C - 0.0, 0.0 -> 168.72, 168.72
% INFO    : Updated Thermal Rating: on line 13256-13268 : Rate B, Rate C - 0.0, 0.0 -> 210.66, 210.66
% INFO    : Updated Thermal Rating: on line 13257-13355 : Rate B, Rate C - 0.0, 0.0 -> 250.93, 250.93
% INFO    : Updated Thermal Rating: on line 13259-13313 : Rate B, Rate C - 0.0, 0.0 -> 236.77, 236.77
% INFO    : Updated Thermal Rating: on line 13301-13260 : Rate B, Rate C - 0.0, 0.0 -> 214.04, 214.04
% INFO    : Updated Thermal Rating: on line 13262-13274 : Rate B, Rate C - 0.0, 0.0 -> 263.42, 263.42
% INFO    : Updated Thermal Rating: on transformer 13264-13263 : Rate B, Rate C - 0.0, 0.0 -> 1663.77, 1663.77
% INFO    : Updated Thermal Rating: on transformer 13264-13263 : Rate B, Rate C - 0.0, 0.0 -> 1663.77, 1663.77
% INFO    : Updated Thermal Rating: on transformer 13264-13263 : Rate B, Rate C - 0.0, 0.0 -> 1663.77, 1663.77
% INFO    : Updated Thermal Rating: on line 13649-13263 : Rate B, Rate C - 0.0, 0.0 -> 3979.9, 3979.9
% INFO    : Updated Thermal Rating: on line 13263-13666 : Rate B, Rate C - 0.0, 0.0 -> 4246.52, 4246.52
% INFO    : Updated Thermal Rating: on transformer 13265-13264 : Rate B, Rate C - 0.0, 0.0 -> 490.32, 490.32
% INFO    : Updated Thermal Rating: on line 13264-13302 : Rate B, Rate C - 0.0, 0.0 -> 1260.23, 1260.23
% INFO    : Updated Thermal Rating: on line 13324-13264 : Rate B, Rate C - 0.0, 0.0 -> 1286.19, 1286.19
% INFO    : Updated Thermal Rating: on line 13295-13265 : Rate B, Rate C - 0.0, 0.0 -> 251.94, 251.94
% INFO    : Updated Thermal Rating: on line 13265-13318 : Rate B, Rate C - 0.0, 0.0 -> 209.98, 209.98
% INFO    : Updated Thermal Rating: on line 13268-13281 : Rate B, Rate C - 0.0, 0.0 -> 249.5, 249.5
% INFO    : Updated Thermal Rating: on line 13272-13304 : Rate B, Rate C - 0.0, 0.0 -> 285.17, 285.17
% INFO    : Updated Thermal Rating: on line 13272-13304 : Rate B, Rate C - 0.0, 0.0 -> 285.17, 285.17
% INFO    : Updated Thermal Rating: on line 13272-13304 : Rate B, Rate C - 0.0, 0.0 -> 285.17, 285.17
% INFO    : Updated Thermal Rating: on line 13273-13323 : Rate B, Rate C - 0.0, 0.0 -> 225.01, 225.01
% INFO    : Updated Thermal Rating: on line 13273-13325 : Rate B, Rate C - 0.0, 0.0 -> 210.47, 210.47
% INFO    : Updated Thermal Rating: on line 13273-13333 : Rate B, Rate C - 0.0, 0.0 -> 290.52, 290.52
% INFO    : Updated Thermal Rating: on line 13274-13284 : Rate B, Rate C - 0.0, 0.0 -> 202.59, 202.59
% INFO    : Updated Thermal Rating: on line 13284-13275 : Rate B, Rate C - 0.0, 0.0 -> 228.32, 228.32
% INFO    : Updated Thermal Rating: on line 13286-13275 : Rate B, Rate C - 0.0, 0.0 -> 247.18, 247.18
% INFO    : Updated Thermal Rating: on line 13277-13325 : Rate B, Rate C - 0.0, 0.0 -> 234.81, 234.81
% INFO    : Updated Thermal Rating: on line 13307-13279 : Rate B, Rate C - 0.0, 0.0 -> 248.54, 248.54
% INFO    : Updated Thermal Rating: on line 13279-13367 : Rate B, Rate C - 0.0, 0.0 -> 246.19, 246.19
% INFO    : Updated Thermal Rating: on line 13281-13304 : Rate B, Rate C - 0.0, 0.0 -> 269.43, 269.43
% INFO    : Updated Thermal Rating: on line 13286-13283 : Rate B, Rate C - 0.0, 0.0 -> 219.38, 219.38
% INFO    : Updated Thermal Rating: on line 13283-13294 : Rate B, Rate C - 0.0, 0.0 -> 183.02, 183.02
% INFO    : Updated Thermal Rating: on line 13283-13318 : Rate B, Rate C - 0.0, 0.0 -> 250.96, 250.96
% INFO    : Updated Thermal Rating: on line 13285-13289 : Rate B, Rate C - 0.0, 0.0 -> 274.29, 274.29
% INFO    : Updated Thermal Rating: on line 13285-13289 : Rate B, Rate C - 0.0, 0.0 -> 274.29, 274.29
% INFO    : Updated Thermal Rating: on line 13285-13301 : Rate B, Rate C - 0.0, 0.0 -> 220.99, 220.99
% INFO    : Updated Thermal Rating: on line 13286-13295 : Rate B, Rate C - 0.0, 0.0 -> 253.07, 253.07
% INFO    : Updated Thermal Rating: on line 13289-13297 : Rate B, Rate C - 0.0, 0.0 -> 230.03, 230.03
% INFO    : Updated Thermal Rating: on line 13303-13289 : Rate B, Rate C - 0.0, 0.0 -> 281.4, 281.4
% INFO    : Updated Thermal Rating: on line 13303-13289 : Rate B, Rate C - 0.0, 0.0 -> 281.4, 281.4
% INFO    : Updated Thermal Rating: on line 13303-13289 : Rate B, Rate C - 0.0, 0.0 -> 281.4, 281.4
% INFO    : Updated Thermal Rating: on line 13293-13294 : Rate B, Rate C - 0.0, 0.0 -> 259.97, 259.97
% INFO    : Updated Thermal Rating: on line 13294-13325 : Rate B, Rate C - 0.0, 0.0 -> 274.36, 274.36
% INFO    : Updated Thermal Rating: on line 13294-13325 : Rate B, Rate C - 0.0, 0.0 -> 274.36, 274.36
% INFO    : Updated Thermal Rating: on line 13294-13325 : Rate B, Rate C - 0.0, 0.0 -> 274.36, 274.36
% INFO    : Updated Thermal Rating: on line 13299-13295 : Rate B, Rate C - 0.0, 0.0 -> 216.94, 216.94
% INFO    : Updated Thermal Rating: on line 13295-13328 : Rate B, Rate C - 0.0, 0.0 -> 240.44, 240.44
% INFO    : Updated Thermal Rating: on line 13305-13296 : Rate B, Rate C - 0.0, 0.0 -> 225.3, 225.3
% INFO    : Updated Thermal Rating: on line 13333-13296 : Rate B, Rate C - 0.0, 0.0 -> 286.54, 286.54
% INFO    : Updated Thermal Rating: on line 13333-13296 : Rate B, Rate C - 0.0, 0.0 -> 286.54, 286.54
% INFO    : Updated Thermal Rating: on line 13333-13296 : Rate B, Rate C - 0.0, 0.0 -> 286.54, 286.54
% INFO    : Updated Thermal Rating: on line 13296-13351 : Rate B, Rate C - 0.0, 0.0 -> 233.55, 233.55
% INFO    : Updated Thermal Rating: on line 13297-13346 : Rate B, Rate C - 0.0, 0.0 -> 197.83, 197.83
% INFO    : Updated Thermal Rating: on line 13299-13322 : Rate B, Rate C - 0.0, 0.0 -> 135.78, 135.78
% INFO    : Updated Thermal Rating: on transformer 13303-13302 : Rate B, Rate C - 0.0, 0.0 -> 655.05, 655.05
% INFO    : Updated Thermal Rating: on transformer 13303-13302 : Rate B, Rate C - 0.0, 0.0 -> 655.05, 655.05
% INFO    : Updated Thermal Rating: on transformer 13303-13302 : Rate B, Rate C - 0.0, 0.0 -> 655.05, 655.05
% INFO    : Updated Thermal Rating: on transformer 13303-13302 : Rate B, Rate C - 0.0, 0.0 -> 655.05, 655.05
% INFO    : Updated Thermal Rating: on transformer 13303-13302 : Rate B, Rate C - 0.0, 0.0 -> 655.05, 655.05
% INFO    : Updated Thermal Rating: on line 13302-13667 : Rate B, Rate C - 0.0, 0.0 -> 1314.46, 1314.46
% INFO    : Updated Thermal Rating: on line 13303-13304 : Rate B, Rate C - 0.0, 0.0 -> 287.79, 287.79
% INFO    : Updated Thermal Rating: on line 13303-13304 : Rate B, Rate C - 0.0, 0.0 -> 287.79, 287.79
% INFO    : Updated Thermal Rating: on line 13303-13304 : Rate B, Rate C - 0.0, 0.0 -> 287.79, 287.79
% INFO    : Updated Thermal Rating: on line 13303-13304 : Rate B, Rate C - 0.0, 0.0 -> 287.79, 287.79
% INFO    : Updated Thermal Rating: on line 13303-13304 : Rate B, Rate C - 0.0, 0.0 -> 287.79, 287.79
% INFO    : Updated Thermal Rating: on line 13310-13303 : Rate B, Rate C - 0.0, 0.0 -> 276.59, 276.59
% INFO    : Updated Thermal Rating: on line 13310-13303 : Rate B, Rate C - 0.0, 0.0 -> 276.59, 276.59
% INFO    : Updated Thermal Rating: on line 13310-13303 : Rate B, Rate C - 0.0, 0.0 -> 276.59, 276.59
% INFO    : Updated Thermal Rating: on line 13303-13312 : Rate B, Rate C - 0.0, 0.0 -> 218.86, 218.86
% INFO    : Updated Thermal Rating: on line 13303-13337 : Rate B, Rate C - 0.0, 0.0 -> 236.31, 236.31
% INFO    : Updated Thermal Rating: on line 13304-13318 : Rate B, Rate C - 0.0, 0.0 -> 241.92, 241.92
% INFO    : Updated Thermal Rating: on line 13304-13328 : Rate B, Rate C - 0.0, 0.0 -> 223.28, 223.28
% INFO    : Updated Thermal Rating: on line 13344-13305 : Rate B, Rate C - 0.0, 0.0 -> 197.52, 197.52
% INFO    : Updated Thermal Rating: on line 13310-13330 : Rate B, Rate C - 0.0, 0.0 -> 253.39, 253.39
% INFO    : Updated Thermal Rating: on line 13338-13310 : Rate B, Rate C - 0.0, 0.0 -> 259.39, 259.39
% INFO    : Updated Thermal Rating: on line 13313-13579 : Rate B, Rate C - 0.0, 0.0 -> 257.48, 257.48
% INFO    : Updated Thermal Rating: on line 13318-13330 : Rate B, Rate C - 0.0, 0.0 -> 209.46, 209.46
% INFO    : Updated Thermal Rating: on line 13319-13323 : Rate B, Rate C - 0.0, 0.0 -> 196.96, 196.96
% INFO    : Updated Thermal Rating: on line 13319-13341 : Rate B, Rate C - 0.0, 0.0 -> 232.77, 232.77
% INFO    : Updated Thermal Rating: on line 13322-13351 : Rate B, Rate C - 0.0, 0.0 -> 224.24, 224.24
% INFO    : Updated Thermal Rating: on transformer 13324-13327 : Rate B, Rate C - 0.0, 0.0 -> 664.21, 664.21
% INFO    : Updated Thermal Rating: on transformer 13325-13327 : Rate B, Rate C - 0.0, 0.0 -> 564.21, 564.21
% INFO    : Updated Thermal Rating: on transformer 13326-13327 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 13328-13338 : Rate B, Rate C - 0.0, 0.0 -> 232.11, 232.11
% INFO    : Updated Thermal Rating: on line 13330-13334 : Rate B, Rate C - 0.0, 0.0 -> 218.34, 218.34
% INFO    : Updated Thermal Rating: on line 13333-13351 : Rate B, Rate C - 0.0, 0.0 -> 237.32, 237.32
% INFO    : Updated Thermal Rating: on line 13333-13365 : Rate B, Rate C - 0.0, 0.0 -> 286.79, 286.79
% INFO    : Updated Thermal Rating: on line 13333-13365 : Rate B, Rate C - 0.0, 0.0 -> 286.79, 286.79
% INFO    : Updated Thermal Rating: on line 13333-13365 : Rate B, Rate C - 0.0, 0.0 -> 286.79, 286.79
% INFO    : Updated Thermal Rating: on line 13333-13365 : Rate B, Rate C - 0.0, 0.0 -> 286.79, 286.79
% INFO    : Updated Thermal Rating: on line 13334-13350 : Rate B, Rate C - 0.0, 0.0 -> 177.33, 177.33
% INFO    : Updated Thermal Rating: on line 13356-13335 : Rate B, Rate C - 0.0, 0.0 -> 177.51, 177.51
% INFO    : Updated Thermal Rating: on line 13337-13347 : Rate B, Rate C - 0.0, 0.0 -> 191.79, 191.79
% INFO    : Updated Thermal Rating: on transformer 13341-13340 : Rate B, Rate C - 0.0, 0.0 -> 456.28, 456.28
% INFO    : Updated Thermal Rating: on line 13351-13341 : Rate B, Rate C - 0.0, 0.0 -> 229.5, 229.5
% INFO    : Updated Thermal Rating: on line 13341-13356 : Rate B, Rate C - 0.0, 0.0 -> 228.82, 228.82
% INFO    : Updated Thermal Rating: on line 13344-13361 : Rate B, Rate C - 0.0, 0.0 -> 247.62, 247.62
% INFO    : Updated Thermal Rating: on line 13357-13346 : Rate B, Rate C - 0.0, 0.0 -> 228.91, 228.91
% INFO    : Updated Thermal Rating: on line 13346-13360 : Rate B, Rate C - 0.0, 0.0 -> 223.21, 223.21
% INFO    : Updated Thermal Rating: on line 13489-13355 : Rate B, Rate C - 0.0, 0.0 -> 259.53, 259.53
% INFO    : Updated Thermal Rating: on line 13365-13357 : Rate B, Rate C - 0.0, 0.0 -> 286.7, 286.7
% INFO    : Updated Thermal Rating: on line 13358-13513 : Rate B, Rate C - 0.0, 0.0 -> 206.72, 206.72
% INFO    : Updated Thermal Rating: on line 13532-13358 : Rate B, Rate C - 0.0, 0.0 -> 215.98, 215.98
% INFO    : Updated Thermal Rating: on line 13360-13359 : Rate B, Rate C - 0.0, 0.0 -> 195.28, 195.28
% INFO    : Updated Thermal Rating: on line 13361-13593 : Rate B, Rate C - 0.0, 0.0 -> 260.01, 260.01
% INFO    : Updated Thermal Rating: on line 13365-13401 : Rate B, Rate C - 0.0, 0.0 -> 287.37, 287.37
% INFO    : Updated Thermal Rating: on line 13365-13401 : Rate B, Rate C - 0.0, 0.0 -> 287.37, 287.37
% INFO    : Updated Thermal Rating: on line 13365-13401 : Rate B, Rate C - 0.0, 0.0 -> 287.37, 287.37
% INFO    : Updated Thermal Rating: on line 13365-13401 : Rate B, Rate C - 0.0, 0.0 -> 287.37, 287.37
% INFO    : Updated Thermal Rating: on line 13365-13401 : Rate B, Rate C - 0.0, 0.0 -> 287.37, 287.37
% INFO    : Updated Thermal Rating: on line 13367-13375 : Rate B, Rate C - 0.0, 0.0 -> 216.8, 216.8
% INFO    : Updated Thermal Rating: on line 13367-13460 : Rate B, Rate C - 0.0, 0.0 -> 253.98, 253.98
% INFO    : Updated Thermal Rating: on line 13454-13368 : Rate B, Rate C - 0.0, 0.0 -> 178.75, 178.75
% INFO    : Updated Thermal Rating: on line 13383-13370 : Rate B, Rate C - 0.0, 0.0 -> 193.89, 193.89
% INFO    : Updated Thermal Rating: on line 13384-13370 : Rate B, Rate C - 0.0, 0.0 -> 168.19, 168.19
% INFO    : Updated Thermal Rating: on line 13370-13522 : Rate B, Rate C - 0.0, 0.0 -> 226.07, 226.07
% INFO    : Updated Thermal Rating: on line 13372-13383 : Rate B, Rate C - 0.0, 0.0 -> 213.58, 213.58
% INFO    : Updated Thermal Rating: on line 13372-13556 : Rate B, Rate C - 0.0, 0.0 -> 236.09, 236.09
% INFO    : Updated Thermal Rating: on line 13375-13382 : Rate B, Rate C - 0.0, 0.0 -> 224.64, 224.64
% INFO    : Updated Thermal Rating: on transformer 13376-13379 : Rate B, Rate C - 0.0, 0.0 -> 107.17, 107.17
% INFO    : Updated Thermal Rating: on line 13380-13376 : Rate B, Rate C - 0.0, 0.0 -> 239.02, 239.02
% INFO    : Updated Thermal Rating: on transformer 13377-13379 : Rate B, Rate C - 0.0, 0.0 -> 53.59, 53.59
% INFO    : Updated Thermal Rating: on transformer 13378-13379 : Rate B, Rate C - 0.0, 0.0 -> 53.59, 53.59
% INFO    : Updated Thermal Rating: on line 13381-13382 : Rate B, Rate C - 0.0, 0.0 -> 243.71, 243.71
% INFO    : Updated Thermal Rating: on line 13381-13388 : Rate B, Rate C - 0.0, 0.0 -> 250.81, 250.81
% INFO    : Updated Thermal Rating: on line 13383-20271 : Rate B, Rate C - 0.0, 0.0 -> 177.89, 177.89
% INFO    : Updated Thermal Rating: on line 13383-20323 : Rate B, Rate C - 0.0, 0.0 -> 191.16, 191.16
% INFO    : Updated Thermal Rating: on line 13383-20475 : Rate B, Rate C - 0.0, 0.0 -> 189.84, 189.84
% INFO    : Updated Thermal Rating: on line 13383-20495 : Rate B, Rate C - 0.0, 0.0 -> 191.38, 191.38
% INFO    : Updated Thermal Rating: on line 13384-13408 : Rate B, Rate C - 0.0, 0.0 -> 189.56, 189.56
% INFO    : Updated Thermal Rating: on line 13385-13489 : Rate B, Rate C - 0.0, 0.0 -> 232.82, 232.82
% INFO    : Updated Thermal Rating: on line 13385-13663 : Rate B, Rate C - 0.0, 0.0 -> 237.66, 237.66
% INFO    : Updated Thermal Rating: on line 13387-13388 : Rate B, Rate C - 0.0, 0.0 -> 206.83, 206.83
% INFO    : Updated Thermal Rating: on line 13387-13392 : Rate B, Rate C - 0.0, 0.0 -> 235.95, 235.95
% INFO    : Updated Thermal Rating: on line 13387-13403 : Rate B, Rate C - 0.0, 0.0 -> 202.97, 202.97
% INFO    : Updated Thermal Rating: on line 13387-13406 : Rate B, Rate C - 0.0, 0.0 -> 218.64, 218.64
% INFO    : Updated Thermal Rating: on line 13388-13399 : Rate B, Rate C - 0.0, 0.0 -> 271.87, 271.87
% INFO    : Updated Thermal Rating: on line 13390-13394 : Rate B, Rate C - 0.0, 0.0 -> 276.56, 276.56
% INFO    : Updated Thermal Rating: on line 13390-13394 : Rate B, Rate C - 0.0, 0.0 -> 276.56, 276.56
% INFO    : Updated Thermal Rating: on line 13390-13394 : Rate B, Rate C - 0.0, 0.0 -> 276.56, 276.56
% INFO    : Updated Thermal Rating: on line 13402-13390 : Rate B, Rate C - 0.0, 0.0 -> 282.42, 282.42
% INFO    : Updated Thermal Rating: on line 13402-13390 : Rate B, Rate C - 0.0, 0.0 -> 282.42, 282.42
% INFO    : Updated Thermal Rating: on line 13402-13390 : Rate B, Rate C - 0.0, 0.0 -> 282.42, 282.42
% INFO    : Updated Thermal Rating: on line 13392-13394 : Rate B, Rate C - 0.0, 0.0 -> 260.83, 260.83
% INFO    : Updated Thermal Rating: on line 13394-13397 : Rate B, Rate C - 0.0, 0.0 -> 272.82, 272.82
% INFO    : Updated Thermal Rating: on transformer 13397-13396 : Rate B, Rate C - 0.0, 0.0 -> 521.64, 521.64
% INFO    : Updated Thermal Rating: on line 13399-13397 : Rate B, Rate C - 0.0, 0.0 -> 274.35, 274.35
% INFO    : Updated Thermal Rating: on line 13399-13397 : Rate B, Rate C - 0.0, 0.0 -> 274.35, 274.35
% INFO    : Updated Thermal Rating: on line 13398-13524 : Rate B, Rate C - 0.0, 0.0 -> 1139.9, 1139.9
% INFO    : Updated Thermal Rating: on line 13401-13622 : Rate B, Rate C - 0.0, 0.0 -> 400.97, 400.97
% INFO    : Updated Thermal Rating: on line 13403-13402 : Rate B, Rate C - 0.0, 0.0 -> 236.77, 236.77
% INFO    : Updated Thermal Rating: on line 13529-13402 : Rate B, Rate C - 0.0, 0.0 -> 286.5, 286.5
% INFO    : Updated Thermal Rating: on line 13529-13402 : Rate B, Rate C - 0.0, 0.0 -> 286.5, 286.5
% INFO    : Updated Thermal Rating: on line 13529-13402 : Rate B, Rate C - 0.0, 0.0 -> 286.5, 286.5
% INFO    : Updated Thermal Rating: on line 13408-13406 : Rate B, Rate C - 0.0, 0.0 -> 214.83, 214.83
% INFO    : Updated Thermal Rating: on line 20271-13408 : Rate B, Rate C - 0.0, 0.0 -> 178.92, 178.92
% INFO    : Updated Thermal Rating: on line 13410-13553 : Rate B, Rate C - 0.0, 0.0 -> 243.74, 243.74
% INFO    : Updated Thermal Rating: on line 13676-13411 : Rate B, Rate C - 0.0, 0.0 -> 210.71, 210.71
% INFO    : Updated Thermal Rating: on line 13411-13697 : Rate B, Rate C - 0.0, 0.0 -> 198.19, 198.19
% INFO    : Updated Thermal Rating: on line 13412-13615 : Rate B, Rate C - 0.0, 0.0 -> 177.63, 177.63
% INFO    : Updated Thermal Rating: on line 13414-13676 : Rate B, Rate C - 0.0, 0.0 -> 213.67, 213.67
% INFO    : Updated Thermal Rating: on line 13416-13426 : Rate B, Rate C - 0.0, 0.0 -> 204.03, 204.03
% INFO    : Updated Thermal Rating: on line 13508-13416 : Rate B, Rate C - 0.0, 0.0 -> 229.74, 229.74
% INFO    : Updated Thermal Rating: on line 13418-13538 : Rate B, Rate C - 0.0, 0.0 -> 229.14, 229.14
% INFO    : Updated Thermal Rating: on line 13419-13423 : Rate B, Rate C - 0.0, 0.0 -> 217.81, 217.81
% INFO    : Updated Thermal Rating: on line 13419-13425 : Rate B, Rate C - 0.0, 0.0 -> 230.68, 230.68
% INFO    : Updated Thermal Rating: on line 13423-74000 : Rate B, Rate C - 0.0, 0.0 -> 198.18, 198.18
% INFO    : Updated Thermal Rating: on line 13426-13425 : Rate B, Rate C - 0.0, 0.0 -> 209.62, 209.62
% INFO    : Updated Thermal Rating: on line 13425-13615 : Rate B, Rate C - 0.0, 0.0 -> 213.86, 213.86
% INFO    : Updated Thermal Rating: on line 13426-13573 : Rate B, Rate C - 0.0, 0.0 -> 231.27, 231.27
% INFO    : Updated Thermal Rating: on line 13427-13442 : Rate B, Rate C - 0.0, 0.0 -> 245.22, 245.22
% INFO    : Updated Thermal Rating: on line 13432-13430 : Rate B, Rate C - 0.0, 0.0 -> 234.44, 234.44
% INFO    : Updated Thermal Rating: on transformer 13431-13434 : Rate B, Rate C - 0.0, 0.0 -> 468.64, 468.64
% INFO    : Updated Thermal Rating: on transformer 13432-13434 : Rate B, Rate C - 0.0, 0.0 -> 393.64, 393.64
% INFO    : Updated Thermal Rating: on transformer 13432-13437 : Rate B, Rate C - 0.0, 0.0 -> 107.14, 107.14
% INFO    : Updated Thermal Rating: on transformer 13433-13434 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 13435-13437 : Rate B, Rate C - 0.0, 0.0 -> 53.57, 53.57
% INFO    : Updated Thermal Rating: on transformer 13436-13437 : Rate B, Rate C - 0.0, 0.0 -> 53.57, 53.57
% INFO    : Updated Thermal Rating: on line 13643-13438 : Rate B, Rate C - 0.0, 0.0 -> 1167.89, 1167.89
% INFO    : Updated Thermal Rating: on line 13439-13440 : Rate B, Rate C - 0.0, 0.0 -> 208.48, 208.48
% INFO    : Updated Thermal Rating: on line 13440-13446 : Rate B, Rate C - 0.0, 0.0 -> 186.8, 186.8
% INFO    : Updated Thermal Rating: on line 13440-13607 : Rate B, Rate C - 0.0, 0.0 -> 220.2, 220.2
% INFO    : Updated Thermal Rating: on line 13441-13442 : Rate B, Rate C - 0.0, 0.0 -> 236.25, 236.25
% INFO    : Updated Thermal Rating: on line 13445-13441 : Rate B, Rate C - 0.0, 0.0 -> 253.18, 253.18
% INFO    : Updated Thermal Rating: on line 13482-13441 : Rate B, Rate C - 0.0, 0.0 -> 233.42, 233.42
% INFO    : Updated Thermal Rating: on line 13445-13688 : Rate B, Rate C - 0.0, 0.0 -> 212.92, 212.92
% INFO    : Updated Thermal Rating: on line 74000-13445 : Rate B, Rate C - 0.0, 0.0 -> 239.76, 239.76
% INFO    : Updated Thermal Rating: on line 13446-13449 : Rate B, Rate C - 0.0, 0.0 -> 210.84, 210.84
% INFO    : Updated Thermal Rating: on line 74013-13446 : Rate B, Rate C - 0.0, 0.0 -> 221.33, 221.33
% INFO    : Updated Thermal Rating: on transformer 13448-13447 : Rate B, Rate C - 0.0, 0.0 -> 449.04, 449.04
% INFO    : Updated Thermal Rating: on line 13447-74218 : Rate B, Rate C - 0.0, 0.0 -> 1213.15, 1213.15
% INFO    : Updated Thermal Rating: on line 13447-74250 : Rate B, Rate C - 0.0, 0.0 -> 1393.24, 1393.24
% INFO    : Updated Thermal Rating: on line 74330-13447 : Rate B, Rate C - 0.0, 0.0 -> 1155.33, 1155.33
% INFO    : Updated Thermal Rating: on line 13448-13688 : Rate B, Rate C - 0.0, 0.0 -> 234.85, 234.85
% INFO    : Updated Thermal Rating: on line 74004-13448 : Rate B, Rate C - 0.0, 0.0 -> 239.01, 239.01
% INFO    : Updated Thermal Rating: on line 13448-74012 : Rate B, Rate C - 0.0, 0.0 -> 247.62, 247.62
% INFO    : Updated Thermal Rating: on line 13448-74109 : Rate B, Rate C - 0.0, 0.0 -> 223.92, 223.92
% INFO    : Updated Thermal Rating: on line 13448-74327 : Rate B, Rate C - 0.0, 0.0 -> 252.32, 252.32
% INFO    : Updated Thermal Rating: on transformer 13449-13452 : Rate B, Rate C - 0.0, 0.0 -> 107.03, 107.03
% INFO    : Updated Thermal Rating: on line 13449-74115 : Rate B, Rate C - 0.0, 0.0 -> 207.09, 207.09
% INFO    : Updated Thermal Rating: on line 13449-74251 : Rate B, Rate C - 0.0, 0.0 -> 227.52, 227.52
% INFO    : Updated Thermal Rating: on transformer 13450-13452 : Rate B, Rate C - 0.0, 0.0 -> 53.52, 53.52
% INFO    : Updated Thermal Rating: on transformer 13451-13452 : Rate B, Rate C - 0.0, 0.0 -> 53.52, 53.52
% INFO    : Updated Thermal Rating: on transformer 13453-13456 : Rate B, Rate C - 0.0, 0.0 -> 409.12, 409.12
% INFO    : Updated Thermal Rating: on transformer 13454-13456 : Rate B, Rate C - 0.0, 0.0 -> 284.12, 284.12
% INFO    : Updated Thermal Rating: on line 13532-13454 : Rate B, Rate C - 0.0, 0.0 -> 257.63, 257.63
% INFO    : Updated Thermal Rating: on transformer 13455-13456 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 13524-13457 : Rate B, Rate C - 0.0, 0.0 -> 1267.1, 1267.1
% INFO    : Updated Thermal Rating: on line 13457-13650 : Rate B, Rate C - 0.0, 0.0 -> 1256.0, 1256.0
% INFO    : Updated Thermal Rating: on line 13591-13458 : Rate B, Rate C - 0.0, 0.0 -> 230.01, 230.01
% INFO    : Updated Thermal Rating: on transformer 13460-13459 : Rate B, Rate C - 0.0, 0.0 -> 373.53, 373.53
% INFO    : Updated Thermal Rating: on line 13459-13555 : Rate B, Rate C - 0.0, 0.0 -> 1294.78, 1294.78
% INFO    : Updated Thermal Rating: on line 13459-20291 : Rate B, Rate C - 0.0, 0.0 -> 1214.22, 1214.22
% INFO    : Updated Thermal Rating: on line 20415-13459 : Rate B, Rate C - 0.0, 0.0 -> 1071.13, 1071.13
% INFO    : Updated Thermal Rating: on line 13460-20048 : Rate B, Rate C - 0.0, 0.0 -> 224.44, 224.44
% INFO    : Updated Thermal Rating: on line 13463-13647 : Rate B, Rate C - 0.0, 0.0 -> 244.93, 244.93
% INFO    : Updated Thermal Rating: on line 13463-13690 : Rate B, Rate C - 0.0, 0.0 -> 199.11, 199.11
% INFO    : Updated Thermal Rating: on transformer 13465-13464 : Rate B, Rate C - 0.0, 0.0 -> 350.42, 350.42
% INFO    : Updated Thermal Rating: on transformer 13464-13466 : Rate B, Rate C - 0.0, 0.0 -> 456.82, 456.82
% INFO    : Updated Thermal Rating: on line 13464-13643 : Rate B, Rate C - 0.0, 0.0 -> 1022.57, 1022.57
% INFO    : Updated Thermal Rating: on transformer 13467-13468 : Rate B, Rate C - 0.0, 0.0 -> 130.65, 130.65
% INFO    : Updated Thermal Rating: on line 13591-13467 : Rate B, Rate C - 0.0, 0.0 -> 261.61, 261.61
% INFO    : Updated Thermal Rating: on line 13617-13467 : Rate B, Rate C - 0.0, 0.0 -> 208.57, 208.57
% INFO    : Updated Thermal Rating: on transformer 13471-13470 : Rate B, Rate C - 0.0, 0.0 -> 1276.43, 1276.43
% INFO    : Updated Thermal Rating: on transformer 13470-13475 : Rate B, Rate C - 0.0, 0.0 -> 1379.97, 1379.97
% INFO    : Updated Thermal Rating: on transformer 13470-13476 : Rate B, Rate C - 0.0, 0.0 -> 1379.32, 1379.32
% INFO    : Updated Thermal Rating: on transformer 13470-13477 : Rate B, Rate C - 0.0, 0.0 -> 1378.05, 1378.05
% INFO    : Updated Thermal Rating: on transformer 13470-13478 : Rate B, Rate C - 0.0, 0.0 -> 1377.09, 1377.09
% INFO    : Updated Thermal Rating: on transformer 13470-13479 : Rate B, Rate C - 0.0, 0.0 -> 1375.54, 1375.54
% INFO    : Updated Thermal Rating: on transformer 13470-13480 : Rate B, Rate C - 0.0, 0.0 -> 1375.09, 1375.09
% INFO    : Updated Thermal Rating: on line 13470-13506 : Rate B, Rate C - 0.0, 0.0 -> 4000.04, 4000.04
% INFO    : Updated Thermal Rating: on line 13695-13470 : Rate B, Rate C - 0.0, 0.0 -> 4180.75, 4180.75
% INFO    : Updated Thermal Rating: on transformer 13471-13474 : Rate B, Rate C - 0.0, 0.0 -> 391.9, 391.9
% INFO    : Updated Thermal Rating: on line 13471-13537 : Rate B, Rate C - 0.0, 0.0 -> 1132.11, 1132.11
% INFO    : Updated Thermal Rating: on transformer 13472-13474 : Rate B, Rate C - 0.0, 0.0 -> 366.9, 366.9
% INFO    : Updated Thermal Rating: on transformer 13473-13474 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 13482-13481 : Rate B, Rate C - 0.0, 0.0 -> 382.46, 382.46
% INFO    : Updated Thermal Rating: on transformer 13481-13483 : Rate B, Rate C - 0.0, 0.0 -> 418.28, 418.28
% INFO    : Updated Thermal Rating: on line 13643-13481 : Rate B, Rate C - 0.0, 0.0 -> 1174.88, 1174.88
% INFO    : Updated Thermal Rating: on line 13481-74250 : Rate B, Rate C - 0.0, 0.0 -> 1123.41, 1123.41
% INFO    : Updated Thermal Rating: on transformer 13485-13484 : Rate B, Rate C - 0.0, 0.0 -> 399.81, 399.81
% INFO    : Updated Thermal Rating: on transformer 13484-13486 : Rate B, Rate C - 0.0, 0.0 -> 478.61, 478.61
% INFO    : Updated Thermal Rating: on transformer 13484-13487 : Rate B, Rate C - 0.0, 0.0 -> 478.49, 478.49
% INFO    : Updated Thermal Rating: on line 13484-13505 : Rate B, Rate C - 0.0, 0.0 -> 1183.99, 1183.99
% INFO    : Updated Thermal Rating: on line 13484-13619 : Rate B, Rate C - 0.0, 0.0 -> 1194.89, 1194.89
% INFO    : Updated Thermal Rating: on line 13529-13485 : Rate B, Rate C - 0.0, 0.0 -> 242.84, 242.84
% INFO    : Updated Thermal Rating: on line 13485-13591 : Rate B, Rate C - 0.0, 0.0 -> 278.6, 278.6
% INFO    : Updated Thermal Rating: on line 13485-13591 : Rate B, Rate C - 0.0, 0.0 -> 278.6, 278.6
% INFO    : Updated Thermal Rating: on line 13485-13591 : Rate B, Rate C - 0.0, 0.0 -> 278.6, 278.6
% INFO    : Updated Thermal Rating: on transformer 13489-13488 : Rate B, Rate C - 0.0, 0.0 -> 358.79, 358.79
% INFO    : Updated Thermal Rating: on line 13491-13592 : Rate B, Rate C - 0.0, 0.0 -> 1249.95, 1249.95
% INFO    : Updated Thermal Rating: on line 13650-13491 : Rate B, Rate C - 0.0, 0.0 -> 1237.6, 1237.6
% INFO    : Updated Thermal Rating: on transformer 13492-13495 : Rate B, Rate C - 0.0, 0.0 -> 234.56, 234.56
% INFO    : Updated Thermal Rating: on transformer 13493-13495 : Rate B, Rate C - 0.0, 0.0 -> 117.28, 117.28
% INFO    : Updated Thermal Rating: on transformer 13494-13495 : Rate B, Rate C - 0.0, 0.0 -> 117.28, 117.28
% INFO    : Updated Thermal Rating: on transformer 13497-13496 : Rate B, Rate C - 0.0, 0.0 -> 1181.72, 1181.72
% INFO    : Updated Thermal Rating: on transformer 13496-13499 : Rate B, Rate C - 0.0, 0.0 -> 1738.67, 1738.67
% INFO    : Updated Thermal Rating: on transformer 13496-13500 : Rate B, Rate C - 0.0, 0.0 -> 1733.87, 1733.87
% INFO    : Updated Thermal Rating: on transformer 13496-13501 : Rate B, Rate C - 0.0, 0.0 -> 1733.72, 1733.72
% INFO    : Updated Thermal Rating: on transformer 13496-13502 : Rate B, Rate C - 0.0, 0.0 -> 1724.91, 1724.91
% INFO    : Updated Thermal Rating: on transformer 13496-13503 : Rate B, Rate C - 0.0, 0.0 -> 1724.62, 1724.62
% INFO    : Updated Thermal Rating: on transformer 13496-13504 : Rate B, Rate C - 0.0, 0.0 -> 1723.91, 1723.91
% INFO    : Updated Thermal Rating: on line 13496-13523 : Rate B, Rate C - 0.0, 0.0 -> 4233.6, 4233.6
% INFO    : Updated Thermal Rating: on line 13631-13496 : Rate B, Rate C - 0.0, 0.0 -> 4092.02, 4092.02
% INFO    : Updated Thermal Rating: on line 13496-13695 : Rate B, Rate C - 0.0, 0.0 -> 4094.2, 4094.2
% INFO    : Updated Thermal Rating: on transformer 13498-13497 : Rate B, Rate C - 0.0, 0.0 -> 339.62, 339.62
% INFO    : Updated Thermal Rating: on line 13516-13505 : Rate B, Rate C - 0.0, 0.0 -> 1217.0, 1217.0
% INFO    : Updated Thermal Rating: on line 13505-13621 : Rate B, Rate C - 0.0, 0.0 -> 1336.14, 1336.14
% INFO    : Updated Thermal Rating: on transformer 13507-13506 : Rate B, Rate C - 0.0, 0.0 -> 1430.34, 1430.34
% INFO    : Updated Thermal Rating: on transformer 13506-13509 : Rate B, Rate C - 0.0, 0.0 -> 1563.97, 1563.97
% INFO    : Updated Thermal Rating: on transformer 13506-13510 : Rate B, Rate C - 0.0, 0.0 -> 1562.09, 1562.09
% INFO    : Updated Thermal Rating: on transformer 13506-13511 : Rate B, Rate C - 0.0, 0.0 -> 1559.25, 1559.25
% INFO    : Updated Thermal Rating: on line 13695-13506 : Rate B, Rate C - 0.0, 0.0 -> 4217.11, 4217.11
% INFO    : Updated Thermal Rating: on transformer 13508-13507 : Rate B, Rate C - 0.0, 0.0 -> 375.38, 375.38
% INFO    : Updated Thermal Rating: on line 13537-13507 : Rate B, Rate C - 0.0, 0.0 -> 1164.43, 1164.43
% INFO    : Updated Thermal Rating: on line 13512-13647 : Rate B, Rate C - 0.0, 0.0 -> 243.13, 243.13
% INFO    : Updated Thermal Rating: on line 13513-13582 : Rate B, Rate C - 0.0, 0.0 -> 220.81, 220.81
% INFO    : Updated Thermal Rating: on transformer 13514-13515 : Rate B, Rate C - 0.0, 0.0 -> 89.93, 89.93
% INFO    : Updated Thermal Rating: on line 13635-13514 : Rate B, Rate C - 0.0, 0.0 -> 208.6, 208.6
% INFO    : Updated Thermal Rating: on line 13514-13683 : Rate B, Rate C - 0.0, 0.0 -> 190.62, 190.62
% INFO    : Updated Thermal Rating: on transformer 13517-13516 : Rate B, Rate C - 0.0, 0.0 -> 402.62, 402.62
% INFO    : Updated Thermal Rating: on transformer 13516-13518 : Rate B, Rate C - 0.0, 0.0 -> 483.85, 483.85
% INFO    : Updated Thermal Rating: on transformer 13516-13519 : Rate B, Rate C - 0.0, 0.0 -> 480.56, 480.56
% INFO    : Updated Thermal Rating: on transformer 13516-13520 : Rate B, Rate C - 0.0, 0.0 -> 479.72, 479.72
% INFO    : Updated Thermal Rating: on transformer 13516-13521 : Rate B, Rate C - 0.0, 0.0 -> 152.25, 152.25
% INFO    : Updated Thermal Rating: on line 13516-13619 : Rate B, Rate C - 0.0, 0.0 -> 1185.93, 1185.93
% INFO    : Updated Thermal Rating: on line 13660-13517 : Rate B, Rate C - 0.0, 0.0 -> 210.55, 210.55
% INFO    : Updated Thermal Rating: on line 13522-13556 : Rate B, Rate C - 0.0, 0.0 -> 186.11, 186.11
% INFO    : Updated Thermal Rating: on transformer 13524-13523 : Rate B, Rate C - 0.0, 0.0 -> 1486.02, 1486.02
% INFO    : Updated Thermal Rating: on transformer 13523-13526 : Rate B, Rate C - 0.0, 0.0 -> 1281.11, 1281.11
% INFO    : Updated Thermal Rating: on transformer 13523-13527 : Rate B, Rate C - 0.0, 0.0 -> 1280.43, 1280.43
% INFO    : Updated Thermal Rating: on transformer 13523-13528 : Rate B, Rate C - 0.0, 0.0 -> 1279.86, 1279.86
% INFO    : Updated Thermal Rating: on line 13523-13554 : Rate B, Rate C - 0.0, 0.0 -> 4347.66, 4347.66
% INFO    : Updated Thermal Rating: on line 13523-13554 : Rate B, Rate C - 0.0, 0.0 -> 4347.66, 4347.66
% INFO    : Updated Thermal Rating: on line 13523-13580 : Rate B, Rate C - 0.0, 0.0 -> 4286.35, 4286.35
% INFO    : Updated Thermal Rating: on line 13681-13523 : Rate B, Rate C - 0.0, 0.0 -> 4266.9, 4266.9
% INFO    : Updated Thermal Rating: on line 13523-13695 : Rate B, Rate C - 0.0, 0.0 -> 4255.5, 4255.5
% INFO    : Updated Thermal Rating: on transformer 13525-13524 : Rate B, Rate C - 0.0, 0.0 -> 322.26, 322.26
% INFO    : Updated Thermal Rating: on line 13525-13663 : Rate B, Rate C - 0.0, 0.0 -> 191.96, 191.96
% INFO    : Updated Thermal Rating: on transformer 13529-13530 : Rate B, Rate C - 0.0, 0.0 -> 140.4, 140.4
% INFO    : Updated Thermal Rating: on line 13529-13575 : Rate B, Rate C - 0.0, 0.0 -> 225.68, 225.68
% INFO    : Updated Thermal Rating: on line 13529-13635 : Rate B, Rate C - 0.0, 0.0 -> 263.52, 263.52
% INFO    : Updated Thermal Rating: on line 13529-13660 : Rate B, Rate C - 0.0, 0.0 -> 253.35, 253.35
% INFO    : Updated Thermal Rating: on transformer 13532-13535 : Rate B, Rate C - 0.0, 0.0 -> 186.52, 186.52
% INFO    : Updated Thermal Rating: on transformer 13533-13535 : Rate B, Rate C - 0.0, 0.0 -> 93.26, 93.26
% INFO    : Updated Thermal Rating: on transformer 13534-13535 : Rate B, Rate C - 0.0, 0.0 -> 93.26, 93.26
% INFO    : Updated Thermal Rating: on transformer 13538-13537 : Rate B, Rate C - 0.0, 0.0 -> 374.09, 374.09
% INFO    : Updated Thermal Rating: on transformer 13537-13539 : Rate B, Rate C - 0.0, 0.0 -> 496.53, 496.53
% INFO    : Updated Thermal Rating: on transformer 13537-13540 : Rate B, Rate C - 0.0, 0.0 -> 493.59, 493.59
% INFO    : Updated Thermal Rating: on transformer 13537-13541 : Rate B, Rate C - 0.0, 0.0 -> 493.47, 493.47
% INFO    : Updated Thermal Rating: on transformer 13537-13542 : Rate B, Rate C - 0.0, 0.0 -> 493.37, 493.37
% INFO    : Updated Thermal Rating: on line 13675-13537 : Rate B, Rate C - 0.0, 0.0 -> 1226.91, 1226.91
% INFO    : Updated Thermal Rating: on transformer 13543-13546 : Rate B, Rate C - 0.0, 0.0 -> 437.95, 437.95
% INFO    : Updated Thermal Rating: on transformer 13544-13546 : Rate B, Rate C - 0.0, 0.0 -> 362.64, 362.64
% INFO    : Updated Thermal Rating: on line 13544-74114 : Rate B, Rate C - 0.0, 0.0 -> 235.06, 235.06
% INFO    : Updated Thermal Rating: on line 74251-13544 : Rate B, Rate C - 0.0, 0.0 -> 205.77, 205.77
% INFO    : Updated Thermal Rating: on transformer 13545-13546 : Rate B, Rate C - 0.0, 0.0 -> 75.31, 75.31
% INFO    : Updated Thermal Rating: on line 13595-13547 : Rate B, Rate C - 0.0, 0.0 -> 1291.05, 1291.05
% INFO    : Updated Thermal Rating: on line 13547-74250 : Rate B, Rate C - 0.0, 0.0 -> 1090.82, 1090.82
% INFO    : Updated Thermal Rating: on line 13547-74330 : Rate B, Rate C - 0.0, 0.0 -> 1339.59, 1339.59
% INFO    : Updated Thermal Rating: on transformer 13549-13548 : Rate B, Rate C - 0.0, 0.0 -> 427.72, 427.72
% INFO    : Updated Thermal Rating: on line 13548-13588 : Rate B, Rate C - 0.0, 0.0 -> 1371.67, 1371.67
% INFO    : Updated Thermal Rating: on transformer 13550-13551 : Rate B, Rate C - 0.0, 0.0 -> 173.09, 173.09
% INFO    : Updated Thermal Rating: on transformer 13550-13552 : Rate B, Rate C - 0.0, 0.0 -> 173.09, 173.09
% INFO    : Updated Thermal Rating: on line 13553-13615 : Rate B, Rate C - 0.0, 0.0 -> 212.38, 212.38
% INFO    : Updated Thermal Rating: on line 13676-13553 : Rate B, Rate C - 0.0, 0.0 -> 273.08, 273.08
% INFO    : Updated Thermal Rating: on transformer 13555-13554 : Rate B, Rate C - 0.0, 0.0 -> 1480.84, 1480.84
% INFO    : Updated Thermal Rating: on transformer 13554-13559 : Rate B, Rate C - 0.0, 0.0 -> 1383.46, 1383.46
% INFO    : Updated Thermal Rating: on transformer 13554-13560 : Rate B, Rate C - 0.0, 0.0 -> 1381.04, 1381.04
% INFO    : Updated Thermal Rating: on transformer 13554-13561 : Rate B, Rate C - 0.0, 0.0 -> 1380.16, 1380.16
% INFO    : Updated Thermal Rating: on line 20321-13554 : Rate B, Rate C - 0.0, 0.0 -> 4332.88, 4332.88
% INFO    : Updated Thermal Rating: on line 20321-13554 : Rate B, Rate C - 0.0, 0.0 -> 4332.88, 4332.88
% INFO    : Updated Thermal Rating: on line 13554-20387 : Rate B, Rate C - 0.0, 0.0 -> 4202.74, 4202.74
% INFO    : Updated Thermal Rating: on transformer 13555-13558 : Rate B, Rate C - 0.0, 0.0 -> 478.33, 478.33
% INFO    : Updated Thermal Rating: on transformer 13556-13558 : Rate B, Rate C - 0.0, 0.0 -> 403.33, 403.33
% INFO    : Updated Thermal Rating: on line 13556-20156 : Rate B, Rate C - 0.0, 0.0 -> 214.22, 214.22
% INFO    : Updated Thermal Rating: on transformer 13557-13558 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 13562-13565 : Rate B, Rate C - 0.0, 0.0 -> 651.06, 651.06
% INFO    : Updated Thermal Rating: on transformer 13562-13568 : Rate B, Rate C - 0.0, 0.0 -> 757.79, 757.79
% INFO    : Updated Thermal Rating: on line 13562-13588 : Rate B, Rate C - 0.0, 0.0 -> 1160.3, 1160.3
% INFO    : Updated Thermal Rating: on line 13650-13562 : Rate B, Rate C - 0.0, 0.0 -> 1317.24, 1317.24
% INFO    : Updated Thermal Rating: on transformer 13563-13565 : Rate B, Rate C - 0.0, 0.0 -> 526.06, 526.06
% INFO    : Updated Thermal Rating: on transformer 13564-13565 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 13566-13568 : Rate B, Rate C - 0.0, 0.0 -> 378.89, 378.89
% INFO    : Updated Thermal Rating: on transformer 13567-13568 : Rate B, Rate C - 0.0, 0.0 -> 378.89, 378.89
% INFO    : Updated Thermal Rating: on transformer 13569-13570 : Rate B, Rate C - 0.0, 0.0 -> 126.1, 126.1
% INFO    : Updated Thermal Rating: on line 13569-13617 : Rate B, Rate C - 0.0, 0.0 -> 222.69, 222.69
% INFO    : Updated Thermal Rating: on transformer 13572-13571 : Rate B, Rate C - 0.0, 0.0 -> 433.04, 433.04
% INFO    : Updated Thermal Rating: on line 13573-13638 : Rate B, Rate C - 0.0, 0.0 -> 245.93, 245.93
% INFO    : Updated Thermal Rating: on line 13575-13591 : Rate B, Rate C - 0.0, 0.0 -> 199.64, 199.64
% INFO    : Updated Thermal Rating: on transformer 13576-13577 : Rate B, Rate C - 0.0, 0.0 -> 60.16, 60.16
% INFO    : Updated Thermal Rating: on transformer 13576-13578 : Rate B, Rate C - 0.0, 0.0 -> 71.52, 71.52
% INFO    : Updated Thermal Rating: on line 13579-13664 : Rate B, Rate C - 0.0, 0.0 -> 227.22, 227.22
% INFO    : Updated Thermal Rating: on transformer 13581-13580 : Rate B, Rate C - 0.0, 0.0 -> 1579.18, 1579.18
% INFO    : Updated Thermal Rating: on transformer 13581-13580 : Rate B, Rate C - 0.0, 0.0 -> 1579.18, 1579.18
% INFO    : Updated Thermal Rating: on transformer 13580-13583 : Rate B, Rate C - 0.0, 0.0 -> 1085.78, 1085.78
% INFO    : Updated Thermal Rating: on transformer 13580-13584 : Rate B, Rate C - 0.0, 0.0 -> 970.61, 970.61
% INFO    : Updated Thermal Rating: on transformer 13580-13585 : Rate B, Rate C - 0.0, 0.0 -> 853.18, 853.18
% INFO    : Updated Thermal Rating: on transformer 13580-13587 : Rate B, Rate C - 0.0, 0.0 -> 813.3, 813.3
% INFO    : Updated Thermal Rating: on line 13580-13631 : Rate B, Rate C - 0.0, 0.0 -> 4222.83, 4222.83
% INFO    : Updated Thermal Rating: on line 13580-20321 : Rate B, Rate C - 0.0, 0.0 -> 4166.89, 4166.89
% INFO    : Updated Thermal Rating: on transformer 13582-13581 : Rate B, Rate C - 0.0, 0.0 -> 480.0, 480.0
% INFO    : Updated Thermal Rating: on transformer 13581-13586 : Rate B, Rate C - 0.0, 0.0 -> 270.44, 270.44
% INFO    : Updated Thermal Rating: on line 13588-13656 : Rate B, Rate C - 0.0, 0.0 -> 1105.95, 1105.95
% INFO    : Updated Thermal Rating: on transformer 13589-13590 : Rate B, Rate C - 0.0, 0.0 -> 133.9, 133.9
% INFO    : Updated Thermal Rating: on transformer 13593-13592 : Rate B, Rate C - 0.0, 0.0 -> 402.44, 402.44
% INFO    : Updated Thermal Rating: on line 13592-13667 : Rate B, Rate C - 0.0, 0.0 -> 1325.02, 1325.02
% INFO    : Updated Thermal Rating: on transformer 13595-13594 : Rate B, Rate C - 0.0, 0.0 -> 1524.82, 1524.82
% INFO    : Updated Thermal Rating: on transformer 13594-13597 : Rate B, Rate C - 0.0, 0.0 -> 1296.98, 1296.98
% INFO    : Updated Thermal Rating: on transformer 13594-13598 : Rate B, Rate C - 0.0, 0.0 -> 1295.56, 1295.56
% INFO    : Updated Thermal Rating: on transformer 13594-13599 : Rate B, Rate C - 0.0, 0.0 -> 1294.39, 1294.39
% INFO    : Updated Thermal Rating: on transformer 13596-13595 : Rate B, Rate C - 0.0, 0.0 -> 364.29, 364.29
% INFO    : Updated Thermal Rating: on line 13595-74250 : Rate B, Rate C - 0.0, 0.0 -> 1216.69, 1216.69
% INFO    : Updated Thermal Rating: on line 13596-74113 : Rate B, Rate C - 0.0, 0.0 -> 227.18, 227.18
% INFO    : Updated Thermal Rating: on line 13600-13657 : Rate B, Rate C - 0.0, 0.0 -> 194.75, 194.75
% INFO    : Updated Thermal Rating: on line 13679-13600 : Rate B, Rate C - 0.0, 0.0 -> 182.07, 182.07
% INFO    : Updated Thermal Rating: on transformer 13601-13604 : Rate B, Rate C - 0.0, 0.0 -> 224.41, 224.41
% INFO    : Updated Thermal Rating: on line 13601-13633 : Rate B, Rate C - 0.0, 0.0 -> 174.76, 174.76
% INFO    : Updated Thermal Rating: on line 13601-13655 : Rate B, Rate C - 0.0, 0.0 -> 248.49, 248.49
% INFO    : Updated Thermal Rating: on line 13657-13601 : Rate B, Rate C - 0.0, 0.0 -> 208.49, 208.49
% INFO    : Updated Thermal Rating: on line 13601-13679 : Rate B, Rate C - 0.0, 0.0 -> 221.71, 221.71
% INFO    : Updated Thermal Rating: on transformer 13602-13604 : Rate B, Rate C - 0.0, 0.0 -> 112.2, 112.2
% INFO    : Updated Thermal Rating: on transformer 13603-13604 : Rate B, Rate C - 0.0, 0.0 -> 112.2, 112.2
% INFO    : Updated Thermal Rating: on transformer 13605-13606 : Rate B, Rate C - 0.0, 0.0 -> 128.57, 128.57
% INFO    : Updated Thermal Rating: on line 13638-13607 : Rate B, Rate C - 0.0, 0.0 -> 204.31, 204.31
% INFO    : Updated Thermal Rating: on transformer 13611-13612 : Rate B, Rate C - 0.0, 0.0 -> 65.57, 65.57
% INFO    : Updated Thermal Rating: on transformer 13611-13613 : Rate B, Rate C - 0.0, 0.0 -> 9.36, 9.36
% INFO    : Updated Thermal Rating: on line 13633-13611 : Rate B, Rate C - 0.0, 0.0 -> 211.1, 211.1
% INFO    : Updated Thermal Rating: on line 13655-13611 : Rate B, Rate C - 0.0, 0.0 -> 227.58, 227.58
% INFO    : Updated Thermal Rating: on transformer 13617-13616 : Rate B, Rate C - 0.0, 0.0 -> 315.61, 315.61
% INFO    : Updated Thermal Rating: on transformer 13616-13618 : Rate B, Rate C - 0.0, 0.0 -> 526.22, 526.22
% INFO    : Updated Thermal Rating: on line 13619-13675 : Rate B, Rate C - 0.0, 0.0 -> 1202.07, 1202.07
% INFO    : Updated Thermal Rating: on transformer 13620-13624 : Rate B, Rate C - 0.0, 0.0 -> 1507.64, 1507.64
% INFO    : Updated Thermal Rating: on transformer 13620-13625 : Rate B, Rate C - 0.0, 0.0 -> 1664.47, 1664.47
% INFO    : Updated Thermal Rating: on transformer 13620-13626 : Rate B, Rate C - 0.0, 0.0 -> 1662.83, 1662.83
% INFO    : Updated Thermal Rating: on transformer 13620-13627 : Rate B, Rate C - 0.0, 0.0 -> 1662.45, 1662.45
% INFO    : Updated Thermal Rating: on transformer 13620-13628 : Rate B, Rate C - 0.0, 0.0 -> 1661.78, 1661.78
% INFO    : Updated Thermal Rating: on transformer 13620-13629 : Rate B, Rate C - 0.0, 0.0 -> 1658.96, 1658.96
% INFO    : Updated Thermal Rating: on transformer 13620-13630 : Rate B, Rate C - 0.0, 0.0 -> 1658.66, 1658.66
% INFO    : Updated Thermal Rating: on transformer 13622-13621 : Rate B, Rate C - 0.0, 0.0 -> 430.69, 430.69
% INFO    : Updated Thermal Rating: on transformer 13621-13624 : Rate B, Rate C - 0.0, 0.0 -> 1407.64, 1407.64
% INFO    : Updated Thermal Rating: on transformer 13623-13624 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 13666-13631 : Rate B, Rate C - 0.0, 0.0 -> 4150.0, 4150.0
% INFO    : Updated Thermal Rating: on transformer 13637-13640 : Rate B, Rate C - 0.0, 0.0 -> 527.06, 527.06
% INFO    : Updated Thermal Rating: on transformer 13637-13641 : Rate B, Rate C - 0.0, 0.0 -> 378.05, 378.05
% INFO    : Updated Thermal Rating: on transformer 13637-13642 : Rate B, Rate C - 0.0, 0.0 -> 323.23, 323.23
% INFO    : Updated Thermal Rating: on transformer 13638-13640 : Rate B, Rate C - 0.0, 0.0 -> 377.06, 377.06
% INFO    : Updated Thermal Rating: on transformer 13639-13640 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 13646-13645 : Rate B, Rate C - 0.0, 0.0 -> 1388.31, 1388.31
% INFO    : Updated Thermal Rating: on transformer 13647-13646 : Rate B, Rate C - 0.0, 0.0 -> 448.19, 448.19
% INFO    : Updated Thermal Rating: on line 13689-13648 : Rate B, Rate C - 0.0, 0.0 -> 1265.07, 1265.07
% INFO    : Updated Thermal Rating: on transformer 13651-13650 : Rate B, Rate C - 0.0, 0.0 -> 547.2, 547.2
% INFO    : Updated Thermal Rating: on transformer 13650-13654 : Rate B, Rate C - 0.0, 0.0 -> 641.08, 641.08
% INFO    : Updated Thermal Rating: on transformer 13652-13654 : Rate B, Rate C - 0.0, 0.0 -> 320.54, 320.54
% INFO    : Updated Thermal Rating: on transformer 13653-13654 : Rate B, Rate C - 0.0, 0.0 -> 320.54, 320.54
% INFO    : Updated Thermal Rating: on transformer 13657-13656 : Rate B, Rate C - 0.0, 0.0 -> 423.57, 423.57
% INFO    : Updated Thermal Rating: on transformer 13656-13658 : Rate B, Rate C - 0.0, 0.0 -> 300.14, 300.14
% INFO    : Updated Thermal Rating: on transformer 13656-13659 : Rate B, Rate C - 0.0, 0.0 -> 298.0, 298.0
% INFO    : Updated Thermal Rating: on transformer 13660-13661 : Rate B, Rate C - 0.0, 0.0 -> 107.12, 107.12
% INFO    : Updated Thermal Rating: on transformer 13660-13662 : Rate B, Rate C - 0.0, 0.0 -> 59.4, 59.4
% INFO    : Updated Thermal Rating: on transformer 13664-13665 : Rate B, Rate C - 0.0, 0.0 -> 69.56, 69.56
% INFO    : Updated Thermal Rating: on transformer 13667-13666 : Rate B, Rate C - 0.0, 0.0 -> 1529.43, 1529.43
% INFO    : Updated Thermal Rating: on transformer 13666-13669 : Rate B, Rate C - 0.0, 0.0 -> 1451.16, 1451.16
% INFO    : Updated Thermal Rating: on transformer 13666-13670 : Rate B, Rate C - 0.0, 0.0 -> 1445.51, 1445.51
% INFO    : Updated Thermal Rating: on transformer 13666-13671 : Rate B, Rate C - 0.0, 0.0 -> 1443.57, 1443.57
% INFO    : Updated Thermal Rating: on transformer 13666-13672 : Rate B, Rate C - 0.0, 0.0 -> 1442.88, 1442.88
% INFO    : Updated Thermal Rating: on transformer 13666-13673 : Rate B, Rate C - 0.0, 0.0 -> 1442.18, 1442.18
% INFO    : Updated Thermal Rating: on transformer 13666-13674 : Rate B, Rate C - 0.0, 0.0 -> 1441.35, 1441.35
% INFO    : Updated Thermal Rating: on transformer 13668-13667 : Rate B, Rate C - 0.0, 0.0 -> 410.42, 410.42
% INFO    : Updated Thermal Rating: on transformer 13676-13675 : Rate B, Rate C - 0.0, 0.0 -> 300.33, 300.33
% INFO    : Updated Thermal Rating: on transformer 13675-13677 : Rate B, Rate C - 0.0, 0.0 -> 477.43, 477.43
% INFO    : Updated Thermal Rating: on transformer 13675-13678 : Rate B, Rate C - 0.0, 0.0 -> 474.84, 474.84
% INFO    : Updated Thermal Rating: on line 13675-13699 : Rate B, Rate C - 0.0, 0.0 -> 1188.15, 1188.15
% INFO    : Updated Thermal Rating: on transformer 13679-13680 : Rate B, Rate C - 0.0, 0.0 -> 72.68, 72.68
% INFO    : Updated Thermal Rating: on transformer 13682-13681 : Rate B, Rate C - 0.0, 0.0 -> 1375.35, 1375.35
% INFO    : Updated Thermal Rating: on transformer 13681-13684 : Rate B, Rate C - 0.0, 0.0 -> 1647.49, 1647.49
% INFO    : Updated Thermal Rating: on transformer 13681-13685 : Rate B, Rate C - 0.0, 0.0 -> 1647.04, 1647.04
% INFO    : Updated Thermal Rating: on transformer 13681-13686 : Rate B, Rate C - 0.0, 0.0 -> 1603.91, 1603.91
% INFO    : Updated Thermal Rating: on line 13681-13695 : Rate B, Rate C - 0.0, 0.0 -> 4144.18, 4144.18
% INFO    : Updated Thermal Rating: on transformer 13683-13682 : Rate B, Rate C - 0.0, 0.0 -> 291.77, 291.77
% INFO    : Updated Thermal Rating: on line 13682-13699 : Rate B, Rate C - 0.0, 0.0 -> 1132.23, 1132.23
% INFO    : Updated Thermal Rating: on transformer 13689-13692 : Rate B, Rate C - 0.0, 0.0 -> 435.8, 435.8
% INFO    : Updated Thermal Rating: on transformer 13689-13693 : Rate B, Rate C - 0.0, 0.0 -> 567.85, 567.85
% INFO    : Updated Thermal Rating: on transformer 13689-13694 : Rate B, Rate C - 0.0, 0.0 -> 565.89, 565.89
% INFO    : Updated Thermal Rating: on transformer 13690-13692 : Rate B, Rate C - 0.0, 0.0 -> 410.8, 410.8
% INFO    : Updated Thermal Rating: on transformer 13691-13692 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 13696-13695 : Rate B, Rate C - 0.0, 0.0 -> 1289.0, 1289.0
% INFO    : Updated Thermal Rating: on transformer 13695-13698 : Rate B, Rate C - 0.0, 0.0 -> 1801.93, 1801.93
% INFO    : Updated Thermal Rating: on transformer 13697-13696 : Rate B, Rate C - 0.0, 0.0 -> 319.8, 319.8
% INFO    : Updated Thermal Rating: on line 20000-20004 : Rate B, Rate C - 0.0, 0.0 -> 173.79, 173.79
% INFO    : Updated Thermal Rating: on line 20000-20433 : Rate B, Rate C - 0.0, 0.0 -> 208.75, 208.75
% INFO    : Updated Thermal Rating: on line 20002-20001 : Rate B, Rate C - 0.0, 0.0 -> 243.64, 243.64
% INFO    : Updated Thermal Rating: on line 20001-20010 : Rate B, Rate C - 0.0, 0.0 -> 210.25, 210.25
% INFO    : Updated Thermal Rating: on line 20002-20532 : Rate B, Rate C - 0.0, 0.0 -> 270.21, 270.21
% INFO    : Updated Thermal Rating: on line 20004-20015 : Rate B, Rate C - 0.0, 0.0 -> 194.3, 194.3
% INFO    : Updated Thermal Rating: on line 20433-20004 : Rate B, Rate C - 0.0, 0.0 -> 202.79, 202.79
% INFO    : Updated Thermal Rating: on transformer 20006-20005 : Rate B, Rate C - 0.0, 0.0 -> 380.02, 380.02
% INFO    : Updated Thermal Rating: on line 20006-20028 : Rate B, Rate C - 0.0, 0.0 -> 179.53, 179.53
% INFO    : Updated Thermal Rating: on line 20008-20433 : Rate B, Rate C - 0.0, 0.0 -> 170.64, 170.64
% INFO    : Updated Thermal Rating: on line 20017-20010 : Rate B, Rate C - 0.0, 0.0 -> 239.36, 239.36
% INFO    : Updated Thermal Rating: on line 20026-20010 : Rate B, Rate C - 0.0, 0.0 -> 229.87, 229.87
% INFO    : Updated Thermal Rating: on line 20013-20014 : Rate B, Rate C - 0.0, 0.0 -> 187.2, 187.2
% INFO    : Updated Thermal Rating: on line 20025-20013 : Rate B, Rate C - 0.0, 0.0 -> 165.81, 165.81
% INFO    : Updated Thermal Rating: on line 20014-20017 : Rate B, Rate C - 0.0, 0.0 -> 233.36, 233.36
% INFO    : Updated Thermal Rating: on line 20014-20019 : Rate B, Rate C - 0.0, 0.0 -> 202.73, 202.73
% INFO    : Updated Thermal Rating: on line 20021-20019 : Rate B, Rate C - 0.0, 0.0 -> 179.15, 179.15
% INFO    : Updated Thermal Rating: on line 20019-20023 : Rate B, Rate C - 0.0, 0.0 -> 175.82, 175.82
% INFO    : Updated Thermal Rating: on line 20025-20021 : Rate B, Rate C - 0.0, 0.0 -> 186.02, 186.02
% INFO    : Updated Thermal Rating: on line 20021-20031 : Rate B, Rate C - 0.0, 0.0 -> 185.58, 185.58
% INFO    : Updated Thermal Rating: on transformer 20023-20022 : Rate B, Rate C - 0.0, 0.0 -> 425.86, 425.86
% INFO    : Updated Thermal Rating: on line 20023-20025 : Rate B, Rate C - 0.0, 0.0 -> 217.94, 217.94
% INFO    : Updated Thermal Rating: on line 20029-20023 : Rate B, Rate C - 0.0, 0.0 -> 215.17, 215.17
% INFO    : Updated Thermal Rating: on line 20024-20533 : Rate B, Rate C - 0.0, 0.0 -> 1234.05, 1234.05
% INFO    : Updated Thermal Rating: on line 20024-21035 : Rate B, Rate C - 0.0, 0.0 -> 1142.61, 1142.61
% INFO    : Updated Thermal Rating: on line 20481-20026 : Rate B, Rate C - 0.0, 0.0 -> 233.08, 233.08
% INFO    : Updated Thermal Rating: on line 20027-21002 : Rate B, Rate C - 0.0, 0.0 -> 218.58, 218.58
% INFO    : Updated Thermal Rating: on line 20032-20029 : Rate B, Rate C - 0.0, 0.0 -> 183.7, 183.7
% INFO    : Updated Thermal Rating: on line 20029-20036 : Rate B, Rate C - 0.0, 0.0 -> 159.84, 159.84
% INFO    : Updated Thermal Rating: on line 20030-20352 : Rate B, Rate C - 0.0, 0.0 -> 193.37, 193.37
% INFO    : Updated Thermal Rating: on line 20030-20477 : Rate B, Rate C - 0.0, 0.0 -> 177.5, 177.5
% INFO    : Updated Thermal Rating: on line 20036-20032 : Rate B, Rate C - 0.0, 0.0 -> 172.73, 172.73
% INFO    : Updated Thermal Rating: on line 20038-20034 : Rate B, Rate C - 0.0, 0.0 -> 190.04, 190.04
% INFO    : Updated Thermal Rating: on line 20048-20034 : Rate B, Rate C - 0.0, 0.0 -> 210.39, 210.39
% INFO    : Updated Thermal Rating: on line 20036-20486 : Rate B, Rate C - 0.0, 0.0 -> 217.56, 217.56
% INFO    : Updated Thermal Rating: on line 20037-20305 : Rate B, Rate C - 0.0, 0.0 -> 216.58, 216.58
% INFO    : Updated Thermal Rating: on line 20037-20450 : Rate B, Rate C - 0.0, 0.0 -> 240.57, 240.57
% INFO    : Updated Thermal Rating: on line 20037-21011 : Rate B, Rate C - 0.0, 0.0 -> 233.66, 233.66
% INFO    : Updated Thermal Rating: on line 20037-21047 : Rate B, Rate C - 0.0, 0.0 -> 206.38, 206.38
% INFO    : Updated Thermal Rating: on line 20047-20038 : Rate B, Rate C - 0.0, 0.0 -> 171.83, 171.83
% INFO    : Updated Thermal Rating: on line 20040-20051 : Rate B, Rate C - 0.0, 0.0 -> 219.62, 219.62
% INFO    : Updated Thermal Rating: on line 20040-20498 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 20042-20051 : Rate B, Rate C - 0.0, 0.0 -> 212.49, 212.49
% INFO    : Updated Thermal Rating: on line 20059-20042 : Rate B, Rate C - 0.0, 0.0 -> 179.25, 179.25
% INFO    : Updated Thermal Rating: on line 20043-20045 : Rate B, Rate C - 0.0, 0.0 -> 237.83, 237.83
% INFO    : Updated Thermal Rating: on line 20348-20043 : Rate B, Rate C - 0.0, 0.0 -> 260.1, 260.1
% INFO    : Updated Thermal Rating: on line 20056-20045 : Rate B, Rate C - 0.0, 0.0 -> 222.5, 222.5
% INFO    : Updated Thermal Rating: on line 20046-20052 : Rate B, Rate C - 0.0, 0.0 -> 238.78, 238.78
% INFO    : Updated Thermal Rating: on line 20046-20529 : Rate B, Rate C - 0.0, 0.0 -> 223.46, 223.46
% INFO    : Updated Thermal Rating: on line 20047-20292 : Rate B, Rate C - 0.0, 0.0 -> 179.82, 179.82
% INFO    : Updated Thermal Rating: on line 20051-20462 : Rate B, Rate C - 0.0, 0.0 -> 267.04, 267.04
% INFO    : Updated Thermal Rating: on line 20052-20054 : Rate B, Rate C - 0.0, 0.0 -> 226.28, 226.28
% INFO    : Updated Thermal Rating: on line 20498-20052 : Rate B, Rate C - 0.0, 0.0 -> 226.27, 226.27
% INFO    : Updated Thermal Rating: on line 20053-20070 : Rate B, Rate C - 0.0, 0.0 -> 248.18, 248.18
% INFO    : Updated Thermal Rating: on line 20298-20053 : Rate B, Rate C - 0.0, 0.0 -> 256.66, 256.66
% INFO    : Updated Thermal Rating: on line 20348-20054 : Rate B, Rate C - 0.0, 0.0 -> 188.07, 188.07
% INFO    : Updated Thermal Rating: on line 20054-20389 : Rate B, Rate C - 0.0, 0.0 -> 238.91, 238.91
% INFO    : Updated Thermal Rating: on line 20056-20058 : Rate B, Rate C - 0.0, 0.0 -> 232.82, 232.82
% INFO    : Updated Thermal Rating: on line 20529-20056 : Rate B, Rate C - 0.0, 0.0 -> 226.11, 226.11
% INFO    : Updated Thermal Rating: on line 20058-20057 : Rate B, Rate C - 0.0, 0.0 -> 209.06, 209.06
% INFO    : Updated Thermal Rating: on line 20057-20087 : Rate B, Rate C - 0.0, 0.0 -> 191.63, 191.63
% INFO    : Updated Thermal Rating: on line 20061-20059 : Rate B, Rate C - 0.0, 0.0 -> 223.85, 223.85
% INFO    : Updated Thermal Rating: on line 20061-20495 : Rate B, Rate C - 0.0, 0.0 -> 249.46, 249.46
% INFO    : Updated Thermal Rating: on line 20062-20348 : Rate B, Rate C - 0.0, 0.0 -> 234.61, 234.61
% INFO    : Updated Thermal Rating: on line 20062-20354 : Rate B, Rate C - 0.0, 0.0 -> 241.09, 241.09
% INFO    : Updated Thermal Rating: on line 20065-20080 : Rate B, Rate C - 0.0, 0.0 -> 224.85, 224.85
% INFO    : Updated Thermal Rating: on line 20065-20498 : Rate B, Rate C - 0.0, 0.0 -> 243.19, 243.19
% INFO    : Updated Thermal Rating: on line 20065-20529 : Rate B, Rate C - 0.0, 0.0 -> 201.91, 201.91
% INFO    : Updated Thermal Rating: on line 20066-20334 : Rate B, Rate C - 0.0, 0.0 -> 234.85, 234.85
% INFO    : Updated Thermal Rating: on line 21324-20066 : Rate B, Rate C - 0.0, 0.0 -> 236.0, 236.0
% INFO    : Updated Thermal Rating: on line 20067-20082 : Rate B, Rate C - 0.0, 0.0 -> 230.71, 230.71
% INFO    : Updated Thermal Rating: on line 20067-20298 : Rate B, Rate C - 0.0, 0.0 -> 243.13, 243.13
% INFO    : Updated Thermal Rating: on line 20069-20292 : Rate B, Rate C - 0.0, 0.0 -> 235.17, 235.17
% INFO    : Updated Thermal Rating: on line 20472-20069 : Rate B, Rate C - 0.0, 0.0 -> 232.05, 232.05
% INFO    : Updated Thermal Rating: on line 20070-20072 : Rate B, Rate C - 0.0, 0.0 -> 216.76, 216.76
% INFO    : Updated Thermal Rating: on line 20070-20107 : Rate B, Rate C - 0.0, 0.0 -> 251.11, 251.11
% INFO    : Updated Thermal Rating: on line 20401-20072 : Rate B, Rate C - 0.0, 0.0 -> 238.6, 238.6
% INFO    : Updated Thermal Rating: on transformer 20074-20073 : Rate B, Rate C - 0.0, 0.0 -> 407.96, 407.96
% INFO    : Updated Thermal Rating: on line 20365-20073 : Rate B, Rate C - 0.0, 0.0 -> 1330.87, 1330.87
% INFO    : Updated Thermal Rating: on line 20381-20073 : Rate B, Rate C - 0.0, 0.0 -> 1073.79, 1073.79
% INFO    : Updated Thermal Rating: on line 20073-20396 : Rate B, Rate C - 0.0, 0.0 -> 1295.99, 1295.99
% INFO    : Updated Thermal Rating: on line 20074-20077 : Rate B, Rate C - 0.0, 0.0 -> 232.45, 232.45
% INFO    : Updated Thermal Rating: on line 20076-20075 : Rate B, Rate C - 0.0, 0.0 -> 244.99, 244.99
% INFO    : Updated Thermal Rating: on line 20075-20519 : Rate B, Rate C - 0.0, 0.0 -> 226.34, 226.34
% INFO    : Updated Thermal Rating: on line 20077-20076 : Rate B, Rate C - 0.0, 0.0 -> 203.63, 203.63
% INFO    : Updated Thermal Rating: on line 20079-20076 : Rate B, Rate C - 0.0, 0.0 -> 192.25, 192.25
% INFO    : Updated Thermal Rating: on line 20076-20109 : Rate B, Rate C - 0.0, 0.0 -> 234.07, 234.07
% INFO    : Updated Thermal Rating: on line 20079-20529 : Rate B, Rate C - 0.0, 0.0 -> 222.36, 222.36
% INFO    : Updated Thermal Rating: on line 20080-20097 : Rate B, Rate C - 0.0, 0.0 -> 195.15, 195.15
% INFO    : Updated Thermal Rating: on line 20082-20099 : Rate B, Rate C - 0.0, 0.0 -> 231.26, 231.26
% INFO    : Updated Thermal Rating: on line 20082-21570 : Rate B, Rate C - 0.0, 0.0 -> 240.75, 240.75
% INFO    : Updated Thermal Rating: on line 21558-20084 : Rate B, Rate C - 0.0, 0.0 -> 195.47, 195.47
% INFO    : Updated Thermal Rating: on line 20084-21570 : Rate B, Rate C - 0.0, 0.0 -> 214.38, 214.38
% INFO    : Updated Thermal Rating: on line 20084-21674 : Rate B, Rate C - 0.0, 0.0 -> 191.76, 191.76
% INFO    : Updated Thermal Rating: on line 20085-20132 : Rate B, Rate C - 0.0, 0.0 -> 223.12, 223.12
% INFO    : Updated Thermal Rating: on line 20085-20453 : Rate B, Rate C - 0.0, 0.0 -> 236.18, 236.18
% INFO    : Updated Thermal Rating: on line 20087-20095 : Rate B, Rate C - 0.0, 0.0 -> 205.73, 205.73
% INFO    : Updated Thermal Rating: on line 20087-20334 : Rate B, Rate C - 0.0, 0.0 -> 258.11, 258.11
% INFO    : Updated Thermal Rating: on line 20087-20519 : Rate B, Rate C - 0.0, 0.0 -> 243.67, 243.67
% INFO    : Updated Thermal Rating: on line 20088-21565 : Rate B, Rate C - 0.0, 0.0 -> 201.34, 201.34
% INFO    : Updated Thermal Rating: on line 20088-21601 : Rate B, Rate C - 0.0, 0.0 -> 165.89, 165.89
% INFO    : Updated Thermal Rating: on line 20088-21677 : Rate B, Rate C - 0.0, 0.0 -> 255.28, 255.28
% INFO    : Updated Thermal Rating: on line 20088-23023 : Rate B, Rate C - 0.0, 0.0 -> 226.05, 226.05
% INFO    : Updated Thermal Rating: on line 20090-20401 : Rate B, Rate C - 0.0, 0.0 -> 270.46, 270.46
% INFO    : Updated Thermal Rating: on line 20090-21570 : Rate B, Rate C - 0.0, 0.0 -> 251.87, 251.87
% INFO    : Updated Thermal Rating: on line 20091-20099 : Rate B, Rate C - 0.0, 0.0 -> 208.27, 208.27
% INFO    : Updated Thermal Rating: on line 20091-20112 : Rate B, Rate C - 0.0, 0.0 -> 254.75, 254.75
% INFO    : Updated Thermal Rating: on line 20091-20425 : Rate B, Rate C - 0.0, 0.0 -> 281.12, 281.12
% INFO    : Updated Thermal Rating: on line 20094-20167 : Rate B, Rate C - 0.0, 0.0 -> 242.73, 242.73
% INFO    : Updated Thermal Rating: on line 20094-20461 : Rate B, Rate C - 0.0, 0.0 -> 224.27, 224.27
% INFO    : Updated Thermal Rating: on line 20095-20097 : Rate B, Rate C - 0.0, 0.0 -> 229.05, 229.05
% INFO    : Updated Thermal Rating: on line 20109-20097 : Rate B, Rate C - 0.0, 0.0 -> 231.59, 231.59
% INFO    : Updated Thermal Rating: on line 20099-20334 : Rate B, Rate C - 0.0, 0.0 -> 246.77, 246.77
% INFO    : Updated Thermal Rating: on line 20103-20112 : Rate B, Rate C - 0.0, 0.0 -> 239.48, 239.48
% INFO    : Updated Thermal Rating: on line 20103-20183 : Rate B, Rate C - 0.0, 0.0 -> 210.34, 210.34
% INFO    : Updated Thermal Rating: on line 20114-20105 : Rate B, Rate C - 0.0, 0.0 -> 197.42, 197.42
% INFO    : Updated Thermal Rating: on line 20105-20121 : Rate B, Rate C - 0.0, 0.0 -> 175.93, 175.93
% INFO    : Updated Thermal Rating: on line 20121-20107 : Rate B, Rate C - 0.0, 0.0 -> 205.04, 205.04
% INFO    : Updated Thermal Rating: on line 21569-20107 : Rate B, Rate C - 0.0, 0.0 -> 211.73, 211.73
% INFO    : Updated Thermal Rating: on line 20109-20325 : Rate B, Rate C - 0.0, 0.0 -> 277.36, 277.36
% INFO    : Updated Thermal Rating: on line 20110-20130 : Rate B, Rate C - 0.0, 0.0 -> 233.48, 233.48
% INFO    : Updated Thermal Rating: on line 20110-20438 : Rate B, Rate C - 0.0, 0.0 -> 258.08, 258.08
% INFO    : Updated Thermal Rating: on line 20114-20136 : Rate B, Rate C - 0.0, 0.0 -> 221.6, 221.6
% INFO    : Updated Thermal Rating: on line 20116-20133 : Rate B, Rate C - 0.0, 0.0 -> 185.52, 185.52
% INFO    : Updated Thermal Rating: on line 20116-20171 : Rate B, Rate C - 0.0, 0.0 -> 203.4, 203.4
% INFO    : Updated Thermal Rating: on line 20116-20510 : Rate B, Rate C - 0.0, 0.0 -> 240.56, 240.56
% INFO    : Updated Thermal Rating: on line 20117-20161 : Rate B, Rate C - 0.0, 0.0 -> 198.46, 198.46
% INFO    : Updated Thermal Rating: on line 20356-20117 : Rate B, Rate C - 0.0, 0.0 -> 230.68, 230.68
% INFO    : Updated Thermal Rating: on line 20119-20124 : Rate B, Rate C - 0.0, 0.0 -> 187.79, 187.79
% INFO    : Updated Thermal Rating: on line 20119-20177 : Rate B, Rate C - 0.0, 0.0 -> 203.22, 203.22
% INFO    : Updated Thermal Rating: on line 20119-20205 : Rate B, Rate C - 0.0, 0.0 -> 218.34, 218.34
% INFO    : Updated Thermal Rating: on line 20135-20120 : Rate B, Rate C - 0.0, 0.0 -> 195.81, 195.81
% INFO    : Updated Thermal Rating: on line 20120-20141 : Rate B, Rate C - 0.0, 0.0 -> 227.14, 227.14
% INFO    : Updated Thermal Rating: on transformer 20123-20122 : Rate B, Rate C - 0.0, 0.0 -> 550.17, 550.17
% INFO    : Updated Thermal Rating: on line 20290-20122 : Rate B, Rate C - 0.0, 0.0 -> 1153.42, 1153.42
% INFO    : Updated Thermal Rating: on line 20404-20122 : Rate B, Rate C - 0.0, 0.0 -> 1144.97, 1144.97
% INFO    : Updated Thermal Rating: on line 20123-20125 : Rate B, Rate C - 0.0, 0.0 -> 248.01, 248.01
% INFO    : Updated Thermal Rating: on line 20141-20123 : Rate B, Rate C - 0.0, 0.0 -> 262.53, 262.53
% INFO    : Updated Thermal Rating: on line 20123-20148 : Rate B, Rate C - 0.0, 0.0 -> 216.88, 216.88
% INFO    : Updated Thermal Rating: on line 20124-20175 : Rate B, Rate C - 0.0, 0.0 -> 226.14, 226.14
% INFO    : Updated Thermal Rating: on line 20125-20176 : Rate B, Rate C - 0.0, 0.0 -> 227.17, 227.17
% INFO    : Updated Thermal Rating: on transformer 20126-20129 : Rate B, Rate C - 0.0, 0.0 -> 105.58, 105.58
% INFO    : Updated Thermal Rating: on line 20126-20144 : Rate B, Rate C - 0.0, 0.0 -> 192.99, 192.99
% INFO    : Updated Thermal Rating: on line 20126-20146 : Rate B, Rate C - 0.0, 0.0 -> 216.73, 216.73
% INFO    : Updated Thermal Rating: on transformer 20127-20129 : Rate B, Rate C - 0.0, 0.0 -> 52.79, 52.79
% INFO    : Updated Thermal Rating: on transformer 20128-20129 : Rate B, Rate C - 0.0, 0.0 -> 52.79, 52.79
% INFO    : Updated Thermal Rating: on line 20132-20130 : Rate B, Rate C - 0.0, 0.0 -> 245.56, 245.56
% INFO    : Updated Thermal Rating: on line 20130-20522 : Rate B, Rate C - 0.0, 0.0 -> 220.89, 220.89
% INFO    : Updated Thermal Rating: on line 20132-20183 : Rate B, Rate C - 0.0, 0.0 -> 262.62, 262.62
% INFO    : Updated Thermal Rating: on line 20139-20133 : Rate B, Rate C - 0.0, 0.0 -> 223.76, 223.76
% INFO    : Updated Thermal Rating: on line 20149-20133 : Rate B, Rate C - 0.0, 0.0 -> 218.23, 218.23
% INFO    : Updated Thermal Rating: on line 20133-20524 : Rate B, Rate C - 0.0, 0.0 -> 216.46, 216.46
% INFO    : Updated Thermal Rating: on line 20146-20134 : Rate B, Rate C - 0.0, 0.0 -> 212.72, 212.72
% INFO    : Updated Thermal Rating: on line 20134-20524 : Rate B, Rate C - 0.0, 0.0 -> 239.8, 239.8
% INFO    : Updated Thermal Rating: on line 21570-20135 : Rate B, Rate C - 0.0, 0.0 -> 201.1, 201.1
% INFO    : Updated Thermal Rating: on line 20175-20136 : Rate B, Rate C - 0.0, 0.0 -> 241.86, 241.86
% INFO    : Updated Thermal Rating: on line 20186-20136 : Rate B, Rate C - 0.0, 0.0 -> 233.19, 233.19
% INFO    : Updated Thermal Rating: on line 20136-20234 : Rate B, Rate C - 0.0, 0.0 -> 216.27, 216.27
% INFO    : Updated Thermal Rating: on line 20136-20457 : Rate B, Rate C - 0.0, 0.0 -> 281.94, 281.94
% INFO    : Updated Thermal Rating: on line 20190-20137 : Rate B, Rate C - 0.0, 0.0 -> 191.61, 191.61
% INFO    : Updated Thermal Rating: on line 20137-20289 : Rate B, Rate C - 0.0, 0.0 -> 218.34, 218.34
% INFO    : Updated Thermal Rating: on line 21570-20139 : Rate B, Rate C - 0.0, 0.0 -> 255.13, 255.13
% INFO    : Updated Thermal Rating: on line 20141-21569 : Rate B, Rate C - 0.0, 0.0 -> 197.17, 197.17
% INFO    : Updated Thermal Rating: on line 20143-20174 : Rate B, Rate C - 0.0, 0.0 -> 178.24, 178.24
% INFO    : Updated Thermal Rating: on line 20143-20185 : Rate B, Rate C - 0.0, 0.0 -> 197.97, 197.97
% INFO    : Updated Thermal Rating: on line 20144-20152 : Rate B, Rate C - 0.0, 0.0 -> 196.48, 196.48
% INFO    : Updated Thermal Rating: on line 20144-20163 : Rate B, Rate C - 0.0, 0.0 -> 228.98, 228.98
% INFO    : Updated Thermal Rating: on line 20200-20144 : Rate B, Rate C - 0.0, 0.0 -> 221.3, 221.3
% INFO    : Updated Thermal Rating: on line 20146-20179 : Rate B, Rate C - 0.0, 0.0 -> 198.45, 198.45
% INFO    : Updated Thermal Rating: on line 20146-20197 : Rate B, Rate C - 0.0, 0.0 -> 208.63, 208.63
% INFO    : Updated Thermal Rating: on line 20198-20148 : Rate B, Rate C - 0.0, 0.0 -> 178.97, 178.97
% INFO    : Updated Thermal Rating: on line 20161-20149 : Rate B, Rate C - 0.0, 0.0 -> 179.42, 179.42
% INFO    : Updated Thermal Rating: on line 20151-20160 : Rate B, Rate C - 0.0, 0.0 -> 229.9, 229.9
% INFO    : Updated Thermal Rating: on line 21558-20151 : Rate B, Rate C - 0.0, 0.0 -> 182.51, 182.51
% INFO    : Updated Thermal Rating: on line 20152-20356 : Rate B, Rate C - 0.0, 0.0 -> 245.69, 245.69
% INFO    : Updated Thermal Rating: on line 20154-20173 : Rate B, Rate C - 0.0, 0.0 -> 168.12, 168.12
% INFO    : Updated Thermal Rating: on line 20154-20213 : Rate B, Rate C - 0.0, 0.0 -> 204.79, 204.79
% INFO    : Updated Thermal Rating: on line 20154-20510 : Rate B, Rate C - 0.0, 0.0 -> 230.66, 230.66
% INFO    : Updated Thermal Rating: on line 20526-20156 : Rate B, Rate C - 0.0, 0.0 -> 204.24, 204.24
% INFO    : Updated Thermal Rating: on line 20160-20356 : Rate B, Rate C - 0.0, 0.0 -> 202.55, 202.55
% INFO    : Updated Thermal Rating: on line 20160-20510 : Rate B, Rate C - 0.0, 0.0 -> 232.77, 232.77
% INFO    : Updated Thermal Rating: on line 20163-20356 : Rate B, Rate C - 0.0, 0.0 -> 250.13, 250.13
% INFO    : Updated Thermal Rating: on line 20167-20380 : Rate B, Rate C - 0.0, 0.0 -> 265.24, 265.24
% INFO    : Updated Thermal Rating: on line 20168-20373 : Rate B, Rate C - 0.0, 0.0 -> 223.57, 223.57
% INFO    : Updated Thermal Rating: on line 20438-20168 : Rate B, Rate C - 0.0, 0.0 -> 231.75, 231.75
% INFO    : Updated Thermal Rating: on line 20519-20168 : Rate B, Rate C - 0.0, 0.0 -> 186.11, 186.11
% INFO    : Updated Thermal Rating: on line 20171-20170 : Rate B, Rate C - 0.0, 0.0 -> 158.17, 158.17
% INFO    : Updated Thermal Rating: on line 20170-20176 : Rate B, Rate C - 0.0, 0.0 -> 204.13, 204.13
% INFO    : Updated Thermal Rating: on line 20181-20172 : Rate B, Rate C - 0.0, 0.0 -> 209.15, 209.15
% INFO    : Updated Thermal Rating: on line 20172-20232 : Rate B, Rate C - 0.0, 0.0 -> 187.56, 187.56
% INFO    : Updated Thermal Rating: on line 20173-20190 : Rate B, Rate C - 0.0, 0.0 -> 221.53, 221.53
% INFO    : Updated Thermal Rating: on line 20174-20175 : Rate B, Rate C - 0.0, 0.0 -> 215.54, 215.54
% INFO    : Updated Thermal Rating: on line 20186-20175 : Rate B, Rate C - 0.0, 0.0 -> 214.26, 214.26
% INFO    : Updated Thermal Rating: on line 20176-20177 : Rate B, Rate C - 0.0, 0.0 -> 159.28, 159.28
% INFO    : Updated Thermal Rating: on line 20179-20524 : Rate B, Rate C - 0.0, 0.0 -> 227.46, 227.46
% INFO    : Updated Thermal Rating: on line 20180-20182 : Rate B, Rate C - 0.0, 0.0 -> 208.94, 208.94
% INFO    : Updated Thermal Rating: on line 20195-20180 : Rate B, Rate C - 0.0, 0.0 -> 216.88, 216.88
% INFO    : Updated Thermal Rating: on line 20206-20180 : Rate B, Rate C - 0.0, 0.0 -> 214.09, 214.09
% INFO    : Updated Thermal Rating: on line 20181-20340 : Rate B, Rate C - 0.0, 0.0 -> 238.79, 238.79
% INFO    : Updated Thermal Rating: on line 20182-20183 : Rate B, Rate C - 0.0, 0.0 -> 249.74, 249.74
% INFO    : Updated Thermal Rating: on line 20184-20195 : Rate B, Rate C - 0.0, 0.0 -> 208.72, 208.72
% INFO    : Updated Thermal Rating: on line 20184-20289 : Rate B, Rate C - 0.0, 0.0 -> 239.9, 239.9
% INFO    : Updated Thermal Rating: on line 20185-20340 : Rate B, Rate C - 0.0, 0.0 -> 248.59, 248.59
% INFO    : Updated Thermal Rating: on transformer 20186-20189 : Rate B, Rate C - 0.0, 0.0 -> 105.31, 105.31
% INFO    : Updated Thermal Rating: on transformer 20187-20189 : Rate B, Rate C - 0.0, 0.0 -> 52.65, 52.65
% INFO    : Updated Thermal Rating: on transformer 20188-20189 : Rate B, Rate C - 0.0, 0.0 -> 52.65, 52.65
% INFO    : Updated Thermal Rating: on line 20190-20289 : Rate B, Rate C - 0.0, 0.0 -> 232.19, 232.19
% INFO    : Updated Thermal Rating: on line 20194-20202 : Rate B, Rate C - 0.0, 0.0 -> 214.96, 214.96
% INFO    : Updated Thermal Rating: on line 20194-20213 : Rate B, Rate C - 0.0, 0.0 -> 190.49, 190.49
% INFO    : Updated Thermal Rating: on line 20194-20219 : Rate B, Rate C - 0.0, 0.0 -> 233.06, 233.06
% INFO    : Updated Thermal Rating: on line 20194-20237 : Rate B, Rate C - 0.0, 0.0 -> 220.64, 220.64
% INFO    : Updated Thermal Rating: on line 20195-20202 : Rate B, Rate C - 0.0, 0.0 -> 199.08, 199.08
% INFO    : Updated Thermal Rating: on line 20510-20197 : Rate B, Rate C - 0.0, 0.0 -> 233.83, 233.83
% INFO    : Updated Thermal Rating: on line 20198-20289 : Rate B, Rate C - 0.0, 0.0 -> 207.2, 207.2
% INFO    : Updated Thermal Rating: on line 23031-20200 : Rate B, Rate C - 0.0, 0.0 -> 188.9, 188.9
% INFO    : Updated Thermal Rating: on line 20205-20203 : Rate B, Rate C - 0.0, 0.0 -> 245.89, 245.89
% INFO    : Updated Thermal Rating: on line 20203-20382 : Rate B, Rate C - 0.0, 0.0 -> 272.11, 272.11
% INFO    : Updated Thermal Rating: on line 20518-20203 : Rate B, Rate C - 0.0, 0.0 -> 171.49, 171.49
% INFO    : Updated Thermal Rating: on line 20206-20210 : Rate B, Rate C - 0.0, 0.0 -> 235.43, 235.43
% INFO    : Updated Thermal Rating: on line 20207-20231 : Rate B, Rate C - 0.0, 0.0 -> 160.3, 160.3
% INFO    : Updated Thermal Rating: on line 20207-20239 : Rate B, Rate C - 0.0, 0.0 -> 207.53, 207.53
% INFO    : Updated Thermal Rating: on line 20236-20208 : Rate B, Rate C - 0.0, 0.0 -> 227.46, 227.46
% INFO    : Updated Thermal Rating: on line 20208-20240 : Rate B, Rate C - 0.0, 0.0 -> 189.16, 189.16
% INFO    : Updated Thermal Rating: on line 20234-20210 : Rate B, Rate C - 0.0, 0.0 -> 232.97, 232.97
% INFO    : Updated Thermal Rating: on line 20210-20252 : Rate B, Rate C - 0.0, 0.0 -> 221.23, 221.23
% INFO    : Updated Thermal Rating: on line 20218-20211 : Rate B, Rate C - 0.0, 0.0 -> 181.63, 181.63
% INFO    : Updated Thermal Rating: on line 20211-20231 : Rate B, Rate C - 0.0, 0.0 -> 207.56, 207.56
% INFO    : Updated Thermal Rating: on line 20216-20214 : Rate B, Rate C - 0.0, 0.0 -> 186.5, 186.5
% INFO    : Updated Thermal Rating: on line 20214-20346 : Rate B, Rate C - 0.0, 0.0 -> 205.7, 205.7
% INFO    : Updated Thermal Rating: on line 20214-23318 : Rate B, Rate C - 0.0, 0.0 -> 189.01, 189.01
% INFO    : Updated Thermal Rating: on line 20216-20241 : Rate B, Rate C - 0.0, 0.0 -> 220.33, 220.33
% INFO    : Updated Thermal Rating: on line 20244-20218 : Rate B, Rate C - 0.0, 0.0 -> 226.31, 226.31
% INFO    : Updated Thermal Rating: on line 20244-20219 : Rate B, Rate C - 0.0, 0.0 -> 259.6, 259.6
% INFO    : Updated Thermal Rating: on line 20220-20467 : Rate B, Rate C - 0.0, 0.0 -> 240.57, 240.57
% INFO    : Updated Thermal Rating: on line 23074-20220 : Rate B, Rate C - 0.0, 0.0 -> 238.66, 238.66
% INFO    : Updated Thermal Rating: on transformer 20222-20225 : Rate B, Rate C - 0.0, 0.0 -> 103.95, 103.95
% INFO    : Updated Thermal Rating: on transformer 20223-20225 : Rate B, Rate C - 0.0, 0.0 -> 51.97, 51.97
% INFO    : Updated Thermal Rating: on transformer 20224-20225 : Rate B, Rate C - 0.0, 0.0 -> 51.97, 51.97
% INFO    : Updated Thermal Rating: on line 20226-20467 : Rate B, Rate C - 0.0, 0.0 -> 254.82, 254.82
% INFO    : Updated Thermal Rating: on line 23058-20226 : Rate B, Rate C - 0.0, 0.0 -> 252.61, 252.61
% INFO    : Updated Thermal Rating: on line 20240-20228 : Rate B, Rate C - 0.0, 0.0 -> 192.9, 192.9
% INFO    : Updated Thermal Rating: on line 20228-20518 : Rate B, Rate C - 0.0, 0.0 -> 227.51, 227.51
% INFO    : Updated Thermal Rating: on line 20230-20232 : Rate B, Rate C - 0.0, 0.0 -> 217.46, 217.46
% INFO    : Updated Thermal Rating: on line 20230-20248 : Rate B, Rate C - 0.0, 0.0 -> 260.25, 260.25
% INFO    : Updated Thermal Rating: on line 20248-20231 : Rate B, Rate C - 0.0, 0.0 -> 230.77, 230.77
% INFO    : Updated Thermal Rating: on line 20340-20234 : Rate B, Rate C - 0.0, 0.0 -> 237.23, 237.23
% INFO    : Updated Thermal Rating: on line 23318-20234 : Rate B, Rate C - 0.0, 0.0 -> 249.99, 249.99
% INFO    : Updated Thermal Rating: on line 20397-20236 : Rate B, Rate C - 0.0, 0.0 -> 241.05, 241.05
% INFO    : Updated Thermal Rating: on line 20237-20253 : Rate B, Rate C - 0.0, 0.0 -> 234.39, 234.39
% INFO    : Updated Thermal Rating: on line 20261-20238 : Rate B, Rate C - 0.0, 0.0 -> 238.03, 238.03
% INFO    : Updated Thermal Rating: on line 20238-20543 : Rate B, Rate C - 0.0, 0.0 -> 252.12, 252.12
% INFO    : Updated Thermal Rating: on line 20258-20239 : Rate B, Rate C - 0.0, 0.0 -> 221.55, 221.55
% INFO    : Updated Thermal Rating: on line 20251-20241 : Rate B, Rate C - 0.0, 0.0 -> 198.96, 198.96
% INFO    : Updated Thermal Rating: on line 20346-20241 : Rate B, Rate C - 0.0, 0.0 -> 179.58, 179.58
% INFO    : Updated Thermal Rating: on line 20241-20454 : Rate B, Rate C - 0.0, 0.0 -> 257.37, 257.37
% INFO    : Updated Thermal Rating: on transformer 20243-20246 : Rate B, Rate C - 0.0, 0.0 -> 657.56, 657.56
% INFO    : Updated Thermal Rating: on transformer 20244-20246 : Rate B, Rate C - 0.0, 0.0 -> 498.11, 498.11
% INFO    : Updated Thermal Rating: on transformer 20245-20246 : Rate B, Rate C - 0.0, 0.0 -> 159.45, 159.45
% INFO    : Updated Thermal Rating: on line 20247-20396 : Rate B, Rate C - 0.0, 0.0 -> 1202.68, 1202.68
% INFO    : Updated Thermal Rating: on line 20397-20248 : Rate B, Rate C - 0.0, 0.0 -> 303.07, 303.07
% INFO    : Updated Thermal Rating: on line 20397-20248 : Rate B, Rate C - 0.0, 0.0 -> 303.07, 303.07
% INFO    : Updated Thermal Rating: on line 20249-20257 : Rate B, Rate C - 0.0, 0.0 -> 194.87, 194.87
% INFO    : Updated Thermal Rating: on line 20249-20504 : Rate B, Rate C - 0.0, 0.0 -> 209.25, 209.25
% INFO    : Updated Thermal Rating: on line 20251-20252 : Rate B, Rate C - 0.0, 0.0 -> 187.65, 187.65
% INFO    : Updated Thermal Rating: on line 20264-20252 : Rate B, Rate C - 0.0, 0.0 -> 267.96, 267.96
% INFO    : Updated Thermal Rating: on line 20254-20253 : Rate B, Rate C - 0.0, 0.0 -> 268.27, 268.27
% INFO    : Updated Thermal Rating: on line 20253-20260 : Rate B, Rate C - 0.0, 0.0 -> 167.77, 167.77
% INFO    : Updated Thermal Rating: on line 20254-20539 : Rate B, Rate C - 0.0, 0.0 -> 279.45, 279.45
% INFO    : Updated Thermal Rating: on line 20262-20255 : Rate B, Rate C - 0.0, 0.0 -> 200.32, 200.32
% INFO    : Updated Thermal Rating: on line 20273-20255 : Rate B, Rate C - 0.0, 0.0 -> 194.63, 194.63
% INFO    : Updated Thermal Rating: on line 20255-20360 : Rate B, Rate C - 0.0, 0.0 -> 188.64, 188.64
% INFO    : Updated Thermal Rating: on line 20257-20261 : Rate B, Rate C - 0.0, 0.0 -> 217.33, 217.33
% INFO    : Updated Thermal Rating: on line 20258-20260 : Rate B, Rate C - 0.0, 0.0 -> 237.88, 237.88
% INFO    : Updated Thermal Rating: on line 20260-20310 : Rate B, Rate C - 0.0, 0.0 -> 251.26, 251.26
% INFO    : Updated Thermal Rating: on line 20262-20275 : Rate B, Rate C - 0.0, 0.0 -> 228.69, 228.69
% INFO    : Updated Thermal Rating: on line 20262-20386 : Rate B, Rate C - 0.0, 0.0 -> 259.22, 259.22
% INFO    : Updated Thermal Rating: on line 20496-20262 : Rate B, Rate C - 0.0, 0.0 -> 228.02, 228.02
% INFO    : Updated Thermal Rating: on line 20265-20264 : Rate B, Rate C - 0.0, 0.0 -> 219.69, 219.69
% INFO    : Updated Thermal Rating: on line 20264-20373 : Rate B, Rate C - 0.0, 0.0 -> 243.03, 243.03
% INFO    : Updated Thermal Rating: on line 20265-20534 : Rate B, Rate C - 0.0, 0.0 -> 227.92, 227.92
% INFO    : Updated Thermal Rating: on line 20266-20310 : Rate B, Rate C - 0.0, 0.0 -> 253.75, 253.75
% INFO    : Updated Thermal Rating: on line 20266-23092 : Rate B, Rate C - 0.0, 0.0 -> 224.66, 224.66
% INFO    : Updated Thermal Rating: on line 23278-20267 : Rate B, Rate C - 0.0, 0.0 -> 240.65, 240.65
% INFO    : Updated Thermal Rating: on line 23371-20267 : Rate B, Rate C - 0.0, 0.0 -> 179.1, 179.1
% INFO    : Updated Thermal Rating: on line 20273-20269 : Rate B, Rate C - 0.0, 0.0 -> 202.7, 202.7
% INFO    : Updated Thermal Rating: on line 20360-20269 : Rate B, Rate C - 0.0, 0.0 -> 193.74, 193.74
% INFO    : Updated Thermal Rating: on line 20269-20526 : Rate B, Rate C - 0.0, 0.0 -> 246.97, 246.97
% INFO    : Updated Thermal Rating: on line 20272-20310 : Rate B, Rate C - 0.0, 0.0 -> 236.52, 236.52
% INFO    : Updated Thermal Rating: on line 20272-20347 : Rate B, Rate C - 0.0, 0.0 -> 252.62, 252.62
% INFO    : Updated Thermal Rating: on transformer 20275-20278 : Rate B, Rate C - 0.0, 0.0 -> 202.09, 202.09
% INFO    : Updated Thermal Rating: on line 30003-20275 : Rate B, Rate C - 0.0, 0.0 -> 225.7, 225.7
% INFO    : Updated Thermal Rating: on transformer 20276-20278 : Rate B, Rate C - 0.0, 0.0 -> 101.04, 101.04
% INFO    : Updated Thermal Rating: on transformer 20277-20278 : Rate B, Rate C - 0.0, 0.0 -> 101.04, 101.04
% INFO    : Updated Thermal Rating: on line 20279-20434 : Rate B, Rate C - 0.0, 0.0 -> 251.41, 251.41
% INFO    : Updated Thermal Rating: on line 20279-30013 : Rate B, Rate C - 0.0, 0.0 -> 215.42, 215.42
% INFO    : Updated Thermal Rating: on line 20280-20281 : Rate B, Rate C - 0.0, 0.0 -> 208.34, 208.34
% INFO    : Updated Thermal Rating: on line 20280-23214 : Rate B, Rate C - 0.0, 0.0 -> 168.97, 168.97
% INFO    : Updated Thermal Rating: on line 20280-30007 : Rate B, Rate C - 0.0, 0.0 -> 169.95, 169.95
% INFO    : Updated Thermal Rating: on line 20409-20281 : Rate B, Rate C - 0.0, 0.0 -> 240.16, 240.16
% INFO    : Updated Thermal Rating: on line 30007-20281 : Rate B, Rate C - 0.0, 0.0 -> 203.13, 203.13
% INFO    : Updated Thermal Rating: on transformer 20283-20286 : Rate B, Rate C - 0.0, 0.0 -> 397.73, 397.73
% INFO    : Updated Thermal Rating: on line 20283-20422 : Rate B, Rate C - 0.0, 0.0 -> 766.1, 766.1
% INFO    : Updated Thermal Rating: on transformer 20284-20286 : Rate B, Rate C - 0.0, 0.0 -> 372.73, 372.73
% INFO    : Updated Thermal Rating: on line 20284-20347 : Rate B, Rate C - 0.0, 0.0 -> 233.0, 233.0
% INFO    : Updated Thermal Rating: on transformer 20285-20286 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 20289-20288 : Rate B, Rate C - 0.0, 0.0 -> 493.51, 493.51
% INFO    : Updated Thermal Rating: on line 20290-20339 : Rate B, Rate C - 0.0, 0.0 -> 1118.68, 1118.68
% INFO    : Updated Thermal Rating: on line 20396-20290 : Rate B, Rate C - 0.0, 0.0 -> 1131.45, 1131.45
% INFO    : Updated Thermal Rating: on line 20509-20290 : Rate B, Rate C - 0.0, 0.0 -> 1062.24, 1062.24
% INFO    : Updated Thermal Rating: on transformer 20292-20291 : Rate B, Rate C - 0.0, 0.0 -> 254.59, 254.59
% INFO    : Updated Thermal Rating: on transformer 20291-20293 : Rate B, Rate C - 0.0, 0.0 -> 420.41, 420.41
% INFO    : Updated Thermal Rating: on line 20291-20322 : Rate B, Rate C - 0.0, 0.0 -> 1154.28, 1154.28
% INFO    : Updated Thermal Rating: on line 20324-20291 : Rate B, Rate C - 0.0, 0.0 -> 1283.44, 1283.44
% INFO    : Updated Thermal Rating: on line 20365-20291 : Rate B, Rate C - 0.0, 0.0 -> 1119.83, 1119.83
% INFO    : Updated Thermal Rating: on line 20291-20527 : Rate B, Rate C - 0.0, 0.0 -> 965.43, 965.43
% INFO    : Updated Thermal Rating: on line 20292-20354 : Rate B, Rate C - 0.0, 0.0 -> 204.64, 204.64
% INFO    : Updated Thermal Rating: on line 20292-20475 : Rate B, Rate C - 0.0, 0.0 -> 232.85, 232.85
% INFO    : Updated Thermal Rating: on transformer 20294-20295 : Rate B, Rate C - 0.0, 0.0 -> 153.27, 153.27
% INFO    : Updated Thermal Rating: on line 20357-20294 : Rate B, Rate C - 0.0, 0.0 -> 200.8, 200.8
% INFO    : Updated Thermal Rating: on line 20375-20294 : Rate B, Rate C - 0.0, 0.0 -> 230.58, 230.58
% INFO    : Updated Thermal Rating: on transformer 20297-20296 : Rate B, Rate C - 0.0, 0.0 -> 1320.36, 1320.36
% INFO    : Updated Thermal Rating: on transformer 20296-20299 : Rate B, Rate C - 0.0, 0.0 -> 1587.13, 1587.13
% INFO    : Updated Thermal Rating: on transformer 20296-20300 : Rate B, Rate C - 0.0, 0.0 -> 1585.65, 1585.65
% INFO    : Updated Thermal Rating: on transformer 20296-20301 : Rate B, Rate C - 0.0, 0.0 -> 1585.34, 1585.34
% INFO    : Updated Thermal Rating: on transformer 20296-20302 : Rate B, Rate C - 0.0, 0.0 -> 955.48, 955.48
% INFO    : Updated Thermal Rating: on transformer 20298-20297 : Rate B, Rate C - 0.0, 0.0 -> 474.76, 474.76
% INFO    : Updated Thermal Rating: on line 20297-20404 : Rate B, Rate C - 0.0, 0.0 -> 1217.45, 1217.45
% INFO    : Updated Thermal Rating: on line 20297-20497 : Rate B, Rate C - 0.0, 0.0 -> 1283.68, 1283.68
% INFO    : Updated Thermal Rating: on line 20303-21593 : Rate B, Rate C - 0.0, 0.0 -> 4067.06, 4067.06
% INFO    : Updated Thermal Rating: on line 20304-20446 : Rate B, Rate C - 0.0, 0.0 -> 233.14, 233.14
% INFO    : Updated Thermal Rating: on line 20304-21139 : Rate B, Rate C - 0.0, 0.0 -> 233.6, 233.6
% INFO    : Updated Thermal Rating: on transformer 20305-20306 : Rate B, Rate C - 0.0, 0.0 -> 95.46, 95.46
% INFO    : Updated Thermal Rating: on transformer 20305-20307 : Rate B, Rate C - 0.0, 0.0 -> 59.81, 59.81
% INFO    : Updated Thermal Rating: on line 20305-20464 : Rate B, Rate C - 0.0, 0.0 -> 223.02, 223.02
% INFO    : Updated Thermal Rating: on line 20305-21024 : Rate B, Rate C - 0.0, 0.0 -> 234.23, 234.23
% INFO    : Updated Thermal Rating: on transformer 20308-20312 : Rate B, Rate C - 0.0, 0.0 -> 1630.0, 1630.0
% INFO    : Updated Thermal Rating: on transformer 20308-20313 : Rate B, Rate C - 0.0, 0.0 -> 1311.78, 1311.78
% INFO    : Updated Thermal Rating: on transformer 20308-20314 : Rate B, Rate C - 0.0, 0.0 -> 1311.75, 1311.75
% INFO    : Updated Thermal Rating: on line 20308-20436 : Rate B, Rate C - 0.0, 0.0 -> 4130.97, 4130.97
% INFO    : Updated Thermal Rating: on line 23457-20308 : Rate B, Rate C - 0.0, 0.0 -> 4152.71, 4152.71
% INFO    : Updated Thermal Rating: on transformer 20310-20309 : Rate B, Rate C - 0.0, 0.0 -> 430.03, 430.03
% INFO    : Updated Thermal Rating: on transformer 20309-20312 : Rate B, Rate C - 0.0, 0.0 -> 1480.0, 1480.0
% INFO    : Updated Thermal Rating: on line 20309-20396 : Rate B, Rate C - 0.0, 0.0 -> 1150.61, 1150.61
% INFO    : Updated Thermal Rating: on line 20309-23280 : Rate B, Rate C - 0.0, 0.0 -> 1161.12, 1161.12
% INFO    : Updated Thermal Rating: on transformer 20310-20315 : Rate B, Rate C - 0.0, 0.0 -> 9.1, 9.1
% INFO    : Updated Thermal Rating: on transformer 20311-20312 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 20317-20316 : Rate B, Rate C - 0.0, 0.0 -> 1451.31, 1451.31
% INFO    : Updated Thermal Rating: on transformer 20316-20319 : Rate B, Rate C - 0.0, 0.0 -> 1124.0, 1124.0
% INFO    : Updated Thermal Rating: on transformer 20316-20320 : Rate B, Rate C - 0.0, 0.0 -> 1122.82, 1122.82
% INFO    : Updated Thermal Rating: on transformer 20318-20317 : Rate B, Rate C - 0.0, 0.0 -> 352.07, 352.07
% INFO    : Updated Thermal Rating: on line 20318-20495 : Rate B, Rate C - 0.0, 0.0 -> 171.75, 171.75
% INFO    : Updated Thermal Rating: on line 20535-20318 : Rate B, Rate C - 0.0, 0.0 -> 224.84, 224.84
% INFO    : Updated Thermal Rating: on line 20321-20387 : Rate B, Rate C - 0.0, 0.0 -> 4211.91, 4211.91
% INFO    : Updated Thermal Rating: on line 20436-20321 : Rate B, Rate C - 0.0, 0.0 -> 4276.25, 4276.25
% INFO    : Updated Thermal Rating: on line 20322-20365 : Rate B, Rate C - 0.0, 0.0 -> 1212.69, 1212.69
% INFO    : Updated Thermal Rating: on line 20323-20354 : Rate B, Rate C - 0.0, 0.0 -> 205.58, 205.58
% INFO    : Updated Thermal Rating: on transformer 20324-20327 : Rate B, Rate C - 0.0, 0.0 -> 493.73, 493.73
% INFO    : Updated Thermal Rating: on transformer 20324-20328 : Rate B, Rate C - 0.0, 0.0 -> 377.3, 377.3
% INFO    : Updated Thermal Rating: on transformer 20324-20329 : Rate B, Rate C - 0.0, 0.0 -> 376.04, 376.04
% INFO    : Updated Thermal Rating: on line 20378-20324 : Rate B, Rate C - 0.0, 0.0 -> 1094.99, 1094.99
% INFO    : Updated Thermal Rating: on line 20324-20381 : Rate B, Rate C - 0.0, 0.0 -> 1254.61, 1254.61
% INFO    : Updated Thermal Rating: on transformer 20325-20327 : Rate B, Rate C - 0.0, 0.0 -> 393.73, 393.73
% INFO    : Updated Thermal Rating: on line 20357-20325 : Rate B, Rate C - 0.0, 0.0 -> 238.98, 238.98
% INFO    : Updated Thermal Rating: on transformer 20326-20327 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 20330-20357 : Rate B, Rate C - 0.0, 0.0 -> 189.06, 189.06
% INFO    : Updated Thermal Rating: on line 20380-20330 : Rate B, Rate C - 0.0, 0.0 -> 245.49, 245.49
% INFO    : Updated Thermal Rating: on transformer 20331-20332 : Rate B, Rate C - 0.0, 0.0 -> 102.51, 102.51
% INFO    : Updated Thermal Rating: on line 20425-20334 : Rate B, Rate C - 0.0, 0.0 -> 172.71, 172.71
% INFO    : Updated Thermal Rating: on transformer 20335-20338 : Rate B, Rate C - 0.0, 0.0 -> 479.44, 479.44
% INFO    : Updated Thermal Rating: on line 20422-20335 : Rate B, Rate C - 0.0, 0.0 -> 1144.79, 1144.79
% INFO    : Updated Thermal Rating: on line 20335-30048 : Rate B, Rate C - 0.0, 0.0 -> 1202.37, 1202.37
% INFO    : Updated Thermal Rating: on transformer 20336-20338 : Rate B, Rate C - 0.0, 0.0 -> 379.44, 379.44
% INFO    : Updated Thermal Rating: on line 20336-20347 : Rate B, Rate C - 0.0, 0.0 -> 221.81, 221.81
% INFO    : Updated Thermal Rating: on line 20539-20336 : Rate B, Rate C - 0.0, 0.0 -> 206.04, 206.04
% INFO    : Updated Thermal Rating: on transformer 20337-20338 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 20339-20342 : Rate B, Rate C - 0.0, 0.0 -> 617.66, 617.66
% INFO    : Updated Thermal Rating: on line 20339-20431 : Rate B, Rate C - 0.0, 0.0 -> 1179.33, 1179.33
% INFO    : Updated Thermal Rating: on transformer 20340-20342 : Rate B, Rate C - 0.0, 0.0 -> 517.66, 517.66
% INFO    : Updated Thermal Rating: on transformer 20341-20342 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 20343-20344 : Rate B, Rate C - 0.0, 0.0 -> 61.95, 61.95
% INFO    : Updated Thermal Rating: on transformer 20343-20345 : Rate B, Rate C - 0.0, 0.0 -> 21.32, 21.32
% INFO    : Updated Thermal Rating: on line 20409-20347 : Rate B, Rate C - 0.0, 0.0 -> 221.96, 221.96
% INFO    : Updated Thermal Rating: on transformer 20348-20349 : Rate B, Rate C - 0.0, 0.0 -> 70.81, 70.81
% INFO    : Updated Thermal Rating: on transformer 20348-20350 : Rate B, Rate C - 0.0, 0.0 -> 29.77, 29.77
% INFO    : Updated Thermal Rating: on transformer 20352-20351 : Rate B, Rate C - 0.0, 0.0 -> 327.16, 327.16
% INFO    : Updated Thermal Rating: on line 20351-20480 : Rate B, Rate C - 0.0, 0.0 -> 1046.25, 1046.25
% INFO    : Updated Thermal Rating: on transformer 20356-20355 : Rate B, Rate C - 0.0, 0.0 -> 524.24, 524.24
% INFO    : Updated Thermal Rating: on line 20355-20466 : Rate B, Rate C - 0.0, 0.0 -> 1048.97, 1048.97
% INFO    : Updated Thermal Rating: on line 20355-20509 : Rate B, Rate C - 0.0, 0.0 -> 1132.57, 1132.57
% INFO    : Updated Thermal Rating: on transformer 20358-20359 : Rate B, Rate C - 0.0, 0.0 -> 70.39, 70.39
% INFO    : Updated Thermal Rating: on transformer 20362-20361 : Rate B, Rate C - 0.0, 0.0 -> 440.72, 440.72
% INFO    : Updated Thermal Rating: on transformer 20361-20363 : Rate B, Rate C - 0.0, 0.0 -> 486.09, 486.09
% INFO    : Updated Thermal Rating: on line 20362-21277 : Rate B, Rate C - 0.0, 0.0 -> 240.27, 240.27
% INFO    : Updated Thermal Rating: on line 20362-21481 : Rate B, Rate C - 0.0, 0.0 -> 267.12, 267.12
% INFO    : Updated Thermal Rating: on line 21482-20362 : Rate B, Rate C - 0.0, 0.0 -> 230.81, 230.81
% INFO    : Updated Thermal Rating: on line 20362-21539 : Rate B, Rate C - 0.0, 0.0 -> 205.97, 205.97
% INFO    : Updated Thermal Rating: on line 21716-20362 : Rate B, Rate C - 0.0, 0.0 -> 178.38, 178.38
% INFO    : Updated Thermal Rating: on line 21759-20362 : Rate B, Rate C - 0.0, 0.0 -> 276.31, 276.31
% INFO    : Updated Thermal Rating: on line 20364-21642 : Rate B, Rate C - 0.0, 0.0 -> 1159.89, 1159.89
% INFO    : Updated Thermal Rating: on line 21682-20364 : Rate B, Rate C - 0.0, 0.0 -> 1029.48, 1029.48
% INFO    : Updated Thermal Rating: on transformer 20366-20365 : Rate B, Rate C - 0.0, 0.0 -> 377.76, 377.76
% INFO    : Updated Thermal Rating: on transformer 20365-20367 : Rate B, Rate C - 0.0, 0.0 -> 342.51, 342.51
% INFO    : Updated Thermal Rating: on transformer 20365-20368 : Rate B, Rate C - 0.0, 0.0 -> 340.37, 340.37
% INFO    : Updated Thermal Rating: on transformer 20365-20369 : Rate B, Rate C - 0.0, 0.0 -> 288.04, 288.04
% INFO    : Updated Thermal Rating: on line 20365-20476 : Rate B, Rate C - 0.0, 0.0 -> 1127.7, 1127.7
% INFO    : Updated Thermal Rating: on transformer 20366-20370 : Rate B, Rate C - 0.0, 0.0 -> 9.88, 9.88
% INFO    : Updated Thermal Rating: on transformer 20366-20371 : Rate B, Rate C - 0.0, 0.0 -> 17.55, 17.55
% INFO    : Updated Thermal Rating: on line 20366-20535 : Rate B, Rate C - 0.0, 0.0 -> 225.68, 225.68
% INFO    : Updated Thermal Rating: on transformer 20375-20374 : Rate B, Rate C - 0.0, 0.0 -> 341.29, 341.29
% INFO    : Updated Thermal Rating: on transformer 20374-20376 : Rate B, Rate C - 0.0, 0.0 -> 349.25, 349.25
% INFO    : Updated Thermal Rating: on transformer 20374-20377 : Rate B, Rate C - 0.0, 0.0 -> 348.93, 348.93
% INFO    : Updated Thermal Rating: on line 20375-20382 : Rate B, Rate C - 0.0, 0.0 -> 271.54, 271.54
% INFO    : Updated Thermal Rating: on line 20386-20375 : Rate B, Rate C - 0.0, 0.0 -> 232.5, 232.5
% INFO    : Updated Thermal Rating: on line 20375-20472 : Rate B, Rate C - 0.0, 0.0 -> 254.22, 254.22
% INFO    : Updated Thermal Rating: on line 20378-20388 : Rate B, Rate C - 0.0, 0.0 -> 1180.1, 1180.1
% INFO    : Updated Thermal Rating: on line 20378-20404 : Rate B, Rate C - 0.0, 0.0 -> 1253.64, 1253.64
% INFO    : Updated Thermal Rating: on transformer 20380-20379 : Rate B, Rate C - 0.0, 0.0 -> 333.19, 333.19
% INFO    : Updated Thermal Rating: on line 20437-20381 : Rate B, Rate C - 0.0, 0.0 -> 1279.64, 1279.64
% INFO    : Updated Thermal Rating: on transformer 20382-20383 : Rate B, Rate C - 0.0, 0.0 -> 99.05, 99.05
% INFO    : Updated Thermal Rating: on transformer 20382-20384 : Rate B, Rate C - 0.0, 0.0 -> 15.73, 15.73
% INFO    : Updated Thermal Rating: on line 20522-20382 : Rate B, Rate C - 0.0, 0.0 -> 221.29, 221.29
% INFO    : Updated Thermal Rating: on transformer 20388-20387 : Rate B, Rate C - 0.0, 0.0 -> 1452.96, 1452.96
% INFO    : Updated Thermal Rating: on transformer 20387-20390 : Rate B, Rate C - 0.0, 0.0 -> 1261.55, 1261.55
% INFO    : Updated Thermal Rating: on transformer 20387-20391 : Rate B, Rate C - 0.0, 0.0 -> 1259.67, 1259.67
% INFO    : Updated Thermal Rating: on transformer 20387-20392 : Rate B, Rate C - 0.0, 0.0 -> 1258.35, 1258.35
% INFO    : Updated Thermal Rating: on transformer 20387-20393 : Rate B, Rate C - 0.0, 0.0 -> 1254.82, 1254.82
% INFO    : Updated Thermal Rating: on transformer 20387-20394 : Rate B, Rate C - 0.0, 0.0 -> 1253.35, 1253.35
% INFO    : Updated Thermal Rating: on transformer 20387-20395 : Rate B, Rate C - 0.0, 0.0 -> 1253.19, 1253.19
% INFO    : Updated Thermal Rating: on line 20387-20423 : Rate B, Rate C - 0.0, 0.0 -> 4206.95, 4206.95
% INFO    : Updated Thermal Rating: on line 20387-20484 : Rate B, Rate C - 0.0, 0.0 -> 4223.39, 4223.39
% INFO    : Updated Thermal Rating: on line 20387-20530 : Rate B, Rate C - 0.0, 0.0 -> 3975.19, 3975.19
% INFO    : Updated Thermal Rating: on transformer 20389-20388 : Rate B, Rate C - 0.0, 0.0 -> 398.03, 398.03
% INFO    : Updated Thermal Rating: on line 20476-20388 : Rate B, Rate C - 0.0, 0.0 -> 1108.61, 1108.61
% INFO    : Updated Thermal Rating: on transformer 20396-20399 : Rate B, Rate C - 0.0, 0.0 -> 709.93, 709.93
% INFO    : Updated Thermal Rating: on transformer 20397-20399 : Rate B, Rate C - 0.0, 0.0 -> 559.93, 559.93
% INFO    : Updated Thermal Rating: on transformer 20398-20399 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 20400-20403 : Rate B, Rate C - 0.0, 0.0 -> 541.95, 541.95
% INFO    : Updated Thermal Rating: on transformer 20401-20403 : Rate B, Rate C - 0.0, 0.0 -> 491.95, 491.95
% INFO    : Updated Thermal Rating: on transformer 20402-20403 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 20431-20404 : Rate B, Rate C - 0.0, 0.0 -> 1213.48, 1213.48
% INFO    : Updated Thermal Rating: on line 20404-21081 : Rate B, Rate C - 0.0, 0.0 -> 1339.47, 1339.47
% INFO    : Updated Thermal Rating: on transformer 20405-20408 : Rate B, Rate C - 0.0, 0.0 -> 209.18, 209.18
% INFO    : Updated Thermal Rating: on transformer 20406-20408 : Rate B, Rate C - 0.0, 0.0 -> 104.59, 104.59
% INFO    : Updated Thermal Rating: on transformer 20407-20408 : Rate B, Rate C - 0.0, 0.0 -> 104.59, 104.59
% INFO    : Updated Thermal Rating: on transformer 20411-20410 : Rate B, Rate C - 0.0, 0.0 -> 413.73, 413.73
% INFO    : Updated Thermal Rating: on transformer 20410-20414 : Rate B, Rate C - 0.0, 0.0 -> 598.19, 598.19
% INFO    : Updated Thermal Rating: on line 20410-20422 : Rate B, Rate C - 0.0, 0.0 -> 1106.21, 1106.21
% INFO    : Updated Thermal Rating: on line 20542-20410 : Rate B, Rate C - 0.0, 0.0 -> 1176.76, 1176.76
% INFO    : Updated Thermal Rating: on line 20534-20411 : Rate B, Rate C - 0.0, 0.0 -> 262.68, 262.68
% INFO    : Updated Thermal Rating: on transformer 20412-20414 : Rate B, Rate C - 0.0, 0.0 -> 299.1, 299.1
% INFO    : Updated Thermal Rating: on transformer 20413-20414 : Rate B, Rate C - 0.0, 0.0 -> 299.1, 299.1
% INFO    : Updated Thermal Rating: on transformer 20416-20415 : Rate B, Rate C - 0.0, 0.0 -> 379.86, 379.86
% INFO    : Updated Thermal Rating: on transformer 20418-20421 : Rate B, Rate C - 0.0, 0.0 -> 416.45, 416.45
% INFO    : Updated Thermal Rating: on transformer 20419-20421 : Rate B, Rate C - 0.0, 0.0 -> 366.45, 366.45
% INFO    : Updated Thermal Rating: on line 20419-20454 : Rate B, Rate C - 0.0, 0.0 -> 225.48, 225.48
% INFO    : Updated Thermal Rating: on transformer 20420-20421 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 20423-20427 : Rate B, Rate C - 0.0, 0.0 -> 1648.26, 1648.26
% INFO    : Updated Thermal Rating: on transformer 20423-20428 : Rate B, Rate C - 0.0, 0.0 -> 1496.36, 1496.36
% INFO    : Updated Thermal Rating: on transformer 20423-20429 : Rate B, Rate C - 0.0, 0.0 -> 1494.48, 1494.48
% INFO    : Updated Thermal Rating: on transformer 20423-20430 : Rate B, Rate C - 0.0, 0.0 -> 1493.68, 1493.68
% INFO    : Updated Thermal Rating: on line 20423-20436 : Rate B, Rate C - 0.0, 0.0 -> 4081.19, 4081.19
% INFO    : Updated Thermal Rating: on line 20423-20465 : Rate B, Rate C - 0.0, 0.0 -> 4095.59, 4095.59
% INFO    : Updated Thermal Rating: on line 20513-20423 : Rate B, Rate C - 0.0, 0.0 -> 4161.79, 4161.79
% INFO    : Updated Thermal Rating: on transformer 20425-20424 : Rate B, Rate C - 0.0, 0.0 -> 451.97, 451.97
% INFO    : Updated Thermal Rating: on transformer 20424-20427 : Rate B, Rate C - 0.0, 0.0 -> 1523.26, 1523.26
% INFO    : Updated Thermal Rating: on transformer 20426-20427 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 20452-20431 : Rate B, Rate C - 0.0, 0.0 -> 1046.44, 1046.44
% INFO    : Updated Thermal Rating: on transformer 20434-20435 : Rate B, Rate C - 0.0, 0.0 -> 86.08, 86.08
% INFO    : Updated Thermal Rating: on line 20434-20504 : Rate B, Rate C - 0.0, 0.0 -> 178.31, 178.31
% INFO    : Updated Thermal Rating: on line 20434-20534 : Rate B, Rate C - 0.0, 0.0 -> 235.17, 235.17
% INFO    : Updated Thermal Rating: on transformer 20437-20436 : Rate B, Rate C - 0.0, 0.0 -> 1433.96, 1433.96
% INFO    : Updated Thermal Rating: on transformer 20436-20439 : Rate B, Rate C - 0.0, 0.0 -> 1248.47, 1248.47
% INFO    : Updated Thermal Rating: on transformer 20436-20440 : Rate B, Rate C - 0.0, 0.0 -> 1246.48, 1246.48
% INFO    : Updated Thermal Rating: on transformer 20436-20441 : Rate B, Rate C - 0.0, 0.0 -> 1243.48, 1243.48
% INFO    : Updated Thermal Rating: on transformer 20436-20442 : Rate B, Rate C - 0.0, 0.0 -> 1192.38, 1192.38
% INFO    : Updated Thermal Rating: on transformer 20436-20443 : Rate B, Rate C - 0.0, 0.0 -> 1187.01, 1187.01
% INFO    : Updated Thermal Rating: on transformer 20436-20444 : Rate B, Rate C - 0.0, 0.0 -> 1184.72, 1184.72
% INFO    : Updated Thermal Rating: on line 30387-20436 : Rate B, Rate C - 0.0, 0.0 -> 4130.0, 4130.0
% INFO    : Updated Thermal Rating: on transformer 20438-20437 : Rate B, Rate C - 0.0, 0.0 -> 457.13, 457.13
% INFO    : Updated Thermal Rating: on transformer 20437-20445 : Rate B, Rate C - 0.0, 0.0 -> 217.61, 217.61
% INFO    : Updated Thermal Rating: on line 20452-20437 : Rate B, Rate C - 0.0, 0.0 -> 1263.84, 1263.84
% INFO    : Updated Thermal Rating: on line 20437-20542 : Rate B, Rate C - 0.0, 0.0 -> 1156.25, 1156.25
% INFO    : Updated Thermal Rating: on transformer 20446-20447 : Rate B, Rate C - 0.0, 0.0 -> 94.93, 94.93
% INFO    : Updated Thermal Rating: on transformer 20446-20448 : Rate B, Rate C - 0.0, 0.0 -> 94.04, 94.04
% INFO    : Updated Thermal Rating: on transformer 20446-20449 : Rate B, Rate C - 0.0, 0.0 -> 59.2, 59.2
% INFO    : Updated Thermal Rating: on line 20446-20486 : Rate B, Rate C - 0.0, 0.0 -> 273.91, 273.91
% INFO    : Updated Thermal Rating: on line 20446-21013 : Rate B, Rate C - 0.0, 0.0 -> 251.66, 251.66
% INFO    : Updated Thermal Rating: on line 20446-21045 : Rate B, Rate C - 0.0, 0.0 -> 249.59, 249.59
% INFO    : Updated Thermal Rating: on line 20464-20450 : Rate B, Rate C - 0.0, 0.0 -> 246.61, 246.61
% INFO    : Updated Thermal Rating: on transformer 20453-20452 : Rate B, Rate C - 0.0, 0.0 -> 332.53, 332.53
% INFO    : Updated Thermal Rating: on line 20452-21385 : Rate B, Rate C - 0.0, 0.0 -> 1282.18, 1282.18
% INFO    : Updated Thermal Rating: on line 20453-20457 : Rate B, Rate C - 0.0, 0.0 -> 238.54, 238.54
% INFO    : Updated Thermal Rating: on line 20461-20453 : Rate B, Rate C - 0.0, 0.0 -> 200.15, 200.15
% INFO    : Updated Thermal Rating: on line 20453-20471 : Rate B, Rate C - 0.0, 0.0 -> 222.49, 222.49
% INFO    : Updated Thermal Rating: on transformer 20455-20456 : Rate B, Rate C - 0.0, 0.0 -> 82.96, 82.96
% INFO    : Updated Thermal Rating: on line 20457-20461 : Rate B, Rate C - 0.0, 0.0 -> 236.65, 236.65
% INFO    : Updated Thermal Rating: on transformer 20459-20460 : Rate B, Rate C - 0.0, 0.0 -> 83.08, 83.08
% INFO    : Updated Thermal Rating: on line 20461-20471 : Rate B, Rate C - 0.0, 0.0 -> 154.02, 154.02
% INFO    : Updated Thermal Rating: on line 20462-20477 : Rate B, Rate C - 0.0, 0.0 -> 227.34, 227.34
% INFO    : Updated Thermal Rating: on line 20473-20464 : Rate B, Rate C - 0.0, 0.0 -> 268.57, 268.57
% INFO    : Updated Thermal Rating: on line 20464-21002 : Rate B, Rate C - 0.0, 0.0 -> 254.44, 254.44
% INFO    : Updated Thermal Rating: on transformer 20466-20465 : Rate B, Rate C - 0.0, 0.0 -> 1470.47, 1470.47
% INFO    : Updated Thermal Rating: on transformer 20465-20468 : Rate B, Rate C - 0.0, 0.0 -> 1426.93, 1426.93
% INFO    : Updated Thermal Rating: on transformer 20465-20469 : Rate B, Rate C - 0.0, 0.0 -> 1426.48, 1426.48
% INFO    : Updated Thermal Rating: on transformer 20465-20470 : Rate B, Rate C - 0.0, 0.0 -> 1425.73, 1425.73
% INFO    : Updated Thermal Rating: on line 20465-23431 : Rate B, Rate C - 0.0, 0.0 -> 4120.91, 4120.91
% INFO    : Updated Thermal Rating: on transformer 20467-20466 : Rate B, Rate C - 0.0, 0.0 -> 491.31, 491.31
% INFO    : Updated Thermal Rating: on line 20466-23473 : Rate B, Rate C - 0.0, 0.0 -> 1176.03, 1176.03
% INFO    : Updated Thermal Rating: on line 23072-20467 : Rate B, Rate C - 0.0, 0.0 -> 213.28, 213.28
% INFO    : Updated Thermal Rating: on transformer 20473-20474 : Rate B, Rate C - 0.0, 0.0 -> 107.34, 107.34
% INFO    : Updated Thermal Rating: on line 20473-20486 : Rate B, Rate C - 0.0, 0.0 -> 218.9, 218.9
% INFO    : Updated Thermal Rating: on transformer 20477-20476 : Rate B, Rate C - 0.0, 0.0 -> 354.75, 354.75
% INFO    : Updated Thermal Rating: on transformer 20476-20478 : Rate B, Rate C - 0.0, 0.0 -> 409.11, 409.11
% INFO    : Updated Thermal Rating: on transformer 20476-20479 : Rate B, Rate C - 0.0, 0.0 -> 408.68, 408.68
% INFO    : Updated Thermal Rating: on line 20476-20497 : Rate B, Rate C - 0.0, 0.0 -> 1208.23, 1208.23
% INFO    : Updated Thermal Rating: on transformer 20481-20480 : Rate B, Rate C - 0.0, 0.0 -> 381.68, 381.68
% INFO    : Updated Thermal Rating: on transformer 20480-20482 : Rate B, Rate C - 0.0, 0.0 -> 402.04, 402.04
% INFO    : Updated Thermal Rating: on transformer 20480-20483 : Rate B, Rate C - 0.0, 0.0 -> 401.18, 401.18
% INFO    : Updated Thermal Rating: on line 20480-20497 : Rate B, Rate C - 0.0, 0.0 -> 1111.12, 1111.12
% INFO    : Updated Thermal Rating: on transformer 20485-20484 : Rate B, Rate C - 0.0, 0.0 -> 1600.17, 1600.17
% INFO    : Updated Thermal Rating: on transformer 20485-20484 : Rate B, Rate C - 0.0, 0.0 -> 1600.17, 1600.17
% INFO    : Updated Thermal Rating: on transformer 20485-20484 : Rate B, Rate C - 0.0, 0.0 -> 1600.17, 1600.17
% INFO    : Updated Thermal Rating: on transformer 20484-20487 : Rate B, Rate C - 0.0, 0.0 -> 1501.15, 1501.15
% INFO    : Updated Thermal Rating: on transformer 20484-20488 : Rate B, Rate C - 0.0, 0.0 -> 1500.6, 1500.6
% INFO    : Updated Thermal Rating: on transformer 20484-20489 : Rate B, Rate C - 0.0, 0.0 -> 1499.1, 1499.1
% INFO    : Updated Thermal Rating: on transformer 20484-20490 : Rate B, Rate C - 0.0, 0.0 -> 1498.36, 1498.36
% INFO    : Updated Thermal Rating: on transformer 20484-20491 : Rate B, Rate C - 0.0, 0.0 -> 1497.0, 1497.0
% INFO    : Updated Thermal Rating: on transformer 20484-20492 : Rate B, Rate C - 0.0, 0.0 -> 1496.37, 1496.37
% INFO    : Updated Thermal Rating: on line 21641-20484 : Rate B, Rate C - 0.0, 0.0 -> 4089.54, 4089.54
% INFO    : Updated Thermal Rating: on transformer 20486-20485 : Rate B, Rate C - 0.0, 0.0 -> 620.0, 620.0
% INFO    : Updated Thermal Rating: on line 21002-20486 : Rate B, Rate C - 0.0, 0.0 -> 241.58, 241.58
% INFO    : Updated Thermal Rating: on line 21026-20493 : Rate B, Rate C - 0.0, 0.0 -> 1433.49, 1433.49
% INFO    : Updated Thermal Rating: on line 21035-20493 : Rate B, Rate C - 0.0, 0.0 -> 1365.35, 1365.35
% INFO    : Updated Thermal Rating: on line 20496-30003 : Rate B, Rate C - 0.0, 0.0 -> 253.31, 253.31
% INFO    : Updated Thermal Rating: on transformer 20498-20497 : Rate B, Rate C - 0.0, 0.0 -> 407.15, 407.15
% INFO    : Updated Thermal Rating: on transformer 20497-20502 : Rate B, Rate C - 0.0, 0.0 -> 394.46, 394.46
% INFO    : Updated Thermal Rating: on transformer 20497-20503 : Rate B, Rate C - 0.0, 0.0 -> 361.51, 361.51
% INFO    : Updated Thermal Rating: on transformer 20498-20501 : Rate B, Rate C - 0.0, 0.0 -> 237.15, 237.15
% INFO    : Updated Thermal Rating: on transformer 20499-20501 : Rate B, Rate C - 0.0, 0.0 -> 118.58, 118.58
% INFO    : Updated Thermal Rating: on transformer 20500-20501 : Rate B, Rate C - 0.0, 0.0 -> 118.58, 118.58
% INFO    : Updated Thermal Rating: on transformer 20504-20507 : Rate B, Rate C - 0.0, 0.0 -> 264.31, 264.31
% INFO    : Updated Thermal Rating: on transformer 20505-20507 : Rate B, Rate C - 0.0, 0.0 -> 132.15, 132.15
% INFO    : Updated Thermal Rating: on transformer 20506-20507 : Rate B, Rate C - 0.0, 0.0 -> 132.15, 132.15
% INFO    : Updated Thermal Rating: on transformer 20509-20508 : Rate B, Rate C - 0.0, 0.0 -> 1451.6, 1451.6
% INFO    : Updated Thermal Rating: on transformer 20509-20512 : Rate B, Rate C - 0.0, 0.0 -> 562.96, 562.96
% INFO    : Updated Thermal Rating: on transformer 20510-20512 : Rate B, Rate C - 0.0, 0.0 -> 537.96, 537.96
% INFO    : Updated Thermal Rating: on transformer 20511-20512 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 23431-20513 : Rate B, Rate C - 0.0, 0.0 -> 4064.85, 4064.85
% INFO    : Updated Thermal Rating: on transformer 20514-20515 : Rate B, Rate C - 0.0, 0.0 -> 64.15, 64.15
% INFO    : Updated Thermal Rating: on transformer 20514-20516 : Rate B, Rate C - 0.0, 0.0 -> 64.48, 64.48
% INFO    : Updated Thermal Rating: on transformer 20514-20517 : Rate B, Rate C - 0.0, 0.0 -> 11.7, 11.7
% INFO    : Updated Thermal Rating: on transformer 20520-20521 : Rate B, Rate C - 0.0, 0.0 -> 76.07, 76.07
% INFO    : Updated Thermal Rating: on transformer 20526-20525 : Rate B, Rate C - 0.0, 0.0 -> 326.7, 326.7
% INFO    : Updated Thermal Rating: on transformer 20531-20530 : Rate B, Rate C - 0.0, 0.0 -> 1415.97, 1415.97
% INFO    : Updated Thermal Rating: on transformer 20532-20531 : Rate B, Rate C - 0.0, 0.0 -> 432.19, 432.19
% INFO    : Updated Thermal Rating: on transformer 20535-20536 : Rate B, Rate C - 0.0, 0.0 -> 104.51, 104.51
% INFO    : Updated Thermal Rating: on transformer 20535-20537 : Rate B, Rate C - 0.0, 0.0 -> 69.13, 69.13
% INFO    : Updated Thermal Rating: on transformer 20535-20538 : Rate B, Rate C - 0.0, 0.0 -> 68.88, 68.88
% INFO    : Updated Thermal Rating: on transformer 20539-20540 : Rate B, Rate C - 0.0, 0.0 -> 110.63, 110.63
% INFO    : Updated Thermal Rating: on transformer 20539-20541 : Rate B, Rate C - 0.0, 0.0 -> 110.2, 110.2
% INFO    : Updated Thermal Rating: on transformer 20543-20542 : Rate B, Rate C - 0.0, 0.0 -> 404.14, 404.14
% INFO    : Updated Thermal Rating: on transformer 20542-20544 : Rate B, Rate C - 0.0, 0.0 -> 496.7, 496.7
% INFO    : Updated Thermal Rating: on transformer 20542-20545 : Rate B, Rate C - 0.0, 0.0 -> 496.65, 496.65
% INFO    : Updated Thermal Rating: on line 21002-21001 : Rate B, Rate C - 0.0, 0.0 -> 258.05, 258.05
% INFO    : Updated Thermal Rating: on line 21001-21005 : Rate B, Rate C - 0.0, 0.0 -> 244.41, 244.41
% INFO    : Updated Thermal Rating: on line 21005-21006 : Rate B, Rate C - 0.0, 0.0 -> 208.53, 208.53
% INFO    : Updated Thermal Rating: on line 21005-21060 : Rate B, Rate C - 0.0, 0.0 -> 245.62, 245.62
% INFO    : Updated Thermal Rating: on line 21027-21006 : Rate B, Rate C - 0.0, 0.0 -> 230.36, 230.36
% INFO    : Updated Thermal Rating: on line 21010-21011 : Rate B, Rate C - 0.0, 0.0 -> 224.01, 224.01
% INFO    : Updated Thermal Rating: on line 21010-21013 : Rate B, Rate C - 0.0, 0.0 -> 228.22, 228.22
% INFO    : Updated Thermal Rating: on line 21010-21031 : Rate B, Rate C - 0.0, 0.0 -> 241.21, 241.21
% INFO    : Updated Thermal Rating: on line 21027-21014 : Rate B, Rate C - 0.0, 0.0 -> 231.48, 231.48
% INFO    : Updated Thermal Rating: on line 21014-21040 : Rate B, Rate C - 0.0, 0.0 -> 206.02, 206.02
% INFO    : Updated Thermal Rating: on line 21016-21019 : Rate B, Rate C - 0.0, 0.0 -> 256.96, 256.96
% INFO    : Updated Thermal Rating: on line 21016-21043 : Rate B, Rate C - 0.0, 0.0 -> 238.57, 238.57
% INFO    : Updated Thermal Rating: on transformer 21018-21021 : Rate B, Rate C - 0.0, 0.0 -> 567.92, 567.92
% INFO    : Updated Thermal Rating: on line 21018-21026 : Rate B, Rate C - 0.0, 0.0 -> 1238.5, 1238.5
% INFO    : Updated Thermal Rating: on transformer 21019-21021 : Rate B, Rate C - 0.0, 0.0 -> 542.92, 542.92
% INFO    : Updated Thermal Rating: on line 21019-21034 : Rate B, Rate C - 0.0, 0.0 -> 272.54, 272.54
% INFO    : Updated Thermal Rating: on transformer 21020-21021 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 21030-21024 : Rate B, Rate C - 0.0, 0.0 -> 209.85, 209.85
% INFO    : Updated Thermal Rating: on transformer 21026-21029 : Rate B, Rate C - 0.0, 0.0 -> 523.49, 523.49
% INFO    : Updated Thermal Rating: on line 21026-21035 : Rate B, Rate C - 0.0, 0.0 -> 1137.78, 1137.78
% INFO    : Updated Thermal Rating: on transformer 21027-21029 : Rate B, Rate C - 0.0, 0.0 -> 448.49, 448.49
% INFO    : Updated Thermal Rating: on transformer 21028-21029 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 21033-21030 : Rate B, Rate C - 0.0, 0.0 -> 209.17, 209.17
% INFO    : Updated Thermal Rating: on line 21030-21041 : Rate B, Rate C - 0.0, 0.0 -> 215.02, 215.02
% INFO    : Updated Thermal Rating: on line 21031-21060 : Rate B, Rate C - 0.0, 0.0 -> 216.91, 216.91
% INFO    : Updated Thermal Rating: on line 21033-21056 : Rate B, Rate C - 0.0, 0.0 -> 181.56, 181.56
% INFO    : Updated Thermal Rating: on line 21034-21069 : Rate B, Rate C - 0.0, 0.0 -> 250.41, 250.41
% INFO    : Updated Thermal Rating: on transformer 21035-21038 : Rate B, Rate C - 0.0, 0.0 -> 475.75, 475.75
% INFO    : Updated Thermal Rating: on line 21035-21166 : Rate B, Rate C - 0.0, 0.0 -> 1345.66, 1345.66
% INFO    : Updated Thermal Rating: on line 21035-21221 : Rate B, Rate C - 0.0, 0.0 -> 1145.14, 1145.14
% INFO    : Updated Thermal Rating: on transformer 21036-21038 : Rate B, Rate C - 0.0, 0.0 -> 425.75, 425.75
% INFO    : Updated Thermal Rating: on line 21041-21036 : Rate B, Rate C - 0.0, 0.0 -> 249.08, 249.08
% INFO    : Updated Thermal Rating: on line 21047-21036 : Rate B, Rate C - 0.0, 0.0 -> 214.45, 214.45
% INFO    : Updated Thermal Rating: on transformer 21037-21038 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 21040-21041 : Rate B, Rate C - 0.0, 0.0 -> 185.86, 185.86
% INFO    : Updated Thermal Rating: on line 21043-21067 : Rate B, Rate C - 0.0, 0.0 -> 197.45, 197.45
% INFO    : Updated Thermal Rating: on line 21055-21044 : Rate B, Rate C - 0.0, 0.0 -> 171.35, 171.35
% INFO    : Updated Thermal Rating: on line 21044-21082 : Rate B, Rate C - 0.0, 0.0 -> 261.26, 261.26
% INFO    : Updated Thermal Rating: on line 21049-21045 : Rate B, Rate C - 0.0, 0.0 -> 243.52, 243.52
% INFO    : Updated Thermal Rating: on line 21047-21056 : Rate B, Rate C - 0.0, 0.0 -> 221.17, 221.17
% INFO    : Updated Thermal Rating: on line 21049-21094 : Rate B, Rate C - 0.0, 0.0 -> 229.66, 229.66
% INFO    : Updated Thermal Rating: on line 21050-21062 : Rate B, Rate C - 0.0, 0.0 -> 187.95, 187.95
% INFO    : Updated Thermal Rating: on line 21070-21050 : Rate B, Rate C - 0.0, 0.0 -> 221.25, 221.25
% INFO    : Updated Thermal Rating: on line 21050-21095 : Rate B, Rate C - 0.0, 0.0 -> 185.94, 185.94
% INFO    : Updated Thermal Rating: on line 21051-21069 : Rate B, Rate C - 0.0, 0.0 -> 225.12, 225.12
% INFO    : Updated Thermal Rating: on line 21051-21119 : Rate B, Rate C - 0.0, 0.0 -> 194.61, 194.61
% INFO    : Updated Thermal Rating: on line 21085-21054 : Rate B, Rate C - 0.0, 0.0 -> 232.25, 232.25
% INFO    : Updated Thermal Rating: on line 21115-21054 : Rate B, Rate C - 0.0, 0.0 -> 250.3, 250.3
% INFO    : Updated Thermal Rating: on line 21069-21055 : Rate B, Rate C - 0.0, 0.0 -> 204.12, 204.12
% INFO    : Updated Thermal Rating: on line 21071-21055 : Rate B, Rate C - 0.0, 0.0 -> 173.31, 173.31
% INFO    : Updated Thermal Rating: on line 21060-21061 : Rate B, Rate C - 0.0, 0.0 -> 250.08, 250.08
% INFO    : Updated Thermal Rating: on line 21061-21067 : Rate B, Rate C - 0.0, 0.0 -> 232.86, 232.86
% INFO    : Updated Thermal Rating: on line 21062-21070 : Rate B, Rate C - 0.0, 0.0 -> 202.87, 202.87
% INFO    : Updated Thermal Rating: on line 21111-21064 : Rate B, Rate C - 0.0, 0.0 -> 259.82, 259.82
% INFO    : Updated Thermal Rating: on line 21064-21115 : Rate B, Rate C - 0.0, 0.0 -> 228.44, 228.44
% INFO    : Updated Thermal Rating: on line 21064-21167 : Rate B, Rate C - 0.0, 0.0 -> 240.88, 240.88
% INFO    : Updated Thermal Rating: on line 21065-21118 : Rate B, Rate C - 0.0, 0.0 -> 228.88, 228.88
% INFO    : Updated Thermal Rating: on line 21065-21167 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 21067-21071 : Rate B, Rate C - 0.0, 0.0 -> 223.24, 223.24
% INFO    : Updated Thermal Rating: on line 21070-21167 : Rate B, Rate C - 0.0, 0.0 -> 258.48, 258.48
% INFO    : Updated Thermal Rating: on line 21105-21072 : Rate B, Rate C - 0.0, 0.0 -> 202.79, 202.79
% INFO    : Updated Thermal Rating: on line 21072-21119 : Rate B, Rate C - 0.0, 0.0 -> 233.71, 233.71
% INFO    : Updated Thermal Rating: on line 21073-21079 : Rate B, Rate C - 0.0, 0.0 -> 199.05, 199.05
% INFO    : Updated Thermal Rating: on line 21108-21073 : Rate B, Rate C - 0.0, 0.0 -> 229.7, 229.7
% INFO    : Updated Thermal Rating: on line 21074-21139 : Rate B, Rate C - 0.0, 0.0 -> 224.11, 224.11
% INFO    : Updated Thermal Rating: on line 21074-21223 : Rate B, Rate C - 0.0, 0.0 -> 188.45, 188.45
% INFO    : Updated Thermal Rating: on line 21074-21237 : Rate B, Rate C - 0.0, 0.0 -> 201.19, 201.19
% INFO    : Updated Thermal Rating: on line 21075-21079 : Rate B, Rate C - 0.0, 0.0 -> 211.61, 211.61
% INFO    : Updated Thermal Rating: on line 21075-21101 : Rate B, Rate C - 0.0, 0.0 -> 255.14, 255.14
% INFO    : Updated Thermal Rating: on line 21105-21078 : Rate B, Rate C - 0.0, 0.0 -> 199.27, 199.27
% INFO    : Updated Thermal Rating: on line 21078-21111 : Rate B, Rate C - 0.0, 0.0 -> 201.21, 201.21
% INFO    : Updated Thermal Rating: on transformer 21082-21081 : Rate B, Rate C - 0.0, 0.0 -> 451.13, 451.13
% INFO    : Updated Thermal Rating: on line 21100-21081 : Rate B, Rate C - 0.0, 0.0 -> 1222.15, 1222.15
% INFO    : Updated Thermal Rating: on line 21081-21107 : Rate B, Rate C - 0.0, 0.0 -> 1127.0, 1127.0
% INFO    : Updated Thermal Rating: on line 21753-21081 : Rate B, Rate C - 0.0, 0.0 -> 1130.42, 1130.42
% INFO    : Updated Thermal Rating: on line 21085-21091 : Rate B, Rate C - 0.0, 0.0 -> 269.9, 269.9
% INFO    : Updated Thermal Rating: on line 21085-21101 : Rate B, Rate C - 0.0, 0.0 -> 255.57, 255.57
% INFO    : Updated Thermal Rating: on line 21086-21087 : Rate B, Rate C - 0.0, 0.0 -> 211.5, 211.5
% INFO    : Updated Thermal Rating: on line 21091-21086 : Rate B, Rate C - 0.0, 0.0 -> 228.97, 228.97
% INFO    : Updated Thermal Rating: on line 21097-21087 : Rate B, Rate C - 0.0, 0.0 -> 203.35, 203.35
% INFO    : Updated Thermal Rating: on line 21088-21133 : Rate B, Rate C - 0.0, 0.0 -> 214.52, 214.52
% INFO    : Updated Thermal Rating: on line 21146-21088 : Rate B, Rate C - 0.0, 0.0 -> 199.58, 199.58
% INFO    : Updated Thermal Rating: on line 21091-21098 : Rate B, Rate C - 0.0, 0.0 -> 177.51, 177.51
% INFO    : Updated Thermal Rating: on line 21091-21099 : Rate B, Rate C - 0.0, 0.0 -> 191.99, 191.99
% INFO    : Updated Thermal Rating: on line 21114-21091 : Rate B, Rate C - 0.0, 0.0 -> 210.9, 210.9
% INFO    : Updated Thermal Rating: on line 21093-21136 : Rate B, Rate C - 0.0, 0.0 -> 232.04, 232.04
% INFO    : Updated Thermal Rating: on line 21094-21177 : Rate B, Rate C - 0.0, 0.0 -> 205.18, 205.18
% INFO    : Updated Thermal Rating: on line 21095-21177 : Rate B, Rate C - 0.0, 0.0 -> 150.12, 150.12
% INFO    : Updated Thermal Rating: on line 21095-21178 : Rate B, Rate C - 0.0, 0.0 -> 222.83, 222.83
% INFO    : Updated Thermal Rating: on line 21096-21151 : Rate B, Rate C - 0.0, 0.0 -> 253.33, 253.33
% INFO    : Updated Thermal Rating: on line 21191-21096 : Rate B, Rate C - 0.0, 0.0 -> 239.5, 239.5
% INFO    : Updated Thermal Rating: on line 21097-21106 : Rate B, Rate C - 0.0, 0.0 -> 242.35, 242.35
% INFO    : Updated Thermal Rating: on line 21098-21111 : Rate B, Rate C - 0.0, 0.0 -> 218.47, 218.47
% INFO    : Updated Thermal Rating: on line 21099-21143 : Rate B, Rate C - 0.0, 0.0 -> 199.84, 199.84
% INFO    : Updated Thermal Rating: on transformer 21100-21103 : Rate B, Rate C - 0.0, 0.0 -> 528.05, 528.05
% INFO    : Updated Thermal Rating: on transformer 21101-21103 : Rate B, Rate C - 0.0, 0.0 -> 478.05, 478.05
% INFO    : Updated Thermal Rating: on transformer 21102-21103 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 21105-21125 : Rate B, Rate C - 0.0, 0.0 -> 211.98, 211.98
% INFO    : Updated Thermal Rating: on line 21106-21145 : Rate B, Rate C - 0.0, 0.0 -> 216.15, 216.15
% INFO    : Updated Thermal Rating: on line 21148-21106 : Rate B, Rate C - 0.0, 0.0 -> 186.96, 186.96
% INFO    : Updated Thermal Rating: on transformer 21108-21107 : Rate B, Rate C - 0.0, 0.0 -> 533.37, 533.37
% INFO    : Updated Thermal Rating: on line 21132-21107 : Rate B, Rate C - 0.0, 0.0 -> 1183.87, 1183.87
% INFO    : Updated Thermal Rating: on line 21107-21181 : Rate B, Rate C - 0.0, 0.0 -> 1153.25, 1153.25
% INFO    : Updated Thermal Rating: on line 21141-21108 : Rate B, Rate C - 0.0, 0.0 -> 243.05, 243.05
% INFO    : Updated Thermal Rating: on line 21108-21146 : Rate B, Rate C - 0.0, 0.0 -> 232.07, 232.07
% INFO    : Updated Thermal Rating: on line 21143-21113 : Rate B, Rate C - 0.0, 0.0 -> 240.81, 240.81
% INFO    : Updated Thermal Rating: on line 21113-21182 : Rate B, Rate C - 0.0, 0.0 -> 266.85, 266.85
% INFO    : Updated Thermal Rating: on line 21114-21141 : Rate B, Rate C - 0.0, 0.0 -> 193.05, 193.05
% INFO    : Updated Thermal Rating: on line 21115-21118 : Rate B, Rate C - 0.0, 0.0 -> 274.81, 274.81
% INFO    : Updated Thermal Rating: on line 21115-21167 : Rate B, Rate C - 0.0, 0.0 -> 310.11, 310.11
% INFO    : Updated Thermal Rating: on line 21115-21167 : Rate B, Rate C - 0.0, 0.0 -> 310.11, 310.11
% INFO    : Updated Thermal Rating: on line 21115-21167 : Rate B, Rate C - 0.0, 0.0 -> 310.11, 310.11
% INFO    : Updated Thermal Rating: on line 21119-21118 : Rate B, Rate C - 0.0, 0.0 -> 240.72, 240.72
% INFO    : Updated Thermal Rating: on line 21118-21145 : Rate B, Rate C - 0.0, 0.0 -> 235.08, 235.08
% INFO    : Updated Thermal Rating: on transformer 21120-21123 : Rate B, Rate C - 0.0, 0.0 -> 645.3, 645.3
% INFO    : Updated Thermal Rating: on line 21181-21120 : Rate B, Rate C - 0.0, 0.0 -> 1105.48, 1105.48
% INFO    : Updated Thermal Rating: on line 21120-21382 : Rate B, Rate C - 0.0, 0.0 -> 1258.49, 1258.49
% INFO    : Updated Thermal Rating: on transformer 21121-21123 : Rate B, Rate C - 0.0, 0.0 -> 495.3, 495.3
% INFO    : Updated Thermal Rating: on line 21121-21125 : Rate B, Rate C - 0.0, 0.0 -> 262.79, 262.79
% INFO    : Updated Thermal Rating: on transformer 21122-21123 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 21125-21130 : Rate B, Rate C - 0.0, 0.0 -> 228.85, 228.85
% INFO    : Updated Thermal Rating: on line 21126-21129 : Rate B, Rate C - 0.0, 0.0 -> 239.61, 239.61
% INFO    : Updated Thermal Rating: on line 21126-21143 : Rate B, Rate C - 0.0, 0.0 -> 214.16, 214.16
% INFO    : Updated Thermal Rating: on line 21127-21143 : Rate B, Rate C - 0.0, 0.0 -> 226.55, 226.55
% INFO    : Updated Thermal Rating: on line 21176-21127 : Rate B, Rate C - 0.0, 0.0 -> 188.2, 188.2
% INFO    : Updated Thermal Rating: on line 21129-21152 : Rate B, Rate C - 0.0, 0.0 -> 228.76, 228.76
% INFO    : Updated Thermal Rating: on line 21129-21165 : Rate B, Rate C - 0.0, 0.0 -> 257.81, 257.81
% INFO    : Updated Thermal Rating: on line 21130-21182 : Rate B, Rate C - 0.0, 0.0 -> 206.72, 206.72
% INFO    : Updated Thermal Rating: on transformer 21132-21135 : Rate B, Rate C - 0.0, 0.0 -> 604.44, 604.44
% INFO    : Updated Thermal Rating: on line 21132-21232 : Rate B, Rate C - 0.0, 0.0 -> 1223.95, 1223.95
% INFO    : Updated Thermal Rating: on transformer 21133-21135 : Rate B, Rate C - 0.0, 0.0 -> 479.44, 479.44
% INFO    : Updated Thermal Rating: on line 21133-21157 : Rate B, Rate C - 0.0, 0.0 -> 228.72, 228.72
% INFO    : Updated Thermal Rating: on line 21133-21158 : Rate B, Rate C - 0.0, 0.0 -> 270.0, 270.0
% INFO    : Updated Thermal Rating: on transformer 21134-21135 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 21136-21154 : Rate B, Rate C - 0.0, 0.0 -> 152.78, 152.78
% INFO    : Updated Thermal Rating: on line 21148-21140 : Rate B, Rate C - 0.0, 0.0 -> 239.22, 239.22
% INFO    : Updated Thermal Rating: on line 21242-21140 : Rate B, Rate C - 0.0, 0.0 -> 286.05, 286.05
% INFO    : Updated Thermal Rating: on line 21144-21154 : Rate B, Rate C - 0.0, 0.0 -> 214.86, 214.86
% INFO    : Updated Thermal Rating: on line 21144-21158 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 21144-21180 : Rate B, Rate C - 0.0, 0.0 -> 225.57, 225.57
% INFO    : Updated Thermal Rating: on line 21147-21239 : Rate B, Rate C - 0.0, 0.0 -> 206.85, 206.85
% INFO    : Updated Thermal Rating: on line 21147-21665 : Rate B, Rate C - 0.0, 0.0 -> 227.26, 227.26
% INFO    : Updated Thermal Rating: on line 21754-21151 : Rate B, Rate C - 0.0, 0.0 -> 264.58, 264.58
% INFO    : Updated Thermal Rating: on line 21152-21191 : Rate B, Rate C - 0.0, 0.0 -> 244.87, 244.87
% INFO    : Updated Thermal Rating: on line 21157-21176 : Rate B, Rate C - 0.0, 0.0 -> 194.89, 194.89
% INFO    : Updated Thermal Rating: on transformer 21160-21163 : Rate B, Rate C - 0.0, 0.0 -> 701.27, 701.27
% INFO    : Updated Thermal Rating: on transformer 21161-21163 : Rate B, Rate C - 0.0, 0.0 -> 551.27, 551.27
% INFO    : Updated Thermal Rating: on line 21161-21165 : Rate B, Rate C - 0.0, 0.0 -> 302.21, 302.21
% INFO    : Updated Thermal Rating: on line 21161-21190 : Rate B, Rate C - 0.0, 0.0 -> 209.89, 209.89
% INFO    : Updated Thermal Rating: on line 21259-21161 : Rate B, Rate C - 0.0, 0.0 -> 207.52, 207.52
% INFO    : Updated Thermal Rating: on transformer 21162-21163 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 21164-21642 : Rate B, Rate C - 0.0, 0.0 -> 1304.64, 1304.64
% INFO    : Updated Thermal Rating: on line 21671-21164 : Rate B, Rate C - 0.0, 0.0 -> 1086.33, 1086.33
% INFO    : Updated Thermal Rating: on line 21185-21165 : Rate B, Rate C - 0.0, 0.0 -> 189.63, 189.63
% INFO    : Updated Thermal Rating: on transformer 21167-21166 : Rate B, Rate C - 0.0, 0.0 -> 599.45, 599.45
% INFO    : Updated Thermal Rating: on transformer 21167-21166 : Rate B, Rate C - 0.0, 0.0 -> 599.45, 599.45
% INFO    : Updated Thermal Rating: on transformer 21167-21166 : Rate B, Rate C - 0.0, 0.0 -> 599.45, 599.45
% INFO    : Updated Thermal Rating: on line 21753-21166 : Rate B, Rate C - 0.0, 0.0 -> 1177.94, 1177.94
% INFO    : Updated Thermal Rating: on line 21170-21654 : Rate B, Rate C - 0.0, 0.0 -> 234.31, 234.31
% INFO    : Updated Thermal Rating: on line 21170-21723 : Rate B, Rate C - 0.0, 0.0 -> 273.36, 273.36
% INFO    : Updated Thermal Rating: on line 21755-21170 : Rate B, Rate C - 0.0, 0.0 -> 200.95, 200.95
% INFO    : Updated Thermal Rating: on line 21173-21195 : Rate B, Rate C - 0.0, 0.0 -> 235.44, 235.44
% INFO    : Updated Thermal Rating: on line 21755-21173 : Rate B, Rate C - 0.0, 0.0 -> 250.38, 250.38
% INFO    : Updated Thermal Rating: on line 21178-21237 : Rate B, Rate C - 0.0, 0.0 -> 212.3, 212.3
% INFO    : Updated Thermal Rating: on line 21178-21389 : Rate B, Rate C - 0.0, 0.0 -> 257.74, 257.74
% INFO    : Updated Thermal Rating: on line 21231-21179 : Rate B, Rate C - 0.0, 0.0 -> 161.0, 161.0
% INFO    : Updated Thermal Rating: on line 21255-21179 : Rate B, Rate C - 0.0, 0.0 -> 238.73, 238.73
% INFO    : Updated Thermal Rating: on line 21180-21233 : Rate B, Rate C - 0.0, 0.0 -> 270.0, 270.0
% INFO    : Updated Thermal Rating: on transformer 21182-21181 : Rate B, Rate C - 0.0, 0.0 -> 500.62, 500.62
% INFO    : Updated Thermal Rating: on line 21181-21671 : Rate B, Rate C - 0.0, 0.0 -> 1245.69, 1245.69
% INFO    : Updated Thermal Rating: on line 21203-21183 : Rate B, Rate C - 0.0, 0.0 -> 193.99, 193.99
% INFO    : Updated Thermal Rating: on line 21264-21183 : Rate B, Rate C - 0.0, 0.0 -> 220.32, 220.32
% INFO    : Updated Thermal Rating: on line 21185-21192 : Rate B, Rate C - 0.0, 0.0 -> 230.22, 230.22
% INFO    : Updated Thermal Rating: on line 21187-21188 : Rate B, Rate C - 0.0, 0.0 -> 243.17, 243.17
% INFO    : Updated Thermal Rating: on line 21187-21273 : Rate B, Rate C - 0.0, 0.0 -> 229.03, 229.03
% INFO    : Updated Thermal Rating: on line 21188-21201 : Rate B, Rate C - 0.0, 0.0 -> 186.7, 186.7
% INFO    : Updated Thermal Rating: on line 21188-21633 : Rate B, Rate C - 0.0, 0.0 -> 261.46, 261.46
% INFO    : Updated Thermal Rating: on line 21189-21206 : Rate B, Rate C - 0.0, 0.0 -> 206.6, 206.6
% INFO    : Updated Thermal Rating: on line 21353-21189 : Rate B, Rate C - 0.0, 0.0 -> 179.51, 179.51
% INFO    : Updated Thermal Rating: on line 21189-21717 : Rate B, Rate C - 0.0, 0.0 -> 229.19, 229.19
% INFO    : Updated Thermal Rating: on line 21190-21259 : Rate B, Rate C - 0.0, 0.0 -> 191.17, 191.17
% INFO    : Updated Thermal Rating: on line 21191-21195 : Rate B, Rate C - 0.0, 0.0 -> 220.91, 220.91
% INFO    : Updated Thermal Rating: on line 21192-21208 : Rate B, Rate C - 0.0, 0.0 -> 270.09, 270.09
% INFO    : Updated Thermal Rating: on line 21206-21193 : Rate B, Rate C - 0.0, 0.0 -> 185.99, 185.99
% INFO    : Updated Thermal Rating: on line 21193-21654 : Rate B, Rate C - 0.0, 0.0 -> 234.08, 234.08
% INFO    : Updated Thermal Rating: on line 21196-21197 : Rate B, Rate C - 0.0, 0.0 -> 231.96, 231.96
% INFO    : Updated Thermal Rating: on line 21196-21317 : Rate B, Rate C - 0.0, 0.0 -> 173.8, 173.8
% INFO    : Updated Thermal Rating: on line 21197-21262 : Rate B, Rate C - 0.0, 0.0 -> 251.86, 251.86
% INFO    : Updated Thermal Rating: on line 21268-21197 : Rate B, Rate C - 0.0, 0.0 -> 204.09, 204.09
% INFO    : Updated Thermal Rating: on line 21217-21198 : Rate B, Rate C - 0.0, 0.0 -> 180.09, 180.09
% INFO    : Updated Thermal Rating: on line 21198-21224 : Rate B, Rate C - 0.0, 0.0 -> 207.85, 207.85
% INFO    : Updated Thermal Rating: on line 21200-21233 : Rate B, Rate C - 0.0, 0.0 -> 235.81, 235.81
% INFO    : Updated Thermal Rating: on line 21200-21294 : Rate B, Rate C - 0.0, 0.0 -> 216.44, 216.44
% INFO    : Updated Thermal Rating: on line 21201-21294 : Rate B, Rate C - 0.0, 0.0 -> 190.87, 190.87
% INFO    : Updated Thermal Rating: on line 21203-21233 : Rate B, Rate C - 0.0, 0.0 -> 215.79, 215.79
% INFO    : Updated Thermal Rating: on line 21205-21213 : Rate B, Rate C - 0.0, 0.0 -> 202.97, 202.97
% INFO    : Updated Thermal Rating: on line 21254-21205 : Rate B, Rate C - 0.0, 0.0 -> 230.89, 230.89
% INFO    : Updated Thermal Rating: on line 21283-21208 : Rate B, Rate C - 0.0, 0.0 -> 228.67, 228.67
% INFO    : Updated Thermal Rating: on line 21208-21695 : Rate B, Rate C - 0.0, 0.0 -> 262.58, 262.58
% INFO    : Updated Thermal Rating: on line 21227-21210 : Rate B, Rate C - 0.0, 0.0 -> 216.14, 216.14
% INFO    : Updated Thermal Rating: on line 21210-21251 : Rate B, Rate C - 0.0, 0.0 -> 230.77, 230.77
% INFO    : Updated Thermal Rating: on line 21213-21211 : Rate B, Rate C - 0.0, 0.0 -> 184.84, 184.84
% INFO    : Updated Thermal Rating: on line 21211-21252 : Rate B, Rate C - 0.0, 0.0 -> 225.93, 225.93
% INFO    : Updated Thermal Rating: on line 21214-21265 : Rate B, Rate C - 0.0, 0.0 -> 203.41, 203.41
% INFO    : Updated Thermal Rating: on line 21214-21294 : Rate B, Rate C - 0.0, 0.0 -> 230.15, 230.15
% INFO    : Updated Thermal Rating: on line 21269-21215 : Rate B, Rate C - 0.0, 0.0 -> 234.93, 234.93
% INFO    : Updated Thermal Rating: on line 21729-21215 : Rate B, Rate C - 0.0, 0.0 -> 249.37, 249.37
% INFO    : Updated Thermal Rating: on line 21217-21351 : Rate B, Rate C - 0.0, 0.0 -> 218.43, 218.43
% INFO    : Updated Thermal Rating: on line 21247-21218 : Rate B, Rate C - 0.0, 0.0 -> 206.01, 206.01
% INFO    : Updated Thermal Rating: on line 21218-21665 : Rate B, Rate C - 0.0, 0.0 -> 233.65, 233.65
% INFO    : Updated Thermal Rating: on line 21268-21219 : Rate B, Rate C - 0.0, 0.0 -> 236.71, 236.71
% INFO    : Updated Thermal Rating: on line 21297-21219 : Rate B, Rate C - 0.0, 0.0 -> 165.35, 165.35
% INFO    : Updated Thermal Rating: on line 21219-21327 : Rate B, Rate C - 0.0, 0.0 -> 251.81, 251.81
% INFO    : Updated Thermal Rating: on line 21220-21269 : Rate B, Rate C - 0.0, 0.0 -> 200.52, 200.52
% INFO    : Updated Thermal Rating: on line 21220-21270 : Rate B, Rate C - 0.0, 0.0 -> 246.9, 246.9
% INFO    : Updated Thermal Rating: on transformer 21222-21221 : Rate B, Rate C - 0.0, 0.0 -> 415.7, 415.7
% INFO    : Updated Thermal Rating: on line 21221-21253 : Rate B, Rate C - 0.0, 0.0 -> 1036.7, 1036.7
% INFO    : Updated Thermal Rating: on line 21222-21286 : Rate B, Rate C - 0.0, 0.0 -> 228.29, 228.29
% INFO    : Updated Thermal Rating: on line 21324-21223 : Rate B, Rate C - 0.0, 0.0 -> 225.5, 225.5
% INFO    : Updated Thermal Rating: on line 21224-21754 : Rate B, Rate C - 0.0, 0.0 -> 227.42, 227.42
% INFO    : Updated Thermal Rating: on line 21247-21227 : Rate B, Rate C - 0.0, 0.0 -> 182.45, 182.45
% INFO    : Updated Thermal Rating: on line 21361-21231 : Rate B, Rate C - 0.0, 0.0 -> 225.37, 225.37
% INFO    : Updated Thermal Rating: on line 21231-21729 : Rate B, Rate C - 0.0, 0.0 -> 249.46, 249.46
% INFO    : Updated Thermal Rating: on transformer 21233-21232 : Rate B, Rate C - 0.0, 0.0 -> 478.66, 478.66
% INFO    : Updated Thermal Rating: on line 21638-21232 : Rate B, Rate C - 0.0, 0.0 -> 1246.8, 1246.8
% INFO    : Updated Thermal Rating: on line 21264-21233 : Rate B, Rate C - 0.0, 0.0 -> 188.31, 188.31
% INFO    : Updated Thermal Rating: on line 21235-21237 : Rate B, Rate C - 0.0, 0.0 -> 206.37, 206.37
% INFO    : Updated Thermal Rating: on line 21235-21254 : Rate B, Rate C - 0.0, 0.0 -> 227.32, 227.32
% INFO    : Updated Thermal Rating: on line 21755-21235 : Rate B, Rate C - 0.0, 0.0 -> 226.15, 226.15
% INFO    : Updated Thermal Rating: on line 21238-21242 : Rate B, Rate C - 0.0, 0.0 -> 254.32, 254.32
% INFO    : Updated Thermal Rating: on line 21665-21238 : Rate B, Rate C - 0.0, 0.0 -> 290.0, 290.0
% INFO    : Updated Thermal Rating: on line 21239-21270 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 21242-21715 : Rate B, Rate C - 0.0, 0.0 -> 285.0, 285.0
% INFO    : Updated Thermal Rating: on line 21244-21297 : Rate B, Rate C - 0.0, 0.0 -> 234.75, 234.75
% INFO    : Updated Thermal Rating: on line 21244-21327 : Rate B, Rate C - 0.0, 0.0 -> 249.36, 249.36
% INFO    : Updated Thermal Rating: on line 21246-21307 : Rate B, Rate C - 0.0, 0.0 -> 178.68, 178.68
% INFO    : Updated Thermal Rating: on line 21336-21246 : Rate B, Rate C - 0.0, 0.0 -> 201.07, 201.07
% INFO    : Updated Thermal Rating: on line 21251-21271 : Rate B, Rate C - 0.0, 0.0 -> 249.1, 249.1
% INFO    : Updated Thermal Rating: on line 21251-21308 : Rate B, Rate C - 0.0, 0.0 -> 254.05, 254.05
% INFO    : Updated Thermal Rating: on line 21251-21333 : Rate B, Rate C - 0.0, 0.0 -> 247.69, 247.69
% INFO    : Updated Thermal Rating: on line 21252-21284 : Rate B, Rate C - 0.0, 0.0 -> 222.83, 222.83
% INFO    : Updated Thermal Rating: on line 21252-21482 : Rate B, Rate C - 0.0, 0.0 -> 227.94, 227.94
% INFO    : Updated Thermal Rating: on transformer 21254-21253 : Rate B, Rate C - 0.0, 0.0 -> 434.44, 434.44
% INFO    : Updated Thermal Rating: on line 21388-21253 : Rate B, Rate C - 0.0, 0.0 -> 1113.04, 1113.04
% INFO    : Updated Thermal Rating: on line 21286-21254 : Rate B, Rate C - 0.0, 0.0 -> 199.72, 199.72
% INFO    : Updated Thermal Rating: on line 21341-21255 : Rate B, Rate C - 0.0, 0.0 -> 152.84, 152.84
% INFO    : Updated Thermal Rating: on line 21729-21255 : Rate B, Rate C - 0.0, 0.0 -> 255.86, 255.86
% INFO    : Updated Thermal Rating: on line 21294-21257 : Rate B, Rate C - 0.0, 0.0 -> 233.24, 233.24
% INFO    : Updated Thermal Rating: on line 21257-21304 : Rate B, Rate C - 0.0, 0.0 -> 250.51, 250.51
% INFO    : Updated Thermal Rating: on line 21290-21259 : Rate B, Rate C - 0.0, 0.0 -> 199.64, 199.64
% INFO    : Updated Thermal Rating: on line 21327-21260 : Rate B, Rate C - 0.0, 0.0 -> 230.04, 230.04
% INFO    : Updated Thermal Rating: on line 21260-21420 : Rate B, Rate C - 0.0, 0.0 -> 207.01, 207.01
% INFO    : Updated Thermal Rating: on transformer 21262-21261 : Rate B, Rate C - 0.0, 0.0 -> 543.22, 543.22
% INFO    : Updated Thermal Rating: on line 21261-21326 : Rate B, Rate C - 0.0, 0.0 -> 1131.96, 1131.96
% INFO    : Updated Thermal Rating: on line 21728-21261 : Rate B, Rate C - 0.0, 0.0 -> 1155.98, 1155.98
% INFO    : Updated Thermal Rating: on line 21262-21270 : Rate B, Rate C - 0.0, 0.0 -> 277.72, 277.72
% INFO    : Updated Thermal Rating: on line 21315-21263 : Rate B, Rate C - 0.0, 0.0 -> 218.25, 218.25
% INFO    : Updated Thermal Rating: on line 21263-21321 : Rate B, Rate C - 0.0, 0.0 -> 169.65, 169.65
% INFO    : Updated Thermal Rating: on line 21273-21265 : Rate B, Rate C - 0.0, 0.0 -> 201.39, 201.39
% INFO    : Updated Thermal Rating: on line 21265-21322 : Rate B, Rate C - 0.0, 0.0 -> 192.83, 192.83
% INFO    : Updated Thermal Rating: on line 21271-21336 : Rate B, Rate C - 0.0, 0.0 -> 226.72, 226.72
% INFO    : Updated Thermal Rating: on line 21274-21299 : Rate B, Rate C - 0.0, 0.0 -> 236.28, 236.28
% INFO    : Updated Thermal Rating: on line 21402-21274 : Rate B, Rate C - 0.0, 0.0 -> 214.32, 214.32
% INFO    : Updated Thermal Rating: on transformer 21276-21275 : Rate B, Rate C - 0.0, 0.0 -> 513.22, 513.22
% INFO    : Updated Thermal Rating: on line 21409-21275 : Rate B, Rate C - 0.0, 0.0 -> 1164.6, 1164.6
% INFO    : Updated Thermal Rating: on line 21275-21474 : Rate B, Rate C - 0.0, 0.0 -> 1234.96, 1234.96
% INFO    : Updated Thermal Rating: on line 21275-21638 : Rate B, Rate C - 0.0, 0.0 -> 1141.53, 1141.53
% INFO    : Updated Thermal Rating: on line 21276-21292 : Rate B, Rate C - 0.0, 0.0 -> 224.22, 224.22
% INFO    : Updated Thermal Rating: on line 21276-21315 : Rate B, Rate C - 0.0, 0.0 -> 238.5, 238.5
% INFO    : Updated Thermal Rating: on line 21316-21276 : Rate B, Rate C - 0.0, 0.0 -> 239.51, 239.51
% INFO    : Updated Thermal Rating: on line 21695-21277 : Rate B, Rate C - 0.0, 0.0 -> 215.33, 215.33
% INFO    : Updated Thermal Rating: on line 21279-21290 : Rate B, Rate C - 0.0, 0.0 -> 235.69, 235.69
% INFO    : Updated Thermal Rating: on line 21279-21331 : Rate B, Rate C - 0.0, 0.0 -> 251.8, 251.8
% INFO    : Updated Thermal Rating: on line 21279-21370 : Rate B, Rate C - 0.0, 0.0 -> 188.04, 188.04
% INFO    : Updated Thermal Rating: on line 21282-21695 : Rate B, Rate C - 0.0, 0.0 -> 200.67, 200.67
% INFO    : Updated Thermal Rating: on line 21723-21282 : Rate B, Rate C - 0.0, 0.0 -> 174.19, 174.19
% INFO    : Updated Thermal Rating: on line 21349-21283 : Rate B, Rate C - 0.0, 0.0 -> 212.5, 212.5
% INFO    : Updated Thermal Rating: on line 21283-21717 : Rate B, Rate C - 0.0, 0.0 -> 223.81, 223.81
% INFO    : Updated Thermal Rating: on line 21284-21386 : Rate B, Rate C - 0.0, 0.0 -> 241.58, 241.58
% INFO    : Updated Thermal Rating: on line 21296-21287 : Rate B, Rate C - 0.0, 0.0 -> 231.59, 231.59
% INFO    : Updated Thermal Rating: on line 21287-21307 : Rate B, Rate C - 0.0, 0.0 -> 212.86, 212.86
% INFO    : Updated Thermal Rating: on line 21288-21293 : Rate B, Rate C - 0.0, 0.0 -> 224.25, 224.25
% INFO    : Updated Thermal Rating: on line 21288-21359 : Rate B, Rate C - 0.0, 0.0 -> 202.71, 202.71
% INFO    : Updated Thermal Rating: on line 21332-21292 : Rate B, Rate C - 0.0, 0.0 -> 222.5, 222.5
% INFO    : Updated Thermal Rating: on line 21292-21357 : Rate B, Rate C - 0.0, 0.0 -> 231.17, 231.17
% INFO    : Updated Thermal Rating: on line 21317-21293 : Rate B, Rate C - 0.0, 0.0 -> 227.67, 227.67
% INFO    : Updated Thermal Rating: on line 21293-21729 : Rate B, Rate C - 0.0, 0.0 -> 269.69, 269.69
% INFO    : Updated Thermal Rating: on line 21296-21297 : Rate B, Rate C - 0.0, 0.0 -> 204.1, 204.1
% INFO    : Updated Thermal Rating: on line 21296-21383 : Rate B, Rate C - 0.0, 0.0 -> 239.62, 239.62
% INFO    : Updated Thermal Rating: on transformer 21298-21301 : Rate B, Rate C - 0.0, 0.0 -> 572.54, 572.54
% INFO    : Updated Thermal Rating: on line 21298-21398 : Rate B, Rate C - 0.0, 0.0 -> 1108.5, 1108.5
% INFO    : Updated Thermal Rating: on line 21298-21685 : Rate B, Rate C - 0.0, 0.0 -> 1157.43, 1157.43
% INFO    : Updated Thermal Rating: on transformer 21299-21301 : Rate B, Rate C - 0.0, 0.0 -> 522.54, 522.54
% INFO    : Updated Thermal Rating: on line 21302-21299 : Rate B, Rate C - 0.0, 0.0 -> 242.86, 242.86
% INFO    : Updated Thermal Rating: on line 21299-21337 : Rate B, Rate C - 0.0, 0.0 -> 238.07, 238.07
% INFO    : Updated Thermal Rating: on transformer 21300-21301 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 21302-21454 : Rate B, Rate C - 0.0, 0.0 -> 214.67, 214.67
% INFO    : Updated Thermal Rating: on line 21334-21304 : Rate B, Rate C - 0.0, 0.0 -> 235.01, 235.01
% INFO    : Updated Thermal Rating: on line 21633-21304 : Rate B, Rate C - 0.0, 0.0 -> 205.4, 205.4
% INFO    : Updated Thermal Rating: on line 21306-21359 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 21429-21306 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 21308-21331 : Rate B, Rate C - 0.0, 0.0 -> 262.36, 262.36
% INFO    : Updated Thermal Rating: on line 21334-21310 : Rate B, Rate C - 0.0, 0.0 -> 214.94, 214.94
% INFO    : Updated Thermal Rating: on line 21438-21310 : Rate B, Rate C - 0.0, 0.0 -> 174.57, 174.57
% INFO    : Updated Thermal Rating: on line 21340-21313 : Rate B, Rate C - 0.0, 0.0 -> 260.03, 260.03
% INFO    : Updated Thermal Rating: on line 21313-21359 : Rate B, Rate C - 0.0, 0.0 -> 195.58, 195.58
% INFO    : Updated Thermal Rating: on line 21378-21314 : Rate B, Rate C - 0.0, 0.0 -> 218.97, 218.97
% INFO    : Updated Thermal Rating: on line 21314-21410 : Rate B, Rate C - 0.0, 0.0 -> 244.21, 244.21
% INFO    : Updated Thermal Rating: on line 21316-21322 : Rate B, Rate C - 0.0, 0.0 -> 218.04, 218.04
% INFO    : Updated Thermal Rating: on line 21318-21394 : Rate B, Rate C - 0.0, 0.0 -> 201.78, 201.78
% INFO    : Updated Thermal Rating: on line 21318-21471 : Rate B, Rate C - 0.0, 0.0 -> 214.44, 214.44
% INFO    : Updated Thermal Rating: on line 21321-21335 : Rate B, Rate C - 0.0, 0.0 -> 227.33, 227.33
% INFO    : Updated Thermal Rating: on line 21371-21325 : Rate B, Rate C - 0.0, 0.0 -> 208.34, 208.34
% INFO    : Updated Thermal Rating: on line 21325-21392 : Rate B, Rate C - 0.0, 0.0 -> 239.52, 239.52
% INFO    : Updated Thermal Rating: on transformer 21326-21329 : Rate B, Rate C - 0.0, 0.0 -> 654.04, 654.04
% INFO    : Updated Thermal Rating: on line 21326-21382 : Rate B, Rate C - 0.0, 0.0 -> 1211.58, 1211.58
% INFO    : Updated Thermal Rating: on line 21326-21607 : Rate B, Rate C - 0.0, 0.0 -> 1312.38, 1312.38
% INFO    : Updated Thermal Rating: on transformer 21327-21329 : Rate B, Rate C - 0.0, 0.0 -> 554.04, 554.04
% INFO    : Updated Thermal Rating: on transformer 21328-21329 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 21499-21330 : Rate B, Rate C - 0.0, 0.0 -> 228.74, 228.74
% INFO    : Updated Thermal Rating: on line 21330-21643 : Rate B, Rate C - 0.0, 0.0 -> 247.84, 247.84
% INFO    : Updated Thermal Rating: on line 21331-21692 : Rate B, Rate C - 0.0, 0.0 -> 250.14, 250.14
% INFO    : Updated Thermal Rating: on line 21331-21699 : Rate B, Rate C - 0.0, 0.0 -> 280.55, 280.55
% INFO    : Updated Thermal Rating: on line 21332-21633 : Rate B, Rate C - 0.0, 0.0 -> 237.25, 237.25
% INFO    : Updated Thermal Rating: on line 21333-21383 : Rate B, Rate C - 0.0, 0.0 -> 267.38, 267.38
% INFO    : Updated Thermal Rating: on line 21335-21406 : Rate B, Rate C - 0.0, 0.0 -> 242.63, 242.63
% INFO    : Updated Thermal Rating: on line 21337-21404 : Rate B, Rate C - 0.0, 0.0 -> 230.88, 230.88
% INFO    : Updated Thermal Rating: on transformer 21340-21339 : Rate B, Rate C - 0.0, 0.0 -> 493.01, 493.01
% INFO    : Updated Thermal Rating: on line 21405-21339 : Rate B, Rate C - 0.0, 0.0 -> 1285.25, 1285.25
% INFO    : Updated Thermal Rating: on line 21339-21607 : Rate B, Rate C - 0.0, 0.0 -> 1322.07, 1322.07
% INFO    : Updated Thermal Rating: on line 21728-21339 : Rate B, Rate C - 0.0, 0.0 -> 1167.48, 1167.48
% INFO    : Updated Thermal Rating: on line 21361-21340 : Rate B, Rate C - 0.0, 0.0 -> 222.79, 222.79
% INFO    : Updated Thermal Rating: on line 21341-21729 : Rate B, Rate C - 0.0, 0.0 -> 236.33, 236.33
% INFO    : Updated Thermal Rating: on line 21343-21363 : Rate B, Rate C - 0.0, 0.0 -> 207.57, 207.57
% INFO    : Updated Thermal Rating: on line 21410-21343 : Rate B, Rate C - 0.0, 0.0 -> 216.33, 216.33
% INFO    : Updated Thermal Rating: on line 21434-21343 : Rate B, Rate C - 0.0, 0.0 -> 188.15, 188.15
% INFO    : Updated Thermal Rating: on line 21343-21484 : Rate B, Rate C - 0.0, 0.0 -> 211.41, 211.41
% INFO    : Updated Thermal Rating: on line 21346-21357 : Rate B, Rate C - 0.0, 0.0 -> 196.36, 196.36
% INFO    : Updated Thermal Rating: on line 21346-21378 : Rate B, Rate C - 0.0, 0.0 -> 185.52, 185.52
% INFO    : Updated Thermal Rating: on line 21349-21370 : Rate B, Rate C - 0.0, 0.0 -> 237.16, 237.16
% INFO    : Updated Thermal Rating: on line 21351-21353 : Rate B, Rate C - 0.0, 0.0 -> 221.57, 221.57
% INFO    : Updated Thermal Rating: on line 21383-21351 : Rate B, Rate C - 0.0, 0.0 -> 263.57, 263.57
% INFO    : Updated Thermal Rating: on line 21354-21729 : Rate B, Rate C - 0.0, 0.0 -> 260.17, 260.17
% INFO    : Updated Thermal Rating: on line 21355-21424 : Rate B, Rate C - 0.0, 0.0 -> 171.99, 171.99
% INFO    : Updated Thermal Rating: on line 21355-21628 : Rate B, Rate C - 0.0, 0.0 -> 224.2, 224.2
% INFO    : Updated Thermal Rating: on line 21357-21402 : Rate B, Rate C - 0.0, 0.0 -> 183.13, 183.13
% INFO    : Updated Thermal Rating: on line 21359-21361 : Rate B, Rate C - 0.0, 0.0 -> 226.69, 226.69
% INFO    : Updated Thermal Rating: on line 21359-21417 : Rate B, Rate C - 0.0, 0.0 -> 179.68, 179.68
% INFO    : Updated Thermal Rating: on line 21363-21491 : Rate B, Rate C - 0.0, 0.0 -> 190.78, 190.78
% INFO    : Updated Thermal Rating: on line 21364-21442 : Rate B, Rate C - 0.0, 0.0 -> 209.17, 209.17
% INFO    : Updated Thermal Rating: on line 21364-21466 : Rate B, Rate C - 0.0, 0.0 -> 185.81, 185.81
% INFO    : Updated Thermal Rating: on line 21365-21367 : Rate B, Rate C - 0.0, 0.0 -> 183.71, 183.71
% INFO    : Updated Thermal Rating: on line 21386-21365 : Rate B, Rate C - 0.0, 0.0 -> 202.35, 202.35
% INFO    : Updated Thermal Rating: on line 21674-21367 : Rate B, Rate C - 0.0, 0.0 -> 219.85, 219.85
% INFO    : Updated Thermal Rating: on line 21368-21499 : Rate B, Rate C - 0.0, 0.0 -> 223.01, 223.01
% INFO    : Updated Thermal Rating: on line 21368-21699 : Rate B, Rate C - 0.0, 0.0 -> 239.29, 239.29
% INFO    : Updated Thermal Rating: on line 21370-21643 : Rate B, Rate C - 0.0, 0.0 -> 258.87, 258.87
% INFO    : Updated Thermal Rating: on line 21420-21371 : Rate B, Rate C - 0.0, 0.0 -> 173.88, 173.88
% INFO    : Updated Thermal Rating: on line 21372-21392 : Rate B, Rate C - 0.0, 0.0 -> 225.78, 225.78
% INFO    : Updated Thermal Rating: on line 21372-21470 : Rate B, Rate C - 0.0, 0.0 -> 220.73, 220.73
% INFO    : Updated Thermal Rating: on line 21372-21555 : Rate B, Rate C - 0.0, 0.0 -> 214.36, 214.36
% INFO    : Updated Thermal Rating: on transformer 21374-21373 : Rate B, Rate C - 0.0, 0.0 -> 466.81, 466.81
% INFO    : Updated Thermal Rating: on line 21474-21373 : Rate B, Rate C - 0.0, 0.0 -> 1169.1, 1169.1
% INFO    : Updated Thermal Rating: on line 21374-21379 : Rate B, Rate C - 0.0, 0.0 -> 275.42, 275.42
% INFO    : Updated Thermal Rating: on line 21418-21374 : Rate B, Rate C - 0.0, 0.0 -> 258.63, 258.63
% INFO    : Updated Thermal Rating: on line 21374-21472 : Rate B, Rate C - 0.0, 0.0 -> 242.14, 242.14
% INFO    : Updated Thermal Rating: on line 21374-21520 : Rate B, Rate C - 0.0, 0.0 -> 220.86, 220.86
% INFO    : Updated Thermal Rating: on line 21375-21472 : Rate B, Rate C - 0.0, 0.0 -> 169.32, 169.32
% INFO    : Updated Thermal Rating: on line 21375-21521 : Rate B, Rate C - 0.0, 0.0 -> 237.9, 237.9
% INFO    : Updated Thermal Rating: on line 21430-21378 : Rate B, Rate C - 0.0, 0.0 -> 180.81, 180.81
% INFO    : Updated Thermal Rating: on line 21477-21379 : Rate B, Rate C - 0.0, 0.0 -> 255.41, 255.41
% INFO    : Updated Thermal Rating: on line 21413-21380 : Rate B, Rate C - 0.0, 0.0 -> 218.77, 218.77
% INFO    : Updated Thermal Rating: on line 21498-21380 : Rate B, Rate C - 0.0, 0.0 -> 188.54, 188.54
% INFO    : Updated Thermal Rating: on transformer 21383-21382 : Rate B, Rate C - 0.0, 0.0 -> 449.27, 449.27
% INFO    : Updated Thermal Rating: on line 21382-21474 : Rate B, Rate C - 0.0, 0.0 -> 1200.95, 1200.95
% INFO    : Updated Thermal Rating: on line 21382-21642 : Rate B, Rate C - 0.0, 0.0 -> 1328.23, 1328.23
% INFO    : Updated Thermal Rating: on line 21382-21649 : Rate B, Rate C - 0.0, 0.0 -> 1457.69, 1457.69
% INFO    : Updated Thermal Rating: on line 21383-21432 : Rate B, Rate C - 0.0, 0.0 -> 281.13, 281.13
% INFO    : Updated Thermal Rating: on transformer 21386-21385 : Rate B, Rate C - 0.0, 0.0 -> 450.77, 450.77
% INFO    : Updated Thermal Rating: on line 21388-21385 : Rate B, Rate C - 0.0, 0.0 -> 1110.82, 1110.82
% INFO    : Updated Thermal Rating: on line 21462-21386 : Rate B, Rate C - 0.0, 0.0 -> 229.32, 229.32
% INFO    : Updated Thermal Rating: on transformer 21389-21388 : Rate B, Rate C - 0.0, 0.0 -> 448.1, 448.1
% INFO    : Updated Thermal Rating: on line 21657-21388 : Rate B, Rate C - 0.0, 0.0 -> 1155.89, 1155.89
% INFO    : Updated Thermal Rating: on line 21450-21389 : Rate B, Rate C - 0.0, 0.0 -> 240.78, 240.78
% INFO    : Updated Thermal Rating: on line 21389-21465 : Rate B, Rate C - 0.0, 0.0 -> 235.09, 235.09
% INFO    : Updated Thermal Rating: on line 21390-21424 : Rate B, Rate C - 0.0, 0.0 -> 211.9, 211.9
% INFO    : Updated Thermal Rating: on line 21390-21492 : Rate B, Rate C - 0.0, 0.0 -> 220.6, 220.6
% INFO    : Updated Thermal Rating: on line 21628-21390 : Rate B, Rate C - 0.0, 0.0 -> 250.87, 250.87
% INFO    : Updated Thermal Rating: on line 21390-21758 : Rate B, Rate C - 0.0, 0.0 -> 205.5, 205.5
% INFO    : Updated Thermal Rating: on line 21391-21479 : Rate B, Rate C - 0.0, 0.0 -> 238.32, 238.32
% INFO    : Updated Thermal Rating: on line 21391-21628 : Rate B, Rate C - 0.0, 0.0 -> 258.81, 258.81
% INFO    : Updated Thermal Rating: on line 21392-21394 : Rate B, Rate C - 0.0, 0.0 -> 226.1, 226.1
% INFO    : Updated Thermal Rating: on line 21396-21392 : Rate B, Rate C - 0.0, 0.0 -> 254.13, 254.13
% INFO    : Updated Thermal Rating: on line 21396-21481 : Rate B, Rate C - 0.0, 0.0 -> 236.71, 236.71
% INFO    : Updated Thermal Rating: on line 21396-21573 : Rate B, Rate C - 0.0, 0.0 -> 229.78, 229.78
% INFO    : Updated Thermal Rating: on line 21399-21397 : Rate B, Rate C - 0.0, 0.0 -> 236.1, 236.1
% INFO    : Updated Thermal Rating: on line 23000-21397 : Rate B, Rate C - 0.0, 0.0 -> 217.76, 217.76
% INFO    : Updated Thermal Rating: on transformer 21399-21398 : Rate B, Rate C - 0.0, 0.0 -> 475.45, 475.45
% INFO    : Updated Thermal Rating: on line 21398-23016 : Rate B, Rate C - 0.0, 0.0 -> 1045.39, 1045.39
% INFO    : Updated Thermal Rating: on line 23375-21398 : Rate B, Rate C - 0.0, 0.0 -> 1252.16, 1252.16
% INFO    : Updated Thermal Rating: on line 21399-21437 : Rate B, Rate C - 0.0, 0.0 -> 270.6, 270.6
% INFO    : Updated Thermal Rating: on line 21404-21434 : Rate B, Rate C - 0.0, 0.0 -> 207.46, 207.46
% INFO    : Updated Thermal Rating: on transformer 21405-21408 : Rate B, Rate C - 0.0, 0.0 -> 519.59, 519.59
% INFO    : Updated Thermal Rating: on line 21629-21405 : Rate B, Rate C - 0.0, 0.0 -> 1124.55, 1124.55
% INFO    : Updated Thermal Rating: on transformer 21406-21408 : Rate B, Rate C - 0.0, 0.0 -> 494.59, 494.59
% INFO    : Updated Thermal Rating: on line 21429-21406 : Rate B, Rate C - 0.0, 0.0 -> 253.57, 253.57
% INFO    : Updated Thermal Rating: on line 21438-21406 : Rate B, Rate C - 0.0, 0.0 -> 207.18, 207.18
% INFO    : Updated Thermal Rating: on transformer 21407-21408 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 21409-21412 : Rate B, Rate C - 0.0, 0.0 -> 481.36, 481.36
% INFO    : Updated Thermal Rating: on line 21458-21409 : Rate B, Rate C - 0.0, 0.0 -> 1160.39, 1160.39
% INFO    : Updated Thermal Rating: on line 21409-21629 : Rate B, Rate C - 0.0, 0.0 -> 1158.16, 1158.16
% INFO    : Updated Thermal Rating: on transformer 21410-21412 : Rate B, Rate C - 0.0, 0.0 -> 456.36, 456.36
% INFO    : Updated Thermal Rating: on transformer 21411-21412 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 21413-21454 : Rate B, Rate C - 0.0, 0.0 -> 228.8, 228.8
% INFO    : Updated Thermal Rating: on line 21415-21436 : Rate B, Rate C - 0.0, 0.0 -> 179.77, 179.77
% INFO    : Updated Thermal Rating: on line 21415-21497 : Rate B, Rate C - 0.0, 0.0 -> 208.86, 208.86
% INFO    : Updated Thermal Rating: on line 21417-21729 : Rate B, Rate C - 0.0, 0.0 -> 237.51, 237.51
% INFO    : Updated Thermal Rating: on line 21418-21504 : Rate B, Rate C - 0.0, 0.0 -> 220.71, 220.71
% INFO    : Updated Thermal Rating: on line 21419-21475 : Rate B, Rate C - 0.0, 0.0 -> 291.81, 291.81
% INFO    : Updated Thermal Rating: on line 21521-21419 : Rate B, Rate C - 0.0, 0.0 -> 274.61, 274.61
% INFO    : Updated Thermal Rating: on line 21424-21468 : Rate B, Rate C - 0.0, 0.0 -> 187.88, 187.88
% INFO    : Updated Thermal Rating: on line 21428-21466 : Rate B, Rate C - 0.0, 0.0 -> 217.82, 217.82
% INFO    : Updated Thermal Rating: on line 21428-21734 : Rate B, Rate C - 0.0, 0.0 -> 254.92, 254.92
% INFO    : Updated Thermal Rating: on line 21429-21439 : Rate B, Rate C - 0.0, 0.0 -> 185.53, 185.53
% INFO    : Updated Thermal Rating: on line 21479-21430 : Rate B, Rate C - 0.0, 0.0 -> 214.25, 214.25
% INFO    : Updated Thermal Rating: on line 21431-21444 : Rate B, Rate C - 0.0, 0.0 -> 203.0, 203.0
% INFO    : Updated Thermal Rating: on line 21431-21494 : Rate B, Rate C - 0.0, 0.0 -> 176.89, 176.89
% INFO    : Updated Thermal Rating: on line 21432-21433 : Rate B, Rate C - 0.0, 0.0 -> 229.53, 229.53
% INFO    : Updated Thermal Rating: on line 21432-21608 : Rate B, Rate C - 0.0, 0.0 -> 270.97, 270.97
% INFO    : Updated Thermal Rating: on line 21480-21433 : Rate B, Rate C - 0.0, 0.0 -> 254.91, 254.91
% INFO    : Updated Thermal Rating: on line 21451-21436 : Rate B, Rate C - 0.0, 0.0 -> 230.3, 230.3
% INFO    : Updated Thermal Rating: on line 21457-21436 : Rate B, Rate C - 0.0, 0.0 -> 206.15, 206.15
% INFO    : Updated Thermal Rating: on line 21437-21498 : Rate B, Rate C - 0.0, 0.0 -> 208.29, 208.29
% INFO    : Updated Thermal Rating: on line 21437-23008 : Rate B, Rate C - 0.0, 0.0 -> 222.92, 222.92
% INFO    : Updated Thermal Rating: on line 21437-23010 : Rate B, Rate C - 0.0, 0.0 -> 204.07, 204.07
% INFO    : Updated Thermal Rating: on line 21437-23012 : Rate B, Rate C - 0.0, 0.0 -> 192.25, 192.25
% INFO    : Updated Thermal Rating: on line 21439-21734 : Rate B, Rate C - 0.0, 0.0 -> 202.45, 202.45
% INFO    : Updated Thermal Rating: on line 21529-21442 : Rate B, Rate C - 0.0, 0.0 -> 218.68, 218.68
% INFO    : Updated Thermal Rating: on line 21734-21442 : Rate B, Rate C - 0.0, 0.0 -> 256.4, 256.4
% INFO    : Updated Thermal Rating: on line 21519-21444 : Rate B, Rate C - 0.0, 0.0 -> 150.63, 150.63
% INFO    : Updated Thermal Rating: on line 21444-21686 : Rate B, Rate C - 0.0, 0.0 -> 228.8, 228.8
% INFO    : Updated Thermal Rating: on line 21517-21446 : Rate B, Rate C - 0.0, 0.0 -> 188.37, 188.37
% INFO    : Updated Thermal Rating: on line 23009-21446 : Rate B, Rate C - 0.0, 0.0 -> 178.03, 178.03
% INFO    : Updated Thermal Rating: on line 21656-21448 : Rate B, Rate C - 0.0, 0.0 -> 251.94, 251.94
% INFO    : Updated Thermal Rating: on line 21448-21759 : Rate B, Rate C - 0.0, 0.0 -> 238.46, 238.46
% INFO    : Updated Thermal Rating: on line 21450-21656 : Rate B, Rate C - 0.0, 0.0 -> 256.94, 256.94
% INFO    : Updated Thermal Rating: on line 21451-21459 : Rate B, Rate C - 0.0, 0.0 -> 244.32, 244.32
% INFO    : Updated Thermal Rating: on line 21454-21459 : Rate B, Rate C - 0.0, 0.0 -> 222.54, 222.54
% INFO    : Updated Thermal Rating: on line 21457-21494 : Rate B, Rate C - 0.0, 0.0 -> 214.37, 214.37
% INFO    : Updated Thermal Rating: on line 21457-21532 : Rate B, Rate C - 0.0, 0.0 -> 227.02, 227.02
% INFO    : Updated Thermal Rating: on transformer 21458-21461 : Rate B, Rate C - 0.0, 0.0 -> 580.18, 580.18
% INFO    : Updated Thermal Rating: on transformer 21459-21461 : Rate B, Rate C - 0.0, 0.0 -> 455.18, 455.18
% INFO    : Updated Thermal Rating: on transformer 21460-21461 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 21465-21462 : Rate B, Rate C - 0.0, 0.0 -> 171.51, 171.51
% INFO    : Updated Thermal Rating: on line 21758-21468 : Rate B, Rate C - 0.0, 0.0 -> 219.26, 219.26
% INFO    : Updated Thermal Rating: on line 21471-21469 : Rate B, Rate C - 0.0, 0.0 -> 223.49, 223.49
% INFO    : Updated Thermal Rating: on line 21475-21469 : Rate B, Rate C - 0.0, 0.0 -> 245.97, 245.97
% INFO    : Updated Thermal Rating: on line 21499-21470 : Rate B, Rate C - 0.0, 0.0 -> 241.48, 241.48
% INFO    : Updated Thermal Rating: on line 21520-21471 : Rate B, Rate C - 0.0, 0.0 -> 243.4, 243.4
% INFO    : Updated Thermal Rating: on line 21471-21743 : Rate B, Rate C - 0.0, 0.0 -> 259.75, 259.75
% INFO    : Updated Thermal Rating: on line 21472-21475 : Rate B, Rate C - 0.0, 0.0 -> 265.17, 265.17
% INFO    : Updated Thermal Rating: on transformer 21475-21474 : Rate B, Rate C - 0.0, 0.0 -> 577.25, 577.25
% INFO    : Updated Thermal Rating: on transformer 21475-21474 : Rate B, Rate C - 0.0, 0.0 -> 577.25, 577.25
% INFO    : Updated Thermal Rating: on line 21474-21626 : Rate B, Rate C - 0.0, 0.0 -> 1314.79, 1314.79
% INFO    : Updated Thermal Rating: on line 21742-21474 : Rate B, Rate C - 0.0, 0.0 -> 1222.23, 1222.23
% INFO    : Updated Thermal Rating: on line 21476-21501 : Rate B, Rate C - 0.0, 0.0 -> 187.05, 187.05
% INFO    : Updated Thermal Rating: on line 21476-21504 : Rate B, Rate C - 0.0, 0.0 -> 212.84, 212.84
% INFO    : Updated Thermal Rating: on line 21477-21504 : Rate B, Rate C - 0.0, 0.0 -> 228.48, 228.48
% INFO    : Updated Thermal Rating: on line 21650-21480 : Rate B, Rate C - 0.0, 0.0 -> 279.36, 279.36
% INFO    : Updated Thermal Rating: on line 21482-21716 : Rate B, Rate C - 0.0, 0.0 -> 225.68, 225.68
% INFO    : Updated Thermal Rating: on line 21721-21484 : Rate B, Rate C - 0.0, 0.0 -> 230.55, 230.55
% INFO    : Updated Thermal Rating: on transformer 21485-21488 : Rate B, Rate C - 0.0, 0.0 -> 103.89, 103.89
% INFO    : Updated Thermal Rating: on line 21485-21516 : Rate B, Rate C - 0.0, 0.0 -> 229.33, 229.33
% INFO    : Updated Thermal Rating: on line 21485-21529 : Rate B, Rate C - 0.0, 0.0 -> 260.75, 260.75
% INFO    : Updated Thermal Rating: on line 21485-21551 : Rate B, Rate C - 0.0, 0.0 -> 208.34, 208.34
% INFO    : Updated Thermal Rating: on transformer 21486-21488 : Rate B, Rate C - 0.0, 0.0 -> 51.94, 51.94
% INFO    : Updated Thermal Rating: on transformer 21487-21488 : Rate B, Rate C - 0.0, 0.0 -> 51.94, 51.94
% INFO    : Updated Thermal Rating: on line 21497-21491 : Rate B, Rate C - 0.0, 0.0 -> 234.85, 234.85
% INFO    : Updated Thermal Rating: on line 21492-21546 : Rate B, Rate C - 0.0, 0.0 -> 226.11, 226.11
% INFO    : Updated Thermal Rating: on line 21492-21721 : Rate B, Rate C - 0.0, 0.0 -> 232.3, 232.3
% INFO    : Updated Thermal Rating: on line 21495-21493 : Rate B, Rate C - 0.0, 0.0 -> 211.02, 211.02
% INFO    : Updated Thermal Rating: on line 21493-21497 : Rate B, Rate C - 0.0, 0.0 -> 248.47, 248.47
% INFO    : Updated Thermal Rating: on line 21533-21495 : Rate B, Rate C - 0.0, 0.0 -> 199.63, 199.63
% INFO    : Updated Thermal Rating: on transformer 21497-21496 : Rate B, Rate C - 0.0, 0.0 -> 571.48, 571.48
% INFO    : Updated Thermal Rating: on line 21496-21527 : Rate B, Rate C - 0.0, 0.0 -> 1261.31, 1261.31
% INFO    : Updated Thermal Rating: on line 21496-21685 : Rate B, Rate C - 0.0, 0.0 -> 1073.89, 1073.89
% INFO    : Updated Thermal Rating: on line 21497-21533 : Rate B, Rate C - 0.0, 0.0 -> 264.14, 264.14
% INFO    : Updated Thermal Rating: on line 21559-21501 : Rate B, Rate C - 0.0, 0.0 -> 243.58, 243.58
% INFO    : Updated Thermal Rating: on line 21562-21501 : Rate B, Rate C - 0.0, 0.0 -> 185.85, 185.85
% INFO    : Updated Thermal Rating: on transformer 21506-21509 : Rate B, Rate C - 0.0, 0.0 -> 103.16, 103.16
% INFO    : Updated Thermal Rating: on line 21513-21506 : Rate B, Rate C - 0.0, 0.0 -> 167.79, 167.79
% INFO    : Updated Thermal Rating: on line 21561-21506 : Rate B, Rate C - 0.0, 0.0 -> 223.76, 223.76
% INFO    : Updated Thermal Rating: on line 21562-21506 : Rate B, Rate C - 0.0, 0.0 -> 193.17, 193.17
% INFO    : Updated Thermal Rating: on line 21506-21582 : Rate B, Rate C - 0.0, 0.0 -> 245.53, 245.53
% INFO    : Updated Thermal Rating: on transformer 21507-21509 : Rate B, Rate C - 0.0, 0.0 -> 51.58, 51.58
% INFO    : Updated Thermal Rating: on transformer 21508-21509 : Rate B, Rate C - 0.0, 0.0 -> 51.58, 51.58
% INFO    : Updated Thermal Rating: on line 21559-21510 : Rate B, Rate C - 0.0, 0.0 -> 265.05, 265.05
% INFO    : Updated Thermal Rating: on line 21510-21616 : Rate B, Rate C - 0.0, 0.0 -> 279.03, 279.03
% INFO    : Updated Thermal Rating: on line 21550-21513 : Rate B, Rate C - 0.0, 0.0 -> 223.03, 223.03
% INFO    : Updated Thermal Rating: on line 21516-21562 : Rate B, Rate C - 0.0, 0.0 -> 183.49, 183.49
% INFO    : Updated Thermal Rating: on line 21519-21517 : Rate B, Rate C - 0.0, 0.0 -> 216.58, 216.58
% INFO    : Updated Thermal Rating: on line 21517-21532 : Rate B, Rate C - 0.0, 0.0 -> 250.93, 250.93
% INFO    : Updated Thermal Rating: on line 21525-21523 : Rate B, Rate C - 0.0, 0.0 -> 204.25, 204.25
% INFO    : Updated Thermal Rating: on line 21523-21533 : Rate B, Rate C - 0.0, 0.0 -> 185.01, 185.01
% INFO    : Updated Thermal Rating: on line 21525-21630 : Rate B, Rate C - 0.0, 0.0 -> 186.48, 186.48
% INFO    : Updated Thermal Rating: on line 21525-21686 : Rate B, Rate C - 0.0, 0.0 -> 225.46, 225.46
% INFO    : Updated Thermal Rating: on transformer 21528-21527 : Rate B, Rate C - 0.0, 0.0 -> 508.15, 508.15
% INFO    : Updated Thermal Rating: on line 21527-21700 : Rate B, Rate C - 0.0, 0.0 -> 1224.22, 1224.22
% INFO    : Updated Thermal Rating: on line 21527-23432 : Rate B, Rate C - 0.0, 0.0 -> 1243.7, 1243.7
% INFO    : Updated Thermal Rating: on line 21528-21542 : Rate B, Rate C - 0.0, 0.0 -> 236.96, 236.96
% INFO    : Updated Thermal Rating: on line 21528-21544 : Rate B, Rate C - 0.0, 0.0 -> 251.51, 251.51
% INFO    : Updated Thermal Rating: on line 21528-21547 : Rate B, Rate C - 0.0, 0.0 -> 212.93, 212.93
% INFO    : Updated Thermal Rating: on line 21529-21734 : Rate B, Rate C - 0.0, 0.0 -> 268.5, 268.5
% INFO    : Updated Thermal Rating: on line 21686-21530 : Rate B, Rate C - 0.0, 0.0 -> 233.72, 233.72
% INFO    : Updated Thermal Rating: on line 23009-21530 : Rate B, Rate C - 0.0, 0.0 -> 175.45, 175.45
% INFO    : Updated Thermal Rating: on transformer 21532-21531 : Rate B, Rate C - 0.0, 0.0 -> 480.33, 480.33
% INFO    : Updated Thermal Rating: on line 21685-21531 : Rate B, Rate C - 0.0, 0.0 -> 1183.67, 1183.67
% INFO    : Updated Thermal Rating: on line 21533-21563 : Rate B, Rate C - 0.0, 0.0 -> 214.27, 214.27
% INFO    : Updated Thermal Rating: on line 21535-21579 : Rate B, Rate C - 0.0, 0.0 -> 187.45, 187.45
% INFO    : Updated Thermal Rating: on line 21630-21535 : Rate B, Rate C - 0.0, 0.0 -> 241.64, 241.64
% INFO    : Updated Thermal Rating: on line 21555-21538 : Rate B, Rate C - 0.0, 0.0 -> 239.78, 239.78
% INFO    : Updated Thermal Rating: on line 21538-21571 : Rate B, Rate C - 0.0, 0.0 -> 258.45, 258.45
% INFO    : Updated Thermal Rating: on line 21675-21538 : Rate B, Rate C - 0.0, 0.0 -> 204.21, 204.21
% INFO    : Updated Thermal Rating: on line 21675-21539 : Rate B, Rate C - 0.0, 0.0 -> 203.26, 203.26
% INFO    : Updated Thermal Rating: on line 21542-21540 : Rate B, Rate C - 0.0, 0.0 -> 209.85, 209.85
% INFO    : Updated Thermal Rating: on line 21551-21540 : Rate B, Rate C - 0.0, 0.0 -> 171.94, 171.94
% INFO    : Updated Thermal Rating: on line 21544-21546 : Rate B, Rate C - 0.0, 0.0 -> 214.18, 214.18
% INFO    : Updated Thermal Rating: on line 21563-21546 : Rate B, Rate C - 0.0, 0.0 -> 207.39, 207.39
% INFO    : Updated Thermal Rating: on line 21551-21547 : Rate B, Rate C - 0.0, 0.0 -> 191.12, 191.12
% INFO    : Updated Thermal Rating: on line 21550-23076 : Rate B, Rate C - 0.0, 0.0 -> 250.1, 250.1
% INFO    : Updated Thermal Rating: on line 21564-21557 : Rate B, Rate C - 0.0, 0.0 -> 242.14, 242.14
% INFO    : Updated Thermal Rating: on line 21622-21557 : Rate B, Rate C - 0.0, 0.0 -> 262.71, 262.71
% INFO    : Updated Thermal Rating: on line 21558-21569 : Rate B, Rate C - 0.0, 0.0 -> 209.54, 209.54
% INFO    : Updated Thermal Rating: on line 21560-21574 : Rate B, Rate C - 0.0, 0.0 -> 193.63, 193.63
% INFO    : Updated Thermal Rating: on line 21743-21560 : Rate B, Rate C - 0.0, 0.0 -> 226.32, 226.32
% INFO    : Updated Thermal Rating: on line 21568-21561 : Rate B, Rate C - 0.0, 0.0 -> 182.27, 182.27
% INFO    : Updated Thermal Rating: on line 21568-21563 : Rate B, Rate C - 0.0, 0.0 -> 207.06, 207.06
% INFO    : Updated Thermal Rating: on line 21564-23022 : Rate B, Rate C - 0.0, 0.0 -> 220.8, 220.8
% INFO    : Updated Thermal Rating: on line 21573-21565 : Rate B, Rate C - 0.0, 0.0 -> 242.37, 242.37
% INFO    : Updated Thermal Rating: on line 21565-21622 : Rate B, Rate C - 0.0, 0.0 -> 248.63, 248.63
% INFO    : Updated Thermal Rating: on line 21622-21571 : Rate B, Rate C - 0.0, 0.0 -> 282.68, 282.68
% INFO    : Updated Thermal Rating: on line 21580-21573 : Rate B, Rate C - 0.0, 0.0 -> 207.71, 207.71
% INFO    : Updated Thermal Rating: on line 21574-21582 : Rate B, Rate C - 0.0, 0.0 -> 293.79, 293.79
% INFO    : Updated Thermal Rating: on line 21661-21574 : Rate B, Rate C - 0.0, 0.0 -> 297.47, 297.47
% INFO    : Updated Thermal Rating: on line 21576-21640 : Rate B, Rate C - 0.0, 0.0 -> 234.77, 234.77
% INFO    : Updated Thermal Rating: on line 23009-21576 : Rate B, Rate C - 0.0, 0.0 -> 230.94, 230.94
% INFO    : Updated Thermal Rating: on line 21579-21577 : Rate B, Rate C - 0.0, 0.0 -> 208.19, 208.19
% INFO    : Updated Thermal Rating: on line 21577-21582 : Rate B, Rate C - 0.0, 0.0 -> 240.11, 240.11
% INFO    : Updated Thermal Rating: on line 21580-21601 : Rate B, Rate C - 0.0, 0.0 -> 227.06, 227.06
% INFO    : Updated Thermal Rating: on line 21581-21585 : Rate B, Rate C - 0.0, 0.0 -> 228.33, 228.33
% INFO    : Updated Thermal Rating: on line 21581-23061 : Rate B, Rate C - 0.0, 0.0 -> 192.54, 192.54
% INFO    : Updated Thermal Rating: on line 21581-23103 : Rate B, Rate C - 0.0, 0.0 -> 177.11, 177.11
% INFO    : Updated Thermal Rating: on line 21582-23076 : Rate B, Rate C - 0.0, 0.0 -> 214.07, 214.07
% INFO    : Updated Thermal Rating: on line 21583-21745 : Rate B, Rate C - 0.0, 0.0 -> 222.86, 222.86
% INFO    : Updated Thermal Rating: on line 21583-23128 : Rate B, Rate C - 0.0, 0.0 -> 181.0, 181.0
% INFO    : Updated Thermal Rating: on line 21745-21584 : Rate B, Rate C - 0.0, 0.0 -> 254.31, 254.31
% INFO    : Updated Thermal Rating: on line 23036-21584 : Rate B, Rate C - 0.0, 0.0 -> 217.06, 217.06
% INFO    : Updated Thermal Rating: on line 21584-23081 : Rate B, Rate C - 0.0, 0.0 -> 184.32, 184.32
% INFO    : Updated Thermal Rating: on line 21701-21585 : Rate B, Rate C - 0.0, 0.0 -> 243.9, 243.9
% INFO    : Updated Thermal Rating: on transformer 21586-21589 : Rate B, Rate C - 0.0, 0.0 -> 216.59, 216.59
% INFO    : Updated Thermal Rating: on line 21616-21586 : Rate B, Rate C - 0.0, 0.0 -> 231.47, 231.47
% INFO    : Updated Thermal Rating: on line 21586-23021 : Rate B, Rate C - 0.0, 0.0 -> 208.65, 208.65
% INFO    : Updated Thermal Rating: on transformer 21587-21589 : Rate B, Rate C - 0.0, 0.0 -> 108.3, 108.3
% INFO    : Updated Thermal Rating: on transformer 21588-21589 : Rate B, Rate C - 0.0, 0.0 -> 108.3, 108.3
% INFO    : Updated Thermal Rating: on line 21591-21592 : Rate B, Rate C - 0.0, 0.0 -> 146.24, 146.24
% INFO    : Updated Thermal Rating: on line 21591-21601 : Rate B, Rate C - 0.0, 0.0 -> 253.02, 253.02
% INFO    : Updated Thermal Rating: on line 21591-23022 : Rate B, Rate C - 0.0, 0.0 -> 240.68, 240.68
% INFO    : Updated Thermal Rating: on line 21591-23058 : Rate B, Rate C - 0.0, 0.0 -> 180.41, 180.41
% INFO    : Updated Thermal Rating: on line 21591-23074 : Rate B, Rate C - 0.0, 0.0 -> 190.78, 190.78
% INFO    : Updated Thermal Rating: on line 21592-23031 : Rate B, Rate C - 0.0, 0.0 -> 206.41, 206.41
% INFO    : Updated Thermal Rating: on transformer 21594-21593 : Rate B, Rate C - 0.0, 0.0 -> 1892.25, 1892.25
% INFO    : Updated Thermal Rating: on transformer 21593-21596 : Rate B, Rate C - 0.0, 0.0 -> 1484.81, 1484.81
% INFO    : Updated Thermal Rating: on transformer 21593-21597 : Rate B, Rate C - 0.0, 0.0 -> 1483.46, 1483.46
% INFO    : Updated Thermal Rating: on transformer 21593-21598 : Rate B, Rate C - 0.0, 0.0 -> 1483.42, 1483.42
% INFO    : Updated Thermal Rating: on transformer 21593-21599 : Rate B, Rate C - 0.0, 0.0 -> 1482.21, 1482.21
% INFO    : Updated Thermal Rating: on line 21593-21641 : Rate B, Rate C - 0.0, 0.0 -> 4059.75, 4059.75
% INFO    : Updated Thermal Rating: on line 21727-21593 : Rate B, Rate C - 0.0, 0.0 -> 4134.26, 4134.26
% INFO    : Updated Thermal Rating: on line 23431-21593 : Rate B, Rate C - 0.0, 0.0 -> 4146.1, 4146.1
% INFO    : Updated Thermal Rating: on transformer 21595-21594 : Rate B, Rate C - 0.0, 0.0 -> 447.91, 447.91
% INFO    : Updated Thermal Rating: on line 21607-21594 : Rate B, Rate C - 0.0, 0.0 -> 1097.7, 1097.7
% INFO    : Updated Thermal Rating: on line 21594-21626 : Rate B, Rate C - 0.0, 0.0 -> 858.23, 858.23
% INFO    : Updated Thermal Rating: on line 21594-21660 : Rate B, Rate C - 0.0, 0.0 -> 1215.56, 1215.56
% INFO    : Updated Thermal Rating: on line 21742-21594 : Rate B, Rate C - 0.0, 0.0 -> 1322.63, 1322.63
% INFO    : Updated Thermal Rating: on line 21595-21622 : Rate B, Rate C - 0.0, 0.0 -> 284.01, 284.01
% INFO    : Updated Thermal Rating: on transformer 21601-21600 : Rate B, Rate C - 0.0, 0.0 -> 438.14, 438.14
% INFO    : Updated Thermal Rating: on transformer 21600-21602 : Rate B, Rate C - 0.0, 0.0 -> 346.49, 346.49
% INFO    : Updated Thermal Rating: on transformer 21600-21603 : Rate B, Rate C - 0.0, 0.0 -> 345.53, 345.53
% INFO    : Updated Thermal Rating: on transformer 21600-21604 : Rate B, Rate C - 0.0, 0.0 -> 345.15, 345.15
% INFO    : Updated Thermal Rating: on transformer 21600-21605 : Rate B, Rate C - 0.0, 0.0 -> 344.51, 344.51
% INFO    : Updated Thermal Rating: on line 21626-21606 : Rate B, Rate C - 0.0, 0.0 -> 1052.99, 1052.99
% INFO    : Updated Thermal Rating: on line 21606-21678 : Rate B, Rate C - 0.0, 0.0 -> 1097.63, 1097.63
% INFO    : Updated Thermal Rating: on transformer 21607-21610 : Rate B, Rate C - 0.0, 0.0 -> 481.94, 481.94
% INFO    : Updated Thermal Rating: on transformer 21607-21611 : Rate B, Rate C - 0.0, 0.0 -> 562.19, 562.19
% INFO    : Updated Thermal Rating: on transformer 21607-21612 : Rate B, Rate C - 0.0, 0.0 -> 561.56, 561.56
% INFO    : Updated Thermal Rating: on transformer 21607-21613 : Rate B, Rate C - 0.0, 0.0 -> 556.35, 556.35
% INFO    : Updated Thermal Rating: on transformer 21607-21614 : Rate B, Rate C - 0.0, 0.0 -> 554.66, 554.66
% INFO    : Updated Thermal Rating: on line 21607-21642 : Rate B, Rate C - 0.0, 0.0 -> 1150.58, 1150.58
% INFO    : Updated Thermal Rating: on line 21649-21607 : Rate B, Rate C - 0.0, 0.0 -> 1059.99, 1059.99
% INFO    : Updated Thermal Rating: on transformer 21608-21610 : Rate B, Rate C - 0.0, 0.0 -> 431.94, 431.94
% INFO    : Updated Thermal Rating: on transformer 21609-21610 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 21616-21615 : Rate B, Rate C - 0.0, 0.0 -> 469.5, 469.5
% INFO    : Updated Thermal Rating: on transformer 21615-21617 : Rate B, Rate C - 0.0, 0.0 -> 594.43, 594.43
% INFO    : Updated Thermal Rating: on transformer 21615-21619 : Rate B, Rate C - 0.0, 0.0 -> 312.35, 312.35
% INFO    : Updated Thermal Rating: on transformer 21615-21620 : Rate B, Rate C - 0.0, 0.0 -> 293.58, 293.58
% INFO    : Updated Thermal Rating: on line 21615-21660 : Rate B, Rate C - 0.0, 0.0 -> 1137.18, 1137.18
% INFO    : Updated Thermal Rating: on line 21615-21741 : Rate B, Rate C - 0.0, 0.0 -> 1292.69, 1292.69
% INFO    : Updated Thermal Rating: on line 21742-21615 : Rate B, Rate C - 0.0, 0.0 -> 1093.86, 1093.86
% INFO    : Updated Thermal Rating: on transformer 21616-21618 : Rate B, Rate C - 0.0, 0.0 -> 58.41, 58.41
% INFO    : Updated Thermal Rating: on transformer 21622-21621 : Rate B, Rate C - 0.0, 0.0 -> 640.0, 640.0
% INFO    : Updated Thermal Rating: on transformer 21621-21623 : Rate B, Rate C - 0.0, 0.0 -> 529.78, 529.78
% INFO    : Updated Thermal Rating: on transformer 21621-21624 : Rate B, Rate C - 0.0, 0.0 -> 529.37, 529.37
% INFO    : Updated Thermal Rating: on transformer 21621-21625 : Rate B, Rate C - 0.0, 0.0 -> 528.87, 528.87
% INFO    : Updated Thermal Rating: on transformer 21628-21627 : Rate B, Rate C - 0.0, 0.0 -> 555.85, 555.85
% INFO    : Updated Thermal Rating: on line 21721-21628 : Rate B, Rate C - 0.0, 0.0 -> 244.14, 244.14
% INFO    : Updated Thermal Rating: on line 21629-21741 : Rate B, Rate C - 0.0, 0.0 -> 1182.5, 1182.5
% INFO    : Updated Thermal Rating: on transformer 21630-21631 : Rate B, Rate C - 0.0, 0.0 -> 95.85, 95.85
% INFO    : Updated Thermal Rating: on line 21630-21686 : Rate B, Rate C - 0.0, 0.0 -> 212.27, 212.27
% INFO    : Updated Thermal Rating: on transformer 21632-21635 : Rate B, Rate C - 0.0, 0.0 -> 590.27, 590.27
% INFO    : Updated Thermal Rating: on transformer 21632-21636 : Rate B, Rate C - 0.0, 0.0 -> 298.27, 298.27
% INFO    : Updated Thermal Rating: on transformer 21633-21635 : Rate B, Rate C - 0.0, 0.0 -> 465.27, 465.27
% INFO    : Updated Thermal Rating: on transformer 21633-21637 : Rate B, Rate C - 0.0, 0.0 -> 62.03, 62.03
% INFO    : Updated Thermal Rating: on transformer 21634-21635 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 21745-21640 : Rate B, Rate C - 0.0, 0.0 -> 172.99, 172.99
% INFO    : Updated Thermal Rating: on transformer 21642-21641 : Rate B, Rate C - 0.0, 0.0 -> 1677.11, 1677.11
% INFO    : Updated Thermal Rating: on transformer 21642-21641 : Rate B, Rate C - 0.0, 0.0 -> 1677.11, 1677.11
% INFO    : Updated Thermal Rating: on transformer 21642-21641 : Rate B, Rate C - 0.0, 0.0 -> 1677.11, 1677.11
% INFO    : Updated Thermal Rating: on transformer 21641-21646 : Rate B, Rate C - 0.0, 0.0 -> 1788.08, 1788.08
% INFO    : Updated Thermal Rating: on transformer 21641-21647 : Rate B, Rate C - 0.0, 0.0 -> 1785.0, 1785.0
% INFO    : Updated Thermal Rating: on transformer 21641-21648 : Rate B, Rate C - 0.0, 0.0 -> 1771.43, 1771.43
% INFO    : Updated Thermal Rating: on transformer 21642-21645 : Rate B, Rate C - 0.0, 0.0 -> 620.82, 620.82
% INFO    : Updated Thermal Rating: on line 21642-21649 : Rate B, Rate C - 0.0, 0.0 -> 1320.65, 1320.65
% INFO    : Updated Thermal Rating: on line 21642-21698 : Rate B, Rate C - 0.0, 0.0 -> 1280.74, 1280.74
% INFO    : Updated Thermal Rating: on transformer 21643-21645 : Rate B, Rate C - 0.0, 0.0 -> 470.82, 470.82
% INFO    : Updated Thermal Rating: on transformer 21644-21645 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 21650-21649 : Rate B, Rate C - 0.0, 0.0 -> 442.79, 442.79
% INFO    : Updated Thermal Rating: on transformer 21649-21651 : Rate B, Rate C - 0.0, 0.0 -> 538.16, 538.16
% INFO    : Updated Thermal Rating: on transformer 21649-21652 : Rate B, Rate C - 0.0, 0.0 -> 536.6, 536.6
% INFO    : Updated Thermal Rating: on transformer 21649-21653 : Rate B, Rate C - 0.0, 0.0 -> 536.33, 536.33
% INFO    : Updated Thermal Rating: on line 21649-21671 : Rate B, Rate C - 0.0, 0.0 -> 1319.39, 1319.39
% INFO    : Updated Thermal Rating: on transformer 21656-21655 : Rate B, Rate C - 0.0, 0.0 -> 365.68, 365.68
% INFO    : Updated Thermal Rating: on line 21657-21682 : Rate B, Rate C - 0.0, 0.0 -> 1188.73, 1188.73
% INFO    : Updated Thermal Rating: on transformer 21661-21660 : Rate B, Rate C - 0.0, 0.0 -> 457.04, 457.04
% INFO    : Updated Thermal Rating: on transformer 21660-21662 : Rate B, Rate C - 0.0, 0.0 -> 417.93, 417.93
% INFO    : Updated Thermal Rating: on transformer 21660-21663 : Rate B, Rate C - 0.0, 0.0 -> 416.6, 416.6
% INFO    : Updated Thermal Rating: on line 21660-21700 : Rate B, Rate C - 0.0, 0.0 -> 1106.04, 1106.04
% INFO    : Updated Thermal Rating: on transformer 21664-21667 : Rate B, Rate C - 0.0, 0.0 -> 581.89, 581.89
% INFO    : Updated Thermal Rating: on transformer 21664-21668 : Rate B, Rate C - 0.0, 0.0 -> 400.88, 400.88
% INFO    : Updated Thermal Rating: on transformer 21664-21669 : Rate B, Rate C - 0.0, 0.0 -> 400.01, 400.01
% INFO    : Updated Thermal Rating: on transformer 21664-21670 : Rate B, Rate C - 0.0, 0.0 -> 397.28, 397.28
% INFO    : Updated Thermal Rating: on transformer 21665-21667 : Rate B, Rate C - 0.0, 0.0 -> 556.89, 556.89
% INFO    : Updated Thermal Rating: on line 21715-21665 : Rate B, Rate C - 0.0, 0.0 -> 229.68, 229.68
% INFO    : Updated Thermal Rating: on transformer 21666-21667 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 21677-21676 : Rate B, Rate C - 0.0, 0.0 -> 408.19, 408.19
% INFO    : Updated Thermal Rating: on line 21678-21682 : Rate B, Rate C - 0.0, 0.0 -> 1156.28, 1156.28
% INFO    : Updated Thermal Rating: on transformer 21680-21679 : Rate B, Rate C - 0.0, 0.0 -> 400.13, 400.13
% INFO    : Updated Thermal Rating: on transformer 21679-21681 : Rate B, Rate C - 0.0, 0.0 -> 486.02, 486.02
% INFO    : Updated Thermal Rating: on line 21692-21680 : Rate B, Rate C - 0.0, 0.0 -> 250.6, 250.6
% INFO    : Updated Thermal Rating: on transformer 21684-21688 : Rate B, Rate C - 0.0, 0.0 -> 1635.13, 1635.13
% INFO    : Updated Thermal Rating: on transformer 21684-21689 : Rate B, Rate C - 0.0, 0.0 -> 1493.66, 1493.66
% INFO    : Updated Thermal Rating: on transformer 21684-21690 : Rate B, Rate C - 0.0, 0.0 -> 1493.52, 1493.52
% INFO    : Updated Thermal Rating: on transformer 21684-21691 : Rate B, Rate C - 0.0, 0.0 -> 1492.74, 1492.74
% INFO    : Updated Thermal Rating: on line 23374-21684 : Rate B, Rate C - 0.0, 0.0 -> 3868.5, 3868.5
% INFO    : Updated Thermal Rating: on transformer 21686-21685 : Rate B, Rate C - 0.0, 0.0 -> 477.5, 477.5
% INFO    : Updated Thermal Rating: on transformer 21685-21688 : Rate B, Rate C - 0.0, 0.0 -> 1642.59, 1642.59
% INFO    : Updated Thermal Rating: on line 21685-21751 : Rate B, Rate C - 0.0, 0.0 -> 1079.73, 1079.73
% INFO    : Updated Thermal Rating: on transformer 21687-21688 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 21692-21693 : Rate B, Rate C - 0.0, 0.0 -> 133.25, 133.25
% INFO    : Updated Thermal Rating: on transformer 21699-21698 : Rate B, Rate C - 0.0, 0.0 -> 409.84, 409.84
% INFO    : Updated Thermal Rating: on line 21722-21698 : Rate B, Rate C - 0.0, 0.0 -> 1201.52, 1201.52
% INFO    : Updated Thermal Rating: on transformer 21701-21700 : Rate B, Rate C - 0.0, 0.0 -> 452.41, 452.41
% INFO    : Updated Thermal Rating: on transformer 21700-21702 : Rate B, Rate C - 0.0, 0.0 -> 448.66, 448.66
% INFO    : Updated Thermal Rating: on transformer 21700-21703 : Rate B, Rate C - 0.0, 0.0 -> 447.11, 447.11
% INFO    : Updated Thermal Rating: on transformer 21700-21704 : Rate B, Rate C - 0.0, 0.0 -> 447.01, 447.01
% INFO    : Updated Thermal Rating: on line 21701-23024 : Rate B, Rate C - 0.0, 0.0 -> 246.23, 246.23
% INFO    : Updated Thermal Rating: on transformer 21705-21708 : Rate B, Rate C - 0.0, 0.0 -> 193.34, 193.34
% INFO    : Updated Thermal Rating: on transformer 21705-21711 : Rate B, Rate C - 0.0, 0.0 -> 262.58, 262.58
% INFO    : Updated Thermal Rating: on transformer 21705-21714 : Rate B, Rate C - 0.0, 0.0 -> 103.0, 103.0
% INFO    : Updated Thermal Rating: on transformer 21706-21708 : Rate B, Rate C - 0.0, 0.0 -> 96.67, 96.67
% INFO    : Updated Thermal Rating: on transformer 21707-21708 : Rate B, Rate C - 0.0, 0.0 -> 96.67, 96.67
% INFO    : Updated Thermal Rating: on transformer 21709-21711 : Rate B, Rate C - 0.0, 0.0 -> 131.29, 131.29
% INFO    : Updated Thermal Rating: on transformer 21710-21711 : Rate B, Rate C - 0.0, 0.0 -> 131.29, 131.29
% INFO    : Updated Thermal Rating: on transformer 21712-21714 : Rate B, Rate C - 0.0, 0.0 -> 51.5, 51.5
% INFO    : Updated Thermal Rating: on transformer 21713-21714 : Rate B, Rate C - 0.0, 0.0 -> 51.5, 51.5
% INFO    : Updated Thermal Rating: on transformer 21717-21718 : Rate B, Rate C - 0.0, 0.0 -> 103.78, 103.78
% INFO    : Updated Thermal Rating: on transformer 21717-21719 : Rate B, Rate C - 0.0, 0.0 -> 66.02, 66.02
% INFO    : Updated Thermal Rating: on transformer 21722-21725 : Rate B, Rate C - 0.0, 0.0 -> 462.11, 462.11
% INFO    : Updated Thermal Rating: on transformer 21722-21726 : Rate B, Rate C - 0.0, 0.0 -> 573.58, 573.58
% INFO    : Updated Thermal Rating: on line 21722-21753 : Rate B, Rate C - 0.0, 0.0 -> 1282.84, 1282.84
% INFO    : Updated Thermal Rating: on transformer 21723-21725 : Rate B, Rate C - 0.0, 0.0 -> 437.11, 437.11
% INFO    : Updated Thermal Rating: on transformer 21724-21725 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 21728-21727 : Rate B, Rate C - 0.0, 0.0 -> 1617.48, 1617.48
% INFO    : Updated Thermal Rating: on transformer 21728-21727 : Rate B, Rate C - 0.0, 0.0 -> 1617.48, 1617.48
% INFO    : Updated Thermal Rating: on transformer 21728-21727 : Rate B, Rate C - 0.0, 0.0 -> 1617.48, 1617.48
% INFO    : Updated Thermal Rating: on transformer 21727-21730 : Rate B, Rate C - 0.0, 0.0 -> 1531.26, 1531.26
% INFO    : Updated Thermal Rating: on transformer 21727-21731 : Rate B, Rate C - 0.0, 0.0 -> 1529.53, 1529.53
% INFO    : Updated Thermal Rating: on transformer 21727-21732 : Rate B, Rate C - 0.0, 0.0 -> 1525.86, 1525.86
% INFO    : Updated Thermal Rating: on transformer 21729-21728 : Rate B, Rate C - 0.0, 0.0 -> 606.89, 606.89
% INFO    : Updated Thermal Rating: on transformer 21729-21728 : Rate B, Rate C - 0.0, 0.0 -> 606.89, 606.89
% INFO    : Updated Thermal Rating: on transformer 21729-21728 : Rate B, Rate C - 0.0, 0.0 -> 606.89, 606.89
% INFO    : Updated Thermal Rating: on transformer 21734-21733 : Rate B, Rate C - 0.0, 0.0 -> 563.53, 563.53
% INFO    : Updated Thermal Rating: on transformer 21733-21735 : Rate B, Rate C - 0.0, 0.0 -> 369.73, 369.73
% INFO    : Updated Thermal Rating: on transformer 21733-21736 : Rate B, Rate C - 0.0, 0.0 -> 368.58, 368.58
% INFO    : Updated Thermal Rating: on transformer 21733-21737 : Rate B, Rate C - 0.0, 0.0 -> 365.11, 365.11
% INFO    : Updated Thermal Rating: on transformer 21733-21738 : Rate B, Rate C - 0.0, 0.0 -> 364.29, 364.29
% INFO    : Updated Thermal Rating: on transformer 21733-21739 : Rate B, Rate C - 0.0, 0.0 -> 361.79, 361.79
% INFO    : Updated Thermal Rating: on transformer 21733-21740 : Rate B, Rate C - 0.0, 0.0 -> 309.75, 309.75
% INFO    : Updated Thermal Rating: on transformer 21743-21742 : Rate B, Rate C - 0.0, 0.0 -> 425.31, 425.31
% INFO    : Updated Thermal Rating: on transformer 21744-21747 : Rate B, Rate C - 0.0, 0.0 -> 554.68, 554.68
% INFO    : Updated Thermal Rating: on transformer 21744-21750 : Rate B, Rate C - 0.0, 0.0 -> 1030.98, 1030.98
% INFO    : Updated Thermal Rating: on transformer 21745-21747 : Rate B, Rate C - 0.0, 0.0 -> 479.68, 479.68
% INFO    : Updated Thermal Rating: on line 21745-23034 : Rate B, Rate C - 0.0, 0.0 -> 238.18, 238.18
% INFO    : Updated Thermal Rating: on transformer 21746-21747 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 21748-21750 : Rate B, Rate C - 0.0, 0.0 -> 515.49, 515.49
% INFO    : Updated Thermal Rating: on transformer 21749-21750 : Rate B, Rate C - 0.0, 0.0 -> 515.49, 515.49
% INFO    : Updated Thermal Rating: on line 23358-21751 : Rate B, Rate C - 0.0, 0.0 -> 921.72, 921.72
% INFO    : Updated Thermal Rating: on transformer 21754-21753 : Rate B, Rate C - 0.0, 0.0 -> 437.2, 437.2
% INFO    : Updated Thermal Rating: on transformer 21755-21756 : Rate B, Rate C - 0.0, 0.0 -> 70.5, 70.5
% INFO    : Updated Thermal Rating: on transformer 21755-21757 : Rate B, Rate C - 0.0, 0.0 -> 28.81, 28.81
% INFO    : Updated Thermal Rating: on transformer 21759-21760 : Rate B, Rate C - 0.0, 0.0 -> 131.69, 131.69
% INFO    : Updated Thermal Rating: on line 23000-23001 : Rate B, Rate C - 0.0, 0.0 -> 223.17, 223.17
% INFO    : Updated Thermal Rating: on line 23000-23004 : Rate B, Rate C - 0.0, 0.0 -> 226.31, 226.31
% INFO    : Updated Thermal Rating: on line 23001-23002 : Rate B, Rate C - 0.0, 0.0 -> 189.91, 189.91
% INFO    : Updated Thermal Rating: on line 23002-23003 : Rate B, Rate C - 0.0, 0.0 -> 206.66, 206.66
% INFO    : Updated Thermal Rating: on line 23003-23017 : Rate B, Rate C - 0.0, 0.0 -> 252.74, 252.74
% INFO    : Updated Thermal Rating: on line 23004-23017 : Rate B, Rate C - 0.0, 0.0 -> 250.39, 250.39
% INFO    : Updated Thermal Rating: on line 23011-23006 : Rate B, Rate C - 0.0, 0.0 -> 239.84, 239.84
% INFO    : Updated Thermal Rating: on line 23376-23006 : Rate B, Rate C - 0.0, 0.0 -> 270.86, 270.86
% INFO    : Updated Thermal Rating: on line 23010-23008 : Rate B, Rate C - 0.0, 0.0 -> 180.49, 180.49
% INFO    : Updated Thermal Rating: on line 23376-23010 : Rate B, Rate C - 0.0, 0.0 -> 222.63, 222.63
% INFO    : Updated Thermal Rating: on line 23013-23011 : Rate B, Rate C - 0.0, 0.0 -> 238.4, 238.4
% INFO    : Updated Thermal Rating: on line 23011-23014 : Rate B, Rate C - 0.0, 0.0 -> 239.64, 239.64
% INFO    : Updated Thermal Rating: on line 23039-23012 : Rate B, Rate C - 0.0, 0.0 -> 170.83, 170.83
% INFO    : Updated Thermal Rating: on line 23018-23013 : Rate B, Rate C - 0.0, 0.0 -> 178.61, 178.61
% INFO    : Updated Thermal Rating: on line 23014-23017 : Rate B, Rate C - 0.0, 0.0 -> 282.21, 282.21
% INFO    : Updated Thermal Rating: on line 23018-23015 : Rate B, Rate C - 0.0, 0.0 -> 241.53, 241.53
% INFO    : Updated Thermal Rating: on line 23015-23376 : Rate B, Rate C - 0.0, 0.0 -> 262.61, 262.61
% INFO    : Updated Thermal Rating: on transformer 23017-23016 : Rate B, Rate C - 0.0, 0.0 -> 583.19, 583.19
% INFO    : Updated Thermal Rating: on line 23016-23375 : Rate B, Rate C - 0.0, 0.0 -> 1279.58, 1279.58
% INFO    : Updated Thermal Rating: on line 23017-23376 : Rate B, Rate C - 0.0, 0.0 -> 377.92, 377.92
% INFO    : Updated Thermal Rating: on line 23021-23019 : Rate B, Rate C - 0.0, 0.0 -> 190.63, 190.63
% INFO    : Updated Thermal Rating: on line 23024-23019 : Rate B, Rate C - 0.0, 0.0 -> 236.65, 236.65
% INFO    : Updated Thermal Rating: on line 23021-23054 : Rate B, Rate C - 0.0, 0.0 -> 179.69, 179.69
% INFO    : Updated Thermal Rating: on line 23022-23023 : Rate B, Rate C - 0.0, 0.0 -> 237.39, 237.39
% INFO    : Updated Thermal Rating: on line 23040-23023 : Rate B, Rate C - 0.0, 0.0 -> 227.95, 227.95
% INFO    : Updated Thermal Rating: on line 23039-23026 : Rate B, Rate C - 0.0, 0.0 -> 195.57, 195.57
% INFO    : Updated Thermal Rating: on line 23026-23330 : Rate B, Rate C - 0.0, 0.0 -> 226.87, 226.87
% INFO    : Updated Thermal Rating: on transformer 23027-23030 : Rate B, Rate C - 0.0, 0.0 -> 102.89, 102.89
% INFO    : Updated Thermal Rating: on transformer 23028-23030 : Rate B, Rate C - 0.0, 0.0 -> 51.44, 51.44
% INFO    : Updated Thermal Rating: on transformer 23029-23030 : Rate B, Rate C - 0.0, 0.0 -> 51.44, 51.44
% INFO    : Updated Thermal Rating: on line 23433-23031 : Rate B, Rate C - 0.0, 0.0 -> 241.67, 241.67
% INFO    : Updated Thermal Rating: on line 23032-23041 : Rate B, Rate C - 0.0, 0.0 -> 244.04, 244.04
% INFO    : Updated Thermal Rating: on line 23032-23042 : Rate B, Rate C - 0.0, 0.0 -> 189.17, 189.17
% INFO    : Updated Thermal Rating: on line 23036-23034 : Rate B, Rate C - 0.0, 0.0 -> 210.48, 210.48
% INFO    : Updated Thermal Rating: on line 23037-23039 : Rate B, Rate C - 0.0, 0.0 -> 213.2, 213.2
% INFO    : Updated Thermal Rating: on line 23286-23037 : Rate B, Rate C - 0.0, 0.0 -> 234.43, 234.43
% INFO    : Updated Thermal Rating: on line 23040-23067 : Rate B, Rate C - 0.0, 0.0 -> 208.87, 208.87
% INFO    : Updated Thermal Rating: on line 23041-23271 : Rate B, Rate C - 0.0, 0.0 -> 274.08, 274.08
% INFO    : Updated Thermal Rating: on line 23042-23059 : Rate B, Rate C - 0.0, 0.0 -> 221.01, 221.01
% INFO    : Updated Thermal Rating: on line 23043-23044 : Rate B, Rate C - 0.0, 0.0 -> 229.75, 229.75
% INFO    : Updated Thermal Rating: on line 23043-23067 : Rate B, Rate C - 0.0, 0.0 -> 212.09, 212.09
% INFO    : Updated Thermal Rating: on line 23044-23053 : Rate B, Rate C - 0.0, 0.0 -> 252.47, 252.47
% INFO    : Updated Thermal Rating: on line 23056-23046 : Rate B, Rate C - 0.0, 0.0 -> 222.77, 222.77
% INFO    : Updated Thermal Rating: on line 23046-23086 : Rate B, Rate C - 0.0, 0.0 -> 230.32, 230.32
% INFO    : Updated Thermal Rating: on line 23046-23402 : Rate B, Rate C - 0.0, 0.0 -> 205.31, 205.31
% INFO    : Updated Thermal Rating: on transformer 23048-23051 : Rate B, Rate C - 0.0, 0.0 -> 319.8, 319.8
% INFO    : Updated Thermal Rating: on line 23067-23048 : Rate B, Rate C - 0.0, 0.0 -> 223.15, 223.15
% INFO    : Updated Thermal Rating: on line 23048-23071 : Rate B, Rate C - 0.0, 0.0 -> 230.09, 230.09
% INFO    : Updated Thermal Rating: on line 23048-23390 : Rate B, Rate C - 0.0, 0.0 -> 313.81, 313.81
% INFO    : Updated Thermal Rating: on transformer 23049-23051 : Rate B, Rate C - 0.0, 0.0 -> 159.9, 159.9
% INFO    : Updated Thermal Rating: on transformer 23050-23051 : Rate B, Rate C - 0.0, 0.0 -> 159.9, 159.9
% INFO    : Updated Thermal Rating: on line 23053-23058 : Rate B, Rate C - 0.0, 0.0 -> 238.82, 238.82
% INFO    : Updated Thermal Rating: on line 23390-23053 : Rate B, Rate C - 0.0, 0.0 -> 237.04, 237.04
% INFO    : Updated Thermal Rating: on line 23054-23056 : Rate B, Rate C - 0.0, 0.0 -> 221.41, 221.41
% INFO    : Updated Thermal Rating: on line 23056-23100 : Rate B, Rate C - 0.0, 0.0 -> 213.39, 213.39
% INFO    : Updated Thermal Rating: on line 23059-23063 : Rate B, Rate C - 0.0, 0.0 -> 208.32, 208.32
% INFO    : Updated Thermal Rating: on line 23059-23433 : Rate B, Rate C - 0.0, 0.0 -> 272.08, 272.08
% INFO    : Updated Thermal Rating: on line 23060-23078 : Rate B, Rate C - 0.0, 0.0 -> 147.29, 147.29
% INFO    : Updated Thermal Rating: on line 23083-23060 : Rate B, Rate C - 0.0, 0.0 -> 212.84, 212.84
% INFO    : Updated Thermal Rating: on line 23069-23061 : Rate B, Rate C - 0.0, 0.0 -> 191.14, 191.14
% INFO    : Updated Thermal Rating: on line 23063-23402 : Rate B, Rate C - 0.0, 0.0 -> 205.38, 205.38
% INFO    : Updated Thermal Rating: on line 23088-23067 : Rate B, Rate C - 0.0, 0.0 -> 186.28, 186.28
% INFO    : Updated Thermal Rating: on line 23355-23069 : Rate B, Rate C - 0.0, 0.0 -> 217.55, 217.55
% INFO    : Updated Thermal Rating: on line 23109-23072 : Rate B, Rate C - 0.0, 0.0 -> 202.02, 202.02
% INFO    : Updated Thermal Rating: on line 23075-23089 : Rate B, Rate C - 0.0, 0.0 -> 210.2, 210.2
% INFO    : Updated Thermal Rating: on line 23474-23075 : Rate B, Rate C - 0.0, 0.0 -> 231.68, 231.68
% INFO    : Updated Thermal Rating: on line 23076-23091 : Rate B, Rate C - 0.0, 0.0 -> 234.49, 234.49
% INFO    : Updated Thermal Rating: on line 23076-23100 : Rate B, Rate C - 0.0, 0.0 -> 227.6, 227.6
% INFO    : Updated Thermal Rating: on line 23076-23310 : Rate B, Rate C - 0.0, 0.0 -> 229.63, 229.63
% INFO    : Updated Thermal Rating: on line 23078-23310 : Rate B, Rate C - 0.0, 0.0 -> 215.59, 215.59
% INFO    : Updated Thermal Rating: on line 23079-23089 : Rate B, Rate C - 0.0, 0.0 -> 209.2, 209.2
% INFO    : Updated Thermal Rating: on line 23349-23079 : Rate B, Rate C - 0.0, 0.0 -> 248.24, 248.24
% INFO    : Updated Thermal Rating: on line 23405-23081 : Rate B, Rate C - 0.0, 0.0 -> 207.6, 207.6
% INFO    : Updated Thermal Rating: on line 23083-23341 : Rate B, Rate C - 0.0, 0.0 -> 249.06, 249.06
% INFO    : Updated Thermal Rating: on line 23086-23421 : Rate B, Rate C - 0.0, 0.0 -> 287.06, 287.06
% INFO    : Updated Thermal Rating: on line 23119-23088 : Rate B, Rate C - 0.0, 0.0 -> 198.2, 198.2
% INFO    : Updated Thermal Rating: on line 23310-23091 : Rate B, Rate C - 0.0, 0.0 -> 267.33, 267.33
% INFO    : Updated Thermal Rating: on line 23092-23109 : Rate B, Rate C - 0.0, 0.0 -> 226.93, 226.93
% INFO    : Updated Thermal Rating: on line 23092-23278 : Rate B, Rate C - 0.0, 0.0 -> 201.43, 201.43
% INFO    : Updated Thermal Rating: on line 23104-23093 : Rate B, Rate C - 0.0, 0.0 -> 191.26, 191.26
% INFO    : Updated Thermal Rating: on line 23093-23310 : Rate B, Rate C - 0.0, 0.0 -> 227.9, 227.9
% INFO    : Updated Thermal Rating: on line 23094-23104 : Rate B, Rate C - 0.0, 0.0 -> 215.0, 215.0
% INFO    : Updated Thermal Rating: on line 23094-23444 : Rate B, Rate C - 0.0, 0.0 -> 249.56, 249.56
% INFO    : Updated Thermal Rating: on line 23097-23349 : Rate B, Rate C - 0.0, 0.0 -> 241.74, 241.74
% INFO    : Updated Thermal Rating: on line 23097-23444 : Rate B, Rate C - 0.0, 0.0 -> 194.59, 194.59
% INFO    : Updated Thermal Rating: on line 23100-23474 : Rate B, Rate C - 0.0, 0.0 -> 300.11, 300.11
% INFO    : Updated Thermal Rating: on line 23349-23102 : Rate B, Rate C - 0.0, 0.0 -> 191.43, 191.43
% INFO    : Updated Thermal Rating: on line 23102-23501 : Rate B, Rate C - 0.0, 0.0 -> 217.23, 217.23
% INFO    : Updated Thermal Rating: on line 23103-23108 : Rate B, Rate C - 0.0, 0.0 -> 205.28, 205.28
% INFO    : Updated Thermal Rating: on line 23108-23105 : Rate B, Rate C - 0.0, 0.0 -> 219.25, 219.25
% INFO    : Updated Thermal Rating: on line 23105-23452 : Rate B, Rate C - 0.0, 0.0 -> 233.59, 233.59
% INFO    : Updated Thermal Rating: on line 23107-23112 : Rate B, Rate C - 0.0, 0.0 -> 220.7, 220.7
% INFO    : Updated Thermal Rating: on line 23107-23444 : Rate B, Rate C - 0.0, 0.0 -> 244.14, 244.14
% INFO    : Updated Thermal Rating: on line 23108-23350 : Rate B, Rate C - 0.0, 0.0 -> 208.35, 208.35
% INFO    : Updated Thermal Rating: on line 23111-23110 : Rate B, Rate C - 0.0, 0.0 -> 193.85, 193.85
% INFO    : Updated Thermal Rating: on line 23110-23128 : Rate B, Rate C - 0.0, 0.0 -> 215.46, 215.46
% INFO    : Updated Thermal Rating: on line 23110-23350 : Rate B, Rate C - 0.0, 0.0 -> 252.06, 252.06
% INFO    : Updated Thermal Rating: on line 23355-23111 : Rate B, Rate C - 0.0, 0.0 -> 215.32, 215.32
% INFO    : Updated Thermal Rating: on line 23120-23112 : Rate B, Rate C - 0.0, 0.0 -> 193.06, 193.06
% INFO    : Updated Thermal Rating: on line 23114-23127 : Rate B, Rate C - 0.0, 0.0 -> 245.3, 245.3
% INFO    : Updated Thermal Rating: on line 23114-23278 : Rate B, Rate C - 0.0, 0.0 -> 266.33, 266.33
% INFO    : Updated Thermal Rating: on line 23118-23139 : Rate B, Rate C - 0.0, 0.0 -> 227.73, 227.73
% INFO    : Updated Thermal Rating: on line 23501-23118 : Rate B, Rate C - 0.0, 0.0 -> 274.0, 274.0
% INFO    : Updated Thermal Rating: on line 23119-23127 : Rate B, Rate C - 0.0, 0.0 -> 231.09, 231.09
% INFO    : Updated Thermal Rating: on line 23124-23120 : Rate B, Rate C - 0.0, 0.0 -> 204.0, 204.0
% INFO    : Updated Thermal Rating: on line 23121-23131 : Rate B, Rate C - 0.0, 0.0 -> 216.69, 216.69
% INFO    : Updated Thermal Rating: on line 23121-23134 : Rate B, Rate C - 0.0, 0.0 -> 242.5, 242.5
% INFO    : Updated Thermal Rating: on transformer 23123-23126 : Rate B, Rate C - 0.0, 0.0 -> 628.52, 628.52
% INFO    : Updated Thermal Rating: on line 23159-23123 : Rate B, Rate C - 0.0, 0.0 -> 1277.32, 1277.32
% INFO    : Updated Thermal Rating: on line 23443-23123 : Rate B, Rate C - 0.0, 0.0 -> 1205.76, 1205.76
% INFO    : Updated Thermal Rating: on line 23123-23500 : Rate B, Rate C - 0.0, 0.0 -> 1214.92, 1214.92
% INFO    : Updated Thermal Rating: on transformer 23124-23126 : Rate B, Rate C - 0.0, 0.0 -> 442.48, 442.48
% INFO    : Updated Thermal Rating: on line 23124-23140 : Rate B, Rate C - 0.0, 0.0 -> 240.71, 240.71
% INFO    : Updated Thermal Rating: on transformer 23125-23126 : Rate B, Rate C - 0.0, 0.0 -> 186.04, 186.04
% INFO    : Updated Thermal Rating: on line 23134-23129 : Rate B, Rate C - 0.0, 0.0 -> 265.3, 265.3
% INFO    : Updated Thermal Rating: on line 23129-23147 : Rate B, Rate C - 0.0, 0.0 -> 239.7, 239.7
% INFO    : Updated Thermal Rating: on line 23129-23347 : Rate B, Rate C - 0.0, 0.0 -> 270.26, 270.26
% INFO    : Updated Thermal Rating: on line 23469-23129 : Rate B, Rate C - 0.0, 0.0 -> 258.63, 258.63
% INFO    : Updated Thermal Rating: on line 23130-23152 : Rate B, Rate C - 0.0, 0.0 -> 219.17, 219.17
% INFO    : Updated Thermal Rating: on line 23499-23130 : Rate B, Rate C - 0.0, 0.0 -> 230.55, 230.55
% INFO    : Updated Thermal Rating: on line 23132-23131 : Rate B, Rate C - 0.0, 0.0 -> 231.39, 231.39
% INFO    : Updated Thermal Rating: on line 23131-23139 : Rate B, Rate C - 0.0, 0.0 -> 232.11, 232.11
% INFO    : Updated Thermal Rating: on line 23132-23148 : Rate B, Rate C - 0.0, 0.0 -> 210.22, 210.22
% INFO    : Updated Thermal Rating: on line 23136-23145 : Rate B, Rate C - 0.0, 0.0 -> 215.38, 215.38
% INFO    : Updated Thermal Rating: on line 23452-23136 : Rate B, Rate C - 0.0, 0.0 -> 227.32, 227.32
% INFO    : Updated Thermal Rating: on line 23366-23137 : Rate B, Rate C - 0.0, 0.0 -> 224.74, 224.74
% INFO    : Updated Thermal Rating: on line 23137-23449 : Rate B, Rate C - 0.0, 0.0 -> 239.77, 239.77
% INFO    : Updated Thermal Rating: on line 23138-23312 : Rate B, Rate C - 0.0, 0.0 -> 212.93, 212.93
% INFO    : Updated Thermal Rating: on line 23138-23387 : Rate B, Rate C - 0.0, 0.0 -> 231.78, 231.78
% INFO    : Updated Thermal Rating: on line 23422-23138 : Rate B, Rate C - 0.0, 0.0 -> 188.86, 188.86
% INFO    : Updated Thermal Rating: on line 23140-23139 : Rate B, Rate C - 0.0, 0.0 -> 220.58, 220.58
% INFO    : Updated Thermal Rating: on transformer 23140-23143 : Rate B, Rate C - 0.0, 0.0 -> 102.79, 102.79
% INFO    : Updated Thermal Rating: on transformer 23141-23143 : Rate B, Rate C - 0.0, 0.0 -> 51.4, 51.4
% INFO    : Updated Thermal Rating: on transformer 23142-23143 : Rate B, Rate C - 0.0, 0.0 -> 51.4, 51.4
% INFO    : Updated Thermal Rating: on line 23371-23144 : Rate B, Rate C - 0.0, 0.0 -> 172.41, 172.41
% INFO    : Updated Thermal Rating: on line 23144-23489 : Rate B, Rate C - 0.0, 0.0 -> 198.19, 198.19
% INFO    : Updated Thermal Rating: on line 23145-23146 : Rate B, Rate C - 0.0, 0.0 -> 226.64, 226.64
% INFO    : Updated Thermal Rating: on line 23145-23160 : Rate B, Rate C - 0.0, 0.0 -> 257.49, 257.49
% INFO    : Updated Thermal Rating: on line 23145-23273 : Rate B, Rate C - 0.0, 0.0 -> 236.87, 236.87
% INFO    : Updated Thermal Rating: on line 23146-23281 : Rate B, Rate C - 0.0, 0.0 -> 173.37, 173.37
% INFO    : Updated Thermal Rating: on line 23424-23146 : Rate B, Rate C - 0.0, 0.0 -> 257.23, 257.23
% INFO    : Updated Thermal Rating: on line 23147-23496 : Rate B, Rate C - 0.0, 0.0 -> 227.17, 227.17
% INFO    : Updated Thermal Rating: on line 23148-23152 : Rate B, Rate C - 0.0, 0.0 -> 203.6, 203.6
% INFO    : Updated Thermal Rating: on line 23148-23449 : Rate B, Rate C - 0.0, 0.0 -> 225.44, 225.44
% INFO    : Updated Thermal Rating: on line 23152-23150 : Rate B, Rate C - 0.0, 0.0 -> 198.77, 198.77
% INFO    : Updated Thermal Rating: on line 23496-23150 : Rate B, Rate C - 0.0, 0.0 -> 205.74, 205.74
% INFO    : Updated Thermal Rating: on line 23162-23153 : Rate B, Rate C - 0.0, 0.0 -> 215.75, 215.75
% INFO    : Updated Thermal Rating: on line 23366-23153 : Rate B, Rate C - 0.0, 0.0 -> 261.36, 261.36
% INFO    : Updated Thermal Rating: on line 23154-23266 : Rate B, Rate C - 0.0, 0.0 -> 201.69, 201.69
% INFO    : Updated Thermal Rating: on line 23312-23154 : Rate B, Rate C - 0.0, 0.0 -> 227.9, 227.9
% INFO    : Updated Thermal Rating: on line 23154-25055 : Rate B, Rate C - 0.0, 0.0 -> 213.79, 213.79
% INFO    : Updated Thermal Rating: on line 23154-26144 : Rate B, Rate C - 0.0, 0.0 -> 192.1, 192.1
% INFO    : Updated Thermal Rating: on line 23155-23158 : Rate B, Rate C - 0.0, 0.0 -> 191.57, 191.57
% INFO    : Updated Thermal Rating: on line 23155-23496 : Rate B, Rate C - 0.0, 0.0 -> 220.31, 220.31
% INFO    : Updated Thermal Rating: on transformer 23158-23157 : Rate B, Rate C - 0.0, 0.0 -> 446.31, 446.31
% INFO    : Updated Thermal Rating: on line 23158-23177 : Rate B, Rate C - 0.0, 0.0 -> 268.76, 268.76
% INFO    : Updated Thermal Rating: on line 23159-23184 : Rate B, Rate C - 0.0, 0.0 -> 1167.37, 1167.37
% INFO    : Updated Thermal Rating: on line 23194-23160 : Rate B, Rate C - 0.0, 0.0 -> 238.38, 238.38
% INFO    : Updated Thermal Rating: on line 23161-23216 : Rate B, Rate C - 0.0, 0.0 -> 242.53, 242.53
% INFO    : Updated Thermal Rating: on line 23161-23366 : Rate B, Rate C - 0.0, 0.0 -> 263.82, 263.82
% INFO    : Updated Thermal Rating: on line 23163-23162 : Rate B, Rate C - 0.0, 0.0 -> 238.84, 238.84
% INFO    : Updated Thermal Rating: on line 23197-23162 : Rate B, Rate C - 0.0, 0.0 -> 228.54, 228.54
% INFO    : Updated Thermal Rating: on line 23398-23163 : Rate B, Rate C - 0.0, 0.0 -> 266.86, 266.86
% INFO    : Updated Thermal Rating: on line 23177-23165 : Rate B, Rate C - 0.0, 0.0 -> 241.79, 241.79
% INFO    : Updated Thermal Rating: on line 23180-23165 : Rate B, Rate C - 0.0, 0.0 -> 201.2, 201.2
% INFO    : Updated Thermal Rating: on line 23167-23172 : Rate B, Rate C - 0.0, 0.0 -> 235.08, 235.08
% INFO    : Updated Thermal Rating: on line 23167-23179 : Rate B, Rate C - 0.0, 0.0 -> 184.55, 184.55
% INFO    : Updated Thermal Rating: on line 23169-23183 : Rate B, Rate C - 0.0, 0.0 -> 227.01, 227.01
% INFO    : Updated Thermal Rating: on line 23169-23407 : Rate B, Rate C - 0.0, 0.0 -> 218.7, 218.7
% INFO    : Updated Thermal Rating: on line 23170-23172 : Rate B, Rate C - 0.0, 0.0 -> 184.07, 184.07
% INFO    : Updated Thermal Rating: on line 23194-23170 : Rate B, Rate C - 0.0, 0.0 -> 216.28, 216.28
% INFO    : Updated Thermal Rating: on line 23172-23441 : Rate B, Rate C - 0.0, 0.0 -> 255.25, 255.25
% INFO    : Updated Thermal Rating: on line 23173-23217 : Rate B, Rate C - 0.0, 0.0 -> 233.06, 233.06
% INFO    : Updated Thermal Rating: on line 23173-23292 : Rate B, Rate C - 0.0, 0.0 -> 286.05, 286.05
% INFO    : Updated Thermal Rating: on line 23174-23175 : Rate B, Rate C - 0.0, 0.0 -> 215.91, 215.91
% INFO    : Updated Thermal Rating: on line 23266-23174 : Rate B, Rate C - 0.0, 0.0 -> 204.54, 204.54
% INFO    : Updated Thermal Rating: on line 23174-23422 : Rate B, Rate C - 0.0, 0.0 -> 216.37, 216.37
% INFO    : Updated Thermal Rating: on line 23174-23439 : Rate B, Rate C - 0.0, 0.0 -> 217.15, 217.15
% INFO    : Updated Thermal Rating: on line 23175-23283 : Rate B, Rate C - 0.0, 0.0 -> 204.78, 204.78
% INFO    : Updated Thermal Rating: on line 23175-23362 : Rate B, Rate C - 0.0, 0.0 -> 195.51, 195.51
% INFO    : Updated Thermal Rating: on line 23183-23179 : Rate B, Rate C - 0.0, 0.0 -> 203.6, 203.6
% INFO    : Updated Thermal Rating: on line 23180-23182 : Rate B, Rate C - 0.0, 0.0 -> 224.86, 224.86
% INFO    : Updated Thermal Rating: on line 23182-23181 : Rate B, Rate C - 0.0, 0.0 -> 204.36, 204.36
% INFO    : Updated Thermal Rating: on line 23407-23181 : Rate B, Rate C - 0.0, 0.0 -> 235.92, 235.92
% INFO    : Updated Thermal Rating: on line 23182-23407 : Rate B, Rate C - 0.0, 0.0 -> 245.19, 245.19
% INFO    : Updated Thermal Rating: on line 23183-23185 : Rate B, Rate C - 0.0, 0.0 -> 222.96, 222.96
% INFO    : Updated Thermal Rating: on line 23183-23190 : Rate B, Rate C - 0.0, 0.0 -> 242.63, 242.63
% INFO    : Updated Thermal Rating: on transformer 23184-23187 : Rate B, Rate C - 0.0, 0.0 -> 514.86, 514.86
% INFO    : Updated Thermal Rating: on line 23291-23184 : Rate B, Rate C - 0.0, 0.0 -> 1184.68, 1184.68
% INFO    : Updated Thermal Rating: on line 23184-23408 : Rate B, Rate C - 0.0, 0.0 -> 1162.82, 1162.82
% INFO    : Updated Thermal Rating: on transformer 23185-23187 : Rate B, Rate C - 0.0, 0.0 -> 439.86, 439.86
% INFO    : Updated Thermal Rating: on line 23185-23189 : Rate B, Rate C - 0.0, 0.0 -> 273.64, 273.64
% INFO    : Updated Thermal Rating: on transformer 23186-23187 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 23201-23189 : Rate B, Rate C - 0.0, 0.0 -> 229.83, 229.83
% INFO    : Updated Thermal Rating: on line 23292-23190 : Rate B, Rate C - 0.0, 0.0 -> 260.65, 260.65
% INFO    : Updated Thermal Rating: on line 23193-23191 : Rate B, Rate C - 0.0, 0.0 -> 210.68, 210.68
% INFO    : Updated Thermal Rating: on line 23191-23201 : Rate B, Rate C - 0.0, 0.0 -> 206.52, 206.52
% INFO    : Updated Thermal Rating: on line 23191-23407 : Rate B, Rate C - 0.0, 0.0 -> 254.87, 254.87
% INFO    : Updated Thermal Rating: on line 23193-23209 : Rate B, Rate C - 0.0, 0.0 -> 210.37, 210.37
% INFO    : Updated Thermal Rating: on line 23197-23210 : Rate B, Rate C - 0.0, 0.0 -> 180.6, 180.6
% INFO    : Updated Thermal Rating: on line 23202-23200 : Rate B, Rate C - 0.0, 0.0 -> 214.68, 214.68
% INFO    : Updated Thermal Rating: on line 23204-23200 : Rate B, Rate C - 0.0, 0.0 -> 213.42, 213.42
% INFO    : Updated Thermal Rating: on line 23200-23206 : Rate B, Rate C - 0.0, 0.0 -> 222.54, 222.54
% INFO    : Updated Thermal Rating: on line 23202-23346 : Rate B, Rate C - 0.0, 0.0 -> 265.38, 265.38
% INFO    : Updated Thermal Rating: on line 23407-23204 : Rate B, Rate C - 0.0, 0.0 -> 223.36, 223.36
% INFO    : Updated Thermal Rating: on line 23206-23217 : Rate B, Rate C - 0.0, 0.0 -> 222.56, 222.56
% INFO    : Updated Thermal Rating: on line 23206-23218 : Rate B, Rate C - 0.0, 0.0 -> 202.32, 202.32
% INFO    : Updated Thermal Rating: on line 23206-23311 : Rate B, Rate C - 0.0, 0.0 -> 290.71, 290.71
% INFO    : Updated Thermal Rating: on line 23209-23217 : Rate B, Rate C - 0.0, 0.0 -> 242.02, 242.02
% INFO    : Updated Thermal Rating: on line 23210-23224 : Rate B, Rate C - 0.0, 0.0 -> 219.73, 219.73
% INFO    : Updated Thermal Rating: on line 23212-23225 : Rate B, Rate C - 0.0, 0.0 -> 226.43, 226.43
% INFO    : Updated Thermal Rating: on line 23227-23212 : Rate B, Rate C - 0.0, 0.0 -> 198.83, 198.83
% INFO    : Updated Thermal Rating: on line 23214-23339 : Rate B, Rate C - 0.0, 0.0 -> 198.7, 198.7
% INFO    : Updated Thermal Rating: on line 23215-23266 : Rate B, Rate C - 0.0, 0.0 -> 223.02, 223.02
% INFO    : Updated Thermal Rating: on line 23426-23215 : Rate B, Rate C - 0.0, 0.0 -> 210.61, 210.61
% INFO    : Updated Thermal Rating: on line 23216-23220 : Rate B, Rate C - 0.0, 0.0 -> 176.34, 176.34
% INFO    : Updated Thermal Rating: on line 23218-23222 : Rate B, Rate C - 0.0, 0.0 -> 207.72, 207.72
% INFO    : Updated Thermal Rating: on line 23362-23220 : Rate B, Rate C - 0.0, 0.0 -> 226.32, 226.32
% INFO    : Updated Thermal Rating: on line 23221-23231 : Rate B, Rate C - 0.0, 0.0 -> 216.43, 216.43
% INFO    : Updated Thermal Rating: on line 23221-23232 : Rate B, Rate C - 0.0, 0.0 -> 237.78, 237.78
% INFO    : Updated Thermal Rating: on line 23223-23222 : Rate B, Rate C - 0.0, 0.0 -> 184.87, 184.87
% INFO    : Updated Thermal Rating: on line 23222-23319 : Rate B, Rate C - 0.0, 0.0 -> 242.36, 242.36
% INFO    : Updated Thermal Rating: on line 23223-23225 : Rate B, Rate C - 0.0, 0.0 -> 212.79, 212.79
% INFO    : Updated Thermal Rating: on line 23346-23224 : Rate B, Rate C - 0.0, 0.0 -> 240.64, 240.64
% INFO    : Updated Thermal Rating: on line 23346-23225 : Rate B, Rate C - 0.0, 0.0 -> 183.23, 183.23
% INFO    : Updated Thermal Rating: on line 23225-23494 : Rate B, Rate C - 0.0, 0.0 -> 273.3, 273.3
% INFO    : Updated Thermal Rating: on line 23232-23227 : Rate B, Rate C - 0.0, 0.0 -> 204.45, 204.45
% INFO    : Updated Thermal Rating: on line 23239-23227 : Rate B, Rate C - 0.0, 0.0 -> 207.33, 207.33
% INFO    : Updated Thermal Rating: on line 23234-23229 : Rate B, Rate C - 0.0, 0.0 -> 250.53, 250.53
% INFO    : Updated Thermal Rating: on line 23235-23229 : Rate B, Rate C - 0.0, 0.0 -> 207.81, 207.81
% INFO    : Updated Thermal Rating: on line 23249-23229 : Rate B, Rate C - 0.0, 0.0 -> 228.23, 228.23
% INFO    : Updated Thermal Rating: on line 23242-23231 : Rate B, Rate C - 0.0, 0.0 -> 204.43, 204.43
% INFO    : Updated Thermal Rating: on line 23231-23283 : Rate B, Rate C - 0.0, 0.0 -> 256.44, 256.44
% INFO    : Updated Thermal Rating: on line 23243-23232 : Rate B, Rate C - 0.0, 0.0 -> 251.38, 251.38
% INFO    : Updated Thermal Rating: on line 23232-23248 : Rate B, Rate C - 0.0, 0.0 -> 241.05, 241.05
% INFO    : Updated Thermal Rating: on transformer 23234-23233 : Rate B, Rate C - 0.0, 0.0 -> 464.15, 464.15
% INFO    : Updated Thermal Rating: on line 23257-23233 : Rate B, Rate C - 0.0, 0.0 -> 1168.9, 1168.9
% INFO    : Updated Thermal Rating: on line 23233-23265 : Rate B, Rate C - 0.0, 0.0 -> 1140.18, 1140.18
% INFO    : Updated Thermal Rating: on line 23233-23345 : Rate B, Rate C - 0.0, 0.0 -> 1195.5, 1195.5
% INFO    : Updated Thermal Rating: on line 23234-23237 : Rate B, Rate C - 0.0, 0.0 -> 228.24, 228.24
% INFO    : Updated Thermal Rating: on line 23242-23234 : Rate B, Rate C - 0.0, 0.0 -> 191.22, 191.22
% INFO    : Updated Thermal Rating: on line 23235-23426 : Rate B, Rate C - 0.0, 0.0 -> 260.1, 260.1
% INFO    : Updated Thermal Rating: on line 25087-23237 : Rate B, Rate C - 0.0, 0.0 -> 209.54, 209.54
% INFO    : Updated Thermal Rating: on line 23247-23239 : Rate B, Rate C - 0.0, 0.0 -> 225.54, 225.54
% INFO    : Updated Thermal Rating: on line 23301-23241 : Rate B, Rate C - 0.0, 0.0 -> 233.76, 233.76
% INFO    : Updated Thermal Rating: on line 23241-25076 : Rate B, Rate C - 0.0, 0.0 -> 220.78, 220.78
% INFO    : Updated Thermal Rating: on line 23242-23245 : Rate B, Rate C - 0.0, 0.0 -> 214.71, 214.71
% INFO    : Updated Thermal Rating: on line 23243-23437 : Rate B, Rate C - 0.0, 0.0 -> 281.06, 281.06
% INFO    : Updated Thermal Rating: on line 23245-23250 : Rate B, Rate C - 0.0, 0.0 -> 227.53, 227.53
% INFO    : Updated Thermal Rating: on line 23247-23483 : Rate B, Rate C - 0.0, 0.0 -> 246.49, 246.49
% INFO    : Updated Thermal Rating: on line 23248-23414 : Rate B, Rate C - 0.0, 0.0 -> 263.22, 263.22
% INFO    : Updated Thermal Rating: on line 23255-23249 : Rate B, Rate C - 0.0, 0.0 -> 166.37, 166.37
% INFO    : Updated Thermal Rating: on line 23250-23437 : Rate B, Rate C - 0.0, 0.0 -> 251.44, 251.44
% INFO    : Updated Thermal Rating: on transformer 23251-23254 : Rate B, Rate C - 0.0, 0.0 -> 102.65, 102.65
% INFO    : Updated Thermal Rating: on line 23251-25086 : Rate B, Rate C - 0.0, 0.0 -> 212.69, 212.69
% INFO    : Updated Thermal Rating: on line 23251-25165 : Rate B, Rate C - 0.0, 0.0 -> 202.17, 202.17
% INFO    : Updated Thermal Rating: on line 23251-25240 : Rate B, Rate C - 0.0, 0.0 -> 162.76, 162.76
% INFO    : Updated Thermal Rating: on line 23251-25241 : Rate B, Rate C - 0.0, 0.0 -> 192.9, 192.9
% INFO    : Updated Thermal Rating: on line 23251-25962 : Rate B, Rate C - 0.0, 0.0 -> 221.18, 221.18
% INFO    : Updated Thermal Rating: on transformer 23252-23254 : Rate B, Rate C - 0.0, 0.0 -> 51.32, 51.32
% INFO    : Updated Thermal Rating: on transformer 23253-23254 : Rate B, Rate C - 0.0, 0.0 -> 51.32, 51.32
% INFO    : Updated Thermal Rating: on line 23258-23255 : Rate B, Rate C - 0.0, 0.0 -> 230.81, 230.81
% INFO    : Updated Thermal Rating: on transformer 23258-23257 : Rate B, Rate C - 0.0, 0.0 -> 411.1, 411.1
% INFO    : Updated Thermal Rating: on line 23257-26205 : Rate B, Rate C - 0.0, 0.0 -> 1086.97, 1086.97
% INFO    : Updated Thermal Rating: on line 23336-23260 : Rate B, Rate C - 0.0, 0.0 -> 200.21, 200.21
% INFO    : Updated Thermal Rating: on line 23392-23260 : Rate B, Rate C - 0.0, 0.0 -> 174.96, 174.96
% INFO    : Updated Thermal Rating: on line 23261-23336 : Rate B, Rate C - 0.0, 0.0 -> 196.67, 196.67
% INFO    : Updated Thermal Rating: on line 23261-23392 : Rate B, Rate C - 0.0, 0.0 -> 195.03, 195.03
% INFO    : Updated Thermal Rating: on line 23263-23264 : Rate B, Rate C - 0.0, 0.0 -> 185.48, 185.48
% INFO    : Updated Thermal Rating: on line 30118-23263 : Rate B, Rate C - 0.0, 0.0 -> 194.21, 194.21
% INFO    : Updated Thermal Rating: on line 23264-23397 : Rate B, Rate C - 0.0, 0.0 -> 211.48, 211.48
% INFO    : Updated Thermal Rating: on transformer 23266-23265 : Rate B, Rate C - 0.0, 0.0 -> 400.98, 400.98
% INFO    : Updated Thermal Rating: on transformer 23265-23269 : Rate B, Rate C - 0.0, 0.0 -> 1037.92, 1037.92
% INFO    : Updated Thermal Rating: on line 23365-23265 : Rate B, Rate C - 0.0, 0.0 -> 1198.85, 1198.85
% INFO    : Updated Thermal Rating: on line 23429-23265 : Rate B, Rate C - 0.0, 0.0 -> 1104.93, 1104.93
% INFO    : Updated Thermal Rating: on line 23283-23266 : Rate B, Rate C - 0.0, 0.0 -> 230.6, 230.6
% INFO    : Updated Thermal Rating: on line 23266-23439 : Rate B, Rate C - 0.0, 0.0 -> 219.4, 219.4
% INFO    : Updated Thermal Rating: on transformer 23267-23269 : Rate B, Rate C - 0.0, 0.0 -> 518.96, 518.96
% INFO    : Updated Thermal Rating: on transformer 23268-23269 : Rate B, Rate C - 0.0, 0.0 -> 518.96, 518.96
% INFO    : Updated Thermal Rating: on line 23271-23433 : Rate B, Rate C - 0.0, 0.0 -> 246.6, 246.6
% INFO    : Updated Thermal Rating: on transformer 23272-23275 : Rate B, Rate C - 0.0, 0.0 -> 425.46, 425.46
% INFO    : Updated Thermal Rating: on transformer 23273-23275 : Rate B, Rate C - 0.0, 0.0 -> 383.24, 383.24
% INFO    : Updated Thermal Rating: on transformer 23274-23275 : Rate B, Rate C - 0.0, 0.0 -> 42.22, 42.22
% INFO    : Updated Thermal Rating: on line 23338-23276 : Rate B, Rate C - 0.0, 0.0 -> 992.01, 992.01
% INFO    : Updated Thermal Rating: on transformer 23278-23277 : Rate B, Rate C - 0.0, 0.0 -> 448.29, 448.29
% INFO    : Updated Thermal Rating: on line 23501-23281 : Rate B, Rate C - 0.0, 0.0 -> 221.06, 221.06
% INFO    : Updated Thermal Rating: on transformer 23285-23284 : Rate B, Rate C - 0.0, 0.0 -> 1509.05, 1509.05
% INFO    : Updated Thermal Rating: on transformer 23284-23287 : Rate B, Rate C - 0.0, 0.0 -> 1234.29, 1234.29
% INFO    : Updated Thermal Rating: on transformer 23284-23288 : Rate B, Rate C - 0.0, 0.0 -> 1230.89, 1230.89
% INFO    : Updated Thermal Rating: on transformer 23284-23289 : Rate B, Rate C - 0.0, 0.0 -> 1230.32, 1230.32
% INFO    : Updated Thermal Rating: on transformer 23284-23290 : Rate B, Rate C - 0.0, 0.0 -> 1224.8, 1224.8
% INFO    : Updated Thermal Rating: on line 23374-23284 : Rate B, Rate C - 0.0, 0.0 -> 4073.0, 4073.0
% INFO    : Updated Thermal Rating: on line 23448-23284 : Rate B, Rate C - 0.0, 0.0 -> 4120.88, 4120.88
% INFO    : Updated Thermal Rating: on line 23284-26048 : Rate B, Rate C - 0.0, 0.0 -> 4223.31, 4223.31
% INFO    : Updated Thermal Rating: on transformer 23286-23285 : Rate B, Rate C - 0.0, 0.0 -> 388.39, 388.39
% INFO    : Updated Thermal Rating: on line 23329-23285 : Rate B, Rate C - 0.0, 0.0 -> 1137.34, 1137.34
% INFO    : Updated Thermal Rating: on line 23285-23365 : Rate B, Rate C - 0.0, 0.0 -> 1289.73, 1289.73
% INFO    : Updated Thermal Rating: on line 23286-23441 : Rate B, Rate C - 0.0, 0.0 -> 247.17, 247.17
% INFO    : Updated Thermal Rating: on line 23449-23286 : Rate B, Rate C - 0.0, 0.0 -> 233.76, 233.76
% INFO    : Updated Thermal Rating: on transformer 23292-23291 : Rate B, Rate C - 0.0, 0.0 -> 317.57, 317.57
% INFO    : Updated Thermal Rating: on transformer 23291-23293 : Rate B, Rate C - 0.0, 0.0 -> 473.15, 473.15
% INFO    : Updated Thermal Rating: on transformer 23291-23296 : Rate B, Rate C - 0.0, 0.0 -> 225.82, 225.82
% INFO    : Updated Thermal Rating: on transformer 23291-23297 : Rate B, Rate C - 0.0, 0.0 -> 224.3, 224.3
% INFO    : Updated Thermal Rating: on line 23409-23291 : Rate B, Rate C - 0.0, 0.0 -> 1216.26, 1216.26
% INFO    : Updated Thermal Rating: on line 23291-23429 : Rate B, Rate C - 0.0, 0.0 -> 1155.84, 1155.84
% INFO    : Updated Thermal Rating: on transformer 23292-23294 : Rate B, Rate C - 0.0, 0.0 -> 14.69, 14.69
% INFO    : Updated Thermal Rating: on transformer 23292-23295 : Rate B, Rate C - 0.0, 0.0 -> 40.54, 40.54
% INFO    : Updated Thermal Rating: on line 23292-23306 : Rate B, Rate C - 0.0, 0.0 -> 246.31, 246.31
% INFO    : Updated Thermal Rating: on line 23292-23328 : Rate B, Rate C - 0.0, 0.0 -> 270.0, 270.0
% INFO    : Updated Thermal Rating: on line 23299-23332 : Rate B, Rate C - 0.0, 0.0 -> 247.11, 247.11
% INFO    : Updated Thermal Rating: on line 23385-23299 : Rate B, Rate C - 0.0, 0.0 -> 186.11, 186.11
% INFO    : Updated Thermal Rating: on transformer 23301-23300 : Rate B, Rate C - 0.0, 0.0 -> 341.05, 341.05
% INFO    : Updated Thermal Rating: on transformer 23300-23302 : Rate B, Rate C - 0.0, 0.0 -> 330.45, 330.45
% INFO    : Updated Thermal Rating: on transformer 23300-23303 : Rate B, Rate C - 0.0, 0.0 -> 323.18, 323.18
% INFO    : Updated Thermal Rating: on transformer 23300-23305 : Rate B, Rate C - 0.0, 0.0 -> 285.3, 285.3
% INFO    : Updated Thermal Rating: on line 23429-23300 : Rate B, Rate C - 0.0, 0.0 -> 1206.57, 1206.57
% INFO    : Updated Thermal Rating: on line 23300-26090 : Rate B, Rate C - 0.0, 0.0 -> 1235.27, 1235.27
% INFO    : Updated Thermal Rating: on transformer 23301-23304 : Rate B, Rate C - 0.0, 0.0 -> 36.63, 36.63
% INFO    : Updated Thermal Rating: on line 23311-23306 : Rate B, Rate C - 0.0, 0.0 -> 174.47, 174.47
% INFO    : Updated Thermal Rating: on line 23437-23308 : Rate B, Rate C - 0.0, 0.0 -> 250.93, 250.93
% INFO    : Updated Thermal Rating: on line 23308-23483 : Rate B, Rate C - 0.0, 0.0 -> 240.03, 240.03
% INFO    : Updated Thermal Rating: on transformer 23310-23309 : Rate B, Rate C - 0.0, 0.0 -> 495.4, 495.4
% INFO    : Updated Thermal Rating: on line 23309-23443 : Rate B, Rate C - 0.0, 0.0 -> 1147.08, 1147.08
% INFO    : Updated Thermal Rating: on line 23473-23309 : Rate B, Rate C - 0.0, 0.0 -> 1145.06, 1145.06
% INFO    : Updated Thermal Rating: on line 23353-23311 : Rate B, Rate C - 0.0, 0.0 -> 225.32, 225.32
% INFO    : Updated Thermal Rating: on transformer 23312-23313 : Rate B, Rate C - 0.0, 0.0 -> 73.69, 73.69
% INFO    : Updated Thermal Rating: on line 23316-23472 : Rate B, Rate C - 0.0, 0.0 -> 213.47, 213.47
% INFO    : Updated Thermal Rating: on line 23316-25000 : Rate B, Rate C - 0.0, 0.0 -> 216.23, 216.23
% INFO    : Updated Thermal Rating: on line 23316-25003 : Rate B, Rate C - 0.0, 0.0 -> 213.22, 213.22
% INFO    : Updated Thermal Rating: on line 23319-23483 : Rate B, Rate C - 0.0, 0.0 -> 172.76, 172.76
% INFO    : Updated Thermal Rating: on transformer 23320-23323 : Rate B, Rate C - 0.0, 0.0 -> 204.65, 204.65
% INFO    : Updated Thermal Rating: on transformer 23320-23324 : Rate B, Rate C - 0.0, 0.0 -> 42.31, 42.31
% INFO    : Updated Thermal Rating: on transformer 23320-23325 : Rate B, Rate C - 0.0, 0.0 -> 42.1, 42.1
% INFO    : Updated Thermal Rating: on transformer 23320-23326 : Rate B, Rate C - 0.0, 0.0 -> 41.97, 41.97
% INFO    : Updated Thermal Rating: on transformer 23321-23323 : Rate B, Rate C - 0.0, 0.0 -> 102.32, 102.32
% INFO    : Updated Thermal Rating: on transformer 23322-23323 : Rate B, Rate C - 0.0, 0.0 -> 102.32, 102.32
% INFO    : Updated Thermal Rating: on line 23328-23468 : Rate B, Rate C - 0.0, 0.0 -> 196.21, 196.21
% INFO    : Updated Thermal Rating: on transformer 23330-23329 : Rate B, Rate C - 0.0, 0.0 -> 401.56, 401.56
% INFO    : Updated Thermal Rating: on line 23329-25009 : Rate B, Rate C - 0.0, 0.0 -> 1168.91, 1168.91
% INFO    : Updated Thermal Rating: on line 23330-23405 : Rate B, Rate C - 0.0, 0.0 -> 214.34, 214.34
% INFO    : Updated Thermal Rating: on line 23330-23472 : Rate B, Rate C - 0.0, 0.0 -> 250.68, 250.68
% INFO    : Updated Thermal Rating: on transformer 23332-23331 : Rate B, Rate C - 0.0, 0.0 -> 374.12, 374.12
% INFO    : Updated Thermal Rating: on transformer 23331-23333 : Rate B, Rate C - 0.0, 0.0 -> 372.06, 372.06
% INFO    : Updated Thermal Rating: on transformer 23331-23334 : Rate B, Rate C - 0.0, 0.0 -> 306.13, 306.13
% INFO    : Updated Thermal Rating: on line 23332-25819 : Rate B, Rate C - 0.0, 0.0 -> 201.4, 201.4
% INFO    : Updated Thermal Rating: on line 23335-28718 : Rate B, Rate C - 0.0, 0.0 -> 1108.97, 1108.97
% INFO    : Updated Thermal Rating: on line 28814-23335 : Rate B, Rate C - 0.0, 0.0 -> 1034.52, 1034.52
% INFO    : Updated Thermal Rating: on transformer 23336-23337 : Rate B, Rate C - 0.0, 0.0 -> 71.49, 71.49
% INFO    : Updated Thermal Rating: on line 23363-23336 : Rate B, Rate C - 0.0, 0.0 -> 163.57, 163.57
% INFO    : Updated Thermal Rating: on transformer 23339-23338 : Rate B, Rate C - 0.0, 0.0 -> 320.5, 320.5
% INFO    : Updated Thermal Rating: on line 23338-23500 : Rate B, Rate C - 0.0, 0.0 -> 1059.9, 1059.9
% INFO    : Updated Thermal Rating: on line 23339-23347 : Rate B, Rate C - 0.0, 0.0 -> 182.31, 182.31
% INFO    : Updated Thermal Rating: on transformer 23340-23343 : Rate B, Rate C - 0.0, 0.0 -> 595.2, 595.2
% INFO    : Updated Thermal Rating: on transformer 23341-23343 : Rate B, Rate C - 0.0, 0.0 -> 459.03, 459.03
% INFO    : Updated Thermal Rating: on line 23341-23421 : Rate B, Rate C - 0.0, 0.0 -> 248.52, 248.52
% INFO    : Updated Thermal Rating: on transformer 23342-23343 : Rate B, Rate C - 0.0, 0.0 -> 136.17, 136.17
% INFO    : Updated Thermal Rating: on line 23389-23344 : Rate B, Rate C - 0.0, 0.0 -> 1115.0, 1115.0
% INFO    : Updated Thermal Rating: on transformer 23346-23345 : Rate B, Rate C - 0.0, 0.0 -> 400.86, 400.86
% INFO    : Updated Thermal Rating: on line 23345-23436 : Rate B, Rate C - 0.0, 0.0 -> 1254.87, 1254.87
% INFO    : Updated Thermal Rating: on transformer 23350-23351 : Rate B, Rate C - 0.0, 0.0 -> 89.34, 89.34
% INFO    : Updated Thermal Rating: on transformer 23350-23352 : Rate B, Rate C - 0.0, 0.0 -> 57.11, 57.11
% INFO    : Updated Thermal Rating: on line 23350-23444 : Rate B, Rate C - 0.0, 0.0 -> 239.25, 239.25
% INFO    : Updated Thermal Rating: on line 23373-23353 : Rate B, Rate C - 0.0, 0.0 -> 266.15, 266.15
% INFO    : Updated Thermal Rating: on line 23353-23494 : Rate B, Rate C - 0.0, 0.0 -> 262.98, 262.98
% INFO    : Updated Thermal Rating: on transformer 23354-23357 : Rate B, Rate C - 0.0, 0.0 -> 512.53, 512.53
% INFO    : Updated Thermal Rating: on transformer 23355-23357 : Rate B, Rate C - 0.0, 0.0 -> 391.61, 391.61
% INFO    : Updated Thermal Rating: on transformer 23356-23357 : Rate B, Rate C - 0.0, 0.0 -> 120.92, 120.92
% INFO    : Updated Thermal Rating: on transformer 23359-23360 : Rate B, Rate C - 0.0, 0.0 -> 35.38, 35.38
% INFO    : Updated Thermal Rating: on transformer 23359-23361 : Rate B, Rate C - 0.0, 0.0 -> 35.18, 35.18
% INFO    : Updated Thermal Rating: on line 23363-23414 : Rate B, Rate C - 0.0, 0.0 -> 212.5, 212.5
% INFO    : Updated Thermal Rating: on transformer 23366-23365 : Rate B, Rate C - 0.0, 0.0 -> 429.44, 429.44
% INFO    : Updated Thermal Rating: on transformer 23366-23369 : Rate B, Rate C - 0.0, 0.0 -> 196.04, 196.04
% INFO    : Updated Thermal Rating: on line 23366-23398 : Rate B, Rate C - 0.0, 0.0 -> 194.56, 194.56
% INFO    : Updated Thermal Rating: on transformer 23367-23369 : Rate B, Rate C - 0.0, 0.0 -> 98.02, 98.02
% INFO    : Updated Thermal Rating: on transformer 23368-23369 : Rate B, Rate C - 0.0, 0.0 -> 98.02, 98.02
% INFO    : Updated Thermal Rating: on line 23468-23373 : Rate B, Rate C - 0.0, 0.0 -> 154.85, 154.85
% INFO    : Updated Thermal Rating: on transformer 23375-23374 : Rate B, Rate C - 0.0, 0.0 -> 1582.33, 1582.33
% INFO    : Updated Thermal Rating: on transformer 23374-23377 : Rate B, Rate C - 0.0, 0.0 -> 1803.44, 1803.44
% INFO    : Updated Thermal Rating: on transformer 23374-23378 : Rate B, Rate C - 0.0, 0.0 -> 1802.12, 1802.12
% INFO    : Updated Thermal Rating: on transformer 23374-23379 : Rate B, Rate C - 0.0, 0.0 -> 1579.0, 1579.0
% INFO    : Updated Thermal Rating: on transformer 23374-23380 : Rate B, Rate C - 0.0, 0.0 -> 1575.67, 1575.67
% INFO    : Updated Thermal Rating: on transformer 23374-23381 : Rate B, Rate C - 0.0, 0.0 -> 1575.31, 1575.31
% INFO    : Updated Thermal Rating: on transformer 23374-23382 : Rate B, Rate C - 0.0, 0.0 -> 1571.96, 1571.96
% INFO    : Updated Thermal Rating: on transformer 23374-23383 : Rate B, Rate C - 0.0, 0.0 -> 1569.86, 1569.86
% INFO    : Updated Thermal Rating: on transformer 23374-23384 : Rate B, Rate C - 0.0, 0.0 -> 1566.56, 1566.56
% INFO    : Updated Thermal Rating: on transformer 23376-23375 : Rate B, Rate C - 0.0, 0.0 -> 548.63, 548.63
% INFO    : Updated Thermal Rating: on line 23385-25764 : Rate B, Rate C - 0.0, 0.0 -> 226.07, 226.07
% INFO    : Updated Thermal Rating: on line 25819-23385 : Rate B, Rate C - 0.0, 0.0 -> 205.69, 205.69
% INFO    : Updated Thermal Rating: on line 23385-25820 : Rate B, Rate C - 0.0, 0.0 -> 208.28, 208.28
% INFO    : Updated Thermal Rating: on line 23387-23449 : Rate B, Rate C - 0.0, 0.0 -> 221.31, 221.31
% INFO    : Updated Thermal Rating: on line 23387-23499 : Rate B, Rate C - 0.0, 0.0 -> 222.28, 222.28
% INFO    : Updated Thermal Rating: on transformer 23390-23389 : Rate B, Rate C - 0.0, 0.0 -> 465.04, 465.04
% INFO    : Updated Thermal Rating: on line 23432-23389 : Rate B, Rate C - 0.0, 0.0 -> 1240.98, 1240.98
% INFO    : Updated Thermal Rating: on transformer 23392-23391 : Rate B, Rate C - 0.0, 0.0 -> 305.29, 305.29
% INFO    : Updated Thermal Rating: on transformer 23391-23393 : Rate B, Rate C - 0.0, 0.0 -> 319.18, 319.18
% INFO    : Updated Thermal Rating: on line 23394-23493 : Rate B, Rate C - 0.0, 0.0 -> 995.43, 995.43
% INFO    : Updated Thermal Rating: on transformer 23395-23396 : Rate B, Rate C - 0.0, 0.0 -> 92.92, 92.92
% INFO    : Updated Thermal Rating: on line 23397-28760 : Rate B, Rate C - 0.0, 0.0 -> 229.01, 229.01
% INFO    : Updated Thermal Rating: on line 30159-23397 : Rate B, Rate C - 0.0, 0.0 -> 214.18, 214.18
% INFO    : Updated Thermal Rating: on transformer 23398-23399 : Rate B, Rate C - 0.0, 0.0 -> 63.84, 63.84
% INFO    : Updated Thermal Rating: on transformer 23398-23400 : Rate B, Rate C - 0.0, 0.0 -> 62.99, 62.99
% INFO    : Updated Thermal Rating: on transformer 23398-23401 : Rate B, Rate C - 0.0, 0.0 -> 62.53, 62.53
% INFO    : Updated Thermal Rating: on transformer 23402-23403 : Rate B, Rate C - 0.0, 0.0 -> 80.1, 80.1
% INFO    : Updated Thermal Rating: on transformer 23407-23406 : Rate B, Rate C - 0.0, 0.0 -> 542.84, 542.84
% INFO    : Updated Thermal Rating: on transformer 23410-23409 : Rate B, Rate C - 0.0, 0.0 -> 325.35, 325.35
% INFO    : Updated Thermal Rating: on transformer 23409-23411 : Rate B, Rate C - 0.0, 0.0 -> 520.9, 520.9
% INFO    : Updated Thermal Rating: on line 23409-23493 : Rate B, Rate C - 0.0, 0.0 -> 1085.99, 1085.99
% INFO    : Updated Thermal Rating: on line 23410-23468 : Rate B, Rate C - 0.0, 0.0 -> 211.64, 211.64
% INFO    : Updated Thermal Rating: on transformer 23412-23416 : Rate B, Rate C - 0.0, 0.0 -> 1467.05, 1467.05
% INFO    : Updated Thermal Rating: on transformer 23412-23417 : Rate B, Rate C - 0.0, 0.0 -> 1713.95, 1713.95
% INFO    : Updated Thermal Rating: on transformer 23412-23418 : Rate B, Rate C - 0.0, 0.0 -> 1711.24, 1711.24
% INFO    : Updated Thermal Rating: on transformer 23412-23419 : Rate B, Rate C - 0.0, 0.0 -> 1711.04, 1711.04
% INFO    : Updated Thermal Rating: on transformer 23414-23413 : Rate B, Rate C - 0.0, 0.0 -> 379.75, 379.75
% INFO    : Updated Thermal Rating: on transformer 23413-23416 : Rate B, Rate C - 0.0, 0.0 -> 1417.05, 1417.05
% INFO    : Updated Thermal Rating: on line 23488-23413 : Rate B, Rate C - 0.0, 0.0 -> 1204.02, 1204.02
% INFO    : Updated Thermal Rating: on transformer 23415-23416 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 25864-23420 : Rate B, Rate C - 0.0, 0.0 -> 4210.01, 4210.01
% INFO    : Updated Thermal Rating: on line 23420-30387 : Rate B, Rate C - 0.0, 0.0 -> 4062.01, 4062.01
% INFO    : Updated Thermal Rating: on transformer 23425-23428 : Rate B, Rate C - 0.0, 0.0 -> 401.46, 401.46
% INFO    : Updated Thermal Rating: on transformer 23426-23428 : Rate B, Rate C - 0.0, 0.0 -> 376.46, 376.46
% INFO    : Updated Thermal Rating: on transformer 23427-23428 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 23432-23431 : Rate B, Rate C - 0.0, 0.0 -> 1568.5, 1568.5
% INFO    : Updated Thermal Rating: on transformer 23431-23434 : Rate B, Rate C - 0.0, 0.0 -> 1436.7, 1436.7
% INFO    : Updated Thermal Rating: on transformer 23431-23435 : Rate B, Rate C - 0.0, 0.0 -> 1214.3, 1214.3
% INFO    : Updated Thermal Rating: on transformer 23433-23432 : Rate B, Rate C - 0.0, 0.0 -> 504.56, 504.56
% INFO    : Updated Thermal Rating: on transformer 23437-23436 : Rate B, Rate C - 0.0, 0.0 -> 417.9, 417.9
% INFO    : Updated Thermal Rating: on line 23488-23436 : Rate B, Rate C - 0.0, 0.0 -> 1281.3, 1281.3
% INFO    : Updated Thermal Rating: on transformer 23443-23442 : Rate B, Rate C - 0.0, 0.0 -> 1429.53, 1429.53
% INFO    : Updated Thermal Rating: on transformer 23442-23445 : Rate B, Rate C - 0.0, 0.0 -> 1195.24, 1195.24
% INFO    : Updated Thermal Rating: on transformer 23442-23446 : Rate B, Rate C - 0.0, 0.0 -> 1193.76, 1193.76
% INFO    : Updated Thermal Rating: on transformer 23442-23447 : Rate B, Rate C - 0.0, 0.0 -> 1192.71, 1192.71
% INFO    : Updated Thermal Rating: on transformer 23444-23443 : Rate B, Rate C - 0.0, 0.0 -> 490.01, 490.01
% INFO    : Updated Thermal Rating: on line 23448-23457 : Rate B, Rate C - 0.0, 0.0 -> 4114.33, 4114.33
% INFO    : Updated Thermal Rating: on line 23449-23499 : Rate B, Rate C - 0.0, 0.0 -> 237.56, 237.56
% INFO    : Updated Thermal Rating: on transformer 23451-23450 : Rate B, Rate C - 0.0, 0.0 -> 1455.05, 1455.05
% INFO    : Updated Thermal Rating: on transformer 23450-23453 : Rate B, Rate C - 0.0, 0.0 -> 1358.87, 1358.87
% INFO    : Updated Thermal Rating: on transformer 23450-23454 : Rate B, Rate C - 0.0, 0.0 -> 1357.49, 1357.49
% INFO    : Updated Thermal Rating: on transformer 23450-23455 : Rate B, Rate C - 0.0, 0.0 -> 825.18, 825.18
% INFO    : Updated Thermal Rating: on transformer 23452-23451 : Rate B, Rate C - 0.0, 0.0 -> 405.16, 405.16
% INFO    : Updated Thermal Rating: on transformer 23451-23456 : Rate B, Rate C - 0.0, 0.0 -> 270.55, 270.55
% INFO    : Updated Thermal Rating: on line 23500-23451 : Rate B, Rate C - 0.0, 0.0 -> 1241.0, 1241.0
% INFO    : Updated Thermal Rating: on transformer 23458-23461 : Rate B, Rate C - 0.0, 0.0 -> 205.7, 205.7
% INFO    : Updated Thermal Rating: on transformer 23458-23464 : Rate B, Rate C - 0.0, 0.0 -> 205.21, 205.21
% INFO    : Updated Thermal Rating: on transformer 23458-23467 : Rate B, Rate C - 0.0, 0.0 -> 102.63, 102.63
% INFO    : Updated Thermal Rating: on transformer 23459-23461 : Rate B, Rate C - 0.0, 0.0 -> 102.85, 102.85
% INFO    : Updated Thermal Rating: on transformer 23460-23461 : Rate B, Rate C - 0.0, 0.0 -> 102.85, 102.85
% INFO    : Updated Thermal Rating: on transformer 23462-23464 : Rate B, Rate C - 0.0, 0.0 -> 102.61, 102.61
% INFO    : Updated Thermal Rating: on transformer 23463-23464 : Rate B, Rate C - 0.0, 0.0 -> 102.61, 102.61
% INFO    : Updated Thermal Rating: on transformer 23465-23467 : Rate B, Rate C - 0.0, 0.0 -> 51.32, 51.32
% INFO    : Updated Thermal Rating: on transformer 23466-23467 : Rate B, Rate C - 0.0, 0.0 -> 51.32, 51.32
% INFO    : Updated Thermal Rating: on line 23469-23501 : Rate B, Rate C - 0.0, 0.0 -> 257.38, 257.38
% INFO    : Updated Thermal Rating: on transformer 23470-23471 : Rate B, Rate C - 0.0, 0.0 -> 72.95, 72.95
% INFO    : Updated Thermal Rating: on line 23472-25001 : Rate B, Rate C - 0.0, 0.0 -> 224.97, 224.97
% INFO    : Updated Thermal Rating: on line 23472-25008 : Rate B, Rate C - 0.0, 0.0 -> 204.96, 204.96
% INFO    : Updated Thermal Rating: on line 23472-25027 : Rate B, Rate C - 0.0, 0.0 -> 217.35, 217.35
% INFO    : Updated Thermal Rating: on transformer 23473-23476 : Rate B, Rate C - 0.0, 0.0 -> 605.34, 605.34
% INFO    : Updated Thermal Rating: on transformer 23473-23477 : Rate B, Rate C - 0.0, 0.0 -> 331.5, 331.5
% INFO    : Updated Thermal Rating: on transformer 23473-23478 : Rate B, Rate C - 0.0, 0.0 -> 413.19, 413.19
% INFO    : Updated Thermal Rating: on transformer 23473-23479 : Rate B, Rate C - 0.0, 0.0 -> 271.88, 271.88
% INFO    : Updated Thermal Rating: on transformer 23474-23476 : Rate B, Rate C - 0.0, 0.0 -> 480.34, 480.34
% INFO    : Updated Thermal Rating: on transformer 23474-23480 : Rate B, Rate C - 0.0, 0.0 -> 22.04, 22.04
% INFO    : Updated Thermal Rating: on transformer 23474-23481 : Rate B, Rate C - 0.0, 0.0 -> 21.84, 21.84
% INFO    : Updated Thermal Rating: on transformer 23475-23476 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 23483-23482 : Rate B, Rate C - 0.0, 0.0 -> 401.36, 401.36
% INFO    : Updated Thermal Rating: on transformer 23482-23486 : Rate B, Rate C - 0.0, 0.0 -> 998.22, 998.22
% INFO    : Updated Thermal Rating: on transformer 23483-23487 : Rate B, Rate C - 0.0, 0.0 -> 85.66, 85.66
% INFO    : Updated Thermal Rating: on transformer 23484-23486 : Rate B, Rate C - 0.0, 0.0 -> 499.11, 499.11
% INFO    : Updated Thermal Rating: on transformer 23485-23486 : Rate B, Rate C - 0.0, 0.0 -> 499.11, 499.11
% INFO    : Updated Thermal Rating: on line 23488-23493 : Rate B, Rate C - 0.0, 0.0 -> 1128.85, 1128.85
% INFO    : Updated Thermal Rating: on transformer 23489-23492 : Rate B, Rate C - 0.0, 0.0 -> 225.84, 225.84
% INFO    : Updated Thermal Rating: on line 23489-30017 : Rate B, Rate C - 0.0, 0.0 -> 208.69, 208.69
% INFO    : Updated Thermal Rating: on transformer 23490-23492 : Rate B, Rate C - 0.0, 0.0 -> 112.92, 112.92
% INFO    : Updated Thermal Rating: on transformer 23491-23492 : Rate B, Rate C - 0.0, 0.0 -> 112.92, 112.92
% INFO    : Updated Thermal Rating: on transformer 23494-23493 : Rate B, Rate C - 0.0, 0.0 -> 299.82, 299.82
% INFO    : Updated Thermal Rating: on transformer 23501-23500 : Rate B, Rate C - 0.0, 0.0 -> 426.51, 426.51
% INFO    : Updated Thermal Rating: on transformer 23500-23504 : Rate B, Rate C - 0.0, 0.0 -> 1011.97, 1011.97
% INFO    : Updated Thermal Rating: on transformer 23502-23504 : Rate B, Rate C - 0.0, 0.0 -> 505.98, 505.98
% INFO    : Updated Thermal Rating: on transformer 23503-23504 : Rate B, Rate C - 0.0, 0.0 -> 505.98, 505.98
% INFO    : Updated Thermal Rating: on transformer 23505-23509 : Rate B, Rate C - 0.0, 0.0 -> 1462.93, 1462.93
% INFO    : Updated Thermal Rating: on transformer 23505-23510 : Rate B, Rate C - 0.0, 0.0 -> 1550.31, 1550.31
% INFO    : Updated Thermal Rating: on transformer 23505-23511 : Rate B, Rate C - 0.0, 0.0 -> 1547.96, 1547.96
% INFO    : Updated Thermal Rating: on transformer 23505-23512 : Rate B, Rate C - 0.0, 0.0 -> 1547.92, 1547.92
% INFO    : Updated Thermal Rating: on transformer 23505-23513 : Rate B, Rate C - 0.0, 0.0 -> 772.06, 772.06
% INFO    : Updated Thermal Rating: on transformer 23507-23506 : Rate B, Rate C - 0.0, 0.0 -> 395.47, 395.47
% INFO    : Updated Thermal Rating: on transformer 23506-23509 : Rate B, Rate C - 0.0, 0.0 -> 1437.93, 1437.93
% INFO    : Updated Thermal Rating: on line 23506-28759 : Rate B, Rate C - 0.0, 0.0 -> 1121.54, 1121.54
% INFO    : Updated Thermal Rating: on line 23506-30125 : Rate B, Rate C - 0.0, 0.0 -> 1136.11, 1136.11
% INFO    : Updated Thermal Rating: on line 23507-28645 : Rate B, Rate C - 0.0, 0.0 -> 222.13, 222.13
% INFO    : Updated Thermal Rating: on line 23507-28716 : Rate B, Rate C - 0.0, 0.0 -> 201.52, 201.52
% INFO    : Updated Thermal Rating: on line 28891-23507 : Rate B, Rate C - 0.0, 0.0 -> 225.0, 225.0
% INFO    : Updated Thermal Rating: on line 23507-30180 : Rate B, Rate C - 0.0, 0.0 -> 253.42, 253.42
% INFO    : Updated Thermal Rating: on transformer 23508-23509 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 23514-28758 : Rate B, Rate C - 0.0, 0.0 -> 4085.13, 4085.13
% INFO    : Updated Thermal Rating: on line 23514-30399 : Rate B, Rate C - 0.0, 0.0 -> 4036.16, 4036.16
% INFO    : Updated Thermal Rating: on line 25000-25007 : Rate B, Rate C - 0.0, 0.0 -> 197.21, 197.21
% INFO    : Updated Thermal Rating: on line 25001-25002 : Rate B, Rate C - 0.0, 0.0 -> 178.2, 178.2
% INFO    : Updated Thermal Rating: on line 25002-25003 : Rate B, Rate C - 0.0, 0.0 -> 190.76, 190.76
% INFO    : Updated Thermal Rating: on line 25015-25003 : Rate B, Rate C - 0.0, 0.0 -> 171.75, 171.75
% INFO    : Updated Thermal Rating: on transformer 25005-25004 : Rate B, Rate C - 0.0, 0.0 -> 423.48, 423.48
% INFO    : Updated Thermal Rating: on line 25004-25009 : Rate B, Rate C - 0.0, 0.0 -> 1100.79, 1100.79
% INFO    : Updated Thermal Rating: on line 25030-25004 : Rate B, Rate C - 0.0, 0.0 -> 1189.55, 1189.55
% INFO    : Updated Thermal Rating: on line 25004-26136 : Rate B, Rate C - 0.0, 0.0 -> 1216.57, 1216.57
% INFO    : Updated Thermal Rating: on line 25016-25005 : Rate B, Rate C - 0.0, 0.0 -> 209.34, 209.34
% INFO    : Updated Thermal Rating: on line 25005-25024 : Rate B, Rate C - 0.0, 0.0 -> 226.22, 226.22
% INFO    : Updated Thermal Rating: on line 25026-25007 : Rate B, Rate C - 0.0, 0.0 -> 212.63, 212.63
% INFO    : Updated Thermal Rating: on line 25007-26132 : Rate B, Rate C - 0.0, 0.0 -> 223.2, 223.2
% INFO    : Updated Thermal Rating: on line 25010-25008 : Rate B, Rate C - 0.0, 0.0 -> 201.76, 201.76
% INFO    : Updated Thermal Rating: on transformer 25009-25012 : Rate B, Rate C - 0.0, 0.0 -> 479.1, 479.1
% INFO    : Updated Thermal Rating: on transformer 25010-25012 : Rate B, Rate C - 0.0, 0.0 -> 404.1, 404.1
% INFO    : Updated Thermal Rating: on line 25010-25015 : Rate B, Rate C - 0.0, 0.0 -> 212.94, 212.94
% INFO    : Updated Thermal Rating: on transformer 25011-25012 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 25026-25016 : Rate B, Rate C - 0.0, 0.0 -> 164.75, 164.75
% INFO    : Updated Thermal Rating: on line 25018-25026 : Rate B, Rate C - 0.0, 0.0 -> 219.67, 219.67
% INFO    : Updated Thermal Rating: on line 26132-25018 : Rate B, Rate C - 0.0, 0.0 -> 228.79, 228.79
% INFO    : Updated Thermal Rating: on transformer 25019-25022 : Rate B, Rate C - 0.0, 0.0 -> 102.15, 102.15
% INFO    : Updated Thermal Rating: on line 25019-25026 : Rate B, Rate C - 0.0, 0.0 -> 226.54, 226.54
% INFO    : Updated Thermal Rating: on line 25037-25019 : Rate B, Rate C - 0.0, 0.0 -> 211.69, 211.69
% INFO    : Updated Thermal Rating: on transformer 25020-25022 : Rate B, Rate C - 0.0, 0.0 -> 51.07, 51.07
% INFO    : Updated Thermal Rating: on transformer 25021-25022 : Rate B, Rate C - 0.0, 0.0 -> 51.07, 51.07
% INFO    : Updated Thermal Rating: on line 25037-25024 : Rate B, Rate C - 0.0, 0.0 -> 209.16, 209.16
% INFO    : Updated Thermal Rating: on line 25032-25027 : Rate B, Rate C - 0.0, 0.0 -> 160.44, 160.44
% INFO    : Updated Thermal Rating: on line 25027-25046 : Rate B, Rate C - 0.0, 0.0 -> 198.19, 198.19
% INFO    : Updated Thermal Rating: on line 25028-25032 : Rate B, Rate C - 0.0, 0.0 -> 195.69, 195.69
% INFO    : Updated Thermal Rating: on line 25028-25045 : Rate B, Rate C - 0.0, 0.0 -> 200.16, 200.16
% INFO    : Updated Thermal Rating: on transformer 25031-25030 : Rate B, Rate C - 0.0, 0.0 -> 461.63, 461.63
% INFO    : Updated Thermal Rating: on line 25048-25030 : Rate B, Rate C - 0.0, 0.0 -> 1293.11, 1293.11
% INFO    : Updated Thermal Rating: on line 26136-25030 : Rate B, Rate C - 0.0, 0.0 -> 1268.43, 1268.43
% INFO    : Updated Thermal Rating: on line 25038-25031 : Rate B, Rate C - 0.0, 0.0 -> 235.1, 235.1
% INFO    : Updated Thermal Rating: on line 25031-25039 : Rate B, Rate C - 0.0, 0.0 -> 219.91, 219.91
% INFO    : Updated Thermal Rating: on line 25032-26132 : Rate B, Rate C - 0.0, 0.0 -> 236.73, 236.73
% INFO    : Updated Thermal Rating: on line 25037-25034 : Rate B, Rate C - 0.0, 0.0 -> 205.45, 205.45
% INFO    : Updated Thermal Rating: on line 25034-26144 : Rate B, Rate C - 0.0, 0.0 -> 226.62, 226.62
% INFO    : Updated Thermal Rating: on line 25037-25043 : Rate B, Rate C - 0.0, 0.0 -> 231.86, 231.86
% INFO    : Updated Thermal Rating: on line 25040-25038 : Rate B, Rate C - 0.0, 0.0 -> 210.25, 210.25
% INFO    : Updated Thermal Rating: on line 25044-25039 : Rate B, Rate C - 0.0, 0.0 -> 178.36, 178.36
% INFO    : Updated Thermal Rating: on line 25040-25043 : Rate B, Rate C - 0.0, 0.0 -> 197.2, 197.2
% INFO    : Updated Thermal Rating: on line 25047-25044 : Rate B, Rate C - 0.0, 0.0 -> 212.97, 212.97
% INFO    : Updated Thermal Rating: on line 25044-26168 : Rate B, Rate C - 0.0, 0.0 -> 229.24, 229.24
% INFO    : Updated Thermal Rating: on line 25045-25998 : Rate B, Rate C - 0.0, 0.0 -> 224.33, 224.33
% INFO    : Updated Thermal Rating: on line 25047-25046 : Rate B, Rate C - 0.0, 0.0 -> 191.16, 191.16
% INFO    : Updated Thermal Rating: on line 25049-25046 : Rate B, Rate C - 0.0, 0.0 -> 173.6, 173.6
% INFO    : Updated Thermal Rating: on line 25055-25047 : Rate B, Rate C - 0.0, 0.0 -> 202.64, 202.64
% INFO    : Updated Thermal Rating: on transformer 25048-25051 : Rate B, Rate C - 0.0, 0.0 -> 445.09, 445.09
% INFO    : Updated Thermal Rating: on line 25048-25059 : Rate B, Rate C - 0.0, 0.0 -> 1233.41, 1233.41
% INFO    : Updated Thermal Rating: on transformer 25049-25051 : Rate B, Rate C - 0.0, 0.0 -> 395.09, 395.09
% INFO    : Updated Thermal Rating: on line 25052-25049 : Rate B, Rate C - 0.0, 0.0 -> 205.97, 205.97
% INFO    : Updated Thermal Rating: on transformer 25050-25051 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 25983-25052 : Rate B, Rate C - 0.0, 0.0 -> 201.65, 201.65
% INFO    : Updated Thermal Rating: on line 25057-25053 : Rate B, Rate C - 0.0, 0.0 -> 220.23, 220.23
% INFO    : Updated Thermal Rating: on line 25053-25058 : Rate B, Rate C - 0.0, 0.0 -> 245.92, 245.92
% INFO    : Updated Thermal Rating: on line 25063-25053 : Rate B, Rate C - 0.0, 0.0 -> 248.98, 248.98
% INFO    : Updated Thermal Rating: on line 25053-25115 : Rate B, Rate C - 0.0, 0.0 -> 265.0, 265.0
% INFO    : Updated Thermal Rating: on line 25056-25882 : Rate B, Rate C - 0.0, 0.0 -> 163.13, 163.13
% INFO    : Updated Thermal Rating: on line 25056-25983 : Rate B, Rate C - 0.0, 0.0 -> 207.67, 207.67
% INFO    : Updated Thermal Rating: on line 25065-25057 : Rate B, Rate C - 0.0, 0.0 -> 197.23, 197.23
% INFO    : Updated Thermal Rating: on line 25058-25060 : Rate B, Rate C - 0.0, 0.0 -> 262.76, 262.76
% INFO    : Updated Thermal Rating: on transformer 25059-25062 : Rate B, Rate C - 0.0, 0.0 -> 615.8, 615.8
% INFO    : Updated Thermal Rating: on line 25064-25059 : Rate B, Rate C - 0.0, 0.0 -> 1247.55, 1247.55
% INFO    : Updated Thermal Rating: on line 25848-25059 : Rate B, Rate C - 0.0, 0.0 -> 1229.56, 1229.56
% INFO    : Updated Thermal Rating: on transformer 25060-25062 : Rate B, Rate C - 0.0, 0.0 -> 515.8, 515.8
% INFO    : Updated Thermal Rating: on line 25060-25063 : Rate B, Rate C - 0.0, 0.0 -> 264.3, 264.3
% INFO    : Updated Thermal Rating: on line 25882-25060 : Rate B, Rate C - 0.0, 0.0 -> 226.48, 226.48
% INFO    : Updated Thermal Rating: on transformer 25061-25062 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 25065-25064 : Rate B, Rate C - 0.0, 0.0 -> 411.93, 411.93
% INFO    : Updated Thermal Rating: on line 25064-26005 : Rate B, Rate C - 0.0, 0.0 -> 1172.93, 1172.93
% INFO    : Updated Thermal Rating: on line 25065-25073 : Rate B, Rate C - 0.0, 0.0 -> 200.75, 200.75
% INFO    : Updated Thermal Rating: on line 25065-25074 : Rate B, Rate C - 0.0, 0.0 -> 245.1, 245.1
% INFO    : Updated Thermal Rating: on line 25066-25069 : Rate B, Rate C - 0.0, 0.0 -> 221.06, 221.06
% INFO    : Updated Thermal Rating: on line 25066-25127 : Rate B, Rate C - 0.0, 0.0 -> 203.3, 203.3
% INFO    : Updated Thermal Rating: on line 25913-25069 : Rate B, Rate C - 0.0, 0.0 -> 234.14, 234.14
% INFO    : Updated Thermal Rating: on line 25072-26162 : Rate B, Rate C - 0.0, 0.0 -> 199.03, 199.03
% INFO    : Updated Thermal Rating: on line 26185-25072 : Rate B, Rate C - 0.0, 0.0 -> 191.2, 191.2
% INFO    : Updated Thermal Rating: on line 25079-25073 : Rate B, Rate C - 0.0, 0.0 -> 227.03, 227.03
% INFO    : Updated Thermal Rating: on line 25084-25074 : Rate B, Rate C - 0.0, 0.0 -> 241.08, 241.08
% INFO    : Updated Thermal Rating: on line 25088-25076 : Rate B, Rate C - 0.0, 0.0 -> 155.0, 155.0
% INFO    : Updated Thermal Rating: on line 25076-25959 : Rate B, Rate C - 0.0, 0.0 -> 177.57, 177.57
% INFO    : Updated Thermal Rating: on line 25111-25078 : Rate B, Rate C - 0.0, 0.0 -> 196.7, 196.7
% INFO    : Updated Thermal Rating: on line 26154-25078 : Rate B, Rate C - 0.0, 0.0 -> 226.57, 226.57
% INFO    : Updated Thermal Rating: on line 25079-26072 : Rate B, Rate C - 0.0, 0.0 -> 231.48, 231.48
% INFO    : Updated Thermal Rating: on line 25089-25080 : Rate B, Rate C - 0.0, 0.0 -> 214.19, 214.19
% INFO    : Updated Thermal Rating: on line 25107-25080 : Rate B, Rate C - 0.0, 0.0 -> 229.93, 229.93
% INFO    : Updated Thermal Rating: on line 25080-25841 : Rate B, Rate C - 0.0, 0.0 -> 222.88, 222.88
% INFO    : Updated Thermal Rating: on line 25097-25083 : Rate B, Rate C - 0.0, 0.0 -> 234.7, 234.7
% INFO    : Updated Thermal Rating: on line 25083-25114 : Rate B, Rate C - 0.0, 0.0 -> 207.83, 207.83
% INFO    : Updated Thermal Rating: on line 25114-25084 : Rate B, Rate C - 0.0, 0.0 -> 217.39, 217.39
% INFO    : Updated Thermal Rating: on line 26091-25086 : Rate B, Rate C - 0.0, 0.0 -> 234.73, 234.73
% INFO    : Updated Thermal Rating: on line 25087-25943 : Rate B, Rate C - 0.0, 0.0 -> 198.67, 198.67
% INFO    : Updated Thermal Rating: on line 25088-26091 : Rate B, Rate C - 0.0, 0.0 -> 203.48, 203.48
% INFO    : Updated Thermal Rating: on line 26037-25089 : Rate B, Rate C - 0.0, 0.0 -> 235.72, 235.72
% INFO    : Updated Thermal Rating: on line 25099-25090 : Rate B, Rate C - 0.0, 0.0 -> 234.85, 234.85
% INFO    : Updated Thermal Rating: on line 25090-25116 : Rate B, Rate C - 0.0, 0.0 -> 214.5, 214.5
% INFO    : Updated Thermal Rating: on line 25091-25123 : Rate B, Rate C - 0.0, 0.0 -> 208.73, 208.73
% INFO    : Updated Thermal Rating: on line 25091-25918 : Rate B, Rate C - 0.0, 0.0 -> 211.69, 211.69
% INFO    : Updated Thermal Rating: on line 25091-25959 : Rate B, Rate C - 0.0, 0.0 -> 246.24, 246.24
% INFO    : Updated Thermal Rating: on line 25143-25094 : Rate B, Rate C - 0.0, 0.0 -> 213.03, 213.03
% INFO    : Updated Thermal Rating: on line 25094-26218 : Rate B, Rate C - 0.0, 0.0 -> 233.87, 233.87
% INFO    : Updated Thermal Rating: on line 25096-25107 : Rate B, Rate C - 0.0, 0.0 -> 190.9, 190.9
% INFO    : Updated Thermal Rating: on line 25096-25157 : Rate B, Rate C - 0.0, 0.0 -> 223.97, 223.97
% INFO    : Updated Thermal Rating: on line 25826-25096 : Rate B, Rate C - 0.0, 0.0 -> 255.11, 255.11
% INFO    : Updated Thermal Rating: on line 25097-25115 : Rate B, Rate C - 0.0, 0.0 -> 195.41, 195.41
% INFO    : Updated Thermal Rating: on line 25097-25893 : Rate B, Rate C - 0.0, 0.0 -> 250.36, 250.36
% INFO    : Updated Thermal Rating: on line 25099-25115 : Rate B, Rate C - 0.0, 0.0 -> 237.75, 237.75
% INFO    : Updated Thermal Rating: on line 25099-25150 : Rate B, Rate C - 0.0, 0.0 -> 227.74, 227.74
% INFO    : Updated Thermal Rating: on line 25099-26006 : Rate B, Rate C - 0.0, 0.0 -> 237.74, 237.74
% INFO    : Updated Thermal Rating: on line 25102-25104 : Rate B, Rate C - 0.0, 0.0 -> 226.38, 226.38
% INFO    : Updated Thermal Rating: on line 25102-25113 : Rate B, Rate C - 0.0, 0.0 -> 204.18, 204.18
% INFO    : Updated Thermal Rating: on transformer 25104-25103 : Rate B, Rate C - 0.0, 0.0 -> 508.53, 508.53
% INFO    : Updated Thermal Rating: on line 25103-25156 : Rate B, Rate C - 0.0, 0.0 -> 1211.18, 1211.18
% INFO    : Updated Thermal Rating: on line 25103-26005 : Rate B, Rate C - 0.0, 0.0 -> 1200.39, 1200.39
% INFO    : Updated Thermal Rating: on line 25103-26036 : Rate B, Rate C - 0.0, 0.0 -> 1218.72, 1218.72
% INFO    : Updated Thermal Rating: on line 25104-25105 : Rate B, Rate C - 0.0, 0.0 -> 264.27, 264.27
% INFO    : Updated Thermal Rating: on line 25105-25130 : Rate B, Rate C - 0.0, 0.0 -> 238.72, 238.72
% INFO    : Updated Thermal Rating: on transformer 25109-25108 : Rate B, Rate C - 0.0, 0.0 -> 393.86, 393.86
% INFO    : Updated Thermal Rating: on line 25138-25108 : Rate B, Rate C - 0.0, 0.0 -> 1073.88, 1073.88
% INFO    : Updated Thermal Rating: on line 25108-26153 : Rate B, Rate C - 0.0, 0.0 -> 1197.36, 1197.36
% INFO    : Updated Thermal Rating: on line 25109-25111 : Rate B, Rate C - 0.0, 0.0 -> 212.31, 212.31
% INFO    : Updated Thermal Rating: on line 25133-25109 : Rate B, Rate C - 0.0, 0.0 -> 220.39, 220.39
% INFO    : Updated Thermal Rating: on line 25112-25152 : Rate B, Rate C - 0.0, 0.0 -> 207.84, 207.84
% INFO    : Updated Thermal Rating: on line 25112-25202 : Rate B, Rate C - 0.0, 0.0 -> 191.2, 191.2
% INFO    : Updated Thermal Rating: on line 25113-25114 : Rate B, Rate C - 0.0, 0.0 -> 174.2, 174.2
% INFO    : Updated Thermal Rating: on line 25114-25146 : Rate B, Rate C - 0.0, 0.0 -> 212.0, 212.0
% INFO    : Updated Thermal Rating: on line 25135-25116 : Rate B, Rate C - 0.0, 0.0 -> 219.85, 219.85
% INFO    : Updated Thermal Rating: on line 25163-25116 : Rate B, Rate C - 0.0, 0.0 -> 219.3, 219.3
% INFO    : Updated Thermal Rating: on line 25127-25117 : Rate B, Rate C - 0.0, 0.0 -> 232.48, 232.48
% INFO    : Updated Thermal Rating: on line 25117-25915 : Rate B, Rate C - 0.0, 0.0 -> 221.02, 221.02
% INFO    : Updated Thermal Rating: on line 25117-26009 : Rate B, Rate C - 0.0, 0.0 -> 234.36, 234.36
% INFO    : Updated Thermal Rating: on line 25120-25127 : Rate B, Rate C - 0.0, 0.0 -> 227.36, 227.36
% INFO    : Updated Thermal Rating: on line 25128-25120 : Rate B, Rate C - 0.0, 0.0 -> 177.43, 177.43
% INFO    : Updated Thermal Rating: on line 25121-25141 : Rate B, Rate C - 0.0, 0.0 -> 231.86, 231.86
% INFO    : Updated Thermal Rating: on line 25121-25143 : Rate B, Rate C - 0.0, 0.0 -> 248.49, 248.49
% INFO    : Updated Thermal Rating: on line 25123-25143 : Rate B, Rate C - 0.0, 0.0 -> 183.66, 183.66
% INFO    : Updated Thermal Rating: on line 25125-25141 : Rate B, Rate C - 0.0, 0.0 -> 211.69, 211.69
% INFO    : Updated Thermal Rating: on line 25125-25146 : Rate B, Rate C - 0.0, 0.0 -> 232.19, 232.19
% INFO    : Updated Thermal Rating: on line 25125-25903 : Rate B, Rate C - 0.0, 0.0 -> 223.65, 223.65
% INFO    : Updated Thermal Rating: on line 25127-25133 : Rate B, Rate C - 0.0, 0.0 -> 185.75, 185.75
% INFO    : Updated Thermal Rating: on line 25839-25128 : Rate B, Rate C - 0.0, 0.0 -> 215.86, 215.86
% INFO    : Updated Thermal Rating: on line 25130-25131 : Rate B, Rate C - 0.0, 0.0 -> 222.72, 222.72
% INFO    : Updated Thermal Rating: on line 25131-25150 : Rate B, Rate C - 0.0, 0.0 -> 206.31, 206.31
% INFO    : Updated Thermal Rating: on line 25177-25131 : Rate B, Rate C - 0.0, 0.0 -> 221.22, 221.22
% INFO    : Updated Thermal Rating: on line 25132-25139 : Rate B, Rate C - 0.0, 0.0 -> 200.9, 200.9
% INFO    : Updated Thermal Rating: on line 25132-25144 : Rate B, Rate C - 0.0, 0.0 -> 192.37, 192.37
% INFO    : Updated Thermal Rating: on line 25135-25188 : Rate B, Rate C - 0.0, 0.0 -> 276.63, 276.63
% INFO    : Updated Thermal Rating: on line 25135-25188 : Rate B, Rate C - 0.0, 0.0 -> 276.63, 276.63
% INFO    : Updated Thermal Rating: on line 25135-25188 : Rate B, Rate C - 0.0, 0.0 -> 276.63, 276.63
% INFO    : Updated Thermal Rating: on line 25135-26006 : Rate B, Rate C - 0.0, 0.0 -> 289.14, 289.14
% INFO    : Updated Thermal Rating: on line 25135-26006 : Rate B, Rate C - 0.0, 0.0 -> 289.14, 289.14
% INFO    : Updated Thermal Rating: on line 25135-26006 : Rate B, Rate C - 0.0, 0.0 -> 289.14, 289.14
% INFO    : Updated Thermal Rating: on line 25152-25137 : Rate B, Rate C - 0.0, 0.0 -> 232.04, 232.04
% INFO    : Updated Thermal Rating: on line 25137-25826 : Rate B, Rate C - 0.0, 0.0 -> 248.31, 248.31
% INFO    : Updated Thermal Rating: on transformer 25139-25138 : Rate B, Rate C - 0.0, 0.0 -> 384.88, 384.88
% INFO    : Updated Thermal Rating: on line 25142-25138 : Rate B, Rate C - 0.0, 0.0 -> 1126.83, 1126.83
% INFO    : Updated Thermal Rating: on line 25168-25138 : Rate B, Rate C - 0.0, 0.0 -> 1057.69, 1057.69
% INFO    : Updated Thermal Rating: on line 25138-26057 : Rate B, Rate C - 0.0, 0.0 -> 1167.64, 1167.64
% INFO    : Updated Thermal Rating: on line 25162-25141 : Rate B, Rate C - 0.0, 0.0 -> 198.66, 198.66
% INFO    : Updated Thermal Rating: on transformer 25143-25142 : Rate B, Rate C - 0.0, 0.0 -> 432.0, 432.0
% INFO    : Updated Thermal Rating: on line 25142-25902 : Rate B, Rate C - 0.0, 0.0 -> 1221.1, 1221.1
% INFO    : Updated Thermal Rating: on line 25142-26049 : Rate B, Rate C - 0.0, 0.0 -> 1225.42, 1225.42
% INFO    : Updated Thermal Rating: on line 25144-25169 : Rate B, Rate C - 0.0, 0.0 -> 184.41, 184.41
% INFO    : Updated Thermal Rating: on line 25144-25890 : Rate B, Rate C - 0.0, 0.0 -> 225.29, 225.29
% INFO    : Updated Thermal Rating: on line 25148-25146 : Rate B, Rate C - 0.0, 0.0 -> 233.36, 233.36
% INFO    : Updated Thermal Rating: on line 25182-25148 : Rate B, Rate C - 0.0, 0.0 -> 216.31, 216.31
% INFO    : Updated Thermal Rating: on line 25154-25177 : Rate B, Rate C - 0.0, 0.0 -> 204.01, 204.01
% INFO    : Updated Thermal Rating: on line 25154-25179 : Rate B, Rate C - 0.0, 0.0 -> 193.12, 193.12
% INFO    : Updated Thermal Rating: on transformer 25156-25159 : Rate B, Rate C - 0.0, 0.0 -> 558.72, 558.72
% INFO    : Updated Thermal Rating: on line 25156-25196 : Rate B, Rate C - 0.0, 0.0 -> 1035.43, 1035.43
% INFO    : Updated Thermal Rating: on transformer 25157-25159 : Rate B, Rate C - 0.0, 0.0 -> 483.72, 483.72
% INFO    : Updated Thermal Rating: on line 25176-25157 : Rate B, Rate C - 0.0, 0.0 -> 276.04, 276.04
% INFO    : Updated Thermal Rating: on line 25176-25157 : Rate B, Rate C - 0.0, 0.0 -> 276.04, 276.04
% INFO    : Updated Thermal Rating: on transformer 25158-25159 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 25258-25160 : Rate B, Rate C - 0.0, 0.0 -> 178.0, 178.0
% INFO    : Updated Thermal Rating: on line 25160-25339 : Rate B, Rate C - 0.0, 0.0 -> 205.42, 205.42
% INFO    : Updated Thermal Rating: on line 25918-25162 : Rate B, Rate C - 0.0, 0.0 -> 226.05, 226.05
% INFO    : Updated Thermal Rating: on line 25163-25221 : Rate B, Rate C - 0.0, 0.0 -> 189.28, 189.28
% INFO    : Updated Thermal Rating: on line 25172-25164 : Rate B, Rate C - 0.0, 0.0 -> 233.1, 233.1
% INFO    : Updated Thermal Rating: on line 25164-25175 : Rate B, Rate C - 0.0, 0.0 -> 216.4, 216.4
% INFO    : Updated Thermal Rating: on line 25198-25164 : Rate B, Rate C - 0.0, 0.0 -> 231.66, 231.66
% INFO    : Updated Thermal Rating: on line 25165-25166 : Rate B, Rate C - 0.0, 0.0 -> 209.2, 209.2
% INFO    : Updated Thermal Rating: on line 25269-25166 : Rate B, Rate C - 0.0, 0.0 -> 237.74, 237.74
% INFO    : Updated Thermal Rating: on transformer 25169-25168 : Rate B, Rate C - 0.0, 0.0 -> 362.23, 362.23
% INFO    : Updated Thermal Rating: on line 25170-25910 : Rate B, Rate C - 0.0, 0.0 -> 208.77, 208.77
% INFO    : Updated Thermal Rating: on line 25170-26034 : Rate B, Rate C - 0.0, 0.0 -> 206.97, 206.97
% INFO    : Updated Thermal Rating: on line 25172-25212 : Rate B, Rate C - 0.0, 0.0 -> 176.67, 176.67
% INFO    : Updated Thermal Rating: on line 25182-25175 : Rate B, Rate C - 0.0, 0.0 -> 193.98, 193.98
% INFO    : Updated Thermal Rating: on line 25175-26084 : Rate B, Rate C - 0.0, 0.0 -> 257.13, 257.13
% INFO    : Updated Thermal Rating: on line 25179-25176 : Rate B, Rate C - 0.0, 0.0 -> 241.08, 241.08
% INFO    : Updated Thermal Rating: on line 25176-25187 : Rate B, Rate C - 0.0, 0.0 -> 248.84, 248.84
% INFO    : Updated Thermal Rating: on line 25179-25208 : Rate B, Rate C - 0.0, 0.0 -> 222.25, 222.25
% INFO    : Updated Thermal Rating: on line 25180-25181 : Rate B, Rate C - 0.0, 0.0 -> 228.13, 228.13
% INFO    : Updated Thermal Rating: on line 25180-25192 : Rate B, Rate C - 0.0, 0.0 -> 193.82, 193.82
% INFO    : Updated Thermal Rating: on line 25180-25216 : Rate B, Rate C - 0.0, 0.0 -> 222.26, 222.26
% INFO    : Updated Thermal Rating: on line 26196-25181 : Rate B, Rate C - 0.0, 0.0 -> 241.27, 241.27
% INFO    : Updated Thermal Rating: on transformer 25185-25184 : Rate B, Rate C - 0.0, 0.0 -> 503.8, 503.8
% INFO    : Updated Thermal Rating: on line 25196-25184 : Rate B, Rate C - 0.0, 0.0 -> 1189.0, 1189.0
% INFO    : Updated Thermal Rating: on line 25199-25184 : Rate B, Rate C - 0.0, 0.0 -> 1188.56, 1188.56
% INFO    : Updated Thermal Rating: on line 25184-25902 : Rate B, Rate C - 0.0, 0.0 -> 1271.29, 1271.29
% INFO    : Updated Thermal Rating: on line 25184-26195 : Rate B, Rate C - 0.0, 0.0 -> 1309.35, 1309.35
% INFO    : Updated Thermal Rating: on line 25185-25193 : Rate B, Rate C - 0.0, 0.0 -> 250.17, 250.17
% INFO    : Updated Thermal Rating: on line 25205-25185 : Rate B, Rate C - 0.0, 0.0 -> 243.7, 243.7
% INFO    : Updated Thermal Rating: on line 25187-25300 : Rate B, Rate C - 0.0, 0.0 -> 238.86, 238.86
% INFO    : Updated Thermal Rating: on line 25189-25188 : Rate B, Rate C - 0.0, 0.0 -> 261.19, 261.19
% INFO    : Updated Thermal Rating: on line 25202-25188 : Rate B, Rate C - 0.0, 0.0 -> 245.86, 245.86
% INFO    : Updated Thermal Rating: on line 25202-25189 : Rate B, Rate C - 0.0, 0.0 -> 222.11, 222.11
% INFO    : Updated Thermal Rating: on line 25189-25210 : Rate B, Rate C - 0.0, 0.0 -> 237.09, 237.09
% INFO    : Updated Thermal Rating: on line 25189-25212 : Rate B, Rate C - 0.0, 0.0 -> 212.26, 212.26
% INFO    : Updated Thermal Rating: on line 25221-25189 : Rate B, Rate C - 0.0, 0.0 -> 195.35, 195.35
% INFO    : Updated Thermal Rating: on line 25203-25191 : Rate B, Rate C - 0.0, 0.0 -> 189.96, 189.96
% INFO    : Updated Thermal Rating: on line 25191-25235 : Rate B, Rate C - 0.0, 0.0 -> 204.15, 204.15
% INFO    : Updated Thermal Rating: on line 26196-25192 : Rate B, Rate C - 0.0, 0.0 -> 219.98, 219.98
% INFO    : Updated Thermal Rating: on line 25193-25252 : Rate B, Rate C - 0.0, 0.0 -> 239.07, 239.07
% INFO    : Updated Thermal Rating: on transformer 25195-25194 : Rate B, Rate C - 0.0, 0.0 -> 543.13, 543.13
% INFO    : Updated Thermal Rating: on line 25195-25220 : Rate B, Rate C - 0.0, 0.0 -> 243.71, 243.71
% INFO    : Updated Thermal Rating: on line 25222-25195 : Rate B, Rate C - 0.0, 0.0 -> 244.48, 244.48
% INFO    : Updated Thermal Rating: on line 25195-25253 : Rate B, Rate C - 0.0, 0.0 -> 225.78, 225.78
% INFO    : Updated Thermal Rating: on line 25196-25483 : Rate B, Rate C - 0.0, 0.0 -> 1250.89, 1250.89
% INFO    : Updated Thermal Rating: on line 25196-26195 : Rate B, Rate C - 0.0, 0.0 -> 1288.39, 1288.39
% INFO    : Updated Thermal Rating: on transformer 25198-25197 : Rate B, Rate C - 0.0, 0.0 -> 485.09, 485.09
% INFO    : Updated Thermal Rating: on line 25215-25198 : Rate B, Rate C - 0.0, 0.0 -> 232.75, 232.75
% INFO    : Updated Thermal Rating: on line 25223-25200 : Rate B, Rate C - 0.0, 0.0 -> 246.34, 246.34
% INFO    : Updated Thermal Rating: on line 25200-25243 : Rate B, Rate C - 0.0, 0.0 -> 231.83, 231.83
% INFO    : Updated Thermal Rating: on line 25253-25200 : Rate B, Rate C - 0.0, 0.0 -> 191.44, 191.44
% INFO    : Updated Thermal Rating: on line 25217-25203 : Rate B, Rate C - 0.0, 0.0 -> 244.91, 244.91
% INFO    : Updated Thermal Rating: on line 26207-25203 : Rate B, Rate C - 0.0, 0.0 -> 267.07, 267.07
% INFO    : Updated Thermal Rating: on line 25205-25216 : Rate B, Rate C - 0.0, 0.0 -> 227.03, 227.03
% INFO    : Updated Thermal Rating: on line 25206-25219 : Rate B, Rate C - 0.0, 0.0 -> 203.96, 203.96
% INFO    : Updated Thermal Rating: on line 25206-25244 : Rate B, Rate C - 0.0, 0.0 -> 158.65, 158.65
% INFO    : Updated Thermal Rating: on line 25208-25300 : Rate B, Rate C - 0.0, 0.0 -> 204.43, 204.43
% INFO    : Updated Thermal Rating: on line 25210-25232 : Rate B, Rate C - 0.0, 0.0 -> 225.5, 225.5
% INFO    : Updated Thermal Rating: on line 25215-25216 : Rate B, Rate C - 0.0, 0.0 -> 236.67, 236.67
% INFO    : Updated Thermal Rating: on line 25215-25223 : Rate B, Rate C - 0.0, 0.0 -> 246.37, 246.37
% INFO    : Updated Thermal Rating: on line 25217-25223 : Rate B, Rate C - 0.0, 0.0 -> 232.01, 232.01
% INFO    : Updated Thermal Rating: on line 25222-25219 : Rate B, Rate C - 0.0, 0.0 -> 222.51, 222.51
% INFO    : Updated Thermal Rating: on line 25220-25230 : Rate B, Rate C - 0.0, 0.0 -> 229.84, 229.84
% INFO    : Updated Thermal Rating: on line 25230-25227 : Rate B, Rate C - 0.0, 0.0 -> 198.52, 198.52
% INFO    : Updated Thermal Rating: on line 25231-25227 : Rate B, Rate C - 0.0, 0.0 -> 228.33, 228.33
% INFO    : Updated Thermal Rating: on line 25275-25228 : Rate B, Rate C - 0.0, 0.0 -> 243.82, 243.82
% INFO    : Updated Thermal Rating: on line 25228-25291 : Rate B, Rate C - 0.0, 0.0 -> 212.26, 212.26
% INFO    : Updated Thermal Rating: on line 25231-25322 : Rate B, Rate C - 0.0, 0.0 -> 241.02, 241.02
% INFO    : Updated Thermal Rating: on line 25244-25232 : Rate B, Rate C - 0.0, 0.0 -> 209.51, 209.51
% INFO    : Updated Thermal Rating: on line 25234-25306 : Rate B, Rate C - 0.0, 0.0 -> 235.88, 235.88
% INFO    : Updated Thermal Rating: on line 25234-25333 : Rate B, Rate C - 0.0, 0.0 -> 255.78, 255.78
% INFO    : Updated Thermal Rating: on line 25237-25235 : Rate B, Rate C - 0.0, 0.0 -> 245.66, 245.66
% INFO    : Updated Thermal Rating: on line 26221-25237 : Rate B, Rate C - 0.0, 0.0 -> 262.92, 262.92
% INFO    : Updated Thermal Rating: on line 25250-25238 : Rate B, Rate C - 0.0, 0.0 -> 269.48, 269.48
% INFO    : Updated Thermal Rating: on line 25238-25271 : Rate B, Rate C - 0.0, 0.0 -> 209.87, 209.87
% INFO    : Updated Thermal Rating: on line 25238-25944 : Rate B, Rate C - 0.0, 0.0 -> 275.39, 275.39
% INFO    : Updated Thermal Rating: on line 25238-25944 : Rate B, Rate C - 0.0, 0.0 -> 275.39, 275.39
% INFO    : Updated Thermal Rating: on line 25240-25967 : Rate B, Rate C - 0.0, 0.0 -> 211.16, 211.16
% INFO    : Updated Thermal Rating: on line 25241-26046 : Rate B, Rate C - 0.0, 0.0 -> 218.07, 218.07
% INFO    : Updated Thermal Rating: on line 25242-25303 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 25242-25365 : Rate B, Rate C - 0.0, 0.0 -> 221.97, 221.97
% INFO    : Updated Thermal Rating: on line 25325-25243 : Rate B, Rate C - 0.0, 0.0 -> 211.0, 211.0
% INFO    : Updated Thermal Rating: on line 25246-25299 : Rate B, Rate C - 0.0, 0.0 -> 212.35, 212.35
% INFO    : Updated Thermal Rating: on line 25246-25322 : Rate B, Rate C - 0.0, 0.0 -> 264.84, 264.84
% INFO    : Updated Thermal Rating: on line 25333-25246 : Rate B, Rate C - 0.0, 0.0 -> 266.91, 266.91
% INFO    : Updated Thermal Rating: on line 25247-25333 : Rate B, Rate C - 0.0, 0.0 -> 232.29, 232.29
% INFO    : Updated Thermal Rating: on line 25247-26105 : Rate B, Rate C - 0.0, 0.0 -> 254.74, 254.74
% INFO    : Updated Thermal Rating: on line 25249-25250 : Rate B, Rate C - 0.0, 0.0 -> 253.69, 253.69
% INFO    : Updated Thermal Rating: on line 25249-25306 : Rate B, Rate C - 0.0, 0.0 -> 239.39, 239.39
% INFO    : Updated Thermal Rating: on line 25252-25299 : Rate B, Rate C - 0.0, 0.0 -> 206.95, 206.95
% INFO    : Updated Thermal Rating: on line 25254-25330 : Rate B, Rate C - 0.0, 0.0 -> 237.48, 237.48
% INFO    : Updated Thermal Rating: on line 25254-25337 : Rate B, Rate C - 0.0, 0.0 -> 216.05, 216.05
% INFO    : Updated Thermal Rating: on line 25255-25293 : Rate B, Rate C - 0.0, 0.0 -> 222.54, 222.54
% INFO    : Updated Thermal Rating: on line 25255-25369 : Rate B, Rate C - 0.0, 0.0 -> 245.74, 245.74
% INFO    : Updated Thermal Rating: on line 25256-25363 : Rate B, Rate C - 0.0, 0.0 -> 246.0, 246.0
% INFO    : Updated Thermal Rating: on line 26033-25256 : Rate B, Rate C - 0.0, 0.0 -> 233.02, 233.02
% INFO    : Updated Thermal Rating: on line 26214-25256 : Rate B, Rate C - 0.0, 0.0 -> 231.99, 231.99
% INFO    : Updated Thermal Rating: on line 25258-25300 : Rate B, Rate C - 0.0, 0.0 -> 209.74, 209.74
% INFO    : Updated Thermal Rating: on line 25260-25290 : Rate B, Rate C - 0.0, 0.0 -> 243.54, 243.54
% INFO    : Updated Thermal Rating: on line 25260-25330 : Rate B, Rate C - 0.0, 0.0 -> 221.31, 221.31
% INFO    : Updated Thermal Rating: on transformer 25261-25264 : Rate B, Rate C - 0.0, 0.0 -> 102.09, 102.09
% INFO    : Updated Thermal Rating: on line 25261-25267 : Rate B, Rate C - 0.0, 0.0 -> 214.25, 214.25
% INFO    : Updated Thermal Rating: on line 25331-25261 : Rate B, Rate C - 0.0, 0.0 -> 179.37, 179.37
% INFO    : Updated Thermal Rating: on transformer 25262-25264 : Rate B, Rate C - 0.0, 0.0 -> 51.05, 51.05
% INFO    : Updated Thermal Rating: on transformer 25263-25264 : Rate B, Rate C - 0.0, 0.0 -> 51.05, 51.05
% INFO    : Updated Thermal Rating: on transformer 25267-25266 : Rate B, Rate C - 0.0, 0.0 -> 568.01, 568.01
% INFO    : Updated Thermal Rating: on line 25266-25334 : Rate B, Rate C - 0.0, 0.0 -> 1239.97, 1239.97
% INFO    : Updated Thermal Rating: on line 25266-25475 : Rate B, Rate C - 0.0, 0.0 -> 1207.91, 1207.91
% INFO    : Updated Thermal Rating: on line 25266-26126 : Rate B, Rate C - 0.0, 0.0 -> 1302.75, 1302.75
% INFO    : Updated Thermal Rating: on line 25326-25267 : Rate B, Rate C - 0.0, 0.0 -> 238.78, 238.78
% INFO    : Updated Thermal Rating: on line 25267-25381 : Rate B, Rate C - 0.0, 0.0 -> 216.48, 216.48
% INFO    : Updated Thermal Rating: on line 25414-25267 : Rate B, Rate C - 0.0, 0.0 -> 244.02, 244.02
% INFO    : Updated Thermal Rating: on line 25267-25423 : Rate B, Rate C - 0.0, 0.0 -> 243.05, 243.05
% INFO    : Updated Thermal Rating: on line 25269-26206 : Rate B, Rate C - 0.0, 0.0 -> 248.65, 248.65
% INFO    : Updated Thermal Rating: on line 25271-25349 : Rate B, Rate C - 0.0, 0.0 -> 163.92, 163.92
% INFO    : Updated Thermal Rating: on line 25274-25299 : Rate B, Rate C - 0.0, 0.0 -> 233.28, 233.28
% INFO    : Updated Thermal Rating: on line 25274-26196 : Rate B, Rate C - 0.0, 0.0 -> 246.88, 246.88
% INFO    : Updated Thermal Rating: on line 25275-26060 : Rate B, Rate C - 0.0, 0.0 -> 273.42, 273.42
% INFO    : Updated Thermal Rating: on line 25275-26060 : Rate B, Rate C - 0.0, 0.0 -> 273.42, 273.42
% INFO    : Updated Thermal Rating: on line 25288-25279 : Rate B, Rate C - 0.0, 0.0 -> 298.96, 298.96
% INFO    : Updated Thermal Rating: on line 25279-25362 : Rate B, Rate C - 0.0, 0.0 -> 258.16, 258.16
% INFO    : Updated Thermal Rating: on line 25283-25380 : Rate B, Rate C - 0.0, 0.0 -> 225.97, 225.97
% INFO    : Updated Thermal Rating: on line 25283-25383 : Rate B, Rate C - 0.0, 0.0 -> 202.8, 202.8
% INFO    : Updated Thermal Rating: on line 25446-25283 : Rate B, Rate C - 0.0, 0.0 -> 174.72, 174.72
% INFO    : Updated Thermal Rating: on line 25285-25348 : Rate B, Rate C - 0.0, 0.0 -> 226.46, 226.46
% INFO    : Updated Thermal Rating: on line 25285-26060 : Rate B, Rate C - 0.0, 0.0 -> 210.77, 210.77
% INFO    : Updated Thermal Rating: on transformer 25288-25287 : Rate B, Rate C - 0.0, 0.0 -> 495.54, 495.54
% INFO    : Updated Thermal Rating: on line 25287-25489 : Rate B, Rate C - 0.0, 0.0 -> 1220.5, 1220.5
% INFO    : Updated Thermal Rating: on line 26059-25287 : Rate B, Rate C - 0.0, 0.0 -> 1174.78, 1174.78
% INFO    : Updated Thermal Rating: on line 25287-26104 : Rate B, Rate C - 0.0, 0.0 -> 1217.4, 1217.4
% INFO    : Updated Thermal Rating: on line 26126-25287 : Rate B, Rate C - 0.0, 0.0 -> 1294.05, 1294.05
% INFO    : Updated Thermal Rating: on line 25287-26237 : Rate B, Rate C - 0.0, 0.0 -> 1181.7, 1181.7
% INFO    : Updated Thermal Rating: on line 25288-25330 : Rate B, Rate C - 0.0, 0.0 -> 226.09, 226.09
% INFO    : Updated Thermal Rating: on line 25308-25290 : Rate B, Rate C - 0.0, 0.0 -> 232.93, 232.93
% INFO    : Updated Thermal Rating: on line 25290-25310 : Rate B, Rate C - 0.0, 0.0 -> 287.31, 287.31
% INFO    : Updated Thermal Rating: on line 25290-25310 : Rate B, Rate C - 0.0, 0.0 -> 287.31, 287.31
% INFO    : Updated Thermal Rating: on line 25290-25310 : Rate B, Rate C - 0.0, 0.0 -> 287.31, 287.31
% INFO    : Updated Thermal Rating: on line 25290-25360 : Rate B, Rate C - 0.0, 0.0 -> 261.39, 261.39
% INFO    : Updated Thermal Rating: on line 25356-25291 : Rate B, Rate C - 0.0, 0.0 -> 181.67, 181.67
% INFO    : Updated Thermal Rating: on line 25365-25293 : Rate B, Rate C - 0.0, 0.0 -> 203.16, 203.16
% INFO    : Updated Thermal Rating: on line 25297-25381 : Rate B, Rate C - 0.0, 0.0 -> 177.22, 177.22
% INFO    : Updated Thermal Rating: on line 26027-25297 : Rate B, Rate C - 0.0, 0.0 -> 202.73, 202.73
% INFO    : Updated Thermal Rating: on line 25298-25306 : Rate B, Rate C - 0.0, 0.0 -> 232.23, 232.23
% INFO    : Updated Thermal Rating: on line 25298-25331 : Rate B, Rate C - 0.0, 0.0 -> 212.45, 212.45
% INFO    : Updated Thermal Rating: on line 25300-25329 : Rate B, Rate C - 0.0, 0.0 -> 195.46, 195.46
% INFO    : Updated Thermal Rating: on transformer 25303-25302 : Rate B, Rate C - 0.0, 0.0 -> 533.21, 533.21
% INFO    : Updated Thermal Rating: on line 25302-26213 : Rate B, Rate C - 0.0, 0.0 -> 1232.02, 1232.02
% INFO    : Updated Thermal Rating: on line 25303-25376 : Rate B, Rate C - 0.0, 0.0 -> 230.29, 230.29
% INFO    : Updated Thermal Rating: on line 25304-25402 : Rate B, Rate C - 0.0, 0.0 -> 229.84, 229.84
% INFO    : Updated Thermal Rating: on line 25304-25520 : Rate B, Rate C - 0.0, 0.0 -> 216.8, 216.8
% INFO    : Updated Thermal Rating: on line 25308-25341 : Rate B, Rate C - 0.0, 0.0 -> 208.01, 208.01
% INFO    : Updated Thermal Rating: on line 26060-25308 : Rate B, Rate C - 0.0, 0.0 -> 203.26, 203.26
% INFO    : Updated Thermal Rating: on transformer 25310-25309 : Rate B, Rate C - 0.0, 0.0 -> 632.16, 632.16
% INFO    : Updated Thermal Rating: on transformer 25310-25309 : Rate B, Rate C - 0.0, 0.0 -> 632.16, 632.16
% INFO    : Updated Thermal Rating: on transformer 25310-25309 : Rate B, Rate C - 0.0, 0.0 -> 632.16, 632.16
% INFO    : Updated Thermal Rating: on line 25309-25334 : Rate B, Rate C - 0.0, 0.0 -> 1127.18, 1127.18
% INFO    : Updated Thermal Rating: on line 25309-25990 : Rate B, Rate C - 0.0, 0.0 -> 1320.92, 1320.92
% INFO    : Updated Thermal Rating: on line 25309-26104 : Rate B, Rate C - 0.0, 0.0 -> 1234.38, 1234.38
% INFO    : Updated Thermal Rating: on line 25310-25348 : Rate B, Rate C - 0.0, 0.0 -> 244.21, 244.21
% INFO    : Updated Thermal Rating: on line 25310-25404 : Rate B, Rate C - 0.0, 0.0 -> 281.43, 281.43
% INFO    : Updated Thermal Rating: on line 25310-25404 : Rate B, Rate C - 0.0, 0.0 -> 281.43, 281.43
% INFO    : Updated Thermal Rating: on line 25310-25404 : Rate B, Rate C - 0.0, 0.0 -> 281.43, 281.43
% INFO    : Updated Thermal Rating: on line 25312-25353 : Rate B, Rate C - 0.0, 0.0 -> 294.07, 294.07
% INFO    : Updated Thermal Rating: on line 25312-25353 : Rate B, Rate C - 0.0, 0.0 -> 294.07, 294.07
% INFO    : Updated Thermal Rating: on line 25312-25353 : Rate B, Rate C - 0.0, 0.0 -> 294.07, 294.07
% INFO    : Updated Thermal Rating: on line 25515-25312 : Rate B, Rate C - 0.0, 0.0 -> 292.1, 292.1
% INFO    : Updated Thermal Rating: on line 25515-25312 : Rate B, Rate C - 0.0, 0.0 -> 292.1, 292.1
% INFO    : Updated Thermal Rating: on line 25515-25312 : Rate B, Rate C - 0.0, 0.0 -> 292.1, 292.1
% INFO    : Updated Thermal Rating: on line 25312-25712 : Rate B, Rate C - 0.0, 0.0 -> 260.36, 260.36
% INFO    : Updated Thermal Rating: on line 25312-26123 : Rate B, Rate C - 0.0, 0.0 -> 247.0, 247.0
% INFO    : Updated Thermal Rating: on line 25313-25363 : Rate B, Rate C - 0.0, 0.0 -> 216.64, 216.64
% INFO    : Updated Thermal Rating: on line 25470-25313 : Rate B, Rate C - 0.0, 0.0 -> 216.09, 216.09
% INFO    : Updated Thermal Rating: on line 25313-26016 : Rate B, Rate C - 0.0, 0.0 -> 254.41, 254.41
% INFO    : Updated Thermal Rating: on line 25316-25319 : Rate B, Rate C - 0.0, 0.0 -> 238.09, 238.09
% INFO    : Updated Thermal Rating: on line 25346-25316 : Rate B, Rate C - 0.0, 0.0 -> 220.34, 220.34
% INFO    : Updated Thermal Rating: on line 25319-25482 : Rate B, Rate C - 0.0, 0.0 -> 276.2, 276.2
% INFO    : Updated Thermal Rating: on line 25319-25482 : Rate B, Rate C - 0.0, 0.0 -> 276.2, 276.2
% INFO    : Updated Thermal Rating: on line 25319-25482 : Rate B, Rate C - 0.0, 0.0 -> 276.2, 276.2
% INFO    : Updated Thermal Rating: on line 25319-25500 : Rate B, Rate C - 0.0, 0.0 -> 256.39, 256.39
% INFO    : Updated Thermal Rating: on line 25321-25447 : Rate B, Rate C - 0.0, 0.0 -> 220.13, 220.13
% INFO    : Updated Thermal Rating: on line 25321-25459 : Rate B, Rate C - 0.0, 0.0 -> 237.06, 237.06
% INFO    : Updated Thermal Rating: on line 25325-25329 : Rate B, Rate C - 0.0, 0.0 -> 181.93, 181.93
% INFO    : Updated Thermal Rating: on line 25337-25325 : Rate B, Rate C - 0.0, 0.0 -> 197.26, 197.26
% INFO    : Updated Thermal Rating: on line 25329-25326 : Rate B, Rate C - 0.0, 0.0 -> 208.33, 208.33
% INFO    : Updated Thermal Rating: on line 25346-25327 : Rate B, Rate C - 0.0, 0.0 -> 227.58, 227.58
% INFO    : Updated Thermal Rating: on line 25327-25383 : Rate B, Rate C - 0.0, 0.0 -> 213.19, 213.19
% INFO    : Updated Thermal Rating: on line 25327-25417 : Rate B, Rate C - 0.0, 0.0 -> 207.95, 207.95
% INFO    : Updated Thermal Rating: on line 25328-25351 : Rate B, Rate C - 0.0, 0.0 -> 197.58, 197.58
% INFO    : Updated Thermal Rating: on line 25375-25328 : Rate B, Rate C - 0.0, 0.0 -> 176.25, 176.25
% INFO    : Updated Thermal Rating: on line 25328-25435 : Rate B, Rate C - 0.0, 0.0 -> 203.37, 203.37
% INFO    : Updated Thermal Rating: on line 26027-25329 : Rate B, Rate C - 0.0, 0.0 -> 179.33, 179.33
% INFO    : Updated Thermal Rating: on transformer 25333-25332 : Rate B, Rate C - 0.0, 0.0 -> 478.46, 478.46
% INFO    : Updated Thermal Rating: on line 26059-25334 : Rate B, Rate C - 0.0, 0.0 -> 992.53, 992.53
% INFO    : Updated Thermal Rating: on line 25334-26083 : Rate B, Rate C - 0.0, 0.0 -> 1250.07, 1250.07
% INFO    : Updated Thermal Rating: on line 25334-26195 : Rate B, Rate C - 0.0, 0.0 -> 1306.69, 1306.69
% INFO    : Updated Thermal Rating: on line 25338-25364 : Rate B, Rate C - 0.0, 0.0 -> 206.23, 206.23
% INFO    : Updated Thermal Rating: on line 26016-25338 : Rate B, Rate C - 0.0, 0.0 -> 228.25, 228.25
% INFO    : Updated Thermal Rating: on line 25368-25339 : Rate B, Rate C - 0.0, 0.0 -> 245.12, 245.12
% INFO    : Updated Thermal Rating: on line 25404-25341 : Rate B, Rate C - 0.0, 0.0 -> 205.15, 205.15
% INFO    : Updated Thermal Rating: on line 25360-25344 : Rate B, Rate C - 0.0, 0.0 -> 239.39, 239.39
% INFO    : Updated Thermal Rating: on line 25517-25344 : Rate B, Rate C - 0.0, 0.0 -> 207.45, 207.45
% INFO    : Updated Thermal Rating: on line 25518-25345 : Rate B, Rate C - 0.0, 0.0 -> 267.45, 267.45
% INFO    : Updated Thermal Rating: on line 25345-25664 : Rate B, Rate C - 0.0, 0.0 -> 243.14, 243.14
% INFO    : Updated Thermal Rating: on line 25346-25501 : Rate B, Rate C - 0.0, 0.0 -> 240.23, 240.23
% INFO    : Updated Thermal Rating: on line 25347-25356 : Rate B, Rate C - 0.0, 0.0 -> 218.45, 218.45
% INFO    : Updated Thermal Rating: on line 25412-25347 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on line 25347-25490 : Rate B, Rate C - 0.0, 0.0 -> 270.09, 270.09
% INFO    : Updated Thermal Rating: on line 25349-25514 : Rate B, Rate C - 0.0, 0.0 -> 211.84, 211.84
% INFO    : Updated Thermal Rating: on line 25351-26016 : Rate B, Rate C - 0.0, 0.0 -> 224.2, 224.2
% INFO    : Updated Thermal Rating: on line 25410-25352 : Rate B, Rate C - 0.0, 0.0 -> 162.29, 162.29
% INFO    : Updated Thermal Rating: on line 25352-25454 : Rate B, Rate C - 0.0, 0.0 -> 212.23, 212.23
% INFO    : Updated Thermal Rating: on line 25851-25353 : Rate B, Rate C - 0.0, 0.0 -> 237.52, 237.52
% INFO    : Updated Thermal Rating: on line 25353-25900 : Rate B, Rate C - 0.0, 0.0 -> 261.6, 261.6
% INFO    : Updated Thermal Rating: on line 25353-25935 : Rate B, Rate C - 0.0, 0.0 -> 279.56, 279.56
% INFO    : Updated Thermal Rating: on line 25353-25935 : Rate B, Rate C - 0.0, 0.0 -> 279.56, 279.56
% INFO    : Updated Thermal Rating: on line 25353-25935 : Rate B, Rate C - 0.0, 0.0 -> 279.56, 279.56
% INFO    : Updated Thermal Rating: on line 25355-25397 : Rate B, Rate C - 0.0, 0.0 -> 220.44, 220.44
% INFO    : Updated Thermal Rating: on line 25355-26151 : Rate B, Rate C - 0.0, 0.0 -> 199.84, 199.84
% INFO    : Updated Thermal Rating: on line 25356-25361 : Rate B, Rate C - 0.0, 0.0 -> 164.3, 164.3
% INFO    : Updated Thermal Rating: on line 25357-25486 : Rate B, Rate C - 0.0, 0.0 -> 247.56, 247.56
% INFO    : Updated Thermal Rating: on line 25361-25478 : Rate B, Rate C - 0.0, 0.0 -> 234.34, 234.34
% INFO    : Updated Thermal Rating: on line 25412-25362 : Rate B, Rate C - 0.0, 0.0 -> 210.49, 210.49
% INFO    : Updated Thermal Rating: on line 25363-25405 : Rate B, Rate C - 0.0, 0.0 -> 239.63, 239.63
% INFO    : Updated Thermal Rating: on line 25364-25376 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 26137-25364 : Rate B, Rate C - 0.0, 0.0 -> 218.56, 218.56
% INFO    : Updated Thermal Rating: on line 25399-25368 : Rate B, Rate C - 0.0, 0.0 -> 213.62, 213.62
% INFO    : Updated Thermal Rating: on line 25368-26214 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 25369-26214 : Rate B, Rate C - 0.0, 0.0 -> 266.32, 266.32
% INFO    : Updated Thermal Rating: on line 25400-25372 : Rate B, Rate C - 0.0, 0.0 -> 224.93, 224.93
% INFO    : Updated Thermal Rating: on line 25372-25418 : Rate B, Rate C - 0.0, 0.0 -> 215.61, 215.61
% INFO    : Updated Thermal Rating: on line 25372-25451 : Rate B, Rate C - 0.0, 0.0 -> 238.33, 238.33
% INFO    : Updated Thermal Rating: on line 25372-25457 : Rate B, Rate C - 0.0, 0.0 -> 263.92, 263.92
% INFO    : Updated Thermal Rating: on line 25374-25470 : Rate B, Rate C - 0.0, 0.0 -> 195.27, 195.27
% INFO    : Updated Thermal Rating: on line 25374-25590 : Rate B, Rate C - 0.0, 0.0 -> 236.56, 236.56
% INFO    : Updated Thermal Rating: on line 25374-26137 : Rate B, Rate C - 0.0, 0.0 -> 202.41, 202.41
% INFO    : Updated Thermal Rating: on line 25375-25530 : Rate B, Rate C - 0.0, 0.0 -> 243.97, 243.97
% INFO    : Updated Thermal Rating: on line 25378-25501 : Rate B, Rate C - 0.0, 0.0 -> 234.96, 234.96
% INFO    : Updated Thermal Rating: on line 25561-25378 : Rate B, Rate C - 0.0, 0.0 -> 195.72, 195.72
% INFO    : Updated Thermal Rating: on line 25380-25449 : Rate B, Rate C - 0.0, 0.0 -> 241.69, 241.69
% INFO    : Updated Thermal Rating: on line 25438-25382 : Rate B, Rate C - 0.0, 0.0 -> 230.47, 230.47
% INFO    : Updated Thermal Rating: on line 25382-25533 : Rate B, Rate C - 0.0, 0.0 -> 181.35, 181.35
% INFO    : Updated Thermal Rating: on line 25383-25431 : Rate B, Rate C - 0.0, 0.0 -> 226.97, 226.97
% INFO    : Updated Thermal Rating: on line 25500-25383 : Rate B, Rate C - 0.0, 0.0 -> 225.2, 225.2
% INFO    : Updated Thermal Rating: on line 25384-25937 : Rate B, Rate C - 0.0, 0.0 -> 232.33, 232.33
% INFO    : Updated Thermal Rating: on line 25384-26016 : Rate B, Rate C - 0.0, 0.0 -> 205.64, 205.64
% INFO    : Updated Thermal Rating: on line 25386-25407 : Rate B, Rate C - 0.0, 0.0 -> 209.13, 209.13
% INFO    : Updated Thermal Rating: on line 25386-26033 : Rate B, Rate C - 0.0, 0.0 -> 230.34, 230.34
% INFO    : Updated Thermal Rating: on line 25388-25435 : Rate B, Rate C - 0.0, 0.0 -> 221.01, 221.01
% INFO    : Updated Thermal Rating: on line 25388-25528 : Rate B, Rate C - 0.0, 0.0 -> 248.43, 248.43
% INFO    : Updated Thermal Rating: on line 25390-25396 : Rate B, Rate C - 0.0, 0.0 -> 243.01, 243.01
% INFO    : Updated Thermal Rating: on line 25390-25406 : Rate B, Rate C - 0.0, 0.0 -> 247.68, 247.68
% INFO    : Updated Thermal Rating: on line 25390-25418 : Rate B, Rate C - 0.0, 0.0 -> 238.34, 238.34
% INFO    : Updated Thermal Rating: on line 25490-25390 : Rate B, Rate C - 0.0, 0.0 -> 291.25, 291.25
% INFO    : Updated Thermal Rating: on line 25490-25390 : Rate B, Rate C - 0.0, 0.0 -> 291.25, 291.25
% INFO    : Updated Thermal Rating: on line 25490-25390 : Rate B, Rate C - 0.0, 0.0 -> 291.25, 291.25
% INFO    : Updated Thermal Rating: on line 25394-25527 : Rate B, Rate C - 0.0, 0.0 -> 262.32, 262.32
% INFO    : Updated Thermal Rating: on line 25394-25574 : Rate B, Rate C - 0.0, 0.0 -> 231.5, 231.5
% INFO    : Updated Thermal Rating: on line 25394-26238 : Rate B, Rate C - 0.0, 0.0 -> 241.2, 241.2
% INFO    : Updated Thermal Rating: on line 25396-25422 : Rate B, Rate C - 0.0, 0.0 -> 196.2, 196.2
% INFO    : Updated Thermal Rating: on line 25396-25446 : Rate B, Rate C - 0.0, 0.0 -> 220.43, 220.43
% INFO    : Updated Thermal Rating: on line 25397-25935 : Rate B, Rate C - 0.0, 0.0 -> 208.24, 208.24
% INFO    : Updated Thermal Rating: on line 25397-26236 : Rate B, Rate C - 0.0, 0.0 -> 222.63, 222.63
% INFO    : Updated Thermal Rating: on line 25399-25459 : Rate B, Rate C - 0.0, 0.0 -> 203.01, 203.01
% INFO    : Updated Thermal Rating: on line 25400-25490 : Rate B, Rate C - 0.0, 0.0 -> 268.75, 268.75
% INFO    : Updated Thermal Rating: on transformer 25402-25401 : Rate B, Rate C - 0.0, 0.0 -> 536.89, 536.89
% INFO    : Updated Thermal Rating: on line 25463-25401 : Rate B, Rate C - 0.0, 0.0 -> 985.91, 985.91
% INFO    : Updated Thermal Rating: on line 25401-25919 : Rate B, Rate C - 0.0, 0.0 -> 1312.12, 1312.12
% INFO    : Updated Thermal Rating: on line 25402-25407 : Rate B, Rate C - 0.0, 0.0 -> 254.6, 254.6
% INFO    : Updated Thermal Rating: on line 25501-25402 : Rate B, Rate C - 0.0, 0.0 -> 292.06, 292.06
% INFO    : Updated Thermal Rating: on line 25501-25402 : Rate B, Rate C - 0.0, 0.0 -> 292.06, 292.06
% INFO    : Updated Thermal Rating: on line 25501-25402 : Rate B, Rate C - 0.0, 0.0 -> 292.06, 292.06
% INFO    : Updated Thermal Rating: on line 25404-25537 : Rate B, Rate C - 0.0, 0.0 -> 231.97, 231.97
% INFO    : Updated Thermal Rating: on line 25404-25550 : Rate B, Rate C - 0.0, 0.0 -> 271.18, 271.18
% INFO    : Updated Thermal Rating: on line 25404-25550 : Rate B, Rate C - 0.0, 0.0 -> 271.18, 271.18
% INFO    : Updated Thermal Rating: on line 25405-25584 : Rate B, Rate C - 0.0, 0.0 -> 228.9, 228.9
% INFO    : Updated Thermal Rating: on line 25406-25569 : Rate B, Rate C - 0.0, 0.0 -> 229.64, 229.64
% INFO    : Updated Thermal Rating: on line 25407-25937 : Rate B, Rate C - 0.0, 0.0 -> 255.73, 255.73
% INFO    : Updated Thermal Rating: on line 25429-25410 : Rate B, Rate C - 0.0, 0.0 -> 228.5, 228.5
% INFO    : Updated Thermal Rating: on line 25410-25431 : Rate B, Rate C - 0.0, 0.0 -> 207.71, 207.71
% INFO    : Updated Thermal Rating: on line 25414-25422 : Rate B, Rate C - 0.0, 0.0 -> 216.82, 216.82
% INFO    : Updated Thermal Rating: on line 25443-25416 : Rate B, Rate C - 0.0, 0.0 -> 202.06, 202.06
% INFO    : Updated Thermal Rating: on line 25416-25444 : Rate B, Rate C - 0.0, 0.0 -> 209.43, 209.43
% INFO    : Updated Thermal Rating: on line 25416-25537 : Rate B, Rate C - 0.0, 0.0 -> 213.07, 213.07
% INFO    : Updated Thermal Rating: on line 25538-25416 : Rate B, Rate C - 0.0, 0.0 -> 188.75, 188.75
% INFO    : Updated Thermal Rating: on line 25417-25482 : Rate B, Rate C - 0.0, 0.0 -> 234.79, 234.79
% INFO    : Updated Thermal Rating: on line 25560-25419 : Rate B, Rate C - 0.0, 0.0 -> 223.9, 223.9
% INFO    : Updated Thermal Rating: on line 25419-25566 : Rate B, Rate C - 0.0, 0.0 -> 262.11, 262.11
% INFO    : Updated Thermal Rating: on line 25419-25578 : Rate B, Rate C - 0.0, 0.0 -> 265.34, 265.34
% INFO    : Updated Thermal Rating: on line 25875-25421 : Rate B, Rate C - 0.0, 0.0 -> 220.63, 220.63
% INFO    : Updated Thermal Rating: on line 25421-26081 : Rate B, Rate C - 0.0, 0.0 -> 180.79, 180.79
% INFO    : Updated Thermal Rating: on line 25423-25482 : Rate B, Rate C - 0.0, 0.0 -> 211.47, 211.47
% INFO    : Updated Thermal Rating: on transformer 25426-25425 : Rate B, Rate C - 0.0, 0.0 -> 558.65, 558.65
% INFO    : Updated Thermal Rating: on line 25426-25452 : Rate B, Rate C - 0.0, 0.0 -> 231.13, 231.13
% INFO    : Updated Thermal Rating: on line 25426-25453 : Rate B, Rate C - 0.0, 0.0 -> 241.33, 241.33
% INFO    : Updated Thermal Rating: on line 25426-25499 : Rate B, Rate C - 0.0, 0.0 -> 209.37, 209.37
% INFO    : Updated Thermal Rating: on line 25546-25426 : Rate B, Rate C - 0.0, 0.0 -> 218.38, 218.38
% INFO    : Updated Thermal Rating: on line 25427-25674 : Rate B, Rate C - 0.0, 0.0 -> 1217.63, 1217.63
% INFO    : Updated Thermal Rating: on line 25999-25427 : Rate B, Rate C - 0.0, 0.0 -> 1184.13, 1184.13
% INFO    : Updated Thermal Rating: on line 25427-26126 : Rate B, Rate C - 0.0, 0.0 -> 1352.66, 1352.66
% INFO    : Updated Thermal Rating: on line 26237-25427 : Rate B, Rate C - 0.0, 0.0 -> 1265.36, 1265.36
% INFO    : Updated Thermal Rating: on line 25429-25465 : Rate B, Rate C - 0.0, 0.0 -> 247.36, 247.36
% INFO    : Updated Thermal Rating: on line 25431-25516 : Rate B, Rate C - 0.0, 0.0 -> 218.21, 218.21
% INFO    : Updated Thermal Rating: on line 25433-25588 : Rate B, Rate C - 0.0, 0.0 -> 204.75, 204.75
% INFO    : Updated Thermal Rating: on line 26000-25433 : Rate B, Rate C - 0.0, 0.0 -> 228.17, 228.17
% INFO    : Updated Thermal Rating: on line 25436-25937 : Rate B, Rate C - 0.0, 0.0 -> 204.28, 204.28
% INFO    : Updated Thermal Rating: on line 26033-25436 : Rate B, Rate C - 0.0, 0.0 -> 197.61, 197.61
% INFO    : Updated Thermal Rating: on transformer 25438-25437 : Rate B, Rate C - 0.0, 0.0 -> 469.22, 469.22
% INFO    : Updated Thermal Rating: on line 25438-25447 : Rate B, Rate C - 0.0, 0.0 -> 230.5, 230.5
% INFO    : Updated Thermal Rating: on line 25438-25477 : Rate B, Rate C - 0.0, 0.0 -> 247.51, 247.51
% INFO    : Updated Thermal Rating: on line 25575-25440 : Rate B, Rate C - 0.0, 0.0 -> 1107.74, 1107.74
% INFO    : Updated Thermal Rating: on line 25440-26126 : Rate B, Rate C - 0.0, 0.0 -> 1339.37, 1339.37
% INFO    : Updated Thermal Rating: on line 25497-25442 : Rate B, Rate C - 0.0, 0.0 -> 236.39, 236.39
% INFO    : Updated Thermal Rating: on line 25550-25442 : Rate B, Rate C - 0.0, 0.0 -> 254.34, 254.34
% INFO    : Updated Thermal Rating: on line 25574-25443 : Rate B, Rate C - 0.0, 0.0 -> 162.15, 162.15
% INFO    : Updated Thermal Rating: on line 25443-26238 : Rate B, Rate C - 0.0, 0.0 -> 220.55, 220.55
% INFO    : Updated Thermal Rating: on line 25444-25916 : Rate B, Rate C - 0.0, 0.0 -> 231.69, 231.69
% INFO    : Updated Thermal Rating: on line 25459-25449 : Rate B, Rate C - 0.0, 0.0 -> 267.02, 267.02
% INFO    : Updated Thermal Rating: on line 25451-26127 : Rate B, Rate C - 0.0, 0.0 -> 255.84, 255.84
% INFO    : Updated Thermal Rating: on line 25452-25488 : Rate B, Rate C - 0.0, 0.0 -> 186.03, 186.03
% INFO    : Updated Thermal Rating: on line 25569-25453 : Rate B, Rate C - 0.0, 0.0 -> 203.29, 203.29
% INFO    : Updated Thermal Rating: on line 25454-25501 : Rate B, Rate C - 0.0, 0.0 -> 249.27, 249.27
% INFO    : Updated Thermal Rating: on line 25454-25520 : Rate B, Rate C - 0.0, 0.0 -> 188.51, 188.51
% INFO    : Updated Thermal Rating: on line 25456-25556 : Rate B, Rate C - 0.0, 0.0 -> 183.68, 183.68
% INFO    : Updated Thermal Rating: on line 25456-25593 : Rate B, Rate C - 0.0, 0.0 -> 222.62, 222.62
% INFO    : Updated Thermal Rating: on line 25542-25457 : Rate B, Rate C - 0.0, 0.0 -> 235.17, 235.17
% INFO    : Updated Thermal Rating: on transformer 25458-25461 : Rate B, Rate C - 0.0, 0.0 -> 535.76, 535.76
% INFO    : Updated Thermal Rating: on transformer 25459-25461 : Rate B, Rate C - 0.0, 0.0 -> 510.76, 510.76
% INFO    : Updated Thermal Rating: on transformer 25460-25461 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 25463-26126 : Rate B, Rate C - 0.0, 0.0 -> 1262.95, 1262.95
% INFO    : Updated Thermal Rating: on line 25465-25937 : Rate B, Rate C - 0.0, 0.0 -> 271.81, 271.81
% INFO    : Updated Thermal Rating: on line 25608-25467 : Rate B, Rate C - 0.0, 0.0 -> 237.56, 237.56
% INFO    : Updated Thermal Rating: on line 26000-25467 : Rate B, Rate C - 0.0, 0.0 -> 295.94, 295.94
% INFO    : Updated Thermal Rating: on line 25469-25486 : Rate B, Rate C - 0.0, 0.0 -> 271.72, 271.72
% INFO    : Updated Thermal Rating: on line 25469-25486 : Rate B, Rate C - 0.0, 0.0 -> 271.72, 271.72
% INFO    : Updated Thermal Rating: on line 25471-25499 : Rate B, Rate C - 0.0, 0.0 -> 248.65, 248.65
% INFO    : Updated Thermal Rating: on line 25541-25471 : Rate B, Rate C - 0.0, 0.0 -> 224.45, 224.45
% INFO    : Updated Thermal Rating: on line 25471-26045 : Rate B, Rate C - 0.0, 0.0 -> 258.1, 258.1
% INFO    : Updated Thermal Rating: on transformer 25474-25473 : Rate B, Rate C - 0.0, 0.0 -> 629.99, 629.99
% INFO    : Updated Thermal Rating: on transformer 25474-25473 : Rate B, Rate C - 0.0, 0.0 -> 629.99, 629.99
% INFO    : Updated Thermal Rating: on transformer 25474-25473 : Rate B, Rate C - 0.0, 0.0 -> 629.99, 629.99
% INFO    : Updated Thermal Rating: on line 25474-25477 : Rate B, Rate C - 0.0, 0.0 -> 284.24, 284.24
% INFO    : Updated Thermal Rating: on line 25474-25477 : Rate B, Rate C - 0.0, 0.0 -> 284.24, 284.24
% INFO    : Updated Thermal Rating: on line 25474-25477 : Rate B, Rate C - 0.0, 0.0 -> 284.24, 284.24
% INFO    : Updated Thermal Rating: on line 25474-25551 : Rate B, Rate C - 0.0, 0.0 -> 226.73, 226.73
% INFO    : Updated Thermal Rating: on line 25587-25474 : Rate B, Rate C - 0.0, 0.0 -> 286.98, 286.98
% INFO    : Updated Thermal Rating: on line 25474-25598 : Rate B, Rate C - 0.0, 0.0 -> 273.67, 273.67
% INFO    : Updated Thermal Rating: on line 25474-25598 : Rate B, Rate C - 0.0, 0.0 -> 273.67, 273.67
% INFO    : Updated Thermal Rating: on line 25575-25475 : Rate B, Rate C - 0.0, 0.0 -> 1109.76, 1109.76
% INFO    : Updated Thermal Rating: on line 25475-25999 : Rate B, Rate C - 0.0, 0.0 -> 1358.52, 1358.52
% INFO    : Updated Thermal Rating: on line 25477-25548 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 25477-25548 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 25477-25548 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 25551-25477 : Rate B, Rate C - 0.0, 0.0 -> 210.78, 210.78
% INFO    : Updated Thermal Rating: on line 25478-26127 : Rate B, Rate C - 0.0, 0.0 -> 250.1, 250.1
% INFO    : Updated Thermal Rating: on line 25480-25562 : Rate B, Rate C - 0.0, 0.0 -> 216.41, 216.41
% INFO    : Updated Thermal Rating: on line 25633-25480 : Rate B, Rate C - 0.0, 0.0 -> 234.64, 234.64
% INFO    : Updated Thermal Rating: on transformer 25482-25481 : Rate B, Rate C - 0.0, 0.0 -> 565.33, 565.33
% INFO    : Updated Thermal Rating: on line 25489-25483 : Rate B, Rate C - 0.0, 0.0 -> 1050.19, 1050.19
% INFO    : Updated Thermal Rating: on line 25485-25491 : Rate B, Rate C - 0.0, 0.0 -> 244.97, 244.97
% INFO    : Updated Thermal Rating: on line 25485-25683 : Rate B, Rate C - 0.0, 0.0 -> 220.41, 220.41
% INFO    : Updated Thermal Rating: on line 25486-25989 : Rate B, Rate C - 0.0, 0.0 -> 286.95, 286.95
% INFO    : Updated Thermal Rating: on line 25486-25989 : Rate B, Rate C - 0.0, 0.0 -> 286.95, 286.95
% INFO    : Updated Thermal Rating: on line 25486-25989 : Rate B, Rate C - 0.0, 0.0 -> 286.95, 286.95
% INFO    : Updated Thermal Rating: on line 25542-25488 : Rate B, Rate C - 0.0, 0.0 -> 209.35, 209.35
% INFO    : Updated Thermal Rating: on line 25488-25660 : Rate B, Rate C - 0.0, 0.0 -> 200.62, 200.62
% INFO    : Updated Thermal Rating: on transformer 25490-25489 : Rate B, Rate C - 0.0, 0.0 -> 623.91, 623.91
% INFO    : Updated Thermal Rating: on transformer 25490-25489 : Rate B, Rate C - 0.0, 0.0 -> 623.91, 623.91
% INFO    : Updated Thermal Rating: on transformer 25490-25489 : Rate B, Rate C - 0.0, 0.0 -> 623.91, 623.91
% INFO    : Updated Thermal Rating: on line 25489-26126 : Rate B, Rate C - 0.0, 0.0 -> 1419.32, 1419.32
% INFO    : Updated Thermal Rating: on line 25541-25490 : Rate B, Rate C - 0.0, 0.0 -> 245.21, 245.21
% INFO    : Updated Thermal Rating: on transformer 25491-25494 : Rate B, Rate C - 0.0, 0.0 -> 101.85, 101.85
% INFO    : Updated Thermal Rating: on line 25549-25491 : Rate B, Rate C - 0.0, 0.0 -> 232.41, 232.41
% INFO    : Updated Thermal Rating: on line 25491-25853 : Rate B, Rate C - 0.0, 0.0 -> 199.01, 199.01
% INFO    : Updated Thermal Rating: on line 26192-25491 : Rate B, Rate C - 0.0, 0.0 -> 227.3, 227.3
% INFO    : Updated Thermal Rating: on transformer 25492-25494 : Rate B, Rate C - 0.0, 0.0 -> 50.93, 50.93
% INFO    : Updated Thermal Rating: on transformer 25493-25494 : Rate B, Rate C - 0.0, 0.0 -> 50.93, 50.93
% INFO    : Updated Thermal Rating: on line 25567-25495 : Rate B, Rate C - 0.0, 0.0 -> 241.15, 241.15
% INFO    : Updated Thermal Rating: on line 25495-25928 : Rate B, Rate C - 0.0, 0.0 -> 234.44, 234.44
% INFO    : Updated Thermal Rating: on line 25495-25989 : Rate B, Rate C - 0.0, 0.0 -> 229.55, 229.55
% INFO    : Updated Thermal Rating: on line 25497-25593 : Rate B, Rate C - 0.0, 0.0 -> 202.86, 202.86
% INFO    : Updated Thermal Rating: on line 25556-25498 : Rate B, Rate C - 0.0, 0.0 -> 228.51, 228.51
% INFO    : Updated Thermal Rating: on line 25985-25498 : Rate B, Rate C - 0.0, 0.0 -> 240.72, 240.72
% INFO    : Updated Thermal Rating: on line 25499-25660 : Rate B, Rate C - 0.0, 0.0 -> 236.53, 236.53
% INFO    : Updated Thermal Rating: on line 25503-25580 : Rate B, Rate C - 0.0, 0.0 -> 226.67, 226.67
% INFO    : Updated Thermal Rating: on line 25503-25634 : Rate B, Rate C - 0.0, 0.0 -> 201.51, 201.51
% INFO    : Updated Thermal Rating: on line 25643-25503 : Rate B, Rate C - 0.0, 0.0 -> 190.66, 190.66
% INFO    : Updated Thermal Rating: on line 25579-25505 : Rate B, Rate C - 0.0, 0.0 -> 248.51, 248.51
% INFO    : Updated Thermal Rating: on line 25505-25581 : Rate B, Rate C - 0.0, 0.0 -> 233.23, 233.23
% INFO    : Updated Thermal Rating: on line 25507-25608 : Rate B, Rate C - 0.0, 0.0 -> 223.91, 223.91
% INFO    : Updated Thermal Rating: on line 25626-25507 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on line 25591-25508 : Rate B, Rate C - 0.0, 0.0 -> 255.06, 255.06
% INFO    : Updated Thermal Rating: on line 25508-25631 : Rate B, Rate C - 0.0, 0.0 -> 228.9, 228.9
% INFO    : Updated Thermal Rating: on line 25640-25508 : Rate B, Rate C - 0.0, 0.0 -> 286.68, 286.68
% INFO    : Updated Thermal Rating: on line 25640-25508 : Rate B, Rate C - 0.0, 0.0 -> 286.68, 286.68
% INFO    : Updated Thermal Rating: on line 25640-25508 : Rate B, Rate C - 0.0, 0.0 -> 286.68, 286.68
% INFO    : Updated Thermal Rating: on line 25508-25642 : Rate B, Rate C - 0.0, 0.0 -> 248.12, 248.12
% INFO    : Updated Thermal Rating: on line 25509-25536 : Rate B, Rate C - 0.0, 0.0 -> 241.72, 241.72
% INFO    : Updated Thermal Rating: on line 25579-25509 : Rate B, Rate C - 0.0, 0.0 -> 280.69, 280.69
% INFO    : Updated Thermal Rating: on line 25579-25509 : Rate B, Rate C - 0.0, 0.0 -> 280.69, 280.69
% INFO    : Updated Thermal Rating: on line 25579-25509 : Rate B, Rate C - 0.0, 0.0 -> 280.69, 280.69
% INFO    : Updated Thermal Rating: on line 25605-25509 : Rate B, Rate C - 0.0, 0.0 -> 258.37, 258.37
% INFO    : Updated Thermal Rating: on line 25510-25536 : Rate B, Rate C - 0.0, 0.0 -> 216.86, 216.86
% INFO    : Updated Thermal Rating: on line 25510-25563 : Rate B, Rate C - 0.0, 0.0 -> 199.04, 199.04
% INFO    : Updated Thermal Rating: on line 25510-25838 : Rate B, Rate C - 0.0, 0.0 -> 232.17, 232.17
% INFO    : Updated Thermal Rating: on line 25511-25517 : Rate B, Rate C - 0.0, 0.0 -> 170.84, 170.84
% INFO    : Updated Thermal Rating: on line 25511-25538 : Rate B, Rate C - 0.0, 0.0 -> 199.76, 199.76
% INFO    : Updated Thermal Rating: on line 25620-25511 : Rate B, Rate C - 0.0, 0.0 -> 221.79, 221.79
% INFO    : Updated Thermal Rating: on line 25512-25516 : Rate B, Rate C - 0.0, 0.0 -> 190.03, 190.03
% INFO    : Updated Thermal Rating: on line 25512-25633 : Rate B, Rate C - 0.0, 0.0 -> 220.69, 220.69
% INFO    : Updated Thermal Rating: on line 25514-25515 : Rate B, Rate C - 0.0, 0.0 -> 228.38, 228.38
% INFO    : Updated Thermal Rating: on line 25514-25727 : Rate B, Rate C - 0.0, 0.0 -> 199.46, 199.46
% INFO    : Updated Thermal Rating: on line 25515-25518 : Rate B, Rate C - 0.0, 0.0 -> 293.79, 293.79
% INFO    : Updated Thermal Rating: on line 25515-25518 : Rate B, Rate C - 0.0, 0.0 -> 293.79, 293.79
% INFO    : Updated Thermal Rating: on line 25515-25518 : Rate B, Rate C - 0.0, 0.0 -> 293.79, 293.79
% INFO    : Updated Thermal Rating: on line 25515-25991 : Rate B, Rate C - 0.0, 0.0 -> 269.95, 269.95
% INFO    : Updated Thermal Rating: on line 25516-25569 : Rate B, Rate C - 0.0, 0.0 -> 227.88, 227.88
% INFO    : Updated Thermal Rating: on line 25516-25612 : Rate B, Rate C - 0.0, 0.0 -> 201.0, 201.0
% INFO    : Updated Thermal Rating: on line 25516-25665 : Rate B, Rate C - 0.0, 0.0 -> 238.25, 238.25
% INFO    : Updated Thermal Rating: on line 25518-25620 : Rate B, Rate C - 0.0, 0.0 -> 249.94, 249.94
% INFO    : Updated Thermal Rating: on line 25640-25518 : Rate B, Rate C - 0.0, 0.0 -> 248.07, 248.07
% INFO    : Updated Thermal Rating: on line 25521-25536 : Rate B, Rate C - 0.0, 0.0 -> 232.75, 232.75
% INFO    : Updated Thermal Rating: on line 25552-25521 : Rate B, Rate C - 0.0, 0.0 -> 207.5, 207.5
% INFO    : Updated Thermal Rating: on line 25523-25545 : Rate B, Rate C - 0.0, 0.0 -> 189.19, 189.19
% INFO    : Updated Thermal Rating: on line 25523-25685 : Rate B, Rate C - 0.0, 0.0 -> 225.9, 225.9
% INFO    : Updated Thermal Rating: on line 25524-25591 : Rate B, Rate C - 0.0, 0.0 -> 244.8, 244.8
% INFO    : Updated Thermal Rating: on line 25690-25524 : Rate B, Rate C - 0.0, 0.0 -> 214.49, 214.49
% INFO    : Updated Thermal Rating: on line 25527-25547 : Rate B, Rate C - 0.0, 0.0 -> 223.23, 223.23
% INFO    : Updated Thermal Rating: on line 25564-25527 : Rate B, Rate C - 0.0, 0.0 -> 212.09, 212.09
% INFO    : Updated Thermal Rating: on line 25875-25528 : Rate B, Rate C - 0.0, 0.0 -> 217.65, 217.65
% INFO    : Updated Thermal Rating: on line 25528-25989 : Rate B, Rate C - 0.0, 0.0 -> 399.96, 399.96
% INFO    : Updated Thermal Rating: on line 25530-26041 : Rate B, Rate C - 0.0, 0.0 -> 269.37, 269.37
% INFO    : Updated Thermal Rating: on line 25530-26041 : Rate B, Rate C - 0.0, 0.0 -> 269.37, 269.37
% INFO    : Updated Thermal Rating: on line 25531-25602 : Rate B, Rate C - 0.0, 0.0 -> 236.82, 236.82
% INFO    : Updated Thermal Rating: on line 25531-25640 : Rate B, Rate C - 0.0, 0.0 -> 230.32, 230.32
% INFO    : Updated Thermal Rating: on line 25533-25563 : Rate B, Rate C - 0.0, 0.0 -> 202.56, 202.56
% INFO    : Updated Thermal Rating: on line 25576-25533 : Rate B, Rate C - 0.0, 0.0 -> 226.86, 226.86
% INFO    : Updated Thermal Rating: on line 25535-25576 : Rate B, Rate C - 0.0, 0.0 -> 209.37, 209.37
% INFO    : Updated Thermal Rating: on line 25535-25598 : Rate B, Rate C - 0.0, 0.0 -> 194.01, 194.01
% INFO    : Updated Thermal Rating: on line 25536-25688 : Rate B, Rate C - 0.0, 0.0 -> 179.39, 179.39
% INFO    : Updated Thermal Rating: on line 25606-25544 : Rate B, Rate C - 0.0, 0.0 -> 237.53, 237.53
% INFO    : Updated Thermal Rating: on line 25858-25544 : Rate B, Rate C - 0.0, 0.0 -> 266.05, 266.05
% INFO    : Updated Thermal Rating: on line 25636-25545 : Rate B, Rate C - 0.0, 0.0 -> 224.65, 224.65
% INFO    : Updated Thermal Rating: on line 25547-25546 : Rate B, Rate C - 0.0, 0.0 -> 197.15, 197.15
% INFO    : Updated Thermal Rating: on line 25548-25656 : Rate B, Rate C - 0.0, 0.0 -> 275.45, 275.45
% INFO    : Updated Thermal Rating: on line 25548-25656 : Rate B, Rate C - 0.0, 0.0 -> 275.45, 275.45
% INFO    : Updated Thermal Rating: on line 25989-25549 : Rate B, Rate C - 0.0, 0.0 -> 273.5, 273.5
% INFO    : Updated Thermal Rating: on line 25989-25549 : Rate B, Rate C - 0.0, 0.0 -> 273.5, 273.5
% INFO    : Updated Thermal Rating: on line 25549-26081 : Rate B, Rate C - 0.0, 0.0 -> 226.02, 226.02
% INFO    : Updated Thermal Rating: on line 25573-25551 : Rate B, Rate C - 0.0, 0.0 -> 207.08, 207.08
% INFO    : Updated Thermal Rating: on line 25552-25555 : Rate B, Rate C - 0.0, 0.0 -> 212.32, 212.32
% INFO    : Updated Thermal Rating: on line 25555-25656 : Rate B, Rate C - 0.0, 0.0 -> 252.96, 252.96
% INFO    : Updated Thermal Rating: on line 25610-25556 : Rate B, Rate C - 0.0, 0.0 -> 208.08, 208.08
% INFO    : Updated Thermal Rating: on transformer 25558-25557 : Rate B, Rate C - 0.0, 0.0 -> 461.86, 461.86
% INFO    : Updated Thermal Rating: on line 25557-25874 : Rate B, Rate C - 0.0, 0.0 -> 1182.55, 1182.55
% INFO    : Updated Thermal Rating: on line 25557-26095 : Rate B, Rate C - 0.0, 0.0 -> 1250.21, 1250.21
% INFO    : Updated Thermal Rating: on line 25557-28158 : Rate B, Rate C - 0.0, 0.0 -> 1229.32, 1229.32
% INFO    : Updated Thermal Rating: on line 25558-25604 : Rate B, Rate C - 0.0, 0.0 -> 264.8, 264.8
% INFO    : Updated Thermal Rating: on line 25558-28030 : Rate B, Rate C - 0.0, 0.0 -> 220.77, 220.77
% INFO    : Updated Thermal Rating: on line 25560-25875 : Rate B, Rate C - 0.0, 0.0 -> 248.7, 248.7
% INFO    : Updated Thermal Rating: on line 25581-25561 : Rate B, Rate C - 0.0, 0.0 -> 217.91, 217.91
% INFO    : Updated Thermal Rating: on line 25562-25658 : Rate B, Rate C - 0.0, 0.0 -> 196.82, 196.82
% INFO    : Updated Thermal Rating: on line 25562-25665 : Rate B, Rate C - 0.0, 0.0 -> 162.06, 162.06
% INFO    : Updated Thermal Rating: on line 25598-25563 : Rate B, Rate C - 0.0, 0.0 -> 224.42, 224.42
% INFO    : Updated Thermal Rating: on line 25564-25888 : Rate B, Rate C - 0.0, 0.0 -> 202.62, 202.62
% INFO    : Updated Thermal Rating: on line 25565-25570 : Rate B, Rate C - 0.0, 0.0 -> 223.98, 223.98
% INFO    : Updated Thermal Rating: on line 25610-25565 : Rate B, Rate C - 0.0, 0.0 -> 184.32, 184.32
% INFO    : Updated Thermal Rating: on line 25853-25566 : Rate B, Rate C - 0.0, 0.0 -> 237.55, 237.55
% INFO    : Updated Thermal Rating: on line 25566-26081 : Rate B, Rate C - 0.0, 0.0 -> 241.1, 241.1
% INFO    : Updated Thermal Rating: on line 25985-25570 : Rate B, Rate C - 0.0, 0.0 -> 262.44, 262.44
% INFO    : Updated Thermal Rating: on line 25571-25673 : Rate B, Rate C - 0.0, 0.0 -> 179.57, 179.57
% INFO    : Updated Thermal Rating: on line 25571-25931 : Rate B, Rate C - 0.0, 0.0 -> 218.21, 218.21
% INFO    : Updated Thermal Rating: on line 26000-25573 : Rate B, Rate C - 0.0, 0.0 -> 214.62, 214.62
% INFO    : Updated Thermal Rating: on line 25617-25574 : Rate B, Rate C - 0.0, 0.0 -> 269.23, 269.23
% INFO    : Updated Thermal Rating: on line 25574-26238 : Rate B, Rate C - 0.0, 0.0 -> 280.4, 280.4
% INFO    : Updated Thermal Rating: on line 25574-26238 : Rate B, Rate C - 0.0, 0.0 -> 280.4, 280.4
% INFO    : Updated Thermal Rating: on line 25574-26238 : Rate B, Rate C - 0.0, 0.0 -> 280.4, 280.4
% INFO    : Updated Thermal Rating: on transformer 25576-25575 : Rate B, Rate C - 0.0, 0.0 -> 459.85, 459.85
% INFO    : Updated Thermal Rating: on line 26021-25575 : Rate B, Rate C - 0.0, 0.0 -> 1172.35, 1172.35
% INFO    : Updated Thermal Rating: on line 25576-25584 : Rate B, Rate C - 0.0, 0.0 -> 137.17, 137.17
% INFO    : Updated Thermal Rating: on line 25578-25673 : Rate B, Rate C - 0.0, 0.0 -> 238.16, 238.16
% INFO    : Updated Thermal Rating: on line 25590-25579 : Rate B, Rate C - 0.0, 0.0 -> 294.43, 294.43
% INFO    : Updated Thermal Rating: on line 25590-25579 : Rate B, Rate C - 0.0, 0.0 -> 294.43, 294.43
% INFO    : Updated Thermal Rating: on line 25590-25579 : Rate B, Rate C - 0.0, 0.0 -> 294.43, 294.43
% INFO    : Updated Thermal Rating: on line 25605-25580 : Rate B, Rate C - 0.0, 0.0 -> 240.37, 240.37
% INFO    : Updated Thermal Rating: on line 25709-25586 : Rate B, Rate C - 0.0, 0.0 -> 220.45, 220.45
% INFO    : Updated Thermal Rating: on line 25931-25586 : Rate B, Rate C - 0.0, 0.0 -> 248.46, 248.46
% INFO    : Updated Thermal Rating: on line 25587-25626 : Rate B, Rate C - 0.0, 0.0 -> 214.81, 214.81
% INFO    : Updated Thermal Rating: on line 25656-25588 : Rate B, Rate C - 0.0, 0.0 -> 218.67, 218.67
% INFO    : Updated Thermal Rating: on line 25590-25875 : Rate B, Rate C - 0.0, 0.0 -> 299.5, 299.5
% INFO    : Updated Thermal Rating: on line 25590-25875 : Rate B, Rate C - 0.0, 0.0 -> 299.5, 299.5
% INFO    : Updated Thermal Rating: on line 25590-25875 : Rate B, Rate C - 0.0, 0.0 -> 299.5, 299.5
% INFO    : Updated Thermal Rating: on line 25590-25875 : Rate B, Rate C - 0.0, 0.0 -> 299.5, 299.5
% INFO    : Updated Thermal Rating: on line 25617-25593 : Rate B, Rate C - 0.0, 0.0 -> 223.78, 223.78
% INFO    : Updated Thermal Rating: on transformer 25594-25597 : Rate B, Rate C - 0.0, 0.0 -> 680.0, 680.0
% INFO    : Updated Thermal Rating: on line 25594-25639 : Rate B, Rate C - 0.0, 0.0 -> 1319.11, 1319.11
% INFO    : Updated Thermal Rating: on line 25713-25594 : Rate B, Rate C - 0.0, 0.0 -> 1262.48, 1262.48
% INFO    : Updated Thermal Rating: on line 25594-25986 : Rate B, Rate C - 0.0, 0.0 -> 1155.18, 1155.18
% INFO    : Updated Thermal Rating: on line 25594-26126 : Rate B, Rate C - 0.0, 0.0 -> 1244.0, 1244.0
% INFO    : Updated Thermal Rating: on transformer 25595-25597 : Rate B, Rate C - 0.0, 0.0 -> 730.24, 730.24
% INFO    : Updated Thermal Rating: on line 25595-25637 : Rate B, Rate C - 0.0, 0.0 -> 254.69, 254.69
% INFO    : Updated Thermal Rating: on line 25715-25595 : Rate B, Rate C - 0.0, 0.0 -> 217.68, 217.68
% INFO    : Updated Thermal Rating: on line 25595-25726 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 25595-25743 : Rate B, Rate C - 0.0, 0.0 -> 254.76, 254.76
% INFO    : Updated Thermal Rating: on transformer 25596-25597 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 25600-25602 : Rate B, Rate C - 0.0, 0.0 -> 240.51, 240.51
% INFO    : Updated Thermal Rating: on line 25600-25851 : Rate B, Rate C - 0.0, 0.0 -> 257.05, 257.05
% INFO    : Updated Thermal Rating: on line 25602-25710 : Rate B, Rate C - 0.0, 0.0 -> 207.14, 207.14
% INFO    : Updated Thermal Rating: on line 25604-25622 : Rate B, Rate C - 0.0, 0.0 -> 210.95, 210.95
% INFO    : Updated Thermal Rating: on line 28000-25604 : Rate B, Rate C - 0.0, 0.0 -> 240.44, 240.44
% INFO    : Updated Thermal Rating: on line 25606-25621 : Rate B, Rate C - 0.0, 0.0 -> 226.78, 226.78
% INFO    : Updated Thermal Rating: on line 25683-25606 : Rate B, Rate C - 0.0, 0.0 -> 179.44, 179.44
% INFO    : Updated Thermal Rating: on line 25634-25607 : Rate B, Rate C - 0.0, 0.0 -> 204.59, 204.59
% INFO    : Updated Thermal Rating: on line 25651-25607 : Rate B, Rate C - 0.0, 0.0 -> 231.83, 231.83
% INFO    : Updated Thermal Rating: on line 25607-28024 : Rate B, Rate C - 0.0, 0.0 -> 258.06, 258.06
% INFO    : Updated Thermal Rating: on line 25609-26172 : Rate B, Rate C - 0.0, 0.0 -> 285.3, 285.3
% INFO    : Updated Thermal Rating: on line 25609-28042 : Rate B, Rate C - 0.0, 0.0 -> 242.04, 242.04
% INFO    : Updated Thermal Rating: on line 25663-25610 : Rate B, Rate C - 0.0, 0.0 -> 186.56, 186.56
% INFO    : Updated Thermal Rating: on line 25612-26000 : Rate B, Rate C - 0.0, 0.0 -> 242.95, 242.95
% INFO    : Updated Thermal Rating: on line 25709-25615 : Rate B, Rate C - 0.0, 0.0 -> 236.16, 236.16
% INFO    : Updated Thermal Rating: on line 28004-25615 : Rate B, Rate C - 0.0, 0.0 -> 187.44, 187.44
% INFO    : Updated Thermal Rating: on line 25619-25664 : Rate B, Rate C - 0.0, 0.0 -> 228.35, 228.35
% INFO    : Updated Thermal Rating: on line 25695-25619 : Rate B, Rate C - 0.0, 0.0 -> 206.48, 206.48
% INFO    : Updated Thermal Rating: on line 25621-25652 : Rate B, Rate C - 0.0, 0.0 -> 206.52, 206.52
% INFO    : Updated Thermal Rating: on line 28000-25622 : Rate B, Rate C - 0.0, 0.0 -> 231.05, 231.05
% INFO    : Updated Thermal Rating: on line 25622-28008 : Rate B, Rate C - 0.0, 0.0 -> 197.79, 197.79
% INFO    : Updated Thermal Rating: on line 25622-28063 : Rate B, Rate C - 0.0, 0.0 -> 217.29, 217.29
% INFO    : Updated Thermal Rating: on line 25624-25696 : Rate B, Rate C - 0.0, 0.0 -> 210.38, 210.38
% INFO    : Updated Thermal Rating: on line 25624-25985 : Rate B, Rate C - 0.0, 0.0 -> 237.23, 237.23
% INFO    : Updated Thermal Rating: on line 25628-25695 : Rate B, Rate C - 0.0, 0.0 -> 169.48, 169.48
% INFO    : Updated Thermal Rating: on line 25628-26076 : Rate B, Rate C - 0.0, 0.0 -> 217.86, 217.86
% INFO    : Updated Thermal Rating: on line 25715-25631 : Rate B, Rate C - 0.0, 0.0 -> 192.23, 192.23
% INFO    : Updated Thermal Rating: on transformer 25633-25632 : Rate B, Rate C - 0.0, 0.0 -> 543.1, 543.1
% INFO    : Updated Thermal Rating: on line 25632-25930 : Rate B, Rate C - 0.0, 0.0 -> 1146.87, 1146.87
% INFO    : Updated Thermal Rating: on line 25632-26126 : Rate B, Rate C - 0.0, 0.0 -> 1344.33, 1344.33
% INFO    : Updated Thermal Rating: on line 25633-25663 : Rate B, Rate C - 0.0, 0.0 -> 243.49, 243.49
% INFO    : Updated Thermal Rating: on line 25636-28024 : Rate B, Rate C - 0.0, 0.0 -> 280.21, 280.21
% INFO    : Updated Thermal Rating: on line 25637-25694 : Rate B, Rate C - 0.0, 0.0 -> 239.27, 239.27
% INFO    : Updated Thermal Rating: on transformer 25640-25639 : Rate B, Rate C - 0.0, 0.0 -> 442.6, 442.6
% INFO    : Updated Thermal Rating: on line 25990-25639 : Rate B, Rate C - 0.0, 0.0 -> 1284.21, 1284.21
% INFO    : Updated Thermal Rating: on line 25639-26228 : Rate B, Rate C - 0.0, 0.0 -> 1221.86, 1221.86
% INFO    : Updated Thermal Rating: on line 25768-25642 : Rate B, Rate C - 0.0, 0.0 -> 212.97, 212.97
% INFO    : Updated Thermal Rating: on line 25643-25673 : Rate B, Rate C - 0.0, 0.0 -> 187.86, 187.86
% INFO    : Updated Thermal Rating: on line 28001-25644 : Rate B, Rate C - 0.0, 0.0 -> 210.75, 210.75
% INFO    : Updated Thermal Rating: on line 25644-28022 : Rate B, Rate C - 0.0, 0.0 -> 242.58, 242.58
% INFO    : Updated Thermal Rating: on line 25644-28025 : Rate B, Rate C - 0.0, 0.0 -> 240.26, 240.26
% INFO    : Updated Thermal Rating: on line 25646-25838 : Rate B, Rate C - 0.0, 0.0 -> 216.63, 216.63
% INFO    : Updated Thermal Rating: on line 25646-26081 : Rate B, Rate C - 0.0, 0.0 -> 236.1, 236.1
% INFO    : Updated Thermal Rating: on line 25649-25700 : Rate B, Rate C - 0.0, 0.0 -> 383.49, 383.49
% INFO    : Updated Thermal Rating: on line 25649-26172 : Rate B, Rate C - 0.0, 0.0 -> 319.93, 319.93
% INFO    : Updated Thermal Rating: on line 25649-26172 : Rate B, Rate C - 0.0, 0.0 -> 319.93, 319.93
% INFO    : Updated Thermal Rating: on line 25649-26172 : Rate B, Rate C - 0.0, 0.0 -> 319.93, 319.93
% INFO    : Updated Thermal Rating: on line 25649-26172 : Rate B, Rate C - 0.0, 0.0 -> 319.93, 319.93
% INFO    : Updated Thermal Rating: on line 28022-25649 : Rate B, Rate C - 0.0, 0.0 -> 297.03, 297.03
% INFO    : Updated Thermal Rating: on line 28022-25649 : Rate B, Rate C - 0.0, 0.0 -> 297.03, 297.03
% INFO    : Updated Thermal Rating: on line 28022-25649 : Rate B, Rate C - 0.0, 0.0 -> 297.03, 297.03
% INFO    : Updated Thermal Rating: on line 28022-25649 : Rate B, Rate C - 0.0, 0.0 -> 297.03, 297.03
% INFO    : Updated Thermal Rating: on line 25651-28004 : Rate B, Rate C - 0.0, 0.0 -> 209.78, 209.78
% INFO    : Updated Thermal Rating: on line 25652-25686 : Rate B, Rate C - 0.0, 0.0 -> 240.12, 240.12
% INFO    : Updated Thermal Rating: on line 25652-28009 : Rate B, Rate C - 0.0, 0.0 -> 374.8, 374.8
% INFO    : Updated Thermal Rating: on line 25652-28010 : Rate B, Rate C - 0.0, 0.0 -> 239.99, 239.99
% INFO    : Updated Thermal Rating: on line 25652-28100 : Rate B, Rate C - 0.0, 0.0 -> 230.3, 230.3
% INFO    : Updated Thermal Rating: on line 25657-25675 : Rate B, Rate C - 0.0, 0.0 -> 222.62, 222.62
% INFO    : Updated Thermal Rating: on line 25742-25657 : Rate B, Rate C - 0.0, 0.0 -> 265.0, 265.0
% INFO    : Updated Thermal Rating: on line 25658-25985 : Rate B, Rate C - 0.0, 0.0 -> 223.22, 223.22
% INFO    : Updated Thermal Rating: on line 25659-25671 : Rate B, Rate C - 0.0, 0.0 -> 214.45, 214.45
% INFO    : Updated Thermal Rating: on line 25714-25659 : Rate B, Rate C - 0.0, 0.0 -> 217.84, 217.84
% INFO    : Updated Thermal Rating: on line 25661-25663 : Rate B, Rate C - 0.0, 0.0 -> 221.4, 221.4
% INFO    : Updated Thermal Rating: on line 25661-25690 : Rate B, Rate C - 0.0, 0.0 -> 175.31, 175.31
% INFO    : Updated Thermal Rating: on line 25696-25661 : Rate B, Rate C - 0.0, 0.0 -> 163.04, 163.04
% INFO    : Updated Thermal Rating: on transformer 25666-25669 : Rate B, Rate C - 0.0, 0.0 -> 100.36, 100.36
% INFO    : Updated Thermal Rating: on transformer 25667-25669 : Rate B, Rate C - 0.0, 0.0 -> 50.18, 50.18
% INFO    : Updated Thermal Rating: on transformer 25668-25669 : Rate B, Rate C - 0.0, 0.0 -> 50.18, 50.18
% INFO    : Updated Thermal Rating: on line 25671-25694 : Rate B, Rate C - 0.0, 0.0 -> 218.5, 218.5
% INFO    : Updated Thermal Rating: on line 25671-25726 : Rate B, Rate C - 0.0, 0.0 -> 222.53, 222.53
% INFO    : Updated Thermal Rating: on line 25688-25672 : Rate B, Rate C - 0.0, 0.0 -> 199.76, 199.76
% INFO    : Updated Thermal Rating: on line 25672-25931 : Rate B, Rate C - 0.0, 0.0 -> 238.26, 238.26
% INFO    : Updated Thermal Rating: on transformer 25674-25677 : Rate B, Rate C - 0.0, 0.0 -> 565.72, 565.72
% INFO    : Updated Thermal Rating: on line 25930-25674 : Rate B, Rate C - 0.0, 0.0 -> 1037.8, 1037.8
% INFO    : Updated Thermal Rating: on transformer 25675-25677 : Rate B, Rate C - 0.0, 0.0 -> 490.72, 490.72
% INFO    : Updated Thermal Rating: on transformer 25676-25677 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 25680-25717 : Rate B, Rate C - 0.0, 0.0 -> 228.23, 228.23
% INFO    : Updated Thermal Rating: on line 25730-25680 : Rate B, Rate C - 0.0, 0.0 -> 253.35, 253.35
% INFO    : Updated Thermal Rating: on line 28016-25680 : Rate B, Rate C - 0.0, 0.0 -> 205.26, 205.26
% INFO    : Updated Thermal Rating: on line 25684-28001 : Rate B, Rate C - 0.0, 0.0 -> 181.02, 181.02
% INFO    : Updated Thermal Rating: on line 28022-25684 : Rate B, Rate C - 0.0, 0.0 -> 227.99, 227.99
% INFO    : Updated Thermal Rating: on line 25685-28003 : Rate B, Rate C - 0.0, 0.0 -> 255.37, 255.37
% INFO    : Updated Thermal Rating: on line 28001-25686 : Rate B, Rate C - 0.0, 0.0 -> 289.53, 289.53
% INFO    : Updated Thermal Rating: on line 28001-25686 : Rate B, Rate C - 0.0, 0.0 -> 289.53, 289.53
% INFO    : Updated Thermal Rating: on line 28001-25686 : Rate B, Rate C - 0.0, 0.0 -> 289.53, 289.53
% INFO    : Updated Thermal Rating: on line 25686-28033 : Rate B, Rate C - 0.0, 0.0 -> 225.5, 225.5
% INFO    : Updated Thermal Rating: on line 25686-28073 : Rate B, Rate C - 0.0, 0.0 -> 248.39, 248.39
% INFO    : Updated Thermal Rating: on line 25734-25687 : Rate B, Rate C - 0.0, 0.0 -> 207.02, 207.02
% INFO    : Updated Thermal Rating: on line 25878-25687 : Rate B, Rate C - 0.0, 0.0 -> 226.89, 226.89
% INFO    : Updated Thermal Rating: on line 25692-25734 : Rate B, Rate C - 0.0, 0.0 -> 219.15, 219.15
% INFO    : Updated Thermal Rating: on line 25743-25692 : Rate B, Rate C - 0.0, 0.0 -> 236.35, 236.35
% INFO    : Updated Thermal Rating: on line 25693-25720 : Rate B, Rate C - 0.0, 0.0 -> 199.68, 199.68
% INFO    : Updated Thermal Rating: on line 25693-25985 : Rate B, Rate C - 0.0, 0.0 -> 227.99, 227.99
% INFO    : Updated Thermal Rating: on line 25698-25728 : Rate B, Rate C - 0.0, 0.0 -> 229.57, 229.57
% INFO    : Updated Thermal Rating: on line 25698-26076 : Rate B, Rate C - 0.0, 0.0 -> 241.98, 241.98
% INFO    : Updated Thermal Rating: on line 25699-25709 : Rate B, Rate C - 0.0, 0.0 -> 232.11, 232.11
% INFO    : Updated Thermal Rating: on line 25699-28024 : Rate B, Rate C - 0.0, 0.0 -> 250.07, 250.07
% INFO    : Updated Thermal Rating: on line 28009-25700 : Rate B, Rate C - 0.0, 0.0 -> 268.95, 268.95
% INFO    : Updated Thermal Rating: on line 25702-25717 : Rate B, Rate C - 0.0, 0.0 -> 203.53, 203.53
% INFO    : Updated Thermal Rating: on line 28084-25702 : Rate B, Rate C - 0.0, 0.0 -> 178.45, 178.45
% INFO    : Updated Thermal Rating: on line 25706-25703 : Rate B, Rate C - 0.0, 0.0 -> 214.74, 214.74
% INFO    : Updated Thermal Rating: on line 25703-25714 : Rate B, Rate C - 0.0, 0.0 -> 239.58, 239.58
% INFO    : Updated Thermal Rating: on line 25747-25703 : Rate B, Rate C - 0.0, 0.0 -> 198.26, 198.26
% INFO    : Updated Thermal Rating: on line 25724-25705 : Rate B, Rate C - 0.0, 0.0 -> 212.02, 212.02
% INFO    : Updated Thermal Rating: on line 25726-25705 : Rate B, Rate C - 0.0, 0.0 -> 229.29, 229.29
% INFO    : Updated Thermal Rating: on line 25759-25706 : Rate B, Rate C - 0.0, 0.0 -> 181.81, 181.81
% INFO    : Updated Thermal Rating: on line 25716-25708 : Rate B, Rate C - 0.0, 0.0 -> 195.78, 195.78
% INFO    : Updated Thermal Rating: on line 25708-25723 : Rate B, Rate C - 0.0, 0.0 -> 234.77, 234.77
% INFO    : Updated Thermal Rating: on line 26076-25708 : Rate B, Rate C - 0.0, 0.0 -> 261.16, 261.16
% INFO    : Updated Thermal Rating: on line 25710-25773 : Rate B, Rate C - 0.0, 0.0 -> 229.66, 229.66
% INFO    : Updated Thermal Rating: on line 25768-25712 : Rate B, Rate C - 0.0, 0.0 -> 241.79, 241.79
% INFO    : Updated Thermal Rating: on transformer 25714-25713 : Rate B, Rate C - 0.0, 0.0 -> 690.0, 690.0
% INFO    : Updated Thermal Rating: on line 25713-25771 : Rate B, Rate C - 0.0, 0.0 -> 1228.6, 1228.6
% INFO    : Updated Thermal Rating: on line 25713-28141 : Rate B, Rate C - 0.0, 0.0 -> 1182.65, 1182.65
% INFO    : Updated Thermal Rating: on line 25714-25721 : Rate B, Rate C - 0.0, 0.0 -> 236.08, 236.08
% INFO    : Updated Thermal Rating: on line 25714-25737 : Rate B, Rate C - 0.0, 0.0 -> 178.53, 178.53
% INFO    : Updated Thermal Rating: on line 25763-25714 : Rate B, Rate C - 0.0, 0.0 -> 231.7, 231.7
% INFO    : Updated Thermal Rating: on line 25716-25878 : Rate B, Rate C - 0.0, 0.0 -> 200.74, 200.74
% INFO    : Updated Thermal Rating: on line 28019-25718 : Rate B, Rate C - 0.0, 0.0 -> 226.79, 226.79
% INFO    : Updated Thermal Rating: on line 25718-28947 : Rate B, Rate C - 0.0, 0.0 -> 201.21, 201.21
% INFO    : Updated Thermal Rating: on line 25738-25720 : Rate B, Rate C - 0.0, 0.0 -> 198.28, 198.28
% INFO    : Updated Thermal Rating: on line 25721-25759 : Rate B, Rate C - 0.0, 0.0 -> 194.55, 194.55
% INFO    : Updated Thermal Rating: on line 25723-28084 : Rate B, Rate C - 0.0, 0.0 -> 214.01, 214.01
% INFO    : Updated Thermal Rating: on line 25724-25737 : Rate B, Rate C - 0.0, 0.0 -> 180.28, 180.28
% INFO    : Updated Thermal Rating: on line 25727-25775 : Rate B, Rate C - 0.0, 0.0 -> 218.12, 218.12
% INFO    : Updated Thermal Rating: on line 25728-25751 : Rate B, Rate C - 0.0, 0.0 -> 218.33, 218.33
% INFO    : Updated Thermal Rating: on line 25728-25790 : Rate B, Rate C - 0.0, 0.0 -> 215.8, 215.8
% INFO    : Updated Thermal Rating: on line 28032-25728 : Rate B, Rate C - 0.0, 0.0 -> 199.45, 199.45
% INFO    : Updated Thermal Rating: on transformer 25730-25729 : Rate B, Rate C - 0.0, 0.0 -> 485.64, 485.64
% INFO    : Updated Thermal Rating: on line 25729-25930 : Rate B, Rate C - 0.0, 0.0 -> 1062.91, 1062.91
% INFO    : Updated Thermal Rating: on line 25729-25986 : Rate B, Rate C - 0.0, 0.0 -> 1224.52, 1224.52
% INFO    : Updated Thermal Rating: on line 25729-28038 : Rate B, Rate C - 0.0, 0.0 -> 1122.08, 1122.08
% INFO    : Updated Thermal Rating: on line 25733-25744 : Rate B, Rate C - 0.0, 0.0 -> 197.28, 197.28
% INFO    : Updated Thermal Rating: on line 25733-25878 : Rate B, Rate C - 0.0, 0.0 -> 238.82, 238.82
% INFO    : Updated Thermal Rating: on line 28087-25733 : Rate B, Rate C - 0.0, 0.0 -> 211.97, 211.97
% INFO    : Updated Thermal Rating: on line 25745-25736 : Rate B, Rate C - 0.0, 0.0 -> 211.9, 211.9
% INFO    : Updated Thermal Rating: on line 25748-25736 : Rate B, Rate C - 0.0, 0.0 -> 189.86, 189.86
% INFO    : Updated Thermal Rating: on line 25737-25749 : Rate B, Rate C - 0.0, 0.0 -> 180.11, 180.11
% INFO    : Updated Thermal Rating: on line 25749-25738 : Rate B, Rate C - 0.0, 0.0 -> 215.44, 215.44
% INFO    : Updated Thermal Rating: on line 25738-25768 : Rate B, Rate C - 0.0, 0.0 -> 238.19, 238.19
% INFO    : Updated Thermal Rating: on line 25739-25754 : Rate B, Rate C - 0.0, 0.0 -> 198.28, 198.28
% INFO    : Updated Thermal Rating: on line 25739-28053 : Rate B, Rate C - 0.0, 0.0 -> 217.94, 217.94
% INFO    : Updated Thermal Rating: on line 25739-28054 : Rate B, Rate C - 0.0, 0.0 -> 197.63, 197.63
% INFO    : Updated Thermal Rating: on line 25739-28111 : Rate B, Rate C - 0.0, 0.0 -> 200.78, 200.78
% INFO    : Updated Thermal Rating: on line 25742-25931 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 25744-28142 : Rate B, Rate C - 0.0, 0.0 -> 227.08, 227.08
% INFO    : Updated Thermal Rating: on line 25812-25745 : Rate B, Rate C - 0.0, 0.0 -> 240.98, 240.98
% INFO    : Updated Thermal Rating: on line 25747-25763 : Rate B, Rate C - 0.0, 0.0 -> 211.35, 211.35
% INFO    : Updated Thermal Rating: on line 25748-25768 : Rate B, Rate C - 0.0, 0.0 -> 237.53, 237.53
% INFO    : Updated Thermal Rating: on line 25748-25799 : Rate B, Rate C - 0.0, 0.0 -> 214.04, 214.04
% INFO    : Updated Thermal Rating: on line 25878-25751 : Rate B, Rate C - 0.0, 0.0 -> 233.3, 233.3
% INFO    : Updated Thermal Rating: on line 25752-25780 : Rate B, Rate C - 0.0, 0.0 -> 196.13, 196.13
% INFO    : Updated Thermal Rating: on line 25752-25878 : Rate B, Rate C - 0.0, 0.0 -> 218.59, 218.59
% INFO    : Updated Thermal Rating: on line 25753-28172 : Rate B, Rate C - 0.0, 0.0 -> 212.32, 212.32
% INFO    : Updated Thermal Rating: on line 25753-29045 : Rate B, Rate C - 0.0, 0.0 -> 176.44, 176.44
% INFO    : Updated Thermal Rating: on line 25754-28071 : Rate B, Rate C - 0.0, 0.0 -> 203.37, 203.37
% INFO    : Updated Thermal Rating: on line 25780-25757 : Rate B, Rate C - 0.0, 0.0 -> 200.91, 200.91
% INFO    : Updated Thermal Rating: on line 25757-25781 : Rate B, Rate C - 0.0, 0.0 -> 222.52, 222.52
% INFO    : Updated Thermal Rating: on transformer 25759-25762 : Rate B, Rate C - 0.0, 0.0 -> 222.63, 222.63
% INFO    : Updated Thermal Rating: on line 25759-25799 : Rate B, Rate C - 0.0, 0.0 -> 174.46, 174.46
% INFO    : Updated Thermal Rating: on transformer 25760-25762 : Rate B, Rate C - 0.0, 0.0 -> 111.32, 111.32
% INFO    : Updated Thermal Rating: on transformer 25761-25762 : Rate B, Rate C - 0.0, 0.0 -> 111.32, 111.32
% INFO    : Updated Thermal Rating: on line 26111-25764 : Rate B, Rate C - 0.0, 0.0 -> 182.07, 182.07
% INFO    : Updated Thermal Rating: on line 25766-25823 : Rate B, Rate C - 0.0, 0.0 -> 232.0, 232.0
% INFO    : Updated Thermal Rating: on line 28192-25766 : Rate B, Rate C - 0.0, 0.0 -> 192.92, 192.92
% INFO    : Updated Thermal Rating: on transformer 25767-25770 : Rate B, Rate C - 0.0, 0.0 -> 594.32, 594.32
% INFO    : Updated Thermal Rating: on transformer 25768-25770 : Rate B, Rate C - 0.0, 0.0 -> 468.92, 468.92
% INFO    : Updated Thermal Rating: on line 25768-25794 : Rate B, Rate C - 0.0, 0.0 -> 233.5, 233.5
% INFO    : Updated Thermal Rating: on transformer 25769-25770 : Rate B, Rate C - 0.0, 0.0 -> 125.4, 125.4
% INFO    : Updated Thermal Rating: on line 25771-25774 : Rate B, Rate C - 0.0, 0.0 -> 1179.79, 1179.79
% INFO    : Updated Thermal Rating: on line 25813-25771 : Rate B, Rate C - 0.0, 0.0 -> 1194.2, 1194.2
% INFO    : Updated Thermal Rating: on line 25771-25936 : Rate B, Rate C - 0.0, 0.0 -> 1370.44, 1370.44
% INFO    : Updated Thermal Rating: on line 25773-26003 : Rate B, Rate C - 0.0, 0.0 -> 260.16, 260.16
% INFO    : Updated Thermal Rating: on transformer 25774-25777 : Rate B, Rate C - 0.0, 0.0 -> 446.99, 446.99
% INFO    : Updated Thermal Rating: on line 25774-25869 : Rate B, Rate C - 0.0, 0.0 -> 1233.81, 1233.81
% INFO    : Updated Thermal Rating: on transformer 25775-25777 : Rate B, Rate C - 0.0, 0.0 -> 296.99, 296.99
% INFO    : Updated Thermal Rating: on line 25775-26092 : Rate B, Rate C - 0.0, 0.0 -> 268.59, 268.59
% INFO    : Updated Thermal Rating: on line 28271-25775 : Rate B, Rate C - 0.0, 0.0 -> 263.84, 263.84
% INFO    : Updated Thermal Rating: on transformer 25776-25777 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 25783-25780 : Rate B, Rate C - 0.0, 0.0 -> 199.67, 199.67
% INFO    : Updated Thermal Rating: on line 25780-28087 : Rate B, Rate C - 0.0, 0.0 -> 210.77, 210.77
% INFO    : Updated Thermal Rating: on line 25781-25789 : Rate B, Rate C - 0.0, 0.0 -> 242.24, 242.24
% INFO    : Updated Thermal Rating: on line 28142-25783 : Rate B, Rate C - 0.0, 0.0 -> 234.32, 234.32
% INFO    : Updated Thermal Rating: on line 25793-25784 : Rate B, Rate C - 0.0, 0.0 -> 203.09, 203.09
% INFO    : Updated Thermal Rating: on line 25784-25812 : Rate B, Rate C - 0.0, 0.0 -> 220.65, 220.65
% INFO    : Updated Thermal Rating: on line 25785-25814 : Rate B, Rate C - 0.0, 0.0 -> 190.85, 190.85
% INFO    : Updated Thermal Rating: on line 25785-28218 : Rate B, Rate C - 0.0, 0.0 -> 213.62, 213.62
% INFO    : Updated Thermal Rating: on line 25786-25800 : Rate B, Rate C - 0.0, 0.0 -> 198.56, 198.56
% INFO    : Updated Thermal Rating: on line 25786-25814 : Rate B, Rate C - 0.0, 0.0 -> 173.0, 173.0
% INFO    : Updated Thermal Rating: on line 26023-25789 : Rate B, Rate C - 0.0, 0.0 -> 262.97, 262.97
% INFO    : Updated Thermal Rating: on line 28032-25790 : Rate B, Rate C - 0.0, 0.0 -> 173.46, 173.46
% INFO    : Updated Thermal Rating: on line 25792-25802 : Rate B, Rate C - 0.0, 0.0 -> 194.24, 194.24
% INFO    : Updated Thermal Rating: on line 25823-25792 : Rate B, Rate C - 0.0, 0.0 -> 209.13, 209.13
% INFO    : Updated Thermal Rating: on line 25794-25793 : Rate B, Rate C - 0.0, 0.0 -> 217.25, 217.25
% INFO    : Updated Thermal Rating: on line 25815-25793 : Rate B, Rate C - 0.0, 0.0 -> 210.14, 210.14
% INFO    : Updated Thermal Rating: on line 25797-26023 : Rate B, Rate C - 0.0, 0.0 -> 237.08, 237.08
% INFO    : Updated Thermal Rating: on line 25797-28173 : Rate B, Rate C - 0.0, 0.0 -> 221.6, 221.6
% INFO    : Updated Thermal Rating: on line 28232-25797 : Rate B, Rate C - 0.0, 0.0 -> 170.94, 170.94
% INFO    : Updated Thermal Rating: on line 28218-25800 : Rate B, Rate C - 0.0, 0.0 -> 226.94, 226.94
% INFO    : Updated Thermal Rating: on line 25802-25810 : Rate B, Rate C - 0.0, 0.0 -> 192.02, 192.02
% INFO    : Updated Thermal Rating: on line 25802-25815 : Rate B, Rate C - 0.0, 0.0 -> 156.83, 156.83
% INFO    : Updated Thermal Rating: on line 25802-28267 : Rate B, Rate C - 0.0, 0.0 -> 161.96, 161.96
% INFO    : Updated Thermal Rating: on transformer 25803-25806 : Rate B, Rate C - 0.0, 0.0 -> 511.47, 511.47
% INFO    : Updated Thermal Rating: on line 25803-28141 : Rate B, Rate C - 0.0, 0.0 -> 1190.08, 1190.08
% INFO    : Updated Thermal Rating: on transformer 25804-25806 : Rate B, Rate C - 0.0, 0.0 -> 486.47, 486.47
% INFO    : Updated Thermal Rating: on line 28172-25804 : Rate B, Rate C - 0.0, 0.0 -> 274.99, 274.99
% INFO    : Updated Thermal Rating: on transformer 25805-25806 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 28142-25809 : Rate B, Rate C - 0.0, 0.0 -> 228.72, 228.72
% INFO    : Updated Thermal Rating: on line 25809-28173 : Rate B, Rate C - 0.0, 0.0 -> 191.03, 191.03
% INFO    : Updated Thermal Rating: on line 26023-25810 : Rate B, Rate C - 0.0, 0.0 -> 226.44, 226.44
% INFO    : Updated Thermal Rating: on transformer 25812-25811 : Rate B, Rate C - 0.0, 0.0 -> 482.47, 482.47
% INFO    : Updated Thermal Rating: on line 25814-25812 : Rate B, Rate C - 0.0, 0.0 -> 244.91, 244.91
% INFO    : Updated Thermal Rating: on line 25877-25813 : Rate B, Rate C - 0.0, 0.0 -> 1182.16, 1182.16
% INFO    : Updated Thermal Rating: on line 25813-26024 : Rate B, Rate C - 0.0, 0.0 -> 1189.18, 1189.18
% INFO    : Updated Thermal Rating: on line 25820-25819 : Rate B, Rate C - 0.0, 0.0 -> 189.28, 189.28
% INFO    : Updated Thermal Rating: on line 25820-28610 : Rate B, Rate C - 0.0, 0.0 -> 161.57, 161.57
% INFO    : Updated Thermal Rating: on line 25823-28195 : Rate B, Rate C - 0.0, 0.0 -> 208.77, 208.77
% INFO    : Updated Thermal Rating: on line 28234-25823 : Rate B, Rate C - 0.0, 0.0 -> 215.66, 215.66
% INFO    : Updated Thermal Rating: on line 25823-28271 : Rate B, Rate C - 0.0, 0.0 -> 248.23, 248.23
% INFO    : Updated Thermal Rating: on transformer 25825-25824 : Rate B, Rate C - 0.0, 0.0 -> 1461.46, 1461.46
% INFO    : Updated Thermal Rating: on transformer 25824-25829 : Rate B, Rate C - 0.0, 0.0 -> 1852.31, 1852.31
% INFO    : Updated Thermal Rating: on transformer 25824-25830 : Rate B, Rate C - 0.0, 0.0 -> 1851.18, 1851.18
% INFO    : Updated Thermal Rating: on transformer 25824-25831 : Rate B, Rate C - 0.0, 0.0 -> 967.77, 967.77
% INFO    : Updated Thermal Rating: on line 26035-25824 : Rate B, Rate C - 0.0, 0.0 -> 3958.64, 3958.64
% INFO    : Updated Thermal Rating: on line 25824-26212 : Rate B, Rate C - 0.0, 0.0 -> 4060.7, 4060.7
% INFO    : Updated Thermal Rating: on transformer 25825-25828 : Rate B, Rate C - 0.0, 0.0 -> 574.21, 574.21
% INFO    : Updated Thermal Rating: on line 26005-25825 : Rate B, Rate C - 0.0, 0.0 -> 1169.01, 1169.01
% INFO    : Updated Thermal Rating: on transformer 25826-25828 : Rate B, Rate C - 0.0, 0.0 -> 499.21, 499.21
% INFO    : Updated Thermal Rating: on transformer 25827-25828 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 25833-25832 : Rate B, Rate C - 0.0, 0.0 -> 324.0, 324.0
% INFO    : Updated Thermal Rating: on transformer 25832-25834 : Rate B, Rate C - 0.0, 0.0 -> 518.59, 518.59
% INFO    : Updated Thermal Rating: on line 25850-25832 : Rate B, Rate C - 0.0, 0.0 -> 1236.54, 1236.54
% INFO    : Updated Thermal Rating: on line 25832-25971 : Rate B, Rate C - 0.0, 0.0 -> 1158.54, 1158.54
% INFO    : Updated Thermal Rating: on line 25833-25851 : Rate B, Rate C - 0.0, 0.0 -> 264.54, 264.54
% INFO    : Updated Thermal Rating: on line 25833-25994 : Rate B, Rate C - 0.0, 0.0 -> 250.2, 250.2
% INFO    : Updated Thermal Rating: on line 25835-25958 : Rate B, Rate C - 0.0, 0.0 -> 217.59, 217.59
% INFO    : Updated Thermal Rating: on line 25835-25994 : Rate B, Rate C - 0.0, 0.0 -> 229.94, 229.94
% INFO    : Updated Thermal Rating: on line 25835-26011 : Rate B, Rate C - 0.0, 0.0 -> 219.41, 219.41
% INFO    : Updated Thermal Rating: on transformer 25836-25837 : Rate B, Rate C - 0.0, 0.0 -> 96.28, 96.28
% INFO    : Updated Thermal Rating: on line 25839-26034 : Rate B, Rate C - 0.0, 0.0 -> 215.99, 215.99
% INFO    : Updated Thermal Rating: on line 26006-25841 : Rate B, Rate C - 0.0, 0.0 -> 198.77, 198.77
% INFO    : Updated Thermal Rating: on transformer 25844-25843 : Rate B, Rate C - 0.0, 0.0 -> 287.24, 287.24
% INFO    : Updated Thermal Rating: on transformer 25843-25847 : Rate B, Rate C - 0.0, 0.0 -> 1046.7, 1046.7
% INFO    : Updated Thermal Rating: on line 25844-25913 : Rate B, Rate C - 0.0, 0.0 -> 208.3, 208.3
% INFO    : Updated Thermal Rating: on transformer 25845-25847 : Rate B, Rate C - 0.0, 0.0 -> 523.35, 523.35
% INFO    : Updated Thermal Rating: on transformer 25846-25847 : Rate B, Rate C - 0.0, 0.0 -> 523.35, 523.35
% INFO    : Updated Thermal Rating: on line 25848-26143 : Rate B, Rate C - 0.0, 0.0 -> 1160.16, 1160.16
% INFO    : Updated Thermal Rating: on transformer 25851-25850 : Rate B, Rate C - 0.0, 0.0 -> 380.37, 380.37
% INFO    : Updated Thermal Rating: on transformer 25850-25852 : Rate B, Rate C - 0.0, 0.0 -> 489.63, 489.63
% INFO    : Updated Thermal Rating: on line 25850-25897 : Rate B, Rate C - 0.0, 0.0 -> 1221.98, 1221.98
% INFO    : Updated Thermal Rating: on line 25850-25990 : Rate B, Rate C - 0.0, 0.0 -> 1226.32, 1226.32
% INFO    : Updated Thermal Rating: on line 25850-26228 : Rate B, Rate C - 0.0, 0.0 -> 1263.2, 1263.2
% INFO    : Updated Thermal Rating: on transformer 25853-25856 : Rate B, Rate C - 0.0, 0.0 -> 284.62, 284.62
% INFO    : Updated Thermal Rating: on line 25853-25858 : Rate B, Rate C - 0.0, 0.0 -> 193.01, 193.01
% INFO    : Updated Thermal Rating: on line 25853-26192 : Rate B, Rate C - 0.0, 0.0 -> 222.55, 222.55
% INFO    : Updated Thermal Rating: on transformer 25854-25856 : Rate B, Rate C - 0.0, 0.0 -> 142.31, 142.31
% INFO    : Updated Thermal Rating: on transformer 25855-25856 : Rate B, Rate C - 0.0, 0.0 -> 142.31, 142.31
% INFO    : Updated Thermal Rating: on line 25973-25858 : Rate B, Rate C - 0.0, 0.0 -> 248.1, 248.1
% INFO    : Updated Thermal Rating: on transformer 25859-25862 : Rate B, Rate C - 0.0, 0.0 -> 428.78, 428.78
% INFO    : Updated Thermal Rating: on transformer 25859-25863 : Rate B, Rate C - 0.0, 0.0 -> 470.02, 470.02
% INFO    : Updated Thermal Rating: on line 26010-25859 : Rate B, Rate C - 0.0, 0.0 -> 1171.31, 1171.31
% INFO    : Updated Thermal Rating: on line 26087-25859 : Rate B, Rate C - 0.0, 0.0 -> 1139.92, 1139.92
% INFO    : Updated Thermal Rating: on transformer 25860-25862 : Rate B, Rate C - 0.0, 0.0 -> 353.78, 353.78
% INFO    : Updated Thermal Rating: on line 25860-25899 : Rate B, Rate C - 0.0, 0.0 -> 220.39, 220.39
% INFO    : Updated Thermal Rating: on transformer 25861-25862 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 25865-25864 : Rate B, Rate C - 0.0, 0.0 -> 1285.24, 1285.24
% INFO    : Updated Thermal Rating: on transformer 25864-25867 : Rate B, Rate C - 0.0, 0.0 -> 1356.5, 1356.5
% INFO    : Updated Thermal Rating: on transformer 25864-25868 : Rate B, Rate C - 0.0, 0.0 -> 1355.43, 1355.43
% INFO    : Updated Thermal Rating: on line 25884-25864 : Rate B, Rate C - 0.0, 0.0 -> 4013.08, 4013.08
% INFO    : Updated Thermal Rating: on line 25864-26125 : Rate B, Rate C - 0.0, 0.0 -> 4161.78, 4161.78
% INFO    : Updated Thermal Rating: on transformer 25866-25865 : Rate B, Rate C - 0.0, 0.0 -> 384.63, 384.63
% INFO    : Updated Thermal Rating: on line 25865-25936 : Rate B, Rate C - 0.0, 0.0 -> 1280.82, 1280.82
% INFO    : Updated Thermal Rating: on line 25865-25956 : Rate B, Rate C - 0.0, 0.0 -> 1166.73, 1166.73
% INFO    : Updated Thermal Rating: on line 25866-25900 : Rate B, Rate C - 0.0, 0.0 -> 252.14, 252.14
% INFO    : Updated Thermal Rating: on line 25994-25866 : Rate B, Rate C - 0.0, 0.0 -> 238.65, 238.65
% INFO    : Updated Thermal Rating: on line 25866-25997 : Rate B, Rate C - 0.0, 0.0 -> 194.4, 194.4
% INFO    : Updated Thermal Rating: on line 25866-26003 : Rate B, Rate C - 0.0, 0.0 -> 320.0, 320.0
% INFO    : Updated Thermal Rating: on transformer 25870-25869 : Rate B, Rate C - 0.0, 0.0 -> 289.8, 289.8
% INFO    : Updated Thermal Rating: on transformer 25869-25873 : Rate B, Rate C - 0.0, 0.0 -> 942.51, 942.51
% INFO    : Updated Thermal Rating: on line 25869-28460 : Rate B, Rate C - 0.0, 0.0 -> 1140.57, 1140.57
% INFO    : Updated Thermal Rating: on line 25869-28718 : Rate B, Rate C - 0.0, 0.0 -> 1292.7, 1292.7
% INFO    : Updated Thermal Rating: on line 25978-25870 : Rate B, Rate C - 0.0, 0.0 -> 236.25, 236.25
% INFO    : Updated Thermal Rating: on line 25870-26111 : Rate B, Rate C - 0.0, 0.0 -> 227.17, 227.17
% INFO    : Updated Thermal Rating: on line 25870-28645 : Rate B, Rate C - 0.0, 0.0 -> 189.98, 189.98
% INFO    : Updated Thermal Rating: on transformer 25871-25873 : Rate B, Rate C - 0.0, 0.0 -> 471.25, 471.25
% INFO    : Updated Thermal Rating: on transformer 25872-25873 : Rate B, Rate C - 0.0, 0.0 -> 471.25, 471.25
% INFO    : Updated Thermal Rating: on transformer 25875-25874 : Rate B, Rate C - 0.0, 0.0 -> 617.57, 617.57
% INFO    : Updated Thermal Rating: on transformer 25875-25874 : Rate B, Rate C - 0.0, 0.0 -> 617.57, 617.57
% INFO    : Updated Thermal Rating: on transformer 25875-25874 : Rate B, Rate C - 0.0, 0.0 -> 617.57, 617.57
% INFO    : Updated Thermal Rating: on line 25874-25972 : Rate B, Rate C - 0.0, 0.0 -> 1120.83, 1120.83
% INFO    : Updated Thermal Rating: on line 25988-25874 : Rate B, Rate C - 0.0, 0.0 -> 1288.9, 1288.9
% INFO    : Updated Thermal Rating: on line 26021-25874 : Rate B, Rate C - 0.0, 0.0 -> 1144.0, 1144.0
% INFO    : Updated Thermal Rating: on transformer 25877-25876 : Rate B, Rate C - 0.0, 0.0 -> 1609.63, 1609.63
% INFO    : Updated Thermal Rating: on transformer 25877-25876 : Rate B, Rate C - 0.0, 0.0 -> 1609.63, 1609.63
% INFO    : Updated Thermal Rating: on transformer 25877-25876 : Rate B, Rate C - 0.0, 0.0 -> 1609.63, 1609.63
% INFO    : Updated Thermal Rating: on transformer 25878-25877 : Rate B, Rate C - 0.0, 0.0 -> 537.48, 537.48
% INFO    : Updated Thermal Rating: on line 25877-25930 : Rate B, Rate C - 0.0, 0.0 -> 1164.8, 1164.8
% INFO    : Updated Thermal Rating: on line 25877-26024 : Rate B, Rate C - 0.0, 0.0 -> 1227.61, 1227.61
% INFO    : Updated Thermal Rating: on line 26075-25877 : Rate B, Rate C - 0.0, 0.0 -> 1194.86, 1194.86
% INFO    : Updated Thermal Rating: on line 25877-28118 : Rate B, Rate C - 0.0, 0.0 -> 1240.3, 1240.3
% INFO    : Updated Thermal Rating: on line 25877-29079 : Rate B, Rate C - 0.0, 0.0 -> 1186.46, 1186.46
% INFO    : Updated Thermal Rating: on line 25879-26204 : Rate B, Rate C - 0.0, 0.0 -> 4094.74, 4094.74
% INFO    : Updated Thermal Rating: on line 25879-28794 : Rate B, Rate C - 0.0, 0.0 -> 3982.98, 3982.98
% INFO    : Updated Thermal Rating: on transformer 25880-25881 : Rate B, Rate C - 0.0, 0.0 -> 97.91, 97.91
% INFO    : Updated Thermal Rating: on transformer 25885-25884 : Rate B, Rate C - 0.0, 0.0 -> 1510.81, 1510.81
% INFO    : Updated Thermal Rating: on transformer 25884-25887 : Rate B, Rate C - 0.0, 0.0 -> 1602.23, 1602.23
% INFO    : Updated Thermal Rating: on line 25909-25884 : Rate B, Rate C - 0.0, 0.0 -> 4162.68, 4162.68
% INFO    : Updated Thermal Rating: on line 25884-26058 : Rate B, Rate C - 0.0, 0.0 -> 4123.37, 4123.37
% INFO    : Updated Thermal Rating: on transformer 25886-25885 : Rate B, Rate C - 0.0, 0.0 -> 340.85, 340.85
% INFO    : Updated Thermal Rating: on line 25885-25990 : Rate B, Rate C - 0.0, 0.0 -> 1242.54, 1242.54
% INFO    : Updated Thermal Rating: on line 26195-25885 : Rate B, Rate C - 0.0, 0.0 -> 1210.4, 1210.4
% INFO    : Updated Thermal Rating: on line 26236-25886 : Rate B, Rate C - 0.0, 0.0 -> 210.35, 210.35
% INFO    : Updated Thermal Rating: on transformer 25888-25889 : Rate B, Rate C - 0.0, 0.0 -> 107.05, 107.05
% INFO    : Updated Thermal Rating: on line 25888-25985 : Rate B, Rate C - 0.0, 0.0 -> 210.6, 210.6
% INFO    : Updated Thermal Rating: on line 25962-25890 : Rate B, Rate C - 0.0, 0.0 -> 204.26, 204.26
% INFO    : Updated Thermal Rating: on transformer 25891-25892 : Rate B, Rate C - 0.0, 0.0 -> 89.16, 89.16
% INFO    : Updated Thermal Rating: on line 25893-26037 : Rate B, Rate C - 0.0, 0.0 -> 230.39, 230.39
% INFO    : Updated Thermal Rating: on transformer 25895-25894 : Rate B, Rate C - 0.0, 0.0 -> 382.14, 382.14
% INFO    : Updated Thermal Rating: on transformer 25894-25896 : Rate B, Rate C - 0.0, 0.0 -> 444.86, 444.86
% INFO    : Updated Thermal Rating: on line 25895-26046 : Rate B, Rate C - 0.0, 0.0 -> 231.9, 231.9
% INFO    : Updated Thermal Rating: on line 25897-26010 : Rate B, Rate C - 0.0, 0.0 -> 1181.1, 1181.1
% INFO    : Updated Thermal Rating: on line 26088-25899 : Rate B, Rate C - 0.0, 0.0 -> 205.99, 205.99
% INFO    : Updated Thermal Rating: on transformer 25902-25901 : Rate B, Rate C - 0.0, 0.0 -> 1469.73, 1469.73
% INFO    : Updated Thermal Rating: on transformer 25901-25904 : Rate B, Rate C - 0.0, 0.0 -> 1365.79, 1365.79
% INFO    : Updated Thermal Rating: on transformer 25901-25905 : Rate B, Rate C - 0.0, 0.0 -> 1364.74, 1364.74
% INFO    : Updated Thermal Rating: on transformer 25901-25906 : Rate B, Rate C - 0.0, 0.0 -> 1363.66, 1363.66
% INFO    : Updated Thermal Rating: on transformer 25901-25907 : Rate B, Rate C - 0.0, 0.0 -> 1360.05, 1360.05
% INFO    : Updated Thermal Rating: on transformer 25901-25908 : Rate B, Rate C - 0.0, 0.0 -> 1359.67, 1359.67
% INFO    : Updated Thermal Rating: on transformer 25903-25902 : Rate B, Rate C - 0.0, 0.0 -> 368.94, 368.94
% INFO    : Updated Thermal Rating: on line 25902-26083 : Rate B, Rate C - 0.0, 0.0 -> 1261.91, 1261.91
% INFO    : Updated Thermal Rating: on line 25909-26048 : Rate B, Rate C - 0.0, 0.0 -> 4177.77, 4177.77
% INFO    : Updated Thermal Rating: on line 25909-26160 : Rate B, Rate C - 0.0, 0.0 -> 4185.64, 4185.64
% INFO    : Updated Thermal Rating: on line 25909-26204 : Rate B, Rate C - 0.0, 0.0 -> 4245.24, 4245.24
% INFO    : Updated Thermal Rating: on transformer 25910-25911 : Rate B, Rate C - 0.0, 0.0 -> 71.67, 71.67
% INFO    : Updated Thermal Rating: on line 25910-25943 : Rate B, Rate C - 0.0, 0.0 -> 208.92, 208.92
% INFO    : Updated Thermal Rating: on transformer 25913-25914 : Rate B, Rate C - 0.0, 0.0 -> 82.64, 82.64
% INFO    : Updated Thermal Rating: on line 26230-25913 : Rate B, Rate C - 0.0, 0.0 -> 169.5, 169.5
% INFO    : Updated Thermal Rating: on line 26034-25915 : Rate B, Rate C - 0.0, 0.0 -> 200.85, 200.85
% INFO    : Updated Thermal Rating: on line 25916-26045 : Rate B, Rate C - 0.0, 0.0 -> 187.67, 187.67
% INFO    : Updated Thermal Rating: on line 26127-25916 : Rate B, Rate C - 0.0, 0.0 -> 196.54, 196.54
% INFO    : Updated Thermal Rating: on line 25967-25917 : Rate B, Rate C - 0.0, 0.0 -> 216.31, 216.31
% INFO    : Updated Thermal Rating: on line 25997-25917 : Rate B, Rate C - 0.0, 0.0 -> 192.98, 192.98
% INFO    : Updated Thermal Rating: on transformer 25919-25922 : Rate B, Rate C - 0.0, 0.0 -> 561.98, 561.98
% INFO    : Updated Thermal Rating: on transformer 25919-25923 : Rate B, Rate C - 0.0, 0.0 -> 468.4, 468.4
% INFO    : Updated Thermal Rating: on transformer 25919-25924 : Rate B, Rate C - 0.0, 0.0 -> 467.4, 467.4
% INFO    : Updated Thermal Rating: on transformer 25919-25925 : Rate B, Rate C - 0.0, 0.0 -> 466.15, 466.15
% INFO    : Updated Thermal Rating: on transformer 25919-25926 : Rate B, Rate C - 0.0, 0.0 -> 463.61, 463.61
% INFO    : Updated Thermal Rating: on line 25919-26213 : Rate B, Rate C - 0.0, 0.0 -> 968.29, 968.29
% INFO    : Updated Thermal Rating: on transformer 25920-25922 : Rate B, Rate C - 0.0, 0.0 -> 461.98, 461.98
% INFO    : Updated Thermal Rating: on line 25920-25937 : Rate B, Rate C - 0.0, 0.0 -> 217.49, 217.49
% INFO    : Updated Thermal Rating: on line 26214-25920 : Rate B, Rate C - 0.0, 0.0 -> 247.88, 247.88
% INFO    : Updated Thermal Rating: on transformer 25921-25922 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 25928-25973 : Rate B, Rate C - 0.0, 0.0 -> 215.26, 215.26
% INFO    : Updated Thermal Rating: on transformer 25931-25930 : Rate B, Rate C - 0.0, 0.0 -> 568.82, 568.82
% INFO    : Updated Thermal Rating: on transformer 25930-25932 : Rate B, Rate C - 0.0, 0.0 -> 379.54, 379.54
% INFO    : Updated Thermal Rating: on transformer 25931-25933 : Rate B, Rate C - 0.0, 0.0 -> 41.87, 41.87
% INFO    : Updated Thermal Rating: on transformer 25935-25934 : Rate B, Rate C - 0.0, 0.0 -> 371.28, 371.28
% INFO    : Updated Thermal Rating: on line 25935-26211 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 25936-25990 : Rate B, Rate C - 0.0, 0.0 -> 1240.12, 1240.12
% INFO    : Updated Thermal Rating: on line 26118-25936 : Rate B, Rate C - 0.0, 0.0 -> 1327.46, 1327.46
% INFO    : Updated Thermal Rating: on transformer 25937-25938 : Rate B, Rate C - 0.0, 0.0 -> 444.6, 444.6
% INFO    : Updated Thermal Rating: on transformer 25939-25940 : Rate B, Rate C - 0.0, 0.0 -> 99.89, 99.89
% INFO    : Updated Thermal Rating: on transformer 25939-25941 : Rate B, Rate C - 0.0, 0.0 -> 11.05, 11.05
% INFO    : Updated Thermal Rating: on line 25977-25942 : Rate B, Rate C - 0.0, 0.0 -> 211.91, 211.91
% INFO    : Updated Thermal Rating: on line 25942-26011 : Rate B, Rate C - 0.0, 0.0 -> 238.84, 238.84
% INFO    : Updated Thermal Rating: on line 26151-25944 : Rate B, Rate C - 0.0, 0.0 -> 221.2, 221.2
% INFO    : Updated Thermal Rating: on line 25944-26236 : Rate B, Rate C - 0.0, 0.0 -> 260.14, 260.14
% INFO    : Updated Thermal Rating: on transformer 25946-25945 : Rate B, Rate C - 0.0, 0.0 -> 356.29, 356.29
% INFO    : Updated Thermal Rating: on transformer 25945-25949 : Rate B, Rate C - 0.0, 0.0 -> 620.28, 620.28
% INFO    : Updated Thermal Rating: on transformer 25945-25950 : Rate B, Rate C - 0.0, 0.0 -> 358.32, 358.32
% INFO    : Updated Thermal Rating: on transformer 25945-25951 : Rate B, Rate C - 0.0, 0.0 -> 348.08, 348.08
% INFO    : Updated Thermal Rating: on transformer 25945-25954 : Rate B, Rate C - 0.0, 0.0 -> 308.95, 308.95
% INFO    : Updated Thermal Rating: on transformer 25946-25952 : Rate B, Rate C - 0.0, 0.0 -> 59.81, 59.81
% INFO    : Updated Thermal Rating: on transformer 25946-25953 : Rate B, Rate C - 0.0, 0.0 -> 55.88, 55.88
% INFO    : Updated Thermal Rating: on transformer 25946-25955 : Rate B, Rate C - 0.0, 0.0 -> 11.21, 11.21
% INFO    : Updated Thermal Rating: on line 25946-25976 : Rate B, Rate C - 0.0, 0.0 -> 204.65, 204.65
% INFO    : Updated Thermal Rating: on transformer 25947-25949 : Rate B, Rate C - 0.0, 0.0 -> 310.14, 310.14
% INFO    : Updated Thermal Rating: on transformer 25948-25949 : Rate B, Rate C - 0.0, 0.0 -> 310.14, 310.14
% INFO    : Updated Thermal Rating: on line 25956-25971 : Rate B, Rate C - 0.0, 0.0 -> 1055.63, 1055.63
% INFO    : Updated Thermal Rating: on line 26118-25956 : Rate B, Rate C - 0.0, 0.0 -> 1033.53, 1033.53
% INFO    : Updated Thermal Rating: on line 25958-25967 : Rate B, Rate C - 0.0, 0.0 -> 231.53, 231.53
% INFO    : Updated Thermal Rating: on transformer 25959-25960 : Rate B, Rate C - 0.0, 0.0 -> 59.64, 59.64
% INFO    : Updated Thermal Rating: on transformer 25959-25961 : Rate B, Rate C - 0.0, 0.0 -> 59.41, 59.41
% INFO    : Updated Thermal Rating: on line 25959-25962 : Rate B, Rate C - 0.0, 0.0 -> 181.68, 181.68
% INFO    : Updated Thermal Rating: on line 25959-25981 : Rate B, Rate C - 0.0, 0.0 -> 230.49, 230.49
% INFO    : Updated Thermal Rating: on transformer 25962-25965 : Rate B, Rate C - 0.0, 0.0 -> 244.93, 244.93
% INFO    : Updated Thermal Rating: on transformer 25963-25965 : Rate B, Rate C - 0.0, 0.0 -> 122.47, 122.47
% INFO    : Updated Thermal Rating: on transformer 25964-25965 : Rate B, Rate C - 0.0, 0.0 -> 122.47, 122.47
% INFO    : Updated Thermal Rating: on transformer 25967-25966 : Rate B, Rate C - 0.0, 0.0 -> 252.64, 252.64
% INFO    : Updated Thermal Rating: on transformer 25966-25968 : Rate B, Rate C - 0.0, 0.0 -> 456.24, 456.24
% INFO    : Updated Thermal Rating: on transformer 25967-25969 : Rate B, Rate C - 0.0, 0.0 -> 54.44, 54.44
% INFO    : Updated Thermal Rating: on transformer 25967-25970 : Rate B, Rate C - 0.0, 0.0 -> 8.97, 8.97
% INFO    : Updated Thermal Rating: on line 26123-25967 : Rate B, Rate C - 0.0, 0.0 -> 236.08, 236.08
% INFO    : Updated Thermal Rating: on transformer 25973-25972 : Rate B, Rate C - 0.0, 0.0 -> 438.22, 438.22
% INFO    : Updated Thermal Rating: on transformer 25974-25975 : Rate B, Rate C - 0.0, 0.0 -> 171.6, 171.6
% INFO    : Updated Thermal Rating: on line 26003-25976 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 25977-26235 : Rate B, Rate C - 0.0, 0.0 -> 168.68, 168.68
% INFO    : Updated Thermal Rating: on line 26092-25978 : Rate B, Rate C - 0.0, 0.0 -> 251.08, 251.08
% INFO    : Updated Thermal Rating: on line 25978-28270 : Rate B, Rate C - 0.0, 0.0 -> 236.9, 236.9
% INFO    : Updated Thermal Rating: on line 25978-28869 : Rate B, Rate C - 0.0, 0.0 -> 251.98, 251.98
% INFO    : Updated Thermal Rating: on transformer 25979-25980 : Rate B, Rate C - 0.0, 0.0 -> 88.42, 88.42
% INFO    : Updated Thermal Rating: on line 26055-25981 : Rate B, Rate C - 0.0, 0.0 -> 195.09, 195.09
% INFO    : Updated Thermal Rating: on transformer 25985-25984 : Rate B, Rate C - 0.0, 0.0 -> 540.48, 540.48
% INFO    : Updated Thermal Rating: on line 25986-26126 : Rate B, Rate C - 0.0, 0.0 -> 1304.78, 1304.78
% INFO    : Updated Thermal Rating: on line 25986-26237 : Rate B, Rate C - 0.0, 0.0 -> 1213.52, 1213.52
% INFO    : Updated Thermal Rating: on transformer 25988-25987 : Rate B, Rate C - 0.0, 0.0 -> 1593.68, 1593.68
% INFO    : Updated Thermal Rating: on transformer 25988-25987 : Rate B, Rate C - 0.0, 0.0 -> 1593.68, 1593.68
% INFO    : Updated Thermal Rating: on line 26014-25987 : Rate B, Rate C - 0.0, 0.0 -> 4064.29, 4064.29
% INFO    : Updated Thermal Rating: on line 25987-26103 : Rate B, Rate C - 0.0, 0.0 -> 4104.88, 4104.88
% INFO    : Updated Thermal Rating: on line 25987-26212 : Rate B, Rate C - 0.0, 0.0 -> 4096.96, 4096.96
% INFO    : Updated Thermal Rating: on transformer 25989-25988 : Rate B, Rate C - 0.0, 0.0 -> 624.56, 624.56
% INFO    : Updated Thermal Rating: on transformer 25989-25988 : Rate B, Rate C - 0.0, 0.0 -> 624.56, 624.56
% INFO    : Updated Thermal Rating: on transformer 25989-25988 : Rate B, Rate C - 0.0, 0.0 -> 624.56, 624.56
% INFO    : Updated Thermal Rating: on line 26070-25989 : Rate B, Rate C - 0.0, 0.0 -> 237.72, 237.72
% INFO    : Updated Thermal Rating: on transformer 25990-25993 : Rate B, Rate C - 0.0, 0.0 -> 444.42, 444.42
% INFO    : Updated Thermal Rating: on transformer 25991-25993 : Rate B, Rate C - 0.0, 0.0 -> 419.42, 419.42
% INFO    : Updated Thermal Rating: on transformer 25992-25993 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 25994-25995 : Rate B, Rate C - 0.0, 0.0 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on line 26162-25998 : Rate B, Rate C - 0.0, 0.0 -> 178.6, 178.6
% INFO    : Updated Thermal Rating: on transformer 25999-26002 : Rate B, Rate C - 0.0, 0.0 -> 576.26, 576.26
% INFO    : Updated Thermal Rating: on line 25999-26126 : Rate B, Rate C - 0.0, 0.0 -> 1318.96, 1318.96
% INFO    : Updated Thermal Rating: on transformer 26000-26002 : Rate B, Rate C - 0.0, 0.0 -> 551.26, 551.26
% INFO    : Updated Thermal Rating: on transformer 26001-26002 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 26003-26004 : Rate B, Rate C - 0.0, 0.0 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on transformer 26005-26008 : Rate B, Rate C - 0.0, 0.0 -> 712.3, 712.3
% INFO    : Updated Thermal Rating: on line 26036-26005 : Rate B, Rate C - 0.0, 0.0 -> 1176.98, 1176.98
% INFO    : Updated Thermal Rating: on transformer 26006-26008 : Rate B, Rate C - 0.0, 0.0 -> 562.3, 562.3
% INFO    : Updated Thermal Rating: on transformer 26007-26008 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 26009-26013 : Rate B, Rate C - 0.0, 0.0 -> 225.29, 225.29
% INFO    : Updated Thermal Rating: on transformer 26011-26010 : Rate B, Rate C - 0.0, 0.0 -> 341.99, 341.99
% INFO    : Updated Thermal Rating: on transformer 26010-26012 : Rate B, Rate C - 0.0, 0.0 -> 505.96, 505.96
% INFO    : Updated Thermal Rating: on line 26010-26118 : Rate B, Rate C - 0.0, 0.0 -> 1126.05, 1126.05
% INFO    : Updated Thermal Rating: on line 26013-26055 : Rate B, Rate C - 0.0, 0.0 -> 224.54, 224.54
% INFO    : Updated Thermal Rating: on transformer 26015-26014 : Rate B, Rate C - 0.0, 0.0 -> 1517.25, 1517.25
% INFO    : Updated Thermal Rating: on transformer 26014-26017 : Rate B, Rate C - 0.0, 0.0 -> 1699.55, 1699.55
% INFO    : Updated Thermal Rating: on transformer 26014-26018 : Rate B, Rate C - 0.0, 0.0 -> 1696.63, 1696.63
% INFO    : Updated Thermal Rating: on transformer 26014-26019 : Rate B, Rate C - 0.0, 0.0 -> 1695.49, 1695.49
% INFO    : Updated Thermal Rating: on transformer 26014-26020 : Rate B, Rate C - 0.0, 0.0 -> 1695.05, 1695.05
% INFO    : Updated Thermal Rating: on transformer 26016-26015 : Rate B, Rate C - 0.0, 0.0 -> 522.12, 522.12
% INFO    : Updated Thermal Rating: on transformer 26023-26022 : Rate B, Rate C - 0.0, 0.0 -> 494.08, 494.08
% INFO    : Updated Thermal Rating: on line 26024-28141 : Rate B, Rate C - 0.0, 0.0 -> 1219.68, 1219.68
% INFO    : Updated Thermal Rating: on transformer 26029-26032 : Rate B, Rate C - 0.0, 0.0 -> 275.2, 275.2
% INFO    : Updated Thermal Rating: on transformer 26030-26032 : Rate B, Rate C - 0.0, 0.0 -> 137.6, 137.6
% INFO    : Updated Thermal Rating: on transformer 26031-26032 : Rate B, Rate C - 0.0, 0.0 -> 137.6, 137.6
% INFO    : Updated Thermal Rating: on transformer 26036-26035 : Rate B, Rate C - 0.0, 0.0 -> 1516.32, 1516.32
% INFO    : Updated Thermal Rating: on transformer 26035-26038 : Rate B, Rate C - 0.0, 0.0 -> 1524.88, 1524.88
% INFO    : Updated Thermal Rating: on transformer 26035-26039 : Rate B, Rate C - 0.0, 0.0 -> 1524.84, 1524.84
% INFO    : Updated Thermal Rating: on transformer 26035-26040 : Rate B, Rate C - 0.0, 0.0 -> 1345.21, 1345.21
% INFO    : Updated Thermal Rating: on line 26035-26125 : Rate B, Rate C - 0.0, 0.0 -> 4115.85, 4115.85
% INFO    : Updated Thermal Rating: on line 26035-26152 : Rate B, Rate C - 0.0, 0.0 -> 4158.61, 4158.61
% INFO    : Updated Thermal Rating: on transformer 26037-26036 : Rate B, Rate C - 0.0, 0.0 -> 434.98, 434.98
% INFO    : Updated Thermal Rating: on transformer 26041-26042 : Rate B, Rate C - 0.0, 0.0 -> 98.53, 98.53
% INFO    : Updated Thermal Rating: on transformer 26041-26043 : Rate B, Rate C - 0.0, 0.0 -> 13.0, 13.0
% INFO    : Updated Thermal Rating: on line 26041-26070 : Rate B, Rate C - 0.0, 0.0 -> 241.27, 241.27
% INFO    : Updated Thermal Rating: on transformer 26046-26047 : Rate B, Rate C - 0.0, 0.0 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on transformer 26049-26048 : Rate B, Rate C - 0.0, 0.0 -> 1401.81, 1401.81
% INFO    : Updated Thermal Rating: on transformer 26048-26051 : Rate B, Rate C - 0.0, 0.0 -> 1471.6, 1471.6
% INFO    : Updated Thermal Rating: on transformer 26048-26052 : Rate B, Rate C - 0.0, 0.0 -> 1471.33, 1471.33
% INFO    : Updated Thermal Rating: on transformer 26048-26053 : Rate B, Rate C - 0.0, 0.0 -> 1470.72, 1470.72
% INFO    : Updated Thermal Rating: on line 26048-26160 : Rate B, Rate C - 0.0, 0.0 -> 4088.49, 4088.49
% INFO    : Updated Thermal Rating: on line 26048-26204 : Rate B, Rate C - 0.0, 0.0 -> 4197.78, 4197.78
% INFO    : Updated Thermal Rating: on transformer 26050-26049 : Rate B, Rate C - 0.0, 0.0 -> 274.24, 274.24
% INFO    : Updated Thermal Rating: on line 26049-26071 : Rate B, Rate C - 0.0, 0.0 -> 1196.49, 1196.49
% INFO    : Updated Thermal Rating: on line 26167-26049 : Rate B, Rate C - 0.0, 0.0 -> 1214.04, 1214.04
% INFO    : Updated Thermal Rating: on line 26168-26050 : Rate B, Rate C - 0.0, 0.0 -> 209.8, 209.8
% INFO    : Updated Thermal Rating: on line 26050-26185 : Rate B, Rate C - 0.0, 0.0 -> 204.8, 204.8
% INFO    : Updated Thermal Rating: on transformer 26055-26054 : Rate B, Rate C - 0.0, 0.0 -> 325.5, 325.5
% INFO    : Updated Thermal Rating: on transformer 26055-26056 : Rate B, Rate C - 0.0, 0.0 -> 78.79, 78.79
% INFO    : Updated Thermal Rating: on line 26057-26090 : Rate B, Rate C - 0.0, 0.0 -> 1184.54, 1184.54
% INFO    : Updated Thermal Rating: on transformer 26059-26058 : Rate B, Rate C - 0.0, 0.0 -> 1464.46, 1464.46
% INFO    : Updated Thermal Rating: on transformer 26058-26061 : Rate B, Rate C - 0.0, 0.0 -> 1492.14, 1492.14
% INFO    : Updated Thermal Rating: on transformer 26058-26062 : Rate B, Rate C - 0.0, 0.0 -> 1490.38, 1490.38
% INFO    : Updated Thermal Rating: on transformer 26058-26063 : Rate B, Rate C - 0.0, 0.0 -> 1490.03, 1490.03
% INFO    : Updated Thermal Rating: on transformer 26058-26064 : Rate B, Rate C - 0.0, 0.0 -> 1076.7, 1076.7
% INFO    : Updated Thermal Rating: on line 26058-26125 : Rate B, Rate C - 0.0, 0.0 -> 4280.36, 4280.36
% INFO    : Updated Thermal Rating: on line 26204-26058 : Rate B, Rate C - 0.0, 0.0 -> 4122.13, 4122.13
% INFO    : Updated Thermal Rating: on transformer 26060-26059 : Rate B, Rate C - 0.0, 0.0 -> 498.16, 498.16
% INFO    : Updated Thermal Rating: on transformer 26065-26068 : Rate B, Rate C - 0.0, 0.0 -> 144.85, 144.85
% INFO    : Updated Thermal Rating: on transformer 26065-26069 : Rate B, Rate C - 0.0, 0.0 -> 30.46, 30.46
% INFO    : Updated Thermal Rating: on transformer 26066-26068 : Rate B, Rate C - 0.0, 0.0 -> 72.43, 72.43
% INFO    : Updated Thermal Rating: on transformer 26067-26068 : Rate B, Rate C - 0.0, 0.0 -> 72.43, 72.43
% INFO    : Updated Thermal Rating: on transformer 26072-26071 : Rate B, Rate C - 0.0, 0.0 -> 398.16, 398.16
% INFO    : Updated Thermal Rating: on transformer 26071-26073 : Rate B, Rate C - 0.0, 0.0 -> 320.33, 320.33
% INFO    : Updated Thermal Rating: on line 26071-26153 : Rate B, Rate C - 0.0, 0.0 -> 1199.38, 1199.38
% INFO    : Updated Thermal Rating: on line 26071-26195 : Rate B, Rate C - 0.0, 0.0 -> 1330.76, 1330.76
% INFO    : Updated Thermal Rating: on transformer 26072-26074 : Rate B, Rate C - 0.0, 0.0 -> 25.64, 25.64
% INFO    : Updated Thermal Rating: on line 26072-26218 : Rate B, Rate C - 0.0, 0.0 -> 204.35, 204.35
% INFO    : Updated Thermal Rating: on transformer 26076-26075 : Rate B, Rate C - 0.0, 0.0 -> 501.06, 501.06
% INFO    : Updated Thermal Rating: on transformer 26075-26079 : Rate B, Rate C - 0.0, 0.0 -> 707.47, 707.47
% INFO    : Updated Thermal Rating: on transformer 26077-26079 : Rate B, Rate C - 0.0, 0.0 -> 353.74, 353.74
% INFO    : Updated Thermal Rating: on transformer 26078-26079 : Rate B, Rate C - 0.0, 0.0 -> 353.74, 353.74
% INFO    : Updated Thermal Rating: on transformer 26084-26083 : Rate B, Rate C - 0.0, 0.0 -> 423.78, 423.78
% INFO    : Updated Thermal Rating: on transformer 26083-26085 : Rate B, Rate C - 0.0, 0.0 -> 396.32, 396.32
% INFO    : Updated Thermal Rating: on transformer 26083-26086 : Rate B, Rate C - 0.0, 0.0 -> 278.71, 278.71
% INFO    : Updated Thermal Rating: on line 26083-26195 : Rate B, Rate C - 0.0, 0.0 -> 1105.79, 1105.79
% INFO    : Updated Thermal Rating: on transformer 26088-26087 : Rate B, Rate C - 0.0, 0.0 -> 311.37, 311.37
% INFO    : Updated Thermal Rating: on transformer 26087-26089 : Rate B, Rate C - 0.0, 0.0 -> 503.53, 503.53
% INFO    : Updated Thermal Rating: on line 26088-26235 : Rate B, Rate C - 0.0, 0.0 -> 202.76, 202.76
% INFO    : Updated Thermal Rating: on transformer 26091-26090 : Rate B, Rate C - 0.0, 0.0 -> 389.66, 389.66
% INFO    : Updated Thermal Rating: on transformer 26092-26093 : Rate B, Rate C - 0.0, 0.0 -> 81.4, 81.4
% INFO    : Updated Thermal Rating: on transformer 26095-26094 : Rate B, Rate C - 0.0, 0.0 -> 1652.58, 1652.58
% INFO    : Updated Thermal Rating: on transformer 26095-26094 : Rate B, Rate C - 0.0, 0.0 -> 1652.58, 1652.58
% INFO    : Updated Thermal Rating: on transformer 26095-26094 : Rate B, Rate C - 0.0, 0.0 -> 1652.58, 1652.58
% INFO    : Updated Thermal Rating: on transformer 26094-26097 : Rate B, Rate C - 0.0, 0.0 -> 1684.78, 1684.78
% INFO    : Updated Thermal Rating: on transformer 26094-26098 : Rate B, Rate C - 0.0, 0.0 -> 1682.29, 1682.29
% INFO    : Updated Thermal Rating: on transformer 26094-26099 : Rate B, Rate C - 0.0, 0.0 -> 1682.03, 1682.03
% INFO    : Updated Thermal Rating: on transformer 26094-26100 : Rate B, Rate C - 0.0, 0.0 -> 1679.27, 1679.27
% INFO    : Updated Thermal Rating: on transformer 26094-26101 : Rate B, Rate C - 0.0, 0.0 -> 1676.4, 1676.4
% INFO    : Updated Thermal Rating: on transformer 26094-26102 : Rate B, Rate C - 0.0, 0.0 -> 1675.98, 1675.98
% INFO    : Updated Thermal Rating: on transformer 26096-26095 : Rate B, Rate C - 0.0, 0.0 -> 441.53, 441.53
% INFO    : Updated Thermal Rating: on line 26095-26184 : Rate B, Rate C - 0.0, 0.0 -> 1680.0, 1680.0
% INFO    : Updated Thermal Rating: on line 26095-28011 : Rate B, Rate C - 0.0, 0.0 -> 1371.37, 1371.37
% INFO    : Updated Thermal Rating: on line 26095-28023 : Rate B, Rate C - 0.0, 0.0 -> 1454.34, 1454.34
% INFO    : Updated Thermal Rating: on line 26095-28049 : Rate B, Rate C - 0.0, 0.0 -> 1290.67, 1290.67
% INFO    : Updated Thermal Rating: on line 28006-26096 : Rate B, Rate C - 0.0, 0.0 -> 412.19, 412.19
% INFO    : Updated Thermal Rating: on line 26103-29039 : Rate B, Rate C - 0.0, 0.0 -> 4036.5, 4036.5
% INFO    : Updated Thermal Rating: on transformer 26105-26104 : Rate B, Rate C - 0.0, 0.0 -> 426.98, 426.98
% INFO    : Updated Thermal Rating: on line 26104-26195 : Rate B, Rate C - 0.0, 0.0 -> 1286.64, 1286.64
% INFO    : Updated Thermal Rating: on line 26228-26104 : Rate B, Rate C - 0.0, 0.0 -> 1256.49, 1256.49
% INFO    : Updated Thermal Rating: on transformer 26105-26108 : Rate B, Rate C - 0.0, 0.0 -> 192.61, 192.61
% INFO    : Updated Thermal Rating: on line 26105-26207 : Rate B, Rate C - 0.0, 0.0 -> 245.32, 245.32
% INFO    : Updated Thermal Rating: on transformer 26106-26108 : Rate B, Rate C - 0.0, 0.0 -> 96.31, 96.31
% INFO    : Updated Thermal Rating: on transformer 26107-26108 : Rate B, Rate C - 0.0, 0.0 -> 96.31, 96.31
% INFO    : Updated Thermal Rating: on transformer 26109-26110 : Rate B, Rate C - 0.0, 0.0 -> 85.47, 85.47
% INFO    : Updated Thermal Rating: on transformer 26112-26115 : Rate B, Rate C - 0.0, 0.0 -> 506.71, 506.71
% INFO    : Updated Thermal Rating: on transformer 26112-26116 : Rate B, Rate C - 0.0, 0.0 -> 505.29, 505.29
% INFO    : Updated Thermal Rating: on transformer 26112-26117 : Rate B, Rate C - 0.0, 0.0 -> 421.52, 421.52
% INFO    : Updated Thermal Rating: on transformer 26113-26115 : Rate B, Rate C - 0.0, 0.0 -> 356.71, 356.71
% INFO    : Updated Thermal Rating: on line 26113-26211 : Rate B, Rate C - 0.0, 0.0 -> 233.78, 233.78
% INFO    : Updated Thermal Rating: on line 26113-26235 : Rate B, Rate C - 0.0, 0.0 -> 257.26, 257.26
% INFO    : Updated Thermal Rating: on transformer 26114-26115 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 26119-26120 : Rate B, Rate C - 0.0, 0.0 -> 117.0, 117.0
% INFO    : Updated Thermal Rating: on transformer 26119-26121 : Rate B, Rate C - 0.0, 0.0 -> 14.76, 14.76
% INFO    : Updated Thermal Rating: on transformer 26119-26122 : Rate B, Rate C - 0.0, 0.0 -> 38.53, 38.53
% INFO    : Updated Thermal Rating: on transformer 26126-26125 : Rate B, Rate C - 0.0, 0.0 -> 1827.89, 1827.89
% INFO    : Updated Thermal Rating: on transformer 26126-26125 : Rate B, Rate C - 0.0, 0.0 -> 3000.0, 3000.0
% INFO    : Updated Thermal Rating: on transformer 26126-26125 : Rate B, Rate C - 0.0, 0.0 -> 1827.89, 1827.89
% INFO    : Updated Thermal Rating: on transformer 26126-26125 : Rate B, Rate C - 0.0, 0.0 -> 1827.89, 1827.89
% INFO    : Updated Thermal Rating: on transformer 26126-26125 : Rate B, Rate C - 0.0, 0.0 -> 3000.0, 3000.0
% INFO    : Updated Thermal Rating: on transformer 26125-26128 : Rate B, Rate C - 0.0, 0.0 -> 1452.53, 1452.53
% INFO    : Updated Thermal Rating: on transformer 26125-26129 : Rate B, Rate C - 0.0, 0.0 -> 1452.09, 1452.09
% INFO    : Updated Thermal Rating: on line 26125-26204 : Rate B, Rate C - 0.0, 0.0 -> 4133.54, 4133.54
% INFO    : Updated Thermal Rating: on transformer 26127-26126 : Rate B, Rate C - 0.0, 0.0 -> 521.0, 521.0
% INFO    : Updated Thermal Rating: on line 26237-26126 : Rate B, Rate C - 0.0, 0.0 -> 1384.25, 1384.25
% INFO    : Updated Thermal Rating: on transformer 26131-26130 : Rate B, Rate C - 0.0, 0.0 -> 1555.44, 1555.44
% INFO    : Updated Thermal Rating: on transformer 26130-26133 : Rate B, Rate C - 0.0, 0.0 -> 1952.82, 1952.82
% INFO    : Updated Thermal Rating: on transformer 26130-26134 : Rate B, Rate C - 0.0, 0.0 -> 1905.41, 1905.41
% INFO    : Updated Thermal Rating: on transformer 26132-26131 : Rate B, Rate C - 0.0, 0.0 -> 476.18, 476.18
% INFO    : Updated Thermal Rating: on line 26142-26135 : Rate B, Rate C - 0.0, 0.0 -> 4098.3, 4098.3
% INFO    : Updated Thermal Rating: on line 26135-26160 : Rate B, Rate C - 0.0, 0.0 -> 4113.38, 4113.38
% INFO    : Updated Thermal Rating: on transformer 26137-26140 : Rate B, Rate C - 0.0, 0.0 -> 187.76, 187.76
% INFO    : Updated Thermal Rating: on transformer 26137-26141 : Rate B, Rate C - 0.0, 0.0 -> 43.17, 43.17
% INFO    : Updated Thermal Rating: on transformer 26138-26140 : Rate B, Rate C - 0.0, 0.0 -> 93.88, 93.88
% INFO    : Updated Thermal Rating: on transformer 26139-26140 : Rate B, Rate C - 0.0, 0.0 -> 93.88, 93.88
% INFO    : Updated Thermal Rating: on transformer 26143-26142 : Rate B, Rate C - 0.0, 0.0 -> 1397.92, 1397.92
% INFO    : Updated Thermal Rating: on transformer 26142-26145 : Rate B, Rate C - 0.0, 0.0 -> 1253.1, 1253.1
% INFO    : Updated Thermal Rating: on transformer 26142-26146 : Rate B, Rate C - 0.0, 0.0 -> 1252.9, 1252.9
% INFO    : Updated Thermal Rating: on transformer 26142-26147 : Rate B, Rate C - 0.0, 0.0 -> 1252.16, 1252.16
% INFO    : Updated Thermal Rating: on transformer 26142-26148 : Rate B, Rate C - 0.0, 0.0 -> 1250.83, 1250.83
% INFO    : Updated Thermal Rating: on transformer 26142-26149 : Rate B, Rate C - 0.0, 0.0 -> 1248.85, 1248.85
% INFO    : Updated Thermal Rating: on line 26142-26160 : Rate B, Rate C - 0.0, 0.0 -> 4129.09, 4129.09
% INFO    : Updated Thermal Rating: on transformer 26144-26143 : Rate B, Rate C - 0.0, 0.0 -> 356.68, 356.68
% INFO    : Updated Thermal Rating: on transformer 26152-26156 : Rate B, Rate C - 0.0, 0.0 -> 1543.19, 1543.19
% INFO    : Updated Thermal Rating: on transformer 26152-26157 : Rate B, Rate C - 0.0, 0.0 -> 1546.49, 1546.49
% INFO    : Updated Thermal Rating: on transformer 26152-26158 : Rate B, Rate C - 0.0, 0.0 -> 1469.72, 1469.72
% INFO    : Updated Thermal Rating: on transformer 26152-26159 : Rate B, Rate C - 0.0, 0.0 -> 1466.96, 1466.96
% INFO    : Updated Thermal Rating: on line 26160-26152 : Rate B, Rate C - 0.0, 0.0 -> 4126.36, 4126.36
% INFO    : Updated Thermal Rating: on transformer 26154-26153 : Rate B, Rate C - 0.0, 0.0 -> 376.11, 376.11
% INFO    : Updated Thermal Rating: on transformer 26153-26156 : Rate B, Rate C - 0.0, 0.0 -> 1393.19, 1393.19
% INFO    : Updated Thermal Rating: on line 26153-26161 : Rate B, Rate C - 0.0, 0.0 -> 1226.0, 1226.0
% INFO    : Updated Thermal Rating: on line 26153-26167 : Rate B, Rate C - 0.0, 0.0 -> 1064.5, 1064.5
% INFO    : Updated Thermal Rating: on transformer 26155-26156 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 26161-26160 : Rate B, Rate C - 0.0, 0.0 -> 1421.43, 1421.43
% INFO    : Updated Thermal Rating: on transformer 26160-26163 : Rate B, Rate C - 0.0, 0.0 -> 1789.62, 1789.62
% INFO    : Updated Thermal Rating: on transformer 26160-26164 : Rate B, Rate C - 0.0, 0.0 -> 1668.82, 1668.82
% INFO    : Updated Thermal Rating: on transformer 26160-26165 : Rate B, Rate C - 0.0, 0.0 -> 1656.05, 1656.05
% INFO    : Updated Thermal Rating: on transformer 26160-26166 : Rate B, Rate C - 0.0, 0.0 -> 1654.12, 1654.12
% INFO    : Updated Thermal Rating: on transformer 26162-26161 : Rate B, Rate C - 0.0, 0.0 -> 328.06, 328.06
% INFO    : Updated Thermal Rating: on transformer 26167-26170 : Rate B, Rate C - 0.0, 0.0 -> 362.62, 362.62
% INFO    : Updated Thermal Rating: on line 26229-26167 : Rate B, Rate C - 0.0, 0.0 -> 1107.78, 1107.78
% INFO    : Updated Thermal Rating: on transformer 26168-26170 : Rate B, Rate C - 0.0, 0.0 -> 337.62, 337.62
% INFO    : Updated Thermal Rating: on transformer 26169-26170 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 26172-26171 : Rate B, Rate C - 0.0, 0.0 -> 647.89, 647.89
% INFO    : Updated Thermal Rating: on transformer 26172-26171 : Rate B, Rate C - 0.0, 0.0 -> 647.89, 647.89
% INFO    : Updated Thermal Rating: on transformer 26172-26171 : Rate B, Rate C - 0.0, 0.0 -> 647.89, 647.89
% INFO    : Updated Thermal Rating: on transformer 26172-26171 : Rate B, Rate C - 0.0, 0.0 -> 647.89, 647.89
% INFO    : Updated Thermal Rating: on transformer 26171-26173 : Rate B, Rate C - 0.0, 0.0 -> 541.43, 541.43
% INFO    : Updated Thermal Rating: on transformer 26171-26174 : Rate B, Rate C - 0.0, 0.0 -> 538.63, 538.63
% INFO    : Updated Thermal Rating: on transformer 26171-26175 : Rate B, Rate C - 0.0, 0.0 -> 532.18, 532.18
% INFO    : Updated Thermal Rating: on transformer 26171-26176 : Rate B, Rate C - 0.0, 0.0 -> 531.58, 531.58
% INFO    : Updated Thermal Rating: on transformer 26171-26177 : Rate B, Rate C - 0.0, 0.0 -> 531.01, 531.01
% INFO    : Updated Thermal Rating: on transformer 26171-26178 : Rate B, Rate C - 0.0, 0.0 -> 444.19, 444.19
% INFO    : Updated Thermal Rating: on transformer 26171-26179 : Rate B, Rate C - 0.0, 0.0 -> 442.59, 442.59
% INFO    : Updated Thermal Rating: on transformer 26171-26180 : Rate B, Rate C - 0.0, 0.0 -> 440.44, 440.44
% INFO    : Updated Thermal Rating: on transformer 26171-26181 : Rate B, Rate C - 0.0, 0.0 -> 439.99, 439.99
% INFO    : Updated Thermal Rating: on transformer 26171-26182 : Rate B, Rate C - 0.0, 0.0 -> 439.56, 439.56
% INFO    : Updated Thermal Rating: on transformer 26171-26183 : Rate B, Rate C - 0.0, 0.0 -> 439.49, 439.49
% INFO    : Updated Thermal Rating: on line 26172-28003 : Rate B, Rate C - 0.0, 0.0 -> 274.08, 274.08
% INFO    : Updated Thermal Rating: on line 26172-28003 : Rate B, Rate C - 0.0, 0.0 -> 274.08, 274.08
% INFO    : Updated Thermal Rating: on line 28006-26172 : Rate B, Rate C - 0.0, 0.0 -> 219.2, 219.2
% INFO    : Updated Thermal Rating: on line 26184-28023 : Rate B, Rate C - 0.0, 0.0 -> 1375.0, 1375.0
% INFO    : Updated Thermal Rating: on transformer 26186-26189 : Rate B, Rate C - 0.0, 0.0 -> 99.05, 99.05
% INFO    : Updated Thermal Rating: on transformer 26186-26190 : Rate B, Rate C - 0.0, 0.0 -> 105.31, 105.31
% INFO    : Updated Thermal Rating: on transformer 26186-26191 : Rate B, Rate C - 0.0, 0.0 -> 69.9, 69.9
% INFO    : Updated Thermal Rating: on transformer 26187-26189 : Rate B, Rate C - 0.0, 0.0 -> 49.53, 49.53
% INFO    : Updated Thermal Rating: on transformer 26188-26189 : Rate B, Rate C - 0.0, 0.0 -> 49.53, 49.53
% INFO    : Updated Thermal Rating: on transformer 26195-26194 : Rate B, Rate C - 0.0, 0.0 -> 1601.13, 1601.13
% INFO    : Updated Thermal Rating: on transformer 26195-26194 : Rate B, Rate C - 0.0, 0.0 -> 1601.13, 1601.13
% INFO    : Updated Thermal Rating: on transformer 26195-26194 : Rate B, Rate C - 0.0, 0.0 -> 1601.13, 1601.13
% INFO    : Updated Thermal Rating: on transformer 26194-26197 : Rate B, Rate C - 0.0, 0.0 -> 1619.35, 1619.35
% INFO    : Updated Thermal Rating: on transformer 26194-26198 : Rate B, Rate C - 0.0, 0.0 -> 1618.58, 1618.58
% INFO    : Updated Thermal Rating: on transformer 26194-26199 : Rate B, Rate C - 0.0, 0.0 -> 1613.93, 1613.93
% INFO    : Updated Thermal Rating: on transformer 26194-26200 : Rate B, Rate C - 0.0, 0.0 -> 1610.52, 1610.52
% INFO    : Updated Thermal Rating: on transformer 26194-26201 : Rate B, Rate C - 0.0, 0.0 -> 1606.62, 1606.62
% INFO    : Updated Thermal Rating: on transformer 26194-26202 : Rate B, Rate C - 0.0, 0.0 -> 1606.32, 1606.32
% INFO    : Updated Thermal Rating: on transformer 26194-26203 : Rate B, Rate C - 0.0, 0.0 -> 1073.58, 1073.58
% INFO    : Updated Thermal Rating: on transformer 26196-26195 : Rate B, Rate C - 0.0, 0.0 -> 506.26, 506.26
% INFO    : Updated Thermal Rating: on line 26195-26228 : Rate B, Rate C - 0.0, 0.0 -> 1275.08, 1275.08
% INFO    : Updated Thermal Rating: on transformer 26206-26205 : Rate B, Rate C - 0.0, 0.0 -> 386.16, 386.16
% INFO    : Updated Thermal Rating: on transformer 26207-26208 : Rate B, Rate C - 0.0, 0.0 -> 77.11, 77.11
% INFO    : Updated Thermal Rating: on transformer 26209-26210 : Rate B, Rate C - 0.0, 0.0 -> 132.6, 132.6
% INFO    : Updated Thermal Rating: on transformer 26213-26212 : Rate B, Rate C - 0.0, 0.0 -> 1503.53, 1503.53
% INFO    : Updated Thermal Rating: on transformer 26212-26215 : Rate B, Rate C - 0.0, 0.0 -> 1623.71, 1623.71
% INFO    : Updated Thermal Rating: on transformer 26212-26216 : Rate B, Rate C - 0.0, 0.0 -> 1622.57, 1622.57
% INFO    : Updated Thermal Rating: on transformer 26212-26217 : Rate B, Rate C - 0.0, 0.0 -> 1620.91, 1620.91
% INFO    : Updated Thermal Rating: on transformer 26214-26213 : Rate B, Rate C - 0.0, 0.0 -> 532.93, 532.93
% INFO    : Updated Thermal Rating: on transformer 26218-26219 : Rate B, Rate C - 0.0, 0.0 -> 78.55, 78.55
% INFO    : Updated Thermal Rating: on transformer 26221-26220 : Rate B, Rate C - 0.0, 0.0 -> 420.31, 420.31
% INFO    : Updated Thermal Rating: on transformer 26220-26224 : Rate B, Rate C - 0.0, 0.0 -> 629.73, 629.73
% INFO    : Updated Thermal Rating: on transformer 26220-26226 : Rate B, Rate C - 0.0, 0.0 -> 299.38, 299.38
% INFO    : Updated Thermal Rating: on transformer 26220-26227 : Rate B, Rate C - 0.0, 0.0 -> 290.52, 290.52
% INFO    : Updated Thermal Rating: on transformer 26221-26225 : Rate B, Rate C - 0.0, 0.0 -> 18.45, 18.45
% INFO    : Updated Thermal Rating: on transformer 26222-26224 : Rate B, Rate C - 0.0, 0.0 -> 314.86, 314.86
% INFO    : Updated Thermal Rating: on transformer 26223-26224 : Rate B, Rate C - 0.0, 0.0 -> 314.86, 314.86
% INFO    : Updated Thermal Rating: on transformer 26229-26232 : Rate B, Rate C - 0.0, 0.0 -> 402.45, 402.45
% INFO    : Updated Thermal Rating: on transformer 26230-26232 : Rate B, Rate C - 0.0, 0.0 -> 377.45, 377.45
% INFO    : Updated Thermal Rating: on transformer 26231-26232 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 26233-26234 : Rate B, Rate C - 0.0, 0.0 -> 179.4, 179.4
% INFO    : Updated Thermal Rating: on transformer 26238-26237 : Rate B, Rate C - 0.0, 0.0 -> 464.56, 464.56
% INFO    : Updated Thermal Rating: on line 28042-28000 : Rate B, Rate C - 0.0, 0.0 -> 207.09, 207.09
% INFO    : Updated Thermal Rating: on line 28022-28001 : Rate B, Rate C - 0.0, 0.0 -> 293.88, 293.88
% INFO    : Updated Thermal Rating: on line 28022-28001 : Rate B, Rate C - 0.0, 0.0 -> 293.88, 293.88
% INFO    : Updated Thermal Rating: on line 28022-28001 : Rate B, Rate C - 0.0, 0.0 -> 293.88, 293.88
% INFO    : Updated Thermal Rating: on line 28005-28012 : Rate B, Rate C - 0.0, 0.0 -> 252.45, 252.45
% INFO    : Updated Thermal Rating: on line 28005-28022 : Rate B, Rate C - 0.0, 0.0 -> 262.54, 262.54
% INFO    : Updated Thermal Rating: on line 28005-28052 : Rate B, Rate C - 0.0, 0.0 -> 255.12, 255.12
% INFO    : Updated Thermal Rating: on line 28073-28005 : Rate B, Rate C - 0.0, 0.0 -> 234.38, 234.38
% INFO    : Updated Thermal Rating: on line 28006-28029 : Rate B, Rate C - 0.0, 0.0 -> 271.14, 271.14
% INFO    : Updated Thermal Rating: on line 28008-29041 : Rate B, Rate C - 0.0, 0.0 -> 216.34, 216.34
% INFO    : Updated Thermal Rating: on line 28009-28021 : Rate B, Rate C - 0.0, 0.0 -> 262.9, 262.9
% INFO    : Updated Thermal Rating: on line 28009-28024 : Rate B, Rate C - 0.0, 0.0 -> 423.59, 423.59
% INFO    : Updated Thermal Rating: on line 28010-28103 : Rate B, Rate C - 0.0, 0.0 -> 213.85, 213.85
% INFO    : Updated Thermal Rating: on transformer 28012-28011 : Rate B, Rate C - 0.0, 0.0 -> 487.88, 487.88
% INFO    : Updated Thermal Rating: on line 28011-28035 : Rate B, Rate C - 0.0, 0.0 -> 1176.26, 1176.26
% INFO    : Updated Thermal Rating: on line 28012-28025 : Rate B, Rate C - 0.0, 0.0 -> 241.77, 241.77
% INFO    : Updated Thermal Rating: on line 28042-28012 : Rate B, Rate C - 0.0, 0.0 -> 190.5, 190.5
% INFO    : Updated Thermal Rating: on line 28012-28110 : Rate B, Rate C - 0.0, 0.0 -> 236.55, 236.55
% INFO    : Updated Thermal Rating: on line 28014-28029 : Rate B, Rate C - 0.0, 0.0 -> 246.02, 246.02
% INFO    : Updated Thermal Rating: on line 28100-28014 : Rate B, Rate C - 0.0, 0.0 -> 186.98, 186.98
% INFO    : Updated Thermal Rating: on line 28103-28014 : Rate B, Rate C - 0.0, 0.0 -> 198.58, 198.58
% INFO    : Updated Thermal Rating: on line 28016-28021 : Rate B, Rate C - 0.0, 0.0 -> 246.1, 246.1
% INFO    : Updated Thermal Rating: on line 28016-28111 : Rate B, Rate C - 0.0, 0.0 -> 220.8, 220.8
% INFO    : Updated Thermal Rating: on line 28019-28073 : Rate B, Rate C - 0.0, 0.0 -> 245.99, 245.99
% INFO    : Updated Thermal Rating: on transformer 28024-28023 : Rate B, Rate C - 0.0, 0.0 -> 587.96, 587.96
% INFO    : Updated Thermal Rating: on transformer 28024-28023 : Rate B, Rate C - 0.0, 0.0 -> 587.96, 587.96
% INFO    : Updated Thermal Rating: on transformer 28024-28023 : Rate B, Rate C - 0.0, 0.0 -> 587.96, 587.96
% INFO    : Updated Thermal Rating: on line 28023-28038 : Rate B, Rate C - 0.0, 0.0 -> 1207.6, 1207.6
% INFO    : Updated Thermal Rating: on line 28025-28068 : Rate B, Rate C - 0.0, 0.0 -> 257.06, 257.06
% INFO    : Updated Thermal Rating: on line 28028-28070 : Rate B, Rate C - 0.0, 0.0 -> 212.22, 212.22
% INFO    : Updated Thermal Rating: on line 28028-28100 : Rate B, Rate C - 0.0, 0.0 -> 193.14, 193.14
% INFO    : Updated Thermal Rating: on line 28075-28030 : Rate B, Rate C - 0.0, 0.0 -> 204.26, 204.26
% INFO    : Updated Thermal Rating: on line 28114-28030 : Rate B, Rate C - 0.0, 0.0 -> 202.29, 202.29
% INFO    : Updated Thermal Rating: on line 28032-28087 : Rate B, Rate C - 0.0, 0.0 -> 214.23, 214.23
% INFO    : Updated Thermal Rating: on line 28033-28039 : Rate B, Rate C - 0.0, 0.0 -> 185.76, 185.76
% INFO    : Updated Thermal Rating: on line 28073-28033 : Rate B, Rate C - 0.0, 0.0 -> 206.51, 206.51
% INFO    : Updated Thermal Rating: on line 28033-28107 : Rate B, Rate C - 0.0, 0.0 -> 207.38, 207.38
% INFO    : Updated Thermal Rating: on transformer 28036-28035 : Rate B, Rate C - 0.0, 0.0 -> 507.24, 507.24
% INFO    : Updated Thermal Rating: on line 28038-28035 : Rate B, Rate C - 0.0, 0.0 -> 1114.67, 1114.67
% INFO    : Updated Thermal Rating: on line 28035-28118 : Rate B, Rate C - 0.0, 0.0 -> 1159.9, 1159.9
% INFO    : Updated Thermal Rating: on line 28035-29079 : Rate B, Rate C - 0.0, 0.0 -> 1157.47, 1157.47
% INFO    : Updated Thermal Rating: on line 28036-28045 : Rate B, Rate C - 0.0, 0.0 -> 247.31, 247.31
% INFO    : Updated Thermal Rating: on line 28036-28115 : Rate B, Rate C - 0.0, 0.0 -> 226.46, 226.46
% INFO    : Updated Thermal Rating: on line 28036-28129 : Rate B, Rate C - 0.0, 0.0 -> 254.3, 254.3
% INFO    : Updated Thermal Rating: on transformer 28039-28038 : Rate B, Rate C - 0.0, 0.0 -> 506.48, 506.48
% INFO    : Updated Thermal Rating: on line 28039-28053 : Rate B, Rate C - 0.0, 0.0 -> 278.19, 278.19
% INFO    : Updated Thermal Rating: on line 28100-28039 : Rate B, Rate C - 0.0, 0.0 -> 188.89, 188.89
% INFO    : Updated Thermal Rating: on line 28039-28107 : Rate B, Rate C - 0.0, 0.0 -> 202.36, 202.36
% INFO    : Updated Thermal Rating: on line 28040-28075 : Rate B, Rate C - 0.0, 0.0 -> 252.16, 252.16
% INFO    : Updated Thermal Rating: on line 28040-28133 : Rate B, Rate C - 0.0, 0.0 -> 218.83, 218.83
% INFO    : Updated Thermal Rating: on line 28043-28149 : Rate B, Rate C - 0.0, 0.0 -> 209.45, 209.45
% INFO    : Updated Thermal Rating: on line 28043-28822 : Rate B, Rate C - 0.0, 0.0 -> 240.63, 240.63
% INFO    : Updated Thermal Rating: on line 28045-28054 : Rate B, Rate C - 0.0, 0.0 -> 232.8, 232.8
% INFO    : Updated Thermal Rating: on line 28045-28110 : Rate B, Rate C - 0.0, 0.0 -> 200.8, 200.8
% INFO    : Updated Thermal Rating: on line 28115-28045 : Rate B, Rate C - 0.0, 0.0 -> 175.15, 175.15
% INFO    : Updated Thermal Rating: on transformer 28047-28046 : Rate B, Rate C - 0.0, 0.0 -> 470.63, 470.63
% INFO    : Updated Thermal Rating: on line 28047-28088 : Rate B, Rate C - 0.0, 0.0 -> 240.63, 240.63
% INFO    : Updated Thermal Rating: on line 28047-28117 : Rate B, Rate C - 0.0, 0.0 -> 242.41, 242.41
% INFO    : Updated Thermal Rating: on line 28145-28047 : Rate B, Rate C - 0.0, 0.0 -> 228.35, 228.35
% INFO    : Updated Thermal Rating: on line 28097-28049 : Rate B, Rate C - 0.0, 0.0 -> 1094.55, 1094.55
% INFO    : Updated Thermal Rating: on line 28055-28050 : Rate B, Rate C - 0.0, 0.0 -> 233.62, 233.62
% INFO    : Updated Thermal Rating: on line 28050-29076 : Rate B, Rate C - 0.0, 0.0 -> 261.39, 261.39
% INFO    : Updated Thermal Rating: on line 28052-28071 : Rate B, Rate C - 0.0, 0.0 -> 249.43, 249.43
% INFO    : Updated Thermal Rating: on line 28052-28947 : Rate B, Rate C - 0.0, 0.0 -> 211.46, 211.46
% INFO    : Updated Thermal Rating: on line 28065-28053 : Rate B, Rate C - 0.0, 0.0 -> 199.17, 199.17
% INFO    : Updated Thermal Rating: on line 28053-28106 : Rate B, Rate C - 0.0, 0.0 -> 227.23, 227.23
% INFO    : Updated Thermal Rating: on transformer 28055-28058 : Rate B, Rate C - 0.0, 0.0 -> 96.52, 96.52
% INFO    : Updated Thermal Rating: on line 28055-28111 : Rate B, Rate C - 0.0, 0.0 -> 199.74, 199.74
% INFO    : Updated Thermal Rating: on transformer 28056-28058 : Rate B, Rate C - 0.0, 0.0 -> 48.26, 48.26
% INFO    : Updated Thermal Rating: on transformer 28057-28058 : Rate B, Rate C - 0.0, 0.0 -> 48.26, 48.26
% INFO    : Updated Thermal Rating: on transformer 28059-28062 : Rate B, Rate C - 0.0, 0.0 -> 551.47, 551.47
% INFO    : Updated Thermal Rating: on line 28074-28059 : Rate B, Rate C - 0.0, 0.0 -> 1220.53, 1220.53
% INFO    : Updated Thermal Rating: on line 28059-28097 : Rate B, Rate C - 0.0, 0.0 -> 1032.03, 1032.03
% INFO    : Updated Thermal Rating: on transformer 28060-28062 : Rate B, Rate C - 0.0, 0.0 -> 501.47, 501.47
% INFO    : Updated Thermal Rating: on line 28060-28066 : Rate B, Rate C - 0.0, 0.0 -> 249.44, 249.44
% INFO    : Updated Thermal Rating: on line 28822-28060 : Rate B, Rate C - 0.0, 0.0 -> 230.26, 230.26
% INFO    : Updated Thermal Rating: on transformer 28061-28062 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 29041-28063 : Rate B, Rate C - 0.0, 0.0 -> 223.43, 223.43
% INFO    : Updated Thermal Rating: on line 28065-28875 : Rate B, Rate C - 0.0, 0.0 -> 225.24, 225.24
% INFO    : Updated Thermal Rating: on line 28066-28114 : Rate B, Rate C - 0.0, 0.0 -> 210.59, 210.59
% INFO    : Updated Thermal Rating: on line 28066-28152 : Rate B, Rate C - 0.0, 0.0 -> 242.75, 242.75
% INFO    : Updated Thermal Rating: on line 28067-28075 : Rate B, Rate C - 0.0, 0.0 -> 239.26, 239.26
% INFO    : Updated Thermal Rating: on line 28067-28133 : Rate B, Rate C - 0.0, 0.0 -> 202.13, 202.13
% INFO    : Updated Thermal Rating: on line 28068-28090 : Rate B, Rate C - 0.0, 0.0 -> 223.46, 223.46
% INFO    : Updated Thermal Rating: on line 28070-29041 : Rate B, Rate C - 0.0, 0.0 -> 251.72, 251.72
% INFO    : Updated Thermal Rating: on transformer 28074-28077 : Rate B, Rate C - 0.0, 0.0 -> 566.8, 566.8
% INFO    : Updated Thermal Rating: on line 29040-28074 : Rate B, Rate C - 0.0, 0.0 -> 1427.5, 1427.5
% INFO    : Updated Thermal Rating: on transformer 28075-28077 : Rate B, Rate C - 0.0, 0.0 -> 466.8, 466.8
% INFO    : Updated Thermal Rating: on transformer 28076-28077 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 28079-28090 : Rate B, Rate C - 0.0, 0.0 -> 215.45, 215.45
% INFO    : Updated Thermal Rating: on line 28079-28117 : Rate B, Rate C - 0.0, 0.0 -> 200.93, 200.93
% INFO    : Updated Thermal Rating: on line 28092-28083 : Rate B, Rate C - 0.0, 0.0 -> 227.38, 227.38
% INFO    : Updated Thermal Rating: on line 28083-28132 : Rate B, Rate C - 0.0, 0.0 -> 165.62, 165.62
% INFO    : Updated Thermal Rating: on line 28083-29076 : Rate B, Rate C - 0.0, 0.0 -> 246.72, 246.72
% INFO    : Updated Thermal Rating: on line 28088-28133 : Rate B, Rate C - 0.0, 0.0 -> 198.91, 198.91
% INFO    : Updated Thermal Rating: on line 28088-28138 : Rate B, Rate C - 0.0, 0.0 -> 231.01, 231.01
% INFO    : Updated Thermal Rating: on line 28090-28145 : Rate B, Rate C - 0.0, 0.0 -> 202.07, 202.07
% INFO    : Updated Thermal Rating: on line 28131-28092 : Rate B, Rate C - 0.0, 0.0 -> 196.52, 196.52
% INFO    : Updated Thermal Rating: on transformer 28093-28096 : Rate B, Rate C - 0.0, 0.0 -> 95.23, 95.23
% INFO    : Updated Thermal Rating: on line 28119-28093 : Rate B, Rate C - 0.0, 0.0 -> 255.25, 255.25
% INFO    : Updated Thermal Rating: on line 28093-28129 : Rate B, Rate C - 0.0, 0.0 -> 176.65, 176.65
% INFO    : Updated Thermal Rating: on line 28093-28153 : Rate B, Rate C - 0.0, 0.0 -> 235.95, 235.95
% INFO    : Updated Thermal Rating: on transformer 28094-28096 : Rate B, Rate C - 0.0, 0.0 -> 47.62, 47.62
% INFO    : Updated Thermal Rating: on transformer 28095-28096 : Rate B, Rate C - 0.0, 0.0 -> 47.62, 47.62
% INFO    : Updated Thermal Rating: on transformer 28098-28097 : Rate B, Rate C - 0.0, 0.0 -> 468.05, 468.05
% INFO    : Updated Thermal Rating: on line 28097-28118 : Rate B, Rate C - 0.0, 0.0 -> 1167.44, 1167.44
% INFO    : Updated Thermal Rating: on line 28098-28116 : Rate B, Rate C - 0.0, 0.0 -> 260.5, 260.5
% INFO    : Updated Thermal Rating: on line 28148-28098 : Rate B, Rate C - 0.0, 0.0 -> 242.42, 242.42
% INFO    : Updated Thermal Rating: on line 28104-28125 : Rate B, Rate C - 0.0, 0.0 -> 213.75, 213.75
% INFO    : Updated Thermal Rating: on line 28138-28104 : Rate B, Rate C - 0.0, 0.0 -> 198.74, 198.74
% INFO    : Updated Thermal Rating: on line 28106-28129 : Rate B, Rate C - 0.0, 0.0 -> 170.89, 170.89
% INFO    : Updated Thermal Rating: on line 28108-29045 : Rate B, Rate C - 0.0, 0.0 -> 196.55, 196.55
% INFO    : Updated Thermal Rating: on line 29076-28108 : Rate B, Rate C - 0.0, 0.0 -> 230.12, 230.12
% INFO    : Updated Thermal Rating: on line 28116-28113 : Rate B, Rate C - 0.0, 0.0 -> 234.21, 234.21
% INFO    : Updated Thermal Rating: on line 28113-28117 : Rate B, Rate C - 0.0, 0.0 -> 190.94, 190.94
% INFO    : Updated Thermal Rating: on transformer 28118-28121 : Rate B, Rate C - 0.0, 0.0 -> 585.9, 585.9
% INFO    : Updated Thermal Rating: on transformer 28119-28121 : Rate B, Rate C - 0.0, 0.0 -> 535.9, 535.9
% INFO    : Updated Thermal Rating: on transformer 28119-28124 : Rate B, Rate C - 0.0, 0.0 -> 341.93, 341.93
% INFO    : Updated Thermal Rating: on line 28119-28125 : Rate B, Rate C - 0.0, 0.0 -> 239.04, 239.04
% INFO    : Updated Thermal Rating: on transformer 28120-28121 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 28122-28124 : Rate B, Rate C - 0.0, 0.0 -> 170.96, 170.96
% INFO    : Updated Thermal Rating: on transformer 28123-28124 : Rate B, Rate C - 0.0, 0.0 -> 170.96, 170.96
% INFO    : Updated Thermal Rating: on line 28199-28131 : Rate B, Rate C - 0.0, 0.0 -> 204.19, 204.19
% INFO    : Updated Thermal Rating: on line 28132-28172 : Rate B, Rate C - 0.0, 0.0 -> 214.69, 214.69
% INFO    : Updated Thermal Rating: on line 28156-28134 : Rate B, Rate C - 0.0, 0.0 -> 252.02, 252.02
% INFO    : Updated Thermal Rating: on line 28134-28205 : Rate B, Rate C - 0.0, 0.0 -> 214.45, 214.45
% INFO    : Updated Thermal Rating: on line 28137-28148 : Rate B, Rate C - 0.0, 0.0 -> 197.6, 197.6
% INFO    : Updated Thermal Rating: on line 28169-28137 : Rate B, Rate C - 0.0, 0.0 -> 232.06, 232.06
% INFO    : Updated Thermal Rating: on line 28137-28207 : Rate B, Rate C - 0.0, 0.0 -> 218.36, 218.36
% INFO    : Updated Thermal Rating: on line 28153-28139 : Rate B, Rate C - 0.0, 0.0 -> 187.02, 187.02
% INFO    : Updated Thermal Rating: on line 28139-28870 : Rate B, Rate C - 0.0, 0.0 -> 227.41, 227.41
% INFO    : Updated Thermal Rating: on line 28144-28140 : Rate B, Rate C - 0.0, 0.0 -> 185.9, 185.9
% INFO    : Updated Thermal Rating: on line 28172-28140 : Rate B, Rate C - 0.0, 0.0 -> 210.12, 210.12
% INFO    : Updated Thermal Rating: on transformer 28142-28141 : Rate B, Rate C - 0.0, 0.0 -> 513.49, 513.49
% INFO    : Updated Thermal Rating: on line 28161-28144 : Rate B, Rate C - 0.0, 0.0 -> 214.89, 214.89
% INFO    : Updated Thermal Rating: on line 28144-28199 : Rate B, Rate C - 0.0, 0.0 -> 216.93, 216.93
% INFO    : Updated Thermal Rating: on line 28144-28933 : Rate B, Rate C - 0.0, 0.0 -> 248.21, 248.21
% INFO    : Updated Thermal Rating: on line 28148-28179 : Rate B, Rate C - 0.0, 0.0 -> 206.29, 206.29
% INFO    : Updated Thermal Rating: on line 28152-28149 : Rate B, Rate C - 0.0, 0.0 -> 208.79, 208.79
% INFO    : Updated Thermal Rating: on line 28149-28167 : Rate B, Rate C - 0.0, 0.0 -> 191.44, 191.44
% INFO    : Updated Thermal Rating: on line 28212-28154 : Rate B, Rate C - 0.0, 0.0 -> 206.25, 206.25
% INFO    : Updated Thermal Rating: on transformer 28156-28155 : Rate B, Rate C - 0.0, 0.0 -> 568.35, 568.35
% INFO    : Updated Thermal Rating: on line 28159-28156 : Rate B, Rate C - 0.0, 0.0 -> 238.01, 238.01
% INFO    : Updated Thermal Rating: on line 28156-28185 : Rate B, Rate C - 0.0, 0.0 -> 253.73, 253.73
% INFO    : Updated Thermal Rating: on line 28156-28189 : Rate B, Rate C - 0.0, 0.0 -> 270.51, 270.51
% INFO    : Updated Thermal Rating: on line 28168-28158 : Rate B, Rate C - 0.0, 0.0 -> 1093.92, 1093.92
% INFO    : Updated Thermal Rating: on line 28211-28158 : Rate B, Rate C - 0.0, 0.0 -> 1063.73, 1063.73
% INFO    : Updated Thermal Rating: on line 28159-28203 : Rate B, Rate C - 0.0, 0.0 -> 185.96, 185.96
% INFO    : Updated Thermal Rating: on line 28161-28227 : Rate B, Rate C - 0.0, 0.0 -> 238.56, 238.56
% INFO    : Updated Thermal Rating: on line 28163-28175 : Rate B, Rate C - 0.0, 0.0 -> 243.45, 243.45
% INFO    : Updated Thermal Rating: on line 28163-28190 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 28163-28232 : Rate B, Rate C - 0.0, 0.0 -> 251.51, 251.51
% INFO    : Updated Thermal Rating: on line 28165-28205 : Rate B, Rate C - 0.0, 0.0 -> 200.03, 200.03
% INFO    : Updated Thermal Rating: on line 28167-28189 : Rate B, Rate C - 0.0, 0.0 -> 231.9, 231.9
% INFO    : Updated Thermal Rating: on transformer 28169-28168 : Rate B, Rate C - 0.0, 0.0 -> 465.5, 465.5
% INFO    : Updated Thermal Rating: on line 28168-29081 : Rate B, Rate C - 0.0, 0.0 -> 1218.68, 1218.68
% INFO    : Updated Thermal Rating: on line 28169-28196 : Rate B, Rate C - 0.0, 0.0 -> 241.49, 241.49
% INFO    : Updated Thermal Rating: on line 28196-28171 : Rate B, Rate C - 0.0, 0.0 -> 204.5, 204.5
% INFO    : Updated Thermal Rating: on line 28221-28171 : Rate B, Rate C - 0.0, 0.0 -> 210.72, 210.72
% INFO    : Updated Thermal Rating: on line 28180-28173 : Rate B, Rate C - 0.0, 0.0 -> 191.36, 191.36
% INFO    : Updated Thermal Rating: on line 28175-28181 : Rate B, Rate C - 0.0, 0.0 -> 206.43, 206.43
% INFO    : Updated Thermal Rating: on line 28197-28179 : Rate B, Rate C - 0.0, 0.0 -> 178.71, 178.71
% INFO    : Updated Thermal Rating: on line 28180-28231 : Rate B, Rate C - 0.0, 0.0 -> 237.15, 237.15
% INFO    : Updated Thermal Rating: on line 28181-28191 : Rate B, Rate C - 0.0, 0.0 -> 225.12, 225.12
% INFO    : Updated Thermal Rating: on line 28225-28181 : Rate B, Rate C - 0.0, 0.0 -> 241.48, 241.48
% INFO    : Updated Thermal Rating: on line 28203-28185 : Rate B, Rate C - 0.0, 0.0 -> 229.04, 229.04
% INFO    : Updated Thermal Rating: on line 28189-28198 : Rate B, Rate C - 0.0, 0.0 -> 185.56, 185.56
% INFO    : Updated Thermal Rating: on line 28190-28218 : Rate B, Rate C - 0.0, 0.0 -> 286.64, 286.64
% INFO    : Updated Thermal Rating: on line 28190-28218 : Rate B, Rate C - 0.0, 0.0 -> 286.64, 286.64
% INFO    : Updated Thermal Rating: on line 28190-28218 : Rate B, Rate C - 0.0, 0.0 -> 286.64, 286.64
% INFO    : Updated Thermal Rating: on line 28191-28199 : Rate B, Rate C - 0.0, 0.0 -> 222.75, 222.75
% INFO    : Updated Thermal Rating: on line 28191-28232 : Rate B, Rate C - 0.0, 0.0 -> 224.27, 224.27
% INFO    : Updated Thermal Rating: on line 28216-28192 : Rate B, Rate C - 0.0, 0.0 -> 222.19, 222.19
% INFO    : Updated Thermal Rating: on line 28192-28228 : Rate B, Rate C - 0.0, 0.0 -> 230.63, 230.63
% INFO    : Updated Thermal Rating: on line 28231-28195 : Rate B, Rate C - 0.0, 0.0 -> 182.59, 182.59
% INFO    : Updated Thermal Rating: on line 28197-28205 : Rate B, Rate C - 0.0, 0.0 -> 189.57, 189.57
% INFO    : Updated Thermal Rating: on line 28210-28197 : Rate B, Rate C - 0.0, 0.0 -> 164.89, 164.89
% INFO    : Updated Thermal Rating: on line 28197-28219 : Rate B, Rate C - 0.0, 0.0 -> 214.89, 214.89
% INFO    : Updated Thermal Rating: on line 28197-28252 : Rate B, Rate C - 0.0, 0.0 -> 198.6, 198.6
% INFO    : Updated Thermal Rating: on line 28197-28253 : Rate B, Rate C - 0.0, 0.0 -> 218.96, 218.96
% INFO    : Updated Thermal Rating: on line 28220-28198 : Rate B, Rate C - 0.0, 0.0 -> 226.03, 226.03
% INFO    : Updated Thermal Rating: on line 28200-28275 : Rate B, Rate C - 0.0, 0.0 -> 165.73, 165.73
% INFO    : Updated Thermal Rating: on line 28200-28999 : Rate B, Rate C - 0.0, 0.0 -> 231.94, 231.94
% INFO    : Updated Thermal Rating: on line 28203-28210 : Rate B, Rate C - 0.0, 0.0 -> 215.5, 215.5
% INFO    : Updated Thermal Rating: on line 28207-28219 : Rate B, Rate C - 0.0, 0.0 -> 169.79, 169.79
% INFO    : Updated Thermal Rating: on transformer 28212-28211 : Rate B, Rate C - 0.0, 0.0 -> 495.98, 495.98
% INFO    : Updated Thermal Rating: on line 28211-29025 : Rate B, Rate C - 0.0, 0.0 -> 1239.74, 1239.74
% INFO    : Updated Thermal Rating: on line 28212-28220 : Rate B, Rate C - 0.0, 0.0 -> 245.28, 245.28
% INFO    : Updated Thermal Rating: on line 28272-28212 : Rate B, Rate C - 0.0, 0.0 -> 237.94, 237.94
% INFO    : Updated Thermal Rating: on line 28215-28213 : Rate B, Rate C - 0.0, 0.0 -> 175.46, 175.46
% INFO    : Updated Thermal Rating: on line 28213-28363 : Rate B, Rate C - 0.0, 0.0 -> 207.71, 207.71
% INFO    : Updated Thermal Rating: on line 28215-28272 : Rate B, Rate C - 0.0, 0.0 -> 216.54, 216.54
% INFO    : Updated Thermal Rating: on line 28224-28216 : Rate B, Rate C - 0.0, 0.0 -> 180.8, 180.8
% INFO    : Updated Thermal Rating: on transformer 28218-28217 : Rate B, Rate C - 0.0, 0.0 -> 595.59, 595.59
% INFO    : Updated Thermal Rating: on transformer 28218-28217 : Rate B, Rate C - 0.0, 0.0 -> 595.59, 595.59
% INFO    : Updated Thermal Rating: on transformer 28218-28217 : Rate B, Rate C - 0.0, 0.0 -> 595.59, 595.59
% INFO    : Updated Thermal Rating: on line 28795-28217 : Rate B, Rate C - 0.0, 0.0 -> 1302.28, 1302.28
% INFO    : Updated Thermal Rating: on line 28217-28831 : Rate B, Rate C - 0.0, 0.0 -> 1215.62, 1215.62
% INFO    : Updated Thermal Rating: on line 28218-28225 : Rate B, Rate C - 0.0, 0.0 -> 257.4, 257.4
% INFO    : Updated Thermal Rating: on line 28218-28231 : Rate B, Rate C - 0.0, 0.0 -> 265.52, 265.52
% INFO    : Updated Thermal Rating: on line 28221-28233 : Rate B, Rate C - 0.0, 0.0 -> 223.75, 223.75
% INFO    : Updated Thermal Rating: on line 28221-28250 : Rate B, Rate C - 0.0, 0.0 -> 225.72, 225.72
% INFO    : Updated Thermal Rating: on transformer 28223-28222 : Rate B, Rate C - 0.0, 0.0 -> 507.42, 507.42
% INFO    : Updated Thermal Rating: on line 28222-29003 : Rate B, Rate C - 0.0, 0.0 -> 1212.85, 1212.85
% INFO    : Updated Thermal Rating: on line 28223-28275 : Rate B, Rate C - 0.0, 0.0 -> 227.07, 227.07
% INFO    : Updated Thermal Rating: on line 28223-29014 : Rate B, Rate C - 0.0, 0.0 -> 268.2, 268.2
% INFO    : Updated Thermal Rating: on line 28224-28267 : Rate B, Rate C - 0.0, 0.0 -> 221.39, 221.39
% INFO    : Updated Thermal Rating: on line 28227-28800 : Rate B, Rate C - 0.0, 0.0 -> 264.45, 264.45
% INFO    : Updated Thermal Rating: on line 28228-28282 : Rate B, Rate C - 0.0, 0.0 -> 226.21, 226.21
% INFO    : Updated Thermal Rating: on line 28228-28796 : Rate B, Rate C - 0.0, 0.0 -> 232.11, 232.11
% INFO    : Updated Thermal Rating: on line 28230-28260 : Rate B, Rate C - 0.0, 0.0 -> 204.17, 204.17
% INFO    : Updated Thermal Rating: on line 28266-28230 : Rate B, Rate C - 0.0, 0.0 -> 247.48, 247.48
% INFO    : Updated Thermal Rating: on line 28233-28870 : Rate B, Rate C - 0.0, 0.0 -> 239.74, 239.74
% INFO    : Updated Thermal Rating: on line 28271-28234 : Rate B, Rate C - 0.0, 0.0 -> 243.61, 243.61
% INFO    : Updated Thermal Rating: on line 28244-28235 : Rate B, Rate C - 0.0, 0.0 -> 211.39, 211.39
% INFO    : Updated Thermal Rating: on line 28235-29014 : Rate B, Rate C - 0.0, 0.0 -> 232.87, 232.87
% INFO    : Updated Thermal Rating: on line 28933-28238 : Rate B, Rate C - 0.0, 0.0 -> 233.79, 233.79
% INFO    : Updated Thermal Rating: on line 28238-28985 : Rate B, Rate C - 0.0, 0.0 -> 215.78, 215.78
% INFO    : Updated Thermal Rating: on line 28238-28999 : Rate B, Rate C - 0.0, 0.0 -> 228.03, 228.03
% INFO    : Updated Thermal Rating: on line 28251-28240 : Rate B, Rate C - 0.0, 0.0 -> 240.17, 240.17
% INFO    : Updated Thermal Rating: on line 28256-28240 : Rate B, Rate C - 0.0, 0.0 -> 261.1, 261.1
% INFO    : Updated Thermal Rating: on line 28243-28250 : Rate B, Rate C - 0.0, 0.0 -> 251.24, 251.24
% INFO    : Updated Thermal Rating: on line 28800-28243 : Rate B, Rate C - 0.0, 0.0 -> 272.34, 272.34
% INFO    : Updated Thermal Rating: on line 28244-28251 : Rate B, Rate C - 0.0, 0.0 -> 203.83, 203.83
% INFO    : Updated Thermal Rating: on line 28273-28245 : Rate B, Rate C - 0.0, 0.0 -> 215.89, 215.89
% INFO    : Updated Thermal Rating: on line 28245-28832 : Rate B, Rate C - 0.0, 0.0 -> 237.07, 237.07
% INFO    : Updated Thermal Rating: on line 28246-28267 : Rate B, Rate C - 0.0, 0.0 -> 254.41, 254.41
% INFO    : Updated Thermal Rating: on line 28246-28341 : Rate B, Rate C - 0.0, 0.0 -> 268.92, 268.92
% INFO    : Updated Thermal Rating: on line 28247-28260 : Rate B, Rate C - 0.0, 0.0 -> 207.29, 207.29
% INFO    : Updated Thermal Rating: on line 28247-28933 : Rate B, Rate C - 0.0, 0.0 -> 178.79, 178.79
% INFO    : Updated Thermal Rating: on line 28252-28327 : Rate B, Rate C - 0.0, 0.0 -> 224.09, 224.09
% INFO    : Updated Thermal Rating: on line 28253-28304 : Rate B, Rate C - 0.0, 0.0 -> 239.65, 239.65
% INFO    : Updated Thermal Rating: on line 28255-28263 : Rate B, Rate C - 0.0, 0.0 -> 180.18, 180.18
% INFO    : Updated Thermal Rating: on line 28255-28800 : Rate B, Rate C - 0.0, 0.0 -> 210.36, 210.36
% INFO    : Updated Thermal Rating: on line 28292-28256 : Rate B, Rate C - 0.0, 0.0 -> 237.56, 237.56
% INFO    : Updated Thermal Rating: on line 28999-28256 : Rate B, Rate C - 0.0, 0.0 -> 283.69, 283.69
% INFO    : Updated Thermal Rating: on line 28999-28256 : Rate B, Rate C - 0.0, 0.0 -> 283.69, 283.69
% INFO    : Updated Thermal Rating: on line 28257-28279 : Rate B, Rate C - 0.0, 0.0 -> 199.33, 199.33
% INFO    : Updated Thermal Rating: on line 28257-28292 : Rate B, Rate C - 0.0, 0.0 -> 193.98, 193.98
% INFO    : Updated Thermal Rating: on line 28257-28832 : Rate B, Rate C - 0.0, 0.0 -> 236.7, 236.7
% INFO    : Updated Thermal Rating: on line 28260-28796 : Rate B, Rate C - 0.0, 0.0 -> 235.02, 235.02
% INFO    : Updated Thermal Rating: on line 28262-28298 : Rate B, Rate C - 0.0, 0.0 -> 222.54, 222.54
% INFO    : Updated Thermal Rating: on line 28299-28262 : Rate B, Rate C - 0.0, 0.0 -> 194.15, 194.15
% INFO    : Updated Thermal Rating: on line 28279-28263 : Rate B, Rate C - 0.0, 0.0 -> 207.55, 207.55
% INFO    : Updated Thermal Rating: on line 29005-28263 : Rate B, Rate C - 0.0, 0.0 -> 247.56, 247.56
% INFO    : Updated Thermal Rating: on line 28266-28293 : Rate B, Rate C - 0.0, 0.0 -> 209.52, 209.52
% INFO    : Updated Thermal Rating: on line 28266-28301 : Rate B, Rate C - 0.0, 0.0 -> 166.61, 166.61
% INFO    : Updated Thermal Rating: on line 28266-28344 : Rate B, Rate C - 0.0, 0.0 -> 279.93, 279.93
% INFO    : Updated Thermal Rating: on line 28312-28270 : Rate B, Rate C - 0.0, 0.0 -> 184.94, 184.94
% INFO    : Updated Thermal Rating: on line 28270-28357 : Rate B, Rate C - 0.0, 0.0 -> 231.21, 231.21
% INFO    : Updated Thermal Rating: on line 28271-28849 : Rate B, Rate C - 0.0, 0.0 -> 252.95, 252.95
% INFO    : Updated Thermal Rating: on line 28273-28306 : Rate B, Rate C - 0.0, 0.0 -> 217.73, 217.73
% INFO    : Updated Thermal Rating: on line 28323-28273 : Rate B, Rate C - 0.0, 0.0 -> 185.17, 185.17
% INFO    : Updated Thermal Rating: on line 28273-28943 : Rate B, Rate C - 0.0, 0.0 -> 235.5, 235.5
% INFO    : Updated Thermal Rating: on line 28324-28277 : Rate B, Rate C - 0.0, 0.0 -> 224.54, 224.54
% INFO    : Updated Thermal Rating: on line 28277-28371 : Rate B, Rate C - 0.0, 0.0 -> 226.12, 226.12
% INFO    : Updated Thermal Rating: on line 28277-28400 : Rate B, Rate C - 0.0, 0.0 -> 231.51, 231.51
% INFO    : Updated Thermal Rating: on line 28280-28291 : Rate B, Rate C - 0.0, 0.0 -> 246.65, 246.65
% INFO    : Updated Thermal Rating: on line 28280-28306 : Rate B, Rate C - 0.0, 0.0 -> 216.4, 216.4
% INFO    : Updated Thermal Rating: on line 28985-28282 : Rate B, Rate C - 0.0, 0.0 -> 253.49, 253.49
% INFO    : Updated Thermal Rating: on line 28290-28284 : Rate B, Rate C - 0.0, 0.0 -> 218.03, 218.03
% INFO    : Updated Thermal Rating: on line 28284-28366 : Rate B, Rate C - 0.0, 0.0 -> 245.26, 245.26
% INFO    : Updated Thermal Rating: on line 28284-28462 : Rate B, Rate C - 0.0, 0.0 -> 250.27, 250.27
% INFO    : Updated Thermal Rating: on line 28355-28286 : Rate B, Rate C - 0.0, 0.0 -> 252.81, 252.81
% INFO    : Updated Thermal Rating: on line 28286-28849 : Rate B, Rate C - 0.0, 0.0 -> 273.12, 273.12
% INFO    : Updated Thermal Rating: on line 28287-28339 : Rate B, Rate C - 0.0, 0.0 -> 250.77, 250.77
% INFO    : Updated Thermal Rating: on line 28348-28287 : Rate B, Rate C - 0.0, 0.0 -> 228.52, 228.52
% INFO    : Updated Thermal Rating: on line 28896-28287 : Rate B, Rate C - 0.0, 0.0 -> 243.97, 243.97
% INFO    : Updated Thermal Rating: on line 28341-28290 : Rate B, Rate C - 0.0, 0.0 -> 244.43, 244.43
% INFO    : Updated Thermal Rating: on line 28326-28291 : Rate B, Rate C - 0.0, 0.0 -> 269.81, 269.81
% INFO    : Updated Thermal Rating: on line 28293-28999 : Rate B, Rate C - 0.0, 0.0 -> 150.8, 150.8
% INFO    : Updated Thermal Rating: on line 28344-28294 : Rate B, Rate C - 0.0, 0.0 -> 172.23, 172.23
% INFO    : Updated Thermal Rating: on line 28294-28355 : Rate B, Rate C - 0.0, 0.0 -> 231.38, 231.38
% INFO    : Updated Thermal Rating: on line 28401-28295 : Rate B, Rate C - 0.0, 0.0 -> 235.67, 235.67
% INFO    : Updated Thermal Rating: on line 28783-28295 : Rate B, Rate C - 0.0, 0.0 -> 263.2, 263.2
% INFO    : Updated Thermal Rating: on line 28329-28298 : Rate B, Rate C - 0.0, 0.0 -> 217.75, 217.75
% INFO    : Updated Thermal Rating: on line 28298-28861 : Rate B, Rate C - 0.0, 0.0 -> 269.1, 269.1
% INFO    : Updated Thermal Rating: on line 28299-28339 : Rate B, Rate C - 0.0, 0.0 -> 238.41, 238.41
% INFO    : Updated Thermal Rating: on line 28301-28861 : Rate B, Rate C - 0.0, 0.0 -> 227.46, 227.46
% INFO    : Updated Thermal Rating: on line 28302-28350 : Rate B, Rate C - 0.0, 0.0 -> 196.8, 196.8
% INFO    : Updated Thermal Rating: on line 28302-28432 : Rate B, Rate C - 0.0, 0.0 -> 255.67, 255.67
% INFO    : Updated Thermal Rating: on line 28303-28318 : Rate B, Rate C - 0.0, 0.0 -> 225.03, 225.03
% INFO    : Updated Thermal Rating: on line 28303-28372 : Rate B, Rate C - 0.0, 0.0 -> 152.25, 152.25
% INFO    : Updated Thermal Rating: on line 28372-28304 : Rate B, Rate C - 0.0, 0.0 -> 215.5, 215.5
% INFO    : Updated Thermal Rating: on line 28304-28429 : Rate B, Rate C - 0.0, 0.0 -> 250.56, 250.56
% INFO    : Updated Thermal Rating: on line 28304-29082 : Rate B, Rate C - 0.0, 0.0 -> 231.93, 231.93
% INFO    : Updated Thermal Rating: on line 28308-28349 : Rate B, Rate C - 0.0, 0.0 -> 254.49, 254.49
% INFO    : Updated Thermal Rating: on line 28308-28400 : Rate B, Rate C - 0.0, 0.0 -> 246.81, 246.81
% INFO    : Updated Thermal Rating: on line 28418-28308 : Rate B, Rate C - 0.0, 0.0 -> 244.88, 244.88
% INFO    : Updated Thermal Rating: on line 28310-28337 : Rate B, Rate C - 0.0, 0.0 -> 286.01, 286.01
% INFO    : Updated Thermal Rating: on line 28310-28363 : Rate B, Rate C - 0.0, 0.0 -> 245.06, 245.06
% INFO    : Updated Thermal Rating: on line 28310-29026 : Rate B, Rate C - 0.0, 0.0 -> 225.86, 225.86
% INFO    : Updated Thermal Rating: on line 28311-28316 : Rate B, Rate C - 0.0, 0.0 -> 244.85, 244.85
% INFO    : Updated Thermal Rating: on line 28311-28462 : Rate B, Rate C - 0.0, 0.0 -> 269.54, 269.54
% INFO    : Updated Thermal Rating: on line 28311-28849 : Rate B, Rate C - 0.0, 0.0 -> 246.95, 246.95
% INFO    : Updated Thermal Rating: on transformer 28312-28315 : Rate B, Rate C - 0.0, 0.0 -> 224.42, 224.42
% INFO    : Updated Thermal Rating: on line 28849-28312 : Rate B, Rate C - 0.0, 0.0 -> 218.26, 218.26
% INFO    : Updated Thermal Rating: on transformer 28313-28315 : Rate B, Rate C - 0.0, 0.0 -> 112.21, 112.21
% INFO    : Updated Thermal Rating: on transformer 28314-28315 : Rate B, Rate C - 0.0, 0.0 -> 112.21, 112.21
% INFO    : Updated Thermal Rating: on line 28316-28719 : Rate B, Rate C - 0.0, 0.0 -> 248.44, 248.44
% INFO    : Updated Thermal Rating: on transformer 28318-28317 : Rate B, Rate C - 0.0, 0.0 -> 479.04, 479.04
% INFO    : Updated Thermal Rating: on line 28317-28428 : Rate B, Rate C - 0.0, 0.0 -> 1183.48, 1183.48
% INFO    : Updated Thermal Rating: on line 28318-28319 : Rate B, Rate C - 0.0, 0.0 -> 241.06, 241.06
% INFO    : Updated Thermal Rating: on line 28411-28318 : Rate B, Rate C - 0.0, 0.0 -> 208.72, 208.72
% INFO    : Updated Thermal Rating: on line 28319-28338 : Rate B, Rate C - 0.0, 0.0 -> 192.76, 192.76
% INFO    : Updated Thermal Rating: on line 28323-28328 : Rate B, Rate C - 0.0, 0.0 -> 205.73, 205.73
% INFO    : Updated Thermal Rating: on line 28324-28326 : Rate B, Rate C - 0.0, 0.0 -> 254.58, 254.58
% INFO    : Updated Thermal Rating: on transformer 28326-28325 : Rate B, Rate C - 0.0, 0.0 -> 516.78, 516.78
% INFO    : Updated Thermal Rating: on line 28325-28782 : Rate B, Rate C - 0.0, 0.0 -> 1216.15, 1216.15
% INFO    : Updated Thermal Rating: on line 28326-28375 : Rate B, Rate C - 0.0, 0.0 -> 192.13, 192.13
% INFO    : Updated Thermal Rating: on line 28958-28326 : Rate B, Rate C - 0.0, 0.0 -> 225.99, 225.99
% INFO    : Updated Thermal Rating: on line 28327-28371 : Rate B, Rate C - 0.0, 0.0 -> 201.99, 201.99
% INFO    : Updated Thermal Rating: on line 28327-28418 : Rate B, Rate C - 0.0, 0.0 -> 241.96, 241.96
% INFO    : Updated Thermal Rating: on line 28328-28381 : Rate B, Rate C - 0.0, 0.0 -> 243.37, 243.37
% INFO    : Updated Thermal Rating: on line 28402-28329 : Rate B, Rate C - 0.0, 0.0 -> 193.39, 193.39
% INFO    : Updated Thermal Rating: on transformer 28330-28333 : Rate B, Rate C - 0.0, 0.0 -> 93.76, 93.76
% INFO    : Updated Thermal Rating: on line 28330-28353 : Rate B, Rate C - 0.0, 0.0 -> 222.29, 222.29
% INFO    : Updated Thermal Rating: on line 28330-28391 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on transformer 28331-28333 : Rate B, Rate C - 0.0, 0.0 -> 46.88, 46.88
% INFO    : Updated Thermal Rating: on transformer 28332-28333 : Rate B, Rate C - 0.0, 0.0 -> 46.88, 46.88
% INFO    : Updated Thermal Rating: on line 28354-28334 : Rate B, Rate C - 0.0, 0.0 -> 188.54, 188.54
% INFO    : Updated Thermal Rating: on line 28334-29026 : Rate B, Rate C - 0.0, 0.0 -> 210.42, 210.42
% INFO    : Updated Thermal Rating: on line 28337-28365 : Rate B, Rate C - 0.0, 0.0 -> 330.0, 330.0
% INFO    : Updated Thermal Rating: on line 28338-28439 : Rate B, Rate C - 0.0, 0.0 -> 206.1, 206.1
% INFO    : Updated Thermal Rating: on line 28341-28348 : Rate B, Rate C - 0.0, 0.0 -> 256.24, 256.24
% INFO    : Updated Thermal Rating: on line 28849-28341 : Rate B, Rate C - 0.0, 0.0 -> 295.25, 295.25
% INFO    : Updated Thermal Rating: on line 28849-28341 : Rate B, Rate C - 0.0, 0.0 -> 295.25, 295.25
% INFO    : Updated Thermal Rating: on line 28849-28341 : Rate B, Rate C - 0.0, 0.0 -> 295.25, 295.25
% INFO    : Updated Thermal Rating: on transformer 28343-28346 : Rate B, Rate C - 0.0, 0.0 -> 617.38, 617.38
% INFO    : Updated Thermal Rating: on line 28343-28460 : Rate B, Rate C - 0.0, 0.0 -> 1326.6, 1326.6
% INFO    : Updated Thermal Rating: on line 28860-28343 : Rate B, Rate C - 0.0, 0.0 -> 1129.33, 1129.33
% INFO    : Updated Thermal Rating: on transformer 28344-28346 : Rate B, Rate C - 0.0, 0.0 -> 492.38, 492.38
% INFO    : Updated Thermal Rating: on line 28344-28896 : Rate B, Rate C - 0.0, 0.0 -> 230.56, 230.56
% INFO    : Updated Thermal Rating: on transformer 28345-28346 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 28362-28349 : Rate B, Rate C - 0.0, 0.0 -> 263.1, 263.1
% INFO    : Updated Thermal Rating: on line 28349-28432 : Rate B, Rate C - 0.0, 0.0 -> 281.64, 281.64
% INFO    : Updated Thermal Rating: on line 28442-28349 : Rate B, Rate C - 0.0, 0.0 -> 231.19, 231.19
% INFO    : Updated Thermal Rating: on line 28349-28463 : Rate B, Rate C - 0.0, 0.0 -> 218.51, 218.51
% INFO    : Updated Thermal Rating: on line 28360-28350 : Rate B, Rate C - 0.0, 0.0 -> 209.3, 209.3
% INFO    : Updated Thermal Rating: on line 28365-28351 : Rate B, Rate C - 0.0, 0.0 -> 196.32, 196.32
% INFO    : Updated Thermal Rating: on line 28351-28503 : Rate B, Rate C - 0.0, 0.0 -> 212.4, 212.4
% INFO    : Updated Thermal Rating: on line 28353-28354 : Rate B, Rate C - 0.0, 0.0 -> 220.2, 220.2
% INFO    : Updated Thermal Rating: on line 28353-28368 : Rate B, Rate C - 0.0, 0.0 -> 222.67, 222.67
% INFO    : Updated Thermal Rating: on line 29026-28354 : Rate B, Rate C - 0.0, 0.0 -> 264.4, 264.4
% INFO    : Updated Thermal Rating: on line 28357-28427 : Rate B, Rate C - 0.0, 0.0 -> 272.98, 272.98
% INFO    : Updated Thermal Rating: on line 28357-28459 : Rate B, Rate C - 0.0, 0.0 -> 265.23, 265.23
% INFO    : Updated Thermal Rating: on line 28360-28367 : Rate B, Rate C - 0.0, 0.0 -> 215.05, 215.05
% INFO    : Updated Thermal Rating: on line 28464-28360 : Rate B, Rate C - 0.0, 0.0 -> 225.17, 225.17
% INFO    : Updated Thermal Rating: on line 28362-28375 : Rate B, Rate C - 0.0, 0.0 -> 215.43, 215.43
% INFO    : Updated Thermal Rating: on transformer 28365-28364 : Rate B, Rate C - 0.0, 0.0 -> 521.2, 521.2
% INFO    : Updated Thermal Rating: on line 29025-28364 : Rate B, Rate C - 0.0, 0.0 -> 1219.84, 1219.84
% INFO    : Updated Thermal Rating: on line 28365-28383 : Rate B, Rate C - 0.0, 0.0 -> 204.59, 204.59
% INFO    : Updated Thermal Rating: on line 28441-28366 : Rate B, Rate C - 0.0, 0.0 -> 235.44, 235.44
% INFO    : Updated Thermal Rating: on line 28367-28427 : Rate B, Rate C - 0.0, 0.0 -> 234.44, 234.44
% INFO    : Updated Thermal Rating: on line 28368-29026 : Rate B, Rate C - 0.0, 0.0 -> 250.64, 250.64
% INFO    : Updated Thermal Rating: on line 28370-28382 : Rate B, Rate C - 0.0, 0.0 -> 213.84, 213.84
% INFO    : Updated Thermal Rating: on line 28417-28373 : Rate B, Rate C - 0.0, 0.0 -> 250.46, 250.46
% INFO    : Updated Thermal Rating: on line 28373-28418 : Rate B, Rate C - 0.0, 0.0 -> 413.4, 413.4
% INFO    : Updated Thermal Rating: on line 28373-28555 : Rate B, Rate C - 0.0, 0.0 -> 255.17, 255.17
% INFO    : Updated Thermal Rating: on line 28377-28404 : Rate B, Rate C - 0.0, 0.0 -> 182.49, 182.49
% INFO    : Updated Thermal Rating: on line 28377-28447 : Rate B, Rate C - 0.0, 0.0 -> 233.6, 233.6
% INFO    : Updated Thermal Rating: on line 28379-28425 : Rate B, Rate C - 0.0, 0.0 -> 192.06, 192.06
% INFO    : Updated Thermal Rating: on line 28379-28472 : Rate B, Rate C - 0.0, 0.0 -> 211.98, 211.98
% INFO    : Updated Thermal Rating: on line 29082-28381 : Rate B, Rate C - 0.0, 0.0 -> 257.34, 257.34
% INFO    : Updated Thermal Rating: on line 28382-28404 : Rate B, Rate C - 0.0, 0.0 -> 231.82, 231.82
% INFO    : Updated Thermal Rating: on line 28383-28466 : Rate B, Rate C - 0.0, 0.0 -> 187.85, 187.85
% INFO    : Updated Thermal Rating: on line 28385-28504 : Rate B, Rate C - 0.0, 0.0 -> 200.28, 200.28
% INFO    : Updated Thermal Rating: on line 28385-28508 : Rate B, Rate C - 0.0, 0.0 -> 248.85, 248.85
% INFO    : Updated Thermal Rating: on line 28386-28783 : Rate B, Rate C - 0.0, 0.0 -> 264.22, 264.22
% INFO    : Updated Thermal Rating: on line 28958-28386 : Rate B, Rate C - 0.0, 0.0 -> 225.83, 225.83
% INFO    : Updated Thermal Rating: on line 28388-28391 : Rate B, Rate C - 0.0, 0.0 -> 225.0, 225.0
% INFO    : Updated Thermal Rating: on line 28388-28393 : Rate B, Rate C - 0.0, 0.0 -> 205.64, 205.64
% INFO    : Updated Thermal Rating: on line 28436-28388 : Rate B, Rate C - 0.0, 0.0 -> 237.54, 237.54
% INFO    : Updated Thermal Rating: on line 28388-28724 : Rate B, Rate C - 0.0, 0.0 -> 266.08, 266.08
% INFO    : Updated Thermal Rating: on line 28389-28436 : Rate B, Rate C - 0.0, 0.0 -> 203.33, 203.33
% INFO    : Updated Thermal Rating: on line 28467-28389 : Rate B, Rate C - 0.0, 0.0 -> 192.98, 192.98
% INFO    : Updated Thermal Rating: on line 28393-29004 : Rate B, Rate C - 0.0, 0.0 -> 239.28, 239.28
% INFO    : Updated Thermal Rating: on line 28547-28394 : Rate B, Rate C - 0.0, 0.0 -> 208.36, 208.36
% INFO    : Updated Thermal Rating: on line 28394-28558 : Rate B, Rate C - 0.0, 0.0 -> 185.62, 185.62
% INFO    : Updated Thermal Rating: on line 28396-28398 : Rate B, Rate C - 0.0, 0.0 -> 224.88, 224.88
% INFO    : Updated Thermal Rating: on line 28396-28908 : Rate B, Rate C - 0.0, 0.0 -> 248.84, 248.84
% INFO    : Updated Thermal Rating: on line 28398-28456 : Rate B, Rate C - 0.0, 0.0 -> 167.11, 167.11
% INFO    : Updated Thermal Rating: on line 28402-28401 : Rate B, Rate C - 0.0, 0.0 -> 212.61, 212.61
% INFO    : Updated Thermal Rating: on line 28441-28402 : Rate B, Rate C - 0.0, 0.0 -> 241.96, 241.96
% INFO    : Updated Thermal Rating: on transformer 28403-28406 : Rate B, Rate C - 0.0, 0.0 -> 610.09, 610.09
% INFO    : Updated Thermal Rating: on transformer 28404-28406 : Rate B, Rate C - 0.0, 0.0 -> 485.09, 485.09
% INFO    : Updated Thermal Rating: on line 28404-28409 : Rate B, Rate C - 0.0, 0.0 -> 255.71, 255.71
% INFO    : Updated Thermal Rating: on line 28404-28836 : Rate B, Rate C - 0.0, 0.0 -> 217.83, 217.83
% INFO    : Updated Thermal Rating: on transformer 28405-28406 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 28780-28408 : Rate B, Rate C - 0.0, 0.0 -> 1094.55, 1094.55
% INFO    : Updated Thermal Rating: on line 28842-28408 : Rate B, Rate C - 0.0, 0.0 -> 1280.67, 1280.67
% INFO    : Updated Thermal Rating: on line 28409-28443 : Rate B, Rate C - 0.0, 0.0 -> 207.56, 207.56
% INFO    : Updated Thermal Rating: on line 28409-28450 : Rate B, Rate C - 0.0, 0.0 -> 243.37, 243.37
% INFO    : Updated Thermal Rating: on line 28409-28473 : Rate B, Rate C - 0.0, 0.0 -> 256.8, 256.8
% INFO    : Updated Thermal Rating: on line 28453-28410 : Rate B, Rate C - 0.0, 0.0 -> 237.55, 237.55
% INFO    : Updated Thermal Rating: on line 28908-28410 : Rate B, Rate C - 0.0, 0.0 -> 257.0, 257.0
% INFO    : Updated Thermal Rating: on line 28411-28469 : Rate B, Rate C - 0.0, 0.0 -> 194.51, 194.51
% INFO    : Updated Thermal Rating: on line 28421-28413 : Rate B, Rate C - 0.0, 0.0 -> 194.73, 194.73
% INFO    : Updated Thermal Rating: on line 28413-28469 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on line 28413-28808 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on transformer 28417-28416 : Rate B, Rate C - 0.0, 0.0 -> 519.4, 519.4
% INFO    : Updated Thermal Rating: on line 28416-28782 : Rate B, Rate C - 0.0, 0.0 -> 1217.42, 1217.42
% INFO    : Updated Thermal Rating: on line 28508-28417 : Rate B, Rate C - 0.0, 0.0 -> 246.98, 246.98
% INFO    : Updated Thermal Rating: on line 28421-28808 : Rate B, Rate C - 0.0, 0.0 -> 209.14, 209.14
% INFO    : Updated Thermal Rating: on line 28422-28481 : Rate B, Rate C - 0.0, 0.0 -> 222.35, 222.35
% INFO    : Updated Thermal Rating: on line 28422-28724 : Rate B, Rate C - 0.0, 0.0 -> 247.2, 247.2
% INFO    : Updated Thermal Rating: on line 28424-28446 : Rate B, Rate C - 0.0, 0.0 -> 231.19, 231.19
% INFO    : Updated Thermal Rating: on line 28456-28424 : Rate B, Rate C - 0.0, 0.0 -> 211.98, 211.98
% INFO    : Updated Thermal Rating: on line 28424-28495 : Rate B, Rate C - 0.0, 0.0 -> 226.58, 226.58
% INFO    : Updated Thermal Rating: on line 28425-28836 : Rate B, Rate C - 0.0, 0.0 -> 234.59, 234.59
% INFO    : Updated Thermal Rating: on line 28427-28441 : Rate B, Rate C - 0.0, 0.0 -> 230.06, 230.06
% INFO    : Updated Thermal Rating: on transformer 28428-28431 : Rate B, Rate C - 0.0, 0.0 -> 474.08, 474.08
% INFO    : Updated Thermal Rating: on line 28428-29081 : Rate B, Rate C - 0.0, 0.0 -> 1299.3, 1299.3
% INFO    : Updated Thermal Rating: on transformer 28429-28431 : Rate B, Rate C - 0.0, 0.0 -> 449.08, 449.08
% INFO    : Updated Thermal Rating: on transformer 28430-28431 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 28432-28783 : Rate B, Rate C - 0.0, 0.0 -> 291.75, 291.75
% INFO    : Updated Thermal Rating: on line 28432-28783 : Rate B, Rate C - 0.0, 0.0 -> 291.75, 291.75
% INFO    : Updated Thermal Rating: on line 28432-28783 : Rate B, Rate C - 0.0, 0.0 -> 291.75, 291.75
% INFO    : Updated Thermal Rating: on line 28508-28434 : Rate B, Rate C - 0.0, 0.0 -> 217.98, 217.98
% INFO    : Updated Thermal Rating: on line 28434-28531 : Rate B, Rate C - 0.0, 0.0 -> 250.12, 250.12
% INFO    : Updated Thermal Rating: on line 28437-28524 : Rate B, Rate C - 0.0, 0.0 -> 231.95, 231.95
% INFO    : Updated Thermal Rating: on line 28437-28843 : Rate B, Rate C - 0.0, 0.0 -> 233.56, 233.56
% INFO    : Updated Thermal Rating: on line 29004-28437 : Rate B, Rate C - 0.0, 0.0 -> 217.89, 217.89
% INFO    : Updated Thermal Rating: on line 28469-28438 : Rate B, Rate C - 0.0, 0.0 -> 226.55, 226.55
% INFO    : Updated Thermal Rating: on line 28438-28626 : Rate B, Rate C - 0.0, 0.0 -> 248.39, 248.39
% INFO    : Updated Thermal Rating: on line 29082-28439 : Rate B, Rate C - 0.0, 0.0 -> 239.17, 239.17
% INFO    : Updated Thermal Rating: on line 28440-28504 : Rate B, Rate C - 0.0, 0.0 -> 196.19, 196.19
% INFO    : Updated Thermal Rating: on line 28440-28583 : Rate B, Rate C - 0.0, 0.0 -> 236.73, 236.73
% INFO    : Updated Thermal Rating: on line 28442-28783 : Rate B, Rate C - 0.0, 0.0 -> 251.06, 251.06
% INFO    : Updated Thermal Rating: on line 28979-28446 : Rate B, Rate C - 0.0, 0.0 -> 251.88, 251.88
% INFO    : Updated Thermal Rating: on line 28447-28493 : Rate B, Rate C - 0.0, 0.0 -> 229.85, 229.85
% INFO    : Updated Thermal Rating: on line 28447-28495 : Rate B, Rate C - 0.0, 0.0 -> 254.76, 254.76
% INFO    : Updated Thermal Rating: on line 28447-28979 : Rate B, Rate C - 0.0, 0.0 -> 287.41, 287.41
% INFO    : Updated Thermal Rating: on line 28447-28979 : Rate B, Rate C - 0.0, 0.0 -> 287.41, 287.41
% INFO    : Updated Thermal Rating: on line 28447-28979 : Rate B, Rate C - 0.0, 0.0 -> 287.41, 287.41
% INFO    : Updated Thermal Rating: on line 28448-28572 : Rate B, Rate C - 0.0, 0.0 -> 157.5, 157.5
% INFO    : Updated Thermal Rating: on line 28448-28806 : Rate B, Rate C - 0.0, 0.0 -> 238.05, 238.05
% INFO    : Updated Thermal Rating: on line 28774-28450 : Rate B, Rate C - 0.0, 0.0 -> 265.32, 265.32
% INFO    : Updated Thermal Rating: on line 28453-28455 : Rate B, Rate C - 0.0, 0.0 -> 202.61, 202.61
% INFO    : Updated Thermal Rating: on transformer 28459-28458 : Rate B, Rate C - 0.0, 0.0 -> 468.62, 468.62
% INFO    : Updated Thermal Rating: on line 28459-28476 : Rate B, Rate C - 0.0, 0.0 -> 212.44, 212.44
% INFO    : Updated Thermal Rating: on line 28460-28848 : Rate B, Rate C - 0.0, 0.0 -> 1113.41, 1113.41
% INFO    : Updated Thermal Rating: on line 28460-28964 : Rate B, Rate C - 0.0, 0.0 -> 1273.95, 1273.95
% INFO    : Updated Thermal Rating: on line 28464-28463 : Rate B, Rate C - 0.0, 0.0 -> 244.85, 244.85
% INFO    : Updated Thermal Rating: on line 28463-28783 : Rate B, Rate C - 0.0, 0.0 -> 303.76, 303.76
% INFO    : Updated Thermal Rating: on line 28503-28466 : Rate B, Rate C - 0.0, 0.0 -> 228.51, 228.51
% INFO    : Updated Thermal Rating: on line 28524-28467 : Rate B, Rate C - 0.0, 0.0 -> 232.78, 232.78
% INFO    : Updated Thermal Rating: on line 28469-28471 : Rate B, Rate C - 0.0, 0.0 -> 163.4, 163.4
% INFO    : Updated Thermal Rating: on line 28471-28567 : Rate B, Rate C - 0.0, 0.0 -> 225.93, 225.93
% INFO    : Updated Thermal Rating: on line 28472-28549 : Rate B, Rate C - 0.0, 0.0 -> 231.71, 231.71
% INFO    : Updated Thermal Rating: on line 28473-28485 : Rate B, Rate C - 0.0, 0.0 -> 217.11, 217.11
% INFO    : Updated Thermal Rating: on line 28474-28475 : Rate B, Rate C - 0.0, 0.0 -> 192.38, 192.38
% INFO    : Updated Thermal Rating: on line 28474-28522 : Rate B, Rate C - 0.0, 0.0 -> 203.67, 203.67
% INFO    : Updated Thermal Rating: on line 28474-28774 : Rate B, Rate C - 0.0, 0.0 -> 306.87, 306.87
% INFO    : Updated Thermal Rating: on line 28475-28490 : Rate B, Rate C - 0.0, 0.0 -> 268.06, 268.06
% INFO    : Updated Thermal Rating: on line 28475-28523 : Rate B, Rate C - 0.0, 0.0 -> 174.96, 174.96
% INFO    : Updated Thermal Rating: on line 28979-28475 : Rate B, Rate C - 0.0, 0.0 -> 282.1, 282.1
% INFO    : Updated Thermal Rating: on line 28979-28475 : Rate B, Rate C - 0.0, 0.0 -> 282.1, 282.1
% INFO    : Updated Thermal Rating: on line 28477-28476 : Rate B, Rate C - 0.0, 0.0 -> 174.37, 174.37
% INFO    : Updated Thermal Rating: on line 28477-28619 : Rate B, Rate C - 0.0, 0.0 -> 218.3, 218.3
% INFO    : Updated Thermal Rating: on line 28485-28479 : Rate B, Rate C - 0.0, 0.0 -> 207.08, 207.08
% INFO    : Updated Thermal Rating: on line 28577-28479 : Rate B, Rate C - 0.0, 0.0 -> 236.41, 236.41
% INFO    : Updated Thermal Rating: on line 28480-28485 : Rate B, Rate C - 0.0, 0.0 -> 194.58, 194.58
% INFO    : Updated Thermal Rating: on line 28480-28488 : Rate B, Rate C - 0.0, 0.0 -> 201.24, 201.24
% INFO    : Updated Thermal Rating: on line 28481-28501 : Rate B, Rate C - 0.0, 0.0 -> 208.8, 208.8
% INFO    : Updated Thermal Rating: on line 28980-28481 : Rate B, Rate C - 0.0, 0.0 -> 216.61, 216.61
% INFO    : Updated Thermal Rating: on line 28482-28513 : Rate B, Rate C - 0.0, 0.0 -> 173.12, 173.12
% INFO    : Updated Thermal Rating: on line 28482-28545 : Rate B, Rate C - 0.0, 0.0 -> 241.49, 241.49
% INFO    : Updated Thermal Rating: on line 28482-29017 : Rate B, Rate C - 0.0, 0.0 -> 261.77, 261.77
% INFO    : Updated Thermal Rating: on line 28484-28513 : Rate B, Rate C - 0.0, 0.0 -> 192.11, 192.11
% INFO    : Updated Thermal Rating: on line 28544-28484 : Rate B, Rate C - 0.0, 0.0 -> 207.81, 207.81
% INFO    : Updated Thermal Rating: on line 28980-28488 : Rate B, Rate C - 0.0, 0.0 -> 240.52, 240.52
% INFO    : Updated Thermal Rating: on line 28490-28541 : Rate B, Rate C - 0.0, 0.0 -> 231.38, 231.38
% INFO    : Updated Thermal Rating: on line 28572-28490 : Rate B, Rate C - 0.0, 0.0 -> 220.24, 220.24
% INFO    : Updated Thermal Rating: on line 28491-28563 : Rate B, Rate C - 0.0, 0.0 -> 218.36, 218.36
% INFO    : Updated Thermal Rating: on line 28491-28599 : Rate B, Rate C - 0.0, 0.0 -> 235.83, 235.83
% INFO    : Updated Thermal Rating: on line 28493-28516 : Rate B, Rate C - 0.0, 0.0 -> 156.92, 156.92
% INFO    : Updated Thermal Rating: on line 28497-29017 : Rate B, Rate C - 0.0, 0.0 -> 228.69, 228.69
% INFO    : Updated Thermal Rating: on line 28497-29061 : Rate B, Rate C - 0.0, 0.0 -> 191.09, 191.09
% INFO    : Updated Thermal Rating: on line 28519-28498 : Rate B, Rate C - 0.0, 0.0 -> 220.42, 220.42
% INFO    : Updated Thermal Rating: on line 28547-28498 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 28501-28790 : Rate B, Rate C - 0.0, 0.0 -> 243.12, 243.12
% INFO    : Updated Thermal Rating: on transformer 28503-28502 : Rate B, Rate C - 0.0, 0.0 -> 505.66, 505.66
% INFO    : Updated Thermal Rating: on line 28813-28502 : Rate B, Rate C - 0.0, 0.0 -> 1108.12, 1108.12
% INFO    : Updated Thermal Rating: on line 28842-28502 : Rate B, Rate C - 0.0, 0.0 -> 1276.48, 1276.48
% INFO    : Updated Thermal Rating: on line 28604-28503 : Rate B, Rate C - 0.0, 0.0 -> 241.29, 241.29
% INFO    : Updated Thermal Rating: on line 28510-28509 : Rate B, Rate C - 0.0, 0.0 -> 228.1, 228.1
% INFO    : Updated Thermal Rating: on line 28567-28509 : Rate B, Rate C - 0.0, 0.0 -> 231.92, 231.92
% INFO    : Updated Thermal Rating: on line 28509-28624 : Rate B, Rate C - 0.0, 0.0 -> 211.96, 211.96
% INFO    : Updated Thermal Rating: on line 28510-28564 : Rate B, Rate C - 0.0, 0.0 -> 195.02, 195.02
% INFO    : Updated Thermal Rating: on line 28513-28728 : Rate B, Rate C - 0.0, 0.0 -> 240.7, 240.7
% INFO    : Updated Thermal Rating: on line 28544-28516 : Rate B, Rate C - 0.0, 0.0 -> 231.45, 231.45
% INFO    : Updated Thermal Rating: on line 28908-28519 : Rate B, Rate C - 0.0, 0.0 -> 258.23, 258.23
% INFO    : Updated Thermal Rating: on line 28520-28544 : Rate B, Rate C - 0.0, 0.0 -> 225.6, 225.6
% INFO    : Updated Thermal Rating: on line 28520-28549 : Rate B, Rate C - 0.0, 0.0 -> 195.87, 195.87
% INFO    : Updated Thermal Rating: on line 28522-28979 : Rate B, Rate C - 0.0, 0.0 -> 210.76, 210.76
% INFO    : Updated Thermal Rating: on line 28523-28900 : Rate B, Rate C - 0.0, 0.0 -> 205.89, 205.89
% INFO    : Updated Thermal Rating: on line 28524-28808 : Rate B, Rate C - 0.0, 0.0 -> 231.26, 231.26
% INFO    : Updated Thermal Rating: on line 28525-28603 : Rate B, Rate C - 0.0, 0.0 -> 206.15, 206.15
% INFO    : Updated Thermal Rating: on line 28604-28525 : Rate B, Rate C - 0.0, 0.0 -> 201.53, 201.53
% INFO    : Updated Thermal Rating: on line 28595-28528 : Rate B, Rate C - 0.0, 0.0 -> 216.75, 216.75
% INFO    : Updated Thermal Rating: on line 28528-28979 : Rate B, Rate C - 0.0, 0.0 -> 264.44, 264.44
% INFO    : Updated Thermal Rating: on line 28592-28530 : Rate B, Rate C - 0.0, 0.0 -> 194.35, 194.35
% INFO    : Updated Thermal Rating: on line 28530-28806 : Rate B, Rate C - 0.0, 0.0 -> 215.64, 215.64
% INFO    : Updated Thermal Rating: on line 28530-28856 : Rate B, Rate C - 0.0, 0.0 -> 216.12, 216.12
% INFO    : Updated Thermal Rating: on line 28531-28582 : Rate B, Rate C - 0.0, 0.0 -> 235.1, 235.1
% INFO    : Updated Thermal Rating: on line 28531-28640 : Rate B, Rate C - 0.0, 0.0 -> 230.98, 230.98
% INFO    : Updated Thermal Rating: on line 28635-28534 : Rate B, Rate C - 0.0, 0.0 -> 238.77, 238.77
% INFO    : Updated Thermal Rating: on line 28534-28688 : Rate B, Rate C - 0.0, 0.0 -> 260.57, 260.57
% INFO    : Updated Thermal Rating: on transformer 28536-28535 : Rate B, Rate C - 0.0, 0.0 -> 528.49, 528.49
% INFO    : Updated Thermal Rating: on line 28535-28631 : Rate B, Rate C - 0.0, 0.0 -> 1038.78, 1038.78
% INFO    : Updated Thermal Rating: on line 28842-28535 : Rate B, Rate C - 0.0, 0.0 -> 1291.81, 1291.81
% INFO    : Updated Thermal Rating: on transformer 28536-28539 : Rate B, Rate C - 0.0, 0.0 -> 91.99, 91.99
% INFO    : Updated Thermal Rating: on line 28536-28577 : Rate B, Rate C - 0.0, 0.0 -> 258.08, 258.08
% INFO    : Updated Thermal Rating: on line 28578-28536 : Rate B, Rate C - 0.0, 0.0 -> 237.67, 237.67
% INFO    : Updated Thermal Rating: on line 28536-28603 : Rate B, Rate C - 0.0, 0.0 -> 244.24, 244.24
% INFO    : Updated Thermal Rating: on line 28623-28536 : Rate B, Rate C - 0.0, 0.0 -> 202.45, 202.45
% INFO    : Updated Thermal Rating: on line 28536-28635 : Rate B, Rate C - 0.0, 0.0 -> 174.91, 174.91
% INFO    : Updated Thermal Rating: on line 28536-28637 : Rate B, Rate C - 0.0, 0.0 -> 178.76, 178.76
% INFO    : Updated Thermal Rating: on transformer 28537-28539 : Rate B, Rate C - 0.0, 0.0 -> 46.0, 46.0
% INFO    : Updated Thermal Rating: on transformer 28538-28539 : Rate B, Rate C - 0.0, 0.0 -> 46.0, 46.0
% INFO    : Updated Thermal Rating: on line 28541-28606 : Rate B, Rate C - 0.0, 0.0 -> 214.95, 214.95
% INFO    : Updated Thermal Rating: on line 28541-28932 : Rate B, Rate C - 0.0, 0.0 -> 206.4, 206.4
% INFO    : Updated Thermal Rating: on transformer 28544-28543 : Rate B, Rate C - 0.0, 0.0 -> 518.57, 518.57
% INFO    : Updated Thermal Rating: on line 28548-28543 : Rate B, Rate C - 0.0, 0.0 -> 1086.3, 1086.3
% INFO    : Updated Thermal Rating: on line 28543-29016 : Rate B, Rate C - 0.0, 0.0 -> 1271.29, 1271.29
% INFO    : Updated Thermal Rating: on line 28544-28547 : Rate B, Rate C - 0.0, 0.0 -> 229.44, 229.44
% INFO    : Updated Thermal Rating: on line 28580-28545 : Rate B, Rate C - 0.0, 0.0 -> 206.09, 206.09
% INFO    : Updated Thermal Rating: on line 28547-28932 : Rate B, Rate C - 0.0, 0.0 -> 233.15, 233.15
% INFO    : Updated Thermal Rating: on transformer 28548-28551 : Rate B, Rate C - 0.0, 0.0 -> 527.18, 527.18
% INFO    : Updated Thermal Rating: on line 28548-28598 : Rate B, Rate C - 0.0, 0.0 -> 1129.75, 1129.75
% INFO    : Updated Thermal Rating: on line 28548-28909 : Rate B, Rate C - 0.0, 0.0 -> 1227.94, 1227.94
% INFO    : Updated Thermal Rating: on line 28978-28548 : Rate B, Rate C - 0.0, 0.0 -> 1158.83, 1158.83
% INFO    : Updated Thermal Rating: on line 28548-29016 : Rate B, Rate C - 0.0, 0.0 -> 1368.54, 1368.54
% INFO    : Updated Thermal Rating: on transformer 28549-28551 : Rate B, Rate C - 0.0, 0.0 -> 502.18, 502.18
% INFO    : Updated Thermal Rating: on line 28549-28560 : Rate B, Rate C - 0.0, 0.0 -> 228.89, 228.89
% INFO    : Updated Thermal Rating: on transformer 28550-28551 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 28573-28552 : Rate B, Rate C - 0.0, 0.0 -> 213.76, 213.76
% INFO    : Updated Thermal Rating: on line 28552-28580 : Rate B, Rate C - 0.0, 0.0 -> 177.42, 177.42
% INFO    : Updated Thermal Rating: on line 28552-28601 : Rate B, Rate C - 0.0, 0.0 -> 204.39, 204.39
% INFO    : Updated Thermal Rating: on line 28554-28553 : Rate B, Rate C - 0.0, 0.0 -> 236.75, 236.75
% INFO    : Updated Thermal Rating: on line 28558-28553 : Rate B, Rate C - 0.0, 0.0 -> 218.53, 218.53
% INFO    : Updated Thermal Rating: on line 28553-28599 : Rate B, Rate C - 0.0, 0.0 -> 254.17, 254.17
% INFO    : Updated Thermal Rating: on line 28553-29061 : Rate B, Rate C - 0.0, 0.0 -> 231.62, 231.62
% INFO    : Updated Thermal Rating: on line 28563-28554 : Rate B, Rate C - 0.0, 0.0 -> 190.48, 190.48
% INFO    : Updated Thermal Rating: on line 28597-28555 : Rate B, Rate C - 0.0, 0.0 -> 195.62, 195.62
% INFO    : Updated Thermal Rating: on line 28638-28555 : Rate B, Rate C - 0.0, 0.0 -> 254.48, 254.48
% INFO    : Updated Thermal Rating: on line 28556-28568 : Rate B, Rate C - 0.0, 0.0 -> 188.27, 188.27
% INFO    : Updated Thermal Rating: on line 28556-28617 : Rate B, Rate C - 0.0, 0.0 -> 215.49, 215.49
% INFO    : Updated Thermal Rating: on line 28560-28606 : Rate B, Rate C - 0.0, 0.0 -> 201.32, 201.32
% INFO    : Updated Thermal Rating: on line 28564-28808 : Rate B, Rate C - 0.0, 0.0 -> 227.68, 227.68
% INFO    : Updated Thermal Rating: on transformer 28567-28566 : Rate B, Rate C - 0.0, 0.0 -> 436.61, 436.61
% INFO    : Updated Thermal Rating: on line 28566-28625 : Rate B, Rate C - 0.0, 0.0 -> 1139.95, 1139.95
% INFO    : Updated Thermal Rating: on line 28567-28646 : Rate B, Rate C - 0.0, 0.0 -> 210.73, 210.73
% INFO    : Updated Thermal Rating: on line 28568-29082 : Rate B, Rate C - 0.0, 0.0 -> 236.92, 236.92
% INFO    : Updated Thermal Rating: on line 28569-28611 : Rate B, Rate C - 0.0, 0.0 -> 176.79, 176.79
% INFO    : Updated Thermal Rating: on line 28569-28647 : Rate B, Rate C - 0.0, 0.0 -> 218.56, 218.56
% INFO    : Updated Thermal Rating: on line 28573-28575 : Rate B, Rate C - 0.0, 0.0 -> 239.24, 239.24
% INFO    : Updated Thermal Rating: on transformer 28575-28574 : Rate B, Rate C - 0.0, 0.0 -> 536.86, 536.86
% INFO    : Updated Thermal Rating: on line 28574-28780 : Rate B, Rate C - 0.0, 0.0 -> 1151.74, 1151.74
% INFO    : Updated Thermal Rating: on line 29016-28574 : Rate B, Rate C - 0.0, 0.0 -> 1342.46, 1342.46
% INFO    : Updated Thermal Rating: on line 28601-28575 : Rate B, Rate C - 0.0, 0.0 -> 237.45, 237.45
% INFO    : Updated Thermal Rating: on line 28575-28628 : Rate B, Rate C - 0.0, 0.0 -> 220.87, 220.87
% INFO    : Updated Thermal Rating: on line 28575-28629 : Rate B, Rate C - 0.0, 0.0 -> 226.84, 226.84
% INFO    : Updated Thermal Rating: on line 28612-28576 : Rate B, Rate C - 0.0, 0.0 -> 187.46, 187.46
% INFO    : Updated Thermal Rating: on line 28618-28576 : Rate B, Rate C - 0.0, 0.0 -> 200.71, 200.71
% INFO    : Updated Thermal Rating: on line 28578-28595 : Rate B, Rate C - 0.0, 0.0 -> 187.77, 187.77
% INFO    : Updated Thermal Rating: on line 28580-28615 : Rate B, Rate C - 0.0, 0.0 -> 214.12, 214.12
% INFO    : Updated Thermal Rating: on transformer 28582-28581 : Rate B, Rate C - 0.0, 0.0 -> 492.92, 492.92
% INFO    : Updated Thermal Rating: on line 28581-28782 : Rate B, Rate C - 0.0, 0.0 -> 1038.88, 1038.88
% INFO    : Updated Thermal Rating: on line 28581-28924 : Rate B, Rate C - 0.0, 0.0 -> 1169.06, 1169.06
% INFO    : Updated Thermal Rating: on line 28582-28583 : Rate B, Rate C - 0.0, 0.0 -> 255.2, 255.2
% INFO    : Updated Thermal Rating: on line 28596-28583 : Rate B, Rate C - 0.0, 0.0 -> 187.92, 187.92
% INFO    : Updated Thermal Rating: on line 28585-28615 : Rate B, Rate C - 0.0, 0.0 -> 234.74, 234.74
% INFO    : Updated Thermal Rating: on line 29017-28585 : Rate B, Rate C - 0.0, 0.0 -> 258.99, 258.99
% INFO    : Updated Thermal Rating: on line 28588-29017 : Rate B, Rate C - 0.0, 0.0 -> 184.57, 184.57
% INFO    : Updated Thermal Rating: on line 28588-29059 : Rate B, Rate C - 0.0, 0.0 -> 220.09, 220.09
% INFO    : Updated Thermal Rating: on line 28599-28589 : Rate B, Rate C - 0.0, 0.0 -> 223.87, 223.87
% INFO    : Updated Thermal Rating: on line 28613-28589 : Rate B, Rate C - 0.0, 0.0 -> 174.95, 174.95
% INFO    : Updated Thermal Rating: on line 28628-28590 : Rate B, Rate C - 0.0, 0.0 -> 192.73, 192.73
% INFO    : Updated Thermal Rating: on line 28590-28632 : Rate B, Rate C - 0.0, 0.0 -> 221.77, 221.77
% INFO    : Updated Thermal Rating: on line 28591-28629 : Rate B, Rate C - 0.0, 0.0 -> 189.86, 189.86
% INFO    : Updated Thermal Rating: on line 28856-28591 : Rate B, Rate C - 0.0, 0.0 -> 222.1, 222.1
% INFO    : Updated Thermal Rating: on line 28592-28806 : Rate B, Rate C - 0.0, 0.0 -> 218.5, 218.5
% INFO    : Updated Thermal Rating: on line 28594-28595 : Rate B, Rate C - 0.0, 0.0 -> 200.77, 200.77
% INFO    : Updated Thermal Rating: on line 28594-28979 : Rate B, Rate C - 0.0, 0.0 -> 241.56, 241.56
% INFO    : Updated Thermal Rating: on line 28595-28608 : Rate B, Rate C - 0.0, 0.0 -> 162.15, 162.15
% INFO    : Updated Thermal Rating: on line 28597-28596 : Rate B, Rate C - 0.0, 0.0 -> 227.31, 227.31
% INFO    : Updated Thermal Rating: on line 28597-29066 : Rate B, Rate C - 0.0, 0.0 -> 260.71, 260.71
% INFO    : Updated Thermal Rating: on transformer 28599-28598 : Rate B, Rate C - 0.0, 0.0 -> 531.69, 531.69
% INFO    : Updated Thermal Rating: on line 28598-29016 : Rate B, Rate C - 0.0, 0.0 -> 1328.35, 1328.35
% INFO    : Updated Thermal Rating: on line 28601-28643 : Rate B, Rate C - 0.0, 0.0 -> 159.68, 159.68
% INFO    : Updated Thermal Rating: on line 28608-28856 : Rate B, Rate C - 0.0, 0.0 -> 229.63, 229.63
% INFO    : Updated Thermal Rating: on line 28610-28891 : Rate B, Rate C - 0.0, 0.0 -> 236.5, 236.5
% INFO    : Updated Thermal Rating: on line 28611-28626 : Rate B, Rate C - 0.0, 0.0 -> 206.4, 206.4
% INFO    : Updated Thermal Rating: on line 28617-28612 : Rate B, Rate C - 0.0, 0.0 -> 234.53, 234.53
% INFO    : Updated Thermal Rating: on line 28626-28612 : Rate B, Rate C - 0.0, 0.0 -> 254.93, 254.93
% INFO    : Updated Thermal Rating: on line 28613-29059 : Rate B, Rate C - 0.0, 0.0 -> 226.26, 226.26
% INFO    : Updated Thermal Rating: on line 28618-28654 : Rate B, Rate C - 0.0, 0.0 -> 225.17, 225.17
% INFO    : Updated Thermal Rating: on line 28641-28619 : Rate B, Rate C - 0.0, 0.0 -> 206.39, 206.39
% INFO    : Updated Thermal Rating: on line 28619-28960 : Rate B, Rate C - 0.0, 0.0 -> 242.24, 242.24
% INFO    : Updated Thermal Rating: on line 28622-28623 : Rate B, Rate C - 0.0, 0.0 -> 193.58, 193.58
% INFO    : Updated Thermal Rating: on line 28622-28632 : Rate B, Rate C - 0.0, 0.0 -> 206.4, 206.4
% INFO    : Updated Thermal Rating: on line 28632-28623 : Rate B, Rate C - 0.0, 0.0 -> 212.43, 212.43
% INFO    : Updated Thermal Rating: on line 28624-28656 : Rate B, Rate C - 0.0, 0.0 -> 245.33, 245.33
% INFO    : Updated Thermal Rating: on transformer 28626-28625 : Rate B, Rate C - 0.0, 0.0 -> 490.73, 490.73
% INFO    : Updated Thermal Rating: on line 28763-28625 : Rate B, Rate C - 0.0, 0.0 -> 1330.67, 1330.67
% INFO    : Updated Thermal Rating: on transformer 28632-28631 : Rate B, Rate C - 0.0, 0.0 -> 448.66, 448.66
% INFO    : Updated Thermal Rating: on line 28857-28631 : Rate B, Rate C - 0.0, 0.0 -> 1125.35, 1125.35
% INFO    : Updated Thermal Rating: on line 28644-28634 : Rate B, Rate C - 0.0, 0.0 -> 229.53, 229.53
% INFO    : Updated Thermal Rating: on line 28634-28756 : Rate B, Rate C - 0.0, 0.0 -> 264.05, 264.05
% INFO    : Updated Thermal Rating: on line 28635-28637 : Rate B, Rate C - 0.0, 0.0 -> 211.31, 211.31
% INFO    : Updated Thermal Rating: on line 28640-28638 : Rate B, Rate C - 0.0, 0.0 -> 192.81, 192.81
% INFO    : Updated Thermal Rating: on line 28638-29037 : Rate B, Rate C - 0.0, 0.0 -> 265.72, 265.72
% INFO    : Updated Thermal Rating: on line 29062-28640 : Rate B, Rate C - 0.0, 0.0 -> 253.88, 253.88
% INFO    : Updated Thermal Rating: on line 28662-28641 : Rate B, Rate C - 0.0, 0.0 -> 162.18, 162.18
% INFO    : Updated Thermal Rating: on line 28643-28644 : Rate B, Rate C - 0.0, 0.0 -> 196.26, 196.26
% INFO    : Updated Thermal Rating: on line 28646-28685 : Rate B, Rate C - 0.0, 0.0 -> 220.72, 220.72
% INFO    : Updated Thermal Rating: on line 28647-28859 : Rate B, Rate C - 0.0, 0.0 -> 241.82, 241.82
% INFO    : Updated Thermal Rating: on line 28648-28917 : Rate B, Rate C - 0.0, 0.0 -> 176.2, 176.2
% INFO    : Updated Thermal Rating: on line 29038-28648 : Rate B, Rate C - 0.0, 0.0 -> 236.37, 236.37
% INFO    : Updated Thermal Rating: on line 29066-28648 : Rate B, Rate C - 0.0, 0.0 -> 214.52, 214.52
% INFO    : Updated Thermal Rating: on transformer 28649-28652 : Rate B, Rate C - 0.0, 0.0 -> 91.24, 91.24
% INFO    : Updated Thermal Rating: on line 28658-28649 : Rate B, Rate C - 0.0, 0.0 -> 207.43, 207.43
% INFO    : Updated Thermal Rating: on line 28649-28925 : Rate B, Rate C - 0.0, 0.0 -> 233.72, 233.72
% INFO    : Updated Thermal Rating: on transformer 28650-28652 : Rate B, Rate C - 0.0, 0.0 -> 45.62, 45.62
% INFO    : Updated Thermal Rating: on transformer 28651-28652 : Rate B, Rate C - 0.0, 0.0 -> 45.62, 45.62
% INFO    : Updated Thermal Rating: on line 29038-28654 : Rate B, Rate C - 0.0, 0.0 -> 247.44, 247.44
% INFO    : Updated Thermal Rating: on transformer 28656-28655 : Rate B, Rate C - 0.0, 0.0 -> 426.81, 426.81
% INFO    : Updated Thermal Rating: on line 28655-28684 : Rate B, Rate C - 0.0, 0.0 -> 1099.42, 1099.42
% INFO    : Updated Thermal Rating: on line 28655-28924 : Rate B, Rate C - 0.0, 0.0 -> 1100.94, 1100.94
% INFO    : Updated Thermal Rating: on line 28664-28656 : Rate B, Rate C - 0.0, 0.0 -> 177.89, 177.89
% INFO    : Updated Thermal Rating: on line 28656-28666 : Rate B, Rate C - 0.0, 0.0 -> 220.49, 220.49
% INFO    : Updated Thermal Rating: on line 28658-28659 : Rate B, Rate C - 0.0, 0.0 -> 189.25, 189.25
% INFO    : Updated Thermal Rating: on line 28859-28658 : Rate B, Rate C - 0.0, 0.0 -> 212.24, 212.24
% INFO    : Updated Thermal Rating: on line 28659-28726 : Rate B, Rate C - 0.0, 0.0 -> 216.95, 216.95
% INFO    : Updated Thermal Rating: on line 29055-28660 : Rate B, Rate C - 0.0, 0.0 -> 243.6, 243.6
% INFO    : Updated Thermal Rating: on line 28660-29062 : Rate B, Rate C - 0.0, 0.0 -> 227.94, 227.94
% INFO    : Updated Thermal Rating: on line 28662-28673 : Rate B, Rate C - 0.0, 0.0 -> 202.75, 202.75
% INFO    : Updated Thermal Rating: on line 28664-28917 : Rate B, Rate C - 0.0, 0.0 -> 211.64, 211.64
% INFO    : Updated Thermal Rating: on line 28666-28667 : Rate B, Rate C - 0.0, 0.0 -> 177.36, 177.36
% INFO    : Updated Thermal Rating: on line 28667-28675 : Rate B, Rate C - 0.0, 0.0 -> 204.88, 204.88
% INFO    : Updated Thermal Rating: on transformer 28668-28671 : Rate B, Rate C - 0.0, 0.0 -> 89.67, 89.67
% INFO    : Updated Thermal Rating: on line 28668-28672 : Rate B, Rate C - 0.0, 0.0 -> 193.53, 193.53
% INFO    : Updated Thermal Rating: on line 28685-28668 : Rate B, Rate C - 0.0, 0.0 -> 234.11, 234.11
% INFO    : Updated Thermal Rating: on transformer 28669-28671 : Rate B, Rate C - 0.0, 0.0 -> 44.83, 44.83
% INFO    : Updated Thermal Rating: on transformer 28670-28671 : Rate B, Rate C - 0.0, 0.0 -> 44.83, 44.83
% INFO    : Updated Thermal Rating: on line 28677-28672 : Rate B, Rate C - 0.0, 0.0 -> 195.77, 195.77
% INFO    : Updated Thermal Rating: on line 29055-28673 : Rate B, Rate C - 0.0, 0.0 -> 219.95, 219.95
% INFO    : Updated Thermal Rating: on line 28674-28680 : Rate B, Rate C - 0.0, 0.0 -> 221.24, 221.24
% INFO    : Updated Thermal Rating: on line 28674-28948 : Rate B, Rate C - 0.0, 0.0 -> 244.81, 244.81
% INFO    : Updated Thermal Rating: on line 28675-28677 : Rate B, Rate C - 0.0, 0.0 -> 218.65, 218.65
% INFO    : Updated Thermal Rating: on line 28675-28685 : Rate B, Rate C - 0.0, 0.0 -> 253.0, 253.0
% INFO    : Updated Thermal Rating: on line 28834-28679 : Rate B, Rate C - 0.0, 0.0 -> 218.51, 218.51
% INFO    : Updated Thermal Rating: on line 28996-28679 : Rate B, Rate C - 0.0, 0.0 -> 198.66, 198.66
% INFO    : Updated Thermal Rating: on line 28834-28680 : Rate B, Rate C - 0.0, 0.0 -> 224.36, 224.36
% INFO    : Updated Thermal Rating: on line 28680-28996 : Rate B, Rate C - 0.0, 0.0 -> 215.09, 215.09
% INFO    : Updated Thermal Rating: on line 28682-28685 : Rate B, Rate C - 0.0, 0.0 -> 241.54, 241.54
% INFO    : Updated Thermal Rating: on line 28996-28682 : Rate B, Rate C - 0.0, 0.0 -> 257.75, 257.75
% INFO    : Updated Thermal Rating: on transformer 28684-28687 : Rate B, Rate C - 0.0, 0.0 -> 544.45, 544.45
% INFO    : Updated Thermal Rating: on line 28833-28684 : Rate B, Rate C - 0.0, 0.0 -> 1225.18, 1225.18
% INFO    : Updated Thermal Rating: on transformer 28685-28687 : Rate B, Rate C - 0.0, 0.0 -> 469.45, 469.45
% INFO    : Updated Thermal Rating: on transformer 28686-28687 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 28688-28986 : Rate B, Rate C - 0.0, 0.0 -> 238.24, 238.24
% INFO    : Updated Thermal Rating: on line 28688-29053 : Rate B, Rate C - 0.0, 0.0 -> 228.14, 228.14
% INFO    : Updated Thermal Rating: on line 28694-28689 : Rate B, Rate C - 0.0, 0.0 -> 219.97, 219.97
% INFO    : Updated Thermal Rating: on line 28689-28823 : Rate B, Rate C - 0.0, 0.0 -> 244.78, 244.78
% INFO    : Updated Thermal Rating: on line 28697-28693 : Rate B, Rate C - 0.0, 0.0 -> 195.61, 195.61
% INFO    : Updated Thermal Rating: on line 29055-28693 : Rate B, Rate C - 0.0, 0.0 -> 186.91, 186.91
% INFO    : Updated Thermal Rating: on line 28694-28834 : Rate B, Rate C - 0.0, 0.0 -> 198.0, 198.0
% INFO    : Updated Thermal Rating: on line 28755-28695 : Rate B, Rate C - 0.0, 0.0 -> 178.2, 178.2
% INFO    : Updated Thermal Rating: on line 28695-28835 : Rate B, Rate C - 0.0, 0.0 -> 226.0, 226.0
% INFO    : Updated Thermal Rating: on line 28739-28697 : Rate B, Rate C - 0.0, 0.0 -> 234.7, 234.7
% INFO    : Updated Thermal Rating: on line 28699-28698 : Rate B, Rate C - 0.0, 0.0 -> 185.75, 185.75
% INFO    : Updated Thermal Rating: on line 28698-28750 : Rate B, Rate C - 0.0, 0.0 -> 228.03, 228.03
% INFO    : Updated Thermal Rating: on line 28699-28921 : Rate B, Rate C - 0.0, 0.0 -> 216.68, 216.68
% INFO    : Updated Thermal Rating: on line 28703-28858 : Rate B, Rate C - 0.0, 0.0 -> 183.47, 183.47
% INFO    : Updated Thermal Rating: on line 29009-28703 : Rate B, Rate C - 0.0, 0.0 -> 191.98, 191.98
% INFO    : Updated Thermal Rating: on line 28705-28704 : Rate B, Rate C - 0.0, 0.0 -> 186.82, 186.82
% INFO    : Updated Thermal Rating: on line 28894-28704 : Rate B, Rate C - 0.0, 0.0 -> 182.56, 182.56
% INFO    : Updated Thermal Rating: on line 28704-28966 : Rate B, Rate C - 0.0, 0.0 -> 228.05, 228.05
% INFO    : Updated Thermal Rating: on line 28705-29023 : Rate B, Rate C - 0.0, 0.0 -> 208.02, 208.02
% INFO    : Updated Thermal Rating: on line 28706-28750 : Rate B, Rate C - 0.0, 0.0 -> 233.13, 233.13
% INFO    : Updated Thermal Rating: on line 28905-28706 : Rate B, Rate C - 0.0, 0.0 -> 224.08, 224.08
% INFO    : Updated Thermal Rating: on line 28708-28710 : Rate B, Rate C - 0.0, 0.0 -> 192.66, 192.66
% INFO    : Updated Thermal Rating: on line 28835-28708 : Rate B, Rate C - 0.0, 0.0 -> 216.67, 216.67
% INFO    : Updated Thermal Rating: on line 28710-28878 : Rate B, Rate C - 0.0, 0.0 -> 189.83, 189.83
% INFO    : Updated Thermal Rating: on transformer 28712-28711 : Rate B, Rate C - 0.0, 0.0 -> 128.88, 128.88
% INFO    : Updated Thermal Rating: on line 28711-28731 : Rate B, Rate C - 0.0, 0.0 -> 181.12, 181.12
% INFO    : Updated Thermal Rating: on line 28711-28915 : Rate B, Rate C - 0.0, 0.0 -> 195.58, 195.58
% INFO    : Updated Thermal Rating: on line 40725-28712 : Rate B, Rate C - 0.0, 0.0 -> 116.63, 116.63
% INFO    : Updated Thermal Rating: on line 28713-28881 : Rate B, Rate C - 0.0, 0.0 -> 220.96, 220.96
% INFO    : Updated Thermal Rating: on line 28950-28713 : Rate B, Rate C - 0.0, 0.0 -> 178.78, 178.78
% INFO    : Updated Thermal Rating: on line 28716-30285 : Rate B, Rate C - 0.0, 0.0 -> 179.3, 179.3
% INFO    : Updated Thermal Rating: on transformer 28718-28717 : Rate B, Rate C - 0.0, 0.0 -> 1413.96, 1413.96
% INFO    : Updated Thermal Rating: on transformer 28717-28720 : Rate B, Rate C - 0.0, 0.0 -> 1346.86, 1346.86
% INFO    : Updated Thermal Rating: on transformer 28717-28721 : Rate B, Rate C - 0.0, 0.0 -> 1345.34, 1345.34
% INFO    : Updated Thermal Rating: on transformer 28717-28722 : Rate B, Rate C - 0.0, 0.0 -> 948.78, 948.78
% INFO    : Updated Thermal Rating: on line 28758-28717 : Rate B, Rate C - 0.0, 0.0 -> 4198.08, 4198.08
% INFO    : Updated Thermal Rating: on line 28717-28847 : Rate B, Rate C - 0.0, 0.0 -> 4162.78, 4162.78
% INFO    : Updated Thermal Rating: on transformer 28719-28718 : Rate B, Rate C - 0.0, 0.0 -> 346.98, 346.98
% INFO    : Updated Thermal Rating: on transformer 28718-28723 : Rate B, Rate C - 0.0, 0.0 -> 205.46, 205.46
% INFO    : Updated Thermal Rating: on line 28719-28869 : Rate B, Rate C - 0.0, 0.0 -> 226.1, 226.1
% INFO    : Updated Thermal Rating: on transformer 28724-28725 : Rate B, Rate C - 0.0, 0.0 -> 98.71, 98.71
% INFO    : Updated Thermal Rating: on line 28843-28724 : Rate B, Rate C - 0.0, 0.0 -> 285.9, 285.9
% INFO    : Updated Thermal Rating: on line 28843-28724 : Rate B, Rate C - 0.0, 0.0 -> 285.9, 285.9
% INFO    : Updated Thermal Rating: on line 28724-29004 : Rate B, Rate C - 0.0, 0.0 -> 244.29, 244.29
% INFO    : Updated Thermal Rating: on transformer 28726-28727 : Rate B, Rate C - 0.0, 0.0 -> 86.45, 86.45
% INFO    : Updated Thermal Rating: on line 28726-28764 : Rate B, Rate C - 0.0, 0.0 -> 188.8, 188.8
% INFO    : Updated Thermal Rating: on line 28726-28925 : Rate B, Rate C - 0.0, 0.0 -> 193.15, 193.15
% INFO    : Updated Thermal Rating: on transformer 28728-28729 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 29059-28728 : Rate B, Rate C - 0.0, 0.0 -> 189.9, 189.9
% INFO    : Updated Thermal Rating: on transformer 28731-28730 : Rate B, Rate C - 0.0, 0.0 -> 277.42, 277.42
% INFO    : Updated Thermal Rating: on line 28730-28920 : Rate B, Rate C - 0.0, 0.0 -> 980.2, 980.2
% INFO    : Updated Thermal Rating: on transformer 28731-28734 : Rate B, Rate C - 0.0, 0.0 -> 166.53, 166.53
% INFO    : Updated Thermal Rating: on transformer 28731-28735 : Rate B, Rate C - 0.0, 0.0 -> 40.58, 40.58
% INFO    : Updated Thermal Rating: on transformer 28731-28736 : Rate B, Rate C - 0.0, 0.0 -> 65.03, 65.03
% INFO    : Updated Thermal Rating: on line 28731-28921 : Rate B, Rate C - 0.0, 0.0 -> 198.46, 198.46
% INFO    : Updated Thermal Rating: on transformer 28732-28734 : Rate B, Rate C - 0.0, 0.0 -> 83.27, 83.27
% INFO    : Updated Thermal Rating: on transformer 28733-28734 : Rate B, Rate C - 0.0, 0.0 -> 83.27, 83.27
% INFO    : Updated Thermal Rating: on transformer 28738-28737 : Rate B, Rate C - 0.0, 0.0 -> 1328.6, 1328.6
% INFO    : Updated Thermal Rating: on transformer 28737-28740 : Rate B, Rate C - 0.0, 0.0 -> 1031.43, 1031.43
% INFO    : Updated Thermal Rating: on transformer 28737-28741 : Rate B, Rate C - 0.0, 0.0 -> 1025.1, 1025.1
% INFO    : Updated Thermal Rating: on transformer 28737-28742 : Rate B, Rate C - 0.0, 0.0 -> 1013.74, 1013.74
% INFO    : Updated Thermal Rating: on transformer 28737-28743 : Rate B, Rate C - 0.0, 0.0 -> 1003.52, 1003.52
% INFO    : Updated Thermal Rating: on transformer 28737-28744 : Rate B, Rate C - 0.0, 0.0 -> 997.12, 997.12
% INFO    : Updated Thermal Rating: on transformer 28737-28745 : Rate B, Rate C - 0.0, 0.0 -> 7500.0, 7500.0
% INFO    : Updated Thermal Rating: on transformer 28737-28746 : Rate B, Rate C - 0.0, 0.0 -> 1119.42, 1119.42
% INFO    : Updated Thermal Rating: on transformer 28737-28747 : Rate B, Rate C - 0.0, 0.0 -> 1116.24, 1116.24
% INFO    : Updated Thermal Rating: on transformer 28737-28748 : Rate B, Rate C - 0.0, 0.0 -> 1113.56, 1113.56
% INFO    : Updated Thermal Rating: on line 28888-28737 : Rate B, Rate C - 0.0, 0.0 -> 4121.36, 4121.36
% INFO    : Updated Thermal Rating: on line 28737-40759 : Rate B, Rate C - 0.0, 0.0 -> 4073.72, 4073.72
% INFO    : Updated Thermal Rating: on transformer 28739-28738 : Rate B, Rate C - 0.0, 0.0 -> 376.68, 376.68
% INFO    : Updated Thermal Rating: on line 28954-28738 : Rate B, Rate C - 0.0, 0.0 -> 1201.27, 1201.27
% INFO    : Updated Thermal Rating: on line 29054-28738 : Rate B, Rate C - 0.0, 0.0 -> 1238.4, 1238.4
% INFO    : Updated Thermal Rating: on line 28745-28772 : Rate B, Rate C - 0.0, 0.0 -> 4125.56, 4125.56
% INFO    : Updated Thermal Rating: on line 28745-28841 : Rate B, Rate C - 0.0, 0.0 -> 4128.28, 4128.28
% INFO    : Updated Thermal Rating: on transformer 28750-28749 : Rate B, Rate C - 0.0, 0.0 -> 327.13, 327.13
% INFO    : Updated Thermal Rating: on transformer 28749-28751 : Rate B, Rate C - 0.0, 0.0 -> 348.68, 348.68
% INFO    : Updated Thermal Rating: on transformer 28749-28752 : Rate B, Rate C - 0.0, 0.0 -> 302.8, 302.8
% INFO    : Updated Thermal Rating: on transformer 28749-28753 : Rate B, Rate C - 0.0, 0.0 -> 348.15, 348.15
% INFO    : Updated Thermal Rating: on transformer 28749-28754 : Rate B, Rate C - 0.0, 0.0 -> 302.42, 302.42
% INFO    : Updated Thermal Rating: on line 28911-28749 : Rate B, Rate C - 0.0, 0.0 -> 1223.2, 1223.2
% INFO    : Updated Thermal Rating: on line 28749-28935 : Rate B, Rate C - 0.0, 0.0 -> 1140.08, 1140.08
% INFO    : Updated Thermal Rating: on line 29023-28750 : Rate B, Rate C - 0.0, 0.0 -> 247.65, 247.65
% INFO    : Updated Thermal Rating: on line 28755-28902 : Rate B, Rate C - 0.0, 0.0 -> 220.01, 220.01
% INFO    : Updated Thermal Rating: on transformer 28756-28757 : Rate B, Rate C - 0.0, 0.0 -> 90.21, 90.21
% INFO    : Updated Thermal Rating: on line 28905-28756 : Rate B, Rate C - 0.0, 0.0 -> 251.43, 251.43
% INFO    : Updated Thermal Rating: on transformer 28759-28758 : Rate B, Rate C - 0.0, 0.0 -> 1410.98, 1410.98
% INFO    : Updated Thermal Rating: on transformer 28758-28761 : Rate B, Rate C - 0.0, 0.0 -> 1321.41, 1321.41
% INFO    : Updated Thermal Rating: on line 28758-40979 : Rate B, Rate C - 0.0, 0.0 -> 4074.29, 4074.29
% INFO    : Updated Thermal Rating: on transformer 28760-28759 : Rate B, Rate C - 0.0, 0.0 -> 321.21, 321.21
% INFO    : Updated Thermal Rating: on line 28759-28964 : Rate B, Rate C - 0.0, 0.0 -> 1300.28, 1300.28
% INFO    : Updated Thermal Rating: on line 28760-28891 : Rate B, Rate C - 0.0, 0.0 -> 209.52, 209.52
% INFO    : Updated Thermal Rating: on transformer 28763-28762 : Rate B, Rate C - 0.0, 0.0 -> 1518.98, 1518.98
% INFO    : Updated Thermal Rating: on transformer 28762-28765 : Rate B, Rate C - 0.0, 0.0 -> 1318.81, 1318.81
% INFO    : Updated Thermal Rating: on transformer 28762-28766 : Rate B, Rate C - 0.0, 0.0 -> 1317.23, 1317.23
% INFO    : Updated Thermal Rating: on transformer 28762-28767 : Rate B, Rate C - 0.0, 0.0 -> 1315.75, 1315.75
% INFO    : Updated Thermal Rating: on transformer 28762-28768 : Rate B, Rate C - 0.0, 0.0 -> 1314.66, 1314.66
% INFO    : Updated Thermal Rating: on transformer 28762-28769 : Rate B, Rate C - 0.0, 0.0 -> 1314.25, 1314.25
% INFO    : Updated Thermal Rating: on transformer 28762-28770 : Rate B, Rate C - 0.0, 0.0 -> 1312.58, 1312.58
% INFO    : Updated Thermal Rating: on transformer 28762-28771 : Rate B, Rate C - 0.0, 0.0 -> 720.55, 720.55
% INFO    : Updated Thermal Rating: on transformer 28764-28763 : Rate B, Rate C - 0.0, 0.0 -> 411.73, 411.73
% INFO    : Updated Thermal Rating: on line 28924-28763 : Rate B, Rate C - 0.0, 0.0 -> 1103.03, 1103.03
% INFO    : Updated Thermal Rating: on line 28764-28825 : Rate B, Rate C - 0.0, 0.0 -> 217.15, 217.15
% INFO    : Updated Thermal Rating: on line 29038-28764 : Rate B, Rate C - 0.0, 0.0 -> 235.13, 235.13
% INFO    : Updated Thermal Rating: on line 28772-28781 : Rate B, Rate C - 0.0, 0.0 -> 4021.48, 4021.48
% INFO    : Updated Thermal Rating: on line 29080-28772 : Rate B, Rate C - 0.0, 0.0 -> 4022.54, 4022.54
% INFO    : Updated Thermal Rating: on transformer 28774-28773 : Rate B, Rate C - 0.0, 0.0 -> 474.34, 474.34
% INFO    : Updated Thermal Rating: on transformer 28773-28778 : Rate B, Rate C - 0.0, 0.0 -> 339.33, 339.33
% INFO    : Updated Thermal Rating: on transformer 28773-28779 : Rate B, Rate C - 0.0, 0.0 -> 338.83, 338.83
% INFO    : Updated Thermal Rating: on transformer 28774-28777 : Rate B, Rate C - 0.0, 0.0 -> 89.5, 89.5
% INFO    : Updated Thermal Rating: on line 28774-28900 : Rate B, Rate C - 0.0, 0.0 -> 203.92, 203.92
% INFO    : Updated Thermal Rating: on transformer 28775-28777 : Rate B, Rate C - 0.0, 0.0 -> 44.75, 44.75
% INFO    : Updated Thermal Rating: on transformer 28776-28777 : Rate B, Rate C - 0.0, 0.0 -> 44.75, 44.75
% INFO    : Updated Thermal Rating: on line 28780-28978 : Rate B, Rate C - 0.0, 0.0 -> 1143.85, 1143.85
% INFO    : Updated Thermal Rating: on transformer 28782-28781 : Rate B, Rate C - 0.0, 0.0 -> 1722.57, 1722.57
% INFO    : Updated Thermal Rating: on transformer 28782-28781 : Rate B, Rate C - 0.0, 0.0 -> 1722.57, 1722.57
% INFO    : Updated Thermal Rating: on transformer 28782-28781 : Rate B, Rate C - 0.0, 0.0 -> 1722.57, 1722.57
% INFO    : Updated Thermal Rating: on transformer 28781-28784 : Rate B, Rate C - 0.0, 0.0 -> 1402.46, 1402.46
% INFO    : Updated Thermal Rating: on transformer 28781-28785 : Rate B, Rate C - 0.0, 0.0 -> 1400.9, 1400.9
% INFO    : Updated Thermal Rating: on transformer 28781-28786 : Rate B, Rate C - 0.0, 0.0 -> 1400.44, 1400.44
% INFO    : Updated Thermal Rating: on transformer 28781-28787 : Rate B, Rate C - 0.0, 0.0 -> 1399.39, 1399.39
% INFO    : Updated Thermal Rating: on transformer 28781-28788 : Rate B, Rate C - 0.0, 0.0 -> 1397.33, 1397.33
% INFO    : Updated Thermal Rating: on transformer 28781-28789 : Rate B, Rate C - 0.0, 0.0 -> 1393.9, 1393.9
% INFO    : Updated Thermal Rating: on line 28794-28781 : Rate B, Rate C - 0.0, 0.0 -> 3978.4, 3978.4
% INFO    : Updated Thermal Rating: on line 28781-28847 : Rate B, Rate C - 0.0, 0.0 -> 4122.47, 4122.47
% INFO    : Updated Thermal Rating: on transformer 28783-28782 : Rate B, Rate C - 0.0, 0.0 -> 641.55, 641.55
% INFO    : Updated Thermal Rating: on transformer 28783-28782 : Rate B, Rate C - 0.0, 0.0 -> 641.55, 641.55
% INFO    : Updated Thermal Rating: on transformer 28783-28782 : Rate B, Rate C - 0.0, 0.0 -> 641.55, 641.55
% INFO    : Updated Thermal Rating: on line 28782-28831 : Rate B, Rate C - 0.0, 0.0 -> 1336.47, 1336.47
% INFO    : Updated Thermal Rating: on line 28782-29003 : Rate B, Rate C - 0.0, 0.0 -> 1293.85, 1293.85
% INFO    : Updated Thermal Rating: on transformer 28790-28793 : Rate B, Rate C - 0.0, 0.0 -> 254.08, 254.08
% INFO    : Updated Thermal Rating: on line 28790-29004 : Rate B, Rate C - 0.0, 0.0 -> 200.75, 200.75
% INFO    : Updated Thermal Rating: on transformer 28791-28793 : Rate B, Rate C - 0.0, 0.0 -> 127.04, 127.04
% INFO    : Updated Thermal Rating: on transformer 28792-28793 : Rate B, Rate C - 0.0, 0.0 -> 127.04, 127.04
% INFO    : Updated Thermal Rating: on transformer 28795-28794 : Rate B, Rate C - 0.0, 0.0 -> 1522.96, 1522.96
% INFO    : Updated Thermal Rating: on transformer 28794-28797 : Rate B, Rate C - 0.0, 0.0 -> 1709.17, 1709.17
% INFO    : Updated Thermal Rating: on transformer 28794-28798 : Rate B, Rate C - 0.0, 0.0 -> 1699.8, 1699.8
% INFO    : Updated Thermal Rating: on transformer 28796-28795 : Rate B, Rate C - 0.0, 0.0 -> 475.85, 475.85
% INFO    : Updated Thermal Rating: on line 28795-28803 : Rate B, Rate C - 0.0, 0.0 -> 1187.28, 1187.28
% INFO    : Updated Thermal Rating: on line 28860-28795 : Rate B, Rate C - 0.0, 0.0 -> 1128.71, 1128.71
% INFO    : Updated Thermal Rating: on line 28796-28985 : Rate B, Rate C - 0.0, 0.0 -> 245.55, 245.55
% INFO    : Updated Thermal Rating: on transformer 28799-28802 : Rate B, Rate C - 0.0, 0.0 -> 621.39, 621.39
% INFO    : Updated Thermal Rating: on transformer 28800-28802 : Rate B, Rate C - 0.0, 0.0 -> 521.39, 521.39
% INFO    : Updated Thermal Rating: on transformer 28801-28802 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 28804-28912 : Rate B, Rate C - 0.0, 0.0 -> 202.61, 202.61
% INFO    : Updated Thermal Rating: on line 28804-28966 : Rate B, Rate C - 0.0, 0.0 -> 180.47, 180.47
% INFO    : Updated Thermal Rating: on line 28856-28806 : Rate B, Rate C - 0.0, 0.0 -> 248.13, 248.13
% INFO    : Updated Thermal Rating: on transformer 28807-28810 : Rate B, Rate C - 0.0, 0.0 -> 610.25, 610.25
% INFO    : Updated Thermal Rating: on transformer 28807-28811 : Rate B, Rate C - 0.0, 0.0 -> 353.21, 353.21
% INFO    : Updated Thermal Rating: on transformer 28807-28812 : Rate B, Rate C - 0.0, 0.0 -> 350.43, 350.43
% INFO    : Updated Thermal Rating: on transformer 28808-28810 : Rate B, Rate C - 0.0, 0.0 -> 485.25, 485.25
% INFO    : Updated Thermal Rating: on transformer 28809-28810 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 28815-28814 : Rate B, Rate C - 0.0, 0.0 -> 336.85, 336.85
% INFO    : Updated Thermal Rating: on transformer 28815-28818 : Rate B, Rate C - 0.0, 0.0 -> 198.69, 198.69
% INFO    : Updated Thermal Rating: on line 28840-28815 : Rate B, Rate C - 0.0, 0.0 -> 212.74, 212.74
% INFO    : Updated Thermal Rating: on transformer 28816-28818 : Rate B, Rate C - 0.0, 0.0 -> 99.34, 99.34
% INFO    : Updated Thermal Rating: on transformer 28817-28818 : Rate B, Rate C - 0.0, 0.0 -> 99.34, 99.34
% INFO    : Updated Thermal Rating: on transformer 28819-28820 : Rate B, Rate C - 0.0, 0.0 -> 34.31, 34.31
% INFO    : Updated Thermal Rating: on transformer 28819-28821 : Rate B, Rate C - 0.0, 0.0 -> 30.23, 30.23
% INFO    : Updated Thermal Rating: on line 28948-28823 : Rate B, Rate C - 0.0, 0.0 -> 205.19, 205.19
% INFO    : Updated Thermal Rating: on line 28823-28981 : Rate B, Rate C - 0.0, 0.0 -> 244.88, 244.88
% INFO    : Updated Thermal Rating: on line 28825-29037 : Rate B, Rate C - 0.0, 0.0 -> 242.61, 242.61
% INFO    : Updated Thermal Rating: on transformer 28827-28826 : Rate B, Rate C - 0.0, 0.0 -> 335.59, 335.59
% INFO    : Updated Thermal Rating: on transformer 28826-28828 : Rate B, Rate C - 0.0, 0.0 -> 340.12, 340.12
% INFO    : Updated Thermal Rating: on transformer 28826-28830 : Rate B, Rate C - 0.0, 0.0 -> 259.84, 259.84
% INFO    : Updated Thermal Rating: on line 28826-28833 : Rate B, Rate C - 0.0, 0.0 -> 1235.91, 1235.91
% INFO    : Updated Thermal Rating: on line 28877-28826 : Rate B, Rate C - 0.0, 0.0 -> 1176.4, 1176.4
% INFO    : Updated Thermal Rating: on line 29008-28826 : Rate B, Rate C - 0.0, 0.0 -> 1058.55, 1058.55
% INFO    : Updated Thermal Rating: on transformer 28827-28829 : Rate B, Rate C - 0.0, 0.0 -> 21.67, 21.67
% INFO    : Updated Thermal Rating: on line 28827-28902 : Rate B, Rate C - 0.0, 0.0 -> 216.4, 216.4
% INFO    : Updated Thermal Rating: on transformer 28832-28831 : Rate B, Rate C - 0.0, 0.0 -> 500.38, 500.38
% INFO    : Updated Thermal Rating: on line 28832-29005 : Rate B, Rate C - 0.0, 0.0 -> 246.52, 246.52
% INFO    : Updated Thermal Rating: on transformer 28834-28833 : Rate B, Rate C - 0.0, 0.0 -> 381.84, 381.84
% INFO    : Updated Thermal Rating: on line 28894-28835 : Rate B, Rate C - 0.0, 0.0 -> 216.09, 216.09
% INFO    : Updated Thermal Rating: on transformer 28836-28837 : Rate B, Rate C - 0.0, 0.0 -> 41.49, 41.49
% INFO    : Updated Thermal Rating: on transformer 28836-28838 : Rate B, Rate C - 0.0, 0.0 -> 14.3, 14.3
% INFO    : Updated Thermal Rating: on line 28840-28869 : Rate B, Rate C - 0.0, 0.0 -> 252.36, 252.36
% INFO    : Updated Thermal Rating: on transformer 28842-28841 : Rate B, Rate C - 0.0, 0.0 -> 1614.73, 1614.73
% INFO    : Updated Thermal Rating: on transformer 28842-28841 : Rate B, Rate C - 0.0, 0.0 -> 1614.73, 1614.73
% INFO    : Updated Thermal Rating: on transformer 28842-28841 : Rate B, Rate C - 0.0, 0.0 -> 1614.73, 1614.73
% INFO    : Updated Thermal Rating: on transformer 28841-28844 : Rate B, Rate C - 0.0, 0.0 -> 1440.14, 1440.14
% INFO    : Updated Thermal Rating: on transformer 28841-28845 : Rate B, Rate C - 0.0, 0.0 -> 1438.13, 1438.13
% INFO    : Updated Thermal Rating: on transformer 28841-28846 : Rate B, Rate C - 0.0, 0.0 -> 1437.86, 1437.86
% INFO    : Updated Thermal Rating: on line 29015-28841 : Rate B, Rate C - 0.0, 0.0 -> 3852.7, 3852.7
% INFO    : Updated Thermal Rating: on line 29024-28841 : Rate B, Rate C - 0.0, 0.0 -> 3974.25, 3974.25
% INFO    : Updated Thermal Rating: on transformer 28843-28842 : Rate B, Rate C - 0.0, 0.0 -> 540.95, 540.95
% INFO    : Updated Thermal Rating: on line 28842-28978 : Rate B, Rate C - 0.0, 0.0 -> 1285.06, 1285.06
% INFO    : Updated Thermal Rating: on transformer 28848-28847 : Rate B, Rate C - 0.0, 0.0 -> 1568.87, 1568.87
% INFO    : Updated Thermal Rating: on transformer 28847-28850 : Rate B, Rate C - 0.0, 0.0 -> 1504.14, 1504.14
% INFO    : Updated Thermal Rating: on transformer 28847-28851 : Rate B, Rate C - 0.0, 0.0 -> 1503.87, 1503.87
% INFO    : Updated Thermal Rating: on transformer 28847-28852 : Rate B, Rate C - 0.0, 0.0 -> 1502.78, 1502.78
% INFO    : Updated Thermal Rating: on transformer 28847-28853 : Rate B, Rate C - 0.0, 0.0 -> 1501.47, 1501.47
% INFO    : Updated Thermal Rating: on transformer 28847-28854 : Rate B, Rate C - 0.0, 0.0 -> 875.87, 875.87
% INFO    : Updated Thermal Rating: on transformer 28849-28848 : Rate B, Rate C - 0.0, 0.0 -> 607.21, 607.21
% INFO    : Updated Thermal Rating: on transformer 28849-28848 : Rate B, Rate C - 0.0, 0.0 -> 607.21, 607.21
% INFO    : Updated Thermal Rating: on transformer 28849-28848 : Rate B, Rate C - 0.0, 0.0 -> 607.21, 607.21
% INFO    : Updated Thermal Rating: on transformer 28856-28855 : Rate B, Rate C - 0.0, 0.0 -> 455.68, 455.68
% INFO    : Updated Thermal Rating: on line 28857-29016 : Rate B, Rate C - 0.0, 0.0 -> 1227.5, 1227.5
% INFO    : Updated Thermal Rating: on line 28858-28950 : Rate B, Rate C - 0.0, 0.0 -> 224.77, 224.77
% INFO    : Updated Thermal Rating: on line 28858-28981 : Rate B, Rate C - 0.0, 0.0 -> 244.14, 244.14
% INFO    : Updated Thermal Rating: on line 28859-28925 : Rate B, Rate C - 0.0, 0.0 -> 256.0, 256.0
% INFO    : Updated Thermal Rating: on transformer 28861-28860 : Rate B, Rate C - 0.0, 0.0 -> 467.61, 467.61
% INFO    : Updated Thermal Rating: on transformer 28860-28864 : Rate B, Rate C - 0.0, 0.0 -> 757.6, 757.6
% INFO    : Updated Thermal Rating: on transformer 28860-28865 : Rate B, Rate C - 0.0, 0.0 -> 392.45, 392.45
% INFO    : Updated Thermal Rating: on transformer 28860-28866 : Rate B, Rate C - 0.0, 0.0 -> 391.96, 391.96
% INFO    : Updated Thermal Rating: on transformer 28860-28867 : Rate B, Rate C - 0.0, 0.0 -> 391.14, 391.14
% INFO    : Updated Thermal Rating: on transformer 28860-28868 : Rate B, Rate C - 0.0, 0.0 -> 391.04, 391.04
% INFO    : Updated Thermal Rating: on transformer 28862-28864 : Rate B, Rate C - 0.0, 0.0 -> 378.8, 378.8
% INFO    : Updated Thermal Rating: on transformer 28863-28864 : Rate B, Rate C - 0.0, 0.0 -> 378.8, 378.8
% INFO    : Updated Thermal Rating: on transformer 28870-28873 : Rate B, Rate C - 0.0, 0.0 -> 235.08, 235.08
% INFO    : Updated Thermal Rating: on line 29014-28870 : Rate B, Rate C - 0.0, 0.0 -> 240.81, 240.81
% INFO    : Updated Thermal Rating: on transformer 28871-28873 : Rate B, Rate C - 0.0, 0.0 -> 117.54, 117.54
% INFO    : Updated Thermal Rating: on transformer 28872-28873 : Rate B, Rate C - 0.0, 0.0 -> 117.54, 117.54
% INFO    : Updated Thermal Rating: on line 29076-28875 : Rate B, Rate C - 0.0, 0.0 -> 163.91, 163.91
% INFO    : Updated Thermal Rating: on transformer 28878-28877 : Rate B, Rate C - 0.0, 0.0 -> 290.44, 290.44
% INFO    : Updated Thermal Rating: on line 28877-28911 : Rate B, Rate C - 0.0, 0.0 -> 1068.67, 1068.67
% INFO    : Updated Thermal Rating: on transformer 28880-28879 : Rate B, Rate C - 0.0, 0.0 -> 1401.76, 1401.76
% INFO    : Updated Thermal Rating: on transformer 28879-28885 : Rate B, Rate C - 0.0, 0.0 -> 1466.18, 1466.18
% INFO    : Updated Thermal Rating: on transformer 28879-28886 : Rate B, Rate C - 0.0, 0.0 -> 1464.85, 1464.85
% INFO    : Updated Thermal Rating: on transformer 28879-28887 : Rate B, Rate C - 0.0, 0.0 -> 1463.57, 1463.57
% INFO    : Updated Thermal Rating: on transformer 28880-28884 : Rate B, Rate C - 0.0, 0.0 -> 386.95, 386.95
% INFO    : Updated Thermal Rating: on line 28880-28954 : Rate B, Rate C - 0.0, 0.0 -> 1080.2, 1080.2
% INFO    : Updated Thermal Rating: on line 28880-40726 : Rate B, Rate C - 0.0, 0.0 -> 1123.71, 1123.71
% INFO    : Updated Thermal Rating: on transformer 28882-28881 : Rate B, Rate C - 0.0, 0.0 -> 92.04, 92.04
% INFO    : Updated Thermal Rating: on transformer 28881-28884 : Rate B, Rate C - 0.0, 0.0 -> 361.95, 361.95
% INFO    : Updated Thermal Rating: on line 28881-28989 : Rate B, Rate C - 0.0, 0.0 -> 202.95, 202.95
% INFO    : Updated Thermal Rating: on line 28882-40013 : Rate B, Rate C - 0.0, 0.0 -> 151.01, 151.01
% INFO    : Updated Thermal Rating: on transformer 28883-28884 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 40722-28888 : Rate B, Rate C - 0.0, 0.0 -> 3998.89, 3998.89
% INFO    : Updated Thermal Rating: on line 28888-40909 : Rate B, Rate C - 0.0, 0.0 -> 4129.38, 4129.38
% INFO    : Updated Thermal Rating: on transformer 28889-28890 : Rate B, Rate C - 0.0, 0.0 -> 172.9, 172.9
% INFO    : Updated Thermal Rating: on transformer 28892-28893 : Rate B, Rate C - 0.0, 0.0 -> 74.14, 74.14
% INFO    : Updated Thermal Rating: on transformer 28896-28899 : Rate B, Rate C - 0.0, 0.0 -> 155.01, 155.01
% INFO    : Updated Thermal Rating: on transformer 28897-28899 : Rate B, Rate C - 0.0, 0.0 -> 77.51, 77.51
% INFO    : Updated Thermal Rating: on transformer 28898-28899 : Rate B, Rate C - 0.0, 0.0 -> 77.51, 77.51
% INFO    : Updated Thermal Rating: on transformer 28900-28901 : Rate B, Rate C - 0.0, 0.0 -> 86.03, 86.03
% INFO    : Updated Thermal Rating: on line 28902-28948 : Rate B, Rate C - 0.0, 0.0 -> 223.83, 223.83
% INFO    : Updated Thermal Rating: on line 28902-28986 : Rate B, Rate C - 0.0, 0.0 -> 214.6, 214.6
% INFO    : Updated Thermal Rating: on transformer 28904-28903 : Rate B, Rate C - 0.0, 0.0 -> 1320.73, 1320.73
% INFO    : Updated Thermal Rating: on transformer 28903-28906 : Rate B, Rate C - 0.0, 0.0 -> 1605.84, 1605.84
% INFO    : Updated Thermal Rating: on line 28903-28919 : Rate B, Rate C - 0.0, 0.0 -> 4131.86, 4131.86
% INFO    : Updated Thermal Rating: on line 29015-28903 : Rate B, Rate C - 0.0, 0.0 -> 4185.2, 4185.2
% INFO    : Updated Thermal Rating: on transformer 28905-28904 : Rate B, Rate C - 0.0, 0.0 -> 356.16, 356.16
% INFO    : Updated Thermal Rating: on line 28911-28904 : Rate B, Rate C - 0.0, 0.0 -> 1247.21, 1247.21
% INFO    : Updated Thermal Rating: on line 29016-28904 : Rate B, Rate C - 0.0, 0.0 -> 1299.33, 1299.33
% INFO    : Updated Thermal Rating: on transformer 28908-28907 : Rate B, Rate C - 0.0, 0.0 -> 541.1, 541.1
% INFO    : Updated Thermal Rating: on transformer 28912-28911 : Rate B, Rate C - 0.0, 0.0 -> 322.38, 322.38
% INFO    : Updated Thermal Rating: on transformer 28911-28913 : Rate B, Rate C - 0.0, 0.0 -> 477.72, 477.72
% INFO    : Updated Thermal Rating: on line 28920-28911 : Rate B, Rate C - 0.0, 0.0 -> 1086.72, 1086.72
% INFO    : Updated Thermal Rating: on transformer 28915-28914 : Rate B, Rate C - 0.0, 0.0 -> 282.8, 282.8
% INFO    : Updated Thermal Rating: on line 40726-28916 : Rate B, Rate C - 0.0, 0.0 -> 985.21, 985.21
% INFO    : Updated Thermal Rating: on transformer 28917-28918 : Rate B, Rate C - 0.0, 0.0 -> 77.94, 77.94
% INFO    : Updated Thermal Rating: on transformer 28920-28919 : Rate B, Rate C - 0.0, 0.0 -> 1281.2, 1281.2
% INFO    : Updated Thermal Rating: on line 28919-40722 : Rate B, Rate C - 0.0, 0.0 -> 4073.08, 4073.08
% INFO    : Updated Thermal Rating: on transformer 28920-28923 : Rate B, Rate C - 0.0, 0.0 -> 436.49, 436.49
% INFO    : Updated Thermal Rating: on transformer 28921-28923 : Rate B, Rate C - 0.0, 0.0 -> 311.49, 311.49
% INFO    : Updated Thermal Rating: on transformer 28922-28923 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 28925-28924 : Rate B, Rate C - 0.0, 0.0 -> 396.47, 396.47
% INFO    : Updated Thermal Rating: on transformer 28924-28926 : Rate B, Rate C - 0.0, 0.0 -> 414.54, 414.54
% INFO    : Updated Thermal Rating: on line 29054-28924 : Rate B, Rate C - 0.0, 0.0 -> 1189.52, 1189.52
% INFO    : Updated Thermal Rating: on transformer 28925-28927 : Rate B, Rate C - 0.0, 0.0 -> 90.16, 90.16
% INFO    : Updated Thermal Rating: on line 28925-29049 : Rate B, Rate C - 0.0, 0.0 -> 192.74, 192.74
% INFO    : Updated Thermal Rating: on transformer 28928-28931 : Rate B, Rate C - 0.0, 0.0 -> 142.35, 142.35
% INFO    : Updated Thermal Rating: on transformer 28929-28931 : Rate B, Rate C - 0.0, 0.0 -> 71.18, 71.18
% INFO    : Updated Thermal Rating: on transformer 28930-28931 : Rate B, Rate C - 0.0, 0.0 -> 71.18, 71.18
% INFO    : Updated Thermal Rating: on transformer 28933-28934 : Rate B, Rate C - 0.0, 0.0 -> 66.59, 66.59
% INFO    : Updated Thermal Rating: on transformer 28936-28935 : Rate B, Rate C - 0.0, 0.0 -> 209.29, 209.29
% INFO    : Updated Thermal Rating: on line 28935-28976 : Rate B, Rate C - 0.0, 0.0 -> 1031.03, 1031.03
% INFO    : Updated Thermal Rating: on line 29023-28936 : Rate B, Rate C - 0.0, 0.0 -> 173.43, 173.43
% INFO    : Updated Thermal Rating: on transformer 28937-28940 : Rate B, Rate C - 0.0, 0.0 -> 155.99, 155.99
% INFO    : Updated Thermal Rating: on transformer 28937-28941 : Rate B, Rate C - 0.0, 0.0 -> 14.56, 14.56
% INFO    : Updated Thermal Rating: on transformer 28937-28942 : Rate B, Rate C - 0.0, 0.0 -> 14.56, 14.56
% INFO    : Updated Thermal Rating: on transformer 28938-28940 : Rate B, Rate C - 0.0, 0.0 -> 78.0, 78.0
% INFO    : Updated Thermal Rating: on transformer 28939-28940 : Rate B, Rate C - 0.0, 0.0 -> 78.0, 78.0
% INFO    : Updated Thermal Rating: on line 29005-28943 : Rate B, Rate C - 0.0, 0.0 -> 218.16, 218.16
% INFO    : Updated Thermal Rating: on transformer 28945-28946 : Rate B, Rate C - 0.0, 0.0 -> 87.67, 87.67
% INFO    : Updated Thermal Rating: on line 28948-29053 : Rate B, Rate C - 0.0, 0.0 -> 188.98, 188.98
% INFO    : Updated Thermal Rating: on transformer 28950-28949 : Rate B, Rate C - 0.0, 0.0 -> 366.88, 366.88
% INFO    : Updated Thermal Rating: on transformer 28949-28951 : Rate B, Rate C - 0.0, 0.0 -> 460.36, 460.36
% INFO    : Updated Thermal Rating: on transformer 28949-28952 : Rate B, Rate C - 0.0, 0.0 -> 458.54, 458.54
% INFO    : Updated Thermal Rating: on transformer 28950-28953 : Rate B, Rate C - 0.0, 0.0 -> 40.42, 40.42
% INFO    : Updated Thermal Rating: on line 28954-28988 : Rate B, Rate C - 0.0, 0.0 -> 1134.85, 1134.85
% INFO    : Updated Thermal Rating: on transformer 28960-28959 : Rate B, Rate C - 0.0, 0.0 -> 347.41, 347.41
% INFO    : Updated Thermal Rating: on transformer 28959-28961 : Rate B, Rate C - 0.0, 0.0 -> 303.83, 303.83
% INFO    : Updated Thermal Rating: on transformer 28960-28962 : Rate B, Rate C - 0.0, 0.0 -> 33.42, 33.42
% INFO    : Updated Thermal Rating: on transformer 28960-28963 : Rate B, Rate C - 0.0, 0.0 -> 56.13, 56.13
% INFO    : Updated Thermal Rating: on transformer 28965-28968 : Rate B, Rate C - 0.0, 0.0 -> 281.17, 281.17
% INFO    : Updated Thermal Rating: on transformer 28965-28971 : Rate B, Rate C - 0.0, 0.0 -> 657.6, 657.6
% INFO    : Updated Thermal Rating: on transformer 28965-28974 : Rate B, Rate C - 0.0, 0.0 -> 256.13, 256.13
% INFO    : Updated Thermal Rating: on transformer 28965-28975 : Rate B, Rate C - 0.0, 0.0 -> 250.09, 250.09
% INFO    : Updated Thermal Rating: on transformer 28966-28968 : Rate B, Rate C - 0.0, 0.0 -> 256.17, 256.17
% INFO    : Updated Thermal Rating: on transformer 28966-28972 : Rate B, Rate C - 0.0, 0.0 -> 65.82, 65.82
% INFO    : Updated Thermal Rating: on transformer 28966-28973 : Rate B, Rate C - 0.0, 0.0 -> 62.47, 62.47
% INFO    : Updated Thermal Rating: on transformer 28967-28968 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 28969-28971 : Rate B, Rate C - 0.0, 0.0 -> 328.8, 328.8
% INFO    : Updated Thermal Rating: on transformer 28970-28971 : Rate B, Rate C - 0.0, 0.0 -> 328.8, 328.8
% INFO    : Updated Thermal Rating: on transformer 28979-28978 : Rate B, Rate C - 0.0, 0.0 -> 612.64, 612.64
% INFO    : Updated Thermal Rating: on transformer 28979-28978 : Rate B, Rate C - 0.0, 0.0 -> 612.64, 612.64
% INFO    : Updated Thermal Rating: on transformer 28979-28978 : Rate B, Rate C - 0.0, 0.0 -> 612.64, 612.64
% INFO    : Updated Thermal Rating: on transformer 28981-28982 : Rate B, Rate C - 0.0, 0.0 -> 69.65, 69.65
% INFO    : Updated Thermal Rating: on transformer 28983-28984 : Rate B, Rate C - 0.0, 0.0 -> 86.89, 86.89
% INFO    : Updated Thermal Rating: on transformer 28986-28987 : Rate B, Rate C - 0.0, 0.0 -> 98.11, 98.11
% INFO    : Updated Thermal Rating: on transformer 28989-28988 : Rate B, Rate C - 0.0, 0.0 -> 344.04, 344.04
% INFO    : Updated Thermal Rating: on transformer 28988-28991 : Rate B, Rate C - 0.0, 0.0 -> 357.43, 357.43
% INFO    : Updated Thermal Rating: on transformer 28988-28992 : Rate B, Rate C - 0.0, 0.0 -> 354.38, 354.38
% INFO    : Updated Thermal Rating: on line 28988-40039 : Rate B, Rate C - 0.0, 0.0 -> 1071.54, 1071.54
% INFO    : Updated Thermal Rating: on transformer 28990-28989 : Rate B, Rate C - 0.0, 0.0 -> 90.0, 90.0
% INFO    : Updated Thermal Rating: on line 40027-28990 : Rate B, Rate C - 0.0, 0.0 -> 138.66, 138.66
% INFO    : Updated Thermal Rating: on line 28990-40040 : Rate B, Rate C - 0.0, 0.0 -> 112.36, 112.36
% INFO    : Updated Thermal Rating: on transformer 28993-28994 : Rate B, Rate C - 0.0, 0.0 -> 82.61, 82.61
% INFO    : Updated Thermal Rating: on transformer 28993-28995 : Rate B, Rate C - 0.0, 0.0 -> 81.7, 81.7
% INFO    : Updated Thermal Rating: on transformer 28999-28998 : Rate B, Rate C - 0.0, 0.0 -> 561.05, 561.05
% INFO    : Updated Thermal Rating: on transformer 28998-29000 : Rate B, Rate C - 0.0, 0.0 -> 330.41, 330.41
% INFO    : Updated Thermal Rating: on transformer 28998-29001 : Rate B, Rate C - 0.0, 0.0 -> 412.91, 412.91
% INFO    : Updated Thermal Rating: on transformer 28998-29002 : Rate B, Rate C - 0.0, 0.0 -> 329.38, 329.38
% INFO    : Updated Thermal Rating: on transformer 29005-29006 : Rate B, Rate C - 0.0, 0.0 -> 43.1, 43.1
% INFO    : Updated Thermal Rating: on transformer 29005-29007 : Rate B, Rate C - 0.0, 0.0 -> 42.58, 42.58
% INFO    : Updated Thermal Rating: on transformer 29009-29008 : Rate B, Rate C - 0.0, 0.0 -> 292.89, 292.89
% INFO    : Updated Thermal Rating: on transformer 29008-29010 : Rate B, Rate C - 0.0, 0.0 -> 360.71, 360.71
% INFO    : Updated Thermal Rating: on transformer 29008-29011 : Rate B, Rate C - 0.0, 0.0 -> 360.32, 360.32
% INFO    : Updated Thermal Rating: on transformer 29012-29013 : Rate B, Rate C - 0.0, 0.0 -> 82.64, 82.64
% INFO    : Updated Thermal Rating: on transformer 29016-29015 : Rate B, Rate C - 0.0, 0.0 -> 1624.34, 1624.34
% INFO    : Updated Thermal Rating: on transformer 29016-29015 : Rate B, Rate C - 0.0, 0.0 -> 1624.34, 1624.34
% INFO    : Updated Thermal Rating: on transformer 29016-29015 : Rate B, Rate C - 0.0, 0.0 -> 1624.34, 1624.34
% INFO    : Updated Thermal Rating: on transformer 29015-29018 : Rate B, Rate C - 0.0, 0.0 -> 1558.2, 1558.2
% INFO    : Updated Thermal Rating: on transformer 29015-29019 : Rate B, Rate C - 0.0, 0.0 -> 1553.84, 1553.84
% INFO    : Updated Thermal Rating: on transformer 29015-29020 : Rate B, Rate C - 0.0, 0.0 -> 1553.42, 1553.42
% INFO    : Updated Thermal Rating: on transformer 29017-29016 : Rate B, Rate C - 0.0, 0.0 -> 535.64, 535.64
% INFO    : Updated Thermal Rating: on transformer 29021-29022 : Rate B, Rate C - 0.0, 0.0 -> 167.57, 167.57
% INFO    : Updated Thermal Rating: on transformer 29025-29024 : Rate B, Rate C - 0.0, 0.0 -> 1562.59, 1562.59
% INFO    : Updated Thermal Rating: on transformer 29024-29027 : Rate B, Rate C - 0.0, 0.0 -> 1458.75, 1458.75
% INFO    : Updated Thermal Rating: on transformer 29024-29028 : Rate B, Rate C - 0.0, 0.0 -> 1458.52, 1458.52
% INFO    : Updated Thermal Rating: on transformer 29024-29029 : Rate B, Rate C - 0.0, 0.0 -> 1457.66, 1457.66
% INFO    : Updated Thermal Rating: on transformer 29024-29030 : Rate B, Rate C - 0.0, 0.0 -> 1457.01, 1457.01
% INFO    : Updated Thermal Rating: on transformer 29024-29031 : Rate B, Rate C - 0.0, 0.0 -> 1456.82, 1456.82
% INFO    : Updated Thermal Rating: on transformer 29026-29025 : Rate B, Rate C - 0.0, 0.0 -> 539.43, 539.43
% INFO    : Updated Thermal Rating: on transformer 29025-29032 : Rate B, Rate C - 0.0, 0.0 -> 276.86, 276.86
% INFO    : Updated Thermal Rating: on transformer 29033-29036 : Rate B, Rate C - 0.0, 0.0 -> 149.31, 149.31
% INFO    : Updated Thermal Rating: on transformer 29034-29036 : Rate B, Rate C - 0.0, 0.0 -> 74.65, 74.65
% INFO    : Updated Thermal Rating: on transformer 29035-29036 : Rate B, Rate C - 0.0, 0.0 -> 74.65, 74.65
% INFO    : Updated Thermal Rating: on line 29038-29049 : Rate B, Rate C - 0.0, 0.0 -> 216.3, 216.3
% INFO    : Updated Thermal Rating: on transformer 29040-29039 : Rate B, Rate C - 0.0, 0.0 -> 1541.07, 1541.07
% INFO    : Updated Thermal Rating: on transformer 29039-29042 : Rate B, Rate C - 0.0, 0.0 -> 1523.34, 1523.34
% INFO    : Updated Thermal Rating: on transformer 29039-29043 : Rate B, Rate C - 0.0, 0.0 -> 1522.14, 1522.14
% INFO    : Updated Thermal Rating: on transformer 29041-29040 : Rate B, Rate C - 0.0, 0.0 -> 455.81, 455.81
% INFO    : Updated Thermal Rating: on transformer 29046-29047 : Rate B, Rate C - 0.0, 0.0 -> 103.19, 103.19
% INFO    : Updated Thermal Rating: on transformer 29046-29048 : Rate B, Rate C - 0.0, 0.0 -> 54.42, 54.42
% INFO    : Updated Thermal Rating: on transformer 29050-29051 : Rate B, Rate C - 0.0, 0.0 -> 93.99, 93.99
% INFO    : Updated Thermal Rating: on transformer 29050-29052 : Rate B, Rate C - 0.0, 0.0 -> 43.4, 43.4
% INFO    : Updated Thermal Rating: on transformer 29055-29054 : Rate B, Rate C - 0.0, 0.0 -> 400.8, 400.8
% INFO    : Updated Thermal Rating: on transformer 29055-29058 : Rate B, Rate C - 0.0, 0.0 -> 152.39, 152.39
% INFO    : Updated Thermal Rating: on transformer 29056-29058 : Rate B, Rate C - 0.0, 0.0 -> 76.2, 76.2
% INFO    : Updated Thermal Rating: on transformer 29057-29058 : Rate B, Rate C - 0.0, 0.0 -> 76.2, 76.2
% INFO    : Updated Thermal Rating: on transformer 29062-29065 : Rate B, Rate C - 0.0, 0.0 -> 228.73, 228.73
% INFO    : Updated Thermal Rating: on transformer 29063-29065 : Rate B, Rate C - 0.0, 0.0 -> 114.36, 114.36
% INFO    : Updated Thermal Rating: on transformer 29064-29065 : Rate B, Rate C - 0.0, 0.0 -> 114.36, 114.36
% INFO    : Updated Thermal Rating: on transformer 29066-29069 : Rate B, Rate C - 0.0, 0.0 -> 87.56, 87.56
% INFO    : Updated Thermal Rating: on transformer 29066-29070 : Rate B, Rate C - 0.0, 0.0 -> 100.72, 100.72
% INFO    : Updated Thermal Rating: on transformer 29066-29071 : Rate B, Rate C - 0.0, 0.0 -> 65.41, 65.41
% INFO    : Updated Thermal Rating: on transformer 29067-29069 : Rate B, Rate C - 0.0, 0.0 -> 43.78, 43.78
% INFO    : Updated Thermal Rating: on transformer 29068-29069 : Rate B, Rate C - 0.0, 0.0 -> 43.78, 43.78
% INFO    : Updated Thermal Rating: on transformer 29072-29073 : Rate B, Rate C - 0.0, 0.0 -> 173.42, 173.42
% INFO    : Updated Thermal Rating: on line 29074-30118 : Rate B, Rate C - 0.0, 0.0 -> 218.89, 218.89
% INFO    : Updated Thermal Rating: on line 29074-30159 : Rate B, Rate C - 0.0, 0.0 -> 224.35, 224.35
% INFO    : Updated Thermal Rating: on transformer 29075-29078 : Rate B, Rate C - 0.0, 0.0 -> 611.2, 611.2
% INFO    : Updated Thermal Rating: on transformer 29076-29078 : Rate B, Rate C - 0.0, 0.0 -> 511.2, 511.2
% INFO    : Updated Thermal Rating: on transformer 29077-29078 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 29081-29080 : Rate B, Rate C - 0.0, 0.0 -> 1580.28, 1580.28
% INFO    : Updated Thermal Rating: on transformer 29080-29083 : Rate B, Rate C - 0.0, 0.0 -> 1756.48, 1756.48
% INFO    : Updated Thermal Rating: on transformer 29080-29084 : Rate B, Rate C - 0.0, 0.0 -> 1752.74, 1752.74
% INFO    : Updated Thermal Rating: on transformer 29082-29081 : Rate B, Rate C - 0.0, 0.0 -> 544.08, 544.08
% INFO    : Updated Thermal Rating: on line 30016-30000 : Rate B, Rate C - 0.0, 0.0 -> 253.92, 253.92
% INFO    : Updated Thermal Rating: on line 30000-30046 : Rate B, Rate C - 0.0, 0.0 -> 276.08, 276.08
% INFO    : Updated Thermal Rating: on line 30001-30002 : Rate B, Rate C - 0.0, 0.0 -> 265.03, 265.03
% INFO    : Updated Thermal Rating: on line 30001-30014 : Rate B, Rate C - 0.0, 0.0 -> 187.14, 187.14
% INFO    : Updated Thermal Rating: on transformer 30003-30002 : Rate B, Rate C - 0.0, 0.0 -> 114.9, 114.9
% INFO    : Updated Thermal Rating: on transformer 30003-30002 : Rate B, Rate C - 0.0, 0.0 -> 114.9, 114.9
% INFO    : Updated Thermal Rating: on transformer 30003-30002 : Rate B, Rate C - 0.0, 0.0 -> 114.9, 114.9
% INFO    : Updated Thermal Rating: on line 30002-30005 : Rate B, Rate C - 0.0, 0.0 -> 234.53, 234.53
% INFO    : Updated Thermal Rating: on line 30002-30028 : Rate B, Rate C - 0.0, 0.0 -> 250.51, 250.51
% INFO    : Updated Thermal Rating: on line 30036-30005 : Rate B, Rate C - 0.0, 0.0 -> 244.75, 244.75
% INFO    : Updated Thermal Rating: on transformer 30006-30009 : Rate B, Rate C - 0.0, 0.0 -> 181.77, 181.77
% INFO    : Updated Thermal Rating: on transformer 30007-30009 : Rate B, Rate C - 0.0, 0.0 -> 106.77, 106.77
% INFO    : Updated Thermal Rating: on transformer 30008-30009 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 30011-30034 : Rate B, Rate C - 0.0, 0.0 -> 235.71, 235.71
% INFO    : Updated Thermal Rating: on transformer 30013-30012 : Rate B, Rate C - 0.0, 0.0 -> 120.0, 120.0
% INFO    : Updated Thermal Rating: on line 30015-30014 : Rate B, Rate C - 0.0, 0.0 -> 214.91, 214.91
% INFO    : Updated Thermal Rating: on line 30031-30015 : Rate B, Rate C - 0.0, 0.0 -> 249.89, 249.89
% INFO    : Updated Thermal Rating: on line 30015-30051 : Rate B, Rate C - 0.0, 0.0 -> 220.6, 220.6
% INFO    : Updated Thermal Rating: on transformer 30017-30016 : Rate B, Rate C - 0.0, 0.0 -> 82.6, 82.6
% INFO    : Updated Thermal Rating: on line 30038-30016 : Rate B, Rate C - 0.0, 0.0 -> 255.78, 255.78
% INFO    : Updated Thermal Rating: on line 30018-30033 : Rate B, Rate C - 0.0, 0.0 -> 249.53, 249.53
% INFO    : Updated Thermal Rating: on line 30018-30042 : Rate B, Rate C - 0.0, 0.0 -> 270.04, 270.04
% INFO    : Updated Thermal Rating: on line 30019-30022 : Rate B, Rate C - 0.0, 0.0 -> 239.29, 239.29
% INFO    : Updated Thermal Rating: on line 30042-30019 : Rate B, Rate C - 0.0, 0.0 -> 250.29, 250.29
% INFO    : Updated Thermal Rating: on line 30019-30062 : Rate B, Rate C - 0.0, 0.0 -> 245.08, 245.08
% INFO    : Updated Thermal Rating: on line 30022-30042 : Rate B, Rate C - 0.0, 0.0 -> 247.74, 247.74
% INFO    : Updated Thermal Rating: on line 30024-30046 : Rate B, Rate C - 0.0, 0.0 -> 263.66, 263.66
% INFO    : Updated Thermal Rating: on line 30049-30024 : Rate B, Rate C - 0.0, 0.0 -> 242.84, 242.84
% INFO    : Updated Thermal Rating: on line 30042-30026 : Rate B, Rate C - 0.0, 0.0 -> 233.45, 233.45
% INFO    : Updated Thermal Rating: on line 30026-30311 : Rate B, Rate C - 0.0, 0.0 -> 259.69, 259.69
% INFO    : Updated Thermal Rating: on line 30028-30039 : Rate B, Rate C - 0.0, 0.0 -> 243.15, 243.15
% INFO    : Updated Thermal Rating: on line 30029-30030 : Rate B, Rate C - 0.0, 0.0 -> 242.4, 242.4
% INFO    : Updated Thermal Rating: on line 30036-30029 : Rate B, Rate C - 0.0, 0.0 -> 263.3, 263.3
% INFO    : Updated Thermal Rating: on line 30029-30059 : Rate B, Rate C - 0.0, 0.0 -> 248.01, 248.01
% INFO    : Updated Thermal Rating: on line 30030-30036 : Rate B, Rate C - 0.0, 0.0 -> 260.18, 260.18
% INFO    : Updated Thermal Rating: on line 30046-30031 : Rate B, Rate C - 0.0, 0.0 -> 260.2, 260.2
% INFO    : Updated Thermal Rating: on line 30033-30032 : Rate B, Rate C - 0.0, 0.0 -> 259.7, 259.7
% INFO    : Updated Thermal Rating: on line 30039-30032 : Rate B, Rate C - 0.0, 0.0 -> 205.57, 205.57
% INFO    : Updated Thermal Rating: on line 30040-30033 : Rate B, Rate C - 0.0, 0.0 -> 266.07, 266.07
% INFO    : Updated Thermal Rating: on line 30034-30038 : Rate B, Rate C - 0.0, 0.0 -> 237.84, 237.84
% INFO    : Updated Thermal Rating: on line 30034-30066 : Rate B, Rate C - 0.0, 0.0 -> 242.53, 242.53
% INFO    : Updated Thermal Rating: on transformer 30036-30035 : Rate B, Rate C - 0.0, 0.0 -> 415.09, 415.09
% INFO    : Updated Thermal Rating: on line 30388-30035 : Rate B, Rate C - 0.0, 0.0 -> 1165.99, 1165.99
% INFO    : Updated Thermal Rating: on line 30038-30049 : Rate B, Rate C - 0.0, 0.0 -> 240.16, 240.16
% INFO    : Updated Thermal Rating: on line 30039-30389 : Rate B, Rate C - 0.0, 0.0 -> 280.9, 280.9
% INFO    : Updated Thermal Rating: on line 30040-30389 : Rate B, Rate C - 0.0, 0.0 -> 304.32, 304.32
% INFO    : Updated Thermal Rating: on transformer 30042-30041 : Rate B, Rate C - 0.0, 0.0 -> 461.74, 461.74
% INFO    : Updated Thermal Rating: on line 30048-30041 : Rate B, Rate C - 0.0, 0.0 -> 1034.67, 1034.67
% INFO    : Updated Thermal Rating: on line 30041-30458 : Rate B, Rate C - 0.0, 0.0 -> 1192.42, 1192.42
% INFO    : Updated Thermal Rating: on line 30042-30044 : Rate B, Rate C - 0.0, 0.0 -> 250.59, 250.59
% INFO    : Updated Thermal Rating: on line 30042-30053 : Rate B, Rate C - 0.0, 0.0 -> 219.11, 219.11
% INFO    : Updated Thermal Rating: on line 30044-30398 : Rate B, Rate C - 0.0, 0.0 -> 255.32, 255.32
% INFO    : Updated Thermal Rating: on transformer 30046-30045 : Rate B, Rate C - 0.0, 0.0 -> 446.13, 446.13
% INFO    : Updated Thermal Rating: on line 30067-30049 : Rate B, Rate C - 0.0, 0.0 -> 259.01, 259.01
% INFO    : Updated Thermal Rating: on line 30275-30051 : Rate B, Rate C - 0.0, 0.0 -> 278.93, 278.93
% INFO    : Updated Thermal Rating: on line 30053-30428 : Rate B, Rate C - 0.0, 0.0 -> 254.8, 254.8
% INFO    : Updated Thermal Rating: on line 30055-30311 : Rate B, Rate C - 0.0, 0.0 -> 247.07, 247.07
% INFO    : Updated Thermal Rating: on line 30055-30459 : Rate B, Rate C - 0.0, 0.0 -> 278.37, 278.37
% INFO    : Updated Thermal Rating: on line 30056-30057 : Rate B, Rate C - 0.0, 0.0 -> 239.99, 239.99
% INFO    : Updated Thermal Rating: on line 30056-30059 : Rate B, Rate C - 0.0, 0.0 -> 262.26, 262.26
% INFO    : Updated Thermal Rating: on line 30056-30426 : Rate B, Rate C - 0.0, 0.0 -> 285.05, 285.05
% INFO    : Updated Thermal Rating: on line 30056-30436 : Rate B, Rate C - 0.0, 0.0 -> 256.49, 256.49
% INFO    : Updated Thermal Rating: on line 30057-30282 : Rate B, Rate C - 0.0, 0.0 -> 259.87, 259.87
% INFO    : Updated Thermal Rating: on line 30063-30059 : Rate B, Rate C - 0.0, 0.0 -> 243.59, 243.59
% INFO    : Updated Thermal Rating: on line 30062-30063 : Rate B, Rate C - 0.0, 0.0 -> 275.91, 275.91
% INFO    : Updated Thermal Rating: on line 30062-30071 : Rate B, Rate C - 0.0, 0.0 -> 279.25, 279.25
% INFO    : Updated Thermal Rating: on line 30428-30062 : Rate B, Rate C - 0.0, 0.0 -> 273.27, 273.27
% INFO    : Updated Thermal Rating: on line 30288-30065 : Rate B, Rate C - 0.0, 0.0 -> 256.38, 256.38
% INFO    : Updated Thermal Rating: on line 30436-30065 : Rate B, Rate C - 0.0, 0.0 -> 250.1, 250.1
% INFO    : Updated Thermal Rating: on line 30066-30072 : Rate B, Rate C - 0.0, 0.0 -> 264.18, 264.18
% INFO    : Updated Thermal Rating: on line 30067-30069 : Rate B, Rate C - 0.0, 0.0 -> 289.83, 289.83
% INFO    : Updated Thermal Rating: on line 30068-30072 : Rate B, Rate C - 0.0, 0.0 -> 244.9, 244.9
% INFO    : Updated Thermal Rating: on line 30068-30459 : Rate B, Rate C - 0.0, 0.0 -> 255.42, 255.42
% INFO    : Updated Thermal Rating: on line 30069-30282 : Rate B, Rate C - 0.0, 0.0 -> 235.47, 235.47
% INFO    : Updated Thermal Rating: on line 30069-30334 : Rate B, Rate C - 0.0, 0.0 -> 266.9, 266.9
% INFO    : Updated Thermal Rating: on line 30069-30459 : Rate B, Rate C - 0.0, 0.0 -> 278.49, 278.49
% INFO    : Updated Thermal Rating: on transformer 30071-30070 : Rate B, Rate C - 0.0, 0.0 -> 427.97, 427.97
% INFO    : Updated Thermal Rating: on line 30271-30070 : Rate B, Rate C - 0.0, 0.0 -> 1168.49, 1168.49
% INFO    : Updated Thermal Rating: on line 30070-30367 : Rate B, Rate C - 0.0, 0.0 -> 1154.09, 1154.09
% INFO    : Updated Thermal Rating: on line 30388-30070 : Rate B, Rate C - 0.0, 0.0 -> 1179.26, 1179.26
% INFO    : Updated Thermal Rating: on line 30073-30072 : Rate B, Rate C - 0.0, 0.0 -> 241.53, 241.53
% INFO    : Updated Thermal Rating: on line 30072-30381 : Rate B, Rate C - 0.0, 0.0 -> 252.36, 252.36
% INFO    : Updated Thermal Rating: on line 30073-30381 : Rate B, Rate C - 0.0, 0.0 -> 249.9, 249.9
% INFO    : Updated Thermal Rating: on transformer 30076-30075 : Rate B, Rate C - 0.0, 0.0 -> 393.4, 393.4
% INFO    : Updated Thermal Rating: on line 30307-30075 : Rate B, Rate C - 0.0, 0.0 -> 1199.66, 1199.66
% INFO    : Updated Thermal Rating: on line 30458-30075 : Rate B, Rate C - 0.0, 0.0 -> 1144.39, 1144.39
% INFO    : Updated Thermal Rating: on line 30278-30076 : Rate B, Rate C - 0.0, 0.0 -> 206.44, 206.44
% INFO    : Updated Thermal Rating: on line 30079-30077 : Rate B, Rate C - 0.0, 0.0 -> 226.72, 226.72
% INFO    : Updated Thermal Rating: on line 30077-30315 : Rate B, Rate C - 0.0, 0.0 -> 262.49, 262.49
% INFO    : Updated Thermal Rating: on line 30309-30078 : Rate B, Rate C - 0.0, 0.0 -> 258.23, 258.23
% INFO    : Updated Thermal Rating: on line 30078-30360 : Rate B, Rate C - 0.0, 0.0 -> 272.45, 272.45
% INFO    : Updated Thermal Rating: on line 30079-30272 : Rate B, Rate C - 0.0, 0.0 -> 232.42, 232.42
% INFO    : Updated Thermal Rating: on line 30315-30080 : Rate B, Rate C - 0.0, 0.0 -> 207.61, 207.61
% INFO    : Updated Thermal Rating: on line 30080-30318 : Rate B, Rate C - 0.0, 0.0 -> 277.02, 277.02
% INFO    : Updated Thermal Rating: on line 30360-30080 : Rate B, Rate C - 0.0, 0.0 -> 263.16, 263.16
% INFO    : Updated Thermal Rating: on line 30082-30087 : Rate B, Rate C - 0.0, 0.0 -> 267.09, 267.09
% INFO    : Updated Thermal Rating: on line 30082-30363 : Rate B, Rate C - 0.0, 0.0 -> 273.48, 273.48
% INFO    : Updated Thermal Rating: on line 30084-30083 : Rate B, Rate C - 0.0, 0.0 -> 218.95, 218.95
% INFO    : Updated Thermal Rating: on line 30083-30091 : Rate B, Rate C - 0.0, 0.0 -> 232.24, 232.24
% INFO    : Updated Thermal Rating: on line 30099-30084 : Rate B, Rate C - 0.0, 0.0 -> 175.35, 175.35
% INFO    : Updated Thermal Rating: on line 30087-30100 : Rate B, Rate C - 0.0, 0.0 -> 262.06, 262.06
% INFO    : Updated Thermal Rating: on line 30088-30092 : Rate B, Rate C - 0.0, 0.0 -> 211.81, 211.81
% INFO    : Updated Thermal Rating: on line 30088-30097 : Rate B, Rate C - 0.0, 0.0 -> 234.82, 234.82
% INFO    : Updated Thermal Rating: on line 30088-30303 : Rate B, Rate C - 0.0, 0.0 -> 199.38, 199.38
% INFO    : Updated Thermal Rating: on transformer 30091-30090 : Rate B, Rate C - 0.0, 0.0 -> 389.29, 389.29
% INFO    : Updated Thermal Rating: on line 30090-30173 : Rate B, Rate C - 0.0, 0.0 -> 1088.44, 1088.44
% INFO    : Updated Thermal Rating: on line 30092-30252 : Rate B, Rate C - 0.0, 0.0 -> 199.86, 199.86
% INFO    : Updated Thermal Rating: on transformer 30094-30093 : Rate B, Rate C - 0.0, 0.0 -> 386.33, 386.33
% INFO    : Updated Thermal Rating: on line 30302-30093 : Rate B, Rate C - 0.0, 0.0 -> 1285.68, 1285.68
% INFO    : Updated Thermal Rating: on line 30093-74223 : Rate B, Rate C - 0.0, 0.0 -> 1340.36, 1340.36
% INFO    : Updated Thermal Rating: on transformer 30095-30094 : Rate B, Rate C - 0.0, 0.0 -> 108.29, 108.29
% INFO    : Updated Thermal Rating: on line 30289-30094 : Rate B, Rate C - 0.0, 0.0 -> 243.05, 243.05
% INFO    : Updated Thermal Rating: on line 30303-30094 : Rate B, Rate C - 0.0, 0.0 -> 276.9, 276.9
% INFO    : Updated Thermal Rating: on line 30290-30095 : Rate B, Rate C - 0.0, 0.0 -> 227.21, 227.21
% INFO    : Updated Thermal Rating: on line 30097-30243 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on line 30100-30099 : Rate B, Rate C - 0.0, 0.0 -> 257.03, 257.03
% INFO    : Updated Thermal Rating: on line 30109-30099 : Rate B, Rate C - 0.0, 0.0 -> 230.88, 230.88
% INFO    : Updated Thermal Rating: on line 30101-30103 : Rate B, Rate C - 0.0, 0.0 -> 280.29, 280.29
% INFO    : Updated Thermal Rating: on line 30116-30101 : Rate B, Rate C - 0.0, 0.0 -> 231.63, 231.63
% INFO    : Updated Thermal Rating: on line 30101-30129 : Rate B, Rate C - 0.0, 0.0 -> 234.19, 234.19
% INFO    : Updated Thermal Rating: on line 30124-30103 : Rate B, Rate C - 0.0, 0.0 -> 305.27, 305.27
% INFO    : Updated Thermal Rating: on line 30104-30137 : Rate B, Rate C - 0.0, 0.0 -> 277.99, 277.99
% INFO    : Updated Thermal Rating: on line 30104-30144 : Rate B, Rate C - 0.0, 0.0 -> 224.49, 224.49
% INFO    : Updated Thermal Rating: on line 30105-30129 : Rate B, Rate C - 0.0, 0.0 -> 290.75, 290.75
% INFO    : Updated Thermal Rating: on line 30105-30153 : Rate B, Rate C - 0.0, 0.0 -> 262.89, 262.89
% INFO    : Updated Thermal Rating: on line 30105-30185 : Rate B, Rate C - 0.0, 0.0 -> 308.31, 308.31
% INFO    : Updated Thermal Rating: on line 30106-30147 : Rate B, Rate C - 0.0, 0.0 -> 242.29, 242.29
% INFO    : Updated Thermal Rating: on line 30106-30186 : Rate B, Rate C - 0.0, 0.0 -> 282.91, 282.91
% INFO    : Updated Thermal Rating: on line 30107-30188 : Rate B, Rate C - 0.0, 0.0 -> 290.93, 290.93
% INFO    : Updated Thermal Rating: on line 30107-30380 : Rate B, Rate C - 0.0, 0.0 -> 315.23, 315.23
% INFO    : Updated Thermal Rating: on line 30108-30110 : Rate B, Rate C - 0.0, 0.0 -> 295.66, 295.66
% INFO    : Updated Thermal Rating: on line 30108-30168 : Rate B, Rate C - 0.0, 0.0 -> 276.59, 276.59
% INFO    : Updated Thermal Rating: on line 30169-30108 : Rate B, Rate C - 0.0, 0.0 -> 279.36, 279.36
% INFO    : Updated Thermal Rating: on line 30137-30109 : Rate B, Rate C - 0.0, 0.0 -> 272.75, 272.75
% INFO    : Updated Thermal Rating: on line 30110-30133 : Rate B, Rate C - 0.0, 0.0 -> 296.29, 296.29
% INFO    : Updated Thermal Rating: on line 30170-30110 : Rate B, Rate C - 0.0, 0.0 -> 265.32, 265.32
% INFO    : Updated Thermal Rating: on transformer 30113-30112 : Rate B, Rate C - 0.0, 0.0 -> 471.72, 471.72
% INFO    : Updated Thermal Rating: on line 30138-30113 : Rate B, Rate C - 0.0, 0.0 -> 252.81, 252.81
% INFO    : Updated Thermal Rating: on line 30113-30140 : Rate B, Rate C - 0.0, 0.0 -> 288.95, 288.95
% INFO    : Updated Thermal Rating: on line 30173-30114 : Rate B, Rate C - 0.0, 0.0 -> 1027.62, 1027.62
% INFO    : Updated Thermal Rating: on line 30114-30433 : Rate B, Rate C - 0.0, 0.0 -> 1161.11, 1161.11
% INFO    : Updated Thermal Rating: on line 30133-30116 : Rate B, Rate C - 0.0, 0.0 -> 258.15, 258.15
% INFO    : Updated Thermal Rating: on line 30140-30116 : Rate B, Rate C - 0.0, 0.0 -> 250.16, 250.16
% INFO    : Updated Thermal Rating: on transformer 30118-30117 : Rate B, Rate C - 0.0, 0.0 -> 108.45, 108.45
% INFO    : Updated Thermal Rating: on line 30117-30158 : Rate B, Rate C - 0.0, 0.0 -> 247.27, 247.27
% INFO    : Updated Thermal Rating: on line 30117-30434 : Rate B, Rate C - 0.0, 0.0 -> 264.77, 264.77
% INFO    : Updated Thermal Rating: on line 30124-30122 : Rate B, Rate C - 0.0, 0.0 -> 267.39, 267.39
% INFO    : Updated Thermal Rating: on line 30122-30136 : Rate B, Rate C - 0.0, 0.0 -> 234.55, 234.55
% INFO    : Updated Thermal Rating: on transformer 30124-30123 : Rate B, Rate C - 0.0, 0.0 -> 517.18, 517.18
% INFO    : Updated Thermal Rating: on line 30125-30416 : Rate B, Rate C - 0.0, 0.0 -> 1119.94, 1119.94
% INFO    : Updated Thermal Rating: on line 30126-30127 : Rate B, Rate C - 0.0, 0.0 -> 291.86, 291.86
% INFO    : Updated Thermal Rating: on line 30174-30126 : Rate B, Rate C - 0.0, 0.0 -> 220.75, 220.75
% INFO    : Updated Thermal Rating: on line 30197-30127 : Rate B, Rate C - 0.0, 0.0 -> 326.17, 326.17
% INFO    : Updated Thermal Rating: on line 30136-30130 : Rate B, Rate C - 0.0, 0.0 -> 276.24, 276.24
% INFO    : Updated Thermal Rating: on line 30130-30160 : Rate B, Rate C - 0.0, 0.0 -> 265.33, 265.33
% INFO    : Updated Thermal Rating: on line 30130-30197 : Rate B, Rate C - 0.0, 0.0 -> 290.15, 290.15
% INFO    : Updated Thermal Rating: on line 30132-30174 : Rate B, Rate C - 0.0, 0.0 -> 239.76, 239.76
% INFO    : Updated Thermal Rating: on line 30132-30189 : Rate B, Rate C - 0.0, 0.0 -> 280.01, 280.01
% INFO    : Updated Thermal Rating: on line 30137-30172 : Rate B, Rate C - 0.0, 0.0 -> 332.26, 332.26
% INFO    : Updated Thermal Rating: on line 30138-30155 : Rate B, Rate C - 0.0, 0.0 -> 251.78, 251.78
% INFO    : Updated Thermal Rating: on line 30139-30200 : Rate B, Rate C - 0.0, 0.0 -> 245.0, 245.0
% INFO    : Updated Thermal Rating: on line 30430-30139 : Rate B, Rate C - 0.0, 0.0 -> 284.46, 284.46
% INFO    : Updated Thermal Rating: on line 30142-30145 : Rate B, Rate C - 0.0, 0.0 -> 251.91, 251.91
% INFO    : Updated Thermal Rating: on line 30430-30142 : Rate B, Rate C - 0.0, 0.0 -> 298.66, 298.66
% INFO    : Updated Thermal Rating: on line 30144-30174 : Rate B, Rate C - 0.0, 0.0 -> 298.05, 298.05
% INFO    : Updated Thermal Rating: on line 30145-30152 : Rate B, Rate C - 0.0, 0.0 -> 275.93, 275.93
% INFO    : Updated Thermal Rating: on line 30188-30145 : Rate B, Rate C - 0.0, 0.0 -> 242.33, 242.33
% INFO    : Updated Thermal Rating: on line 30147-30158 : Rate B, Rate C - 0.0, 0.0 -> 260.26, 260.26
% INFO    : Updated Thermal Rating: on line 30148-30164 : Rate B, Rate C - 0.0, 0.0 -> 247.45, 247.45
% INFO    : Updated Thermal Rating: on line 30148-30213 : Rate B, Rate C - 0.0, 0.0 -> 264.03, 264.03
% INFO    : Updated Thermal Rating: on line 30178-30152 : Rate B, Rate C - 0.0, 0.0 -> 310.6, 310.6
% INFO    : Updated Thermal Rating: on line 30156-30153 : Rate B, Rate C - 0.0, 0.0 -> 294.08, 294.08
% INFO    : Updated Thermal Rating: on line 30154-30160 : Rate B, Rate C - 0.0, 0.0 -> 257.63, 257.63
% INFO    : Updated Thermal Rating: on line 30154-30209 : Rate B, Rate C - 0.0, 0.0 -> 293.15, 293.15
% INFO    : Updated Thermal Rating: on line 30154-30286 : Rate B, Rate C - 0.0, 0.0 -> 218.47, 218.47
% INFO    : Updated Thermal Rating: on line 30155-30172 : Rate B, Rate C - 0.0, 0.0 -> 291.32, 291.32
% INFO    : Updated Thermal Rating: on line 30197-30156 : Rate B, Rate C - 0.0, 0.0 -> 316.35, 316.35
% INFO    : Updated Thermal Rating: on transformer 30159-30158 : Rate B, Rate C - 0.0, 0.0 -> 104.73, 104.73
% INFO    : Updated Thermal Rating: on line 30161-30159 : Rate B, Rate C - 0.0, 0.0 -> 219.0, 219.0
% INFO    : Updated Thermal Rating: on line 30159-30327 : Rate B, Rate C - 0.0, 0.0 -> 199.21, 199.21
% INFO    : Updated Thermal Rating: on transformer 30160-30163 : Rate B, Rate C - 0.0, 0.0 -> 173.27, 173.27
% INFO    : Updated Thermal Rating: on transformer 30161-30163 : Rate B, Rate C - 0.0, 0.0 -> 98.27, 98.27
% INFO    : Updated Thermal Rating: on line 30180-30161 : Rate B, Rate C - 0.0, 0.0 -> 203.38, 203.38
% INFO    : Updated Thermal Rating: on transformer 30162-30163 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 30164-30166 : Rate B, Rate C - 0.0, 0.0 -> 290.25, 290.25
% INFO    : Updated Thermal Rating: on line 30185-30166 : Rate B, Rate C - 0.0, 0.0 -> 263.85, 263.85
% INFO    : Updated Thermal Rating: on line 30166-30232 : Rate B, Rate C - 0.0, 0.0 -> 306.53, 306.53
% INFO    : Updated Thermal Rating: on line 30166-30401 : Rate B, Rate C - 0.0, 0.0 -> 283.73, 283.73
% INFO    : Updated Thermal Rating: on line 30215-30167 : Rate B, Rate C - 0.0, 0.0 -> 265.53, 265.53
% INFO    : Updated Thermal Rating: on line 30167-30450 : Rate B, Rate C - 0.0, 0.0 -> 295.91, 295.91
% INFO    : Updated Thermal Rating: on line 30172-30168 : Rate B, Rate C - 0.0, 0.0 -> 310.14, 310.14
% INFO    : Updated Thermal Rating: on line 30170-30169 : Rate B, Rate C - 0.0, 0.0 -> 306.4, 306.4
% INFO    : Updated Thermal Rating: on line 30169-30172 : Rate B, Rate C - 0.0, 0.0 -> 309.13, 309.13
% INFO    : Updated Thermal Rating: on line 30169-30427 : Rate B, Rate C - 0.0, 0.0 -> 464.69, 464.69
% INFO    : Updated Thermal Rating: on transformer 30172-30171 : Rate B, Rate C - 0.0, 0.0 -> 599.02, 599.02
% INFO    : Updated Thermal Rating: on transformer 30172-30171 : Rate B, Rate C - 0.0, 0.0 -> 599.02, 599.02
% INFO    : Updated Thermal Rating: on transformer 30172-30171 : Rate B, Rate C - 0.0, 0.0 -> 599.02, 599.02
% INFO    : Updated Thermal Rating: on line 30171-30378 : Rate B, Rate C - 0.0, 0.0 -> 1244.21, 1244.21
% INFO    : Updated Thermal Rating: on line 30444-30171 : Rate B, Rate C - 0.0, 0.0 -> 1269.95, 1269.95
% INFO    : Updated Thermal Rating: on transformer 30174-30173 : Rate B, Rate C - 0.0, 0.0 -> 460.36, 460.36
% INFO    : Updated Thermal Rating: on line 30173-30416 : Rate B, Rate C - 0.0, 0.0 -> 1225.7, 1225.7
% INFO    : Updated Thermal Rating: on line 30177-30175 : Rate B, Rate C - 0.0, 0.0 -> 284.48, 284.48
% INFO    : Updated Thermal Rating: on line 30175-30186 : Rate B, Rate C - 0.0, 0.0 -> 268.71, 268.71
% INFO    : Updated Thermal Rating: on line 30177-30197 : Rate B, Rate C - 0.0, 0.0 -> 308.4, 308.4
% INFO    : Updated Thermal Rating: on line 30191-30178 : Rate B, Rate C - 0.0, 0.0 -> 317.3, 317.3
% INFO    : Updated Thermal Rating: on line 30178-30430 : Rate B, Rate C - 0.0, 0.0 -> 286.94, 286.94
% INFO    : Updated Thermal Rating: on transformer 30180-30179 : Rate B, Rate C - 0.0, 0.0 -> 94.75, 94.75
% INFO    : Updated Thermal Rating: on line 30179-30209 : Rate B, Rate C - 0.0, 0.0 -> 220.88, 220.88
% INFO    : Updated Thermal Rating: on line 30181-30206 : Rate B, Rate C - 0.0, 0.0 -> 237.41, 237.41
% INFO    : Updated Thermal Rating: on line 30181-30215 : Rate B, Rate C - 0.0, 0.0 -> 232.55, 232.55
% INFO    : Updated Thermal Rating: on line 30181-30339 : Rate B, Rate C - 0.0, 0.0 -> 267.11, 267.11
% INFO    : Updated Thermal Rating: on line 30183-30203 : Rate B, Rate C - 0.0, 0.0 -> 243.49, 243.49
% INFO    : Updated Thermal Rating: on line 30183-30237 : Rate B, Rate C - 0.0, 0.0 -> 246.38, 246.38
% INFO    : Updated Thermal Rating: on line 30183-30277 : Rate B, Rate C - 0.0, 0.0 -> 288.0, 288.0
% INFO    : Updated Thermal Rating: on line 30203-30184 : Rate B, Rate C - 0.0, 0.0 -> 249.67, 249.67
% INFO    : Updated Thermal Rating: on line 30238-30184 : Rate B, Rate C - 0.0, 0.0 -> 272.72, 272.72
% INFO    : Updated Thermal Rating: on line 30185-30380 : Rate B, Rate C - 0.0, 0.0 -> 314.31, 314.31
% INFO    : Updated Thermal Rating: on line 30186-30230 : Rate B, Rate C - 0.0, 0.0 -> 297.72, 297.72
% INFO    : Updated Thermal Rating: on line 30226-30189 : Rate B, Rate C - 0.0, 0.0 -> 200.41, 200.41
% INFO    : Updated Thermal Rating: on line 30189-30425 : Rate B, Rate C - 0.0, 0.0 -> 318.97, 318.97
% INFO    : Updated Thermal Rating: on line 30190-30236 : Rate B, Rate C - 0.0, 0.0 -> 254.87, 254.87
% INFO    : Updated Thermal Rating: on line 30190-30380 : Rate B, Rate C - 0.0, 0.0 -> 263.82, 263.82
% INFO    : Updated Thermal Rating: on line 30191-30296 : Rate B, Rate C - 0.0, 0.0 -> 391.54, 391.54
% INFO    : Updated Thermal Rating: on line 30234-30192 : Rate B, Rate C - 0.0, 0.0 -> 257.2, 257.2
% INFO    : Updated Thermal Rating: on line 30192-30380 : Rate B, Rate C - 0.0, 0.0 -> 304.86, 304.86
% INFO    : Updated Thermal Rating: on line 30195-30216 : Rate B, Rate C - 0.0, 0.0 -> 244.49, 244.49
% INFO    : Updated Thermal Rating: on line 30195-30222 : Rate B, Rate C - 0.0, 0.0 -> 255.83, 255.83
% INFO    : Updated Thermal Rating: on transformer 30197-30196 : Rate B, Rate C - 0.0, 0.0 -> 593.49, 593.49
% INFO    : Updated Thermal Rating: on transformer 30197-30196 : Rate B, Rate C - 0.0, 0.0 -> 593.49, 593.49
% INFO    : Updated Thermal Rating: on transformer 30197-30196 : Rate B, Rate C - 0.0, 0.0 -> 593.49, 593.49
% INFO    : Updated Thermal Rating: on line 30379-30196 : Rate B, Rate C - 0.0, 0.0 -> 1169.72, 1169.72
% INFO    : Updated Thermal Rating: on line 30196-30416 : Rate B, Rate C - 0.0, 0.0 -> 1324.12, 1324.12
% INFO    : Updated Thermal Rating: on line 30204-30199 : Rate B, Rate C - 0.0, 0.0 -> 277.27, 277.27
% INFO    : Updated Thermal Rating: on line 30199-30221 : Rate B, Rate C - 0.0, 0.0 -> 301.99, 301.99
% INFO    : Updated Thermal Rating: on line 30199-30333 : Rate B, Rate C - 0.0, 0.0 -> 360.0, 360.0
% INFO    : Updated Thermal Rating: on line 30202-30200 : Rate B, Rate C - 0.0, 0.0 -> 243.2, 243.2
% INFO    : Updated Thermal Rating: on line 30202-30224 : Rate B, Rate C - 0.0, 0.0 -> 278.13, 278.13
% INFO    : Updated Thermal Rating: on line 30203-30244 : Rate B, Rate C - 0.0, 0.0 -> 288.19, 288.19
% INFO    : Updated Thermal Rating: on line 30204-30232 : Rate B, Rate C - 0.0, 0.0 -> 254.84, 254.84
% INFO    : Updated Thermal Rating: on line 30216-30206 : Rate B, Rate C - 0.0, 0.0 -> 243.09, 243.09
% INFO    : Updated Thermal Rating: on line 30206-30401 : Rate B, Rate C - 0.0, 0.0 -> 295.51, 295.51
% INFO    : Updated Thermal Rating: on transformer 30209-30208 : Rate B, Rate C - 0.0, 0.0 -> 455.17, 455.17
% INFO    : Updated Thermal Rating: on line 30324-30208 : Rate B, Rate C - 0.0, 0.0 -> 1161.72, 1161.72
% INFO    : Updated Thermal Rating: on line 30208-30355 : Rate B, Rate C - 0.0, 0.0 -> 950.25, 950.25
% INFO    : Updated Thermal Rating: on line 30209-30215 : Rate B, Rate C - 0.0, 0.0 -> 234.82, 234.82
% INFO    : Updated Thermal Rating: on line 30210-30352 : Rate B, Rate C - 0.0, 0.0 -> 256.99, 256.99
% INFO    : Updated Thermal Rating: on line 30210-30368 : Rate B, Rate C - 0.0, 0.0 -> 253.54, 253.54
% INFO    : Updated Thermal Rating: on line 30213-30234 : Rate B, Rate C - 0.0, 0.0 -> 302.34, 302.34
% INFO    : Updated Thermal Rating: on line 30219-30214 : Rate B, Rate C - 0.0, 0.0 -> 280.74, 280.74
% INFO    : Updated Thermal Rating: on line 30214-30236 : Rate B, Rate C - 0.0, 0.0 -> 242.62, 242.62
% INFO    : Updated Thermal Rating: on line 30216-30223 : Rate B, Rate C - 0.0, 0.0 -> 247.34, 247.34
% INFO    : Updated Thermal Rating: on line 30216-30323 : Rate B, Rate C - 0.0, 0.0 -> 291.17, 291.17
% INFO    : Updated Thermal Rating: on transformer 30219-30218 : Rate B, Rate C - 0.0, 0.0 -> 431.35, 431.35
% INFO    : Updated Thermal Rating: on line 30324-30218 : Rate B, Rate C - 0.0, 0.0 -> 1210.87, 1210.87
% INFO    : Updated Thermal Rating: on line 30219-30232 : Rate B, Rate C - 0.0, 0.0 -> 270.54, 270.54
% INFO    : Updated Thermal Rating: on line 30224-30221 : Rate B, Rate C - 0.0, 0.0 -> 303.95, 303.95
% INFO    : Updated Thermal Rating: on line 30221-30425 : Rate B, Rate C - 0.0, 0.0 -> 306.58, 306.58
% INFO    : Updated Thermal Rating: on line 30323-30222 : Rate B, Rate C - 0.0, 0.0 -> 288.46, 288.46
% INFO    : Updated Thermal Rating: on line 30223-30352 : Rate B, Rate C - 0.0, 0.0 -> 280.41, 280.41
% INFO    : Updated Thermal Rating: on line 30226-30224 : Rate B, Rate C - 0.0, 0.0 -> 295.38, 295.38
% INFO    : Updated Thermal Rating: on line 30224-30242 : Rate B, Rate C - 0.0, 0.0 -> 311.68, 311.68
% INFO    : Updated Thermal Rating: on line 30231-30229 : Rate B, Rate C - 0.0, 0.0 -> 263.63, 263.63
% INFO    : Updated Thermal Rating: on line 30229-30232 : Rate B, Rate C - 0.0, 0.0 -> 244.49, 244.49
% INFO    : Updated Thermal Rating: on line 30229-30256 : Rate B, Rate C - 0.0, 0.0 -> 313.3, 313.3
% INFO    : Updated Thermal Rating: on line 30230-30380 : Rate B, Rate C - 0.0, 0.0 -> 327.68, 327.68
% INFO    : Updated Thermal Rating: on line 30231-30239 : Rate B, Rate C - 0.0, 0.0 -> 215.7, 215.7
% INFO    : Updated Thermal Rating: on line 30232-30348 : Rate B, Rate C - 0.0, 0.0 -> 307.7, 307.7
% INFO    : Updated Thermal Rating: on line 30244-30233 : Rate B, Rate C - 0.0, 0.0 -> 247.08, 247.08
% INFO    : Updated Thermal Rating: on line 30233-30450 : Rate B, Rate C - 0.0, 0.0 -> 280.08, 280.08
% INFO    : Updated Thermal Rating: on line 30401-30234 : Rate B, Rate C - 0.0, 0.0 -> 304.34, 304.34
% INFO    : Updated Thermal Rating: on line 30236-30380 : Rate B, Rate C - 0.0, 0.0 -> 286.34, 286.34
% INFO    : Updated Thermal Rating: on line 30352-30237 : Rate B, Rate C - 0.0, 0.0 -> 282.67, 282.67
% INFO    : Updated Thermal Rating: on line 30238-30240 : Rate B, Rate C - 0.0, 0.0 -> 243.66, 243.66
% INFO    : Updated Thermal Rating: on line 30238-30323 : Rate B, Rate C - 0.0, 0.0 -> 290.65, 290.65
% INFO    : Updated Thermal Rating: on line 30323-30239 : Rate B, Rate C - 0.0, 0.0 -> 277.72, 277.72
% INFO    : Updated Thermal Rating: on transformer 30241-30240 : Rate B, Rate C - 0.0, 0.0 -> 106.73, 106.73
% INFO    : Updated Thermal Rating: on line 30241-30245 : Rate B, Rate C - 0.0, 0.0 -> 186.93, 186.93
% INFO    : Updated Thermal Rating: on line 40021-30241 : Rate B, Rate C - 0.0, 0.0 -> 138.12, 138.12
% INFO    : Updated Thermal Rating: on line 30242-30267 : Rate B, Rate C - 0.0, 0.0 -> 312.91, 312.91
% INFO    : Updated Thermal Rating: on line 30248-30243 : Rate B, Rate C - 0.0, 0.0 -> 271.78, 271.78
% INFO    : Updated Thermal Rating: on line 30243-30265 : Rate B, Rate C - 0.0, 0.0 -> 219.46, 219.46
% INFO    : Updated Thermal Rating: on transformer 30244-30247 : Rate B, Rate C - 0.0, 0.0 -> 243.59, 243.59
% INFO    : Updated Thermal Rating: on transformer 30245-30247 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 40981-30245 : Rate B, Rate C - 0.0, 0.0 -> 201.46, 201.46
% INFO    : Updated Thermal Rating: on line 40981-30245 : Rate B, Rate C - 0.0, 0.0 -> 201.46, 201.46
% INFO    : Updated Thermal Rating: on line 40981-30245 : Rate B, Rate C - 0.0, 0.0 -> 201.46, 201.46
% INFO    : Updated Thermal Rating: on transformer 30246-30247 : Rate B, Rate C - 0.0, 0.0 -> 133.75, 133.75
% INFO    : Updated Thermal Rating: on transformer 30248-30251 : Rate B, Rate C - 0.0, 0.0 -> 239.52, 239.52
% INFO    : Updated Thermal Rating: on transformer 30249-30251 : Rate B, Rate C - 0.0, 0.0 -> 114.52, 114.52
% INFO    : Updated Thermal Rating: on line 30249-74261 : Rate B, Rate C - 0.0, 0.0 -> 223.88, 223.88
% INFO    : Updated Thermal Rating: on line 30249-74307 : Rate B, Rate C - 0.0, 0.0 -> 212.88, 212.88
% INFO    : Updated Thermal Rating: on line 30249-74336 : Rate B, Rate C - 0.0, 0.0 -> 171.73, 171.73
% INFO    : Updated Thermal Rating: on transformer 30250-30251 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 30383-30252 : Rate B, Rate C - 0.0, 0.0 -> 250.79, 250.79
% INFO    : Updated Thermal Rating: on transformer 30254-30253 : Rate B, Rate C - 0.0, 0.0 -> 102.77, 102.77
% INFO    : Updated Thermal Rating: on line 30286-30253 : Rate B, Rate C - 0.0, 0.0 -> 229.93, 229.93
% INFO    : Updated Thermal Rating: on line 30254-40009 : Rate B, Rate C - 0.0, 0.0 -> 134.4, 134.4
% INFO    : Updated Thermal Rating: on line 40014-30254 : Rate B, Rate C - 0.0, 0.0 -> 124.25, 124.25
% INFO    : Updated Thermal Rating: on line 40731-30254 : Rate B, Rate C - 0.0, 0.0 -> 128.96, 128.96
% INFO    : Updated Thermal Rating: on line 30256-30259 : Rate B, Rate C - 0.0, 0.0 -> 320.46, 320.46
% INFO    : Updated Thermal Rating: on line 30263-30259 : Rate B, Rate C - 0.0, 0.0 -> 305.68, 305.68
% INFO    : Updated Thermal Rating: on line 50001-30259 : Rate B, Rate C - 0.0, 0.0 -> 265.19, 265.19
% INFO    : Updated Thermal Rating: on line 30261-30263 : Rate B, Rate C - 0.0, 0.0 -> 265.8, 265.8
% INFO    : Updated Thermal Rating: on line 30261-50422 : Rate B, Rate C - 0.0, 0.0 -> 275.07, 275.07
% INFO    : Updated Thermal Rating: on line 30262-30333 : Rate B, Rate C - 0.0, 0.0 -> 304.04, 304.04
% INFO    : Updated Thermal Rating: on line 30346-30262 : Rate B, Rate C - 0.0, 0.0 -> 309.9, 309.9
% INFO    : Updated Thermal Rating: on line 50000-30263 : Rate B, Rate C - 0.0, 0.0 -> 279.47, 279.47
% INFO    : Updated Thermal Rating: on line 30264-50006 : Rate B, Rate C - 0.0, 0.0 -> 277.0, 277.0
% INFO    : Updated Thermal Rating: on line 50002-30267 : Rate B, Rate C - 0.0, 0.0 -> 323.15, 323.15
% INFO    : Updated Thermal Rating: on line 30267-50014 : Rate B, Rate C - 0.0, 0.0 -> 275.01, 275.01
% INFO    : Updated Thermal Rating: on transformer 30268-30269 : Rate B, Rate C - 0.0, 0.0 -> 132.77, 132.77
% INFO    : Updated Thermal Rating: on line 30270-30311 : Rate B, Rate C - 0.0, 0.0 -> 251.81, 251.81
% INFO    : Updated Thermal Rating: on line 30270-30428 : Rate B, Rate C - 0.0, 0.0 -> 243.87, 243.87
% INFO    : Updated Thermal Rating: on line 30270-30445 : Rate B, Rate C - 0.0, 0.0 -> 221.74, 221.74
% INFO    : Updated Thermal Rating: on transformer 30272-30271 : Rate B, Rate C - 0.0, 0.0 -> 264.77, 264.77
% INFO    : Updated Thermal Rating: on line 30314-30271 : Rate B, Rate C - 0.0, 0.0 -> 1160.89, 1160.89
% INFO    : Updated Thermal Rating: on transformer 30273-30274 : Rate B, Rate C - 0.0, 0.0 -> 71.44, 71.44
% INFO    : Updated Thermal Rating: on line 30398-30275 : Rate B, Rate C - 0.0, 0.0 -> 273.26, 273.26
% INFO    : Updated Thermal Rating: on line 30277-30339 : Rate B, Rate C - 0.0, 0.0 -> 280.23, 280.23
% INFO    : Updated Thermal Rating: on transformer 30278-30279 : Rate B, Rate C - 0.0, 0.0 -> 60.48, 60.48
% INFO    : Updated Thermal Rating: on transformer 30278-30280 : Rate B, Rate C - 0.0, 0.0 -> 24.08, 24.08
% INFO    : Updated Thermal Rating: on line 30278-30308 : Rate B, Rate C - 0.0, 0.0 -> 267.82, 267.82
% INFO    : Updated Thermal Rating: on line 30278-30381 : Rate B, Rate C - 0.0, 0.0 -> 276.9, 276.9
% INFO    : Updated Thermal Rating: on line 30428-30282 : Rate B, Rate C - 0.0, 0.0 -> 237.43, 237.43
% INFO    : Updated Thermal Rating: on transformer 30285-30284 : Rate B, Rate C - 0.0, 0.0 -> 85.79, 85.79
% INFO    : Updated Thermal Rating: on line 30288-30309 : Rate B, Rate C - 0.0, 0.0 -> 275.25, 275.25
% INFO    : Updated Thermal Rating: on line 30288-30426 : Rate B, Rate C - 0.0, 0.0 -> 265.92, 265.92
% INFO    : Updated Thermal Rating: on transformer 30290-30289 : Rate B, Rate C - 0.0, 0.0 -> 70.41, 70.41
% INFO    : Updated Thermal Rating: on transformer 30289-30291 : Rate B, Rate C - 0.0, 0.0 -> 95.66, 95.66
% INFO    : Updated Thermal Rating: on line 30290-74104 : Rate B, Rate C - 0.0, 0.0 -> 226.8, 226.8
% INFO    : Updated Thermal Rating: on transformer 30293-30292 : Rate B, Rate C - 0.0, 0.0 -> 109.39, 109.39
% INFO    : Updated Thermal Rating: on line 40981-30293 : Rate B, Rate C - 0.0, 0.0 -> 135.82, 135.82
% INFO    : Updated Thermal Rating: on line 30294-30348 : Rate B, Rate C - 0.0, 0.0 -> 260.11, 260.11
% INFO    : Updated Thermal Rating: on transformer 30296-30295 : Rate B, Rate C - 0.0, 0.0 -> 452.45, 452.45
% INFO    : Updated Thermal Rating: on transformer 30295-30297 : Rate B, Rate C - 0.0, 0.0 -> 516.33, 516.33
% INFO    : Updated Thermal Rating: on transformer 30295-30298 : Rate B, Rate C - 0.0, 0.0 -> 516.12, 516.12
% INFO    : Updated Thermal Rating: on transformer 30295-30299 : Rate B, Rate C - 0.0, 0.0 -> 515.8, 515.8
% INFO    : Updated Thermal Rating: on transformer 30295-30300 : Rate B, Rate C - 0.0, 0.0 -> 410.17, 410.17
% INFO    : Updated Thermal Rating: on transformer 30295-30301 : Rate B, Rate C - 0.0, 0.0 -> 409.89, 409.89
% INFO    : Updated Thermal Rating: on line 30444-30295 : Rate B, Rate C - 0.0, 0.0 -> 1038.57, 1038.57
% INFO    : Updated Thermal Rating: on transformer 30302-30305 : Rate B, Rate C - 0.0, 0.0 -> 327.48, 327.48
% INFO    : Updated Thermal Rating: on transformer 30302-30306 : Rate B, Rate C - 0.0, 0.0 -> 570.57, 570.57
% INFO    : Updated Thermal Rating: on line 30302-30307 : Rate B, Rate C - 0.0, 0.0 -> 1197.35, 1197.35
% INFO    : Updated Thermal Rating: on line 30314-30302 : Rate B, Rate C - 0.0, 0.0 -> 1175.0, 1175.0
% INFO    : Updated Thermal Rating: on transformer 30303-30305 : Rate B, Rate C - 0.0, 0.0 -> 277.48, 277.48
% INFO    : Updated Thermal Rating: on line 30318-30303 : Rate B, Rate C - 0.0, 0.0 -> 270.59, 270.59
% INFO    : Updated Thermal Rating: on transformer 30304-30305 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 30308-30307 : Rate B, Rate C - 0.0, 0.0 -> 370.0, 370.0
% INFO    : Updated Thermal Rating: on line 30309-30334 : Rate B, Rate C - 0.0, 0.0 -> 212.55, 212.55
% INFO    : Updated Thermal Rating: on line 30311-30398 : Rate B, Rate C - 0.0, 0.0 -> 281.55, 281.55
% INFO    : Updated Thermal Rating: on line 30311-30445 : Rate B, Rate C - 0.0, 0.0 -> 249.95, 249.95
% INFO    : Updated Thermal Rating: on transformer 30314-30313 : Rate B, Rate C - 0.0, 0.0 -> 1080.78, 1080.78
% INFO    : Updated Thermal Rating: on transformer 30313-30316 : Rate B, Rate C - 0.0, 0.0 -> 1641.37, 1641.37
% INFO    : Updated Thermal Rating: on transformer 30313-30317 : Rate B, Rate C - 0.0, 0.0 -> 1640.35, 1640.35
% INFO    : Updated Thermal Rating: on line 30387-30313 : Rate B, Rate C - 0.0, 0.0 -> 4016.08, 4016.08
% INFO    : Updated Thermal Rating: on transformer 30315-30314 : Rate B, Rate C - 0.0, 0.0 -> 346.96, 346.96
% INFO    : Updated Thermal Rating: on transformer 30318-30321 : Rate B, Rate C - 0.0, 0.0 -> 289.78, 289.78
% INFO    : Updated Thermal Rating: on transformer 30319-30321 : Rate B, Rate C - 0.0, 0.0 -> 144.89, 144.89
% INFO    : Updated Thermal Rating: on transformer 30320-30321 : Rate B, Rate C - 0.0, 0.0 -> 144.89, 144.89
% INFO    : Updated Thermal Rating: on transformer 30323-30322 : Rate B, Rate C - 0.0, 0.0 -> 487.5, 487.5
% INFO    : Updated Thermal Rating: on line 30416-30324 : Rate B, Rate C - 0.0, 0.0 -> 1251.16, 1251.16
% INFO    : Updated Thermal Rating: on line 30324-30457 : Rate B, Rate C - 0.0, 0.0 -> 1269.04, 1269.04
% INFO    : Updated Thermal Rating: on transformer 30326-30329 : Rate B, Rate C - 0.0, 0.0 -> 145.49, 145.49
% INFO    : Updated Thermal Rating: on transformer 30327-30329 : Rate B, Rate C - 0.0, 0.0 -> 95.49, 95.49
% INFO    : Updated Thermal Rating: on transformer 30328-30329 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 30339-30330 : Rate B, Rate C - 0.0, 0.0 -> 243.99, 243.99
% INFO    : Updated Thermal Rating: on line 30333-30371 : Rate B, Rate C - 0.0, 0.0 -> 296.14, 296.14
% INFO    : Updated Thermal Rating: on transformer 30334-30335 : Rate B, Rate C - 0.0, 0.0 -> 138.38, 138.38
% INFO    : Updated Thermal Rating: on transformer 30334-30336 : Rate B, Rate C - 0.0, 0.0 -> 91.06, 91.06
% INFO    : Updated Thermal Rating: on transformer 30334-30337 : Rate B, Rate C - 0.0, 0.0 -> 15.34, 15.34
% INFO    : Updated Thermal Rating: on transformer 30338-30341 : Rate B, Rate C - 0.0, 0.0 -> 529.32, 529.32
% INFO    : Updated Thermal Rating: on transformer 30338-30342 : Rate B, Rate C - 0.0, 0.0 -> 514.4, 514.4
% INFO    : Updated Thermal Rating: on transformer 30338-30343 : Rate B, Rate C - 0.0, 0.0 -> 514.32, 514.32
% INFO    : Updated Thermal Rating: on transformer 30338-30344 : Rate B, Rate C - 0.0, 0.0 -> 513.31, 513.31
% INFO    : Updated Thermal Rating: on line 30338-30355 : Rate B, Rate C - 0.0, 0.0 -> 1098.84, 1098.84
% INFO    : Updated Thermal Rating: on transformer 30339-30341 : Rate B, Rate C - 0.0, 0.0 -> 429.32, 429.32
% INFO    : Updated Thermal Rating: on line 30368-30339 : Rate B, Rate C - 0.0, 0.0 -> 254.14, 254.14
% INFO    : Updated Thermal Rating: on line 30339-30434 : Rate B, Rate C - 0.0, 0.0 -> 221.58, 221.58
% INFO    : Updated Thermal Rating: on transformer 30340-30341 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 30346-30345 : Rate B, Rate C - 0.0, 0.0 -> 388.92, 388.92
% INFO    : Updated Thermal Rating: on transformer 30345-30347 : Rate B, Rate C - 0.0, 0.0 -> 588.4, 588.4
% INFO    : Updated Thermal Rating: on line 30345-30424 : Rate B, Rate C - 0.0, 0.0 -> 1202.56, 1202.56
% INFO    : Updated Thermal Rating: on transformer 30348-30349 : Rate B, Rate C - 0.0, 0.0 -> 190.68, 190.68
% INFO    : Updated Thermal Rating: on transformer 30348-30350 : Rate B, Rate C - 0.0, 0.0 -> 170.68, 170.68
% INFO    : Updated Thermal Rating: on transformer 30351-30354 : Rate B, Rate C - 0.0, 0.0 -> 538.9, 538.9
% INFO    : Updated Thermal Rating: on transformer 30352-30354 : Rate B, Rate C - 0.0, 0.0 -> 413.9, 413.9
% INFO    : Updated Thermal Rating: on line 30434-30352 : Rate B, Rate C - 0.0, 0.0 -> 234.73, 234.73
% INFO    : Updated Thermal Rating: on transformer 30353-30354 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 30356-30359 : Rate B, Rate C - 0.0, 0.0 -> 330.14, 330.14
% INFO    : Updated Thermal Rating: on transformer 30357-30359 : Rate B, Rate C - 0.0, 0.0 -> 165.07, 165.07
% INFO    : Updated Thermal Rating: on transformer 30358-30359 : Rate B, Rate C - 0.0, 0.0 -> 165.07, 165.07
% INFO    : Updated Thermal Rating: on transformer 30363-30362 : Rate B, Rate C - 0.0, 0.0 -> 374.16, 374.16
% INFO    : Updated Thermal Rating: on transformer 30362-30366 : Rate B, Rate C - 0.0, 0.0 -> 787.67, 787.67
% INFO    : Updated Thermal Rating: on transformer 30364-30366 : Rate B, Rate C - 0.0, 0.0 -> 393.84, 393.84
% INFO    : Updated Thermal Rating: on transformer 30365-30366 : Rate B, Rate C - 0.0, 0.0 -> 393.84, 393.84
% INFO    : Updated Thermal Rating: on line 30367-30382 : Rate B, Rate C - 0.0, 0.0 -> 1177.37, 1177.37
% INFO    : Updated Thermal Rating: on transformer 30370-30369 : Rate B, Rate C - 0.0, 0.0 -> 1514.04, 1514.04
% INFO    : Updated Thermal Rating: on transformer 30369-30372 : Rate B, Rate C - 0.0, 0.0 -> 1601.71, 1601.71
% INFO    : Updated Thermal Rating: on transformer 30369-30373 : Rate B, Rate C - 0.0, 0.0 -> 1598.29, 1598.29
% INFO    : Updated Thermal Rating: on transformer 30369-30374 : Rate B, Rate C - 0.0, 0.0 -> 1595.71, 1595.71
% INFO    : Updated Thermal Rating: on transformer 30369-30375 : Rate B, Rate C - 0.0, 0.0 -> 1592.69, 1592.69
% INFO    : Updated Thermal Rating: on transformer 30369-30376 : Rate B, Rate C - 0.0, 0.0 -> 1591.17, 1591.17
% INFO    : Updated Thermal Rating: on transformer 30369-30377 : Rate B, Rate C - 0.0, 0.0 -> 1587.51, 1587.51
% INFO    : Updated Thermal Rating: on line 30399-30369 : Rate B, Rate C - 0.0, 0.0 -> 3937.64, 3937.64
% INFO    : Updated Thermal Rating: on transformer 30371-30370 : Rate B, Rate C - 0.0, 0.0 -> 401.26, 401.26
% INFO    : Updated Thermal Rating: on line 30378-30424 : Rate B, Rate C - 0.0, 0.0 -> 1176.79, 1176.79
% INFO    : Updated Thermal Rating: on transformer 30380-30379 : Rate B, Rate C - 0.0, 0.0 -> 602.06, 602.06
% INFO    : Updated Thermal Rating: on transformer 30380-30379 : Rate B, Rate C - 0.0, 0.0 -> 602.06, 602.06
% INFO    : Updated Thermal Rating: on transformer 30380-30379 : Rate B, Rate C - 0.0, 0.0 -> 602.06, 602.06
% INFO    : Updated Thermal Rating: on line 30379-30416 : Rate B, Rate C - 0.0, 0.0 -> 1375.66, 1375.66
% INFO    : Updated Thermal Rating: on line 30379-30457 : Rate B, Rate C - 0.0, 0.0 -> 1254.05, 1254.05
% INFO    : Updated Thermal Rating: on transformer 30382-30385 : Rate B, Rate C - 0.0, 0.0 -> 393.97, 393.97
% INFO    : Updated Thermal Rating: on transformer 30382-30386 : Rate B, Rate C - 0.0, 0.0 -> 484.58, 484.58
% INFO    : Updated Thermal Rating: on line 30382-50410 : Rate B, Rate C - 0.0, 0.0 -> 1059.25, 1059.25
% INFO    : Updated Thermal Rating: on transformer 30383-30385 : Rate B, Rate C - 0.0, 0.0 -> 318.97, 318.97
% INFO    : Updated Thermal Rating: on line 50422-30383 : Rate B, Rate C - 0.0, 0.0 -> 221.89, 221.89
% INFO    : Updated Thermal Rating: on transformer 30384-30385 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 30388-30387 : Rate B, Rate C - 0.0, 0.0 -> 1348.7, 1348.7
% INFO    : Updated Thermal Rating: on transformer 30387-30390 : Rate B, Rate C - 0.0, 0.0 -> 1354.74, 1354.74
% INFO    : Updated Thermal Rating: on transformer 30387-30391 : Rate B, Rate C - 0.0, 0.0 -> 1353.79, 1353.79
% INFO    : Updated Thermal Rating: on transformer 30387-30392 : Rate B, Rate C - 0.0, 0.0 -> 1352.62, 1352.62
% INFO    : Updated Thermal Rating: on transformer 30387-30393 : Rate B, Rate C - 0.0, 0.0 -> 1351.51, 1351.51
% INFO    : Updated Thermal Rating: on transformer 30387-30394 : Rate B, Rate C - 0.0, 0.0 -> 1350.55, 1350.55
% INFO    : Updated Thermal Rating: on transformer 30387-30395 : Rate B, Rate C - 0.0, 0.0 -> 1269.57, 1269.57
% INFO    : Updated Thermal Rating: on transformer 30387-30396 : Rate B, Rate C - 0.0, 0.0 -> 1141.11, 1141.11
% INFO    : Updated Thermal Rating: on transformer 30387-30397 : Rate B, Rate C - 0.0, 0.0 -> 1127.17, 1127.17
% INFO    : Updated Thermal Rating: on transformer 30389-30388 : Rate B, Rate C - 0.0, 0.0 -> 441.79, 441.79
% INFO    : Updated Thermal Rating: on line 30428-30389 : Rate B, Rate C - 0.0, 0.0 -> 252.41, 252.41
% INFO    : Updated Thermal Rating: on transformer 30400-30399 : Rate B, Rate C - 0.0, 0.0 -> 1652.28, 1652.28
% INFO    : Updated Thermal Rating: on transformer 30400-30399 : Rate B, Rate C - 0.0, 0.0 -> 1652.28, 1652.28
% INFO    : Updated Thermal Rating: on transformer 30400-30399 : Rate B, Rate C - 0.0, 0.0 -> 1652.28, 1652.28
% INFO    : Updated Thermal Rating: on transformer 30399-30404 : Rate B, Rate C - 0.0, 0.0 -> 1306.07, 1306.07
% INFO    : Updated Thermal Rating: on transformer 30399-30405 : Rate B, Rate C - 0.0, 0.0 -> 1305.21, 1305.21
% INFO    : Updated Thermal Rating: on transformer 30399-30406 : Rate B, Rate C - 0.0, 0.0 -> 1302.02, 1302.02
% INFO    : Updated Thermal Rating: on transformer 30399-30407 : Rate B, Rate C - 0.0, 0.0 -> 1301.73, 1301.73
% INFO    : Updated Thermal Rating: on transformer 30399-30408 : Rate B, Rate C - 0.0, 0.0 -> 1300.98, 1300.98
% INFO    : Updated Thermal Rating: on transformer 30399-30409 : Rate B, Rate C - 0.0, 0.0 -> 1298.79, 1298.79
% INFO    : Updated Thermal Rating: on transformer 30399-30410 : Rate B, Rate C - 0.0, 0.0 -> 1178.77, 1178.77
% INFO    : Updated Thermal Rating: on transformer 30399-30411 : Rate B, Rate C - 0.0, 0.0 -> 1167.98, 1167.98
% INFO    : Updated Thermal Rating: on transformer 30399-30412 : Rate B, Rate C - 0.0, 0.0 -> 1164.05, 1164.05
% INFO    : Updated Thermal Rating: on transformer 30399-30413 : Rate B, Rate C - 0.0, 0.0 -> 1161.93, 1161.93
% INFO    : Updated Thermal Rating: on transformer 30399-30414 : Rate B, Rate C - 0.0, 0.0 -> 1161.04, 1161.04
% INFO    : Updated Thermal Rating: on transformer 30399-30415 : Rate B, Rate C - 0.0, 0.0 -> 1156.9, 1156.9
% INFO    : Updated Thermal Rating: on line 30399-40783 : Rate B, Rate C - 0.0, 0.0 -> 4235.96, 4235.96
% INFO    : Updated Thermal Rating: on transformer 30400-30403 : Rate B, Rate C - 0.0, 0.0 -> 700.0, 700.0
% INFO    : Updated Thermal Rating: on transformer 30401-30403 : Rate B, Rate C - 0.0, 0.0 -> 700.0, 700.0
% INFO    : Updated Thermal Rating: on transformer 30402-30403 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 30417-30420 : Rate B, Rate C - 0.0, 0.0 -> 590.15, 590.15
% INFO    : Updated Thermal Rating: on transformer 30417-30421 : Rate B, Rate C - 0.0, 0.0 -> 535.02, 535.02
% INFO    : Updated Thermal Rating: on transformer 30417-30422 : Rate B, Rate C - 0.0, 0.0 -> 534.8, 534.8
% INFO    : Updated Thermal Rating: on transformer 30417-30423 : Rate B, Rate C - 0.0, 0.0 -> 532.91, 532.91
% INFO    : Updated Thermal Rating: on transformer 30418-30420 : Rate B, Rate C - 0.0, 0.0 -> 465.15, 465.15
% INFO    : Updated Thermal Rating: on line 30418-30425 : Rate B, Rate C - 0.0, 0.0 -> 385.2, 385.2
% INFO    : Updated Thermal Rating: on line 30438-30418 : Rate B, Rate C - 0.0, 0.0 -> 258.46, 258.46
% INFO    : Updated Thermal Rating: on transformer 30419-30420 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 30433-30424 : Rate B, Rate C - 0.0, 0.0 -> 1210.24, 1210.24
% INFO    : Updated Thermal Rating: on line 30424-30444 : Rate B, Rate C - 0.0, 0.0 -> 1114.68, 1114.68
% INFO    : Updated Thermal Rating: on line 30425-30427 : Rate B, Rate C - 0.0, 0.0 -> 248.02, 248.02
% INFO    : Updated Thermal Rating: on line 30427-30438 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on transformer 30429-30432 : Rate B, Rate C - 0.0, 0.0 -> 646.25, 646.25
% INFO    : Updated Thermal Rating: on transformer 30430-30432 : Rate B, Rate C - 0.0, 0.0 -> 521.25, 521.25
% INFO    : Updated Thermal Rating: on transformer 30431-30432 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 30437-30440 : Rate B, Rate C - 0.0, 0.0 -> 608.7, 608.7
% INFO    : Updated Thermal Rating: on transformer 30437-30441 : Rate B, Rate C - 0.0, 0.0 -> 525.45, 525.45
% INFO    : Updated Thermal Rating: on transformer 30437-30442 : Rate B, Rate C - 0.0, 0.0 -> 525.0, 525.0
% INFO    : Updated Thermal Rating: on transformer 30437-30443 : Rate B, Rate C - 0.0, 0.0 -> 523.79, 523.79
% INFO    : Updated Thermal Rating: on transformer 30438-30440 : Rate B, Rate C - 0.0, 0.0 -> 458.7, 458.7
% INFO    : Updated Thermal Rating: on transformer 30439-30440 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 30445-30448 : Rate B, Rate C - 0.0, 0.0 -> 283.04, 283.04
% INFO    : Updated Thermal Rating: on transformer 30446-30448 : Rate B, Rate C - 0.0, 0.0 -> 141.52, 141.52
% INFO    : Updated Thermal Rating: on transformer 30447-30448 : Rate B, Rate C - 0.0, 0.0 -> 141.52, 141.52
% INFO    : Updated Thermal Rating: on transformer 30450-30449 : Rate B, Rate C - 0.0, 0.0 -> 451.13, 451.13
% INFO    : Updated Thermal Rating: on transformer 30449-30451 : Rate B, Rate C - 0.0, 0.0 -> 511.9, 511.9
% INFO    : Updated Thermal Rating: on transformer 30449-30452 : Rate B, Rate C - 0.0, 0.0 -> 511.4, 511.4
% INFO    : Updated Thermal Rating: on transformer 30449-30453 : Rate B, Rate C - 0.0, 0.0 -> 511.02, 511.02
% INFO    : Updated Thermal Rating: on transformer 30449-30454 : Rate B, Rate C - 0.0, 0.0 -> 510.01, 510.01
% INFO    : Updated Thermal Rating: on transformer 30449-30455 : Rate B, Rate C - 0.0, 0.0 -> 509.74, 509.74
% INFO    : Updated Thermal Rating: on transformer 30449-30456 : Rate B, Rate C - 0.0, 0.0 -> 508.11, 508.11
% INFO    : Updated Thermal Rating: on transformer 30459-30458 : Rate B, Rate C - 0.0, 0.0 -> 453.65, 453.65
% INFO    : Updated Thermal Rating: on transformer 30458-30460 : Rate B, Rate C - 0.0, 0.0 -> 450.18, 450.18
% INFO    : Updated Thermal Rating: on transformer 30458-30461 : Rate B, Rate C - 0.0, 0.0 -> 449.56, 449.56
% INFO    : Updated Thermal Rating: on line 40000-40951 : Rate B, Rate C - 0.0, 0.0 -> 158.83, 158.83
% INFO    : Updated Thermal Rating: on line 40002-40001 : Rate B, Rate C - 0.0, 0.0 -> 115.41, 115.41
% INFO    : Updated Thermal Rating: on line 40001-40861 : Rate B, Rate C - 0.0, 0.0 -> 161.83, 161.83
% INFO    : Updated Thermal Rating: on line 40002-40016 : Rate B, Rate C - 0.0, 0.0 -> 148.54, 148.54
% INFO    : Updated Thermal Rating: on line 40002-40861 : Rate B, Rate C - 0.0, 0.0 -> 157.11, 157.11
% INFO    : Updated Thermal Rating: on line 40005-40003 : Rate B, Rate C - 0.0, 0.0 -> 167.84, 167.84
% INFO    : Updated Thermal Rating: on line 40003-40013 : Rate B, Rate C - 0.0, 0.0 -> 151.03, 151.03
% INFO    : Updated Thermal Rating: on line 40003-40861 : Rate B, Rate C - 0.0, 0.0 -> 151.1, 151.1
% INFO    : Updated Thermal Rating: on line 40005-40725 : Rate B, Rate C - 0.0, 0.0 -> 202.63, 202.63
% INFO    : Updated Thermal Rating: on line 40005-40725 : Rate B, Rate C - 0.0, 0.0 -> 202.63, 202.63
% INFO    : Updated Thermal Rating: on line 40005-40725 : Rate B, Rate C - 0.0, 0.0 -> 202.63, 202.63
% INFO    : Updated Thermal Rating: on line 40861-40005 : Rate B, Rate C - 0.0, 0.0 -> 151.87, 151.87
% INFO    : Updated Thermal Rating: on line 40012-40006 : Rate B, Rate C - 0.0, 0.0 -> 159.72, 159.72
% INFO    : Updated Thermal Rating: on line 40006-40026 : Rate B, Rate C - 0.0, 0.0 -> 121.13, 121.13
% INFO    : Updated Thermal Rating: on line 40008-40012 : Rate B, Rate C - 0.0, 0.0 -> 171.25, 171.25
% INFO    : Updated Thermal Rating: on line 40008-40731 : Rate B, Rate C - 0.0, 0.0 -> 190.76, 190.76
% INFO    : Updated Thermal Rating: on line 40009-40753 : Rate B, Rate C - 0.0, 0.0 -> 171.29, 171.29
% INFO    : Updated Thermal Rating: on line 40013-40029 : Rate B, Rate C - 0.0, 0.0 -> 126.06, 126.06
% INFO    : Updated Thermal Rating: on line 40731-40014 : Rate B, Rate C - 0.0, 0.0 -> 139.89, 139.89
% INFO    : Updated Thermal Rating: on line 40016-40028 : Rate B, Rate C - 0.0, 0.0 -> 153.37, 153.37
% INFO    : Updated Thermal Rating: on line 40016-40725 : Rate B, Rate C - 0.0, 0.0 -> 167.43, 167.43
% INFO    : Updated Thermal Rating: on line 40951-40016 : Rate B, Rate C - 0.0, 0.0 -> 127.35, 127.35
% INFO    : Updated Thermal Rating: on line 40019-40022 : Rate B, Rate C - 0.0, 0.0 -> 163.62, 163.62
% INFO    : Updated Thermal Rating: on line 40019-40832 : Rate B, Rate C - 0.0, 0.0 -> 169.18, 169.18
% INFO    : Updated Thermal Rating: on line 40023-40021 : Rate B, Rate C - 0.0, 0.0 -> 131.39, 131.39
% INFO    : Updated Thermal Rating: on line 40022-40026 : Rate B, Rate C - 0.0, 0.0 -> 97.89, 97.89
% INFO    : Updated Thermal Rating: on line 40023-40731 : Rate B, Rate C - 0.0, 0.0 -> 150.74, 150.74
% INFO    : Updated Thermal Rating: on line 40040-40026 : Rate B, Rate C - 0.0, 0.0 -> 167.79, 167.79
% INFO    : Updated Thermal Rating: on line 40027-40040 : Rate B, Rate C - 0.0, 0.0 -> 133.27, 133.27
% INFO    : Updated Thermal Rating: on line 40028-40034 : Rate B, Rate C - 0.0, 0.0 -> 163.89, 163.89
% INFO    : Updated Thermal Rating: on line 40029-40044 : Rate B, Rate C - 0.0, 0.0 -> 142.6, 142.6
% INFO    : Updated Thermal Rating: on line 40031-40034 : Rate B, Rate C - 0.0, 0.0 -> 174.62, 174.62
% INFO    : Updated Thermal Rating: on line 40031-40699 : Rate B, Rate C - 0.0, 0.0 -> 163.01, 163.01
% INFO    : Updated Thermal Rating: on line 40031-40951 : Rate B, Rate C - 0.0, 0.0 -> 162.9, 162.9
% INFO    : Updated Thermal Rating: on transformer 40033-40036 : Rate B, Rate C - 0.0, 0.0 -> 993.03, 993.03
% INFO    : Updated Thermal Rating: on transformer 40034-40036 : Rate B, Rate C - 0.0, 0.0 -> 752.25, 752.25
% INFO    : Updated Thermal Rating: on transformer 40035-40036 : Rate B, Rate C - 0.0, 0.0 -> 240.79, 240.79
% INFO    : Updated Thermal Rating: on line 40037-40698 : Rate B, Rate C - 0.0, 0.0 -> 2681.57, 2681.57
% INFO    : Updated Thermal Rating: on line 40037-40723 : Rate B, Rate C - 0.0, 0.0 -> 2409.64, 2409.64
% INFO    : Updated Thermal Rating: on transformer 40039-40038 : Rate B, Rate C - 0.0, 0.0 -> 659.91, 659.91
% INFO    : Updated Thermal Rating: on line 40752-40038 : Rate B, Rate C - 0.0, 0.0 -> 2202.32, 2202.32
% INFO    : Updated Thermal Rating: on transformer 40040-40039 : Rate B, Rate C - 0.0, 0.0 -> 434.18, 434.18
% INFO    : Updated Thermal Rating: on line 40039-41007 : Rate B, Rate C - 0.0, 0.0 -> 1112.55, 1112.55
% INFO    : Updated Thermal Rating: on line 40041-40043 : Rate B, Rate C - 0.0, 0.0 -> 150.12, 150.12
% INFO    : Updated Thermal Rating: on line 40041-40049 : Rate B, Rate C - 0.0, 0.0 -> 153.52, 153.52
% INFO    : Updated Thermal Rating: on line 40042-40043 : Rate B, Rate C - 0.0, 0.0 -> 163.01, 163.01
% INFO    : Updated Thermal Rating: on line 40042-40046 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on line 40047-40042 : Rate B, Rate C - 0.0, 0.0 -> 127.32, 127.32
% INFO    : Updated Thermal Rating: on line 40043-41017 : Rate B, Rate C - 0.0, 0.0 -> 170.21, 170.21
% INFO    : Updated Thermal Rating: on line 40045-40044 : Rate B, Rate C - 0.0, 0.0 -> 146.75, 146.75
% INFO    : Updated Thermal Rating: on line 40051-40045 : Rate B, Rate C - 0.0, 0.0 -> 135.82, 135.82
% INFO    : Updated Thermal Rating: on line 41004-40045 : Rate B, Rate C - 0.0, 0.0 -> 163.96, 163.96
% INFO    : Updated Thermal Rating: on line 40832-40046 : Rate B, Rate C - 0.0, 0.0 -> 149.83, 149.83
% INFO    : Updated Thermal Rating: on line 40046-41008 : Rate B, Rate C - 0.0, 0.0 -> 163.52, 163.52
% INFO    : Updated Thermal Rating: on line 40047-40055 : Rate B, Rate C - 0.0, 0.0 -> 111.14, 111.14
% INFO    : Updated Thermal Rating: on line 40049-40061 : Rate B, Rate C - 0.0, 0.0 -> 162.07, 162.07
% INFO    : Updated Thermal Rating: on line 40051-40058 : Rate B, Rate C - 0.0, 0.0 -> 132.02, 132.02
% INFO    : Updated Thermal Rating: on line 40068-40052 : Rate B, Rate C - 0.0, 0.0 -> 136.56, 136.56
% INFO    : Updated Thermal Rating: on line 40749-40052 : Rate B, Rate C - 0.0, 0.0 -> 129.49, 129.49
% INFO    : Updated Thermal Rating: on line 40054-40064 : Rate B, Rate C - 0.0, 0.0 -> 165.46, 165.46
% INFO    : Updated Thermal Rating: on line 40054-40999 : Rate B, Rate C - 0.0, 0.0 -> 177.12, 177.12
% INFO    : Updated Thermal Rating: on line 40055-40057 : Rate B, Rate C - 0.0, 0.0 -> 121.85, 121.85
% INFO    : Updated Thermal Rating: on line 40061-40056 : Rate B, Rate C - 0.0, 0.0 -> 166.55, 166.55
% INFO    : Updated Thermal Rating: on line 40056-50022 : Rate B, Rate C - 0.0, 0.0 -> 175.79, 175.79
% INFO    : Updated Thermal Rating: on line 40057-40078 : Rate B, Rate C - 0.0, 0.0 -> 167.77, 167.77
% INFO    : Updated Thermal Rating: on line 40749-40057 : Rate B, Rate C - 0.0, 0.0 -> 127.39, 127.39
% INFO    : Updated Thermal Rating: on line 40059-40058 : Rate B, Rate C - 0.0, 0.0 -> 116.74, 116.74
% INFO    : Updated Thermal Rating: on line 40059-40068 : Rate B, Rate C - 0.0, 0.0 -> 146.88, 146.88
% INFO    : Updated Thermal Rating: on line 40063-40117 : Rate B, Rate C - 0.0, 0.0 -> 183.73, 183.73
% INFO    : Updated Thermal Rating: on line 40063-40883 : Rate B, Rate C - 0.0, 0.0 -> 188.5, 188.5
% INFO    : Updated Thermal Rating: on line 40106-40064 : Rate B, Rate C - 0.0, 0.0 -> 195.32, 195.32
% INFO    : Updated Thermal Rating: on line 40106-40064 : Rate B, Rate C - 0.0, 0.0 -> 195.32, 195.32
% INFO    : Updated Thermal Rating: on line 40064-40996 : Rate B, Rate C - 0.0, 0.0 -> 191.57, 191.57
% INFO    : Updated Thermal Rating: on line 40286-40065 : Rate B, Rate C - 0.0, 0.0 -> 159.81, 159.81
% INFO    : Updated Thermal Rating: on line 40958-40065 : Rate B, Rate C - 0.0, 0.0 -> 164.37, 164.37
% INFO    : Updated Thermal Rating: on line 40078-40067 : Rate B, Rate C - 0.0, 0.0 -> 174.13, 174.13
% INFO    : Updated Thermal Rating: on line 40067-40716 : Rate B, Rate C - 0.0, 0.0 -> 177.06, 177.06
% INFO    : Updated Thermal Rating: on line 40068-40133 : Rate B, Rate C - 0.0, 0.0 -> 162.01, 162.01
% INFO    : Updated Thermal Rating: on line 40081-40071 : Rate B, Rate C - 0.0, 0.0 -> 125.12, 125.12
% INFO    : Updated Thermal Rating: on line 40071-40111 : Rate B, Rate C - 0.0, 0.0 -> 143.55, 143.55
% INFO    : Updated Thermal Rating: on line 40073-40096 : Rate B, Rate C - 0.0, 0.0 -> 144.27, 144.27
% INFO    : Updated Thermal Rating: on line 40073-40720 : Rate B, Rate C - 0.0, 0.0 -> 189.12, 189.12
% INFO    : Updated Thermal Rating: on transformer 40075-40074 : Rate B, Rate C - 0.0, 0.0 -> 915.65, 915.65
% INFO    : Updated Thermal Rating: on line 40152-40074 : Rate B, Rate C - 0.0, 0.0 -> 2663.43, 2663.43
% INFO    : Updated Thermal Rating: on line 40074-40273 : Rate B, Rate C - 0.0, 0.0 -> 2570.74, 2570.74
% INFO    : Updated Thermal Rating: on line 40074-40298 : Rate B, Rate C - 0.0, 0.0 -> 2741.69, 2741.69
% INFO    : Updated Thermal Rating: on line 40841-40074 : Rate B, Rate C - 0.0, 0.0 -> 2924.68, 2924.68
% INFO    : Updated Thermal Rating: on line 40074-40965 : Rate B, Rate C - 0.0, 0.0 -> 2806.35, 2806.35
% INFO    : Updated Thermal Rating: on line 40967-40074 : Rate B, Rate C - 0.0, 0.0 -> 2758.86, 2758.86
% INFO    : Updated Thermal Rating: on line 40075-40257 : Rate B, Rate C - 0.0, 0.0 -> 216.15, 216.15
% INFO    : Updated Thermal Rating: on line 40075-40257 : Rate B, Rate C - 0.0, 0.0 -> 216.15, 216.15
% INFO    : Updated Thermal Rating: on line 40075-40257 : Rate B, Rate C - 0.0, 0.0 -> 216.15, 216.15
% INFO    : Updated Thermal Rating: on line 40086-40080 : Rate B, Rate C - 0.0, 0.0 -> 175.38, 175.38
% INFO    : Updated Thermal Rating: on line 40080-40092 : Rate B, Rate C - 0.0, 0.0 -> 112.06, 112.06
% INFO    : Updated Thermal Rating: on line 40125-40080 : Rate B, Rate C - 0.0, 0.0 -> 161.21, 161.21
% INFO    : Updated Thermal Rating: on line 40081-40094 : Rate B, Rate C - 0.0, 0.0 -> 174.32, 174.32
% INFO    : Updated Thermal Rating: on line 40081-40179 : Rate B, Rate C - 0.0, 0.0 -> 155.51, 155.51
% INFO    : Updated Thermal Rating: on line 40089-40083 : Rate B, Rate C - 0.0, 0.0 -> 172.17, 172.17
% INFO    : Updated Thermal Rating: on line 40083-40228 : Rate B, Rate C - 0.0, 0.0 -> 132.64, 132.64
% INFO    : Updated Thermal Rating: on line 40086-40108 : Rate B, Rate C - 0.0, 0.0 -> 204.39, 204.39
% INFO    : Updated Thermal Rating: on line 40086-40108 : Rate B, Rate C - 0.0, 0.0 -> 204.39, 204.39
% INFO    : Updated Thermal Rating: on line 40086-40108 : Rate B, Rate C - 0.0, 0.0 -> 204.39, 204.39
% INFO    : Updated Thermal Rating: on line 40086-40116 : Rate B, Rate C - 0.0, 0.0 -> 111.08, 111.08
% INFO    : Updated Thermal Rating: on line 40086-40129 : Rate B, Rate C - 0.0, 0.0 -> 135.15, 135.15
% INFO    : Updated Thermal Rating: on line 40086-40146 : Rate B, Rate C - 0.0, 0.0 -> 177.4, 177.4
% INFO    : Updated Thermal Rating: on transformer 40088-40091 : Rate B, Rate C - 0.0, 0.0 -> 938.81, 938.81
% INFO    : Updated Thermal Rating: on line 40260-40088 : Rate B, Rate C - 0.0, 0.0 -> 2463.01, 2463.01
% INFO    : Updated Thermal Rating: on transformer 40089-40091 : Rate B, Rate C - 0.0, 0.0 -> 787.81, 787.81
% INFO    : Updated Thermal Rating: on line 40089-40124 : Rate B, Rate C - 0.0, 0.0 -> 176.02, 176.02
% INFO    : Updated Thermal Rating: on line 40834-40089 : Rate B, Rate C - 0.0, 0.0 -> 157.42, 157.42
% INFO    : Updated Thermal Rating: on transformer 40090-40091 : Rate B, Rate C - 0.0, 0.0 -> 151.0, 151.0
% INFO    : Updated Thermal Rating: on line 40092-40103 : Rate B, Rate C - 0.0, 0.0 -> 187.85, 187.85
% INFO    : Updated Thermal Rating: on line 40092-40117 : Rate B, Rate C - 0.0, 0.0 -> 167.06, 167.06
% INFO    : Updated Thermal Rating: on line 40094-40106 : Rate B, Rate C - 0.0, 0.0 -> 170.82, 170.82
% INFO    : Updated Thermal Rating: on line 40113-40094 : Rate B, Rate C - 0.0, 0.0 -> 162.42, 162.42
% INFO    : Updated Thermal Rating: on line 40095-40096 : Rate B, Rate C - 0.0, 0.0 -> 185.54, 185.54
% INFO    : Updated Thermal Rating: on line 40095-40234 : Rate B, Rate C - 0.0, 0.0 -> 179.21, 179.21
% INFO    : Updated Thermal Rating: on line 40095-41016 : Rate B, Rate C - 0.0, 0.0 -> 206.77, 206.77
% INFO    : Updated Thermal Rating: on line 40095-41016 : Rate B, Rate C - 0.0, 0.0 -> 206.77, 206.77
% INFO    : Updated Thermal Rating: on line 40095-41016 : Rate B, Rate C - 0.0, 0.0 -> 206.77, 206.77
% INFO    : Updated Thermal Rating: on line 40180-40096 : Rate B, Rate C - 0.0, 0.0 -> 168.34, 168.34
% INFO    : Updated Thermal Rating: on line 40097-40123 : Rate B, Rate C - 0.0, 0.0 -> 165.0, 165.0
% INFO    : Updated Thermal Rating: on line 40097-40834 : Rate B, Rate C - 0.0, 0.0 -> 163.19, 163.19
% INFO    : Updated Thermal Rating: on line 40097-41015 : Rate B, Rate C - 0.0, 0.0 -> 167.23, 167.23
% INFO    : Updated Thermal Rating: on line 40101-40136 : Rate B, Rate C - 0.0, 0.0 -> 134.96, 134.96
% INFO    : Updated Thermal Rating: on line 40156-40101 : Rate B, Rate C - 0.0, 0.0 -> 149.12, 149.12
% INFO    : Updated Thermal Rating: on line 40103-40109 : Rate B, Rate C - 0.0, 0.0 -> 135.18, 135.18
% INFO    : Updated Thermal Rating: on line 40103-40781 : Rate B, Rate C - 0.0, 0.0 -> 193.19, 193.19
% INFO    : Updated Thermal Rating: on transformer 40108-40107 : Rate B, Rate C - 0.0, 0.0 -> 1130.59, 1130.59
% INFO    : Updated Thermal Rating: on transformer 40108-40107 : Rate B, Rate C - 0.0, 0.0 -> 1130.59, 1130.59
% INFO    : Updated Thermal Rating: on transformer 40108-40107 : Rate B, Rate C - 0.0, 0.0 -> 1130.59, 1130.59
% INFO    : Updated Thermal Rating: on line 40107-40991 : Rate B, Rate C - 0.0, 0.0 -> 2892.48, 2892.48
% INFO    : Updated Thermal Rating: on line 40107-41003 : Rate B, Rate C - 0.0, 0.0 -> 2947.73, 2947.73
% INFO    : Updated Thermal Rating: on line 40113-40108 : Rate B, Rate C - 0.0, 0.0 -> 284.88, 284.88
% INFO    : Updated Thermal Rating: on line 40108-40116 : Rate B, Rate C - 0.0, 0.0 -> 261.81, 261.81
% INFO    : Updated Thermal Rating: on line 40127-40108 : Rate B, Rate C - 0.0, 0.0 -> 290.2, 290.2
% INFO    : Updated Thermal Rating: on line 40108-40129 : Rate B, Rate C - 0.0, 0.0 -> 223.7, 223.7
% INFO    : Updated Thermal Rating: on line 40108-40129 : Rate B, Rate C - 0.0, 0.0 -> 223.7, 223.7
% INFO    : Updated Thermal Rating: on line 40108-40129 : Rate B, Rate C - 0.0, 0.0 -> 223.7, 223.7
% INFO    : Updated Thermal Rating: on line 40108-40129 : Rate B, Rate C - 0.0, 0.0 -> 223.7, 223.7
% INFO    : Updated Thermal Rating: on line 40108-40129 : Rate B, Rate C - 0.0, 0.0 -> 223.7, 223.7
% INFO    : Updated Thermal Rating: on line 40109-40996 : Rate B, Rate C - 0.0, 0.0 -> 177.74, 177.74
% INFO    : Updated Thermal Rating: on line 40125-40110 : Rate B, Rate C - 0.0, 0.0 -> 154.27, 154.27
% INFO    : Updated Thermal Rating: on line 40110-40127 : Rate B, Rate C - 0.0, 0.0 -> 209.63, 209.63
% INFO    : Updated Thermal Rating: on line 40110-40127 : Rate B, Rate C - 0.0, 0.0 -> 209.63, 209.63
% INFO    : Updated Thermal Rating: on line 40110-40127 : Rate B, Rate C - 0.0, 0.0 -> 209.63, 209.63
% INFO    : Updated Thermal Rating: on line 40110-40146 : Rate B, Rate C - 0.0, 0.0 -> 154.5, 154.5
% INFO    : Updated Thermal Rating: on line 40170-40110 : Rate B, Rate C - 0.0, 0.0 -> 235.5, 235.5
% INFO    : Updated Thermal Rating: on line 40110-40810 : Rate B, Rate C - 0.0, 0.0 -> 191.31, 191.31
% INFO    : Updated Thermal Rating: on line 40116-40111 : Rate B, Rate C - 0.0, 0.0 -> 194.39, 194.39
% INFO    : Updated Thermal Rating: on line 40116-40111 : Rate B, Rate C - 0.0, 0.0 -> 194.39, 194.39
% INFO    : Updated Thermal Rating: on line 40145-40111 : Rate B, Rate C - 0.0, 0.0 -> 174.17, 174.17
% INFO    : Updated Thermal Rating: on line 40113-40114 : Rate B, Rate C - 0.0, 0.0 -> 182.97, 182.97
% INFO    : Updated Thermal Rating: on line 40116-40113 : Rate B, Rate C - 0.0, 0.0 -> 155.31, 155.31
% INFO    : Updated Thermal Rating: on line 40128-40113 : Rate B, Rate C - 0.0, 0.0 -> 130.8, 130.8
% INFO    : Updated Thermal Rating: on line 40113-40129 : Rate B, Rate C - 0.0, 0.0 -> 164.09, 164.09
% INFO    : Updated Thermal Rating: on line 40114-40145 : Rate B, Rate C - 0.0, 0.0 -> 160.44, 160.44
% INFO    : Updated Thermal Rating: on line 40116-40125 : Rate B, Rate C - 0.0, 0.0 -> 190.59, 190.59
% INFO    : Updated Thermal Rating: on line 40116-40128 : Rate B, Rate C - 0.0, 0.0 -> 156.7, 156.7
% INFO    : Updated Thermal Rating: on line 40129-40116 : Rate B, Rate C - 0.0, 0.0 -> 214.72, 214.72
% INFO    : Updated Thermal Rating: on line 40129-40116 : Rate B, Rate C - 0.0, 0.0 -> 214.72, 214.72
% INFO    : Updated Thermal Rating: on line 40129-40116 : Rate B, Rate C - 0.0, 0.0 -> 214.72, 214.72
% INFO    : Updated Thermal Rating: on line 40136-40117 : Rate B, Rate C - 0.0, 0.0 -> 180.16, 180.16
% INFO    : Updated Thermal Rating: on line 40132-40118 : Rate B, Rate C - 0.0, 0.0 -> 130.37, 130.37
% INFO    : Updated Thermal Rating: on line 40118-40147 : Rate B, Rate C - 0.0, 0.0 -> 167.91, 167.91
% INFO    : Updated Thermal Rating: on line 40137-40119 : Rate B, Rate C - 0.0, 0.0 -> 164.41, 164.41
% INFO    : Updated Thermal Rating: on line 40119-40169 : Rate B, Rate C - 0.0, 0.0 -> 142.88, 142.88
% INFO    : Updated Thermal Rating: on line 40121-40132 : Rate B, Rate C - 0.0, 0.0 -> 165.27, 165.27
% INFO    : Updated Thermal Rating: on line 40121-40151 : Rate B, Rate C - 0.0, 0.0 -> 189.82, 189.82
% INFO    : Updated Thermal Rating: on line 40157-40122 : Rate B, Rate C - 0.0, 0.0 -> 145.52, 145.52
% INFO    : Updated Thermal Rating: on line 40122-40159 : Rate B, Rate C - 0.0, 0.0 -> 138.52, 138.52
% INFO    : Updated Thermal Rating: on line 40122-40170 : Rate B, Rate C - 0.0, 0.0 -> 144.18, 144.18
% INFO    : Updated Thermal Rating: on line 40122-40810 : Rate B, Rate C - 0.0, 0.0 -> 265.26, 265.26
% INFO    : Updated Thermal Rating: on line 40123-40133 : Rate B, Rate C - 0.0, 0.0 -> 117.69, 117.69
% INFO    : Updated Thermal Rating: on line 40124-40133 : Rate B, Rate C - 0.0, 0.0 -> 141.4, 141.4
% INFO    : Updated Thermal Rating: on line 40125-40137 : Rate B, Rate C - 0.0, 0.0 -> 192.06, 192.06
% INFO    : Updated Thermal Rating: on line 40125-40157 : Rate B, Rate C - 0.0, 0.0 -> 163.33, 163.33
% INFO    : Updated Thermal Rating: on line 40127-40129 : Rate B, Rate C - 0.0, 0.0 -> 205.07, 205.07
% INFO    : Updated Thermal Rating: on line 40127-40129 : Rate B, Rate C - 0.0, 0.0 -> 205.07, 205.07
% INFO    : Updated Thermal Rating: on line 40127-40129 : Rate B, Rate C - 0.0, 0.0 -> 205.07, 205.07
% INFO    : Updated Thermal Rating: on line 40151-40130 : Rate B, Rate C - 0.0, 0.0 -> 160.28, 160.28
% INFO    : Updated Thermal Rating: on line 40130-40174 : Rate B, Rate C - 0.0, 0.0 -> 129.83, 129.83
% INFO    : Updated Thermal Rating: on line 40132-40156 : Rate B, Rate C - 0.0, 0.0 -> 125.54, 125.54
% INFO    : Updated Thermal Rating: on line 40133-40198 : Rate B, Rate C - 0.0, 0.0 -> 165.65, 165.65
% INFO    : Updated Thermal Rating: on line 40167-40138 : Rate B, Rate C - 0.0, 0.0 -> 189.2, 189.2
% INFO    : Updated Thermal Rating: on line 40138-40210 : Rate B, Rate C - 0.0, 0.0 -> 144.89, 144.89
% INFO    : Updated Thermal Rating: on line 40138-40279 : Rate B, Rate C - 0.0, 0.0 -> 149.33, 149.33
% INFO    : Updated Thermal Rating: on line 40141-40139 : Rate B, Rate C - 0.0, 0.0 -> 126.6, 126.6
% INFO    : Updated Thermal Rating: on line 40139-40146 : Rate B, Rate C - 0.0, 0.0 -> 155.43, 155.43
% INFO    : Updated Thermal Rating: on line 40139-40160 : Rate B, Rate C - 0.0, 0.0 -> 145.11, 145.11
% INFO    : Updated Thermal Rating: on line 40139-40170 : Rate B, Rate C - 0.0, 0.0 -> 162.91, 162.91
% INFO    : Updated Thermal Rating: on line 40141-40187 : Rate B, Rate C - 0.0, 0.0 -> 181.12, 181.12
% INFO    : Updated Thermal Rating: on line 40141-40209 : Rate B, Rate C - 0.0, 0.0 -> 136.55, 136.55
% INFO    : Updated Thermal Rating: on line 40142-40143 : Rate B, Rate C - 0.0, 0.0 -> 140.17, 140.17
% INFO    : Updated Thermal Rating: on line 40142-40145 : Rate B, Rate C - 0.0, 0.0 -> 148.59, 148.59
% INFO    : Updated Thermal Rating: on line 40161-40142 : Rate B, Rate C - 0.0, 0.0 -> 134.34, 134.34
% INFO    : Updated Thermal Rating: on line 40719-40143 : Rate B, Rate C - 0.0, 0.0 -> 178.21, 178.21
% INFO    : Updated Thermal Rating: on line 40144-40168 : Rate B, Rate C - 0.0, 0.0 -> 172.56, 172.56
% INFO    : Updated Thermal Rating: on line 40144-40209 : Rate B, Rate C - 0.0, 0.0 -> 144.11, 144.11
% INFO    : Updated Thermal Rating: on line 40147-40148 : Rate B, Rate C - 0.0, 0.0 -> 206.2, 206.2
% INFO    : Updated Thermal Rating: on line 40148-40155 : Rate B, Rate C - 0.0, 0.0 -> 157.15, 157.15
% INFO    : Updated Thermal Rating: on line 40148-40796 : Rate B, Rate C - 0.0, 0.0 -> 199.47, 199.47
% INFO    : Updated Thermal Rating: on line 40148-40796 : Rate B, Rate C - 0.0, 0.0 -> 199.47, 199.47
% INFO    : Updated Thermal Rating: on line 40148-40796 : Rate B, Rate C - 0.0, 0.0 -> 199.47, 199.47
% INFO    : Updated Thermal Rating: on transformer 40151-40150 : Rate B, Rate C - 0.0, 0.0 -> 998.89, 998.89
% INFO    : Updated Thermal Rating: on line 40192-40151 : Rate B, Rate C - 0.0, 0.0 -> 197.35, 197.35
% INFO    : Updated Thermal Rating: on line 40192-40151 : Rate B, Rate C - 0.0, 0.0 -> 197.35, 197.35
% INFO    : Updated Thermal Rating: on line 40151-40207 : Rate B, Rate C - 0.0, 0.0 -> 215.47, 215.47
% INFO    : Updated Thermal Rating: on line 40152-40298 : Rate B, Rate C - 0.0, 0.0 -> 2569.78, 2569.78
% INFO    : Updated Thermal Rating: on line 40795-40152 : Rate B, Rate C - 0.0, 0.0 -> 2195.77, 2195.77
% INFO    : Updated Thermal Rating: on line 40152-40847 : Rate B, Rate C - 0.0, 0.0 -> 2543.21, 2543.21
% INFO    : Updated Thermal Rating: on line 40165-40153 : Rate B, Rate C - 0.0, 0.0 -> 171.15, 171.15
% INFO    : Updated Thermal Rating: on line 40796-40153 : Rate B, Rate C - 0.0, 0.0 -> 196.81, 196.81
% INFO    : Updated Thermal Rating: on line 40796-40153 : Rate B, Rate C - 0.0, 0.0 -> 196.81, 196.81
% INFO    : Updated Thermal Rating: on line 40155-40191 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 40155-40227 : Rate B, Rate C - 0.0, 0.0 -> 130.57, 130.57
% INFO    : Updated Thermal Rating: on line 40156-40192 : Rate B, Rate C - 0.0, 0.0 -> 178.68, 178.68
% INFO    : Updated Thermal Rating: on line 40159-40167 : Rate B, Rate C - 0.0, 0.0 -> 136.96, 136.96
% INFO    : Updated Thermal Rating: on line 40159-40810 : Rate B, Rate C - 0.0, 0.0 -> 175.81, 175.81
% INFO    : Updated Thermal Rating: on line 40209-40160 : Rate B, Rate C - 0.0, 0.0 -> 134.91, 134.91
% INFO    : Updated Thermal Rating: on line 40160-40810 : Rate B, Rate C - 0.0, 0.0 -> 171.36, 171.36
% INFO    : Updated Thermal Rating: on line 40179-40161 : Rate B, Rate C - 0.0, 0.0 -> 109.1, 109.1
% INFO    : Updated Thermal Rating: on line 40161-40187 : Rate B, Rate C - 0.0, 0.0 -> 190.06, 190.06
% INFO    : Updated Thermal Rating: on line 40163-40187 : Rate B, Rate C - 0.0, 0.0 -> 221.17, 221.17
% INFO    : Updated Thermal Rating: on line 40163-40187 : Rate B, Rate C - 0.0, 0.0 -> 221.17, 221.17
% INFO    : Updated Thermal Rating: on line 40163-40187 : Rate B, Rate C - 0.0, 0.0 -> 221.17, 221.17
% INFO    : Updated Thermal Rating: on line 40163-40187 : Rate B, Rate C - 0.0, 0.0 -> 221.17, 221.17
% INFO    : Updated Thermal Rating: on line 40163-40187 : Rate B, Rate C - 0.0, 0.0 -> 221.17, 221.17
% INFO    : Updated Thermal Rating: on line 40189-40163 : Rate B, Rate C - 0.0, 0.0 -> 182.47, 182.47
% INFO    : Updated Thermal Rating: on line 40163-40210 : Rate B, Rate C - 0.0, 0.0 -> 190.13, 190.13
% INFO    : Updated Thermal Rating: on line 40163-40210 : Rate B, Rate C - 0.0, 0.0 -> 190.13, 190.13
% INFO    : Updated Thermal Rating: on line 40220-40163 : Rate B, Rate C - 0.0, 0.0 -> 204.92, 204.92
% INFO    : Updated Thermal Rating: on line 40220-40163 : Rate B, Rate C - 0.0, 0.0 -> 204.92, 204.92
% INFO    : Updated Thermal Rating: on line 40220-40163 : Rate B, Rate C - 0.0, 0.0 -> 204.92, 204.92
% INFO    : Updated Thermal Rating: on line 40163-40224 : Rate B, Rate C - 0.0, 0.0 -> 272.07, 272.07
% INFO    : Updated Thermal Rating: on line 40163-40233 : Rate B, Rate C - 0.0, 0.0 -> 170.12, 170.12
% INFO    : Updated Thermal Rating: on line 40165-40184 : Rate B, Rate C - 0.0, 0.0 -> 144.79, 144.79
% INFO    : Updated Thermal Rating: on line 40168-40166 : Rate B, Rate C - 0.0, 0.0 -> 160.83, 160.83
% INFO    : Updated Thermal Rating: on line 40166-40217 : Rate B, Rate C - 0.0, 0.0 -> 157.58, 157.58
% INFO    : Updated Thermal Rating: on line 40166-40229 : Rate B, Rate C - 0.0, 0.0 -> 144.16, 144.16
% INFO    : Updated Thermal Rating: on line 40167-40168 : Rate B, Rate C - 0.0, 0.0 -> 145.42, 145.42
% INFO    : Updated Thermal Rating: on line 40167-40810 : Rate B, Rate C - 0.0, 0.0 -> 168.52, 168.52
% INFO    : Updated Thermal Rating: on line 40168-40171 : Rate B, Rate C - 0.0, 0.0 -> 173.62, 173.62
% INFO    : Updated Thermal Rating: on line 40210-40168 : Rate B, Rate C - 0.0, 0.0 -> 198.57, 198.57
% INFO    : Updated Thermal Rating: on line 40810-40168 : Rate B, Rate C - 0.0, 0.0 -> 215.76, 215.76
% INFO    : Updated Thermal Rating: on line 40810-40168 : Rate B, Rate C - 0.0, 0.0 -> 215.76, 215.76
% INFO    : Updated Thermal Rating: on line 40810-40168 : Rate B, Rate C - 0.0, 0.0 -> 215.76, 215.76
% INFO    : Updated Thermal Rating: on line 40183-40169 : Rate B, Rate C - 0.0, 0.0 -> 183.28, 183.28
% INFO    : Updated Thermal Rating: on line 40184-40169 : Rate B, Rate C - 0.0, 0.0 -> 141.19, 141.19
% INFO    : Updated Thermal Rating: on line 40171-40184 : Rate B, Rate C - 0.0, 0.0 -> 141.93, 141.93
% INFO    : Updated Thermal Rating: on line 40172-40197 : Rate B, Rate C - 0.0, 0.0 -> 159.84, 159.84
% INFO    : Updated Thermal Rating: on line 40207-40172 : Rate B, Rate C - 0.0, 0.0 -> 182.07, 182.07
% INFO    : Updated Thermal Rating: on line 40174-40257 : Rate B, Rate C - 0.0, 0.0 -> 171.6, 171.6
% INFO    : Updated Thermal Rating: on line 40176-40270 : Rate B, Rate C - 0.0, 0.0 -> 205.6, 205.6
% INFO    : Updated Thermal Rating: on line 40274-40176 : Rate B, Rate C - 0.0, 0.0 -> 197.02, 197.02
% INFO    : Updated Thermal Rating: on line 40274-40176 : Rate B, Rate C - 0.0, 0.0 -> 197.02, 197.02
% INFO    : Updated Thermal Rating: on line 40177-40205 : Rate B, Rate C - 0.0, 0.0 -> 138.53, 138.53
% INFO    : Updated Thermal Rating: on line 40245-40177 : Rate B, Rate C - 0.0, 0.0 -> 177.97, 177.97
% INFO    : Updated Thermal Rating: on line 40205-40179 : Rate B, Rate C - 0.0, 0.0 -> 243.49, 243.49
% INFO    : Updated Thermal Rating: on line 40255-40179 : Rate B, Rate C - 0.0, 0.0 -> 174.24, 174.24
% INFO    : Updated Thermal Rating: on line 40180-40289 : Rate B, Rate C - 0.0, 0.0 -> 111.68, 111.68
% INFO    : Updated Thermal Rating: on line 40196-40181 : Rate B, Rate C - 0.0, 0.0 -> 178.13, 178.13
% INFO    : Updated Thermal Rating: on line 40229-40181 : Rate B, Rate C - 0.0, 0.0 -> 129.07, 129.07
% INFO    : Updated Thermal Rating: on line 40259-40181 : Rate B, Rate C - 0.0, 0.0 -> 192.87, 192.87
% INFO    : Updated Thermal Rating: on line 40259-40181 : Rate B, Rate C - 0.0, 0.0 -> 192.87, 192.87
% INFO    : Updated Thermal Rating: on line 40183-40810 : Rate B, Rate C - 0.0, 0.0 -> 194.21, 194.21
% INFO    : Updated Thermal Rating: on line 40183-40810 : Rate B, Rate C - 0.0, 0.0 -> 194.21, 194.21
% INFO    : Updated Thermal Rating: on transformer 40187-40186 : Rate B, Rate C - 0.0, 0.0 -> 1179.99, 1179.99
% INFO    : Updated Thermal Rating: on transformer 40187-40186 : Rate B, Rate C - 0.0, 0.0 -> 1179.99, 1179.99
% INFO    : Updated Thermal Rating: on transformer 40187-40186 : Rate B, Rate C - 0.0, 0.0 -> 1179.99, 1179.99
% INFO    : Updated Thermal Rating: on line 40254-40186 : Rate B, Rate C - 0.0, 0.0 -> 2222.71, 2222.71
% INFO    : Updated Thermal Rating: on line 40186-40795 : Rate B, Rate C - 0.0, 0.0 -> 2637.44, 2637.44
% INFO    : Updated Thermal Rating: on line 40186-40809 : Rate B, Rate C - 0.0, 0.0 -> 2488.2, 2488.2
% INFO    : Updated Thermal Rating: on line 40186-40967 : Rate B, Rate C - 0.0, 0.0 -> 2892.72, 2892.72
% INFO    : Updated Thermal Rating: on line 40187-40217 : Rate B, Rate C - 0.0, 0.0 -> 183.6, 183.6
% INFO    : Updated Thermal Rating: on line 40187-40220 : Rate B, Rate C - 0.0, 0.0 -> 174.22, 174.22
% INFO    : Updated Thermal Rating: on line 40224-40187 : Rate B, Rate C - 0.0, 0.0 -> 214.35, 214.35
% INFO    : Updated Thermal Rating: on line 40224-40187 : Rate B, Rate C - 0.0, 0.0 -> 214.35, 214.35
% INFO    : Updated Thermal Rating: on line 40224-40187 : Rate B, Rate C - 0.0, 0.0 -> 214.35, 214.35
% INFO    : Updated Thermal Rating: on line 40189-40190 : Rate B, Rate C - 0.0, 0.0 -> 178.53, 178.53
% INFO    : Updated Thermal Rating: on line 40189-40224 : Rate B, Rate C - 0.0, 0.0 -> 206.58, 206.58
% INFO    : Updated Thermal Rating: on line 40189-40224 : Rate B, Rate C - 0.0, 0.0 -> 206.58, 206.58
% INFO    : Updated Thermal Rating: on line 40189-40224 : Rate B, Rate C - 0.0, 0.0 -> 206.58, 206.58
% INFO    : Updated Thermal Rating: on line 40189-40245 : Rate B, Rate C - 0.0, 0.0 -> 196.76, 196.76
% INFO    : Updated Thermal Rating: on line 40189-40245 : Rate B, Rate C - 0.0, 0.0 -> 196.76, 196.76
% INFO    : Updated Thermal Rating: on line 40189-40247 : Rate B, Rate C - 0.0, 0.0 -> 169.39, 169.39
% INFO    : Updated Thermal Rating: on line 40190-40277 : Rate B, Rate C - 0.0, 0.0 -> 155.99, 155.99
% INFO    : Updated Thermal Rating: on line 40191-40207 : Rate B, Rate C - 0.0, 0.0 -> 274.88, 274.88
% INFO    : Updated Thermal Rating: on line 40191-40257 : Rate B, Rate C - 0.0, 0.0 -> 199.01, 199.01
% INFO    : Updated Thermal Rating: on line 40191-40257 : Rate B, Rate C - 0.0, 0.0 -> 199.01, 199.01
% INFO    : Updated Thermal Rating: on line 40191-40257 : Rate B, Rate C - 0.0, 0.0 -> 199.01, 199.01
% INFO    : Updated Thermal Rating: on line 40199-40193 : Rate B, Rate C - 0.0, 0.0 -> 160.52, 160.52
% INFO    : Updated Thermal Rating: on line 40193-40226 : Rate B, Rate C - 0.0, 0.0 -> 142.48, 142.48
% INFO    : Updated Thermal Rating: on line 40194-40473 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40716-40194 : Rate B, Rate C - 0.0, 0.0 -> 178.42, 178.42
% INFO    : Updated Thermal Rating: on line 40231-40196 : Rate B, Rate C - 0.0, 0.0 -> 160.0, 160.0
% INFO    : Updated Thermal Rating: on line 40271-40197 : Rate B, Rate C - 0.0, 0.0 -> 139.97, 139.97
% INFO    : Updated Thermal Rating: on line 40261-40198 : Rate B, Rate C - 0.0, 0.0 -> 173.1, 173.1
% INFO    : Updated Thermal Rating: on line 40199-40255 : Rate B, Rate C - 0.0, 0.0 -> 189.93, 189.93
% INFO    : Updated Thermal Rating: on line 40199-40255 : Rate B, Rate C - 0.0, 0.0 -> 189.93, 189.93
% INFO    : Updated Thermal Rating: on transformer 40201-40204 : Rate B, Rate C - 0.0, 0.0 -> 177.93, 177.93
% INFO    : Updated Thermal Rating: on transformer 40202-40204 : Rate B, Rate C - 0.0, 0.0 -> 120.0, 120.0
% INFO    : Updated Thermal Rating: on transformer 40203-40204 : Rate B, Rate C - 0.0, 0.0 -> 88.97, 88.97
% INFO    : Updated Thermal Rating: on line 40206-40250 : Rate B, Rate C - 0.0, 0.0 -> 158.53, 158.53
% INFO    : Updated Thermal Rating: on line 40299-40206 : Rate B, Rate C - 0.0, 0.0 -> 193.49, 193.49
% INFO    : Updated Thermal Rating: on line 40299-40206 : Rate B, Rate C - 0.0, 0.0 -> 193.49, 193.49
% INFO    : Updated Thermal Rating: on line 40224-40209 : Rate B, Rate C - 0.0, 0.0 -> 181.6, 181.6
% INFO    : Updated Thermal Rating: on line 40210-40247 : Rate B, Rate C - 0.0, 0.0 -> 154.1, 154.1
% INFO    : Updated Thermal Rating: on line 40228-40211 : Rate B, Rate C - 0.0, 0.0 -> 173.23, 173.23
% INFO    : Updated Thermal Rating: on line 40211-40261 : Rate B, Rate C - 0.0, 0.0 -> 185.41, 185.41
% INFO    : Updated Thermal Rating: on line 40213-40250 : Rate B, Rate C - 0.0, 0.0 -> 170.85, 170.85
% INFO    : Updated Thermal Rating: on line 40257-40213 : Rate B, Rate C - 0.0, 0.0 -> 180.93, 180.93
% INFO    : Updated Thermal Rating: on transformer 40215-40214 : Rate B, Rate C - 0.0, 0.0 -> 963.0, 963.0
% INFO    : Updated Thermal Rating: on line 40298-40214 : Rate B, Rate C - 0.0, 0.0 -> 2323.95, 2323.95
% INFO    : Updated Thermal Rating: on line 40335-40214 : Rate B, Rate C - 0.0, 0.0 -> 2463.37, 2463.37
% INFO    : Updated Thermal Rating: on line 40214-40795 : Rate B, Rate C - 0.0, 0.0 -> 2783.99, 2783.99
% INFO    : Updated Thermal Rating: on line 40222-40215 : Rate B, Rate C - 0.0, 0.0 -> 194.05, 194.05
% INFO    : Updated Thermal Rating: on line 40222-40215 : Rate B, Rate C - 0.0, 0.0 -> 194.05, 194.05
% INFO    : Updated Thermal Rating: on line 40215-40241 : Rate B, Rate C - 0.0, 0.0 -> 182.82, 182.82
% INFO    : Updated Thermal Rating: on line 40215-40280 : Rate B, Rate C - 0.0, 0.0 -> 205.0, 205.0
% INFO    : Updated Thermal Rating: on line 40215-40310 : Rate B, Rate C - 0.0, 0.0 -> 251.83, 251.83
% INFO    : Updated Thermal Rating: on line 40216-40250 : Rate B, Rate C - 0.0, 0.0 -> 139.11, 139.11
% INFO    : Updated Thermal Rating: on line 40216-40299 : Rate B, Rate C - 0.0, 0.0 -> 178.28, 178.28
% INFO    : Updated Thermal Rating: on line 40220-40217 : Rate B, Rate C - 0.0, 0.0 -> 197.23, 197.23
% INFO    : Updated Thermal Rating: on line 40220-40217 : Rate B, Rate C - 0.0, 0.0 -> 197.23, 197.23
% INFO    : Updated Thermal Rating: on line 40217-40231 : Rate B, Rate C - 0.0, 0.0 -> 176.41, 176.41
% INFO    : Updated Thermal Rating: on line 40217-40238 : Rate B, Rate C - 0.0, 0.0 -> 272.34, 272.34
% INFO    : Updated Thermal Rating: on line 40220-40279 : Rate B, Rate C - 0.0, 0.0 -> 177.33, 177.33
% INFO    : Updated Thermal Rating: on line 40231-40221 : Rate B, Rate C - 0.0, 0.0 -> 157.78, 157.78
% INFO    : Updated Thermal Rating: on line 40240-40221 : Rate B, Rate C - 0.0, 0.0 -> 121.29, 121.29
% INFO    : Updated Thermal Rating: on line 40221-40241 : Rate B, Rate C - 0.0, 0.0 -> 164.55, 164.55
% INFO    : Updated Thermal Rating: on line 40221-40297 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40225-40222 : Rate B, Rate C - 0.0, 0.0 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on line 40247-40223 : Rate B, Rate C - 0.0, 0.0 -> 205.74, 205.74
% INFO    : Updated Thermal Rating: on line 40223-40255 : Rate B, Rate C - 0.0, 0.0 -> 193.06, 193.06
% INFO    : Updated Thermal Rating: on line 40223-40255 : Rate B, Rate C - 0.0, 0.0 -> 193.06, 193.06
% INFO    : Updated Thermal Rating: on line 40223-40282 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 40223-40322 : Rate B, Rate C - 0.0, 0.0 -> 163.24, 163.24
% INFO    : Updated Thermal Rating: on line 40266-40225 : Rate B, Rate C - 0.0, 0.0 -> 148.4, 148.4
% INFO    : Updated Thermal Rating: on line 40225-40267 : Rate B, Rate C - 0.0, 0.0 -> 203.3, 203.3
% INFO    : Updated Thermal Rating: on line 40305-40226 : Rate B, Rate C - 0.0, 0.0 -> 153.36, 153.36
% INFO    : Updated Thermal Rating: on line 40226-40322 : Rate B, Rate C - 0.0, 0.0 -> 119.63, 119.63
% INFO    : Updated Thermal Rating: on line 40227-40796 : Rate B, Rate C - 0.0, 0.0 -> 173.58, 173.58
% INFO    : Updated Thermal Rating: on line 40719-40228 : Rate B, Rate C - 0.0, 0.0 -> 170.03, 170.03
% INFO    : Updated Thermal Rating: on line 40233-40231 : Rate B, Rate C - 0.0, 0.0 -> 138.61, 138.61
% INFO    : Updated Thermal Rating: on line 40274-40234 : Rate B, Rate C - 0.0, 0.0 -> 148.95, 148.95
% INFO    : Updated Thermal Rating: on line 40311-40236 : Rate B, Rate C - 0.0, 0.0 -> 277.85, 277.85
% INFO    : Updated Thermal Rating: on line 40236-40316 : Rate B, Rate C - 0.0, 0.0 -> 137.66, 137.66
% INFO    : Updated Thermal Rating: on line 40236-40318 : Rate B, Rate C - 0.0, 0.0 -> 143.93, 143.93
% INFO    : Updated Thermal Rating: on line 40236-40738 : Rate B, Rate C - 0.0, 0.0 -> 199.84, 199.84
% INFO    : Updated Thermal Rating: on line 40236-40738 : Rate B, Rate C - 0.0, 0.0 -> 199.84, 199.84
% INFO    : Updated Thermal Rating: on line 40236-40738 : Rate B, Rate C - 0.0, 0.0 -> 199.84, 199.84
% INFO    : Updated Thermal Rating: on line 40238-40277 : Rate B, Rate C - 0.0, 0.0 -> 147.07, 147.07
% INFO    : Updated Thermal Rating: on line 40238-40284 : Rate B, Rate C - 0.0, 0.0 -> 130.97, 130.97
% INFO    : Updated Thermal Rating: on line 40240-40250 : Rate B, Rate C - 0.0, 0.0 -> 167.83, 167.83
% INFO    : Updated Thermal Rating: on line 40244-40300 : Rate B, Rate C - 0.0, 0.0 -> 166.37, 166.37
% INFO    : Updated Thermal Rating: on line 40244-40738 : Rate B, Rate C - 0.0, 0.0 -> 183.25, 183.25
% INFO    : Updated Thermal Rating: on line 40247-40284 : Rate B, Rate C - 0.0, 0.0 -> 155.02, 155.02
% INFO    : Updated Thermal Rating: on line 40331-40248 : Rate B, Rate C - 0.0, 0.0 -> 132.25, 132.25
% INFO    : Updated Thermal Rating: on line 40253-40299 : Rate B, Rate C - 0.0, 0.0 -> 195.66, 195.66
% INFO    : Updated Thermal Rating: on line 40253-40299 : Rate B, Rate C - 0.0, 0.0 -> 195.66, 195.66
% INFO    : Updated Thermal Rating: on line 40253-40308 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 40255-40254 : Rate B, Rate C - 0.0, 0.0 -> 930.43, 930.43
% INFO    : Updated Thermal Rating: on line 40254-40260 : Rate B, Rate C - 0.0, 0.0 -> 2878.89, 2878.89
% INFO    : Updated Thermal Rating: on line 40255-40305 : Rate B, Rate C - 0.0, 0.0 -> 181.35, 181.35
% INFO    : Updated Thermal Rating: on line 40259-40796 : Rate B, Rate C - 0.0, 0.0 -> 200.68, 200.68
% INFO    : Updated Thermal Rating: on line 40259-40796 : Rate B, Rate C - 0.0, 0.0 -> 200.68, 200.68
% INFO    : Updated Thermal Rating: on line 40259-40796 : Rate B, Rate C - 0.0, 0.0 -> 200.68, 200.68
% INFO    : Updated Thermal Rating: on transformer 40260-40263 : Rate B, Rate C - 0.0, 0.0 -> 1207.62, 1207.62
% INFO    : Updated Thermal Rating: on line 40260-40428 : Rate B, Rate C - 0.0, 0.0 -> 2961.12, 2961.12
% INFO    : Updated Thermal Rating: on line 40715-40260 : Rate B, Rate C - 0.0, 0.0 -> 2911.25, 2911.25
% INFO    : Updated Thermal Rating: on line 40260-40752 : Rate B, Rate C - 0.0, 0.0 -> 2118.51, 2118.51
% INFO    : Updated Thermal Rating: on transformer 40261-40263 : Rate B, Rate C - 0.0, 0.0 -> 966.58, 966.58
% INFO    : Updated Thermal Rating: on line 40261-40386 : Rate B, Rate C - 0.0, 0.0 -> 153.57, 153.57
% INFO    : Updated Thermal Rating: on line 40261-40392 : Rate B, Rate C - 0.0, 0.0 -> 170.44, 170.44
% INFO    : Updated Thermal Rating: on line 40261-40422 : Rate B, Rate C - 0.0, 0.0 -> 159.74, 159.74
% INFO    : Updated Thermal Rating: on line 40261-41015 : Rate B, Rate C - 0.0, 0.0 -> 166.91, 166.91
% INFO    : Updated Thermal Rating: on transformer 40262-40263 : Rate B, Rate C - 0.0, 0.0 -> 241.04, 241.04
% INFO    : Updated Thermal Rating: on line 40264-40465 : Rate B, Rate C - 0.0, 0.0 -> 145.31, 145.31
% INFO    : Updated Thermal Rating: on line 40264-40468 : Rate B, Rate C - 0.0, 0.0 -> 153.0, 153.0
% INFO    : Updated Thermal Rating: on line 40271-40266 : Rate B, Rate C - 0.0, 0.0 -> 140.03, 140.03
% INFO    : Updated Thermal Rating: on line 40266-40299 : Rate B, Rate C - 0.0, 0.0 -> 170.6, 170.6
% INFO    : Updated Thermal Rating: on line 40300-40267 : Rate B, Rate C - 0.0, 0.0 -> 234.31, 234.31
% INFO    : Updated Thermal Rating: on line 40267-40302 : Rate B, Rate C - 0.0, 0.0 -> 157.04, 157.04
% INFO    : Updated Thermal Rating: on line 40270-40272 : Rate B, Rate C - 0.0, 0.0 -> 150.76, 150.76
% INFO    : Updated Thermal Rating: on line 40270-40311 : Rate B, Rate C - 0.0, 0.0 -> 131.91, 131.91
% INFO    : Updated Thermal Rating: on line 40271-40299 : Rate B, Rate C - 0.0, 0.0 -> 186.2, 186.2
% INFO    : Updated Thermal Rating: on line 40311-40272 : Rate B, Rate C - 0.0, 0.0 -> 150.1, 150.1
% INFO    : Updated Thermal Rating: on transformer 40273-40276 : Rate B, Rate C - 0.0, 0.0 -> 931.57, 931.57
% INFO    : Updated Thermal Rating: on transformer 40274-40276 : Rate B, Rate C - 0.0, 0.0 -> 881.57, 881.57
% INFO    : Updated Thermal Rating: on line 40274-40289 : Rate B, Rate C - 0.0, 0.0 -> 166.74, 166.74
% INFO    : Updated Thermal Rating: on line 40274-40343 : Rate B, Rate C - 0.0, 0.0 -> 181.0, 181.0
% INFO    : Updated Thermal Rating: on transformer 40275-40276 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 40290-40280 : Rate B, Rate C - 0.0, 0.0 -> 143.75, 143.75
% INFO    : Updated Thermal Rating: on line 40282-40320 : Rate B, Rate C - 0.0, 0.0 -> 179.02, 179.02
% INFO    : Updated Thermal Rating: on line 40336-40282 : Rate B, Rate C - 0.0, 0.0 -> 192.83, 192.83
% INFO    : Updated Thermal Rating: on line 40336-40282 : Rate B, Rate C - 0.0, 0.0 -> 192.83, 192.83
% INFO    : Updated Thermal Rating: on line 40286-40474 : Rate B, Rate C - 0.0, 0.0 -> 143.3, 143.3
% INFO    : Updated Thermal Rating: on line 40287-40350 : Rate B, Rate C - 0.0, 0.0 -> 151.22, 151.22
% INFO    : Updated Thermal Rating: on line 40867-40287 : Rate B, Rate C - 0.0, 0.0 -> 181.95, 181.95
% INFO    : Updated Thermal Rating: on line 40290-40303 : Rate B, Rate C - 0.0, 0.0 -> 144.84, 144.84
% INFO    : Updated Thermal Rating: on line 40321-40290 : Rate B, Rate C - 0.0, 0.0 -> 151.08, 151.08
% INFO    : Updated Thermal Rating: on line 40290-40359 : Rate B, Rate C - 0.0, 0.0 -> 181.43, 181.43
% INFO    : Updated Thermal Rating: on transformer 40292-40295 : Rate B, Rate C - 0.0, 0.0 -> 72.83, 72.83
% INFO    : Updated Thermal Rating: on transformer 40293-40295 : Rate B, Rate C - 0.0, 0.0 -> 36.42, 36.42
% INFO    : Updated Thermal Rating: on transformer 40294-40295 : Rate B, Rate C - 0.0, 0.0 -> 36.42, 36.42
% INFO    : Updated Thermal Rating: on line 40297-40303 : Rate B, Rate C - 0.0, 0.0 -> 144.32, 144.32
% INFO    : Updated Thermal Rating: on transformer 40299-40298 : Rate B, Rate C - 0.0, 0.0 -> 1044.8, 1044.8
% INFO    : Updated Thermal Rating: on line 40940-40302 : Rate B, Rate C - 0.0, 0.0 -> 182.47, 182.47
% INFO    : Updated Thermal Rating: on line 40303-40336 : Rate B, Rate C - 0.0, 0.0 -> 191.43, 191.43
% INFO    : Updated Thermal Rating: on line 40304-40336 : Rate B, Rate C - 0.0, 0.0 -> 182.46, 182.46
% INFO    : Updated Thermal Rating: on line 40372-40304 : Rate B, Rate C - 0.0, 0.0 -> 162.05, 162.05
% INFO    : Updated Thermal Rating: on line 40304-40403 : Rate B, Rate C - 0.0, 0.0 -> 172.54, 172.54
% INFO    : Updated Thermal Rating: on line 40305-40331 : Rate B, Rate C - 0.0, 0.0 -> 156.94, 156.94
% INFO    : Updated Thermal Rating: on line 40307-40345 : Rate B, Rate C - 0.0, 0.0 -> 185.0, 185.0
% INFO    : Updated Thermal Rating: on line 40362-40307 : Rate B, Rate C - 0.0, 0.0 -> 174.59, 174.59
% INFO    : Updated Thermal Rating: on line 40308-40321 : Rate B, Rate C - 0.0, 0.0 -> 193.38, 193.38
% INFO    : Updated Thermal Rating: on line 40708-40308 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 40310-40324 : Rate B, Rate C - 0.0, 0.0 -> 153.21, 153.21
% INFO    : Updated Thermal Rating: on line 40313-40324 : Rate B, Rate C - 0.0, 0.0 -> 202.95, 202.95
% INFO    : Updated Thermal Rating: on line 40313-40324 : Rate B, Rate C - 0.0, 0.0 -> 202.95, 202.95
% INFO    : Updated Thermal Rating: on line 40313-40324 : Rate B, Rate C - 0.0, 0.0 -> 202.95, 202.95
% INFO    : Updated Thermal Rating: on line 40346-40313 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 40738-40316 : Rate B, Rate C - 0.0, 0.0 -> 166.06, 166.06
% INFO    : Updated Thermal Rating: on line 40738-40318 : Rate B, Rate C - 0.0, 0.0 -> 163.88, 163.88
% INFO    : Updated Thermal Rating: on line 40320-40340 : Rate B, Rate C - 0.0, 0.0 -> 147.74, 147.74
% INFO    : Updated Thermal Rating: on line 40321-40340 : Rate B, Rate C - 0.0, 0.0 -> 155.97, 155.97
% INFO    : Updated Thermal Rating: on line 40321-40376 : Rate B, Rate C - 0.0, 0.0 -> 147.84, 147.84
% INFO    : Updated Thermal Rating: on line 40322-40327 : Rate B, Rate C - 0.0, 0.0 -> 132.36, 132.36
% INFO    : Updated Thermal Rating: on line 40324-40864 : Rate B, Rate C - 0.0, 0.0 -> 210.48, 210.48
% INFO    : Updated Thermal Rating: on line 40324-40864 : Rate B, Rate C - 0.0, 0.0 -> 210.48, 210.48
% INFO    : Updated Thermal Rating: on line 40324-40864 : Rate B, Rate C - 0.0, 0.0 -> 210.48, 210.48
% INFO    : Updated Thermal Rating: on line 40325-40340 : Rate B, Rate C - 0.0, 0.0 -> 149.14, 149.14
% INFO    : Updated Thermal Rating: on line 40346-40325 : Rate B, Rate C - 0.0, 0.0 -> 158.39, 158.39
% INFO    : Updated Thermal Rating: on line 40331-40332 : Rate B, Rate C - 0.0, 0.0 -> 135.85, 135.85
% INFO    : Updated Thermal Rating: on line 40332-40455 : Rate B, Rate C - 0.0, 0.0 -> 169.73, 169.73
% INFO    : Updated Thermal Rating: on line 40354-40334 : Rate B, Rate C - 0.0, 0.0 -> 146.97, 146.97
% INFO    : Updated Thermal Rating: on line 40392-40334 : Rate B, Rate C - 0.0, 0.0 -> 168.18, 168.18
% INFO    : Updated Thermal Rating: on line 40334-40455 : Rate B, Rate C - 0.0, 0.0 -> 172.19, 172.19
% INFO    : Updated Thermal Rating: on transformer 40335-40338 : Rate B, Rate C - 0.0, 0.0 -> 1191.18, 1191.18
% INFO    : Updated Thermal Rating: on line 40382-40335 : Rate B, Rate C - 0.0, 0.0 -> 2491.44, 2491.44
% INFO    : Updated Thermal Rating: on line 40335-40809 : Rate B, Rate C - 0.0, 0.0 -> 2411.29, 2411.29
% INFO    : Updated Thermal Rating: on transformer 40336-40338 : Rate B, Rate C - 0.0, 0.0 -> 1066.18, 1066.18
% INFO    : Updated Thermal Rating: on line 40341-40336 : Rate B, Rate C - 0.0, 0.0 -> 181.03, 181.03
% INFO    : Updated Thermal Rating: on line 40359-40336 : Rate B, Rate C - 0.0, 0.0 -> 175.72, 175.72
% INFO    : Updated Thermal Rating: on line 40372-40336 : Rate B, Rate C - 0.0, 0.0 -> 189.49, 189.49
% INFO    : Updated Thermal Rating: on line 40336-40381 : Rate B, Rate C - 0.0, 0.0 -> 171.82, 171.82
% INFO    : Updated Thermal Rating: on transformer 40337-40338 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 40359-40341 : Rate B, Rate C - 0.0, 0.0 -> 150.7, 150.7
% INFO    : Updated Thermal Rating: on line 40376-40342 : Rate B, Rate C - 0.0, 0.0 -> 163.95, 163.95
% INFO    : Updated Thermal Rating: on line 40342-40383 : Rate B, Rate C - 0.0, 0.0 -> 186.57, 186.57
% INFO    : Updated Thermal Rating: on line 40343-40352 : Rate B, Rate C - 0.0, 0.0 -> 138.53, 138.53
% INFO    : Updated Thermal Rating: on line 40344-40369 : Rate B, Rate C - 0.0, 0.0 -> 186.99, 186.99
% INFO    : Updated Thermal Rating: on line 40344-40389 : Rate B, Rate C - 0.0, 0.0 -> 155.35, 155.35
% INFO    : Updated Thermal Rating: on line 40390-40345 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40404-40345 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 40346-40380 : Rate B, Rate C - 0.0, 0.0 -> 150.12, 150.12
% INFO    : Updated Thermal Rating: on line 40402-40350 : Rate B, Rate C - 0.0, 0.0 -> 172.72, 172.72
% INFO    : Updated Thermal Rating: on line 40350-40411 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40352-40404 : Rate B, Rate C - 0.0, 0.0 -> 178.44, 178.44
% INFO    : Updated Thermal Rating: on line 40352-40738 : Rate B, Rate C - 0.0, 0.0 -> 190.5, 190.5
% INFO    : Updated Thermal Rating: on line 40352-40738 : Rate B, Rate C - 0.0, 0.0 -> 190.5, 190.5
% INFO    : Updated Thermal Rating: on line 40424-40354 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40356-40367 : Rate B, Rate C - 0.0, 0.0 -> 194.08, 194.08
% INFO    : Updated Thermal Rating: on line 40356-40367 : Rate B, Rate C - 0.0, 0.0 -> 194.08, 194.08
% INFO    : Updated Thermal Rating: on line 40900-40356 : Rate B, Rate C - 0.0, 0.0 -> 201.44, 201.44
% INFO    : Updated Thermal Rating: on line 40900-40356 : Rate B, Rate C - 0.0, 0.0 -> 201.44, 201.44
% INFO    : Updated Thermal Rating: on line 40900-40356 : Rate B, Rate C - 0.0, 0.0 -> 201.44, 201.44
% INFO    : Updated Thermal Rating: on line 40390-40358 : Rate B, Rate C - 0.0, 0.0 -> 154.0, 154.0
% INFO    : Updated Thermal Rating: on line 40358-40395 : Rate B, Rate C - 0.0, 0.0 -> 173.3, 173.3
% INFO    : Updated Thermal Rating: on line 40358-40405 : Rate B, Rate C - 0.0, 0.0 -> 237.53, 237.53
% INFO    : Updated Thermal Rating: on line 40360-40383 : Rate B, Rate C - 0.0, 0.0 -> 189.84, 189.84
% INFO    : Updated Thermal Rating: on line 40395-40360 : Rate B, Rate C - 0.0, 0.0 -> 169.06, 169.06
% INFO    : Updated Thermal Rating: on line 40362-40378 : Rate B, Rate C - 0.0, 0.0 -> 139.1, 139.1
% INFO    : Updated Thermal Rating: on line 40940-40362 : Rate B, Rate C - 0.0, 0.0 -> 189.78, 189.78
% INFO    : Updated Thermal Rating: on line 40363-40369 : Rate B, Rate C - 0.0, 0.0 -> 190.55, 190.55
% INFO    : Updated Thermal Rating: on line 40363-40369 : Rate B, Rate C - 0.0, 0.0 -> 190.55, 190.55
% INFO    : Updated Thermal Rating: on line 40387-40363 : Rate B, Rate C - 0.0, 0.0 -> 161.39, 161.39
% INFO    : Updated Thermal Rating: on line 40366-40369 : Rate B, Rate C - 0.0, 0.0 -> 158.07, 158.07
% INFO    : Updated Thermal Rating: on line 40366-40369 : Rate B, Rate C - 0.0, 0.0 -> 158.07, 158.07
% INFO    : Updated Thermal Rating: on line 40366-40900 : Rate B, Rate C - 0.0, 0.0 -> 143.33, 143.33
% INFO    : Updated Thermal Rating: on line 40366-40900 : Rate B, Rate C - 0.0, 0.0 -> 143.33, 143.33
% INFO    : Updated Thermal Rating: on line 40367-40405 : Rate B, Rate C - 0.0, 0.0 -> 147.68, 147.68
% INFO    : Updated Thermal Rating: on line 40367-40410 : Rate B, Rate C - 0.0, 0.0 -> 130.56, 130.56
% INFO    : Updated Thermal Rating: on transformer 40368-40371 : Rate B, Rate C - 0.0, 0.0 -> 1112.81, 1112.81
% INFO    : Updated Thermal Rating: on line 40368-40866 : Rate B, Rate C - 0.0, 0.0 -> 2312.83, 2312.83
% INFO    : Updated Thermal Rating: on line 40368-40899 : Rate B, Rate C - 0.0, 0.0 -> 2720.75, 2720.75
% INFO    : Updated Thermal Rating: on transformer 40369-40371 : Rate B, Rate C - 0.0, 0.0 -> 1012.81, 1012.81
% INFO    : Updated Thermal Rating: on line 40369-40406 : Rate B, Rate C - 0.0, 0.0 -> 207.62, 207.62
% INFO    : Updated Thermal Rating: on line 40411-40369 : Rate B, Rate C - 0.0, 0.0 -> 159.68, 159.68
% INFO    : Updated Thermal Rating: on line 40369-40434 : Rate B, Rate C - 0.0, 0.0 -> 168.46, 168.46
% INFO    : Updated Thermal Rating: on transformer 40370-40371 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 40376-40403 : Rate B, Rate C - 0.0, 0.0 -> 137.42, 137.42
% INFO    : Updated Thermal Rating: on line 40377-40421 : Rate B, Rate C - 0.0, 0.0 -> 140.19, 140.19
% INFO    : Updated Thermal Rating: on line 40377-40867 : Rate B, Rate C - 0.0, 0.0 -> 156.0, 156.0
% INFO    : Updated Thermal Rating: on line 40378-40384 : Rate B, Rate C - 0.0, 0.0 -> 178.12, 178.12
% INFO    : Updated Thermal Rating: on line 40397-40379 : Rate B, Rate C - 0.0, 0.0 -> 170.33, 170.33
% INFO    : Updated Thermal Rating: on line 40379-40453 : Rate B, Rate C - 0.0, 0.0 -> 119.5, 119.5
% INFO    : Updated Thermal Rating: on line 40403-40380 : Rate B, Rate C - 0.0, 0.0 -> 157.62, 157.62
% INFO    : Updated Thermal Rating: on line 40381-40403 : Rate B, Rate C - 0.0, 0.0 -> 149.34, 149.34
% INFO    : Updated Thermal Rating: on transformer 40383-40382 : Rate B, Rate C - 0.0, 0.0 -> 1110.72, 1110.72
% INFO    : Updated Thermal Rating: on line 40382-40439 : Rate B, Rate C - 0.0, 0.0 -> 2655.92, 2655.92
% INFO    : Updated Thermal Rating: on line 40899-40382 : Rate B, Rate C - 0.0, 0.0 -> 2882.29, 2882.29
% INFO    : Updated Thermal Rating: on line 40383-40390 : Rate B, Rate C - 0.0, 0.0 -> 180.08, 180.08
% INFO    : Updated Thermal Rating: on line 40383-40397 : Rate B, Rate C - 0.0, 0.0 -> 206.99, 206.99
% INFO    : Updated Thermal Rating: on line 40383-40397 : Rate B, Rate C - 0.0, 0.0 -> 206.99, 206.99
% INFO    : Updated Thermal Rating: on line 40383-40397 : Rate B, Rate C - 0.0, 0.0 -> 206.99, 206.99
% INFO    : Updated Thermal Rating: on line 40418-40383 : Rate B, Rate C - 0.0, 0.0 -> 190.63, 190.63
% INFO    : Updated Thermal Rating: on line 40384-40940 : Rate B, Rate C - 0.0, 0.0 -> 193.72, 193.72
% INFO    : Updated Thermal Rating: on line 40386-40422 : Rate B, Rate C - 0.0, 0.0 -> 124.78, 124.78
% INFO    : Updated Thermal Rating: on line 40406-40387 : Rate B, Rate C - 0.0, 0.0 -> 162.77, 162.77
% INFO    : Updated Thermal Rating: on line 40387-40412 : Rate B, Rate C - 0.0, 0.0 -> 154.17, 154.17
% INFO    : Updated Thermal Rating: on line 40389-40410 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40414-40391 : Rate B, Rate C - 0.0, 0.0 -> 161.33, 161.33
% INFO    : Updated Thermal Rating: on line 40900-40391 : Rate B, Rate C - 0.0, 0.0 -> 195.22, 195.22
% INFO    : Updated Thermal Rating: on line 40900-40391 : Rate B, Rate C - 0.0, 0.0 -> 195.22, 195.22
% INFO    : Updated Thermal Rating: on line 40422-40392 : Rate B, Rate C - 0.0, 0.0 -> 140.18, 140.18
% INFO    : Updated Thermal Rating: on line 40418-40395 : Rate B, Rate C - 0.0, 0.0 -> 170.03, 170.03
% INFO    : Updated Thermal Rating: on line 40397-40407 : Rate B, Rate C - 0.0, 0.0 -> 293.43, 293.43
% INFO    : Updated Thermal Rating: on line 40398-40443 : Rate B, Rate C - 0.0, 0.0 -> 147.16, 147.16
% INFO    : Updated Thermal Rating: on line 40398-40891 : Rate B, Rate C - 0.0, 0.0 -> 167.38, 167.38
% INFO    : Updated Thermal Rating: on line 40443-40402 : Rate B, Rate C - 0.0, 0.0 -> 156.29, 156.29
% INFO    : Updated Thermal Rating: on line 40891-40402 : Rate B, Rate C - 0.0, 0.0 -> 190.16, 190.16
% INFO    : Updated Thermal Rating: on line 40891-40402 : Rate B, Rate C - 0.0, 0.0 -> 190.16, 190.16
% INFO    : Updated Thermal Rating: on line 40405-40900 : Rate B, Rate C - 0.0, 0.0 -> 175.44, 175.44
% INFO    : Updated Thermal Rating: on line 40407-40415 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 40407-40437 : Rate B, Rate C - 0.0, 0.0 -> 152.18, 152.18
% INFO    : Updated Thermal Rating: on line 40419-40409 : Rate B, Rate C - 0.0, 0.0 -> 185.94, 185.94
% INFO    : Updated Thermal Rating: on line 40409-40440 : Rate B, Rate C - 0.0, 0.0 -> 205.12, 205.12
% INFO    : Updated Thermal Rating: on line 40409-40440 : Rate B, Rate C - 0.0, 0.0 -> 205.12, 205.12
% INFO    : Updated Thermal Rating: on line 40409-40440 : Rate B, Rate C - 0.0, 0.0 -> 205.12, 205.12
% INFO    : Updated Thermal Rating: on line 40458-40409 : Rate B, Rate C - 0.0, 0.0 -> 159.49, 159.49
% INFO    : Updated Thermal Rating: on line 40410-40433 : Rate B, Rate C - 0.0, 0.0 -> 203.8, 203.8
% INFO    : Updated Thermal Rating: on line 40410-40900 : Rate B, Rate C - 0.0, 0.0 -> 290.3, 290.3
% INFO    : Updated Thermal Rating: on line 40411-40434 : Rate B, Rate C - 0.0, 0.0 -> 177.78, 177.78
% INFO    : Updated Thermal Rating: on line 40414-40412 : Rate B, Rate C - 0.0, 0.0 -> 161.0, 161.0
% INFO    : Updated Thermal Rating: on line 40442-40412 : Rate B, Rate C - 0.0, 0.0 -> 151.59, 151.59
% INFO    : Updated Thermal Rating: on line 40442-40412 : Rate B, Rate C - 0.0, 0.0 -> 151.59, 151.59
% INFO    : Updated Thermal Rating: on line 40807-40412 : Rate B, Rate C - 0.0, 0.0 -> 160.99, 160.99
% INFO    : Updated Thermal Rating: on line 40413-40431 : Rate B, Rate C - 0.0, 0.0 -> 158.76, 158.76
% INFO    : Updated Thermal Rating: on line 40413-40440 : Rate B, Rate C - 0.0, 0.0 -> 178.9, 178.9
% INFO    : Updated Thermal Rating: on line 40414-40415 : Rate B, Rate C - 0.0, 0.0 -> 174.31, 174.31
% INFO    : Updated Thermal Rating: on line 40415-40431 : Rate B, Rate C - 0.0, 0.0 -> 160.53, 160.53
% INFO    : Updated Thermal Rating: on line 40440-40417 : Rate B, Rate C - 0.0, 0.0 -> 176.65, 176.65
% INFO    : Updated Thermal Rating: on line 40417-40447 : Rate B, Rate C - 0.0, 0.0 -> 133.73, 133.73
% INFO    : Updated Thermal Rating: on line 40431-40419 : Rate B, Rate C - 0.0, 0.0 -> 126.57, 126.57
% INFO    : Updated Thermal Rating: on line 40437-40419 : Rate B, Rate C - 0.0, 0.0 -> 158.25, 158.25
% INFO    : Updated Thermal Rating: on line 40456-40421 : Rate B, Rate C - 0.0, 0.0 -> 145.08, 145.08
% INFO    : Updated Thermal Rating: on line 40421-40459 : Rate B, Rate C - 0.0, 0.0 -> 157.36, 157.36
% INFO    : Updated Thermal Rating: on line 40429-40424 : Rate B, Rate C - 0.0, 0.0 -> 197.54, 197.54
% INFO    : Updated Thermal Rating: on line 40426-40429 : Rate B, Rate C - 0.0, 0.0 -> 171.96, 171.96
% INFO    : Updated Thermal Rating: on line 40426-40472 : Rate B, Rate C - 0.0, 0.0 -> 130.79, 130.79
% INFO    : Updated Thermal Rating: on transformer 40429-40428 : Rate B, Rate C - 0.0, 0.0 -> 814.45, 814.45
% INFO    : Updated Thermal Rating: on transformer 40429-40428 : Rate B, Rate C - 0.0, 0.0 -> 814.45, 814.45
% INFO    : Updated Thermal Rating: on line 40930-40428 : Rate B, Rate C - 0.0, 0.0 -> 3286.04, 3286.04
% INFO    : Updated Thermal Rating: on line 40429-40473 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 40431-40433 : Rate B, Rate C - 0.0, 0.0 -> 167.86, 167.86
% INFO    : Updated Thermal Rating: on line 40433-40440 : Rate B, Rate C - 0.0, 0.0 -> 187.29, 187.29
% INFO    : Updated Thermal Rating: on line 40436-40434 : Rate B, Rate C - 0.0, 0.0 -> 168.61, 168.61
% INFO    : Updated Thermal Rating: on line 40436-40462 : Rate B, Rate C - 0.0, 0.0 -> 140.78, 140.78
% INFO    : Updated Thermal Rating: on transformer 40440-40439 : Rate B, Rate C - 0.0, 0.0 -> 995.32, 995.32
% INFO    : Updated Thermal Rating: on line 40439-40947 : Rate B, Rate C - 0.0, 0.0 -> 2986.74, 2986.74
% INFO    : Updated Thermal Rating: on line 40955-40439 : Rate B, Rate C - 0.0, 0.0 -> 2460.23, 2460.23
% INFO    : Updated Thermal Rating: on line 40442-40477 : Rate B, Rate C - 0.0, 0.0 -> 161.14, 161.14
% INFO    : Updated Thermal Rating: on transformer 40443-40446 : Rate B, Rate C - 0.0, 0.0 -> 122.01, 122.01
% INFO    : Updated Thermal Rating: on line 40443-40867 : Rate B, Rate C - 0.0, 0.0 -> 261.6, 261.6
% INFO    : Updated Thermal Rating: on transformer 40444-40446 : Rate B, Rate C - 0.0, 0.0 -> 61.01, 61.01
% INFO    : Updated Thermal Rating: on transformer 40445-40446 : Rate B, Rate C - 0.0, 0.0 -> 61.01, 61.01
% INFO    : Updated Thermal Rating: on line 40450-40447 : Rate B, Rate C - 0.0, 0.0 -> 172.93, 172.93
% INFO    : Updated Thermal Rating: on line 40454-40448 : Rate B, Rate C - 0.0, 0.0 -> 174.85, 174.85
% INFO    : Updated Thermal Rating: on line 40448-40458 : Rate B, Rate C - 0.0, 0.0 -> 138.69, 138.69
% INFO    : Updated Thermal Rating: on line 40454-40450 : Rate B, Rate C - 0.0, 0.0 -> 198.64, 198.64
% INFO    : Updated Thermal Rating: on line 40454-40450 : Rate B, Rate C - 0.0, 0.0 -> 198.64, 198.64
% INFO    : Updated Thermal Rating: on line 40450-40464 : Rate B, Rate C - 0.0, 0.0 -> 210.7, 210.7
% INFO    : Updated Thermal Rating: on line 40450-40464 : Rate B, Rate C - 0.0, 0.0 -> 210.7, 210.7
% INFO    : Updated Thermal Rating: on line 40450-40464 : Rate B, Rate C - 0.0, 0.0 -> 210.7, 210.7
% INFO    : Updated Thermal Rating: on line 40454-40453 : Rate B, Rate C - 0.0, 0.0 -> 161.04, 161.04
% INFO    : Updated Thermal Rating: on line 40455-40478 : Rate B, Rate C - 0.0, 0.0 -> 118.72, 118.72
% INFO    : Updated Thermal Rating: on line 40456-40459 : Rate B, Rate C - 0.0, 0.0 -> 156.38, 156.38
% INFO    : Updated Thermal Rating: on line 40463-40457 : Rate B, Rate C - 0.0, 0.0 -> 153.26, 153.26
% INFO    : Updated Thermal Rating: on line 40457-40874 : Rate B, Rate C - 0.0, 0.0 -> 147.46, 147.46
% INFO    : Updated Thermal Rating: on line 40459-40463 : Rate B, Rate C - 0.0, 0.0 -> 179.88, 179.88
% INFO    : Updated Thermal Rating: on line 40459-40477 : Rate B, Rate C - 0.0, 0.0 -> 179.95, 179.95
% INFO    : Updated Thermal Rating: on line 40821-40459 : Rate B, Rate C - 0.0, 0.0 -> 211.48, 211.48
% INFO    : Updated Thermal Rating: on line 40821-40459 : Rate B, Rate C - 0.0, 0.0 -> 211.48, 211.48
% INFO    : Updated Thermal Rating: on line 40821-40459 : Rate B, Rate C - 0.0, 0.0 -> 211.48, 211.48
% INFO    : Updated Thermal Rating: on line 40461-40478 : Rate B, Rate C - 0.0, 0.0 -> 128.98, 128.98
% INFO    : Updated Thermal Rating: on line 40462-40776 : Rate B, Rate C - 0.0, 0.0 -> 176.38, 176.38
% INFO    : Updated Thermal Rating: on line 40464-40954 : Rate B, Rate C - 0.0, 0.0 -> 215.96, 215.96
% INFO    : Updated Thermal Rating: on line 40464-40954 : Rate B, Rate C - 0.0, 0.0 -> 215.96, 215.96
% INFO    : Updated Thermal Rating: on line 40464-40954 : Rate B, Rate C - 0.0, 0.0 -> 215.96, 215.96
% INFO    : Updated Thermal Rating: on line 40492-40465 : Rate B, Rate C - 0.0, 0.0 -> 137.23, 137.23
% INFO    : Updated Thermal Rating: on line 40467-40785 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on line 40923-40468 : Rate B, Rate C - 0.0, 0.0 -> 172.07, 172.07
% INFO    : Updated Thermal Rating: on line 40469-40504 : Rate B, Rate C - 0.0, 0.0 -> 148.86, 148.86
% INFO    : Updated Thermal Rating: on line 40469-40694 : Rate B, Rate C - 0.0, 0.0 -> 179.62, 179.62
% INFO    : Updated Thermal Rating: on line 40473-40472 : Rate B, Rate C - 0.0, 0.0 -> 139.62, 139.62
% INFO    : Updated Thermal Rating: on line 40472-40533 : Rate B, Rate C - 0.0, 0.0 -> 153.07, 153.07
% INFO    : Updated Thermal Rating: on line 40496-40474 : Rate B, Rate C - 0.0, 0.0 -> 125.23, 125.23
% INFO    : Updated Thermal Rating: on line 40475-40510 : Rate B, Rate C - 0.0, 0.0 -> 137.73, 137.73
% INFO    : Updated Thermal Rating: on line 40475-40774 : Rate B, Rate C - 0.0, 0.0 -> 138.7, 138.7
% INFO    : Updated Thermal Rating: on line 40478-40596 : Rate B, Rate C - 0.0, 0.0 -> 177.69, 177.69
% INFO    : Updated Thermal Rating: on line 40480-40479 : Rate B, Rate C - 0.0, 0.0 -> 135.62, 135.62
% INFO    : Updated Thermal Rating: on line 40488-40479 : Rate B, Rate C - 0.0, 0.0 -> 164.47, 164.47
% INFO    : Updated Thermal Rating: on line 40479-40506 : Rate B, Rate C - 0.0, 0.0 -> 181.89, 181.89
% INFO    : Updated Thermal Rating: on line 40874-40480 : Rate B, Rate C - 0.0, 0.0 -> 173.34, 173.34
% INFO    : Updated Thermal Rating: on line 40482-40549 : Rate B, Rate C - 0.0, 0.0 -> 137.23, 137.23
% INFO    : Updated Thermal Rating: on line 40714-40482 : Rate B, Rate C - 0.0, 0.0 -> 144.34, 144.34
% INFO    : Updated Thermal Rating: on line 40484-40495 : Rate B, Rate C - 0.0, 0.0 -> 171.85, 171.85
% INFO    : Updated Thermal Rating: on line 40484-40806 : Rate B, Rate C - 0.0, 0.0 -> 189.9, 189.9
% INFO    : Updated Thermal Rating: on line 40510-40485 : Rate B, Rate C - 0.0, 0.0 -> 184.74, 184.74
% INFO    : Updated Thermal Rating: on line 40485-40519 : Rate B, Rate C - 0.0, 0.0 -> 169.31, 169.31
% INFO    : Updated Thermal Rating: on line 40486-40496 : Rate B, Rate C - 0.0, 0.0 -> 132.17, 132.17
% INFO    : Updated Thermal Rating: on line 40505-40486 : Rate B, Rate C - 0.0, 0.0 -> 102.98, 102.98
% INFO    : Updated Thermal Rating: on line 40488-40520 : Rate B, Rate C - 0.0, 0.0 -> 147.65, 147.65
% INFO    : Updated Thermal Rating: on line 40490-40549 : Rate B, Rate C - 0.0, 0.0 -> 161.83, 161.83
% INFO    : Updated Thermal Rating: on line 40954-40490 : Rate B, Rate C - 0.0, 0.0 -> 168.43, 168.43
% INFO    : Updated Thermal Rating: on line 40502-40491 : Rate B, Rate C - 0.0, 0.0 -> 149.92, 149.92
% INFO    : Updated Thermal Rating: on line 40491-40510 : Rate B, Rate C - 0.0, 0.0 -> 178.58, 178.58
% INFO    : Updated Thermal Rating: on line 40492-40578 : Rate B, Rate C - 0.0, 0.0 -> 143.34, 143.34
% INFO    : Updated Thermal Rating: on line 40492-40588 : Rate B, Rate C - 0.0, 0.0 -> 159.22, 159.22
% INFO    : Updated Thermal Rating: on line 40494-40495 : Rate B, Rate C - 0.0, 0.0 -> 156.35, 156.35
% INFO    : Updated Thermal Rating: on line 40494-40694 : Rate B, Rate C - 0.0, 0.0 -> 183.15, 183.15
% INFO    : Updated Thermal Rating: on line 40495-40519 : Rate B, Rate C - 0.0, 0.0 -> 159.97, 159.97
% INFO    : Updated Thermal Rating: on line 40496-40526 : Rate B, Rate C - 0.0, 0.0 -> 164.35, 164.35
% INFO    : Updated Thermal Rating: on line 40538-40496 : Rate B, Rate C - 0.0, 0.0 -> 147.84, 147.84
% INFO    : Updated Thermal Rating: on line 40497-40503 : Rate B, Rate C - 0.0, 0.0 -> 188.17, 188.17
% INFO    : Updated Thermal Rating: on line 40497-40518 : Rate B, Rate C - 0.0, 0.0 -> 191.27, 191.27
% INFO    : Updated Thermal Rating: on line 40497-40540 : Rate B, Rate C - 0.0, 0.0 -> 144.0, 144.0
% INFO    : Updated Thermal Rating: on line 40498-40532 : Rate B, Rate C - 0.0, 0.0 -> 150.46, 150.46
% INFO    : Updated Thermal Rating: on line 40498-40561 : Rate B, Rate C - 0.0, 0.0 -> 162.97, 162.97
% INFO    : Updated Thermal Rating: on line 40498-40806 : Rate B, Rate C - 0.0, 0.0 -> 190.79, 190.79
% INFO    : Updated Thermal Rating: on line 40565-40499 : Rate B, Rate C - 0.0, 0.0 -> 146.91, 146.91
% INFO    : Updated Thermal Rating: on line 40499-40785 : Rate B, Rate C - 0.0, 0.0 -> 154.04, 154.04
% INFO    : Updated Thermal Rating: on line 40500-40508 : Rate B, Rate C - 0.0, 0.0 -> 170.47, 170.47
% INFO    : Updated Thermal Rating: on line 40500-40550 : Rate B, Rate C - 0.0, 0.0 -> 127.49, 127.49
% INFO    : Updated Thermal Rating: on line 40502-40516 : Rate B, Rate C - 0.0, 0.0 -> 134.07, 134.07
% INFO    : Updated Thermal Rating: on line 40502-40526 : Rate B, Rate C - 0.0, 0.0 -> 126.4, 126.4
% INFO    : Updated Thermal Rating: on line 40502-40865 : Rate B, Rate C - 0.0, 0.0 -> 155.01, 155.01
% INFO    : Updated Thermal Rating: on line 40503-40519 : Rate B, Rate C - 0.0, 0.0 -> 162.84, 162.84
% INFO    : Updated Thermal Rating: on line 40504-40540 : Rate B, Rate C - 0.0, 0.0 -> 172.49, 172.49
% INFO    : Updated Thermal Rating: on line 40806-40504 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 40505-40579 : Rate B, Rate C - 0.0, 0.0 -> 172.79, 172.79
% INFO    : Updated Thermal Rating: on line 40506-40891 : Rate B, Rate C - 0.0, 0.0 -> 183.95, 183.95
% INFO    : Updated Thermal Rating: on transformer 40508-40507 : Rate B, Rate C - 0.0, 0.0 -> 813.77, 813.77
% INFO    : Updated Thermal Rating: on line 40507-40860 : Rate B, Rate C - 0.0, 0.0 -> 2493.54, 2493.54
% INFO    : Updated Thermal Rating: on line 40508-40547 : Rate B, Rate C - 0.0, 0.0 -> 174.9, 174.9
% INFO    : Updated Thermal Rating: on line 40508-40579 : Rate B, Rate C - 0.0, 0.0 -> 169.5, 169.5
% INFO    : Updated Thermal Rating: on transformer 40509-40512 : Rate B, Rate C - 0.0, 0.0 -> 991.07, 991.07
% INFO    : Updated Thermal Rating: on transformer 40510-40512 : Rate B, Rate C - 0.0, 0.0 -> 841.07, 841.07
% INFO    : Updated Thermal Rating: on line 40516-40510 : Rate B, Rate C - 0.0, 0.0 -> 182.95, 182.95
% INFO    : Updated Thermal Rating: on transformer 40511-40512 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 40513-40562 : Rate B, Rate C - 0.0, 0.0 -> 2047.36, 2047.36
% INFO    : Updated Thermal Rating: on line 40513-40860 : Rate B, Rate C - 0.0, 0.0 -> 2657.39, 2657.39
% INFO    : Updated Thermal Rating: on transformer 40518-40517 : Rate B, Rate C - 0.0, 0.0 -> 998.73, 998.73
% INFO    : Updated Thermal Rating: on line 40517-40805 : Rate B, Rate C - 0.0, 0.0 -> 2430.73, 2430.73
% INFO    : Updated Thermal Rating: on line 40860-40517 : Rate B, Rate C - 0.0, 0.0 -> 2417.13, 2417.13
% INFO    : Updated Thermal Rating: on line 40553-40518 : Rate B, Rate C - 0.0, 0.0 -> 201.71, 201.71
% INFO    : Updated Thermal Rating: on line 40553-40518 : Rate B, Rate C - 0.0, 0.0 -> 201.71, 201.71
% INFO    : Updated Thermal Rating: on line 40553-40518 : Rate B, Rate C - 0.0, 0.0 -> 201.71, 201.71
% INFO    : Updated Thermal Rating: on line 40518-40865 : Rate B, Rate C - 0.0, 0.0 -> 115.26, 115.26
% INFO    : Updated Thermal Rating: on line 40518-40966 : Rate B, Rate C - 0.0, 0.0 -> 165.52, 165.52
% INFO    : Updated Thermal Rating: on line 40522-40519 : Rate B, Rate C - 0.0, 0.0 -> 167.55, 167.55
% INFO    : Updated Thermal Rating: on line 40520-40522 : Rate B, Rate C - 0.0, 0.0 -> 126.8, 126.8
% INFO    : Updated Thermal Rating: on line 40520-40580 : Rate B, Rate C - 0.0, 0.0 -> 146.36, 146.36
% INFO    : Updated Thermal Rating: on line 40520-40591 : Rate B, Rate C - 0.0, 0.0 -> 109.68, 109.68
% INFO    : Updated Thermal Rating: on line 40523-40541 : Rate B, Rate C - 0.0, 0.0 -> 126.92, 126.92
% INFO    : Updated Thermal Rating: on line 40523-40865 : Rate B, Rate C - 0.0, 0.0 -> 166.95, 166.95
% INFO    : Updated Thermal Rating: on line 40525-40568 : Rate B, Rate C - 0.0, 0.0 -> 150.45, 150.45
% INFO    : Updated Thermal Rating: on line 40525-40694 : Rate B, Rate C - 0.0, 0.0 -> 176.29, 176.29
% INFO    : Updated Thermal Rating: on line 40853-40526 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 40527-40547 : Rate B, Rate C - 0.0, 0.0 -> 125.03, 125.03
% INFO    : Updated Thermal Rating: on line 40527-40853 : Rate B, Rate C - 0.0, 0.0 -> 165.02, 165.02
% INFO    : Updated Thermal Rating: on line 40528-40529 : Rate B, Rate C - 0.0, 0.0 -> 220.68, 220.68
% INFO    : Updated Thermal Rating: on line 40528-40541 : Rate B, Rate C - 0.0, 0.0 -> 157.61, 157.61
% INFO    : Updated Thermal Rating: on line 40575-40528 : Rate B, Rate C - 0.0, 0.0 -> 134.08, 134.08
% INFO    : Updated Thermal Rating: on line 40553-40529 : Rate B, Rate C - 0.0, 0.0 -> 182.89, 182.89
% INFO    : Updated Thermal Rating: on line 40529-40966 : Rate B, Rate C - 0.0, 0.0 -> 191.74, 191.74
% INFO    : Updated Thermal Rating: on line 40532-40774 : Rate B, Rate C - 0.0, 0.0 -> 156.99, 156.99
% INFO    : Updated Thermal Rating: on line 40592-40533 : Rate B, Rate C - 0.0, 0.0 -> 158.42, 158.42
% INFO    : Updated Thermal Rating: on line 40534-40563 : Rate B, Rate C - 0.0, 0.0 -> 161.36, 161.36
% INFO    : Updated Thermal Rating: on line 40534-40920 : Rate B, Rate C - 0.0, 0.0 -> 160.86, 160.86
% INFO    : Updated Thermal Rating: on line 40535-40536 : Rate B, Rate C - 0.0, 0.0 -> 141.32, 141.32
% INFO    : Updated Thermal Rating: on line 40535-40574 : Rate B, Rate C - 0.0, 0.0 -> 157.6, 157.6
% INFO    : Updated Thermal Rating: on line 40535-40853 : Rate B, Rate C - 0.0, 0.0 -> 195.92, 195.92
% INFO    : Updated Thermal Rating: on line 40535-40853 : Rate B, Rate C - 0.0, 0.0 -> 195.92, 195.92
% INFO    : Updated Thermal Rating: on line 40536-40537 : Rate B, Rate C - 0.0, 0.0 -> 136.96, 136.96
% INFO    : Updated Thermal Rating: on line 40536-40563 : Rate B, Rate C - 0.0, 0.0 -> 149.62, 149.62
% INFO    : Updated Thermal Rating: on line 40536-40920 : Rate B, Rate C - 0.0, 0.0 -> 141.48, 141.48
% INFO    : Updated Thermal Rating: on line 40574-40537 : Rate B, Rate C - 0.0, 0.0 -> 144.17, 144.17
% INFO    : Updated Thermal Rating: on line 40537-40966 : Rate B, Rate C - 0.0, 0.0 -> 170.05, 170.05
% INFO    : Updated Thermal Rating: on line 40538-40543 : Rate B, Rate C - 0.0, 0.0 -> 162.51, 162.51
% INFO    : Updated Thermal Rating: on line 40705-40543 : Rate B, Rate C - 0.0, 0.0 -> 192.09, 192.09
% INFO    : Updated Thermal Rating: on line 40705-40543 : Rate B, Rate C - 0.0, 0.0 -> 192.09, 192.09
% INFO    : Updated Thermal Rating: on line 40547-40544 : Rate B, Rate C - 0.0, 0.0 -> 141.32, 141.32
% INFO    : Updated Thermal Rating: on line 40544-40558 : Rate B, Rate C - 0.0, 0.0 -> 156.68, 156.68
% INFO    : Updated Thermal Rating: on line 40549-40570 : Rate B, Rate C - 0.0, 0.0 -> 135.49, 135.49
% INFO    : Updated Thermal Rating: on line 40549-40580 : Rate B, Rate C - 0.0, 0.0 -> 153.88, 153.88
% INFO    : Updated Thermal Rating: on line 40550-40871 : Rate B, Rate C - 0.0, 0.0 -> 168.4, 168.4
% INFO    : Updated Thermal Rating: on line 40552-40555 : Rate B, Rate C - 0.0, 0.0 -> 159.21, 159.21
% INFO    : Updated Thermal Rating: on line 40560-40552 : Rate B, Rate C - 0.0, 0.0 -> 134.06, 134.06
% INFO    : Updated Thermal Rating: on line 40571-40552 : Rate B, Rate C - 0.0, 0.0 -> 83.79, 83.79
% INFO    : Updated Thermal Rating: on line 40871-40553 : Rate B, Rate C - 0.0, 0.0 -> 163.51, 163.51
% INFO    : Updated Thermal Rating: on transformer 40554-40557 : Rate B, Rate C - 0.0, 0.0 -> 1009.11, 1009.11
% INFO    : Updated Thermal Rating: on line 40860-40554 : Rate B, Rate C - 0.0, 0.0 -> 2528.2, 2528.2
% INFO    : Updated Thermal Rating: on transformer 40555-40557 : Rate B, Rate C - 0.0, 0.0 -> 828.67, 828.67
% INFO    : Updated Thermal Rating: on line 40555-40564 : Rate B, Rate C - 0.0, 0.0 -> 174.66, 174.66
% INFO    : Updated Thermal Rating: on line 40575-40555 : Rate B, Rate C - 0.0, 0.0 -> 190.92, 190.92
% INFO    : Updated Thermal Rating: on line 40575-40555 : Rate B, Rate C - 0.0, 0.0 -> 190.92, 190.92
% INFO    : Updated Thermal Rating: on transformer 40556-40557 : Rate B, Rate C - 0.0, 0.0 -> 180.44, 180.44
% INFO    : Updated Thermal Rating: on line 40853-40558 : Rate B, Rate C - 0.0, 0.0 -> 202.13, 202.13
% INFO    : Updated Thermal Rating: on line 40558-40920 : Rate B, Rate C - 0.0, 0.0 -> 168.13, 168.13
% INFO    : Updated Thermal Rating: on line 40563-40560 : Rate B, Rate C - 0.0, 0.0 -> 173.42, 173.42
% INFO    : Updated Thermal Rating: on line 40561-40564 : Rate B, Rate C - 0.0, 0.0 -> 150.62, 150.62
% INFO    : Updated Thermal Rating: on transformer 40563-40562 : Rate B, Rate C - 0.0, 0.0 -> 954.83, 954.83
% INFO    : Updated Thermal Rating: on line 40562-40860 : Rate B, Rate C - 0.0, 0.0 -> 2635.47, 2635.47
% INFO    : Updated Thermal Rating: on line 40563-40571 : Rate B, Rate C - 0.0, 0.0 -> 169.13, 169.13
% INFO    : Updated Thermal Rating: on line 40573-40563 : Rate B, Rate C - 0.0, 0.0 -> 246.1, 246.1
% INFO    : Updated Thermal Rating: on line 40564-40575 : Rate B, Rate C - 0.0, 0.0 -> 160.87, 160.87
% INFO    : Updated Thermal Rating: on line 40565-40588 : Rate B, Rate C - 0.0, 0.0 -> 162.55, 162.55
% INFO    : Updated Thermal Rating: on line 40565-40785 : Rate B, Rate C - 0.0, 0.0 -> 155.8, 155.8
% INFO    : Updated Thermal Rating: on line 40591-40568 : Rate B, Rate C - 0.0, 0.0 -> 138.4, 138.4
% INFO    : Updated Thermal Rating: on line 40573-40569 : Rate B, Rate C - 0.0, 0.0 -> 174.62, 174.62
% INFO    : Updated Thermal Rating: on line 40585-40569 : Rate B, Rate C - 0.0, 0.0 -> 110.5, 110.5
% INFO    : Updated Thermal Rating: on line 40569-40598 : Rate B, Rate C - 0.0, 0.0 -> 116.12, 116.12
% INFO    : Updated Thermal Rating: on line 40597-40570 : Rate B, Rate C - 0.0, 0.0 -> 149.01, 149.01
% INFO    : Updated Thermal Rating: on line 40592-40578 : Rate B, Rate C - 0.0, 0.0 -> 138.22, 138.22
% INFO    : Updated Thermal Rating: on line 40604-40579 : Rate B, Rate C - 0.0, 0.0 -> 135.2, 135.2
% INFO    : Updated Thermal Rating: on line 40582-40609 : Rate B, Rate C - 0.0, 0.0 -> 139.89, 139.89
% INFO    : Updated Thermal Rating: on line 40582-40933 : Rate B, Rate C - 0.0, 0.0 -> 149.83, 149.83
% INFO    : Updated Thermal Rating: on line 40585-40624 : Rate B, Rate C - 0.0, 0.0 -> 174.48, 174.48
% INFO    : Updated Thermal Rating: on line 40592-40593 : Rate B, Rate C - 0.0, 0.0 -> 136.3, 136.3
% INFO    : Updated Thermal Rating: on line 40628-40592 : Rate B, Rate C - 0.0, 0.0 -> 133.72, 133.72
% INFO    : Updated Thermal Rating: on line 40614-40593 : Rate B, Rate C - 0.0, 0.0 -> 141.61, 141.61
% INFO    : Updated Thermal Rating: on line 40596-40601 : Rate B, Rate C - 0.0, 0.0 -> 132.71, 132.71
% INFO    : Updated Thermal Rating: on line 40596-40918 : Rate B, Rate C - 0.0, 0.0 -> 153.11, 153.11
% INFO    : Updated Thermal Rating: on line 40596-40948 : Rate B, Rate C - 0.0, 0.0 -> 166.34, 166.34
% INFO    : Updated Thermal Rating: on line 40605-40597 : Rate B, Rate C - 0.0, 0.0 -> 130.18, 130.18
% INFO    : Updated Thermal Rating: on line 40642-40597 : Rate B, Rate C - 0.0, 0.0 -> 156.48, 156.48
% INFO    : Updated Thermal Rating: on line 40643-40598 : Rate B, Rate C - 0.0, 0.0 -> 153.4, 153.4
% INFO    : Updated Thermal Rating: on line 40604-40599 : Rate B, Rate C - 0.0, 0.0 -> 156.0, 156.0
% INFO    : Updated Thermal Rating: on line 40748-40599 : Rate B, Rate C - 0.0, 0.0 -> 165.11, 165.11
% INFO    : Updated Thermal Rating: on line 40601-40630 : Rate B, Rate C - 0.0, 0.0 -> 137.05, 137.05
% INFO    : Updated Thermal Rating: on line 40602-40610 : Rate B, Rate C - 0.0, 0.0 -> 145.24, 145.24
% INFO    : Updated Thermal Rating: on line 50332-40602 : Rate B, Rate C - 0.0, 0.0 -> 148.99, 148.99
% INFO    : Updated Thermal Rating: on line 40619-40605 : Rate B, Rate C - 0.0, 0.0 -> 132.11, 132.11
% INFO    : Updated Thermal Rating: on line 40640-40605 : Rate B, Rate C - 0.0, 0.0 -> 131.71, 131.71
% INFO    : Updated Thermal Rating: on line 40609-40629 : Rate B, Rate C - 0.0, 0.0 -> 112.07, 112.07
% INFO    : Updated Thermal Rating: on line 40933-40609 : Rate B, Rate C - 0.0, 0.0 -> 146.01, 146.01
% INFO    : Updated Thermal Rating: on transformer 40610-40613 : Rate B, Rate C - 0.0, 0.0 -> 124.82, 124.82
% INFO    : Updated Thermal Rating: on line 40610-40614 : Rate B, Rate C - 0.0, 0.0 -> 114.85, 114.85
% INFO    : Updated Thermal Rating: on transformer 40611-40613 : Rate B, Rate C - 0.0, 0.0 -> 62.41, 62.41
% INFO    : Updated Thermal Rating: on transformer 40612-40613 : Rate B, Rate C - 0.0, 0.0 -> 62.41, 62.41
% INFO    : Updated Thermal Rating: on line 40645-40614 : Rate B, Rate C - 0.0, 0.0 -> 158.7, 158.7
% INFO    : Updated Thermal Rating: on line 40616-40615 : Rate B, Rate C - 0.0, 0.0 -> 132.32, 132.32
% INFO    : Updated Thermal Rating: on line 40615-40624 : Rate B, Rate C - 0.0, 0.0 -> 158.57, 158.57
% INFO    : Updated Thermal Rating: on line 40748-40616 : Rate B, Rate C - 0.0, 0.0 -> 156.87, 156.87
% INFO    : Updated Thermal Rating: on line 40619-40640 : Rate B, Rate C - 0.0, 0.0 -> 136.4, 136.4
% INFO    : Updated Thermal Rating: on line 40638-40620 : Rate B, Rate C - 0.0, 0.0 -> 147.36, 147.36
% INFO    : Updated Thermal Rating: on line 40620-40660 : Rate B, Rate C - 0.0, 0.0 -> 142.94, 142.94
% INFO    : Updated Thermal Rating: on line 40620-40748 : Rate B, Rate C - 0.0, 0.0 -> 155.65, 155.65
% INFO    : Updated Thermal Rating: on line 40624-40622 : Rate B, Rate C - 0.0, 0.0 -> 167.98, 167.98
% INFO    : Updated Thermal Rating: on line 40624-40622 : Rate B, Rate C - 0.0, 0.0 -> 167.98, 167.98
% INFO    : Updated Thermal Rating: on line 40622-40647 : Rate B, Rate C - 0.0, 0.0 -> 117.23, 117.23
% INFO    : Updated Thermal Rating: on transformer 40624-40623 : Rate B, Rate C - 0.0, 0.0 -> 803.83, 803.83
% INFO    : Updated Thermal Rating: on line 40623-40666 : Rate B, Rate C - 0.0, 0.0 -> 2372.88, 2372.88
% INFO    : Updated Thermal Rating: on line 40704-40623 : Rate B, Rate C - 0.0, 0.0 -> 2101.79, 2101.79
% INFO    : Updated Thermal Rating: on line 40623-53250 : Rate B, Rate C - 0.0, 0.0 -> 2298.84, 2298.84
% INFO    : Updated Thermal Rating: on transformer 40624-40627 : Rate B, Rate C - 0.0, 0.0 -> 68.53, 68.53
% INFO    : Updated Thermal Rating: on line 40624-40748 : Rate B, Rate C - 0.0, 0.0 -> 160.33, 160.33
% INFO    : Updated Thermal Rating: on transformer 40625-40627 : Rate B, Rate C - 0.0, 0.0 -> 34.26, 34.26
% INFO    : Updated Thermal Rating: on transformer 40626-40627 : Rate B, Rate C - 0.0, 0.0 -> 34.26, 34.26
% INFO    : Updated Thermal Rating: on line 40654-40628 : Rate B, Rate C - 0.0, 0.0 -> 145.69, 145.69
% INFO    : Updated Thermal Rating: on line 40632-40629 : Rate B, Rate C - 0.0, 0.0 -> 134.54, 134.54
% INFO    : Updated Thermal Rating: on line 40634-40629 : Rate B, Rate C - 0.0, 0.0 -> 137.28, 137.28
% INFO    : Updated Thermal Rating: on line 40629-40933 : Rate B, Rate C - 0.0, 0.0 -> 135.27, 135.27
% INFO    : Updated Thermal Rating: on line 40632-40630 : Rate B, Rate C - 0.0, 0.0 -> 125.89, 125.89
% INFO    : Updated Thermal Rating: on line 40630-40782 : Rate B, Rate C - 0.0, 0.0 -> 147.39, 147.39
% INFO    : Updated Thermal Rating: on line 40948-40632 : Rate B, Rate C - 0.0, 0.0 -> 138.05, 138.05
% INFO    : Updated Thermal Rating: on line 40663-40634 : Rate B, Rate C - 0.0, 0.0 -> 145.2, 145.2
% INFO    : Updated Thermal Rating: on line 40767-40638 : Rate B, Rate C - 0.0, 0.0 -> 152.94, 152.94
% INFO    : Updated Thermal Rating: on line 40639-40644 : Rate B, Rate C - 0.0, 0.0 -> 133.73, 133.73
% INFO    : Updated Thermal Rating: on line 40658-40639 : Rate B, Rate C - 0.0, 0.0 -> 160.62, 160.62
% INFO    : Updated Thermal Rating: on line 40653-40640 : Rate B, Rate C - 0.0, 0.0 -> 156.03, 156.03
% INFO    : Updated Thermal Rating: on line 40642-40649 : Rate B, Rate C - 0.0, 0.0 -> 170.54, 170.54
% INFO    : Updated Thermal Rating: on line 40643-40767 : Rate B, Rate C - 0.0, 0.0 -> 171.63, 171.63
% INFO    : Updated Thermal Rating: on line 40644-40649 : Rate B, Rate C - 0.0, 0.0 -> 157.72, 157.72
% INFO    : Updated Thermal Rating: on line 40656-40645 : Rate B, Rate C - 0.0, 0.0 -> 161.98, 161.98
% INFO    : Updated Thermal Rating: on line 40647-40727 : Rate B, Rate C - 0.0, 0.0 -> 148.42, 148.42
% INFO    : Updated Thermal Rating: on line 40649-40657 : Rate B, Rate C - 0.0, 0.0 -> 173.98, 173.98
% INFO    : Updated Thermal Rating: on line 40649-40675 : Rate B, Rate C - 0.0, 0.0 -> 167.22, 167.22
% INFO    : Updated Thermal Rating: on line 40661-40650 : Rate B, Rate C - 0.0, 0.0 -> 127.12, 127.12
% INFO    : Updated Thermal Rating: on line 50332-40650 : Rate B, Rate C - 0.0, 0.0 -> 133.26, 133.26
% INFO    : Updated Thermal Rating: on line 40664-40653 : Rate B, Rate C - 0.0, 0.0 -> 149.81, 149.81
% INFO    : Updated Thermal Rating: on line 40653-40665 : Rate B, Rate C - 0.0, 0.0 -> 154.01, 154.01
% INFO    : Updated Thermal Rating: on line 40654-40656 : Rate B, Rate C - 0.0, 0.0 -> 176.83, 176.83
% INFO    : Updated Thermal Rating: on line 40663-40654 : Rate B, Rate C - 0.0, 0.0 -> 148.88, 148.88
% INFO    : Updated Thermal Rating: on transformer 40656-40655 : Rate B, Rate C - 0.0, 0.0 -> 732.81, 732.81
% INFO    : Updated Thermal Rating: on line 40932-40655 : Rate B, Rate C - 0.0, 0.0 -> 2947.77, 2947.77
% INFO    : Updated Thermal Rating: on line 53220-40655 : Rate B, Rate C - 0.0, 0.0 -> 3104.37, 3104.37
% INFO    : Updated Thermal Rating: on line 40656-40682 : Rate B, Rate C - 0.0, 0.0 -> 157.4, 157.4
% INFO    : Updated Thermal Rating: on line 40656-40689 : Rate B, Rate C - 0.0, 0.0 -> 153.13, 153.13
% INFO    : Updated Thermal Rating: on line 40657-40762 : Rate B, Rate C - 0.0, 0.0 -> 176.25, 176.25
% INFO    : Updated Thermal Rating: on line 40658-40948 : Rate B, Rate C - 0.0, 0.0 -> 164.73, 164.73
% INFO    : Updated Thermal Rating: on line 40660-40767 : Rate B, Rate C - 0.0, 0.0 -> 155.34, 155.34
% INFO    : Updated Thermal Rating: on line 40661-40662 : Rate B, Rate C - 0.0, 0.0 -> 119.78, 119.78
% INFO    : Updated Thermal Rating: on line 40662-40674 : Rate B, Rate C - 0.0, 0.0 -> 132.57, 132.57
% INFO    : Updated Thermal Rating: on line 40685-40663 : Rate B, Rate C - 0.0, 0.0 -> 81.23, 81.23
% INFO    : Updated Thermal Rating: on line 53204-40664 : Rate B, Rate C - 0.0, 0.0 -> 163.14, 163.14
% INFO    : Updated Thermal Rating: on line 40665-40688 : Rate B, Rate C - 0.0, 0.0 -> 160.06, 160.06
% INFO    : Updated Thermal Rating: on transformer 40667-40666 : Rate B, Rate C - 0.0, 0.0 -> 666.53, 666.53
% INFO    : Updated Thermal Rating: on line 40666-40668 : Rate B, Rate C - 0.0, 0.0 -> 2524.63, 2524.63
% INFO    : Updated Thermal Rating: on line 40727-40667 : Rate B, Rate C - 0.0, 0.0 -> 156.88, 156.88
% INFO    : Updated Thermal Rating: on line 40667-53174 : Rate B, Rate C - 0.0, 0.0 -> 125.18, 125.18
% INFO    : Updated Thermal Rating: on transformer 40668-40671 : Rate B, Rate C - 0.0, 0.0 -> 783.99, 783.99
% INFO    : Updated Thermal Rating: on line 40766-40668 : Rate B, Rate C - 0.0, 0.0 -> 2536.8, 2536.8
% INFO    : Updated Thermal Rating: on line 40668-40876 : Rate B, Rate C - 0.0, 0.0 -> 2975.83, 2975.83
% INFO    : Updated Thermal Rating: on transformer 40669-40671 : Rate B, Rate C - 0.0, 0.0 -> 633.99, 633.99
% INFO    : Updated Thermal Rating: on line 40669-40688 : Rate B, Rate C - 0.0, 0.0 -> 142.27, 142.27
% INFO    : Updated Thermal Rating: on transformer 40670-40671 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 40675-40672 : Rate B, Rate C - 0.0, 0.0 -> 175.49, 175.49
% INFO    : Updated Thermal Rating: on line 40672-40877 : Rate B, Rate C - 0.0, 0.0 -> 192.0, 192.0
% INFO    : Updated Thermal Rating: on line 53204-40672 : Rate B, Rate C - 0.0, 0.0 -> 165.07, 165.07
% INFO    : Updated Thermal Rating: on line 40674-50353 : Rate B, Rate C - 0.0, 0.0 -> 142.86, 142.86
% INFO    : Updated Thermal Rating: on line 40679-40762 : Rate B, Rate C - 0.0, 0.0 -> 154.34, 154.34
% INFO    : Updated Thermal Rating: on line 40679-53209 : Rate B, Rate C - 0.0, 0.0 -> 141.23, 141.23
% INFO    : Updated Thermal Rating: on line 40682-40681 : Rate B, Rate C - 0.0, 0.0 -> 139.55, 139.55
% INFO    : Updated Thermal Rating: on line 40687-40681 : Rate B, Rate C - 0.0, 0.0 -> 147.9, 147.9
% INFO    : Updated Thermal Rating: on line 40682-53211 : Rate B, Rate C - 0.0, 0.0 -> 147.7, 147.7
% INFO    : Updated Thermal Rating: on line 40684-40685 : Rate B, Rate C - 0.0, 0.0 -> 114.43, 114.43
% INFO    : Updated Thermal Rating: on line 53209-40684 : Rate B, Rate C - 0.0, 0.0 -> 127.7, 127.7
% INFO    : Updated Thermal Rating: on line 40685-40686 : Rate B, Rate C - 0.0, 0.0 -> 126.11, 126.11
% INFO    : Updated Thermal Rating: on line 40686-40692 : Rate B, Rate C - 0.0, 0.0 -> 148.01, 148.01
% INFO    : Updated Thermal Rating: on line 40686-53203 : Rate B, Rate C - 0.0, 0.0 -> 131.27, 131.27
% INFO    : Updated Thermal Rating: on line 40687-53187 : Rate B, Rate C - 0.0, 0.0 -> 124.6, 124.6
% INFO    : Updated Thermal Rating: on line 53199-40687 : Rate B, Rate C - 0.0, 0.0 -> 161.48, 161.48
% INFO    : Updated Thermal Rating: on line 40688-53247 : Rate B, Rate C - 0.0, 0.0 -> 149.95, 149.95
% INFO    : Updated Thermal Rating: on line 40689-40690 : Rate B, Rate C - 0.0, 0.0 -> 131.27, 131.27
% INFO    : Updated Thermal Rating: on line 40692-40690 : Rate B, Rate C - 0.0, 0.0 -> 163.6, 163.6
% INFO    : Updated Thermal Rating: on line 40690-53202 : Rate B, Rate C - 0.0, 0.0 -> 164.97, 164.97
% INFO    : Updated Thermal Rating: on line 40692-53208 : Rate B, Rate C - 0.0, 0.0 -> 131.95, 131.95
% INFO    : Updated Thermal Rating: on transformer 40694-40693 : Rate B, Rate C - 0.0, 0.0 -> 794.59, 794.59
% INFO    : Updated Thermal Rating: on transformer 40693-40695 : Rate B, Rate C - 0.0, 0.0 -> 551.52, 551.52
% INFO    : Updated Thermal Rating: on transformer 40693-40696 : Rate B, Rate C - 0.0, 0.0 -> 549.43, 549.43
% INFO    : Updated Thermal Rating: on transformer 40693-40697 : Rate B, Rate C - 0.0, 0.0 -> 547.59, 547.59
% INFO    : Updated Thermal Rating: on line 40805-40693 : Rate B, Rate C - 0.0, 0.0 -> 2785.76, 2785.76
% INFO    : Updated Thermal Rating: on line 40693-40831 : Rate B, Rate C - 0.0, 0.0 -> 2593.12, 2593.12
% INFO    : Updated Thermal Rating: on line 40890-40693 : Rate B, Rate C - 0.0, 0.0 -> 2532.2, 2532.2
% INFO    : Updated Thermal Rating: on transformer 40699-40698 : Rate B, Rate C - 0.0, 0.0 -> 505.63, 505.63
% INFO    : Updated Thermal Rating: on transformer 40698-40700 : Rate B, Rate C - 0.0, 0.0 -> 752.64, 752.64
% INFO    : Updated Thermal Rating: on transformer 40698-40701 : Rate B, Rate C - 0.0, 0.0 -> 752.54, 752.54
% INFO    : Updated Thermal Rating: on transformer 40698-40702 : Rate B, Rate C - 0.0, 0.0 -> 751.15, 751.15
% INFO    : Updated Thermal Rating: on line 40698-40910 : Rate B, Rate C - 0.0, 0.0 -> 2274.74, 2274.74
% INFO    : Updated Thermal Rating: on line 40919-40699 : Rate B, Rate C - 0.0, 0.0 -> 146.17, 146.17
% INFO    : Updated Thermal Rating: on line 40703-40832 : Rate B, Rate C - 0.0, 0.0 -> 178.48, 178.48
% INFO    : Updated Thermal Rating: on line 40703-41008 : Rate B, Rate C - 0.0, 0.0 -> 113.36, 113.36
% INFO    : Updated Thermal Rating: on transformer 40705-40704 : Rate B, Rate C - 0.0, 0.0 -> 685.14, 685.14
% INFO    : Updated Thermal Rating: on transformer 40705-40704 : Rate B, Rate C - 0.0, 0.0 -> 685.14, 685.14
% INFO    : Updated Thermal Rating: on transformer 40704-40706 : Rate B, Rate C - 0.0, 0.0 -> 530.72, 530.72
% INFO    : Updated Thermal Rating: on transformer 40704-40707 : Rate B, Rate C - 0.0, 0.0 -> 529.53, 529.53
% INFO    : Updated Thermal Rating: on transformer 40708-40711 : Rate B, Rate C - 0.0, 0.0 -> 86.08, 86.08
% INFO    : Updated Thermal Rating: on line 40940-40708 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 40709-40711 : Rate B, Rate C - 0.0, 0.0 -> 43.04, 43.04
% INFO    : Updated Thermal Rating: on transformer 40710-40711 : Rate B, Rate C - 0.0, 0.0 -> 43.04, 43.04
% INFO    : Updated Thermal Rating: on transformer 40715-40718 : Rate B, Rate C - 0.0, 0.0 -> 782.8, 782.8
% INFO    : Updated Thermal Rating: on transformer 40716-40718 : Rate B, Rate C - 0.0, 0.0 -> 707.8, 707.8
% INFO    : Updated Thermal Rating: on transformer 40717-40718 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 40720-40721 : Rate B, Rate C - 0.0, 0.0 -> 19.5, 19.5
% INFO    : Updated Thermal Rating: on line 40720-40791 : Rate B, Rate C - 0.0, 0.0 -> 201.65, 201.65
% INFO    : Updated Thermal Rating: on line 40720-40791 : Rate B, Rate C - 0.0, 0.0 -> 201.65, 201.65
% INFO    : Updated Thermal Rating: on line 40720-40791 : Rate B, Rate C - 0.0, 0.0 -> 201.65, 201.65
% INFO    : Updated Thermal Rating: on line 40958-40720 : Rate B, Rate C - 0.0, 0.0 -> 162.16, 162.16
% INFO    : Updated Thermal Rating: on line 41016-40720 : Rate B, Rate C - 0.0, 0.0 -> 194.89, 194.89
% INFO    : Updated Thermal Rating: on line 41016-40720 : Rate B, Rate C - 0.0, 0.0 -> 194.89, 194.89
% INFO    : Updated Thermal Rating: on transformer 40723-40722 : Rate B, Rate C - 0.0, 0.0 -> 1370.1, 1370.1
% INFO    : Updated Thermal Rating: on transformer 40724-40723 : Rate B, Rate C - 0.0, 0.0 -> 741.71, 741.71
% INFO    : Updated Thermal Rating: on transformer 40725-40724 : Rate B, Rate C - 0.0, 0.0 -> 548.61, 548.61
% INFO    : Updated Thermal Rating: on line 40725-40861 : Rate B, Rate C - 0.0, 0.0 -> 247.2, 247.2
% INFO    : Updated Thermal Rating: on transformer 40727-40728 : Rate B, Rate C - 0.0, 0.0 -> 38.43, 38.43
% INFO    : Updated Thermal Rating: on transformer 40730-40729 : Rate B, Rate C - 0.0, 0.0 -> 754.42, 754.42
% INFO    : Updated Thermal Rating: on transformer 40729-40732 : Rate B, Rate C - 0.0, 0.0 -> 508.23, 508.23
% INFO    : Updated Thermal Rating: on transformer 40729-40733 : Rate B, Rate C - 0.0, 0.0 -> 496.43, 496.43
% INFO    : Updated Thermal Rating: on transformer 40729-40734 : Rate B, Rate C - 0.0, 0.0 -> 478.17, 478.17
% INFO    : Updated Thermal Rating: on transformer 40729-40735 : Rate B, Rate C - 0.0, 0.0 -> 466.05, 466.05
% INFO    : Updated Thermal Rating: on transformer 40729-40736 : Rate B, Rate C - 0.0, 0.0 -> 455.01, 455.01
% INFO    : Updated Thermal Rating: on line 40729-40752 : Rate B, Rate C - 0.0, 0.0 -> 2644.51, 2644.51
% INFO    : Updated Thermal Rating: on line 40980-40729 : Rate B, Rate C - 0.0, 0.0 -> 2671.46, 2671.46
% INFO    : Updated Thermal Rating: on transformer 40731-40730 : Rate B, Rate C - 0.0, 0.0 -> 452.09, 452.09
% INFO    : Updated Thermal Rating: on line 40730-41007 : Rate B, Rate C - 0.0, 0.0 -> 1036.13, 1036.13
% INFO    : Updated Thermal Rating: on transformer 40738-40737 : Rate B, Rate C - 0.0, 0.0 -> 1003.61, 1003.61
% INFO    : Updated Thermal Rating: on transformer 40737-40739 : Rate B, Rate C - 0.0, 0.0 -> 794.16, 794.16
% INFO    : Updated Thermal Rating: on transformer 40737-40740 : Rate B, Rate C - 0.0, 0.0 -> 794.14, 794.14
% INFO    : Updated Thermal Rating: on transformer 40737-40741 : Rate B, Rate C - 0.0, 0.0 -> 546.42, 546.42
% INFO    : Updated Thermal Rating: on transformer 40737-40742 : Rate B, Rate C - 0.0, 0.0 -> 545.29, 545.29
% INFO    : Updated Thermal Rating: on transformer 40737-40743 : Rate B, Rate C - 0.0, 0.0 -> 544.92, 544.92
% INFO    : Updated Thermal Rating: on transformer 40737-40744 : Rate B, Rate C - 0.0, 0.0 -> 523.57, 523.57
% INFO    : Updated Thermal Rating: on transformer 40737-40745 : Rate B, Rate C - 0.0, 0.0 -> 514.73, 514.73
% INFO    : Updated Thermal Rating: on line 40746-40899 : Rate B, Rate C - 0.0, 0.0 -> 2532.18, 2532.18
% INFO    : Updated Thermal Rating: on line 40939-40746 : Rate B, Rate C - 0.0, 0.0 -> 2315.49, 2315.49
% INFO    : Updated Thermal Rating: on transformer 40749-40750 : Rate B, Rate C - 0.0, 0.0 -> 19.5, 19.5
% INFO    : Updated Thermal Rating: on transformer 40751-40755 : Rate B, Rate C - 0.0, 0.0 -> 1585.42, 1585.42
% INFO    : Updated Thermal Rating: on transformer 40751-40756 : Rate B, Rate C - 0.0, 0.0 -> 1585.24, 1585.24
% INFO    : Updated Thermal Rating: on transformer 40751-40757 : Rate B, Rate C - 0.0, 0.0 -> 1583.3, 1583.3
% INFO    : Updated Thermal Rating: on transformer 40751-40758 : Rate B, Rate C - 0.0, 0.0 -> 1581.54, 1581.54
% INFO    : Updated Thermal Rating: on transformer 40753-40752 : Rate B, Rate C - 0.0, 0.0 -> 582.57, 582.57
% INFO    : Updated Thermal Rating: on transformer 40752-40755 : Rate B, Rate C - 0.0, 0.0 -> 1485.42, 1485.42
% INFO    : Updated Thermal Rating: on line 41012-40752 : Rate B, Rate C - 0.0, 0.0 -> 2399.59, 2399.59
% INFO    : Updated Thermal Rating: on transformer 40754-40755 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 40761-40760 : Rate B, Rate C - 0.0, 0.0 -> 1439.54, 1439.54
% INFO    : Updated Thermal Rating: on transformer 40760-40763 : Rate B, Rate C - 0.0, 0.0 -> 1761.89, 1761.89
% INFO    : Updated Thermal Rating: on transformer 40760-40764 : Rate B, Rate C - 0.0, 0.0 -> 1756.88, 1756.88
% INFO    : Updated Thermal Rating: on line 40760-40882 : Rate B, Rate C - 0.0, 0.0 -> 4043.49, 4043.49
% INFO    : Updated Thermal Rating: on line 40760-40938 : Rate B, Rate C - 0.0, 0.0 -> 4045.51, 4045.51
% INFO    : Updated Thermal Rating: on transformer 40762-40761 : Rate B, Rate C - 0.0, 0.0 -> 666.98, 666.98
% INFO    : Updated Thermal Rating: on line 40876-40761 : Rate B, Rate C - 0.0, 0.0 -> 2442.58, 2442.58
% INFO    : Updated Thermal Rating: on line 40761-40947 : Rate B, Rate C - 0.0, 0.0 -> 2814.24, 2814.24
% INFO    : Updated Thermal Rating: on line 40761-53234 : Rate B, Rate C - 0.0, 0.0 -> 2810.72, 2810.72
% INFO    : Updated Thermal Rating: on transformer 40766-40765 : Rate B, Rate C - 0.0, 0.0 -> 1382.15, 1382.15
% INFO    : Updated Thermal Rating: on transformer 40765-40768 : Rate B, Rate C - 0.0, 0.0 -> 1475.68, 1475.68
% INFO    : Updated Thermal Rating: on transformer 40765-40769 : Rate B, Rate C - 0.0, 0.0 -> 1473.92, 1473.92
% INFO    : Updated Thermal Rating: on transformer 40765-40770 : Rate B, Rate C - 0.0, 0.0 -> 1107.56, 1107.56
% INFO    : Updated Thermal Rating: on transformer 40765-40771 : Rate B, Rate C - 0.0, 0.0 -> 975.74, 975.74
% INFO    : Updated Thermal Rating: on transformer 40765-40772 : Rate B, Rate C - 0.0, 0.0 -> 1142.07, 1142.07
% INFO    : Updated Thermal Rating: on transformer 40765-40773 : Rate B, Rate C - 0.0, 0.0 -> 973.94, 973.94
% INFO    : Updated Thermal Rating: on line 40851-40765 : Rate B, Rate C - 0.0, 0.0 -> 3974.79, 3974.79
% INFO    : Updated Thermal Rating: on transformer 40767-40766 : Rate B, Rate C - 0.0, 0.0 -> 726.38, 726.38
% INFO    : Updated Thermal Rating: on line 40766-40860 : Rate B, Rate C - 0.0, 0.0 -> 2553.69, 2553.69
% INFO    : Updated Thermal Rating: on line 40774-40997 : Rate B, Rate C - 0.0, 0.0 -> 158.46, 158.46
% INFO    : Updated Thermal Rating: on line 40776-40949 : Rate B, Rate C - 0.0, 0.0 -> 173.83, 173.83
% INFO    : Updated Thermal Rating: on transformer 40777-40778 : Rate B, Rate C - 0.0, 0.0 -> 90.0, 90.0
% INFO    : Updated Thermal Rating: on transformer 40777-40779 : Rate B, Rate C - 0.0, 0.0 -> 67.08, 67.08
% INFO    : Updated Thermal Rating: on transformer 40777-40780 : Rate B, Rate C - 0.0, 0.0 -> 37.59, 37.59
% INFO    : Updated Thermal Rating: on line 40781-40839 : Rate B, Rate C - 0.0, 0.0 -> 134.01, 134.01
% INFO    : Updated Thermal Rating: on line 40782-40918 : Rate B, Rate C - 0.0, 0.0 -> 151.57, 151.57
% INFO    : Updated Thermal Rating: on transformer 40784-40783 : Rate B, Rate C - 0.0, 0.0 -> 2207.54, 2207.54
% INFO    : Updated Thermal Rating: on transformer 40784-40783 : Rate B, Rate C - 0.0, 0.0 -> 2207.54, 2207.54
% INFO    : Updated Thermal Rating: on transformer 40783-40786 : Rate B, Rate C - 0.0, 0.0 -> 1834.75, 1834.75
% INFO    : Updated Thermal Rating: on transformer 40783-40787 : Rate B, Rate C - 0.0, 0.0 -> 1827.2, 1827.2
% INFO    : Updated Thermal Rating: on transformer 40783-40788 : Rate B, Rate C - 0.0, 0.0 -> 1826.09, 1826.09
% INFO    : Updated Thermal Rating: on transformer 40785-40784 : Rate B, Rate C - 0.0, 0.0 -> 589.54, 589.54
% INFO    : Updated Thermal Rating: on line 40789-40930 : Rate B, Rate C - 0.0, 0.0 -> 2646.19, 2646.19
% INFO    : Updated Thermal Rating: on line 40791-40883 : Rate B, Rate C - 0.0, 0.0 -> 206.5, 206.5
% INFO    : Updated Thermal Rating: on line 40791-40883 : Rate B, Rate C - 0.0, 0.0 -> 206.5, 206.5
% INFO    : Updated Thermal Rating: on line 40791-40883 : Rate B, Rate C - 0.0, 0.0 -> 206.5, 206.5
% INFO    : Updated Thermal Rating: on line 40791-40958 : Rate B, Rate C - 0.0, 0.0 -> 165.19, 165.19
% INFO    : Updated Thermal Rating: on line 41016-40791 : Rate B, Rate C - 0.0, 0.0 -> 269.78, 269.78
% INFO    : Updated Thermal Rating: on line 40992-40793 : Rate B, Rate C - 0.0, 0.0 -> 179.1, 179.1
% INFO    : Updated Thermal Rating: on line 40793-40999 : Rate B, Rate C - 0.0, 0.0 -> 115.43, 115.43
% INFO    : Updated Thermal Rating: on transformer 40795-40794 : Rate B, Rate C - 0.0, 0.0 -> 1585.62, 1585.62
% INFO    : Updated Thermal Rating: on transformer 40794-40797 : Rate B, Rate C - 0.0, 0.0 -> 1436.69, 1436.69
% INFO    : Updated Thermal Rating: on transformer 40794-40798 : Rate B, Rate C - 0.0, 0.0 -> 1435.15, 1435.15
% INFO    : Updated Thermal Rating: on transformer 40794-40799 : Rate B, Rate C - 0.0, 0.0 -> 1434.98, 1434.98
% INFO    : Updated Thermal Rating: on transformer 40794-40800 : Rate B, Rate C - 0.0, 0.0 -> 1430.11, 1430.11
% INFO    : Updated Thermal Rating: on transformer 40794-40801 : Rate B, Rate C - 0.0, 0.0 -> 1429.12, 1429.12
% INFO    : Updated Thermal Rating: on transformer 40794-40802 : Rate B, Rate C - 0.0, 0.0 -> 1428.3, 1428.3
% INFO    : Updated Thermal Rating: on transformer 40794-40803 : Rate B, Rate C - 0.0, 0.0 -> 1067.55, 1067.55
% INFO    : Updated Thermal Rating: on transformer 40794-40804 : Rate B, Rate C - 0.0, 0.0 -> 1066.37, 1066.37
% INFO    : Updated Thermal Rating: on line 40846-40794 : Rate B, Rate C - 0.0, 0.0 -> 4042.87, 4042.87
% INFO    : Updated Thermal Rating: on transformer 40796-40795 : Rate B, Rate C - 0.0, 0.0 -> 1056.68, 1056.68
% INFO    : Updated Thermal Rating: on line 40795-40841 : Rate B, Rate C - 0.0, 0.0 -> 2769.42, 2769.42
% INFO    : Updated Thermal Rating: on transformer 40806-40805 : Rate B, Rate C - 0.0, 0.0 -> 816.58, 816.58
% INFO    : Updated Thermal Rating: on line 40806-40997 : Rate B, Rate C - 0.0, 0.0 -> 144.12, 144.12
% INFO    : Updated Thermal Rating: on transformer 40807-40808 : Rate B, Rate C - 0.0, 0.0 -> 24.7, 24.7
% INFO    : Updated Thermal Rating: on line 40807-40874 : Rate B, Rate C - 0.0, 0.0 -> 148.83, 148.83
% INFO    : Updated Thermal Rating: on transformer 40809-40812 : Rate B, Rate C - 0.0, 0.0 -> 1254.38, 1254.38
% INFO    : Updated Thermal Rating: on transformer 40809-40813 : Rate B, Rate C - 0.0, 0.0 -> 762.22, 762.22
% INFO    : Updated Thermal Rating: on transformer 40809-40814 : Rate B, Rate C - 0.0, 0.0 -> 758.41, 758.41
% INFO    : Updated Thermal Rating: on transformer 40809-40815 : Rate B, Rate C - 0.0, 0.0 -> 756.95, 756.95
% INFO    : Updated Thermal Rating: on transformer 40809-40816 : Rate B, Rate C - 0.0, 0.0 -> 610.07, 610.07
% INFO    : Updated Thermal Rating: on transformer 40809-40817 : Rate B, Rate C - 0.0, 0.0 -> 601.63, 601.63
% INFO    : Updated Thermal Rating: on transformer 40809-40818 : Rate B, Rate C - 0.0, 0.0 -> 591.81, 591.81
% INFO    : Updated Thermal Rating: on line 40809-40841 : Rate B, Rate C - 0.0, 0.0 -> 2911.02, 2911.02
% INFO    : Updated Thermal Rating: on transformer 40810-40812 : Rate B, Rate C - 0.0, 0.0 -> 1104.38, 1104.38
% INFO    : Updated Thermal Rating: on transformer 40811-40812 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 40819-40823 : Rate B, Rate C - 0.0, 0.0 -> 1586.52, 1586.52
% INFO    : Updated Thermal Rating: on transformer 40819-40824 : Rate B, Rate C - 0.0, 0.0 -> 1278.61, 1278.61
% INFO    : Updated Thermal Rating: on transformer 40819-40825 : Rate B, Rate C - 0.0, 0.0 -> 1277.17, 1277.17
% INFO    : Updated Thermal Rating: on transformer 40819-40826 : Rate B, Rate C - 0.0, 0.0 -> 1277.16, 1277.16
% INFO    : Updated Thermal Rating: on transformer 40819-40827 : Rate B, Rate C - 0.0, 0.0 -> 1275.72, 1275.72
% INFO    : Updated Thermal Rating: on transformer 40819-40828 : Rate B, Rate C - 0.0, 0.0 -> 1275.18, 1275.18
% INFO    : Updated Thermal Rating: on transformer 40819-40829 : Rate B, Rate C - 0.0, 0.0 -> 1272.78, 1272.78
% INFO    : Updated Thermal Rating: on transformer 40821-40820 : Rate B, Rate C - 0.0, 0.0 -> 823.7, 823.7
% INFO    : Updated Thermal Rating: on transformer 40820-40823 : Rate B, Rate C - 0.0, 0.0 -> 1536.52, 1536.52
% INFO    : Updated Thermal Rating: on transformer 40822-40823 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 40851-40830 : Rate B, Rate C - 0.0, 0.0 -> 4109.72, 4109.72
% INFO    : Updated Thermal Rating: on line 40830-40898 : Rate B, Rate C - 0.0, 0.0 -> 4022.71, 4022.71
% INFO    : Updated Thermal Rating: on line 40956-40830 : Rate B, Rate C - 0.0, 0.0 -> 4055.71, 4055.71
% INFO    : Updated Thermal Rating: on line 40890-40831 : Rate B, Rate C - 0.0, 0.0 -> 2239.08, 2239.08
% INFO    : Updated Thermal Rating: on transformer 40832-40833 : Rate B, Rate C - 0.0, 0.0 -> 11.7, 11.7
% INFO    : Updated Thermal Rating: on transformer 40835-40836 : Rate B, Rate C - 0.0, 0.0 -> 299.69, 299.69
% INFO    : Updated Thermal Rating: on transformer 40835-40837 : Rate B, Rate C - 0.0, 0.0 -> 299.69, 299.69
% INFO    : Updated Thermal Rating: on transformer 40835-40838 : Rate B, Rate C - 0.0, 0.0 -> 299.69, 299.69
% INFO    : Updated Thermal Rating: on line 40839-40968 : Rate B, Rate C - 0.0, 0.0 -> 176.81, 176.81
% INFO    : Updated Thermal Rating: on line 40992-40839 : Rate B, Rate C - 0.0, 0.0 -> 155.42, 155.42
% INFO    : Updated Thermal Rating: on line 40839-40999 : Rate B, Rate C - 0.0, 0.0 -> 207.54, 207.54
% INFO    : Updated Thermal Rating: on line 40839-40999 : Rate B, Rate C - 0.0, 0.0 -> 207.54, 207.54
% INFO    : Updated Thermal Rating: on line 40839-40999 : Rate B, Rate C - 0.0, 0.0 -> 207.54, 207.54
% INFO    : Updated Thermal Rating: on transformer 40841-40840 : Rate B, Rate C - 0.0, 0.0 -> 1789.86, 1789.86
% INFO    : Updated Thermal Rating: on transformer 40841-40840 : Rate B, Rate C - 0.0, 0.0 -> 1789.86, 1789.86
% INFO    : Updated Thermal Rating: on transformer 40841-40840 : Rate B, Rate C - 0.0, 0.0 -> 1789.86, 1789.86
% INFO    : Updated Thermal Rating: on transformer 40840-40843 : Rate B, Rate C - 0.0, 0.0 -> 2106.89, 2106.89
% INFO    : Updated Thermal Rating: on transformer 40840-40844 : Rate B, Rate C - 0.0, 0.0 -> 2092.36, 2092.36
% INFO    : Updated Thermal Rating: on transformer 40840-40845 : Rate B, Rate C - 0.0, 0.0 -> 2004.92, 2004.92
% INFO    : Updated Thermal Rating: on transformer 40842-40841 : Rate B, Rate C - 0.0, 0.0 -> 750.25, 750.25
% INFO    : Updated Thermal Rating: on line 40841-40991 : Rate B, Rate C - 0.0, 0.0 -> 2484.89, 2484.89
% INFO    : Updated Thermal Rating: on line 40841-41003 : Rate B, Rate C - 0.0, 0.0 -> 2486.57, 2486.57
% INFO    : Updated Thermal Rating: on line 40996-40842 : Rate B, Rate C - 0.0, 0.0 -> 200.38, 200.38
% INFO    : Updated Thermal Rating: on line 40996-40842 : Rate B, Rate C - 0.0, 0.0 -> 200.38, 200.38
% INFO    : Updated Thermal Rating: on line 40996-40842 : Rate B, Rate C - 0.0, 0.0 -> 200.38, 200.38
% INFO    : Updated Thermal Rating: on line 40846-40898 : Rate B, Rate C - 0.0, 0.0 -> 4049.42, 4049.42
% INFO    : Updated Thermal Rating: on line 40909-40846 : Rate B, Rate C - 0.0, 0.0 -> 4013.77, 4013.77
% INFO    : Updated Thermal Rating: on line 40846-40956 : Rate B, Rate C - 0.0, 0.0 -> 4016.9, 4016.9
% INFO    : Updated Thermal Rating: on transformer 40848-40847 : Rate B, Rate C - 0.0, 0.0 -> 200.8, 200.8
% INFO    : Updated Thermal Rating: on transformer 40847-40849 : Rate B, Rate C - 0.0, 0.0 -> 772.94, 772.94
% INFO    : Updated Thermal Rating: on transformer 40847-40850 : Rate B, Rate C - 0.0, 0.0 -> 772.33, 772.33
% INFO    : Updated Thermal Rating: on line 40847-40965 : Rate B, Rate C - 0.0, 0.0 -> 2349.32, 2349.32
% INFO    : Updated Thermal Rating: on line 40975-40848 : Rate B, Rate C - 0.0, 0.0 -> 125.72, 125.72
% INFO    : Updated Thermal Rating: on line 40848-40990 : Rate B, Rate C - 0.0, 0.0 -> 123.19, 123.19
% INFO    : Updated Thermal Rating: on transformer 40852-40851 : Rate B, Rate C - 0.0, 0.0 -> 1607.0, 1607.0
% INFO    : Updated Thermal Rating: on transformer 40852-40851 : Rate B, Rate C - 0.0, 0.0 -> 1607.0, 1607.0
% INFO    : Updated Thermal Rating: on transformer 40852-40851 : Rate B, Rate C - 0.0, 0.0 -> 1607.0, 1607.0
% INFO    : Updated Thermal Rating: on transformer 40851-40854 : Rate B, Rate C - 0.0, 0.0 -> 1424.7, 1424.7
% INFO    : Updated Thermal Rating: on transformer 40851-40855 : Rate B, Rate C - 0.0, 0.0 -> 1236.11, 1236.11
% INFO    : Updated Thermal Rating: on transformer 40851-40856 : Rate B, Rate C - 0.0, 0.0 -> 1235.71, 1235.71
% INFO    : Updated Thermal Rating: on transformer 40851-40857 : Rate B, Rate C - 0.0, 0.0 -> 1235.16, 1235.16
% INFO    : Updated Thermal Rating: on transformer 40851-40858 : Rate B, Rate C - 0.0, 0.0 -> 954.16, 954.16
% INFO    : Updated Thermal Rating: on transformer 40853-40852 : Rate B, Rate C - 0.0, 0.0 -> 970.81, 970.81
% INFO    : Updated Thermal Rating: on transformer 40852-40859 : Rate B, Rate C - 0.0, 0.0 -> 291.05, 291.05
% INFO    : Updated Thermal Rating: on line 40853-40966 : Rate B, Rate C - 0.0, 0.0 -> 260.26, 260.26
% INFO    : Updated Thermal Rating: on transformer 40862-40863 : Rate B, Rate C - 0.0, 0.0 -> 11.96, 11.96
% INFO    : Updated Thermal Rating: on line 40864-40940 : Rate B, Rate C - 0.0, 0.0 -> 209.14, 209.14
% INFO    : Updated Thermal Rating: on line 40864-40940 : Rate B, Rate C - 0.0, 0.0 -> 209.14, 209.14
% INFO    : Updated Thermal Rating: on line 40864-40940 : Rate B, Rate C - 0.0, 0.0 -> 209.14, 209.14
% INFO    : Updated Thermal Rating: on transformer 40867-40866 : Rate B, Rate C - 0.0, 0.0 -> 760.73, 760.73
% INFO    : Updated Thermal Rating: on transformer 40866-40868 : Rate B, Rate C - 0.0, 0.0 -> 942.05, 942.05
% INFO    : Updated Thermal Rating: on transformer 40866-40869 : Rate B, Rate C - 0.0, 0.0 -> 925.46, 925.46
% INFO    : Updated Thermal Rating: on transformer 40866-40870 : Rate B, Rate C - 0.0, 0.0 -> 920.05, 920.05
% INFO    : Updated Thermal Rating: on line 40866-40890 : Rate B, Rate C - 0.0, 0.0 -> 2196.97, 2196.97
% INFO    : Updated Thermal Rating: on transformer 40872-40873 : Rate B, Rate C - 0.0, 0.0 -> 26.0, 26.0
% INFO    : Updated Thermal Rating: on line 40874-40891 : Rate B, Rate C - 0.0, 0.0 -> 187.83, 187.83
% INFO    : Updated Thermal Rating: on transformer 40876-40875 : Rate B, Rate C - 0.0, 0.0 -> 1503.14, 1503.14
% INFO    : Updated Thermal Rating: on transformer 40875-40878 : Rate B, Rate C - 0.0, 0.0 -> 1769.13, 1769.13
% INFO    : Updated Thermal Rating: on transformer 40875-40879 : Rate B, Rate C - 0.0, 0.0 -> 1764.56, 1764.56
% INFO    : Updated Thermal Rating: on transformer 40875-40880 : Rate B, Rate C - 0.0, 0.0 -> 1763.55, 1763.55
% INFO    : Updated Thermal Rating: on transformer 40875-40881 : Rate B, Rate C - 0.0, 0.0 -> 1762.46, 1762.46
% INFO    : Updated Thermal Rating: on transformer 40877-40876 : Rate B, Rate C - 0.0, 0.0 -> 686.96, 686.96
% INFO    : Updated Thermal Rating: on transformer 40883-40884 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on transformer 40883-40885 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on transformer 40883-40886 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on transformer 40883-40887 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on transformer 40883-40888 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on transformer 40883-40889 : Rate B, Rate C - 0.0, 0.0 -> 268.23, 268.23
% INFO    : Updated Thermal Rating: on line 40883-40958 : Rate B, Rate C - 0.0, 0.0 -> 205.24, 205.24
% INFO    : Updated Thermal Rating: on line 40883-40958 : Rate B, Rate C - 0.0, 0.0 -> 205.24, 205.24
% INFO    : Updated Thermal Rating: on line 40883-40958 : Rate B, Rate C - 0.0, 0.0 -> 205.24, 205.24
% INFO    : Updated Thermal Rating: on transformer 40891-40890 : Rate B, Rate C - 0.0, 0.0 -> 913.72, 913.72
% INFO    : Updated Thermal Rating: on transformer 40890-40892 : Rate B, Rate C - 0.0, 0.0 -> 704.24, 704.24
% INFO    : Updated Thermal Rating: on transformer 40890-40893 : Rate B, Rate C - 0.0, 0.0 -> 697.18, 697.18
% INFO    : Updated Thermal Rating: on transformer 40890-40894 : Rate B, Rate C - 0.0, 0.0 -> 688.44, 688.44
% INFO    : Updated Thermal Rating: on transformer 40890-40895 : Rate B, Rate C - 0.0, 0.0 -> 687.28, 687.28
% INFO    : Updated Thermal Rating: on transformer 40890-40896 : Rate B, Rate C - 0.0, 0.0 -> 685.33, 685.33
% INFO    : Updated Thermal Rating: on transformer 40890-40897 : Rate B, Rate C - 0.0, 0.0 -> 684.92, 684.92
% INFO    : Updated Thermal Rating: on transformer 40899-40898 : Rate B, Rate C - 0.0, 0.0 -> 1775.27, 1775.27
% INFO    : Updated Thermal Rating: on transformer 40899-40898 : Rate B, Rate C - 0.0, 0.0 -> 1775.27, 1775.27
% INFO    : Updated Thermal Rating: on transformer 40899-40898 : Rate B, Rate C - 0.0, 0.0 -> 1775.27, 1775.27
% INFO    : Updated Thermal Rating: on transformer 40898-40903 : Rate B, Rate C - 0.0, 0.0 -> 1544.8, 1544.8
% INFO    : Updated Thermal Rating: on transformer 40898-40904 : Rate B, Rate C - 0.0, 0.0 -> 1543.4, 1543.4
% INFO    : Updated Thermal Rating: on transformer 40898-40905 : Rate B, Rate C - 0.0, 0.0 -> 1542.48, 1542.48
% INFO    : Updated Thermal Rating: on transformer 40898-40906 : Rate B, Rate C - 0.0, 0.0 -> 1540.69, 1540.69
% INFO    : Updated Thermal Rating: on transformer 40898-40907 : Rate B, Rate C - 0.0, 0.0 -> 1540.51, 1540.51
% INFO    : Updated Thermal Rating: on transformer 40898-40908 : Rate B, Rate C - 0.0, 0.0 -> 1538.19, 1538.19
% INFO    : Updated Thermal Rating: on line 40898-40938 : Rate B, Rate C - 0.0, 0.0 -> 4170.11, 4170.11
% INFO    : Updated Thermal Rating: on transformer 40899-40902 : Rate B, Rate C - 0.0, 0.0 -> 1083.46, 1083.46
% INFO    : Updated Thermal Rating: on line 40939-40899 : Rate B, Rate C - 0.0, 0.0 -> 2583.8, 2583.8
% INFO    : Updated Thermal Rating: on transformer 40900-40902 : Rate B, Rate C - 0.0, 0.0 -> 1008.46, 1008.46
% INFO    : Updated Thermal Rating: on transformer 40901-40902 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 40910-40909 : Rate B, Rate C - 0.0, 0.0 -> 1490.53, 1490.53
% INFO    : Updated Thermal Rating: on transformer 40909-40912 : Rate B, Rate C - 0.0, 0.0 -> 1536.34, 1536.34
% INFO    : Updated Thermal Rating: on transformer 40909-40913 : Rate B, Rate C - 0.0, 0.0 -> 1536.32, 1536.32
% INFO    : Updated Thermal Rating: on transformer 40909-40914 : Rate B, Rate C - 0.0, 0.0 -> 1535.89, 1535.89
% INFO    : Updated Thermal Rating: on transformer 40909-40915 : Rate B, Rate C - 0.0, 0.0 -> 1533.61, 1533.61
% INFO    : Updated Thermal Rating: on transformer 40909-40916 : Rate B, Rate C - 0.0, 0.0 -> 1533.53, 1533.53
% INFO    : Updated Thermal Rating: on transformer 40909-40917 : Rate B, Rate C - 0.0, 0.0 -> 1531.93, 1531.93
% INFO    : Updated Thermal Rating: on transformer 40911-40910 : Rate B, Rate C - 0.0, 0.0 -> 525.0, 525.0
% INFO    : Updated Thermal Rating: on line 40910-41003 : Rate B, Rate C - 0.0, 0.0 -> 2619.42, 2619.42
% INFO    : Updated Thermal Rating: on line 41004-40911 : Rate B, Rate C - 0.0, 0.0 -> 156.12, 156.12
% INFO    : Updated Thermal Rating: on line 40919-40975 : Rate B, Rate C - 0.0, 0.0 -> 135.56, 135.56
% INFO    : Updated Thermal Rating: on transformer 40920-40921 : Rate B, Rate C - 0.0, 0.0 -> 13.0, 13.0
% INFO    : Updated Thermal Rating: on transformer 40923-40922 : Rate B, Rate C - 0.0, 0.0 -> 582.53, 582.53
% INFO    : Updated Thermal Rating: on transformer 40922-40924 : Rate B, Rate C - 0.0, 0.0 -> 999.45, 999.45
% INFO    : Updated Thermal Rating: on transformer 40922-40925 : Rate B, Rate C - 0.0, 0.0 -> 998.6, 998.6
% INFO    : Updated Thermal Rating: on transformer 40922-40926 : Rate B, Rate C - 0.0, 0.0 -> 997.77, 997.77
% INFO    : Updated Thermal Rating: on transformer 40922-40927 : Rate B, Rate C - 0.0, 0.0 -> 982.08, 982.08
% INFO    : Updated Thermal Rating: on transformer 40922-40928 : Rate B, Rate C - 0.0, 0.0 -> 981.56, 981.56
% INFO    : Updated Thermal Rating: on transformer 40922-40929 : Rate B, Rate C - 0.0, 0.0 -> 977.64, 977.64
% INFO    : Updated Thermal Rating: on line 40930-50453 : Rate B, Rate C - 0.0, 0.0 -> 2985.64, 2985.64
% INFO    : Updated Thermal Rating: on transformer 40932-40931 : Rate B, Rate C - 0.0, 0.0 -> 1437.54, 1437.54
% INFO    : Updated Thermal Rating: on transformer 40931-40934 : Rate B, Rate C - 0.0, 0.0 -> 1637.52, 1637.52
% INFO    : Updated Thermal Rating: on transformer 40931-40935 : Rate B, Rate C - 0.0, 0.0 -> 1630.07, 1630.07
% INFO    : Updated Thermal Rating: on transformer 40931-40936 : Rate B, Rate C - 0.0, 0.0 -> 1630.06, 1630.06
% INFO    : Updated Thermal Rating: on transformer 40931-40937 : Rate B, Rate C - 0.0, 0.0 -> 1629.93, 1629.93
% INFO    : Updated Thermal Rating: on transformer 40933-40932 : Rate B, Rate C - 0.0, 0.0 -> 603.82, 603.82
% INFO    : Updated Thermal Rating: on line 40932-40947 : Rate B, Rate C - 0.0, 0.0 -> 2404.76, 2404.76
% INFO    : Updated Thermal Rating: on line 40932-40955 : Rate B, Rate C - 0.0, 0.0 -> 2996.93, 2996.93
% INFO    : Updated Thermal Rating: on transformer 40939-40942 : Rate B, Rate C - 0.0, 0.0 -> 1195.46, 1195.46
% INFO    : Updated Thermal Rating: on transformer 40939-40943 : Rate B, Rate C - 0.0, 0.0 -> 748.13, 748.13
% INFO    : Updated Thermal Rating: on transformer 40939-40944 : Rate B, Rate C - 0.0, 0.0 -> 748.04, 748.04
% INFO    : Updated Thermal Rating: on transformer 40939-40945 : Rate B, Rate C - 0.0, 0.0 -> 513.48, 513.48
% INFO    : Updated Thermal Rating: on transformer 40939-40946 : Rate B, Rate C - 0.0, 0.0 -> 510.45, 510.45
% INFO    : Updated Thermal Rating: on transformer 40940-40942 : Rate B, Rate C - 0.0, 0.0 -> 1070.46, 1070.46
% INFO    : Updated Thermal Rating: on transformer 40941-40942 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 40948-40947 : Rate B, Rate C - 0.0, 0.0 -> 688.24, 688.24
% INFO    : Updated Thermal Rating: on line 40949-40954 : Rate B, Rate C - 0.0, 0.0 -> 170.29, 170.29
% INFO    : Updated Thermal Rating: on transformer 40954-40953 : Rate B, Rate C - 0.0, 0.0 -> 981.68, 981.68
% INFO    : Updated Thermal Rating: on transformer 40957-40956 : Rate B, Rate C - 0.0, 0.0 -> 1521.87, 1521.87
% INFO    : Updated Thermal Rating: on transformer 40956-40959 : Rate B, Rate C - 0.0, 0.0 -> 1482.02, 1482.02
% INFO    : Updated Thermal Rating: on transformer 40956-40960 : Rate B, Rate C - 0.0, 0.0 -> 1481.93, 1481.93
% INFO    : Updated Thermal Rating: on transformer 40956-40961 : Rate B, Rate C - 0.0, 0.0 -> 1480.29, 1480.29
% INFO    : Updated Thermal Rating: on transformer 40956-40962 : Rate B, Rate C - 0.0, 0.0 -> 1477.72, 1477.72
% INFO    : Updated Thermal Rating: on transformer 40956-40963 : Rate B, Rate C - 0.0, 0.0 -> 1477.71, 1477.71
% INFO    : Updated Thermal Rating: on transformer 40956-40964 : Rate B, Rate C - 0.0, 0.0 -> 1477.09, 1477.09
% INFO    : Updated Thermal Rating: on transformer 40958-40957 : Rate B, Rate C - 0.0, 0.0 -> 618.51, 618.51
% INFO    : Updated Thermal Rating: on transformer 40968-40967 : Rate B, Rate C - 0.0, 0.0 -> 645.55, 645.55
% INFO    : Updated Thermal Rating: on transformer 40967-40969 : Rate B, Rate C - 0.0, 0.0 -> 867.1, 867.1
% INFO    : Updated Thermal Rating: on transformer 40967-40970 : Rate B, Rate C - 0.0, 0.0 -> 865.23, 865.23
% INFO    : Updated Thermal Rating: on transformer 40967-40971 : Rate B, Rate C - 0.0, 0.0 -> 862.53, 862.53
% INFO    : Updated Thermal Rating: on transformer 40967-40972 : Rate B, Rate C - 0.0, 0.0 -> 853.64, 853.64
% INFO    : Updated Thermal Rating: on transformer 40967-40973 : Rate B, Rate C - 0.0, 0.0 -> 841.36, 841.36
% INFO    : Updated Thermal Rating: on transformer 40967-40974 : Rate B, Rate C - 0.0, 0.0 -> 831.07, 831.07
% INFO    : Updated Thermal Rating: on line 41003-40967 : Rate B, Rate C - 0.0, 0.0 -> 1882.01, 1882.01
% INFO    : Updated Thermal Rating: on line 40968-40999 : Rate B, Rate C - 0.0, 0.0 -> 170.49, 170.49
% INFO    : Updated Thermal Rating: on transformer 40975-40978 : Rate B, Rate C - 0.0, 0.0 -> 101.67, 101.67
% INFO    : Updated Thermal Rating: on transformer 40976-40978 : Rate B, Rate C - 0.0, 0.0 -> 50.83, 50.83
% INFO    : Updated Thermal Rating: on transformer 40977-40978 : Rate B, Rate C - 0.0, 0.0 -> 50.83, 50.83
% INFO    : Updated Thermal Rating: on transformer 40980-40979 : Rate B, Rate C - 0.0, 0.0 -> 1388.44, 1388.44
% INFO    : Updated Thermal Rating: on transformer 40979-40984 : Rate B, Rate C - 0.0, 0.0 -> 1409.15, 1409.15
% INFO    : Updated Thermal Rating: on transformer 40979-40985 : Rate B, Rate C - 0.0, 0.0 -> 1408.07, 1408.07
% INFO    : Updated Thermal Rating: on transformer 40979-40986 : Rate B, Rate C - 0.0, 0.0 -> 1406.95, 1406.95
% INFO    : Updated Thermal Rating: on transformer 40979-40987 : Rate B, Rate C - 0.0, 0.0 -> 1405.04, 1405.04
% INFO    : Updated Thermal Rating: on transformer 40979-40988 : Rate B, Rate C - 0.0, 0.0 -> 1404.34, 1404.34
% INFO    : Updated Thermal Rating: on transformer 40979-40989 : Rate B, Rate C - 0.0, 0.0 -> 1404.27, 1404.27
% INFO    : Updated Thermal Rating: on transformer 40980-40983 : Rate B, Rate C - 0.0, 0.0 -> 878.54, 878.54
% INFO    : Updated Thermal Rating: on line 50453-40980 : Rate B, Rate C - 0.0, 0.0 -> 3111.74, 3111.74
% INFO    : Updated Thermal Rating: on transformer 40981-40983 : Rate B, Rate C - 0.0, 0.0 -> 778.54, 778.54
% INFO    : Updated Thermal Rating: on transformer 40982-40983 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 40990-41016 : Rate B, Rate C - 0.0, 0.0 -> 122.23, 122.23
% INFO    : Updated Thermal Rating: on transformer 40992-40991 : Rate B, Rate C - 0.0, 0.0 -> 677.7, 677.7
% INFO    : Updated Thermal Rating: on transformer 40991-40993 : Rate B, Rate C - 0.0, 0.0 -> 1087.75, 1087.75
% INFO    : Updated Thermal Rating: on transformer 40991-40994 : Rate B, Rate C - 0.0, 0.0 -> 1078.87, 1078.87
% INFO    : Updated Thermal Rating: on transformer 40991-40995 : Rate B, Rate C - 0.0, 0.0 -> 1077.66, 1077.66
% INFO    : Updated Thermal Rating: on line 40991-41003 : Rate B, Rate C - 0.0, 0.0 -> 2314.68, 2314.68
% INFO    : Updated Thermal Rating: on transformer 40999-40998 : Rate B, Rate C - 0.0, 0.0 -> 714.89, 714.89
% INFO    : Updated Thermal Rating: on transformer 40998-41000 : Rate B, Rate C - 0.0, 0.0 -> 1033.71, 1033.71
% INFO    : Updated Thermal Rating: on transformer 40998-41001 : Rate B, Rate C - 0.0, 0.0 -> 1021.51, 1021.51
% INFO    : Updated Thermal Rating: on transformer 40998-41002 : Rate B, Rate C - 0.0, 0.0 -> 1020.68, 1020.68
% INFO    : Updated Thermal Rating: on transformer 41004-41005 : Rate B, Rate C - 0.0, 0.0 -> 19.5, 19.5
% INFO    : Updated Thermal Rating: on transformer 41007-41006 : Rate B, Rate C - 0.0, 0.0 -> 744.09, 744.09
% INFO    : Updated Thermal Rating: on transformer 41006-41009 : Rate B, Rate C - 0.0, 0.0 -> 973.18, 973.18
% INFO    : Updated Thermal Rating: on transformer 41006-41010 : Rate B, Rate C - 0.0, 0.0 -> 971.79, 971.79
% INFO    : Updated Thermal Rating: on transformer 41006-41011 : Rate B, Rate C - 0.0, 0.0 -> 969.93, 969.93
% INFO    : Updated Thermal Rating: on transformer 41008-41007 : Rate B, Rate C - 0.0, 0.0 -> 404.75, 404.75
% INFO    : Updated Thermal Rating: on line 41008-41017 : Rate B, Rate C - 0.0, 0.0 -> 167.49, 167.49
% INFO    : Updated Thermal Rating: on transformer 41013-41014 : Rate B, Rate C - 0.0, 0.0 -> 24.7, 24.7
% INFO    : Updated Thermal Rating: on line 50020-50000 : Rate B, Rate C - 0.0, 0.0 -> 283.78, 283.78
% INFO    : Updated Thermal Rating: on line 50003-50001 : Rate B, Rate C - 0.0, 0.0 -> 281.35, 281.35
% INFO    : Updated Thermal Rating: on line 50005-50002 : Rate B, Rate C - 0.0, 0.0 -> 288.56, 288.56
% INFO    : Updated Thermal Rating: on line 50002-50013 : Rate B, Rate C - 0.0, 0.0 -> 294.15, 294.15
% INFO    : Updated Thermal Rating: on line 50013-50003 : Rate B, Rate C - 0.0, 0.0 -> 248.05, 248.05
% INFO    : Updated Thermal Rating: on line 50015-50003 : Rate B, Rate C - 0.0, 0.0 -> 267.89, 267.89
% INFO    : Updated Thermal Rating: on line 50003-50016 : Rate B, Rate C - 0.0, 0.0 -> 305.59, 305.59
% INFO    : Updated Thermal Rating: on line 50005-50010 : Rate B, Rate C - 0.0, 0.0 -> 312.7, 312.7
% INFO    : Updated Thermal Rating: on line 50027-50006 : Rate B, Rate C - 0.0, 0.0 -> 219.25, 219.25
% INFO    : Updated Thermal Rating: on line 50008-50017 : Rate B, Rate C - 0.0, 0.0 -> 202.45, 202.45
% INFO    : Updated Thermal Rating: on line 50008-50454 : Rate B, Rate C - 0.0, 0.0 -> 263.32, 263.32
% INFO    : Updated Thermal Rating: on line 50010-50454 : Rate B, Rate C - 0.0, 0.0 -> 337.69, 337.69
% INFO    : Updated Thermal Rating: on line 50454-50013 : Rate B, Rate C - 0.0, 0.0 -> 302.7, 302.7
% INFO    : Updated Thermal Rating: on line 50014-50015 : Rate B, Rate C - 0.0, 0.0 -> 278.48, 278.48
% INFO    : Updated Thermal Rating: on line 50015-50021 : Rate B, Rate C - 0.0, 0.0 -> 245.67, 245.67
% INFO    : Updated Thermal Rating: on line 50015-50039 : Rate B, Rate C - 0.0, 0.0 -> 325.61, 325.61
% INFO    : Updated Thermal Rating: on line 50016-50018 : Rate B, Rate C - 0.0, 0.0 -> 311.9, 311.9
% INFO    : Updated Thermal Rating: on line 50017-50021 : Rate B, Rate C - 0.0, 0.0 -> 258.17, 258.17
% INFO    : Updated Thermal Rating: on line 50020-50018 : Rate B, Rate C - 0.0, 0.0 -> 308.47, 308.47
% INFO    : Updated Thermal Rating: on line 50018-50026 : Rate B, Rate C - 0.0, 0.0 -> 301.27, 301.27
% INFO    : Updated Thermal Rating: on line 50018-50031 : Rate B, Rate C - 0.0, 0.0 -> 256.64, 256.64
% INFO    : Updated Thermal Rating: on transformer 50020-50019 : Rate B, Rate C - 0.0, 0.0 -> 904.72, 904.72
% INFO    : Updated Thermal Rating: on line 50019-50388 : Rate B, Rate C - 0.0, 0.0 -> 3024.12, 3024.12
% INFO    : Updated Thermal Rating: on line 50406-50019 : Rate B, Rate C - 0.0, 0.0 -> 2794.15, 2794.15
% INFO    : Updated Thermal Rating: on line 50019-50453 : Rate B, Rate C - 0.0, 0.0 -> 3241.99, 3241.99
% INFO    : Updated Thermal Rating: on line 50026-50020 : Rate B, Rate C - 0.0, 0.0 -> 307.32, 307.32
% INFO    : Updated Thermal Rating: on transformer 50022-50021 : Rate B, Rate C - 0.0, 0.0 -> 116.4, 116.4
% INFO    : Updated Thermal Rating: on line 50053-50021 : Rate B, Rate C - 0.0, 0.0 -> 275.97, 275.97
% INFO    : Updated Thermal Rating: on line 50022-50029 : Rate B, Rate C - 0.0, 0.0 -> 155.8, 155.8
% INFO    : Updated Thermal Rating: on line 50023-50052 : Rate B, Rate C - 0.0, 0.0 -> 292.85, 292.85
% INFO    : Updated Thermal Rating: on line 50389-50023 : Rate B, Rate C - 0.0, 0.0 -> 263.97, 263.97
% INFO    : Updated Thermal Rating: on line 50023-50422 : Rate B, Rate C - 0.0, 0.0 -> 255.19, 255.19
% INFO    : Updated Thermal Rating: on line 50027-50050 : Rate B, Rate C - 0.0, 0.0 -> 240.05, 240.05
% INFO    : Updated Thermal Rating: on line 50451-50027 : Rate B, Rate C - 0.0, 0.0 -> 276.99, 276.99
% INFO    : Updated Thermal Rating: on transformer 50029-50028 : Rate B, Rate C - 0.0, 0.0 -> 101.18, 101.18
% INFO    : Updated Thermal Rating: on line 50039-50033 : Rate B, Rate C - 0.0, 0.0 -> 291.89, 291.89
% INFO    : Updated Thermal Rating: on line 50389-50033 : Rate B, Rate C - 0.0, 0.0 -> 298.1, 298.1
% INFO    : Updated Thermal Rating: on line 50035-50034 : Rate B, Rate C - 0.0, 0.0 -> 275.17, 275.17
% INFO    : Updated Thermal Rating: on line 50384-50034 : Rate B, Rate C - 0.0, 0.0 -> 287.16, 287.16
% INFO    : Updated Thermal Rating: on line 50035-50050 : Rate B, Rate C - 0.0, 0.0 -> 267.81, 267.81
% INFO    : Updated Thermal Rating: on line 50047-50036 : Rate B, Rate C - 0.0, 0.0 -> 224.07, 224.07
% INFO    : Updated Thermal Rating: on line 50058-50036 : Rate B, Rate C - 0.0, 0.0 -> 230.43, 230.43
% INFO    : Updated Thermal Rating: on line 50052-50039 : Rate B, Rate C - 0.0, 0.0 -> 288.96, 288.96
% INFO    : Updated Thermal Rating: on line 50384-50040 : Rate B, Rate C - 0.0, 0.0 -> 293.22, 293.22
% INFO    : Updated Thermal Rating: on line 50394-50040 : Rate B, Rate C - 0.0, 0.0 -> 284.73, 284.73
% INFO    : Updated Thermal Rating: on line 50042-50384 : Rate B, Rate C - 0.0, 0.0 -> 268.66, 268.66
% INFO    : Updated Thermal Rating: on line 50401-50042 : Rate B, Rate C - 0.0, 0.0 -> 267.79, 267.79
% INFO    : Updated Thermal Rating: on transformer 50043-50046 : Rate B, Rate C - 0.0, 0.0 -> 128.9, 128.9
% INFO    : Updated Thermal Rating: on transformer 50044-50046 : Rate B, Rate C - 0.0, 0.0 -> 78.9, 78.9
% INFO    : Updated Thermal Rating: on line 74163-50044 : Rate B, Rate C - 0.0, 0.0 -> 210.08, 210.08
% INFO    : Updated Thermal Rating: on transformer 50045-50046 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 50047-50378 : Rate B, Rate C - 0.0, 0.0 -> 236.98, 236.98
% INFO    : Updated Thermal Rating: on line 50050-50049 : Rate B, Rate C - 0.0, 0.0 -> 229.95, 229.95
% INFO    : Updated Thermal Rating: on line 50067-50049 : Rate B, Rate C - 0.0, 0.0 -> 263.11, 263.11
% INFO    : Updated Thermal Rating: on line 50070-50053 : Rate B, Rate C - 0.0, 0.0 -> 285.08, 285.08
% INFO    : Updated Thermal Rating: on line 50439-50054 : Rate B, Rate C - 0.0, 0.0 -> 261.19, 261.19
% INFO    : Updated Thermal Rating: on line 50055-50091 : Rate B, Rate C - 0.0, 0.0 -> 223.23, 223.23
% INFO    : Updated Thermal Rating: on line 50055-50439 : Rate B, Rate C - 0.0, 0.0 -> 264.49, 264.49
% INFO    : Updated Thermal Rating: on line 50056-50073 : Rate B, Rate C - 0.0, 0.0 -> 239.79, 239.79
% INFO    : Updated Thermal Rating: on line 50078-50056 : Rate B, Rate C - 0.0, 0.0 -> 221.43, 221.43
% INFO    : Updated Thermal Rating: on line 50063-50057 : Rate B, Rate C - 0.0, 0.0 -> 232.74, 232.74
% INFO    : Updated Thermal Rating: on line 50057-50394 : Rate B, Rate C - 0.0, 0.0 -> 217.61, 217.61
% INFO    : Updated Thermal Rating: on line 50062-50058 : Rate B, Rate C - 0.0, 0.0 -> 235.08, 235.08
% INFO    : Updated Thermal Rating: on transformer 50060-50059 : Rate B, Rate C - 0.0, 0.0 -> 556.78, 556.78
% INFO    : Updated Thermal Rating: on line 50059-50068 : Rate B, Rate C - 0.0, 0.0 -> 2296.44, 2296.44
% INFO    : Updated Thermal Rating: on line 50203-50059 : Rate B, Rate C - 0.0, 0.0 -> 2350.68, 2350.68
% INFO    : Updated Thermal Rating: on transformer 50061-50060 : Rate B, Rate C - 0.0, 0.0 -> 574.93, 574.93
% INFO    : Updated Thermal Rating: on transformer 50061-50060 : Rate B, Rate C - 0.0, 0.0 -> 574.93, 574.93
% INFO    : Updated Thermal Rating: on line 50060-70122 : Rate B, Rate C - 0.0, 0.0 -> 1288.08, 1288.08
% INFO    : Updated Thermal Rating: on line 50081-50061 : Rate B, Rate C - 0.0, 0.0 -> 308.5, 308.5
% INFO    : Updated Thermal Rating: on line 50061-50084 : Rate B, Rate C - 0.0, 0.0 -> 269.66, 269.66
% INFO    : Updated Thermal Rating: on line 50123-50061 : Rate B, Rate C - 0.0, 0.0 -> 291.19, 291.19
% INFO    : Updated Thermal Rating: on line 50061-50161 : Rate B, Rate C - 0.0, 0.0 -> 292.09, 292.09
% INFO    : Updated Thermal Rating: on line 50081-50062 : Rate B, Rate C - 0.0, 0.0 -> 280.81, 280.81
% INFO    : Updated Thermal Rating: on line 50107-50062 : Rate B, Rate C - 0.0, 0.0 -> 240.08, 240.08
% INFO    : Updated Thermal Rating: on line 50063-50248 : Rate B, Rate C - 0.0, 0.0 -> 242.5, 242.5
% INFO    : Updated Thermal Rating: on transformer 50066-50065 : Rate B, Rate C - 0.0, 0.0 -> 827.17, 827.17
% INFO    : Updated Thermal Rating: on line 50377-50065 : Rate B, Rate C - 0.0, 0.0 -> 2522.47, 2522.47
% INFO    : Updated Thermal Rating: on line 50067-50066 : Rate B, Rate C - 0.0, 0.0 -> 283.79, 283.79
% INFO    : Updated Thermal Rating: on line 50066-50088 : Rate B, Rate C - 0.0, 0.0 -> 312.27, 312.27
% INFO    : Updated Thermal Rating: on line 50091-50066 : Rate B, Rate C - 0.0, 0.0 -> 260.79, 260.79
% INFO    : Updated Thermal Rating: on line 50088-50067 : Rate B, Rate C - 0.0, 0.0 -> 236.46, 236.46
% INFO    : Updated Thermal Rating: on transformer 50069-50068 : Rate B, Rate C - 0.0, 0.0 -> 757.9, 757.9
% INFO    : Updated Thermal Rating: on line 50076-50068 : Rate B, Rate C - 0.0, 0.0 -> 2347.45, 2347.45
% INFO    : Updated Thermal Rating: on line 50163-50068 : Rate B, Rate C - 0.0, 0.0 -> 2491.16, 2491.16
% INFO    : Updated Thermal Rating: on line 50074-50069 : Rate B, Rate C - 0.0, 0.0 -> 257.29, 257.29
% INFO    : Updated Thermal Rating: on line 50069-50136 : Rate B, Rate C - 0.0, 0.0 -> 281.24, 281.24
% INFO    : Updated Thermal Rating: on line 50069-50148 : Rate B, Rate C - 0.0, 0.0 -> 239.3, 239.3
% INFO    : Updated Thermal Rating: on line 50070-50279 : Rate B, Rate C - 0.0, 0.0 -> 288.34, 288.34
% INFO    : Updated Thermal Rating: on line 50197-50073 : Rate B, Rate C - 0.0, 0.0 -> 252.07, 252.07
% INFO    : Updated Thermal Rating: on line 50073-50378 : Rate B, Rate C - 0.0, 0.0 -> 199.16, 199.16
% INFO    : Updated Thermal Rating: on line 50074-50181 : Rate B, Rate C - 0.0, 0.0 -> 260.19, 260.19
% INFO    : Updated Thermal Rating: on transformer 50077-50076 : Rate B, Rate C - 0.0, 0.0 -> 912.95, 912.95
% INFO    : Updated Thermal Rating: on line 50076-50438 : Rate B, Rate C - 0.0, 0.0 -> 2359.48, 2359.48
% INFO    : Updated Thermal Rating: on line 50108-50077 : Rate B, Rate C - 0.0, 0.0 -> 301.73, 301.73
% INFO    : Updated Thermal Rating: on line 50077-50111 : Rate B, Rate C - 0.0, 0.0 -> 303.48, 303.48
% INFO    : Updated Thermal Rating: on line 50135-50077 : Rate B, Rate C - 0.0, 0.0 -> 279.49, 279.49
% INFO    : Updated Thermal Rating: on line 50078-50205 : Rate B, Rate C - 0.0, 0.0 -> 273.29, 273.29
% INFO    : Updated Thermal Rating: on line 50084-50120 : Rate B, Rate C - 0.0, 0.0 -> 205.21, 205.21
% INFO    : Updated Thermal Rating: on line 50100-50086 : Rate B, Rate C - 0.0, 0.0 -> 253.46, 253.46
% INFO    : Updated Thermal Rating: on line 50439-50086 : Rate B, Rate C - 0.0, 0.0 -> 288.9, 288.9
% INFO    : Updated Thermal Rating: on line 50088-50092 : Rate B, Rate C - 0.0, 0.0 -> 279.83, 279.83
% INFO    : Updated Thermal Rating: on line 50092-50130 : Rate B, Rate C - 0.0, 0.0 -> 259.61, 259.61
% INFO    : Updated Thermal Rating: on line 50092-50137 : Rate B, Rate C - 0.0, 0.0 -> 271.96, 271.96
% INFO    : Updated Thermal Rating: on line 50093-50122 : Rate B, Rate C - 0.0, 0.0 -> 229.71, 229.71
% INFO    : Updated Thermal Rating: on line 50201-50093 : Rate B, Rate C - 0.0, 0.0 -> 238.73, 238.73
% INFO    : Updated Thermal Rating: on line 50097-50095 : Rate B, Rate C - 0.0, 0.0 -> 252.67, 252.67
% INFO    : Updated Thermal Rating: on line 50111-50095 : Rate B, Rate C - 0.0, 0.0 -> 295.47, 295.47
% INFO    : Updated Thermal Rating: on line 50097-50125 : Rate B, Rate C - 0.0, 0.0 -> 267.13, 267.13
% INFO    : Updated Thermal Rating: on transformer 50099-50098 : Rate B, Rate C - 0.0, 0.0 -> 846.22, 846.22
% INFO    : Updated Thermal Rating: on line 50116-50098 : Rate B, Rate C - 0.0, 0.0 -> 2540.94, 2540.94
% INFO    : Updated Thermal Rating: on line 50099-50100 : Rate B, Rate C - 0.0, 0.0 -> 269.52, 269.52
% INFO    : Updated Thermal Rating: on line 50099-50189 : Rate B, Rate C - 0.0, 0.0 -> 329.02, 329.02
% INFO    : Updated Thermal Rating: on line 50102-50134 : Rate B, Rate C - 0.0, 0.0 -> 243.31, 243.31
% INFO    : Updated Thermal Rating: on line 50102-50444 : Rate B, Rate C - 0.0, 0.0 -> 298.5, 298.5
% INFO    : Updated Thermal Rating: on line 50103-50129 : Rate B, Rate C - 0.0, 0.0 -> 280.89, 280.89
% INFO    : Updated Thermal Rating: on line 50103-50137 : Rate B, Rate C - 0.0, 0.0 -> 204.2, 204.2
% INFO    : Updated Thermal Rating: on line 50104-50226 : Rate B, Rate C - 0.0, 0.0 -> 263.52, 263.52
% INFO    : Updated Thermal Rating: on line 50233-50104 : Rate B, Rate C - 0.0, 0.0 -> 227.94, 227.94
% INFO    : Updated Thermal Rating: on line 50123-50107 : Rate B, Rate C - 0.0, 0.0 -> 250.66, 250.66
% INFO    : Updated Thermal Rating: on line 50108-50111 : Rate B, Rate C - 0.0, 0.0 -> 255.96, 255.96
% INFO    : Updated Thermal Rating: on line 50371-50112 : Rate B, Rate C - 0.0, 0.0 -> 260.56, 260.56
% INFO    : Updated Thermal Rating: on line 50439-50112 : Rate B, Rate C - 0.0, 0.0 -> 239.11, 239.11
% INFO    : Updated Thermal Rating: on line 50130-50114 : Rate B, Rate C - 0.0, 0.0 -> 298.34, 298.34
% INFO    : Updated Thermal Rating: on line 50114-50236 : Rate B, Rate C - 0.0, 0.0 -> 286.94, 286.94
% INFO    : Updated Thermal Rating: on line 50114-50260 : Rate B, Rate C - 0.0, 0.0 -> 295.86, 295.86
% INFO    : Updated Thermal Rating: on transformer 50116-50119 : Rate B, Rate C - 0.0, 0.0 -> 871.39, 871.39
% INFO    : Updated Thermal Rating: on line 50116-50176 : Rate B, Rate C - 0.0, 0.0 -> 2600.23, 2600.23
% INFO    : Updated Thermal Rating: on line 50116-50263 : Rate B, Rate C - 0.0, 0.0 -> 2540.47, 2540.47
% INFO    : Updated Thermal Rating: on line 50116-50356 : Rate B, Rate C - 0.0, 0.0 -> 2624.3, 2624.3
% INFO    : Updated Thermal Rating: on line 50377-50116 : Rate B, Rate C - 0.0, 0.0 -> 2710.17, 2710.17
% INFO    : Updated Thermal Rating: on transformer 50117-50119 : Rate B, Rate C - 0.0, 0.0 -> 821.39, 821.39
% INFO    : Updated Thermal Rating: on line 50117-50129 : Rate B, Rate C - 0.0, 0.0 -> 380.0, 380.0
% INFO    : Updated Thermal Rating: on line 50117-50169 : Rate B, Rate C - 0.0, 0.0 -> 238.12, 238.12
% INFO    : Updated Thermal Rating: on line 50117-50437 : Rate B, Rate C - 0.0, 0.0 -> 250.62, 250.62
% INFO    : Updated Thermal Rating: on transformer 50118-50119 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 50120-50195 : Rate B, Rate C - 0.0, 0.0 -> 246.94, 246.94
% INFO    : Updated Thermal Rating: on line 50122-50208 : Rate B, Rate C - 0.0, 0.0 -> 237.91, 237.91
% INFO    : Updated Thermal Rating: on line 50136-50125 : Rate B, Rate C - 0.0, 0.0 -> 238.91, 238.91
% INFO    : Updated Thermal Rating: on line 50125-50161 : Rate B, Rate C - 0.0, 0.0 -> 246.02, 246.02
% INFO    : Updated Thermal Rating: on line 50126-50139 : Rate B, Rate C - 0.0, 0.0 -> 254.4, 254.4
% INFO    : Updated Thermal Rating: on line 50189-50126 : Rate B, Rate C - 0.0, 0.0 -> 303.71, 303.71
% INFO    : Updated Thermal Rating: on line 50137-50127 : Rate B, Rate C - 0.0, 0.0 -> 228.83, 228.83
% INFO    : Updated Thermal Rating: on line 50127-50153 : Rate B, Rate C - 0.0, 0.0 -> 291.52, 291.52
% INFO    : Updated Thermal Rating: on line 50127-50170 : Rate B, Rate C - 0.0, 0.0 -> 230.65, 230.65
% INFO    : Updated Thermal Rating: on line 50129-50151 : Rate B, Rate C - 0.0, 0.0 -> 291.87, 291.87
% INFO    : Updated Thermal Rating: on line 50133-50134 : Rate B, Rate C - 0.0, 0.0 -> 268.55, 268.55
% INFO    : Updated Thermal Rating: on line 50172-50133 : Rate B, Rate C - 0.0, 0.0 -> 288.63, 288.63
% INFO    : Updated Thermal Rating: on line 50133-50180 : Rate B, Rate C - 0.0, 0.0 -> 262.23, 262.23
% INFO    : Updated Thermal Rating: on line 50369-50133 : Rate B, Rate C - 0.0, 0.0 -> 279.49, 279.49
% INFO    : Updated Thermal Rating: on line 50134-50148 : Rate B, Rate C - 0.0, 0.0 -> 252.3, 252.3
% INFO    : Updated Thermal Rating: on line 50135-50162 : Rate B, Rate C - 0.0, 0.0 -> 236.33, 236.33
% INFO    : Updated Thermal Rating: on line 50139-50187 : Rate B, Rate C - 0.0, 0.0 -> 262.84, 262.84
% INFO    : Updated Thermal Rating: on line 50200-50139 : Rate B, Rate C - 0.0, 0.0 -> 228.72, 228.72
% INFO    : Updated Thermal Rating: on line 50195-50140 : Rate B, Rate C - 0.0, 0.0 -> 239.85, 239.85
% INFO    : Updated Thermal Rating: on line 50140-50205 : Rate B, Rate C - 0.0, 0.0 -> 270.31, 270.31
% INFO    : Updated Thermal Rating: on line 50140-50208 : Rate B, Rate C - 0.0, 0.0 -> 241.95, 241.95
% INFO    : Updated Thermal Rating: on line 50140-50265 : Rate B, Rate C - 0.0, 0.0 -> 223.41, 223.41
% INFO    : Updated Thermal Rating: on line 50166-50143 : Rate B, Rate C - 0.0, 0.0 -> 237.29, 237.29
% INFO    : Updated Thermal Rating: on line 50143-50178 : Rate B, Rate C - 0.0, 0.0 -> 284.95, 284.95
% INFO    : Updated Thermal Rating: on line 50156-50145 : Rate B, Rate C - 0.0, 0.0 -> 253.27, 253.27
% INFO    : Updated Thermal Rating: on line 50145-50169 : Rate B, Rate C - 0.0, 0.0 -> 279.38, 279.38
% INFO    : Updated Thermal Rating: on line 50145-50401 : Rate B, Rate C - 0.0, 0.0 -> 334.38, 334.38
% INFO    : Updated Thermal Rating: on line 50164-50147 : Rate B, Rate C - 0.0, 0.0 -> 227.11, 227.11
% INFO    : Updated Thermal Rating: on line 50147-50444 : Rate B, Rate C - 0.0, 0.0 -> 239.65, 239.65
% INFO    : Updated Thermal Rating: on line 50149-50270 : Rate B, Rate C - 0.0, 0.0 -> 258.31, 258.31
% INFO    : Updated Thermal Rating: on line 50149-50276 : Rate B, Rate C - 0.0, 0.0 -> 265.85, 265.85
% INFO    : Updated Thermal Rating: on line 50151-50170 : Rate B, Rate C - 0.0, 0.0 -> 240.99, 240.99
% INFO    : Updated Thermal Rating: on line 50153-50371 : Rate B, Rate C - 0.0, 0.0 -> 315.36, 315.36
% INFO    : Updated Thermal Rating: on line 50155-50181 : Rate B, Rate C - 0.0, 0.0 -> 248.09, 248.09
% INFO    : Updated Thermal Rating: on line 50155-50258 : Rate B, Rate C - 0.0, 0.0 -> 275.81, 275.81
% INFO    : Updated Thermal Rating: on line 50155-50300 : Rate B, Rate C - 0.0, 0.0 -> 285.64, 285.64
% INFO    : Updated Thermal Rating: on line 50411-50155 : Rate B, Rate C - 0.0, 0.0 -> 276.8, 276.8
% INFO    : Updated Thermal Rating: on transformer 50156-50159 : Rate B, Rate C - 0.0, 0.0 -> 181.02, 181.02
% INFO    : Updated Thermal Rating: on line 50177-50156 : Rate B, Rate C - 0.0, 0.0 -> 275.5, 275.5
% INFO    : Updated Thermal Rating: on line 50156-50179 : Rate B, Rate C - 0.0, 0.0 -> 266.46, 266.46
% INFO    : Updated Thermal Rating: on transformer 50157-50159 : Rate B, Rate C - 0.0, 0.0 -> 90.51, 90.51
% INFO    : Updated Thermal Rating: on transformer 50158-50159 : Rate B, Rate C - 0.0, 0.0 -> 90.51, 90.51
% INFO    : Updated Thermal Rating: on line 50258-50162 : Rate B, Rate C - 0.0, 0.0 -> 243.61, 243.61
% INFO    : Updated Thermal Rating: on transformer 50164-50163 : Rate B, Rate C - 0.0, 0.0 -> 774.07, 774.07
% INFO    : Updated Thermal Rating: on line 50239-50163 : Rate B, Rate C - 0.0, 0.0 -> 2501.61, 2501.61
% INFO    : Updated Thermal Rating: on line 50445-50163 : Rate B, Rate C - 0.0, 0.0 -> 2402.1, 2402.1
% INFO    : Updated Thermal Rating: on line 50164-50171 : Rate B, Rate C - 0.0, 0.0 -> 329.23, 329.23
% INFO    : Updated Thermal Rating: on line 50185-50165 : Rate B, Rate C - 0.0, 0.0 -> 213.52, 213.52
% INFO    : Updated Thermal Rating: on line 50165-50245 : Rate B, Rate C - 0.0, 0.0 -> 246.2, 246.2
% INFO    : Updated Thermal Rating: on line 50215-50166 : Rate B, Rate C - 0.0, 0.0 -> 233.43, 233.43
% INFO    : Updated Thermal Rating: on line 50167-50371 : Rate B, Rate C - 0.0, 0.0 -> 254.09, 254.09
% INFO    : Updated Thermal Rating: on line 50444-50167 : Rate B, Rate C - 0.0, 0.0 -> 240.84, 240.84
% INFO    : Updated Thermal Rating: on line 50168-50187 : Rate B, Rate C - 0.0, 0.0 -> 278.71, 278.71
% INFO    : Updated Thermal Rating: on line 50210-50168 : Rate B, Rate C - 0.0, 0.0 -> 316.67, 316.67
% INFO    : Updated Thermal Rating: on line 50171-50411 : Rate B, Rate C - 0.0, 0.0 -> 307.72, 307.72
% INFO    : Updated Thermal Rating: on line 50444-50172 : Rate B, Rate C - 0.0, 0.0 -> 303.97, 303.97
% INFO    : Updated Thermal Rating: on line 50218-50173 : Rate B, Rate C - 0.0, 0.0 -> 239.93, 239.93
% INFO    : Updated Thermal Rating: on line 50378-50173 : Rate B, Rate C - 0.0, 0.0 -> 213.97, 213.97
% INFO    : Updated Thermal Rating: on line 50179-50175 : Rate B, Rate C - 0.0, 0.0 -> 262.15, 262.15
% INFO    : Updated Thermal Rating: on line 50175-50264 : Rate B, Rate C - 0.0, 0.0 -> 238.06, 238.06
% INFO    : Updated Thermal Rating: on transformer 50177-50176 : Rate B, Rate C - 0.0, 0.0 -> 875.91, 875.91
% INFO    : Updated Thermal Rating: on line 50176-50356 : Rate B, Rate C - 0.0, 0.0 -> 2402.8, 2402.8
% INFO    : Updated Thermal Rating: on line 50176-50428 : Rate B, Rate C - 0.0, 0.0 -> 2752.94, 2752.94
% INFO    : Updated Thermal Rating: on line 50177-50178 : Rate B, Rate C - 0.0, 0.0 -> 308.72, 308.72
% INFO    : Updated Thermal Rating: on line 50177-50257 : Rate B, Rate C - 0.0, 0.0 -> 283.37, 283.37
% INFO    : Updated Thermal Rating: on line 50178-50179 : Rate B, Rate C - 0.0, 0.0 -> 213.37, 213.37
% INFO    : Updated Thermal Rating: on line 50179-50235 : Rate B, Rate C - 0.0, 0.0 -> 274.16, 274.16
% INFO    : Updated Thermal Rating: on line 50230-50180 : Rate B, Rate C - 0.0, 0.0 -> 232.14, 232.14
% INFO    : Updated Thermal Rating: on line 50181-50411 : Rate B, Rate C - 0.0, 0.0 -> 282.93, 282.93
% INFO    : Updated Thermal Rating: on line 50198-50182 : Rate B, Rate C - 0.0, 0.0 -> 246.92, 246.92
% INFO    : Updated Thermal Rating: on line 50182-50277 : Rate B, Rate C - 0.0, 0.0 -> 264.71, 264.71
% INFO    : Updated Thermal Rating: on line 50187-50184 : Rate B, Rate C - 0.0, 0.0 -> 257.36, 257.36
% INFO    : Updated Thermal Rating: on line 50184-50244 : Rate B, Rate C - 0.0, 0.0 -> 266.55, 266.55
% INFO    : Updated Thermal Rating: on line 50184-50293 : Rate B, Rate C - 0.0, 0.0 -> 252.72, 252.72
% INFO    : Updated Thermal Rating: on line 50219-50185 : Rate B, Rate C - 0.0, 0.0 -> 207.18, 207.18
% INFO    : Updated Thermal Rating: on line 50437-50185 : Rate B, Rate C - 0.0, 0.0 -> 266.46, 266.46
% INFO    : Updated Thermal Rating: on line 50228-50186 : Rate B, Rate C - 0.0, 0.0 -> 274.4, 274.4
% INFO    : Updated Thermal Rating: on line 50245-50186 : Rate B, Rate C - 0.0, 0.0 -> 234.14, 234.14
% INFO    : Updated Thermal Rating: on line 50192-50200 : Rate B, Rate C - 0.0, 0.0 -> 258.66, 258.66
% INFO    : Updated Thermal Rating: on line 50192-50245 : Rate B, Rate C - 0.0, 0.0 -> 298.27, 298.27
% INFO    : Updated Thermal Rating: on line 50275-50195 : Rate B, Rate C - 0.0, 0.0 -> 234.58, 234.58
% INFO    : Updated Thermal Rating: on line 50197-74320 : Rate B, Rate C - 0.0, 0.0 -> 257.52, 257.52
% INFO    : Updated Thermal Rating: on line 50198-50226 : Rate B, Rate C - 0.0, 0.0 -> 299.65, 299.65
% INFO    : Updated Thermal Rating: on line 50401-50198 : Rate B, Rate C - 0.0, 0.0 -> 281.83, 281.83
% INFO    : Updated Thermal Rating: on line 50220-50201 : Rate B, Rate C - 0.0, 0.0 -> 273.15, 273.15
% INFO    : Updated Thermal Rating: on line 50227-50201 : Rate B, Rate C - 0.0, 0.0 -> 240.15, 240.15
% INFO    : Updated Thermal Rating: on transformer 50203-50207 : Rate B, Rate C - 0.0, 0.0 -> 847.81, 847.81
% INFO    : Updated Thermal Rating: on transformer 50205-50204 : Rate B, Rate C - 0.0, 0.0 -> 496.37, 496.37
% INFO    : Updated Thermal Rating: on transformer 50204-50207 : Rate B, Rate C - 0.0, 0.0 -> 747.81, 747.81
% INFO    : Updated Thermal Rating: on line 70122-50204 : Rate B, Rate C - 0.0, 0.0 -> 1177.3, 1177.3
% INFO    : Updated Thermal Rating: on line 74317-50204 : Rate B, Rate C - 0.0, 0.0 -> 1057.89, 1057.89
% INFO    : Updated Thermal Rating: on line 50204-74325 : Rate B, Rate C - 0.0, 0.0 -> 1164.12, 1164.12
% INFO    : Updated Thermal Rating: on line 50218-50205 : Rate B, Rate C - 0.0, 0.0 -> 236.28, 236.28
% INFO    : Updated Thermal Rating: on line 50227-50205 : Rate B, Rate C - 0.0, 0.0 -> 292.97, 292.97
% INFO    : Updated Thermal Rating: on transformer 50206-50207 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 50209-50212 : Rate B, Rate C - 0.0, 0.0 -> 1050.88, 1050.88
% INFO    : Updated Thermal Rating: on transformer 50210-50212 : Rate B, Rate C - 0.0, 0.0 -> 900.88, 900.88
% INFO    : Updated Thermal Rating: on line 50219-50210 : Rate B, Rate C - 0.0, 0.0 -> 269.78, 269.78
% INFO    : Updated Thermal Rating: on line 50210-50245 : Rate B, Rate C - 0.0, 0.0 -> 320.9, 320.9
% INFO    : Updated Thermal Rating: on transformer 50211-50212 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 50239-50214 : Rate B, Rate C - 0.0, 0.0 -> 2003.06, 2003.06
% INFO    : Updated Thermal Rating: on line 50263-50214 : Rate B, Rate C - 0.0, 0.0 -> 2635.28, 2635.28
% INFO    : Updated Thermal Rating: on line 50215-50264 : Rate B, Rate C - 0.0, 0.0 -> 292.34, 292.34
% INFO    : Updated Thermal Rating: on line 50216-50225 : Rate B, Rate C - 0.0, 0.0 -> 241.61, 241.61
% INFO    : Updated Thermal Rating: on line 50216-50248 : Rate B, Rate C - 0.0, 0.0 -> 305.43, 305.43
% INFO    : Updated Thermal Rating: on line 50216-50303 : Rate B, Rate C - 0.0, 0.0 -> 295.39, 295.39
% INFO    : Updated Thermal Rating: on line 50220-50217 : Rate B, Rate C - 0.0, 0.0 -> 287.52, 287.52
% INFO    : Updated Thermal Rating: on line 50265-50217 : Rate B, Rate C - 0.0, 0.0 -> 249.43, 249.43
% INFO    : Updated Thermal Rating: on line 50217-50275 : Rate B, Rate C - 0.0, 0.0 -> 239.82, 239.82
% INFO    : Updated Thermal Rating: on line 50217-70123 : Rate B, Rate C - 0.0, 0.0 -> 320.47, 320.47
% INFO    : Updated Thermal Rating: on line 50221-50218 : Rate B, Rate C - 0.0, 0.0 -> 278.69, 278.69
% INFO    : Updated Thermal Rating: on transformer 50221-50224 : Rate B, Rate C - 0.0, 0.0 -> 243.0, 243.0
% INFO    : Updated Thermal Rating: on line 50297-50221 : Rate B, Rate C - 0.0, 0.0 -> 257.8, 257.8
% INFO    : Updated Thermal Rating: on transformer 50222-50224 : Rate B, Rate C - 0.0, 0.0 -> 83.8, 83.8
% INFO    : Updated Thermal Rating: on line 74187-50222 : Rate B, Rate C - 0.0, 0.0 -> 214.4, 214.4
% INFO    : Updated Thermal Rating: on transformer 50223-50224 : Rate B, Rate C - 0.0, 0.0 -> 159.2, 159.2
% INFO    : Updated Thermal Rating: on line 50225-50303 : Rate B, Rate C - 0.0, 0.0 -> 253.36, 253.36
% INFO    : Updated Thermal Rating: on line 50226-50236 : Rate B, Rate C - 0.0, 0.0 -> 233.55, 233.55
% INFO    : Updated Thermal Rating: on line 50228-50264 : Rate B, Rate C - 0.0, 0.0 -> 294.34, 294.34
% INFO    : Updated Thermal Rating: on line 50247-50230 : Rate B, Rate C - 0.0, 0.0 -> 246.26, 246.26
% INFO    : Updated Thermal Rating: on line 50289-50230 : Rate B, Rate C - 0.0, 0.0 -> 254.76, 254.76
% INFO    : Updated Thermal Rating: on line 50233-50234 : Rate B, Rate C - 0.0, 0.0 -> 232.49, 232.49
% INFO    : Updated Thermal Rating: on line 50233-50250 : Rate B, Rate C - 0.0, 0.0 -> 252.72, 252.72
% INFO    : Updated Thermal Rating: on line 50243-50234 : Rate B, Rate C - 0.0, 0.0 -> 219.47, 219.47
% INFO    : Updated Thermal Rating: on line 50357-50234 : Rate B, Rate C - 0.0, 0.0 -> 263.71, 263.71
% INFO    : Updated Thermal Rating: on line 50235-50282 : Rate B, Rate C - 0.0, 0.0 -> 293.34, 293.34
% INFO    : Updated Thermal Rating: on line 50236-50401 : Rate B, Rate C - 0.0, 0.0 -> 310.55, 310.55
% INFO    : Updated Thermal Rating: on line 50254-50237 : Rate B, Rate C - 0.0, 0.0 -> 222.44, 222.44
% INFO    : Updated Thermal Rating: on line 50261-50237 : Rate B, Rate C - 0.0, 0.0 -> 261.49, 261.49
% INFO    : Updated Thermal Rating: on transformer 50240-50239 : Rate B, Rate C - 0.0, 0.0 -> 815.63, 815.63
% INFO    : Updated Thermal Rating: on line 50239-50435 : Rate B, Rate C - 0.0, 0.0 -> 2935.73, 2935.73
% INFO    : Updated Thermal Rating: on line 50240-50244 : Rate B, Rate C - 0.0, 0.0 -> 298.34, 298.34
% INFO    : Updated Thermal Rating: on line 50240-50247 : Rate B, Rate C - 0.0, 0.0 -> 301.16, 301.16
% INFO    : Updated Thermal Rating: on line 50289-50240 : Rate B, Rate C - 0.0, 0.0 -> 295.88, 295.88
% INFO    : Updated Thermal Rating: on line 50243-50242 : Rate B, Rate C - 0.0, 0.0 -> 246.37, 246.37
% INFO    : Updated Thermal Rating: on line 50242-50251 : Rate B, Rate C - 0.0, 0.0 -> 292.49, 292.49
% INFO    : Updated Thermal Rating: on line 50243-50282 : Rate B, Rate C - 0.0, 0.0 -> 242.15, 242.15
% INFO    : Updated Thermal Rating: on line 50268-50248 : Rate B, Rate C - 0.0, 0.0 -> 296.71, 296.71
% INFO    : Updated Thermal Rating: on line 50248-50270 : Rate B, Rate C - 0.0, 0.0 -> 251.9, 251.9
% INFO    : Updated Thermal Rating: on line 50250-50249 : Rate B, Rate C - 0.0, 0.0 -> 246.76, 246.76
% INFO    : Updated Thermal Rating: on line 50249-50267 : Rate B, Rate C - 0.0, 0.0 -> 286.73, 286.73
% INFO    : Updated Thermal Rating: on line 50253-50250 : Rate B, Rate C - 0.0, 0.0 -> 265.95, 265.95
% INFO    : Updated Thermal Rating: on line 50251-50425 : Rate B, Rate C - 0.0, 0.0 -> 319.04, 319.04
% INFO    : Updated Thermal Rating: on line 50253-50425 : Rate B, Rate C - 0.0, 0.0 -> 301.64, 301.64
% INFO    : Updated Thermal Rating: on line 50254-50257 : Rate B, Rate C - 0.0, 0.0 -> 274.66, 274.66
% INFO    : Updated Thermal Rating: on line 50292-50254 : Rate B, Rate C - 0.0, 0.0 -> 227.08, 227.08
% INFO    : Updated Thermal Rating: on line 50257-50261 : Rate B, Rate C - 0.0, 0.0 -> 235.76, 235.76
% INFO    : Updated Thermal Rating: on line 50264-50257 : Rate B, Rate C - 0.0, 0.0 -> 277.24, 277.24
% INFO    : Updated Thermal Rating: on line 50357-50260 : Rate B, Rate C - 0.0, 0.0 -> 323.47, 323.47
% INFO    : Updated Thermal Rating: on line 50264-50261 : Rate B, Rate C - 0.0, 0.0 -> 294.9, 294.9
% INFO    : Updated Thermal Rating: on transformer 50264-50263 : Rate B, Rate C - 0.0, 0.0 -> 936.13, 936.13
% INFO    : Updated Thermal Rating: on line 50284-50263 : Rate B, Rate C - 0.0, 0.0 -> 2548.31, 2548.31
% INFO    : Updated Thermal Rating: on line 50356-50263 : Rate B, Rate C - 0.0, 0.0 -> 2542.73, 2542.73
% INFO    : Updated Thermal Rating: on line 50263-50428 : Rate B, Rate C - 0.0, 0.0 -> 2743.2, 2743.2
% INFO    : Updated Thermal Rating: on line 50267-50272 : Rate B, Rate C - 0.0, 0.0 -> 289.75, 289.75
% INFO    : Updated Thermal Rating: on line 50267-50295 : Rate B, Rate C - 0.0, 0.0 -> 251.33, 251.33
% INFO    : Updated Thermal Rating: on line 50296-50267 : Rate B, Rate C - 0.0, 0.0 -> 256.78, 256.78
% INFO    : Updated Thermal Rating: on line 50267-50310 : Rate B, Rate C - 0.0, 0.0 -> 298.97, 298.97
% INFO    : Updated Thermal Rating: on line 50279-50268 : Rate B, Rate C - 0.0, 0.0 -> 292.69, 292.69
% INFO    : Updated Thermal Rating: on line 50272-50274 : Rate B, Rate C - 0.0, 0.0 -> 290.4, 290.4
% INFO    : Updated Thermal Rating: on line 50272-50317 : Rate B, Rate C - 0.0, 0.0 -> 261.27, 261.27
% INFO    : Updated Thermal Rating: on line 50274-50280 : Rate B, Rate C - 0.0, 0.0 -> 208.08, 208.08
% INFO    : Updated Thermal Rating: on line 50285-50274 : Rate B, Rate C - 0.0, 0.0 -> 244.45, 244.45
% INFO    : Updated Thermal Rating: on line 50276-50287 : Rate B, Rate C - 0.0, 0.0 -> 276.81, 276.81
% INFO    : Updated Thermal Rating: on line 50298-50277 : Rate B, Rate C - 0.0, 0.0 -> 275.98, 275.98
% INFO    : Updated Thermal Rating: on line 50282-50280 : Rate B, Rate C - 0.0, 0.0 -> 277.95, 277.95
% INFO    : Updated Thermal Rating: on transformer 50282-50281 : Rate B, Rate C - 0.0, 0.0 -> 765.91, 765.91
% INFO    : Updated Thermal Rating: on line 50294-50282 : Rate B, Rate C - 0.0, 0.0 -> 247.42, 247.42
% INFO    : Updated Thermal Rating: on line 50356-50284 : Rate B, Rate C - 0.0, 0.0 -> 2262.43, 2262.43
% INFO    : Updated Thermal Rating: on line 50284-50446 : Rate B, Rate C - 0.0, 0.0 -> 2988.44, 2988.44
% INFO    : Updated Thermal Rating: on line 50285-50294 : Rate B, Rate C - 0.0, 0.0 -> 212.7, 212.7
% INFO    : Updated Thermal Rating: on line 50287-50301 : Rate B, Rate C - 0.0, 0.0 -> 293.72, 293.72
% INFO    : Updated Thermal Rating: on line 50292-50299 : Rate B, Rate C - 0.0, 0.0 -> 240.03, 240.03
% INFO    : Updated Thermal Rating: on line 50302-50293 : Rate B, Rate C - 0.0, 0.0 -> 276.09, 276.09
% INFO    : Updated Thermal Rating: on line 50295-50415 : Rate B, Rate C - 0.0, 0.0 -> 287.48, 287.48
% INFO    : Updated Thermal Rating: on line 50296-50401 : Rate B, Rate C - 0.0, 0.0 -> 264.76, 264.76
% INFO    : Updated Thermal Rating: on line 70123-50297 : Rate B, Rate C - 0.0, 0.0 -> 264.64, 264.64
% INFO    : Updated Thermal Rating: on line 50306-50298 : Rate B, Rate C - 0.0, 0.0 -> 281.55, 281.55
% INFO    : Updated Thermal Rating: on line 50299-50302 : Rate B, Rate C - 0.0, 0.0 -> 285.7, 285.7
% INFO    : Updated Thermal Rating: on line 50431-50300 : Rate B, Rate C - 0.0, 0.0 -> 295.28, 295.28
% INFO    : Updated Thermal Rating: on line 50301-50309 : Rate B, Rate C - 0.0, 0.0 -> 295.87, 295.87
% INFO    : Updated Thermal Rating: on line 50302-50308 : Rate B, Rate C - 0.0, 0.0 -> 319.67, 319.67
% INFO    : Updated Thermal Rating: on line 50303-50396 : Rate B, Rate C - 0.0, 0.0 -> 312.87, 312.87
% INFO    : Updated Thermal Rating: on line 50447-50306 : Rate B, Rate C - 0.0, 0.0 -> 289.87, 289.87
% INFO    : Updated Thermal Rating: on line 50308-50314 : Rate B, Rate C - 0.0, 0.0 -> 264.91, 264.91
% INFO    : Updated Thermal Rating: on line 50308-50321 : Rate B, Rate C - 0.0, 0.0 -> 265.26, 265.26
% INFO    : Updated Thermal Rating: on line 50308-50325 : Rate B, Rate C - 0.0, 0.0 -> 275.83, 275.83
% INFO    : Updated Thermal Rating: on line 50396-50309 : Rate B, Rate C - 0.0, 0.0 -> 298.39, 298.39
% INFO    : Updated Thermal Rating: on line 50310-50415 : Rate B, Rate C - 0.0, 0.0 -> 304.86, 304.86
% INFO    : Updated Thermal Rating: on line 50313-50312 : Rate B, Rate C - 0.0, 0.0 -> 228.36, 228.36
% INFO    : Updated Thermal Rating: on line 50312-50368 : Rate B, Rate C - 0.0, 0.0 -> 239.02, 239.02
% INFO    : Updated Thermal Rating: on line 50313-50319 : Rate B, Rate C - 0.0, 0.0 -> 212.45, 212.45
% INFO    : Updated Thermal Rating: on line 50313-50447 : Rate B, Rate C - 0.0, 0.0 -> 232.71, 232.71
% INFO    : Updated Thermal Rating: on transformer 50315-50314 : Rate B, Rate C - 0.0, 0.0 -> 87.48, 87.48
% INFO    : Updated Thermal Rating: on line 50314-50431 : Rate B, Rate C - 0.0, 0.0 -> 273.11, 273.11
% INFO    : Updated Thermal Rating: on line 50315-70169 : Rate B, Rate C - 0.0, 0.0 -> 219.1, 219.1
% INFO    : Updated Thermal Rating: on line 50317-50326 : Rate B, Rate C - 0.0, 0.0 -> 271.32, 271.32
% INFO    : Updated Thermal Rating: on line 50319-50368 : Rate B, Rate C - 0.0, 0.0 -> 220.67, 220.67
% INFO    : Updated Thermal Rating: on line 50321-50324 : Rate B, Rate C - 0.0, 0.0 -> 269.78, 269.78
% INFO    : Updated Thermal Rating: on line 50338-50322 : Rate B, Rate C - 0.0, 0.0 -> 253.81, 253.81
% INFO    : Updated Thermal Rating: on line 50322-50368 : Rate B, Rate C - 0.0, 0.0 -> 260.1, 260.1
% INFO    : Updated Thermal Rating: on line 50324-50327 : Rate B, Rate C - 0.0, 0.0 -> 236.39, 236.39
% INFO    : Updated Thermal Rating: on line 50324-50381 : Rate B, Rate C - 0.0, 0.0 -> 279.6, 279.6
% INFO    : Updated Thermal Rating: on line 50330-50325 : Rate B, Rate C - 0.0, 0.0 -> 278.43, 278.43
% INFO    : Updated Thermal Rating: on line 50326-50327 : Rate B, Rate C - 0.0, 0.0 -> 276.04, 276.04
% INFO    : Updated Thermal Rating: on line 50327-50341 : Rate B, Rate C - 0.0, 0.0 -> 295.2, 295.2
% INFO    : Updated Thermal Rating: on line 50341-50330 : Rate B, Rate C - 0.0, 0.0 -> 280.25, 280.25
% INFO    : Updated Thermal Rating: on transformer 50332-50331 : Rate B, Rate C - 0.0, 0.0 -> 114.97, 114.97
% INFO    : Updated Thermal Rating: on line 50331-50352 : Rate B, Rate C - 0.0, 0.0 -> 258.38, 258.38
% INFO    : Updated Thermal Rating: on transformer 50335-50334 : Rate B, Rate C - 0.0, 0.0 -> 71.22, 71.22
% INFO    : Updated Thermal Rating: on line 50334-50338 : Rate B, Rate C - 0.0, 0.0 -> 276.55, 276.55
% INFO    : Updated Thermal Rating: on line 50334-50349 : Rate B, Rate C - 0.0, 0.0 -> 267.43, 267.43
% INFO    : Updated Thermal Rating: on line 50339-50335 : Rate B, Rate C - 0.0, 0.0 -> 144.07, 144.07
% INFO    : Updated Thermal Rating: on line 50335-50346 : Rate B, Rate C - 0.0, 0.0 -> 136.89, 136.89
% INFO    : Updated Thermal Rating: on line 50335-60029 : Rate B, Rate C - 0.0, 0.0 -> 133.15, 133.15
% INFO    : Updated Thermal Rating: on transformer 50338-50337 : Rate B, Rate C - 0.0, 0.0 -> 625.37, 625.37
% INFO    : Updated Thermal Rating: on line 50337-50367 : Rate B, Rate C - 0.0, 0.0 -> 2177.86, 2177.86
% INFO    : Updated Thermal Rating: on transformer 50339-50338 : Rate B, Rate C - 0.0, 0.0 -> 132.03, 132.03
% INFO    : Updated Thermal Rating: on transformer 50340-50343 : Rate B, Rate C - 0.0, 0.0 -> 888.03, 888.03
% INFO    : Updated Thermal Rating: on line 50380-50340 : Rate B, Rate C - 0.0, 0.0 -> 2704.03, 2704.03
% INFO    : Updated Thermal Rating: on line 50340-50458 : Rate B, Rate C - 0.0, 0.0 -> 2487.21, 2487.21
% INFO    : Updated Thermal Rating: on transformer 50341-50343 : Rate B, Rate C - 0.0, 0.0 -> 737.13, 737.13
% INFO    : Updated Thermal Rating: on line 50344-50341 : Rate B, Rate C - 0.0, 0.0 -> 230.86, 230.86
% INFO    : Updated Thermal Rating: on line 50341-50354 : Rate B, Rate C - 0.0, 0.0 -> 305.03, 305.03
% INFO    : Updated Thermal Rating: on transformer 50342-50343 : Rate B, Rate C - 0.0, 0.0 -> 150.9, 150.9
% INFO    : Updated Thermal Rating: on line 50344-50459 : Rate B, Rate C - 0.0, 0.0 -> 236.93, 236.93
% INFO    : Updated Thermal Rating: on transformer 50345-50348 : Rate B, Rate C - 0.0, 0.0 -> 158.5, 158.5
% INFO    : Updated Thermal Rating: on transformer 50346-50348 : Rate B, Rate C - 0.0, 0.0 -> 58.5, 58.5
% INFO    : Updated Thermal Rating: on transformer 50347-50348 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 50349-50352 : Rate B, Rate C - 0.0, 0.0 -> 267.92, 267.92
% INFO    : Updated Thermal Rating: on transformer 50353-50352 : Rate B, Rate C - 0.0, 0.0 -> 85.55, 85.55
% INFO    : Updated Thermal Rating: on line 50352-60010 : Rate B, Rate C - 0.0, 0.0 -> 214.11, 214.11
% INFO    : Updated Thermal Rating: on line 50352-60736 : Rate B, Rate C - 0.0, 0.0 -> 241.38, 241.38
% INFO    : Updated Thermal Rating: on line 50381-50354 : Rate B, Rate C - 0.0, 0.0 -> 282.99, 282.99
% INFO    : Updated Thermal Rating: on transformer 50356-50359 : Rate B, Rate C - 0.0, 0.0 -> 801.0, 801.0
% INFO    : Updated Thermal Rating: on transformer 50356-50360 : Rate B, Rate C - 0.0, 0.0 -> 1066.62, 1066.62
% INFO    : Updated Thermal Rating: on transformer 50356-50361 : Rate B, Rate C - 0.0, 0.0 -> 1063.74, 1063.74
% INFO    : Updated Thermal Rating: on transformer 50356-50362 : Rate B, Rate C - 0.0, 0.0 -> 1060.01, 1060.01
% INFO    : Updated Thermal Rating: on transformer 50356-50363 : Rate B, Rate C - 0.0, 0.0 -> 1053.8, 1053.8
% INFO    : Updated Thermal Rating: on transformer 50356-50364 : Rate B, Rate C - 0.0, 0.0 -> 1047.95, 1047.95
% INFO    : Updated Thermal Rating: on transformer 50356-50365 : Rate B, Rate C - 0.0, 0.0 -> 1033.82, 1033.82
% INFO    : Updated Thermal Rating: on transformer 50356-50366 : Rate B, Rate C - 0.0, 0.0 -> 82.31, 82.31
% INFO    : Updated Thermal Rating: on transformer 50357-50359 : Rate B, Rate C - 0.0, 0.0 -> 751.0, 751.0
% INFO    : Updated Thermal Rating: on transformer 50358-50359 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 50368-50367 : Rate B, Rate C - 0.0, 0.0 -> 632.39, 632.39
% INFO    : Updated Thermal Rating: on line 50395-50367 : Rate B, Rate C - 0.0, 0.0 -> 2436.22, 2436.22
% INFO    : Updated Thermal Rating: on line 50367-50414 : Rate B, Rate C - 0.0, 0.0 -> 2404.87, 2404.87
% INFO    : Updated Thermal Rating: on line 50444-50369 : Rate B, Rate C - 0.0, 0.0 -> 268.82, 268.82
% INFO    : Updated Thermal Rating: on transformer 50370-50373 : Rate B, Rate C - 0.0, 0.0 -> 848.1, 848.1
% INFO    : Updated Thermal Rating: on transformer 50370-50374 : Rate B, Rate C - 0.0, 0.0 -> 630.46, 630.46
% INFO    : Updated Thermal Rating: on transformer 50370-50375 : Rate B, Rate C - 0.0, 0.0 -> 627.49, 627.49
% INFO    : Updated Thermal Rating: on transformer 50370-50376 : Rate B, Rate C - 0.0, 0.0 -> 415.83, 415.83
% INFO    : Updated Thermal Rating: on transformer 50371-50373 : Rate B, Rate C - 0.0, 0.0 -> 773.1, 773.1
% INFO    : Updated Thermal Rating: on transformer 50372-50373 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 50438-50377 : Rate B, Rate C - 0.0, 0.0 -> 2317.71, 2317.71
% INFO    : Updated Thermal Rating: on line 50377-50452 : Rate B, Rate C - 0.0, 0.0 -> 1974.2, 1974.2
% INFO    : Updated Thermal Rating: on transformer 50378-50379 : Rate B, Rate C - 0.0, 0.0 -> 132.35, 132.35
% INFO    : Updated Thermal Rating: on transformer 50381-50380 : Rate B, Rate C - 0.0, 0.0 -> 669.0, 669.0
% INFO    : Updated Thermal Rating: on transformer 50380-50382 : Rate B, Rate C - 0.0, 0.0 -> 1161.56, 1161.56
% INFO    : Updated Thermal Rating: on transformer 50384-50383 : Rate B, Rate C - 0.0, 0.0 -> 853.39, 853.39
% INFO    : Updated Thermal Rating: on transformer 50383-50385 : Rate B, Rate C - 0.0, 0.0 -> 1349.86, 1349.86
% INFO    : Updated Thermal Rating: on transformer 50383-50386 : Rate B, Rate C - 0.0, 0.0 -> 1307.04, 1307.04
% INFO    : Updated Thermal Rating: on transformer 50384-50387 : Rate B, Rate C - 0.0, 0.0 -> 77.36, 77.36
% INFO    : Updated Thermal Rating: on line 50384-50401 : Rate B, Rate C - 0.0, 0.0 -> 326.14, 326.14
% INFO    : Updated Thermal Rating: on line 50406-50388 : Rate B, Rate C - 0.0, 0.0 -> 2971.09, 2971.09
% INFO    : Updated Thermal Rating: on transformer 50389-50390 : Rate B, Rate C - 0.0, 0.0 -> 145.61, 145.61
% INFO    : Updated Thermal Rating: on transformer 50389-50391 : Rate B, Rate C - 0.0, 0.0 -> 72.09, 72.09
% INFO    : Updated Thermal Rating: on line 50389-50394 : Rate B, Rate C - 0.0, 0.0 -> 298.44, 298.44
% INFO    : Updated Thermal Rating: on transformer 50392-50393 : Rate B, Rate C - 0.0, 0.0 -> 123.62, 123.62
% INFO    : Updated Thermal Rating: on transformer 50396-50395 : Rate B, Rate C - 0.0, 0.0 -> 780.55, 780.55
% INFO    : Updated Thermal Rating: on transformer 50395-50397 : Rate B, Rate C - 0.0, 0.0 -> 1190.01, 1190.01
% INFO    : Updated Thermal Rating: on transformer 50395-50398 : Rate B, Rate C - 0.0, 0.0 -> 1186.85, 1186.85
% INFO    : Updated Thermal Rating: on transformer 50395-50399 : Rate B, Rate C - 0.0, 0.0 -> 1169.24, 1169.24
% INFO    : Updated Thermal Rating: on line 50395-50414 : Rate B, Rate C - 0.0, 0.0 -> 2622.48, 2622.48
% INFO    : Updated Thermal Rating: on line 50395-50446 : Rate B, Rate C - 0.0, 0.0 -> 3173.4, 3173.4
% INFO    : Updated Thermal Rating: on transformer 50401-50400 : Rate B, Rate C - 0.0, 0.0 -> 789.25, 789.25
% INFO    : Updated Thermal Rating: on transformer 50400-50402 : Rate B, Rate C - 0.0, 0.0 -> 944.93, 944.93
% INFO    : Updated Thermal Rating: on transformer 50400-50403 : Rate B, Rate C - 0.0, 0.0 -> 943.17, 943.17
% INFO    : Updated Thermal Rating: on transformer 50400-50404 : Rate B, Rate C - 0.0, 0.0 -> 943.14, 943.14
% INFO    : Updated Thermal Rating: on line 50405-50428 : Rate B, Rate C - 0.0, 0.0 -> 2713.76, 2713.76
% INFO    : Updated Thermal Rating: on transformer 50407-50406 : Rate B, Rate C - 0.0, 0.0 -> 576.82, 576.82
% INFO    : Updated Thermal Rating: on transformer 50406-50409 : Rate B, Rate C - 0.0, 0.0 -> 916.04, 916.04
% INFO    : Updated Thermal Rating: on line 50406-50446 : Rate B, Rate C - 0.0, 0.0 -> 2908.44, 2908.44
% INFO    : Updated Thermal Rating: on line 50406-50453 : Rate B, Rate C - 0.0, 0.0 -> 3217.61, 3217.61
% INFO    : Updated Thermal Rating: on transformer 50408-50407 : Rate B, Rate C - 0.0, 0.0 -> 296.15, 296.15
% INFO    : Updated Thermal Rating: on line 50422-50408 : Rate B, Rate C - 0.0, 0.0 -> 228.58, 228.58
% INFO    : Updated Thermal Rating: on transformer 50411-50412 : Rate B, Rate C - 0.0, 0.0 -> 79.98, 79.98
% INFO    : Updated Thermal Rating: on transformer 50411-50413 : Rate B, Rate C - 0.0, 0.0 -> 30.0, 30.0
% INFO    : Updated Thermal Rating: on transformer 50414-50417 : Rate B, Rate C - 0.0, 0.0 -> 873.74, 873.74
% INFO    : Updated Thermal Rating: on transformer 50414-50418 : Rate B, Rate C - 0.0, 0.0 -> 724.37, 724.37
% INFO    : Updated Thermal Rating: on transformer 50414-50419 : Rate B, Rate C - 0.0, 0.0 -> 715.0, 715.0
% INFO    : Updated Thermal Rating: on line 50414-50428 : Rate B, Rate C - 0.0, 0.0 -> 2929.38, 2929.38
% INFO    : Updated Thermal Rating: on transformer 50415-50417 : Rate B, Rate C - 0.0, 0.0 -> 748.74, 748.74
% INFO    : Updated Thermal Rating: on transformer 50416-50417 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 50420-50421 : Rate B, Rate C - 0.0, 0.0 -> 193.93, 193.93
% INFO    : Updated Thermal Rating: on transformer 50424-50427 : Rate B, Rate C - 0.0, 0.0 -> 886.83, 886.83
% INFO    : Updated Thermal Rating: on transformer 50425-50427 : Rate B, Rate C - 0.0, 0.0 -> 786.83, 786.83
% INFO    : Updated Thermal Rating: on transformer 50426-50427 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 50430-50429 : Rate B, Rate C - 0.0, 0.0 -> 716.42, 716.42
% INFO    : Updated Thermal Rating: on transformer 50429-50433 : Rate B, Rate C - 0.0, 0.0 -> 780.56, 780.56
% INFO    : Updated Thermal Rating: on transformer 50429-50434 : Rate B, Rate C - 0.0, 0.0 -> 223.69, 223.69
% INFO    : Updated Thermal Rating: on transformer 50431-50430 : Rate B, Rate C - 0.0, 0.0 -> 411.38, 411.38
% INFO    : Updated Thermal Rating: on transformer 50432-50431 : Rate B, Rate C - 0.0, 0.0 -> 87.3, 87.3
% INFO    : Updated Thermal Rating: on line 70130-50432 : Rate B, Rate C - 0.0, 0.0 -> 216.29, 216.29
% INFO    : Updated Thermal Rating: on line 50458-50435 : Rate B, Rate C - 0.0, 0.0 -> 2621.93, 2621.93
% INFO    : Updated Thermal Rating: on line 70122-50436 : Rate B, Rate C - 0.0, 0.0 -> 1082.51, 1082.51
% INFO    : Updated Thermal Rating: on line 50436-70157 : Rate B, Rate C - 0.0, 0.0 -> 1257.13, 1257.13
% INFO    : Updated Thermal Rating: on transformer 50439-50438 : Rate B, Rate C - 0.0, 0.0 -> 753.89, 753.89
% INFO    : Updated Thermal Rating: on transformer 50438-50440 : Rate B, Rate C - 0.0, 0.0 -> 649.41, 649.41
% INFO    : Updated Thermal Rating: on transformer 50438-50441 : Rate B, Rate C - 0.0, 0.0 -> 641.16, 641.16
% INFO    : Updated Thermal Rating: on transformer 50438-50442 : Rate B, Rate C - 0.0, 0.0 -> 299.21, 299.21
% INFO    : Updated Thermal Rating: on transformer 50444-50443 : Rate B, Rate C - 0.0, 0.0 -> 849.19, 849.19
% INFO    : Updated Thermal Rating: on transformer 50447-50446 : Rate B, Rate C - 0.0, 0.0 -> 652.35, 652.35
% INFO    : Updated Thermal Rating: on transformer 50446-50448 : Rate B, Rate C - 0.0, 0.0 -> 1164.08, 1164.08
% INFO    : Updated Thermal Rating: on transformer 50446-50449 : Rate B, Rate C - 0.0, 0.0 -> 1161.9, 1161.9
% INFO    : Updated Thermal Rating: on transformer 50451-50450 : Rate B, Rate C - 0.0, 0.0 -> 359.01, 359.01
% INFO    : Updated Thermal Rating: on transformer 50453-50456 : Rate B, Rate C - 0.0, 0.0 -> 1008.94, 1008.94
% INFO    : Updated Thermal Rating: on transformer 50453-50457 : Rate B, Rate C - 0.0, 0.0 -> 612.1, 612.1
% INFO    : Updated Thermal Rating: on transformer 50454-50456 : Rate B, Rate C - 0.0, 0.0 -> 883.94, 883.94
% INFO    : Updated Thermal Rating: on transformer 50455-50456 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 50459-50458 : Rate B, Rate C - 0.0, 0.0 -> 448.54, 448.54
% INFO    : Updated Thermal Rating: on transformer 50460-50459 : Rate B, Rate C - 0.0, 0.0 -> 75.79, 75.79
% INFO    : Updated Thermal Rating: on line 70017-50460 : Rate B, Rate C - 0.0, 0.0 -> 186.89, 186.89
% INFO    : Updated Thermal Rating: on line 53000-53004 : Rate B, Rate C - 0.0, 0.0 -> 152.03, 152.03
% INFO    : Updated Thermal Rating: on line 53013-53000 : Rate B, Rate C - 0.0, 0.0 -> 128.63, 128.63
% INFO    : Updated Thermal Rating: on line 53006-53001 : Rate B, Rate C - 0.0, 0.0 -> 172.32, 172.32
% INFO    : Updated Thermal Rating: on line 53001-53007 : Rate B, Rate C - 0.0, 0.0 -> 156.67, 156.67
% INFO    : Updated Thermal Rating: on line 60578-53001 : Rate B, Rate C - 0.0, 0.0 -> 150.89, 150.89
% INFO    : Updated Thermal Rating: on line 53003-53019 : Rate B, Rate C - 0.0, 0.0 -> 139.27, 139.27
% INFO    : Updated Thermal Rating: on line 53003-53021 : Rate B, Rate C - 0.0, 0.0 -> 143.4, 143.4
% INFO    : Updated Thermal Rating: on line 53004-53020 : Rate B, Rate C - 0.0, 0.0 -> 177.66, 177.66
% INFO    : Updated Thermal Rating: on line 53022-53004 : Rate B, Rate C - 0.0, 0.0 -> 154.43, 154.43
% INFO    : Updated Thermal Rating: on line 53014-53006 : Rate B, Rate C - 0.0, 0.0 -> 164.34, 164.34
% INFO    : Updated Thermal Rating: on line 53020-53006 : Rate B, Rate C - 0.0, 0.0 -> 188.04, 188.04
% INFO    : Updated Thermal Rating: on line 53007-53014 : Rate B, Rate C - 0.0, 0.0 -> 174.45, 174.45
% INFO    : Updated Thermal Rating: on line 53007-60155 : Rate B, Rate C - 0.0, 0.0 -> 188.2, 188.2
% INFO    : Updated Thermal Rating: on line 53007-60578 : Rate B, Rate C - 0.0, 0.0 -> 141.64, 141.64
% INFO    : Updated Thermal Rating: on line 53009-53013 : Rate B, Rate C - 0.0, 0.0 -> 138.82, 138.82
% INFO    : Updated Thermal Rating: on line 53009-53030 : Rate B, Rate C - 0.0, 0.0 -> 144.93, 144.93
% INFO    : Updated Thermal Rating: on line 53010-53012 : Rate B, Rate C - 0.0, 0.0 -> 139.8, 139.8
% INFO    : Updated Thermal Rating: on line 53019-53010 : Rate B, Rate C - 0.0, 0.0 -> 147.47, 147.47
% INFO    : Updated Thermal Rating: on line 53027-53012 : Rate B, Rate C - 0.0, 0.0 -> 122.29, 122.29
% INFO    : Updated Thermal Rating: on line 53019-53017 : Rate B, Rate C - 0.0, 0.0 -> 145.98, 145.98
% INFO    : Updated Thermal Rating: on line 53021-53017 : Rate B, Rate C - 0.0, 0.0 -> 163.39, 163.39
% INFO    : Updated Thermal Rating: on line 53033-53017 : Rate B, Rate C - 0.0, 0.0 -> 140.63, 140.63
% INFO    : Updated Thermal Rating: on line 53271-53021 : Rate B, Rate C - 0.0, 0.0 -> 178.37, 178.37
% INFO    : Updated Thermal Rating: on line 53023-53022 : Rate B, Rate C - 0.0, 0.0 -> 141.96, 141.96
% INFO    : Updated Thermal Rating: on line 53023-53032 : Rate B, Rate C - 0.0, 0.0 -> 98.35, 98.35
% INFO    : Updated Thermal Rating: on line 53048-53023 : Rate B, Rate C - 0.0, 0.0 -> 185.39, 185.39
% INFO    : Updated Thermal Rating: on line 53024-53026 : Rate B, Rate C - 0.0, 0.0 -> 134.84, 134.84
% INFO    : Updated Thermal Rating: on line 53031-53024 : Rate B, Rate C - 0.0, 0.0 -> 162.27, 162.27
% INFO    : Updated Thermal Rating: on line 53048-53026 : Rate B, Rate C - 0.0, 0.0 -> 139.15, 139.15
% INFO    : Updated Thermal Rating: on line 53039-53027 : Rate B, Rate C - 0.0, 0.0 -> 99.97, 99.97
% INFO    : Updated Thermal Rating: on line 53028-53030 : Rate B, Rate C - 0.0, 0.0 -> 126.66, 126.66
% INFO    : Updated Thermal Rating: on line 53028-53051 : Rate B, Rate C - 0.0, 0.0 -> 138.1, 138.1
% INFO    : Updated Thermal Rating: on line 53032-53029 : Rate B, Rate C - 0.0, 0.0 -> 147.6, 147.6
% INFO    : Updated Thermal Rating: on line 53029-53040 : Rate B, Rate C - 0.0, 0.0 -> 162.37, 162.37
% INFO    : Updated Thermal Rating: on line 53030-53271 : Rate B, Rate C - 0.0, 0.0 -> 151.89, 151.89
% INFO    : Updated Thermal Rating: on line 53031-53045 : Rate B, Rate C - 0.0, 0.0 -> 150.23, 150.23
% INFO    : Updated Thermal Rating: on line 53031-53063 : Rate B, Rate C - 0.0, 0.0 -> 168.08, 168.08
% INFO    : Updated Thermal Rating: on line 53039-53033 : Rate B, Rate C - 0.0, 0.0 -> 128.33, 128.33
% INFO    : Updated Thermal Rating: on line 53035-53037 : Rate B, Rate C - 0.0, 0.0 -> 173.81, 173.81
% INFO    : Updated Thermal Rating: on line 53035-53052 : Rate B, Rate C - 0.0, 0.0 -> 152.12, 152.12
% INFO    : Updated Thermal Rating: on transformer 53037-53036 : Rate B, Rate C - 0.0, 0.0 -> 164.72, 164.72
% INFO    : Updated Thermal Rating: on line 53036-53272 : Rate B, Rate C - 0.0, 0.0 -> 558.27, 558.27
% INFO    : Updated Thermal Rating: on line 53036-53290 : Rate B, Rate C - 0.0, 0.0 -> 467.18, 467.18
% INFO    : Updated Thermal Rating: on line 53039-53037 : Rate B, Rate C - 0.0, 0.0 -> 111.34, 111.34
% INFO    : Updated Thermal Rating: on transformer 53040-53043 : Rate B, Rate C - 0.0, 0.0 -> 126.66, 126.66
% INFO    : Updated Thermal Rating: on line 53064-53040 : Rate B, Rate C - 0.0, 0.0 -> 187.55, 187.55
% INFO    : Updated Thermal Rating: on transformer 53041-53043 : Rate B, Rate C - 0.0, 0.0 -> 63.33, 63.33
% INFO    : Updated Thermal Rating: on transformer 53042-53043 : Rate B, Rate C - 0.0, 0.0 -> 63.33, 63.33
% INFO    : Updated Thermal Rating: on transformer 53044-53047 : Rate B, Rate C - 0.0, 0.0 -> 311.19, 311.19
% INFO    : Updated Thermal Rating: on line 53135-53044 : Rate B, Rate C - 0.0, 0.0 -> 577.0, 577.0
% INFO    : Updated Thermal Rating: on line 53306-53044 : Rate B, Rate C - 0.0, 0.0 -> 577.02, 577.02
% INFO    : Updated Thermal Rating: on transformer 53045-53047 : Rate B, Rate C - 0.0, 0.0 -> 209.12, 209.12
% INFO    : Updated Thermal Rating: on line 53048-53045 : Rate B, Rate C - 0.0, 0.0 -> 163.89, 163.89
% INFO    : Updated Thermal Rating: on line 53057-53045 : Rate B, Rate C - 0.0, 0.0 -> 167.2, 167.2
% INFO    : Updated Thermal Rating: on transformer 53046-53047 : Rate B, Rate C - 0.0, 0.0 -> 102.07, 102.07
% INFO    : Updated Thermal Rating: on line 53048-53057 : Rate B, Rate C - 0.0, 0.0 -> 139.27, 139.27
% INFO    : Updated Thermal Rating: on line 53062-53051 : Rate B, Rate C - 0.0, 0.0 -> 137.39, 137.39
% INFO    : Updated Thermal Rating: on line 53051-53086 : Rate B, Rate C - 0.0, 0.0 -> 147.79, 147.79
% INFO    : Updated Thermal Rating: on line 53052-53117 : Rate B, Rate C - 0.0, 0.0 -> 176.17, 176.17
% INFO    : Updated Thermal Rating: on line 80074-53052 : Rate B, Rate C - 0.0, 0.0 -> 158.85, 158.85
% INFO    : Updated Thermal Rating: on line 53114-53054 : Rate B, Rate C - 0.0, 0.0 -> 163.65, 163.65
% INFO    : Updated Thermal Rating: on line 53147-53054 : Rate B, Rate C - 0.0, 0.0 -> 162.24, 162.24
% INFO    : Updated Thermal Rating: on line 53059-53065 : Rate B, Rate C - 0.0, 0.0 -> 149.94, 149.94
% INFO    : Updated Thermal Rating: on line 53059-53307 : Rate B, Rate C - 0.0, 0.0 -> 157.02, 157.02
% INFO    : Updated Thermal Rating: on line 53062-53101 : Rate B, Rate C - 0.0, 0.0 -> 154.32, 154.32
% INFO    : Updated Thermal Rating: on line 53063-53249 : Rate B, Rate C - 0.0, 0.0 -> 175.52, 175.52
% INFO    : Updated Thermal Rating: on line 53064-53153 : Rate B, Rate C - 0.0, 0.0 -> 190.48, 190.48
% INFO    : Updated Thermal Rating: on line 53065-53249 : Rate B, Rate C - 0.0, 0.0 -> 140.73, 140.73
% INFO    : Updated Thermal Rating: on line 53066-53070 : Rate B, Rate C - 0.0, 0.0 -> 117.03, 117.03
% INFO    : Updated Thermal Rating: on line 53101-53066 : Rate B, Rate C - 0.0, 0.0 -> 143.55, 143.55
% INFO    : Updated Thermal Rating: on line 53066-53267 : Rate B, Rate C - 0.0, 0.0 -> 182.09, 182.09
% INFO    : Updated Thermal Rating: on line 53070-53267 : Rate B, Rate C - 0.0, 0.0 -> 155.61, 155.61
% INFO    : Updated Thermal Rating: on line 53072-53071 : Rate B, Rate C - 0.0, 0.0 -> 161.71, 161.71
% INFO    : Updated Thermal Rating: on line 53075-53071 : Rate B, Rate C - 0.0, 0.0 -> 123.86, 123.86
% INFO    : Updated Thermal Rating: on line 53072-53088 : Rate B, Rate C - 0.0, 0.0 -> 193.6, 193.6
% INFO    : Updated Thermal Rating: on line 53075-53073 : Rate B, Rate C - 0.0, 0.0 -> 167.13, 167.13
% INFO    : Updated Thermal Rating: on line 53073-53081 : Rate B, Rate C - 0.0, 0.0 -> 172.46, 172.46
% INFO    : Updated Thermal Rating: on line 53073-53082 : Rate B, Rate C - 0.0, 0.0 -> 148.08, 148.08
% INFO    : Updated Thermal Rating: on line 53078-53083 : Rate B, Rate C - 0.0, 0.0 -> 164.76, 164.76
% INFO    : Updated Thermal Rating: on line 53078-53096 : Rate B, Rate C - 0.0, 0.0 -> 128.92, 128.92
% INFO    : Updated Thermal Rating: on line 53080-53106 : Rate B, Rate C - 0.0, 0.0 -> 194.91, 194.91
% INFO    : Updated Thermal Rating: on line 53080-53123 : Rate B, Rate C - 0.0, 0.0 -> 191.72, 191.72
% INFO    : Updated Thermal Rating: on line 53080-53307 : Rate B, Rate C - 0.0, 0.0 -> 223.83, 223.83
% INFO    : Updated Thermal Rating: on line 53080-53307 : Rate B, Rate C - 0.0, 0.0 -> 223.83, 223.83
% INFO    : Updated Thermal Rating: on line 53106-53081 : Rate B, Rate C - 0.0, 0.0 -> 192.11, 192.11
% INFO    : Updated Thermal Rating: on line 53082-53096 : Rate B, Rate C - 0.0, 0.0 -> 173.66, 173.66
% INFO    : Updated Thermal Rating: on line 53083-53307 : Rate B, Rate C - 0.0, 0.0 -> 187.74, 187.74
% INFO    : Updated Thermal Rating: on line 53103-53085 : Rate B, Rate C - 0.0, 0.0 -> 168.49, 168.49
% INFO    : Updated Thermal Rating: on line 53085-53116 : Rate B, Rate C - 0.0, 0.0 -> 134.97, 134.97
% INFO    : Updated Thermal Rating: on line 53267-53085 : Rate B, Rate C - 0.0, 0.0 -> 179.7, 179.7
% INFO    : Updated Thermal Rating: on line 53103-53086 : Rate B, Rate C - 0.0, 0.0 -> 173.79, 173.79
% INFO    : Updated Thermal Rating: on line 53088-53307 : Rate B, Rate C - 0.0, 0.0 -> 199.73, 199.73
% INFO    : Updated Thermal Rating: on line 53249-53092 : Rate B, Rate C - 0.0, 0.0 -> 127.57, 127.57
% INFO    : Updated Thermal Rating: on line 53092-53307 : Rate B, Rate C - 0.0, 0.0 -> 147.48, 147.48
% INFO    : Updated Thermal Rating: on line 53093-53291 : Rate B, Rate C - 0.0, 0.0 -> 196.12, 196.12
% INFO    : Updated Thermal Rating: on line 80001-53093 : Rate B, Rate C - 0.0, 0.0 -> 155.43, 155.43
% INFO    : Updated Thermal Rating: on line 80004-53093 : Rate B, Rate C - 0.0, 0.0 -> 163.08, 163.08
% INFO    : Updated Thermal Rating: on line 53096-53267 : Rate B, Rate C - 0.0, 0.0 -> 215.47, 215.47
% INFO    : Updated Thermal Rating: on line 53110-53098 : Rate B, Rate C - 0.0, 0.0 -> 133.52, 133.52
% INFO    : Updated Thermal Rating: on line 53098-53267 : Rate B, Rate C - 0.0, 0.0 -> 141.26, 141.26
% INFO    : Updated Thermal Rating: on line 53098-53307 : Rate B, Rate C - 0.0, 0.0 -> 162.73, 162.73
% INFO    : Updated Thermal Rating: on line 53099-80003 : Rate B, Rate C - 0.0, 0.0 -> 190.25, 190.25
% INFO    : Updated Thermal Rating: on line 53099-80017 : Rate B, Rate C - 0.0, 0.0 -> 187.05, 187.05
% INFO    : Updated Thermal Rating: on line 53101-53125 : Rate B, Rate C - 0.0, 0.0 -> 154.5, 154.5
% INFO    : Updated Thermal Rating: on line 53119-53103 : Rate B, Rate C - 0.0, 0.0 -> 154.87, 154.87
% INFO    : Updated Thermal Rating: on line 53107-53111 : Rate B, Rate C - 0.0, 0.0 -> 120.11, 120.11
% INFO    : Updated Thermal Rating: on line 53123-53107 : Rate B, Rate C - 0.0, 0.0 -> 145.38, 145.38
% INFO    : Updated Thermal Rating: on line 53133-53110 : Rate B, Rate C - 0.0, 0.0 -> 139.57, 139.57
% INFO    : Updated Thermal Rating: on line 53133-53111 : Rate B, Rate C - 0.0, 0.0 -> 162.7, 162.7
% INFO    : Updated Thermal Rating: on line 53113-53112 : Rate B, Rate C - 0.0, 0.0 -> 134.35, 134.35
% INFO    : Updated Thermal Rating: on line 53112-53291 : Rate B, Rate C - 0.0, 0.0 -> 159.48, 159.48
% INFO    : Updated Thermal Rating: on line 53113-53137 : Rate B, Rate C - 0.0, 0.0 -> 136.72, 136.72
% INFO    : Updated Thermal Rating: on line 53258-53114 : Rate B, Rate C - 0.0, 0.0 -> 169.66, 169.66
% INFO    : Updated Thermal Rating: on line 53116-53258 : Rate B, Rate C - 0.0, 0.0 -> 169.5, 169.5
% INFO    : Updated Thermal Rating: on line 53142-53117 : Rate B, Rate C - 0.0, 0.0 -> 178.96, 178.96
% INFO    : Updated Thermal Rating: on line 53119-53267 : Rate B, Rate C - 0.0, 0.0 -> 170.33, 170.33
% INFO    : Updated Thermal Rating: on line 53240-53120 : Rate B, Rate C - 0.0, 0.0 -> 175.98, 175.98
% INFO    : Updated Thermal Rating: on line 53265-53120 : Rate B, Rate C - 0.0, 0.0 -> 146.83, 146.83
% INFO    : Updated Thermal Rating: on line 53120-80005 : Rate B, Rate C - 0.0, 0.0 -> 181.84, 181.84
% INFO    : Updated Thermal Rating: on line 53123-53121 : Rate B, Rate C - 0.0, 0.0 -> 136.45, 136.45
% INFO    : Updated Thermal Rating: on line 53127-53121 : Rate B, Rate C - 0.0, 0.0 -> 139.22, 139.22
% INFO    : Updated Thermal Rating: on line 53128-53121 : Rate B, Rate C - 0.0, 0.0 -> 149.37, 149.37
% INFO    : Updated Thermal Rating: on line 53125-53307 : Rate B, Rate C - 0.0, 0.0 -> 158.21, 158.21
% INFO    : Updated Thermal Rating: on line 53127-53129 : Rate B, Rate C - 0.0, 0.0 -> 130.0, 130.0
% INFO    : Updated Thermal Rating: on line 53127-53140 : Rate B, Rate C - 0.0, 0.0 -> 166.24, 166.24
% INFO    : Updated Thermal Rating: on line 53128-53307 : Rate B, Rate C - 0.0, 0.0 -> 173.33, 173.33
% INFO    : Updated Thermal Rating: on line 53129-53139 : Rate B, Rate C - 0.0, 0.0 -> 135.16, 135.16
% INFO    : Updated Thermal Rating: on line 53129-53167 : Rate B, Rate C - 0.0, 0.0 -> 142.52, 142.52
% INFO    : Updated Thermal Rating: on line 53131-53146 : Rate B, Rate C - 0.0, 0.0 -> 162.98, 162.98
% INFO    : Updated Thermal Rating: on line 53131-53291 : Rate B, Rate C - 0.0, 0.0 -> 184.2, 184.2
% INFO    : Updated Thermal Rating: on line 53143-53132 : Rate B, Rate C - 0.0, 0.0 -> 138.62, 138.62
% INFO    : Updated Thermal Rating: on line 53146-53132 : Rate B, Rate C - 0.0, 0.0 -> 141.24, 141.24
% INFO    : Updated Thermal Rating: on line 53136-53133 : Rate B, Rate C - 0.0, 0.0 -> 197.7, 197.7
% INFO    : Updated Thermal Rating: on transformer 53136-53135 : Rate B, Rate C - 0.0, 0.0 -> 235.79, 235.79
% INFO    : Updated Thermal Rating: on transformer 53136-53135 : Rate B, Rate C - 0.0, 0.0 -> 235.79, 235.79
% INFO    : Updated Thermal Rating: on transformer 53136-53135 : Rate B, Rate C - 0.0, 0.0 -> 235.79, 235.79
% INFO    : Updated Thermal Rating: on line 53135-53229 : Rate B, Rate C - 0.0, 0.0 -> 558.61, 558.61
% INFO    : Updated Thermal Rating: on line 53135-53266 : Rate B, Rate C - 0.0, 0.0 -> 425.11, 425.11
% INFO    : Updated Thermal Rating: on line 53135-53273 : Rate B, Rate C - 0.0, 0.0 -> 559.7, 559.7
% INFO    : Updated Thermal Rating: on line 53135-53306 : Rate B, Rate C - 0.0, 0.0 -> 488.07, 488.07
% INFO    : Updated Thermal Rating: on line 53136-53140 : Rate B, Rate C - 0.0, 0.0 -> 191.86, 191.86
% INFO    : Updated Thermal Rating: on line 53136-53149 : Rate B, Rate C - 0.0, 0.0 -> 184.5, 184.5
% INFO    : Updated Thermal Rating: on line 53138-53137 : Rate B, Rate C - 0.0, 0.0 -> 157.34, 157.34
% INFO    : Updated Thermal Rating: on line 53138-53143 : Rate B, Rate C - 0.0, 0.0 -> 159.12, 159.12
% INFO    : Updated Thermal Rating: on line 53138-53227 : Rate B, Rate C - 0.0, 0.0 -> 193.71, 193.71
% INFO    : Updated Thermal Rating: on line 53139-53149 : Rate B, Rate C - 0.0, 0.0 -> 156.5, 156.5
% INFO    : Updated Thermal Rating: on line 53291-53142 : Rate B, Rate C - 0.0, 0.0 -> 187.4, 187.4
% INFO    : Updated Thermal Rating: on line 53173-53147 : Rate B, Rate C - 0.0, 0.0 -> 143.04, 143.04
% INFO    : Updated Thermal Rating: on line 53148-53150 : Rate B, Rate C - 0.0, 0.0 -> 155.22, 155.22
% INFO    : Updated Thermal Rating: on line 53148-53267 : Rate B, Rate C - 0.0, 0.0 -> 137.32, 137.32
% INFO    : Updated Thermal Rating: on line 53274-53150 : Rate B, Rate C - 0.0, 0.0 -> 185.23, 185.23
% INFO    : Updated Thermal Rating: on line 53152-53164 : Rate B, Rate C - 0.0, 0.0 -> 141.79, 141.79
% INFO    : Updated Thermal Rating: on line 53227-53152 : Rate B, Rate C - 0.0, 0.0 -> 149.67, 149.67
% INFO    : Updated Thermal Rating: on line 53153-60070 : Rate B, Rate C - 0.0, 0.0 -> 186.97, 186.97
% INFO    : Updated Thermal Rating: on line 53153-60105 : Rate B, Rate C - 0.0, 0.0 -> 141.43, 141.43
% INFO    : Updated Thermal Rating: on line 53291-53155 : Rate B, Rate C - 0.0, 0.0 -> 174.31, 174.31
% INFO    : Updated Thermal Rating: on line 53155-80001 : Rate B, Rate C - 0.0, 0.0 -> 150.72, 150.72
% INFO    : Updated Thermal Rating: on line 53258-53156 : Rate B, Rate C - 0.0, 0.0 -> 160.0, 160.0
% INFO    : Updated Thermal Rating: on line 53158-53159 : Rate B, Rate C - 0.0, 0.0 -> 102.93, 102.93
% INFO    : Updated Thermal Rating: on line 53158-53171 : Rate B, Rate C - 0.0, 0.0 -> 159.59, 159.59
% INFO    : Updated Thermal Rating: on line 53166-53159 : Rate B, Rate C - 0.0, 0.0 -> 160.66, 160.66
% INFO    : Updated Thermal Rating: on line 53162-53164 : Rate B, Rate C - 0.0, 0.0 -> 111.0, 111.0
% INFO    : Updated Thermal Rating: on line 53162-53173 : Rate B, Rate C - 0.0, 0.0 -> 137.54, 137.54
% INFO    : Updated Thermal Rating: on line 53164-53169 : Rate B, Rate C - 0.0, 0.0 -> 117.52, 117.52
% INFO    : Updated Thermal Rating: on line 53164-53301 : Rate B, Rate C - 0.0, 0.0 -> 146.11, 146.11
% INFO    : Updated Thermal Rating: on line 53166-53274 : Rate B, Rate C - 0.0, 0.0 -> 165.31, 165.31
% INFO    : Updated Thermal Rating: on line 53182-53167 : Rate B, Rate C - 0.0, 0.0 -> 155.66, 155.66
% INFO    : Updated Thermal Rating: on line 53169-53301 : Rate B, Rate C - 0.0, 0.0 -> 133.91, 133.91
% INFO    : Updated Thermal Rating: on line 53179-53171 : Rate B, Rate C - 0.0, 0.0 -> 162.22, 162.22
% INFO    : Updated Thermal Rating: on line 53174-53175 : Rate B, Rate C - 0.0, 0.0 -> 97.36, 97.36
% INFO    : Updated Thermal Rating: on line 53175-53252 : Rate B, Rate C - 0.0, 0.0 -> 161.14, 161.14
% INFO    : Updated Thermal Rating: on line 53176-53179 : Rate B, Rate C - 0.0, 0.0 -> 156.87, 156.87
% INFO    : Updated Thermal Rating: on line 53176-53230 : Rate B, Rate C - 0.0, 0.0 -> 164.16, 164.16
% INFO    : Updated Thermal Rating: on line 53178-53279 : Rate B, Rate C - 0.0, 0.0 -> 192.81, 192.81
% INFO    : Updated Thermal Rating: on line 53178-60053 : Rate B, Rate C - 0.0, 0.0 -> 174.09, 174.09
% INFO    : Updated Thermal Rating: on line 53179-53197 : Rate B, Rate C - 0.0, 0.0 -> 149.22, 149.22
% INFO    : Updated Thermal Rating: on line 53180-53182 : Rate B, Rate C - 0.0, 0.0 -> 162.4, 162.4
% INFO    : Updated Thermal Rating: on line 53180-53187 : Rate B, Rate C - 0.0, 0.0 -> 180.79, 180.79
% INFO    : Updated Thermal Rating: on line 53227-53184 : Rate B, Rate C - 0.0, 0.0 -> 181.13, 181.13
% INFO    : Updated Thermal Rating: on line 53184-53237 : Rate B, Rate C - 0.0, 0.0 -> 174.34, 174.34
% INFO    : Updated Thermal Rating: on line 53283-53184 : Rate B, Rate C - 0.0, 0.0 -> 148.86, 148.86
% INFO    : Updated Thermal Rating: on line 53188-53186 : Rate B, Rate C - 0.0, 0.0 -> 156.77, 156.77
% INFO    : Updated Thermal Rating: on line 53186-53194 : Rate B, Rate C - 0.0, 0.0 -> 173.03, 173.03
% INFO    : Updated Thermal Rating: on line 53187-53304 : Rate B, Rate C - 0.0, 0.0 -> 196.14, 196.14
% INFO    : Updated Thermal Rating: on line 53188-53304 : Rate B, Rate C - 0.0, 0.0 -> 125.17, 125.17
% INFO    : Updated Thermal Rating: on line 53189-53201 : Rate B, Rate C - 0.0, 0.0 -> 156.36, 156.36
% INFO    : Updated Thermal Rating: on line 53189-53208 : Rate B, Rate C - 0.0, 0.0 -> 145.94, 145.94
% INFO    : Updated Thermal Rating: on line 53189-53230 : Rate B, Rate C - 0.0, 0.0 -> 176.38, 176.38
% INFO    : Updated Thermal Rating: on line 53192-53247 : Rate B, Rate C - 0.0, 0.0 -> 177.3, 177.3
% INFO    : Updated Thermal Rating: on line 53192-53283 : Rate B, Rate C - 0.0, 0.0 -> 157.68, 157.68
% INFO    : Updated Thermal Rating: on line 53194-53202 : Rate B, Rate C - 0.0, 0.0 -> 181.72, 181.72
% INFO    : Updated Thermal Rating: on line 53194-53214 : Rate B, Rate C - 0.0, 0.0 -> 173.35, 173.35
% INFO    : Updated Thermal Rating: on line 53194-53296 : Rate B, Rate C - 0.0, 0.0 -> 188.91, 188.91
% INFO    : Updated Thermal Rating: on line 53197-53230 : Rate B, Rate C - 0.0, 0.0 -> 155.14, 155.14
% INFO    : Updated Thermal Rating: on line 53296-53199 : Rate B, Rate C - 0.0, 0.0 -> 171.63, 171.63
% INFO    : Updated Thermal Rating: on line 53201-53203 : Rate B, Rate C - 0.0, 0.0 -> 147.14, 147.14
% INFO    : Updated Thermal Rating: on line 53208-53201 : Rate B, Rate C - 0.0, 0.0 -> 142.27, 142.27
% INFO    : Updated Thermal Rating: on line 53210-53201 : Rate B, Rate C - 0.0, 0.0 -> 144.21, 144.21
% INFO    : Updated Thermal Rating: on line 53210-53203 : Rate B, Rate C - 0.0, 0.0 -> 136.2, 136.2
% INFO    : Updated Thermal Rating: on line 53214-53211 : Rate B, Rate C - 0.0, 0.0 -> 168.81, 168.81
% INFO    : Updated Thermal Rating: on transformer 53213-53212 : Rate B, Rate C - 0.0, 0.0 -> 557.3, 557.3
% INFO    : Updated Thermal Rating: on transformer 53212-53215 : Rate B, Rate C - 0.0, 0.0 -> 1136.3, 1136.3
% INFO    : Updated Thermal Rating: on transformer 53212-53216 : Rate B, Rate C - 0.0, 0.0 -> 1134.54, 1134.54
% INFO    : Updated Thermal Rating: on transformer 53212-53217 : Rate B, Rate C - 0.0, 0.0 -> 1132.84, 1132.84
% INFO    : Updated Thermal Rating: on transformer 53212-53218 : Rate B, Rate C - 0.0, 0.0 -> 1130.97, 1130.97
% INFO    : Updated Thermal Rating: on transformer 53214-53213 : Rate B, Rate C - 0.0, 0.0 -> 179.46, 179.46
% INFO    : Updated Thermal Rating: on line 53219-53295 : Rate B, Rate C - 0.0, 0.0 -> 570.0, 570.0
% INFO    : Updated Thermal Rating: on line 53299-53220 : Rate B, Rate C - 0.0, 0.0 -> 2848.2, 2848.2
% INFO    : Updated Thermal Rating: on transformer 53221-53222 : Rate B, Rate C - 0.0, 0.0 -> 40.82, 40.82
% INFO    : Updated Thermal Rating: on transformer 53221-53223 : Rate B, Rate C - 0.0, 0.0 -> 24.18, 24.18
% INFO    : Updated Thermal Rating: on transformer 53221-53224 : Rate B, Rate C - 0.0, 0.0 -> 22.49, 22.49
% INFO    : Updated Thermal Rating: on line 53279-53225 : Rate B, Rate C - 0.0, 0.0 -> 122.82, 122.82
% INFO    : Updated Thermal Rating: on line 53225-60070 : Rate B, Rate C - 0.0, 0.0 -> 179.15, 179.15
% INFO    : Updated Thermal Rating: on line 53301-53227 : Rate B, Rate C - 0.0, 0.0 -> 165.48, 165.48
% INFO    : Updated Thermal Rating: on transformer 53229-53228 : Rate B, Rate C - 0.0, 0.0 -> 814.95, 814.95
% INFO    : Updated Thermal Rating: on transformer 53228-53233 : Rate B, Rate C - 0.0, 0.0 -> 1100.26, 1100.26
% INFO    : Updated Thermal Rating: on line 53228-53305 : Rate B, Rate C - 0.0, 0.0 -> 3100.0, 3100.0
% INFO    : Updated Thermal Rating: on transformer 53229-53232 : Rate B, Rate C - 0.0, 0.0 -> 304.94, 304.94
% INFO    : Updated Thermal Rating: on line 53273-53229 : Rate B, Rate C - 0.0, 0.0 -> 568.37, 568.37
% INFO    : Updated Thermal Rating: on line 53295-53229 : Rate B, Rate C - 0.0, 0.0 -> 547.58, 547.58
% INFO    : Updated Thermal Rating: on transformer 53230-53232 : Rate B, Rate C - 0.0, 0.0 -> 201.75, 201.75
% INFO    : Updated Thermal Rating: on transformer 53231-53232 : Rate B, Rate C - 0.0, 0.0 -> 103.19, 103.19
% INFO    : Updated Thermal Rating: on line 53234-53299 : Rate B, Rate C - 0.0, 0.0 -> 2841.7, 2841.7
% INFO    : Updated Thermal Rating: on line 53237-53289 : Rate B, Rate C - 0.0, 0.0 -> 164.1, 164.1
% INFO    : Updated Thermal Rating: on transformer 53239-53238 : Rate B, Rate C - 0.0, 0.0 -> 980.79, 980.79
% INFO    : Updated Thermal Rating: on transformer 53238-53241 : Rate B, Rate C - 0.0, 0.0 -> 742.62, 742.62
% INFO    : Updated Thermal Rating: on transformer 53238-53242 : Rate B, Rate C - 0.0, 0.0 -> 640.49, 640.49
% INFO    : Updated Thermal Rating: on transformer 53238-53243 : Rate B, Rate C - 0.0, 0.0 -> 636.55, 636.55
% INFO    : Updated Thermal Rating: on transformer 53238-53244 : Rate B, Rate C - 0.0, 0.0 -> 632.92, 632.92
% INFO    : Updated Thermal Rating: on line 53250-53238 : Rate B, Rate C - 0.0, 0.0 -> 2406.68, 2406.68
% INFO    : Updated Thermal Rating: on line 53238-80048 : Rate B, Rate C - 0.0, 0.0 -> 2323.7, 2323.7
% INFO    : Updated Thermal Rating: on transformer 53240-53239 : Rate B, Rate C - 0.0, 0.0 -> 257.54, 257.54
% INFO    : Updated Thermal Rating: on transformer 53240-53239 : Rate B, Rate C - 0.0, 0.0 -> 257.54, 257.54
% INFO    : Updated Thermal Rating: on transformer 53240-53239 : Rate B, Rate C - 0.0, 0.0 -> 257.54, 257.54
% INFO    : Updated Thermal Rating: on line 80010-53240 : Rate B, Rate C - 0.0, 0.0 -> 200.46, 200.46
% INFO    : Updated Thermal Rating: on line 80013-53240 : Rate B, Rate C - 0.0, 0.0 -> 178.38, 178.38
% INFO    : Updated Thermal Rating: on line 53240-80022 : Rate B, Rate C - 0.0, 0.0 -> 179.37, 179.37
% INFO    : Updated Thermal Rating: on line 80006-53245 : Rate B, Rate C - 0.0, 0.0 -> 526.82, 526.82
% INFO    : Updated Thermal Rating: on transformer 53251-53250 : Rate B, Rate C - 0.0, 0.0 -> 716.18, 716.18
% INFO    : Updated Thermal Rating: on transformer 53250-53253 : Rate B, Rate C - 0.0, 0.0 -> 949.52, 949.52
% INFO    : Updated Thermal Rating: on transformer 53250-53254 : Rate B, Rate C - 0.0, 0.0 -> 948.41, 948.41
% INFO    : Updated Thermal Rating: on transformer 53250-53255 : Rate B, Rate C - 0.0, 0.0 -> 947.81, 947.81
% INFO    : Updated Thermal Rating: on transformer 53252-53251 : Rate B, Rate C - 0.0, 0.0 -> 160.1, 160.1
% INFO    : Updated Thermal Rating: on line 53256-53302 : Rate B, Rate C - 0.0, 0.0 -> 535.96, 535.96
% INFO    : Updated Thermal Rating: on transformer 53257-53260 : Rate B, Rate C - 0.0, 0.0 -> 276.55, 276.55
% INFO    : Updated Thermal Rating: on transformer 53257-53261 : Rate B, Rate C - 0.0, 0.0 -> 242.36, 242.36
% INFO    : Updated Thermal Rating: on line 53257-53272 : Rate B, Rate C - 0.0, 0.0 -> 529.62, 529.62
% INFO    : Updated Thermal Rating: on line 53257-53306 : Rate B, Rate C - 0.0, 0.0 -> 410.5, 410.5
% INFO    : Updated Thermal Rating: on transformer 53258-53260 : Rate B, Rate C - 0.0, 0.0 -> 176.55, 176.55
% INFO    : Updated Thermal Rating: on transformer 53259-53260 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 53262-53263 : Rate B, Rate C - 0.0, 0.0 -> 43.8, 43.8
% INFO    : Updated Thermal Rating: on transformer 53262-53264 : Rate B, Rate C - 0.0, 0.0 -> 22.75, 22.75
% INFO    : Updated Thermal Rating: on line 80001-53265 : Rate B, Rate C - 0.0, 0.0 -> 133.15, 133.15
% INFO    : Updated Thermal Rating: on transformer 53267-53266 : Rate B, Rate C - 0.0, 0.0 -> 243.93, 243.93
% INFO    : Updated Thermal Rating: on transformer 53267-53266 : Rate B, Rate C - 0.0, 0.0 -> 243.93, 243.93
% INFO    : Updated Thermal Rating: on transformer 53267-53266 : Rate B, Rate C - 0.0, 0.0 -> 243.93, 243.93
% INFO    : Updated Thermal Rating: on transformer 53266-53268 : Rate B, Rate C - 0.0, 0.0 -> 239.95, 239.95
% INFO    : Updated Thermal Rating: on line 53266-53306 : Rate B, Rate C - 0.0, 0.0 -> 555.57, 555.57
% INFO    : Updated Thermal Rating: on transformer 53267-53269 : Rate B, Rate C - 0.0, 0.0 -> 17.81, 17.81
% INFO    : Updated Thermal Rating: on transformer 53271-53270 : Rate B, Rate C - 0.0, 0.0 -> 175.08, 175.08
% INFO    : Updated Thermal Rating: on transformer 53273-53276 : Rate B, Rate C - 0.0, 0.0 -> 288.47, 288.47
% INFO    : Updated Thermal Rating: on transformer 53273-53277 : Rate B, Rate C - 0.0, 0.0 -> 220.07, 220.07
% INFO    : Updated Thermal Rating: on transformer 53274-53276 : Rate B, Rate C - 0.0, 0.0 -> 188.47, 188.47
% INFO    : Updated Thermal Rating: on transformer 53275-53276 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 53278-53281 : Rate B, Rate C - 0.0, 0.0 -> 301.26, 301.26
% INFO    : Updated Thermal Rating: on line 53295-53278 : Rate B, Rate C - 0.0, 0.0 -> 476.61, 476.61
% INFO    : Updated Thermal Rating: on line 53278-60005 : Rate B, Rate C - 0.0, 0.0 -> 431.09, 431.09
% INFO    : Updated Thermal Rating: on line 53278-60056 : Rate B, Rate C - 0.0, 0.0 -> 340.01, 340.01
% INFO    : Updated Thermal Rating: on transformer 53279-53281 : Rate B, Rate C - 0.0, 0.0 -> 151.26, 151.26
% INFO    : Updated Thermal Rating: on line 53279-60035 : Rate B, Rate C - 0.0, 0.0 -> 164.38, 164.38
% INFO    : Updated Thermal Rating: on transformer 53280-53281 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 53283-53282 : Rate B, Rate C - 0.0, 0.0 -> 145.98, 145.98
% INFO    : Updated Thermal Rating: on transformer 53282-53286 : Rate B, Rate C - 0.0, 0.0 -> 440.91, 440.91
% INFO    : Updated Thermal Rating: on transformer 53284-53286 : Rate B, Rate C - 0.0, 0.0 -> 220.45, 220.45
% INFO    : Updated Thermal Rating: on transformer 53285-53286 : Rate B, Rate C - 0.0, 0.0 -> 220.45, 220.45
% INFO    : Updated Thermal Rating: on line 53287-53288 : Rate B, Rate C - 0.0, 0.0 -> 546.83, 546.83
% INFO    : Updated Thermal Rating: on line 53287-53290 : Rate B, Rate C - 0.0, 0.0 -> 619.53, 619.53
% INFO    : Updated Thermal Rating: on transformer 53289-53288 : Rate B, Rate C - 0.0, 0.0 -> 187.67, 187.67
% INFO    : Updated Thermal Rating: on transformer 53291-53290 : Rate B, Rate C - 0.0, 0.0 -> 275.46, 275.46
% INFO    : Updated Thermal Rating: on transformer 53291-53290 : Rate B, Rate C - 0.0, 0.0 -> 275.46, 275.46
% INFO    : Updated Thermal Rating: on transformer 53291-53290 : Rate B, Rate C - 0.0, 0.0 -> 275.46, 275.46
% INFO    : Updated Thermal Rating: on transformer 53290-53292 : Rate B, Rate C - 0.0, 0.0 -> 238.82, 238.82
% INFO    : Updated Thermal Rating: on transformer 53290-53293 : Rate B, Rate C - 0.0, 0.0 -> 228.23, 228.23
% INFO    : Updated Thermal Rating: on line 53290-80006 : Rate B, Rate C - 0.0, 0.0 -> 518.44, 518.44
% INFO    : Updated Thermal Rating: on line 53291-80003 : Rate B, Rate C - 0.0, 0.0 -> 210.01, 210.01
% INFO    : Updated Thermal Rating: on transformer 53295-53294 : Rate B, Rate C - 0.0, 0.0 -> 1200.0, 1200.0
% INFO    : Updated Thermal Rating: on transformer 53294-53297 : Rate B, Rate C - 0.0, 0.0 -> 1305.2, 1305.2
% INFO    : Updated Thermal Rating: on transformer 53294-53298 : Rate B, Rate C - 0.0, 0.0 -> 1298.56, 1298.56
% INFO    : Updated Thermal Rating: on transformer 53296-53295 : Rate B, Rate C - 0.0, 0.0 -> 194.47, 194.47
% INFO    : Updated Thermal Rating: on line 53299-60734 : Rate B, Rate C - 0.0, 0.0 -> 2451.72, 2451.72
% INFO    : Updated Thermal Rating: on transformer 53301-53300 : Rate B, Rate C - 0.0, 0.0 -> 162.61, 162.61
% INFO    : Updated Thermal Rating: on line 53302-80006 : Rate B, Rate C - 0.0, 0.0 -> 541.87, 541.87
% INFO    : Updated Thermal Rating: on transformer 53306-53305 : Rate B, Rate C - 0.0, 0.0 -> 1118.4, 1118.4
% INFO    : Updated Thermal Rating: on transformer 53306-53305 : Rate B, Rate C - 0.0, 0.0 -> 1118.4, 1118.4
% INFO    : Updated Thermal Rating: on line 60801-53305 : Rate B, Rate C - 0.0, 0.0 -> 3096.71, 3096.71
% INFO    : Updated Thermal Rating: on transformer 53307-53306 : Rate B, Rate C - 0.0, 0.0 -> 279.03, 279.03
% INFO    : Updated Thermal Rating: on transformer 53307-53306 : Rate B, Rate C - 0.0, 0.0 -> 279.03, 279.03
% INFO    : Updated Thermal Rating: on transformer 53307-53306 : Rate B, Rate C - 0.0, 0.0 -> 279.03, 279.03
% INFO    : Updated Thermal Rating: on transformer 53307-53306 : Rate B, Rate C - 0.0, 0.0 -> 279.03, 279.03
% INFO    : Updated Thermal Rating: on line 60007-60000 : Rate B, Rate C - 0.0, 0.0 -> 143.77, 143.77
% INFO    : Updated Thermal Rating: on line 60029-60000 : Rate B, Rate C - 0.0, 0.0 -> 150.54, 150.54
% INFO    : Updated Thermal Rating: on line 60015-60002 : Rate B, Rate C - 0.0, 0.0 -> 124.09, 124.09
% INFO    : Updated Thermal Rating: on line 60002-60020 : Rate B, Rate C - 0.0, 0.0 -> 168.65, 168.65
% INFO    : Updated Thermal Rating: on line 60004-60015 : Rate B, Rate C - 0.0, 0.0 -> 162.51, 162.51
% INFO    : Updated Thermal Rating: on line 60004-60017 : Rate B, Rate C - 0.0, 0.0 -> 168.73, 168.73
% INFO    : Updated Thermal Rating: on transformer 60006-60005 : Rate B, Rate C - 0.0, 0.0 -> 154.97, 154.97
% INFO    : Updated Thermal Rating: on transformer 60006-60009 : Rate B, Rate C - 0.0, 0.0 -> 188.45, 188.45
% INFO    : Updated Thermal Rating: on transformer 60007-60009 : Rate B, Rate C - 0.0, 0.0 -> 113.45, 113.45
% INFO    : Updated Thermal Rating: on line 60007-60032 : Rate B, Rate C - 0.0, 0.0 -> 125.73, 125.73
% INFO    : Updated Thermal Rating: on transformer 60008-60009 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 60057-60010 : Rate B, Rate C - 0.0, 0.0 -> 183.9, 183.9
% INFO    : Updated Thermal Rating: on transformer 60011-60014 : Rate B, Rate C - 0.0, 0.0 -> 99.86, 99.86
% INFO    : Updated Thermal Rating: on line 60011-60020 : Rate B, Rate C - 0.0, 0.0 -> 165.18, 165.18
% INFO    : Updated Thermal Rating: on line 60011-60044 : Rate B, Rate C - 0.0, 0.0 -> 140.78, 140.78
% INFO    : Updated Thermal Rating: on line 60063-60011 : Rate B, Rate C - 0.0, 0.0 -> 163.58, 163.58
% INFO    : Updated Thermal Rating: on transformer 60012-60014 : Rate B, Rate C - 0.0, 0.0 -> 49.93, 49.93
% INFO    : Updated Thermal Rating: on transformer 60013-60014 : Rate B, Rate C - 0.0, 0.0 -> 49.93, 49.93
% INFO    : Updated Thermal Rating: on transformer 60017-60016 : Rate B, Rate C - 0.0, 0.0 -> 250.39, 250.39
% INFO    : Updated Thermal Rating: on transformer 60017-60016 : Rate B, Rate C - 0.0, 0.0 -> 250.39, 250.39
% INFO    : Updated Thermal Rating: on transformer 60017-60016 : Rate B, Rate C - 0.0, 0.0 -> 250.39, 250.39
% INFO    : Updated Thermal Rating: on line 60848-60016 : Rate B, Rate C - 0.0, 0.0 -> 587.61, 587.61
% INFO    : Updated Thermal Rating: on line 60016-60868 : Rate B, Rate C - 0.0, 0.0 -> 609.37, 609.37
% INFO    : Updated Thermal Rating: on line 60017-60021 : Rate B, Rate C - 0.0, 0.0 -> 163.55, 163.55
% INFO    : Updated Thermal Rating: on line 60017-60025 : Rate B, Rate C - 0.0, 0.0 -> 134.22, 134.22
% INFO    : Updated Thermal Rating: on line 60028-60017 : Rate B, Rate C - 0.0, 0.0 -> 202.49, 202.49
% INFO    : Updated Thermal Rating: on line 60028-60017 : Rate B, Rate C - 0.0, 0.0 -> 202.49, 202.49
% INFO    : Updated Thermal Rating: on line 60018-60026 : Rate B, Rate C - 0.0, 0.0 -> 144.36, 144.36
% INFO    : Updated Thermal Rating: on line 60018-60028 : Rate B, Rate C - 0.0, 0.0 -> 173.92, 173.92
% INFO    : Updated Thermal Rating: on line 60031-60018 : Rate B, Rate C - 0.0, 0.0 -> 144.19, 144.19
% INFO    : Updated Thermal Rating: on line 60020-60022 : Rate B, Rate C - 0.0, 0.0 -> 161.31, 161.31
% INFO    : Updated Thermal Rating: on line 60021-60022 : Rate B, Rate C - 0.0, 0.0 -> 162.46, 162.46
% INFO    : Updated Thermal Rating: on line 60028-60021 : Rate B, Rate C - 0.0, 0.0 -> 161.03, 161.03
% INFO    : Updated Thermal Rating: on line 60022-60028 : Rate B, Rate C - 0.0, 0.0 -> 163.03, 163.03
% INFO    : Updated Thermal Rating: on line 60025-60050 : Rate B, Rate C - 0.0, 0.0 -> 142.51, 142.51
% INFO    : Updated Thermal Rating: on line 60026-60031 : Rate B, Rate C - 0.0, 0.0 -> 113.14, 113.14
% INFO    : Updated Thermal Rating: on line 60026-60045 : Rate B, Rate C - 0.0, 0.0 -> 155.26, 155.26
% INFO    : Updated Thermal Rating: on line 60737-60029 : Rate B, Rate C - 0.0, 0.0 -> 150.92, 150.92
% INFO    : Updated Thermal Rating: on line 60031-60052 : Rate B, Rate C - 0.0, 0.0 -> 124.03, 124.03
% INFO    : Updated Thermal Rating: on line 60032-60035 : Rate B, Rate C - 0.0, 0.0 -> 160.74, 160.74
% INFO    : Updated Thermal Rating: on line 60055-60032 : Rate B, Rate C - 0.0, 0.0 -> 156.43, 156.43
% INFO    : Updated Thermal Rating: on line 60038-60033 : Rate B, Rate C - 0.0, 0.0 -> 157.96, 157.96
% INFO    : Updated Thermal Rating: on line 60033-60060 : Rate B, Rate C - 0.0, 0.0 -> 168.42, 168.42
% INFO    : Updated Thermal Rating: on line 60038-60049 : Rate B, Rate C - 0.0, 0.0 -> 126.79, 126.79
% INFO    : Updated Thermal Rating: on line 60054-60041 : Rate B, Rate C - 0.0, 0.0 -> 144.04, 144.04
% INFO    : Updated Thermal Rating: on line 60041-60055 : Rate B, Rate C - 0.0, 0.0 -> 117.94, 117.94
% INFO    : Updated Thermal Rating: on line 60044-60045 : Rate B, Rate C - 0.0, 0.0 -> 109.86, 109.86
% INFO    : Updated Thermal Rating: on line 60849-60044 : Rate B, Rate C - 0.0, 0.0 -> 168.48, 168.48
% INFO    : Updated Thermal Rating: on line 60045-60064 : Rate B, Rate C - 0.0, 0.0 -> 156.59, 156.59
% INFO    : Updated Thermal Rating: on line 60849-60045 : Rate B, Rate C - 0.0, 0.0 -> 180.95, 180.95
% INFO    : Updated Thermal Rating: on line 60052-60049 : Rate B, Rate C - 0.0, 0.0 -> 143.6, 143.6
% INFO    : Updated Thermal Rating: on line 60050-60060 : Rate B, Rate C - 0.0, 0.0 -> 154.5, 154.5
% INFO    : Updated Thermal Rating: on line 60050-60737 : Rate B, Rate C - 0.0, 0.0 -> 145.86, 145.86
% INFO    : Updated Thermal Rating: on line 60064-60052 : Rate B, Rate C - 0.0, 0.0 -> 156.85, 156.85
% INFO    : Updated Thermal Rating: on line 60053-60058 : Rate B, Rate C - 0.0, 0.0 -> 134.11, 134.11
% INFO    : Updated Thermal Rating: on line 60070-60053 : Rate B, Rate C - 0.0, 0.0 -> 149.16, 149.16
% INFO    : Updated Thermal Rating: on line 60054-60062 : Rate B, Rate C - 0.0, 0.0 -> 159.04, 159.04
% INFO    : Updated Thermal Rating: on line 60055-60058 : Rate B, Rate C - 0.0, 0.0 -> 134.56, 134.56
% INFO    : Updated Thermal Rating: on transformer 60057-60056 : Rate B, Rate C - 0.0, 0.0 -> 169.06, 169.06
% INFO    : Updated Thermal Rating: on line 60056-60061 : Rate B, Rate C - 0.0, 0.0 -> 509.89, 509.89
% INFO    : Updated Thermal Rating: on transformer 60058-60057 : Rate B, Rate C - 0.0, 0.0 -> 137.57, 137.57
% INFO    : Updated Thermal Rating: on line 60058-60074 : Rate B, Rate C - 0.0, 0.0 -> 150.74, 150.74
% INFO    : Updated Thermal Rating: on transformer 60060-60059 : Rate B, Rate C - 0.0, 0.0 -> 181.87, 181.87
% INFO    : Updated Thermal Rating: on line 60060-60765 : Rate B, Rate C - 0.0, 0.0 -> 163.43, 163.43
% INFO    : Updated Thermal Rating: on line 60061-60805 : Rate B, Rate C - 0.0, 0.0 -> 537.88, 537.88
% INFO    : Updated Thermal Rating: on line 60061-60848 : Rate B, Rate C - 0.0, 0.0 -> 504.8, 504.8
% INFO    : Updated Thermal Rating: on line 60062-60812 : Rate B, Rate C - 0.0, 0.0 -> 166.96, 166.96
% INFO    : Updated Thermal Rating: on line 60076-60063 : Rate B, Rate C - 0.0, 0.0 -> 147.36, 147.36
% INFO    : Updated Thermal Rating: on line 60080-60063 : Rate B, Rate C - 0.0, 0.0 -> 146.8, 146.8
% INFO    : Updated Thermal Rating: on line 60063-60869 : Rate B, Rate C - 0.0, 0.0 -> 186.77, 186.77
% INFO    : Updated Thermal Rating: on line 60071-60064 : Rate B, Rate C - 0.0, 0.0 -> 143.14, 143.14
% INFO    : Updated Thermal Rating: on line 60706-60065 : Rate B, Rate C - 0.0, 0.0 -> 130.36, 130.36
% INFO    : Updated Thermal Rating: on line 60869-60065 : Rate B, Rate C - 0.0, 0.0 -> 156.96, 156.96
% INFO    : Updated Thermal Rating: on line 60073-60069 : Rate B, Rate C - 0.0, 0.0 -> 124.87, 124.87
% INFO    : Updated Thermal Rating: on line 60069-60079 : Rate B, Rate C - 0.0, 0.0 -> 169.95, 169.95
% INFO    : Updated Thermal Rating: on line 60069-60849 : Rate B, Rate C - 0.0, 0.0 -> 180.3, 180.3
% INFO    : Updated Thermal Rating: on line 60765-60071 : Rate B, Rate C - 0.0, 0.0 -> 152.97, 152.97
% INFO    : Updated Thermal Rating: on line 60073-60849 : Rate B, Rate C - 0.0, 0.0 -> 142.75, 142.75
% INFO    : Updated Thermal Rating: on line 60074-60082 : Rate B, Rate C - 0.0, 0.0 -> 105.8, 105.8
% INFO    : Updated Thermal Rating: on line 60076-60080 : Rate B, Rate C - 0.0, 0.0 -> 116.28, 116.28
% INFO    : Updated Thermal Rating: on line 60076-60849 : Rate B, Rate C - 0.0, 0.0 -> 152.85, 152.85
% INFO    : Updated Thermal Rating: on line 60077-60090 : Rate B, Rate C - 0.0, 0.0 -> 178.68, 178.68
% INFO    : Updated Thermal Rating: on line 60077-60104 : Rate B, Rate C - 0.0, 0.0 -> 147.42, 147.42
% INFO    : Updated Thermal Rating: on line 60706-60077 : Rate B, Rate C - 0.0, 0.0 -> 188.86, 188.86
% INFO    : Updated Thermal Rating: on line 60079-60088 : Rate B, Rate C - 0.0, 0.0 -> 134.4, 134.4
% INFO    : Updated Thermal Rating: on line 60082-60102 : Rate B, Rate C - 0.0, 0.0 -> 159.74, 159.74
% INFO    : Updated Thermal Rating: on line 60084-60806 : Rate B, Rate C - 0.0, 0.0 -> 143.94, 143.94
% INFO    : Updated Thermal Rating: on line 60812-60084 : Rate B, Rate C - 0.0, 0.0 -> 139.66, 139.66
% INFO    : Updated Thermal Rating: on line 60088-60086 : Rate B, Rate C - 0.0, 0.0 -> 141.71, 141.71
% INFO    : Updated Thermal Rating: on line 60086-60829 : Rate B, Rate C - 0.0, 0.0 -> 154.91, 154.91
% INFO    : Updated Thermal Rating: on line 60095-60088 : Rate B, Rate C - 0.0, 0.0 -> 141.52, 141.52
% INFO    : Updated Thermal Rating: on line 60089-60095 : Rate B, Rate C - 0.0, 0.0 -> 141.28, 141.28
% INFO    : Updated Thermal Rating: on line 60089-60100 : Rate B, Rate C - 0.0, 0.0 -> 157.54, 157.54
% INFO    : Updated Thermal Rating: on line 60092-60090 : Rate B, Rate C - 0.0, 0.0 -> 149.64, 149.64
% INFO    : Updated Thermal Rating: on line 60101-60090 : Rate B, Rate C - 0.0, 0.0 -> 140.74, 140.74
% INFO    : Updated Thermal Rating: on line 60090-60104 : Rate B, Rate C - 0.0, 0.0 -> 143.03, 143.03
% INFO    : Updated Thermal Rating: on line 60092-60093 : Rate B, Rate C - 0.0, 0.0 -> 146.57, 146.57
% INFO    : Updated Thermal Rating: on line 60092-60101 : Rate B, Rate C - 0.0, 0.0 -> 126.98, 126.98
% INFO    : Updated Thermal Rating: on line 60093-60097 : Rate B, Rate C - 0.0, 0.0 -> 143.68, 143.68
% INFO    : Updated Thermal Rating: on line 60100-60093 : Rate B, Rate C - 0.0, 0.0 -> 139.83, 139.83
% INFO    : Updated Thermal Rating: on transformer 60097-60096 : Rate B, Rate C - 0.0, 0.0 -> 183.87, 183.87
% INFO    : Updated Thermal Rating: on line 60096-60184 : Rate B, Rate C - 0.0, 0.0 -> 485.58, 485.58
% INFO    : Updated Thermal Rating: on line 60096-60705 : Rate B, Rate C - 0.0, 0.0 -> 595.02, 595.02
% INFO    : Updated Thermal Rating: on line 60100-60097 : Rate B, Rate C - 0.0, 0.0 -> 168.44, 168.44
% INFO    : Updated Thermal Rating: on line 60097-60109 : Rate B, Rate C - 0.0, 0.0 -> 137.68, 137.68
% INFO    : Updated Thermal Rating: on line 60117-60102 : Rate B, Rate C - 0.0, 0.0 -> 166.89, 166.89
% INFO    : Updated Thermal Rating: on line 60103-60119 : Rate B, Rate C - 0.0, 0.0 -> 154.05, 154.05
% INFO    : Updated Thermal Rating: on line 60103-60829 : Rate B, Rate C - 0.0, 0.0 -> 168.82, 168.82
% INFO    : Updated Thermal Rating: on line 60105-60116 : Rate B, Rate C - 0.0, 0.0 -> 151.28, 151.28
% INFO    : Updated Thermal Rating: on line 60107-60121 : Rate B, Rate C - 0.0, 0.0 -> 148.56, 148.56
% INFO    : Updated Thermal Rating: on line 60829-60107 : Rate B, Rate C - 0.0, 0.0 -> 163.24, 163.24
% INFO    : Updated Thermal Rating: on line 60110-60109 : Rate B, Rate C - 0.0, 0.0 -> 135.11, 135.11
% INFO    : Updated Thermal Rating: on line 60109-60800 : Rate B, Rate C - 0.0, 0.0 -> 142.24, 142.24
% INFO    : Updated Thermal Rating: on line 60128-60110 : Rate B, Rate C - 0.0, 0.0 -> 133.03, 133.03
% INFO    : Updated Thermal Rating: on line 60110-60800 : Rate B, Rate C - 0.0, 0.0 -> 145.9, 145.9
% INFO    : Updated Thermal Rating: on line 60111-60124 : Rate B, Rate C - 0.0, 0.0 -> 146.2, 146.2
% INFO    : Updated Thermal Rating: on line 60111-60128 : Rate B, Rate C - 0.0, 0.0 -> 145.2, 145.2
% INFO    : Updated Thermal Rating: on line 60111-60829 : Rate B, Rate C - 0.0, 0.0 -> 164.99, 164.99
% INFO    : Updated Thermal Rating: on line 60115-60116 : Rate B, Rate C - 0.0, 0.0 -> 176.47, 176.47
% INFO    : Updated Thermal Rating: on line 60115-60134 : Rate B, Rate C - 0.0, 0.0 -> 157.4, 157.4
% INFO    : Updated Thermal Rating: on line 60803-60115 : Rate B, Rate C - 0.0, 0.0 -> 171.42, 171.42
% INFO    : Updated Thermal Rating: on line 60116-60135 : Rate B, Rate C - 0.0, 0.0 -> 160.52, 160.52
% INFO    : Updated Thermal Rating: on line 60803-60117 : Rate B, Rate C - 0.0, 0.0 -> 174.26, 174.26
% INFO    : Updated Thermal Rating: on line 60119-60141 : Rate B, Rate C - 0.0, 0.0 -> 123.44, 123.44
% INFO    : Updated Thermal Rating: on line 60124-60121 : Rate B, Rate C - 0.0, 0.0 -> 134.85, 134.85
% INFO    : Updated Thermal Rating: on line 60130-60126 : Rate B, Rate C - 0.0, 0.0 -> 137.17, 137.17
% INFO    : Updated Thermal Rating: on line 60136-60126 : Rate B, Rate C - 0.0, 0.0 -> 154.35, 154.35
% INFO    : Updated Thermal Rating: on transformer 60130-60133 : Rate B, Rate C - 0.0, 0.0 -> 62.2, 62.2
% INFO    : Updated Thermal Rating: on line 60139-60130 : Rate B, Rate C - 0.0, 0.0 -> 156.94, 156.94
% INFO    : Updated Thermal Rating: on line 60130-60162 : Rate B, Rate C - 0.0, 0.0 -> 155.22, 155.22
% INFO    : Updated Thermal Rating: on transformer 60131-60133 : Rate B, Rate C - 0.0, 0.0 -> 31.1, 31.1
% INFO    : Updated Thermal Rating: on transformer 60132-60133 : Rate B, Rate C - 0.0, 0.0 -> 31.1, 31.1
% INFO    : Updated Thermal Rating: on line 60135-60134 : Rate B, Rate C - 0.0, 0.0 -> 169.37, 169.37
% INFO    : Updated Thermal Rating: on line 60134-60695 : Rate B, Rate C - 0.0, 0.0 -> 194.83, 194.83
% INFO    : Updated Thermal Rating: on line 60155-60135 : Rate B, Rate C - 0.0, 0.0 -> 182.78, 182.78
% INFO    : Updated Thermal Rating: on line 60136-60855 : Rate B, Rate C - 0.0, 0.0 -> 158.86, 158.86
% INFO    : Updated Thermal Rating: on line 60139-60151 : Rate B, Rate C - 0.0, 0.0 -> 163.71, 163.71
% INFO    : Updated Thermal Rating: on line 60740-60139 : Rate B, Rate C - 0.0, 0.0 -> 183.5, 183.5
% INFO    : Updated Thermal Rating: on line 60141-60154 : Rate B, Rate C - 0.0, 0.0 -> 80.98, 80.98
% INFO    : Updated Thermal Rating: on line 60141-60159 : Rate B, Rate C - 0.0, 0.0 -> 139.27, 139.27
% INFO    : Updated Thermal Rating: on line 60142-60145 : Rate B, Rate C - 0.0, 0.0 -> 163.83, 163.83
% INFO    : Updated Thermal Rating: on line 60855-60142 : Rate B, Rate C - 0.0, 0.0 -> 142.9, 142.9
% INFO    : Updated Thermal Rating: on line 60145-60163 : Rate B, Rate C - 0.0, 0.0 -> 167.79, 167.79
% INFO    : Updated Thermal Rating: on line 60162-60148 : Rate B, Rate C - 0.0, 0.0 -> 147.59, 147.59
% INFO    : Updated Thermal Rating: on line 60148-60212 : Rate B, Rate C - 0.0, 0.0 -> 161.87, 161.87
% INFO    : Updated Thermal Rating: on line 60151-60149 : Rate B, Rate C - 0.0, 0.0 -> 145.58, 145.58
% INFO    : Updated Thermal Rating: on line 60149-60170 : Rate B, Rate C - 0.0, 0.0 -> 157.11, 157.11
% INFO    : Updated Thermal Rating: on line 60149-60180 : Rate B, Rate C - 0.0, 0.0 -> 148.63, 148.63
% INFO    : Updated Thermal Rating: on line 60740-60151 : Rate B, Rate C - 0.0, 0.0 -> 166.82, 166.82
% INFO    : Updated Thermal Rating: on line 60219-60154 : Rate B, Rate C - 0.0, 0.0 -> 138.73, 138.73
% INFO    : Updated Thermal Rating: on line 60156-60159 : Rate B, Rate C - 0.0, 0.0 -> 159.21, 159.21
% INFO    : Updated Thermal Rating: on line 60219-60156 : Rate B, Rate C - 0.0, 0.0 -> 134.99, 134.99
% INFO    : Updated Thermal Rating: on transformer 60159-60158 : Rate B, Rate C - 0.0, 0.0 -> 193.25, 193.25
% INFO    : Updated Thermal Rating: on line 60639-60158 : Rate B, Rate C - 0.0, 0.0 -> 496.46, 496.46
% INFO    : Updated Thermal Rating: on line 60802-60158 : Rate B, Rate C - 0.0, 0.0 -> 401.31, 401.31
% INFO    : Updated Thermal Rating: on line 60158-60828 : Rate B, Rate C - 0.0, 0.0 -> 501.52, 501.52
% INFO    : Updated Thermal Rating: on line 60159-60172 : Rate B, Rate C - 0.0, 0.0 -> 147.95, 147.95
% INFO    : Updated Thermal Rating: on line 60160-60162 : Rate B, Rate C - 0.0, 0.0 -> 115.65, 115.65
% INFO    : Updated Thermal Rating: on line 60177-60160 : Rate B, Rate C - 0.0, 0.0 -> 163.5, 163.5
% INFO    : Updated Thermal Rating: on line 60163-60199 : Rate B, Rate C - 0.0, 0.0 -> 112.66, 112.66
% INFO    : Updated Thermal Rating: on line 60163-70072 : Rate B, Rate C - 0.0, 0.0 -> 170.01, 170.01
% INFO    : Updated Thermal Rating: on transformer 60164-60167 : Rate B, Rate C - 0.0, 0.0 -> 117.78, 117.78
% INFO    : Updated Thermal Rating: on transformer 60165-60167 : Rate B, Rate C - 0.0, 0.0 -> 58.89, 58.89
% INFO    : Updated Thermal Rating: on transformer 60166-60167 : Rate B, Rate C - 0.0, 0.0 -> 58.89, 58.89
% INFO    : Updated Thermal Rating: on line 60723-60168 : Rate B, Rate C - 0.0, 0.0 -> 121.07, 121.07
% INFO    : Updated Thermal Rating: on line 60168-60855 : Rate B, Rate C - 0.0, 0.0 -> 146.11, 146.11
% INFO    : Updated Thermal Rating: on line 60170-60202 : Rate B, Rate C - 0.0, 0.0 -> 163.3, 163.3
% INFO    : Updated Thermal Rating: on line 60216-60172 : Rate B, Rate C - 0.0, 0.0 -> 135.71, 135.71
% INFO    : Updated Thermal Rating: on line 60182-60173 : Rate B, Rate C - 0.0, 0.0 -> 158.58, 158.58
% INFO    : Updated Thermal Rating: on line 60173-60190 : Rate B, Rate C - 0.0, 0.0 -> 147.33, 147.33
% INFO    : Updated Thermal Rating: on line 60173-60773 : Rate B, Rate C - 0.0, 0.0 -> 163.35, 163.35
% INFO    : Updated Thermal Rating: on line 60177-60176 : Rate B, Rate C - 0.0, 0.0 -> 159.21, 159.21
% INFO    : Updated Thermal Rating: on line 60176-60676 : Rate B, Rate C - 0.0, 0.0 -> 178.09, 178.09
% INFO    : Updated Thermal Rating: on line 60177-60723 : Rate B, Rate C - 0.0, 0.0 -> 164.78, 164.78
% INFO    : Updated Thermal Rating: on line 60178-60182 : Rate B, Rate C - 0.0, 0.0 -> 172.71, 172.71
% INFO    : Updated Thermal Rating: on line 60676-60178 : Rate B, Rate C - 0.0, 0.0 -> 182.54, 182.54
% INFO    : Updated Thermal Rating: on line 60180-60205 : Rate B, Rate C - 0.0, 0.0 -> 118.57, 118.57
% INFO    : Updated Thermal Rating: on line 60182-60851 : Rate B, Rate C - 0.0, 0.0 -> 219.43, 219.43
% INFO    : Updated Thermal Rating: on transformer 60185-60184 : Rate B, Rate C - 0.0, 0.0 -> 276.19, 276.19
% INFO    : Updated Thermal Rating: on transformer 60185-60184 : Rate B, Rate C - 0.0, 0.0 -> 276.19, 276.19
% INFO    : Updated Thermal Rating: on transformer 60185-60184 : Rate B, Rate C - 0.0, 0.0 -> 276.19, 276.19
% INFO    : Updated Thermal Rating: on transformer 60185-60184 : Rate B, Rate C - 0.0, 0.0 -> 276.19, 276.19
% INFO    : Updated Thermal Rating: on line 60278-60184 : Rate B, Rate C - 0.0, 0.0 -> 510.01, 510.01
% INFO    : Updated Thermal Rating: on line 60184-60675 : Rate B, Rate C - 0.0, 0.0 -> 632.41, 632.41
% INFO    : Updated Thermal Rating: on line 60739-60184 : Rate B, Rate C - 0.0, 0.0 -> 610.66, 610.66
% INFO    : Updated Thermal Rating: on line 60186-60185 : Rate B, Rate C - 0.0, 0.0 -> 176.88, 176.88
% INFO    : Updated Thermal Rating: on line 60185-60202 : Rate B, Rate C - 0.0, 0.0 -> 184.12, 184.12
% INFO    : Updated Thermal Rating: on line 60185-60209 : Rate B, Rate C - 0.0, 0.0 -> 181.18, 181.18
% INFO    : Updated Thermal Rating: on line 60185-60262 : Rate B, Rate C - 0.0, 0.0 -> 181.12, 181.12
% INFO    : Updated Thermal Rating: on line 60185-60273 : Rate B, Rate C - 0.0, 0.0 -> 195.78, 195.78
% INFO    : Updated Thermal Rating: on line 60260-60186 : Rate B, Rate C - 0.0, 0.0 -> 137.68, 137.68
% INFO    : Updated Thermal Rating: on line 60247-60187 : Rate B, Rate C - 0.0, 0.0 -> 147.76, 147.76
% INFO    : Updated Thermal Rating: on line 60249-60187 : Rate B, Rate C - 0.0, 0.0 -> 175.46, 175.46
% INFO    : Updated Thermal Rating: on line 60189-60247 : Rate B, Rate C - 0.0, 0.0 -> 160.97, 160.97
% INFO    : Updated Thermal Rating: on line 60189-60676 : Rate B, Rate C - 0.0, 0.0 -> 182.16, 182.16
% INFO    : Updated Thermal Rating: on line 60190-60254 : Rate B, Rate C - 0.0, 0.0 -> 163.89, 163.89
% INFO    : Updated Thermal Rating: on line 60192-60205 : Rate B, Rate C - 0.0, 0.0 -> 165.32, 165.32
% INFO    : Updated Thermal Rating: on line 60192-60212 : Rate B, Rate C - 0.0, 0.0 -> 185.43, 185.43
% INFO    : Updated Thermal Rating: on line 60271-60194 : Rate B, Rate C - 0.0, 0.0 -> 138.33, 138.33
% INFO    : Updated Thermal Rating: on line 60194-60826 : Rate B, Rate C - 0.0, 0.0 -> 188.84, 188.84
% INFO    : Updated Thermal Rating: on line 60195-60232 : Rate B, Rate C - 0.0, 0.0 -> 180.26, 180.26
% INFO    : Updated Thermal Rating: on line 60851-60195 : Rate B, Rate C - 0.0, 0.0 -> 188.36, 188.36
% INFO    : Updated Thermal Rating: on line 60198-60216 : Rate B, Rate C - 0.0, 0.0 -> 118.55, 118.55
% INFO    : Updated Thermal Rating: on line 60238-60198 : Rate B, Rate C - 0.0, 0.0 -> 134.43, 134.43
% INFO    : Updated Thermal Rating: on line 60199-60290 : Rate B, Rate C - 0.0, 0.0 -> 136.82, 136.82
% INFO    : Updated Thermal Rating: on line 60200-60249 : Rate B, Rate C - 0.0, 0.0 -> 140.51, 140.51
% INFO    : Updated Thermal Rating: on line 60200-60389 : Rate B, Rate C - 0.0, 0.0 -> 164.17, 164.17
% INFO    : Updated Thermal Rating: on line 60286-60201 : Rate B, Rate C - 0.0, 0.0 -> 155.56, 155.56
% INFO    : Updated Thermal Rating: on line 60201-60303 : Rate B, Rate C - 0.0, 0.0 -> 154.76, 154.76
% INFO    : Updated Thermal Rating: on line 60203-60230 : Rate B, Rate C - 0.0, 0.0 -> 155.19, 155.19
% INFO    : Updated Thermal Rating: on line 60203-60236 : Rate B, Rate C - 0.0, 0.0 -> 230.4, 230.4
% INFO    : Updated Thermal Rating: on line 60255-60203 : Rate B, Rate C - 0.0, 0.0 -> 172.45, 172.45
% INFO    : Updated Thermal Rating: on line 60203-60259 : Rate B, Rate C - 0.0, 0.0 -> 158.94, 158.94
% INFO    : Updated Thermal Rating: on line 60203-60283 : Rate B, Rate C - 0.0, 0.0 -> 189.82, 189.82
% INFO    : Updated Thermal Rating: on line 60203-60326 : Rate B, Rate C - 0.0, 0.0 -> 143.1, 143.1
% INFO    : Updated Thermal Rating: on line 60209-60205 : Rate B, Rate C - 0.0, 0.0 -> 144.71, 144.71
% INFO    : Updated Thermal Rating: on line 60676-60212 : Rate B, Rate C - 0.0, 0.0 -> 201.04, 201.04
% INFO    : Updated Thermal Rating: on line 60676-60212 : Rate B, Rate C - 0.0, 0.0 -> 201.04, 201.04
% INFO    : Updated Thermal Rating: on line 60407-60215 : Rate B, Rate C - 0.0, 0.0 -> 156.5, 156.5
% INFO    : Updated Thermal Rating: on line 60215-60411 : Rate B, Rate C - 0.0, 0.0 -> 145.9, 145.9
% INFO    : Updated Thermal Rating: on line 60723-60217 : Rate B, Rate C - 0.0, 0.0 -> 111.15, 111.15
% INFO    : Updated Thermal Rating: on line 60217-60784 : Rate B, Rate C - 0.0, 0.0 -> 173.25, 173.25
% INFO    : Updated Thermal Rating: on line 60218-60288 : Rate B, Rate C - 0.0, 0.0 -> 161.51, 161.51
% INFO    : Updated Thermal Rating: on line 60218-60306 : Rate B, Rate C - 0.0, 0.0 -> 152.57, 152.57
% INFO    : Updated Thermal Rating: on line 60310-60219 : Rate B, Rate C - 0.0, 0.0 -> 157.18, 157.18
% INFO    : Updated Thermal Rating: on line 60469-60219 : Rate B, Rate C - 0.0, 0.0 -> 145.15, 145.15
% INFO    : Updated Thermal Rating: on line 60253-60221 : Rate B, Rate C - 0.0, 0.0 -> 158.2, 158.2
% INFO    : Updated Thermal Rating: on line 60221-60300 : Rate B, Rate C - 0.0, 0.0 -> 176.24, 176.24
% INFO    : Updated Thermal Rating: on line 60224-60230 : Rate B, Rate C - 0.0, 0.0 -> 137.59, 137.59
% INFO    : Updated Thermal Rating: on line 60224-60338 : Rate B, Rate C - 0.0, 0.0 -> 166.58, 166.58
% INFO    : Updated Thermal Rating: on line 60227-60228 : Rate B, Rate C - 0.0, 0.0 -> 179.05, 179.05
% INFO    : Updated Thermal Rating: on line 60227-70076 : Rate B, Rate C - 0.0, 0.0 -> 193.16, 193.16
% INFO    : Updated Thermal Rating: on line 60228-60389 : Rate B, Rate C - 0.0, 0.0 -> 149.76, 149.76
% INFO    : Updated Thermal Rating: on line 60229-60296 : Rate B, Rate C - 0.0, 0.0 -> 182.4, 182.4
% INFO    : Updated Thermal Rating: on line 60229-60338 : Rate B, Rate C - 0.0, 0.0 -> 196.9, 196.9
% INFO    : Updated Thermal Rating: on line 60229-60338 : Rate B, Rate C - 0.0, 0.0 -> 196.9, 196.9
% INFO    : Updated Thermal Rating: on line 60300-60230 : Rate B, Rate C - 0.0, 0.0 -> 176.16, 176.16
% INFO    : Updated Thermal Rating: on line 60232-60260 : Rate B, Rate C - 0.0, 0.0 -> 150.42, 150.42
% INFO    : Updated Thermal Rating: on line 60235-60296 : Rate B, Rate C - 0.0, 0.0 -> 137.61, 137.61
% INFO    : Updated Thermal Rating: on line 60235-60347 : Rate B, Rate C - 0.0, 0.0 -> 169.44, 169.44
% INFO    : Updated Thermal Rating: on line 60236-60330 : Rate B, Rate C - 0.0, 0.0 -> 171.22, 171.22
% INFO    : Updated Thermal Rating: on line 60236-60773 : Rate B, Rate C - 0.0, 0.0 -> 204.17, 204.17
% INFO    : Updated Thermal Rating: on line 60236-60773 : Rate B, Rate C - 0.0, 0.0 -> 204.17, 204.17
% INFO    : Updated Thermal Rating: on line 60236-60773 : Rate B, Rate C - 0.0, 0.0 -> 204.17, 204.17
% INFO    : Updated Thermal Rating: on line 60238-60490 : Rate B, Rate C - 0.0, 0.0 -> 165.19, 165.19
% INFO    : Updated Thermal Rating: on line 60408-60241 : Rate B, Rate C - 0.0, 0.0 -> 163.39, 163.39
% INFO    : Updated Thermal Rating: on line 60241-60518 : Rate B, Rate C - 0.0, 0.0 -> 158.24, 158.24
% INFO    : Updated Thermal Rating: on line 60296-60244 : Rate B, Rate C - 0.0, 0.0 -> 165.15, 165.15
% INFO    : Updated Thermal Rating: on line 60326-60244 : Rate B, Rate C - 0.0, 0.0 -> 128.21, 128.21
% INFO    : Updated Thermal Rating: on line 60249-60246 : Rate B, Rate C - 0.0, 0.0 -> 197.14, 197.14
% INFO    : Updated Thermal Rating: on line 60249-60246 : Rate B, Rate C - 0.0, 0.0 -> 197.14, 197.14
% INFO    : Updated Thermal Rating: on line 60246-60311 : Rate B, Rate C - 0.0, 0.0 -> 199.69, 199.69
% INFO    : Updated Thermal Rating: on line 60246-60311 : Rate B, Rate C - 0.0, 0.0 -> 199.69, 199.69
% INFO    : Updated Thermal Rating: on line 60246-60413 : Rate B, Rate C - 0.0, 0.0 -> 154.6, 154.6
% INFO    : Updated Thermal Rating: on line 60250-60283 : Rate B, Rate C - 0.0, 0.0 -> 191.08, 191.08
% INFO    : Updated Thermal Rating: on line 60250-60352 : Rate B, Rate C - 0.0, 0.0 -> 166.01, 166.01
% INFO    : Updated Thermal Rating: on line 60253-60378 : Rate B, Rate C - 0.0, 0.0 -> 126.04, 126.04
% INFO    : Updated Thermal Rating: on line 60254-60826 : Rate B, Rate C - 0.0, 0.0 -> 183.04, 183.04
% INFO    : Updated Thermal Rating: on line 60260-60255 : Rate B, Rate C - 0.0, 0.0 -> 143.69, 143.69
% INFO    : Updated Thermal Rating: on line 60257-60273 : Rate B, Rate C - 0.0, 0.0 -> 173.92, 173.92
% INFO    : Updated Thermal Rating: on line 60257-60362 : Rate B, Rate C - 0.0, 0.0 -> 147.29, 147.29
% INFO    : Updated Thermal Rating: on line 60258-60272 : Rate B, Rate C - 0.0, 0.0 -> 158.59, 158.59
% INFO    : Updated Thermal Rating: on line 60258-60365 : Rate B, Rate C - 0.0, 0.0 -> 210.0, 210.0
% INFO    : Updated Thermal Rating: on line 60258-60838 : Rate B, Rate C - 0.0, 0.0 -> 176.9, 176.9
% INFO    : Updated Thermal Rating: on line 60259-60283 : Rate B, Rate C - 0.0, 0.0 -> 162.18, 162.18
% INFO    : Updated Thermal Rating: on line 60292-60259 : Rate B, Rate C - 0.0, 0.0 -> 227.95, 227.95
% INFO    : Updated Thermal Rating: on line 60259-60308 : Rate B, Rate C - 0.0, 0.0 -> 218.67, 218.67
% INFO    : Updated Thermal Rating: on line 60262-60377 : Rate B, Rate C - 0.0, 0.0 -> 170.41, 170.41
% INFO    : Updated Thermal Rating: on transformer 60264-60267 : Rate B, Rate C - 0.0, 0.0 -> 341.41, 341.41
% INFO    : Updated Thermal Rating: on line 60264-60725 : Rate B, Rate C - 0.0, 0.0 -> 605.26, 605.26
% INFO    : Updated Thermal Rating: on line 60842-60264 : Rate B, Rate C - 0.0, 0.0 -> 513.56, 513.56
% INFO    : Updated Thermal Rating: on transformer 60265-60267 : Rate B, Rate C - 0.0, 0.0 -> 266.41, 266.41
% INFO    : Updated Thermal Rating: on line 60268-60265 : Rate B, Rate C - 0.0, 0.0 -> 184.62, 184.62
% INFO    : Updated Thermal Rating: on line 60284-60265 : Rate B, Rate C - 0.0, 0.0 -> 168.45, 168.45
% INFO    : Updated Thermal Rating: on line 60265-60333 : Rate B, Rate C - 0.0, 0.0 -> 171.25, 171.25
% INFO    : Updated Thermal Rating: on transformer 60266-60267 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 60268-60335 : Rate B, Rate C - 0.0, 0.0 -> 160.82, 160.82
% INFO    : Updated Thermal Rating: on line 60270-60338 : Rate B, Rate C - 0.0, 0.0 -> 204.16, 204.16
% INFO    : Updated Thermal Rating: on line 60270-60338 : Rate B, Rate C - 0.0, 0.0 -> 204.16, 204.16
% INFO    : Updated Thermal Rating: on line 60270-60338 : Rate B, Rate C - 0.0, 0.0 -> 204.16, 204.16
% INFO    : Updated Thermal Rating: on line 60347-60270 : Rate B, Rate C - 0.0, 0.0 -> 183.09, 183.09
% INFO    : Updated Thermal Rating: on line 60270-60378 : Rate B, Rate C - 0.0, 0.0 -> 173.62, 173.62
% INFO    : Updated Thermal Rating: on line 60271-60676 : Rate B, Rate C - 0.0, 0.0 -> 181.77, 181.77
% INFO    : Updated Thermal Rating: on line 60322-60272 : Rate B, Rate C - 0.0, 0.0 -> 260.46, 260.46
% INFO    : Updated Thermal Rating: on line 60272-60327 : Rate B, Rate C - 0.0, 0.0 -> 172.58, 172.58
% INFO    : Updated Thermal Rating: on line 60272-60329 : Rate B, Rate C - 0.0, 0.0 -> 170.97, 170.97
% INFO    : Updated Thermal Rating: on line 60390-60272 : Rate B, Rate C - 0.0, 0.0 -> 103.68, 103.68
% INFO    : Updated Thermal Rating: on line 60272-60838 : Rate B, Rate C - 0.0, 0.0 -> 296.27, 296.27
% INFO    : Updated Thermal Rating: on transformer 60274-60277 : Rate B, Rate C - 0.0, 0.0 -> 283.09, 283.09
% INFO    : Updated Thermal Rating: on transformer 60275-60277 : Rate B, Rate C - 0.0, 0.0 -> 183.09, 183.09
% INFO    : Updated Thermal Rating: on line 60326-60275 : Rate B, Rate C - 0.0, 0.0 -> 160.76, 160.76
% INFO    : Updated Thermal Rating: on line 60330-60275 : Rate B, Rate C - 0.0, 0.0 -> 97.23, 97.23
% INFO    : Updated Thermal Rating: on transformer 60276-60277 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 60278-60307 : Rate B, Rate C - 0.0, 0.0 -> 642.98, 642.98
% INFO    : Updated Thermal Rating: on line 60278-60387 : Rate B, Rate C - 0.0, 0.0 -> 525.79, 525.79
% INFO    : Updated Thermal Rating: on line 60278-60675 : Rate B, Rate C - 0.0, 0.0 -> 653.97, 653.97
% INFO    : Updated Thermal Rating: on line 60278-60684 : Rate B, Rate C - 0.0, 0.0 -> 577.66, 577.66
% INFO    : Updated Thermal Rating: on line 60278-60842 : Rate B, Rate C - 0.0, 0.0 -> 578.35, 578.35
% INFO    : Updated Thermal Rating: on line 60338-60279 : Rate B, Rate C - 0.0, 0.0 -> 188.52, 188.52
% INFO    : Updated Thermal Rating: on line 60279-60346 : Rate B, Rate C - 0.0, 0.0 -> 166.82, 166.82
% INFO    : Updated Thermal Rating: on line 60283-60308 : Rate B, Rate C - 0.0, 0.0 -> 216.95, 216.95
% INFO    : Updated Thermal Rating: on line 60283-60308 : Rate B, Rate C - 0.0, 0.0 -> 216.95, 216.95
% INFO    : Updated Thermal Rating: on line 60283-60308 : Rate B, Rate C - 0.0, 0.0 -> 216.95, 216.95
% INFO    : Updated Thermal Rating: on line 60283-60309 : Rate B, Rate C - 0.0, 0.0 -> 187.55, 187.55
% INFO    : Updated Thermal Rating: on line 60365-60284 : Rate B, Rate C - 0.0, 0.0 -> 146.9, 146.9
% INFO    : Updated Thermal Rating: on line 60288-60286 : Rate B, Rate C - 0.0, 0.0 -> 186.93, 186.93
% INFO    : Updated Thermal Rating: on transformer 60288-60287 : Rate B, Rate C - 0.0, 0.0 -> 200.12, 200.12
% INFO    : Updated Thermal Rating: on line 60287-60337 : Rate B, Rate C - 0.0, 0.0 -> 605.97, 605.97
% INFO    : Updated Thermal Rating: on line 60684-60287 : Rate B, Rate C - 0.0, 0.0 -> 513.89, 513.89
% INFO    : Updated Thermal Rating: on line 60783-60287 : Rate B, Rate C - 0.0, 0.0 -> 477.52, 477.52
% INFO    : Updated Thermal Rating: on line 60886-60287 : Rate B, Rate C - 0.0, 0.0 -> 642.89, 642.89
% INFO    : Updated Thermal Rating: on line 60287-70136 : Rate B, Rate C - 0.0, 0.0 -> 632.78, 632.78
% INFO    : Updated Thermal Rating: on line 60290-60888 : Rate B, Rate C - 0.0, 0.0 -> 160.5, 160.5
% INFO    : Updated Thermal Rating: on line 60292-60328 : Rate B, Rate C - 0.0, 0.0 -> 169.18, 169.18
% INFO    : Updated Thermal Rating: on line 60293-60308 : Rate B, Rate C - 0.0, 0.0 -> 286.76, 286.76
% INFO    : Updated Thermal Rating: on line 60293-60390 : Rate B, Rate C - 0.0, 0.0 -> 211.12, 211.12
% INFO    : Updated Thermal Rating: on line 60295-60380 : Rate B, Rate C - 0.0, 0.0 -> 155.57, 155.57
% INFO    : Updated Thermal Rating: on line 60295-60386 : Rate B, Rate C - 0.0, 0.0 -> 180.21, 180.21
% INFO    : Updated Thermal Rating: on line 60296-60330 : Rate B, Rate C - 0.0, 0.0 -> 133.08, 133.08
% INFO    : Updated Thermal Rating: on line 60300-60338 : Rate B, Rate C - 0.0, 0.0 -> 201.87, 201.87
% INFO    : Updated Thermal Rating: on line 60300-60338 : Rate B, Rate C - 0.0, 0.0 -> 201.87, 201.87
% INFO    : Updated Thermal Rating: on transformer 60302-60301 : Rate B, Rate C - 0.0, 0.0 -> 139.7, 139.7
% INFO    : Updated Thermal Rating: on line 60301-60482 : Rate B, Rate C - 0.0, 0.0 -> 557.87, 557.87
% INFO    : Updated Thermal Rating: on line 60301-60684 : Rate B, Rate C - 0.0, 0.0 -> 605.31, 605.31
% INFO    : Updated Thermal Rating: on line 60301-60886 : Rate B, Rate C - 0.0, 0.0 -> 663.0, 663.0
% INFO    : Updated Thermal Rating: on transformer 60302-60305 : Rate B, Rate C - 0.0, 0.0 -> 242.72, 242.72
% INFO    : Updated Thermal Rating: on line 60302-60554 : Rate B, Rate C - 0.0, 0.0 -> 213.13, 213.13
% INFO    : Updated Thermal Rating: on line 60887-60302 : Rate B, Rate C - 0.0, 0.0 -> 250.5, 250.5
% INFO    : Updated Thermal Rating: on transformer 60303-60305 : Rate B, Rate C - 0.0, 0.0 -> 95.0, 95.0
% INFO    : Updated Thermal Rating: on line 60564-60303 : Rate B, Rate C - 0.0, 0.0 -> 153.71, 153.71
% INFO    : Updated Thermal Rating: on transformer 60304-60305 : Rate B, Rate C - 0.0, 0.0 -> 159.44, 159.44
% INFO    : Updated Thermal Rating: on line 60306-60784 : Rate B, Rate C - 0.0, 0.0 -> 188.74, 188.74
% INFO    : Updated Thermal Rating: on transformer 60308-60307 : Rate B, Rate C - 0.0, 0.0 -> 295.95, 295.95
% INFO    : Updated Thermal Rating: on transformer 60308-60307 : Rate B, Rate C - 0.0, 0.0 -> 295.95, 295.95
% INFO    : Updated Thermal Rating: on transformer 60308-60307 : Rate B, Rate C - 0.0, 0.0 -> 295.95, 295.95
% INFO    : Updated Thermal Rating: on transformer 60308-60307 : Rate B, Rate C - 0.0, 0.0 -> 295.95, 295.95
% INFO    : Updated Thermal Rating: on line 60307-60725 : Rate B, Rate C - 0.0, 0.0 -> 694.05, 694.05
% INFO    : Updated Thermal Rating: on line 60307-60850 : Rate B, Rate C - 0.0, 0.0 -> 517.0, 517.0
% INFO    : Updated Thermal Rating: on line 60308-60331 : Rate B, Rate C - 0.0, 0.0 -> 85.42, 85.42
% INFO    : Updated Thermal Rating: on line 60308-60810 : Rate B, Rate C - 0.0, 0.0 -> 180.5, 180.5
% INFO    : Updated Thermal Rating: on line 60309-60339 : Rate B, Rate C - 0.0, 0.0 -> 130.42, 130.42
% INFO    : Updated Thermal Rating: on line 60310-60878 : Rate B, Rate C - 0.0, 0.0 -> 164.43, 164.43
% INFO    : Updated Thermal Rating: on line 60311-60685 : Rate B, Rate C - 0.0, 0.0 -> 210.0, 210.0
% INFO    : Updated Thermal Rating: on line 60311-60685 : Rate B, Rate C - 0.0, 0.0 -> 210.0, 210.0
% INFO    : Updated Thermal Rating: on line 60311-60685 : Rate B, Rate C - 0.0, 0.0 -> 210.0, 210.0
% INFO    : Updated Thermal Rating: on line 60312-60401 : Rate B, Rate C - 0.0, 0.0 -> 169.39, 169.39
% INFO    : Updated Thermal Rating: on line 60312-60860 : Rate B, Rate C - 0.0, 0.0 -> 194.07, 194.07
% INFO    : Updated Thermal Rating: on line 60313-60315 : Rate B, Rate C - 0.0, 0.0 -> 191.83, 191.83
% INFO    : Updated Thermal Rating: on line 60313-60888 : Rate B, Rate C - 0.0, 0.0 -> 218.53, 218.53
% INFO    : Updated Thermal Rating: on line 60315-60413 : Rate B, Rate C - 0.0, 0.0 -> 177.42, 177.42
% INFO    : Updated Thermal Rating: on line 60317-60373 : Rate B, Rate C - 0.0, 0.0 -> 162.04, 162.04
% INFO    : Updated Thermal Rating: on line 60380-60317 : Rate B, Rate C - 0.0, 0.0 -> 157.64, 157.64
% INFO    : Updated Thermal Rating: on line 60327-60319 : Rate B, Rate C - 0.0, 0.0 -> 200.86, 200.86
% INFO    : Updated Thermal Rating: on line 60327-60319 : Rate B, Rate C - 0.0, 0.0 -> 200.86, 200.86
% INFO    : Updated Thermal Rating: on line 60838-60319 : Rate B, Rate C - 0.0, 0.0 -> 203.19, 203.19
% INFO    : Updated Thermal Rating: on line 60838-60319 : Rate B, Rate C - 0.0, 0.0 -> 203.19, 203.19
% INFO    : Updated Thermal Rating: on line 60838-60319 : Rate B, Rate C - 0.0, 0.0 -> 203.19, 203.19
% INFO    : Updated Thermal Rating: on line 60322-60362 : Rate B, Rate C - 0.0, 0.0 -> 157.52, 157.52
% INFO    : Updated Thermal Rating: on line 60322-60377 : Rate B, Rate C - 0.0, 0.0 -> 142.13, 142.13
% INFO    : Updated Thermal Rating: on line 60324-60350 : Rate B, Rate C - 0.0, 0.0 -> 126.71, 126.71
% INFO    : Updated Thermal Rating: on line 60324-60415 : Rate B, Rate C - 0.0, 0.0 -> 170.01, 170.01
% INFO    : Updated Thermal Rating: on line 60726-60324 : Rate B, Rate C - 0.0, 0.0 -> 187.75, 187.75
% INFO    : Updated Thermal Rating: on line 60327-60393 : Rate B, Rate C - 0.0, 0.0 -> 175.69, 175.69
% INFO    : Updated Thermal Rating: on line 60328-60342 : Rate B, Rate C - 0.0, 0.0 -> 139.49, 139.49
% INFO    : Updated Thermal Rating: on line 60362-60329 : Rate B, Rate C - 0.0, 0.0 -> 121.35, 121.35
% INFO    : Updated Thermal Rating: on line 60350-60331 : Rate B, Rate C - 0.0, 0.0 -> 160.49, 160.49
% INFO    : Updated Thermal Rating: on line 60331-60378 : Rate B, Rate C - 0.0, 0.0 -> 138.42, 138.42
% INFO    : Updated Thermal Rating: on line 60726-60331 : Rate B, Rate C - 0.0, 0.0 -> 180.64, 180.64
% INFO    : Updated Thermal Rating: on line 60333-60411 : Rate B, Rate C - 0.0, 0.0 -> 146.89, 146.89
% INFO    : Updated Thermal Rating: on line 60365-60335 : Rate B, Rate C - 0.0, 0.0 -> 115.93, 115.93
% INFO    : Updated Thermal Rating: on line 60386-60336 : Rate B, Rate C - 0.0, 0.0 -> 160.71, 160.71
% INFO    : Updated Thermal Rating: on line 60401-60336 : Rate B, Rate C - 0.0, 0.0 -> 173.89, 173.89
% INFO    : Updated Thermal Rating: on line 60336-60402 : Rate B, Rate C - 0.0, 0.0 -> 178.6, 178.6
% INFO    : Updated Thermal Rating: on transformer 60338-60337 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on transformer 60338-60337 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on transformer 60338-60337 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on transformer 60338-60337 : Rate B, Rate C - 0.0, 0.0 -> 303.18, 303.18
% INFO    : Updated Thermal Rating: on line 60387-60337 : Rate B, Rate C - 0.0, 0.0 -> 498.34, 498.34
% INFO    : Updated Thermal Rating: on line 60675-60337 : Rate B, Rate C - 0.0, 0.0 -> 652.15, 652.15
% INFO    : Updated Thermal Rating: on line 60337-60725 : Rate B, Rate C - 0.0, 0.0 -> 558.67, 558.67
% INFO    : Updated Thermal Rating: on line 60337-60863 : Rate B, Rate C - 0.0, 0.0 -> 558.05, 558.05
% INFO    : Updated Thermal Rating: on line 60339-60350 : Rate B, Rate C - 0.0, 0.0 -> 171.95, 171.95
% INFO    : Updated Thermal Rating: on line 60369-60339 : Rate B, Rate C - 0.0, 0.0 -> 150.9, 150.9
% INFO    : Updated Thermal Rating: on line 60448-60341 : Rate B, Rate C - 0.0, 0.0 -> 138.9, 138.9
% INFO    : Updated Thermal Rating: on line 60341-60523 : Rate B, Rate C - 0.0, 0.0 -> 163.23, 163.23
% INFO    : Updated Thermal Rating: on line 60342-60838 : Rate B, Rate C - 0.0, 0.0 -> 162.49, 162.49
% INFO    : Updated Thermal Rating: on line 60343-60350 : Rate B, Rate C - 0.0, 0.0 -> 155.48, 155.48
% INFO    : Updated Thermal Rating: on line 60452-60343 : Rate B, Rate C - 0.0, 0.0 -> 137.09, 137.09
% INFO    : Updated Thermal Rating: on line 60346-60372 : Rate B, Rate C - 0.0, 0.0 -> 168.64, 168.64
% INFO    : Updated Thermal Rating: on line 60388-60346 : Rate B, Rate C - 0.0, 0.0 -> 161.06, 161.06
% INFO    : Updated Thermal Rating: on line 60346-60401 : Rate B, Rate C - 0.0, 0.0 -> 181.03, 181.03
% INFO    : Updated Thermal Rating: on line 60350-60726 : Rate B, Rate C - 0.0, 0.0 -> 192.15, 192.15
% INFO    : Updated Thermal Rating: on line 60404-60352 : Rate B, Rate C - 0.0, 0.0 -> 169.66, 169.66
% INFO    : Updated Thermal Rating: on line 60352-60426 : Rate B, Rate C - 0.0, 0.0 -> 167.57, 167.57
% INFO    : Updated Thermal Rating: on transformer 60355-60354 : Rate B, Rate C - 0.0, 0.0 -> 264.25, 264.25
% INFO    : Updated Thermal Rating: on transformer 60355-60354 : Rate B, Rate C - 0.0, 0.0 -> 264.25, 264.25
% INFO    : Updated Thermal Rating: on transformer 60355-60354 : Rate B, Rate C - 0.0, 0.0 -> 264.25, 264.25
% INFO    : Updated Thermal Rating: on line 60354-60370 : Rate B, Rate C - 0.0, 0.0 -> 525.57, 525.57
% INFO    : Updated Thermal Rating: on line 60725-60354 : Rate B, Rate C - 0.0, 0.0 -> 628.65, 628.65
% INFO    : Updated Thermal Rating: on line 60354-60753 : Rate B, Rate C - 0.0, 0.0 -> 594.39, 594.39
% INFO    : Updated Thermal Rating: on line 60355-60383 : Rate B, Rate C - 0.0, 0.0 -> 228.02, 228.02
% INFO    : Updated Thermal Rating: on line 60355-60383 : Rate B, Rate C - 0.0, 0.0 -> 228.02, 228.02
% INFO    : Updated Thermal Rating: on line 60355-60383 : Rate B, Rate C - 0.0, 0.0 -> 228.02, 228.02
% INFO    : Updated Thermal Rating: on line 60355-60398 : Rate B, Rate C - 0.0, 0.0 -> 171.58, 171.58
% INFO    : Updated Thermal Rating: on line 60375-60359 : Rate B, Rate C - 0.0, 0.0 -> 155.67, 155.67
% INFO    : Updated Thermal Rating: on line 60359-60838 : Rate B, Rate C - 0.0, 0.0 -> 185.51, 185.51
% INFO    : Updated Thermal Rating: on line 60404-60361 : Rate B, Rate C - 0.0, 0.0 -> 167.94, 167.94
% INFO    : Updated Thermal Rating: on line 60409-60361 : Rate B, Rate C - 0.0, 0.0 -> 139.67, 139.67
% INFO    : Updated Thermal Rating: on line 60361-60810 : Rate B, Rate C - 0.0, 0.0 -> 189.67, 189.67
% INFO    : Updated Thermal Rating: on line 60369-60363 : Rate B, Rate C - 0.0, 0.0 -> 133.46, 133.46
% INFO    : Updated Thermal Rating: on line 60363-60810 : Rate B, Rate C - 0.0, 0.0 -> 170.65, 170.65
% INFO    : Updated Thermal Rating: on line 60368-60417 : Rate B, Rate C - 0.0, 0.0 -> 159.0, 159.0
% INFO    : Updated Thermal Rating: on line 60368-60433 : Rate B, Rate C - 0.0, 0.0 -> 168.01, 168.01
% INFO    : Updated Thermal Rating: on line 60496-60368 : Rate B, Rate C - 0.0, 0.0 -> 179.01, 179.01
% INFO    : Updated Thermal Rating: on transformer 60371-60370 : Rate B, Rate C - 0.0, 0.0 -> 250.9, 250.9
% INFO    : Updated Thermal Rating: on transformer 60371-60370 : Rate B, Rate C - 0.0, 0.0 -> 250.9, 250.9
% INFO    : Updated Thermal Rating: on transformer 60371-60370 : Rate B, Rate C - 0.0, 0.0 -> 250.9, 250.9
% INFO    : Updated Thermal Rating: on line 60725-60370 : Rate B, Rate C - 0.0, 0.0 -> 656.64, 656.64
% INFO    : Updated Thermal Rating: on line 60370-60753 : Rate B, Rate C - 0.0, 0.0 -> 561.31, 561.31
% INFO    : Updated Thermal Rating: on line 60394-60371 : Rate B, Rate C - 0.0, 0.0 -> 190.79, 190.79
% INFO    : Updated Thermal Rating: on line 60451-60371 : Rate B, Rate C - 0.0, 0.0 -> 184.61, 184.61
% INFO    : Updated Thermal Rating: on line 60371-60452 : Rate B, Rate C - 0.0, 0.0 -> 175.24, 175.24
% INFO    : Updated Thermal Rating: on line 60430-60372 : Rate B, Rate C - 0.0, 0.0 -> 147.01, 147.01
% INFO    : Updated Thermal Rating: on line 60373-60477 : Rate B, Rate C - 0.0, 0.0 -> 168.18, 168.18
% INFO    : Updated Thermal Rating: on line 60375-60382 : Rate B, Rate C - 0.0, 0.0 -> 164.52, 164.52
% INFO    : Updated Thermal Rating: on line 60390-60375 : Rate B, Rate C - 0.0, 0.0 -> 156.86, 156.86
% INFO    : Updated Thermal Rating: on line 60375-60393 : Rate B, Rate C - 0.0, 0.0 -> 152.67, 152.67
% INFO    : Updated Thermal Rating: on line 60419-60380 : Rate B, Rate C - 0.0, 0.0 -> 167.78, 167.78
% INFO    : Updated Thermal Rating: on line 60426-60382 : Rate B, Rate C - 0.0, 0.0 -> 131.54, 131.54
% INFO    : Updated Thermal Rating: on line 60391-60383 : Rate B, Rate C - 0.0, 0.0 -> 198.94, 198.94
% INFO    : Updated Thermal Rating: on line 60391-60383 : Rate B, Rate C - 0.0, 0.0 -> 198.94, 198.94
% INFO    : Updated Thermal Rating: on line 60383-60396 : Rate B, Rate C - 0.0, 0.0 -> 228.53, 228.53
% INFO    : Updated Thermal Rating: on transformer 60386-60385 : Rate B, Rate C - 0.0, 0.0 -> 227.71, 227.71
% INFO    : Updated Thermal Rating: on transformer 60386-60385 : Rate B, Rate C - 0.0, 0.0 -> 227.71, 227.71
% INFO    : Updated Thermal Rating: on transformer 60386-60385 : Rate B, Rate C - 0.0, 0.0 -> 227.71, 227.71
% INFO    : Updated Thermal Rating: on line 60386-60419 : Rate B, Rate C - 0.0, 0.0 -> 182.29, 182.29
% INFO    : Updated Thermal Rating: on line 60387-60673 : Rate B, Rate C - 0.0, 0.0 -> 563.74, 563.74
% INFO    : Updated Thermal Rating: on line 60675-60387 : Rate B, Rate C - 0.0, 0.0 -> 618.3, 618.3
% INFO    : Updated Thermal Rating: on line 60863-60387 : Rate B, Rate C - 0.0, 0.0 -> 530.47, 530.47
% INFO    : Updated Thermal Rating: on line 60451-60388 : Rate B, Rate C - 0.0, 0.0 -> 156.42, 156.42
% INFO    : Updated Thermal Rating: on line 60470-60389 : Rate B, Rate C - 0.0, 0.0 -> 162.55, 162.55
% INFO    : Updated Thermal Rating: on line 60389-60481 : Rate B, Rate C - 0.0, 0.0 -> 149.08, 149.08
% INFO    : Updated Thermal Rating: on line 60391-60458 : Rate B, Rate C - 0.0, 0.0 -> 189.29, 189.29
% INFO    : Updated Thermal Rating: on line 60436-60392 : Rate B, Rate C - 0.0, 0.0 -> 168.01, 168.01
% INFO    : Updated Thermal Rating: on line 60440-60392 : Rate B, Rate C - 0.0, 0.0 -> 185.41, 185.41
% INFO    : Updated Thermal Rating: on line 60420-60394 : Rate B, Rate C - 0.0, 0.0 -> 173.46, 173.46
% INFO    : Updated Thermal Rating: on line 60480-60394 : Rate B, Rate C - 0.0, 0.0 -> 140.92, 140.92
% INFO    : Updated Thermal Rating: on line 60396-60418 : Rate B, Rate C - 0.0, 0.0 -> 236.97, 236.97
% INFO    : Updated Thermal Rating: on line 60396-60456 : Rate B, Rate C - 0.0, 0.0 -> 151.53, 151.53
% INFO    : Updated Thermal Rating: on line 60457-60398 : Rate B, Rate C - 0.0, 0.0 -> 139.69, 139.69
% INFO    : Updated Thermal Rating: on line 60860-60402 : Rate B, Rate C - 0.0, 0.0 -> 191.31, 191.31
% INFO    : Updated Thermal Rating: on line 60404-60415 : Rate B, Rate C - 0.0, 0.0 -> 175.66, 175.66
% INFO    : Updated Thermal Rating: on line 60458-60404 : Rate B, Rate C - 0.0, 0.0 -> 156.98, 156.98
% INFO    : Updated Thermal Rating: on line 60432-60405 : Rate B, Rate C - 0.0, 0.0 -> 130.86, 130.86
% INFO    : Updated Thermal Rating: on line 60490-60405 : Rate B, Rate C - 0.0, 0.0 -> 164.91, 164.91
% INFO    : Updated Thermal Rating: on line 60407-60459 : Rate B, Rate C - 0.0, 0.0 -> 152.27, 152.27
% INFO    : Updated Thermal Rating: on line 60460-60407 : Rate B, Rate C - 0.0, 0.0 -> 151.4, 151.4
% INFO    : Updated Thermal Rating: on line 60408-60469 : Rate B, Rate C - 0.0, 0.0 -> 145.51, 145.51
% INFO    : Updated Thermal Rating: on line 60408-60528 : Rate B, Rate C - 0.0, 0.0 -> 154.16, 154.16
% INFO    : Updated Thermal Rating: on line 60421-60409 : Rate B, Rate C - 0.0, 0.0 -> 162.47, 162.47
% INFO    : Updated Thermal Rating: on line 60411-60414 : Rate B, Rate C - 0.0, 0.0 -> 138.73, 138.73
% INFO    : Updated Thermal Rating: on line 60436-60414 : Rate B, Rate C - 0.0, 0.0 -> 174.38, 174.38
% INFO    : Updated Thermal Rating: on line 60420-60415 : Rate B, Rate C - 0.0, 0.0 -> 158.51, 158.51
% INFO    : Updated Thermal Rating: on line 60417-60440 : Rate B, Rate C - 0.0, 0.0 -> 181.81, 181.81
% INFO    : Updated Thermal Rating: on line 60418-60425 : Rate B, Rate C - 0.0, 0.0 -> 133.77, 133.77
% INFO    : Updated Thermal Rating: on line 60418-60558 : Rate B, Rate C - 0.0, 0.0 -> 147.06, 147.06
% INFO    : Updated Thermal Rating: on line 60421-60487 : Rate B, Rate C - 0.0, 0.0 -> 140.0, 140.0
% INFO    : Updated Thermal Rating: on line 60421-60488 : Rate B, Rate C - 0.0, 0.0 -> 179.92, 179.92
% INFO    : Updated Thermal Rating: on line 60422-60431 : Rate B, Rate C - 0.0, 0.0 -> 147.56, 147.56
% INFO    : Updated Thermal Rating: on line 60478-60422 : Rate B, Rate C - 0.0, 0.0 -> 142.56, 142.56
% INFO    : Updated Thermal Rating: on line 60423-60471 : Rate B, Rate C - 0.0, 0.0 -> 151.58, 151.58
% INFO    : Updated Thermal Rating: on line 60423-60500 : Rate B, Rate C - 0.0, 0.0 -> 160.52, 160.52
% INFO    : Updated Thermal Rating: on line 60424-60441 : Rate B, Rate C - 0.0, 0.0 -> 133.09, 133.09
% INFO    : Updated Thermal Rating: on line 60424-60854 : Rate B, Rate C - 0.0, 0.0 -> 168.74, 168.74
% INFO    : Updated Thermal Rating: on line 60425-60433 : Rate B, Rate C - 0.0, 0.0 -> 146.63, 146.63
% INFO    : Updated Thermal Rating: on line 60425-60511 : Rate B, Rate C - 0.0, 0.0 -> 152.81, 152.81
% INFO    : Updated Thermal Rating: on line 60429-60501 : Rate B, Rate C - 0.0, 0.0 -> 156.62, 156.62
% INFO    : Updated Thermal Rating: on line 60429-60502 : Rate B, Rate C - 0.0, 0.0 -> 159.95, 159.95
% INFO    : Updated Thermal Rating: on line 60429-60878 : Rate B, Rate C - 0.0, 0.0 -> 233.76, 233.76
% INFO    : Updated Thermal Rating: on line 60430-60726 : Rate B, Rate C - 0.0, 0.0 -> 180.2, 180.2
% INFO    : Updated Thermal Rating: on line 60431-60520 : Rate B, Rate C - 0.0, 0.0 -> 181.24, 181.24
% INFO    : Updated Thermal Rating: on line 60432-60449 : Rate B, Rate C - 0.0, 0.0 -> 134.18, 134.18
% INFO    : Updated Thermal Rating: on line 60490-60432 : Rate B, Rate C - 0.0, 0.0 -> 161.78, 161.78
% INFO    : Updated Thermal Rating: on line 60436-60499 : Rate B, Rate C - 0.0, 0.0 -> 170.1, 170.1
% INFO    : Updated Thermal Rating: on transformer 60440-60439 : Rate B, Rate C - 0.0, 0.0 -> 237.08, 237.08
% INFO    : Updated Thermal Rating: on transformer 60440-60439 : Rate B, Rate C - 0.0, 0.0 -> 237.08, 237.08
% INFO    : Updated Thermal Rating: on transformer 60440-60439 : Rate B, Rate C - 0.0, 0.0 -> 237.08, 237.08
% INFO    : Updated Thermal Rating: on line 60439-60639 : Rate B, Rate C - 0.0, 0.0 -> 536.98, 536.98
% INFO    : Updated Thermal Rating: on line 60439-60649 : Rate B, Rate C - 0.0, 0.0 -> 629.31, 629.31
% INFO    : Updated Thermal Rating: on line 60459-60440 : Rate B, Rate C - 0.0, 0.0 -> 174.89, 174.89
% INFO    : Updated Thermal Rating: on line 60441-60535 : Rate B, Rate C - 0.0, 0.0 -> 166.82, 166.82
% INFO    : Updated Thermal Rating: on line 60854-60441 : Rate B, Rate C - 0.0, 0.0 -> 187.64, 187.64
% INFO    : Updated Thermal Rating: on transformer 60443-60446 : Rate B, Rate C - 0.0, 0.0 -> 133.23, 133.23
% INFO    : Updated Thermal Rating: on transformer 60444-60446 : Rate B, Rate C - 0.0, 0.0 -> 66.62, 66.62
% INFO    : Updated Thermal Rating: on transformer 60445-60446 : Rate B, Rate C - 0.0, 0.0 -> 66.62, 66.62
% INFO    : Updated Thermal Rating: on line 60466-60447 : Rate B, Rate C - 0.0, 0.0 -> 149.32, 149.32
% INFO    : Updated Thermal Rating: on line 60447-60854 : Rate B, Rate C - 0.0, 0.0 -> 172.47, 172.47
% INFO    : Updated Thermal Rating: on line 60470-60448 : Rate B, Rate C - 0.0, 0.0 -> 168.84, 168.84
% INFO    : Updated Thermal Rating: on line 60448-60483 : Rate B, Rate C - 0.0, 0.0 -> 184.62, 184.62
% INFO    : Updated Thermal Rating: on line 60449-60589 : Rate B, Rate C - 0.0, 0.0 -> 170.98, 170.98
% INFO    : Updated Thermal Rating: on line 60522-60453 : Rate B, Rate C - 0.0, 0.0 -> 106.68, 106.68
% INFO    : Updated Thermal Rating: on line 60550-60453 : Rate B, Rate C - 0.0, 0.0 -> 166.43, 166.43
% INFO    : Updated Thermal Rating: on line 60455-60456 : Rate B, Rate C - 0.0, 0.0 -> 155.09, 155.09
% INFO    : Updated Thermal Rating: on line 60455-60488 : Rate B, Rate C - 0.0, 0.0 -> 181.94, 181.94
% INFO    : Updated Thermal Rating: on line 60457-60488 : Rate B, Rate C - 0.0, 0.0 -> 169.93, 169.93
% INFO    : Updated Thermal Rating: on transformer 60460-60463 : Rate B, Rate C - 0.0, 0.0 -> 56.41, 56.41
% INFO    : Updated Thermal Rating: on line 60460-60573 : Rate B, Rate C - 0.0, 0.0 -> 172.09, 172.09
% INFO    : Updated Thermal Rating: on transformer 60461-60463 : Rate B, Rate C - 0.0, 0.0 -> 28.21, 28.21
% INFO    : Updated Thermal Rating: on transformer 60462-60463 : Rate B, Rate C - 0.0, 0.0 -> 28.21, 28.21
% INFO    : Updated Thermal Rating: on line 60464-60490 : Rate B, Rate C - 0.0, 0.0 -> 159.32, 159.32
% INFO    : Updated Thermal Rating: on line 60464-60507 : Rate B, Rate C - 0.0, 0.0 -> 161.47, 161.47
% INFO    : Updated Thermal Rating: on line 60464-60524 : Rate B, Rate C - 0.0, 0.0 -> 163.58, 163.58
% INFO    : Updated Thermal Rating: on line 60509-60466 : Rate B, Rate C - 0.0, 0.0 -> 143.42, 143.42
% INFO    : Updated Thermal Rating: on line 60467-60493 : Rate B, Rate C - 0.0, 0.0 -> 134.34, 134.34
% INFO    : Updated Thermal Rating: on line 60535-60467 : Rate B, Rate C - 0.0, 0.0 -> 151.16, 151.16
% INFO    : Updated Thermal Rating: on line 60467-60536 : Rate B, Rate C - 0.0, 0.0 -> 138.05, 138.05
% INFO    : Updated Thermal Rating: on line 60528-60468 : Rate B, Rate C - 0.0, 0.0 -> 167.21, 167.21
% INFO    : Updated Thermal Rating: on line 60468-60566 : Rate B, Rate C - 0.0, 0.0 -> 165.18, 165.18
% INFO    : Updated Thermal Rating: on line 60468-60574 : Rate B, Rate C - 0.0, 0.0 -> 166.58, 166.58
% INFO    : Updated Thermal Rating: on line 60469-60659 : Rate B, Rate C - 0.0, 0.0 -> 183.12, 183.12
% INFO    : Updated Thermal Rating: on line 60471-60500 : Rate B, Rate C - 0.0, 0.0 -> 155.93, 155.93
% INFO    : Updated Thermal Rating: on line 60471-60521 : Rate B, Rate C - 0.0, 0.0 -> 157.04, 157.04
% INFO    : Updated Thermal Rating: on line 60473-60472 : Rate B, Rate C - 0.0, 0.0 -> 151.97, 151.97
% INFO    : Updated Thermal Rating: on line 60472-60845 : Rate B, Rate C - 0.0, 0.0 -> 179.3, 179.3
% INFO    : Updated Thermal Rating: on transformer 60473-60476 : Rate B, Rate C - 0.0, 0.0 -> 50.35, 50.35
% INFO    : Updated Thermal Rating: on line 60754-60473 : Rate B, Rate C - 0.0, 0.0 -> 149.44, 149.44
% INFO    : Updated Thermal Rating: on transformer 60474-60476 : Rate B, Rate C - 0.0, 0.0 -> 25.17, 25.17
% INFO    : Updated Thermal Rating: on transformer 60475-60476 : Rate B, Rate C - 0.0, 0.0 -> 25.17, 25.17
% INFO    : Updated Thermal Rating: on line 60477-60685 : Rate B, Rate C - 0.0, 0.0 -> 183.57, 183.57
% INFO    : Updated Thermal Rating: on line 60478-60715 : Rate B, Rate C - 0.0, 0.0 -> 180.9, 180.9
% INFO    : Updated Thermal Rating: on line 60480-60845 : Rate B, Rate C - 0.0, 0.0 -> 180.28, 180.28
% INFO    : Updated Thermal Rating: on line 60481-60570 : Rate B, Rate C - 0.0, 0.0 -> 188.77, 188.77
% INFO    : Updated Thermal Rating: on transformer 60483-60482 : Rate B, Rate C - 0.0, 0.0 -> 236.02, 236.02
% INFO    : Updated Thermal Rating: on transformer 60483-60482 : Rate B, Rate C - 0.0, 0.0 -> 236.02, 236.02
% INFO    : Updated Thermal Rating: on transformer 60483-60482 : Rate B, Rate C - 0.0, 0.0 -> 236.02, 236.02
% INFO    : Updated Thermal Rating: on line 60482-60556 : Rate B, Rate C - 0.0, 0.0 -> 608.17, 608.17
% INFO    : Updated Thermal Rating: on line 60523-60483 : Rate B, Rate C - 0.0, 0.0 -> 215.79, 215.79
% INFO    : Updated Thermal Rating: on line 60483-60552 : Rate B, Rate C - 0.0, 0.0 -> 172.06, 172.06
% INFO    : Updated Thermal Rating: on line 60494-60485 : Rate B, Rate C - 0.0, 0.0 -> 160.44, 160.44
% INFO    : Updated Thermal Rating: on line 60514-60485 : Rate B, Rate C - 0.0, 0.0 -> 163.59, 163.59
% INFO    : Updated Thermal Rating: on line 60485-60587 : Rate B, Rate C - 0.0, 0.0 -> 163.99, 163.99
% INFO    : Updated Thermal Rating: on line 60495-60486 : Rate B, Rate C - 0.0, 0.0 -> 151.0, 151.0
% INFO    : Updated Thermal Rating: on line 60486-60557 : Rate B, Rate C - 0.0, 0.0 -> 151.91, 151.91
% INFO    : Updated Thermal Rating: on line 60487-60590 : Rate B, Rate C - 0.0, 0.0 -> 176.29, 176.29
% INFO    : Updated Thermal Rating: on line 60488-60832 : Rate B, Rate C - 0.0, 0.0 -> 212.59, 212.59
% INFO    : Updated Thermal Rating: on line 60488-60832 : Rate B, Rate C - 0.0, 0.0 -> 212.59, 212.59
% INFO    : Updated Thermal Rating: on line 60488-60832 : Rate B, Rate C - 0.0, 0.0 -> 212.59, 212.59
% INFO    : Updated Thermal Rating: on transformer 60490-60489 : Rate B, Rate C - 0.0, 0.0 -> 272.23, 272.23
% INFO    : Updated Thermal Rating: on transformer 60490-60489 : Rate B, Rate C - 0.0, 0.0 -> 272.23, 272.23
% INFO    : Updated Thermal Rating: on transformer 60490-60489 : Rate B, Rate C - 0.0, 0.0 -> 272.23, 272.23
% INFO    : Updated Thermal Rating: on line 60489-60796 : Rate B, Rate C - 0.0, 0.0 -> 563.47, 563.47
% INFO    : Updated Thermal Rating: on line 60853-60489 : Rate B, Rate C - 0.0, 0.0 -> 536.61, 536.61
% INFO    : Updated Thermal Rating: on line 60877-60489 : Rate B, Rate C - 0.0, 0.0 -> 584.57, 584.57
% INFO    : Updated Thermal Rating: on line 60493-60490 : Rate B, Rate C - 0.0, 0.0 -> 179.51, 179.51
% INFO    : Updated Thermal Rating: on line 60490-60526 : Rate B, Rate C - 0.0, 0.0 -> 191.88, 191.88
% INFO    : Updated Thermal Rating: on line 60490-60543 : Rate B, Rate C - 0.0, 0.0 -> 160.11, 160.11
% INFO    : Updated Thermal Rating: on line 60542-60494 : Rate B, Rate C - 0.0, 0.0 -> 135.78, 135.78
% INFO    : Updated Thermal Rating: on line 60494-60549 : Rate B, Rate C - 0.0, 0.0 -> 165.46, 165.46
% INFO    : Updated Thermal Rating: on line 60511-60495 : Rate B, Rate C - 0.0, 0.0 -> 193.3, 193.3
% INFO    : Updated Thermal Rating: on line 60495-60715 : Rate B, Rate C - 0.0, 0.0 -> 211.49, 211.49
% INFO    : Updated Thermal Rating: on line 60495-60715 : Rate B, Rate C - 0.0, 0.0 -> 211.49, 211.49
% INFO    : Updated Thermal Rating: on line 60495-60715 : Rate B, Rate C - 0.0, 0.0 -> 211.49, 211.49
% INFO    : Updated Thermal Rating: on line 60496-60499 : Rate B, Rate C - 0.0, 0.0 -> 198.08, 198.08
% INFO    : Updated Thermal Rating: on line 60496-60499 : Rate B, Rate C - 0.0, 0.0 -> 198.08, 198.08
% INFO    : Updated Thermal Rating: on transformer 60499-60498 : Rate B, Rate C - 0.0, 0.0 -> 234.32, 234.32
% INFO    : Updated Thermal Rating: on transformer 60499-60498 : Rate B, Rate C - 0.0, 0.0 -> 234.32, 234.32
% INFO    : Updated Thermal Rating: on transformer 60499-60498 : Rate B, Rate C - 0.0, 0.0 -> 234.32, 234.32
% INFO    : Updated Thermal Rating: on line 60498-60510 : Rate B, Rate C - 0.0, 0.0 -> 511.4, 511.4
% INFO    : Updated Thermal Rating: on line 60498-60639 : Rate B, Rate C - 0.0, 0.0 -> 567.45, 567.45
% INFO    : Updated Thermal Rating: on line 60498-60842 : Rate B, Rate C - 0.0, 0.0 -> 497.42, 497.42
% INFO    : Updated Thermal Rating: on line 60504-60500 : Rate B, Rate C - 0.0, 0.0 -> 154.55, 154.55
% INFO    : Updated Thermal Rating: on line 60500-60522 : Rate B, Rate C - 0.0, 0.0 -> 164.35, 164.35
% INFO    : Updated Thermal Rating: on line 60500-60854 : Rate B, Rate C - 0.0, 0.0 -> 169.15, 169.15
% INFO    : Updated Thermal Rating: on line 60500-60878 : Rate B, Rate C - 0.0, 0.0 -> 294.95, 294.95
% INFO    : Updated Thermal Rating: on line 60501-60504 : Rate B, Rate C - 0.0, 0.0 -> 141.51, 141.51
% INFO    : Updated Thermal Rating: on line 60516-60501 : Rate B, Rate C - 0.0, 0.0 -> 159.34, 159.34
% INFO    : Updated Thermal Rating: on line 60502-60516 : Rate B, Rate C - 0.0, 0.0 -> 133.92, 133.92
% INFO    : Updated Thermal Rating: on line 60506-60505 : Rate B, Rate C - 0.0, 0.0 -> 124.8, 124.8
% INFO    : Updated Thermal Rating: on line 60576-60505 : Rate B, Rate C - 0.0, 0.0 -> 161.9, 161.9
% INFO    : Updated Thermal Rating: on line 60636-60506 : Rate B, Rate C - 0.0, 0.0 -> 126.36, 126.36
% INFO    : Updated Thermal Rating: on line 60506-60787 : Rate B, Rate C - 0.0, 0.0 -> 169.5, 169.5
% INFO    : Updated Thermal Rating: on line 60526-60507 : Rate B, Rate C - 0.0, 0.0 -> 144.81, 144.81
% INFO    : Updated Thermal Rating: on line 60509-60762 : Rate B, Rate C - 0.0, 0.0 -> 152.47, 152.47
% INFO    : Updated Thermal Rating: on line 60509-60854 : Rate B, Rate C - 0.0, 0.0 -> 172.35, 172.35
% INFO    : Updated Thermal Rating: on transformer 60510-60513 : Rate B, Rate C - 0.0, 0.0 -> 253.06, 253.06
% INFO    : Updated Thermal Rating: on line 60510-60714 : Rate B, Rate C - 0.0, 0.0 -> 514.02, 514.02
% INFO    : Updated Thermal Rating: on transformer 60511-60513 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 60512-60513 : Rate B, Rate C - 0.0, 0.0 -> 142.6, 142.6
% INFO    : Updated Thermal Rating: on line 60514-60541 : Rate B, Rate C - 0.0, 0.0 -> 199.52, 199.52
% INFO    : Updated Thermal Rating: on line 60514-60541 : Rate B, Rate C - 0.0, 0.0 -> 199.52, 199.52
% INFO    : Updated Thermal Rating: on line 60514-60557 : Rate B, Rate C - 0.0, 0.0 -> 167.12, 167.12
% INFO    : Updated Thermal Rating: on line 60558-60514 : Rate B, Rate C - 0.0, 0.0 -> 174.24, 174.24
% INFO    : Updated Thermal Rating: on line 60515-60527 : Rate B, Rate C - 0.0, 0.0 -> 149.68, 149.68
% INFO    : Updated Thermal Rating: on line 60515-60548 : Rate B, Rate C - 0.0, 0.0 -> 157.55, 157.55
% INFO    : Updated Thermal Rating: on line 60854-60516 : Rate B, Rate C - 0.0, 0.0 -> 184.14, 184.14
% INFO    : Updated Thermal Rating: on line 60578-60518 : Rate B, Rate C - 0.0, 0.0 -> 181.11, 181.11
% INFO    : Updated Thermal Rating: on line 60518-60594 : Rate B, Rate C - 0.0, 0.0 -> 173.05, 173.05
% INFO    : Updated Thermal Rating: on line 60520-60568 : Rate B, Rate C - 0.0, 0.0 -> 141.04, 141.04
% INFO    : Updated Thermal Rating: on line 60520-60754 : Rate B, Rate C - 0.0, 0.0 -> 189.51, 189.51
% INFO    : Updated Thermal Rating: on line 60521-60551 : Rate B, Rate C - 0.0, 0.0 -> 179.69, 179.69
% INFO    : Updated Thermal Rating: on line 60685-60523 : Rate B, Rate C - 0.0, 0.0 -> 144.15, 144.15
% INFO    : Updated Thermal Rating: on line 60524-60527 : Rate B, Rate C - 0.0, 0.0 -> 173.33, 173.33
% INFO    : Updated Thermal Rating: on line 60524-60535 : Rate B, Rate C - 0.0, 0.0 -> 152.88, 152.88
% INFO    : Updated Thermal Rating: on line 60524-60545 : Rate B, Rate C - 0.0, 0.0 -> 164.32, 164.32
% INFO    : Updated Thermal Rating: on line 60524-60854 : Rate B, Rate C - 0.0, 0.0 -> 209.32, 209.32
% INFO    : Updated Thermal Rating: on line 60524-60854 : Rate B, Rate C - 0.0, 0.0 -> 209.32, 209.32
% INFO    : Updated Thermal Rating: on line 60524-60854 : Rate B, Rate C - 0.0, 0.0 -> 209.32, 209.32
% INFO    : Updated Thermal Rating: on line 60548-60526 : Rate B, Rate C - 0.0, 0.0 -> 137.71, 137.71
% INFO    : Updated Thermal Rating: on line 60528-60530 : Rate B, Rate C - 0.0, 0.0 -> 147.13, 147.13
% INFO    : Updated Thermal Rating: on line 60530-60659 : Rate B, Rate C - 0.0, 0.0 -> 172.77, 172.77
% INFO    : Updated Thermal Rating: on line 60534-60542 : Rate B, Rate C - 0.0, 0.0 -> 177.17, 177.17
% INFO    : Updated Thermal Rating: on line 60579-60534 : Rate B, Rate C - 0.0, 0.0 -> 182.25, 182.25
% INFO    : Updated Thermal Rating: on line 60561-60536 : Rate B, Rate C - 0.0, 0.0 -> 172.42, 172.42
% INFO    : Updated Thermal Rating: on transformer 60537-60540 : Rate B, Rate C - 0.0, 0.0 -> 159.32, 159.32
% INFO    : Updated Thermal Rating: on transformer 60538-60540 : Rate B, Rate C - 0.0, 0.0 -> 79.66, 79.66
% INFO    : Updated Thermal Rating: on transformer 60539-60540 : Rate B, Rate C - 0.0, 0.0 -> 79.66, 79.66
% INFO    : Updated Thermal Rating: on line 60549-60541 : Rate B, Rate C - 0.0, 0.0 -> 178.13, 178.13
% INFO    : Updated Thermal Rating: on line 60541-60715 : Rate B, Rate C - 0.0, 0.0 -> 214.99, 214.99
% INFO    : Updated Thermal Rating: on line 60541-60715 : Rate B, Rate C - 0.0, 0.0 -> 214.99, 214.99
% INFO    : Updated Thermal Rating: on line 60541-60715 : Rate B, Rate C - 0.0, 0.0 -> 214.99, 214.99
% INFO    : Updated Thermal Rating: on line 60543-60545 : Rate B, Rate C - 0.0, 0.0 -> 123.78, 123.78
% INFO    : Updated Thermal Rating: on line 60545-60548 : Rate B, Rate C - 0.0, 0.0 -> 122.5, 122.5
% INFO    : Updated Thermal Rating: on line 60547-60754 : Rate B, Rate C - 0.0, 0.0 -> 148.04, 148.04
% INFO    : Updated Thermal Rating: on line 60547-60832 : Rate B, Rate C - 0.0, 0.0 -> 166.14, 166.14
% INFO    : Updated Thermal Rating: on line 60548-60762 : Rate B, Rate C - 0.0, 0.0 -> 170.68, 170.68
% INFO    : Updated Thermal Rating: on line 60550-60878 : Rate B, Rate C - 0.0, 0.0 -> 187.78, 187.78
% INFO    : Updated Thermal Rating: on line 60551-60636 : Rate B, Rate C - 0.0, 0.0 -> 189.83, 189.83
% INFO    : Updated Thermal Rating: on line 60777-60551 : Rate B, Rate C - 0.0, 0.0 -> 165.02, 165.02
% INFO    : Updated Thermal Rating: on line 60552-60555 : Rate B, Rate C - 0.0, 0.0 -> 134.84, 134.84
% INFO    : Updated Thermal Rating: on transformer 60554-60553 : Rate B, Rate C - 0.0, 0.0 -> 170.05, 170.05
% INFO    : Updated Thermal Rating: on transformer 60555-60554 : Rate B, Rate C - 0.0, 0.0 -> 83.81, 83.81
% INFO    : Updated Thermal Rating: on transformer 60555-60554 : Rate B, Rate C - 0.0, 0.0 -> 83.81, 83.81
% INFO    : Updated Thermal Rating: on transformer 60555-60554 : Rate B, Rate C - 0.0, 0.0 -> 83.81, 83.81
% INFO    : Updated Thermal Rating: on line 60555-60560 : Rate B, Rate C - 0.0, 0.0 -> 137.83, 137.83
% INFO    : Updated Thermal Rating: on line 60586-60555 : Rate B, Rate C - 0.0, 0.0 -> 164.77, 164.77
% INFO    : Updated Thermal Rating: on line 60556-60710 : Rate B, Rate C - 0.0, 0.0 -> 561.91, 561.91
% INFO    : Updated Thermal Rating: on line 60556-60749 : Rate B, Rate C - 0.0, 0.0 -> 552.8, 552.8
% INFO    : Updated Thermal Rating: on line 60573-60557 : Rate B, Rate C - 0.0, 0.0 -> 191.58, 191.58
% INFO    : Updated Thermal Rating: on line 60560-60564 : Rate B, Rate C - 0.0, 0.0 -> 167.55, 167.55
% INFO    : Updated Thermal Rating: on line 60570-60560 : Rate B, Rate C - 0.0, 0.0 -> 179.54, 179.54
% INFO    : Updated Thermal Rating: on line 60561-60777 : Rate B, Rate C - 0.0, 0.0 -> 183.32, 183.32
% INFO    : Updated Thermal Rating: on line 60659-60566 : Rate B, Rate C - 0.0, 0.0 -> 185.66, 185.66
% INFO    : Updated Thermal Rating: on line 60567-60576 : Rate B, Rate C - 0.0, 0.0 -> 136.53, 136.53
% INFO    : Updated Thermal Rating: on line 60582-60567 : Rate B, Rate C - 0.0, 0.0 -> 161.09, 161.09
% INFO    : Updated Thermal Rating: on line 60584-60568 : Rate B, Rate C - 0.0, 0.0 -> 153.62, 153.62
% INFO    : Updated Thermal Rating: on line 60570-60643 : Rate B, Rate C - 0.0, 0.0 -> 183.51, 183.51
% INFO    : Updated Thermal Rating: on line 70138-60570 : Rate B, Rate C - 0.0, 0.0 -> 189.64, 189.64
% INFO    : Updated Thermal Rating: on line 60579-60573 : Rate B, Rate C - 0.0, 0.0 -> 186.25, 186.25
% INFO    : Updated Thermal Rating: on line 60573-60768 : Rate B, Rate C - 0.0, 0.0 -> 223.18, 223.18
% INFO    : Updated Thermal Rating: on line 60573-60768 : Rate B, Rate C - 0.0, 0.0 -> 223.18, 223.18
% INFO    : Updated Thermal Rating: on line 60573-60768 : Rate B, Rate C - 0.0, 0.0 -> 223.18, 223.18
% INFO    : Updated Thermal Rating: on line 60659-60574 : Rate B, Rate C - 0.0, 0.0 -> 179.62, 179.62
% INFO    : Updated Thermal Rating: on line 60574-60787 : Rate B, Rate C - 0.0, 0.0 -> 174.54, 174.54
% INFO    : Updated Thermal Rating: on line 60576-60659 : Rate B, Rate C - 0.0, 0.0 -> 178.91, 178.91
% INFO    : Updated Thermal Rating: on line 60787-60582 : Rate B, Rate C - 0.0, 0.0 -> 178.35, 178.35
% INFO    : Updated Thermal Rating: on line 60583-60588 : Rate B, Rate C - 0.0, 0.0 -> 145.71, 145.71
% INFO    : Updated Thermal Rating: on line 60583-60589 : Rate B, Rate C - 0.0, 0.0 -> 164.13, 164.13
% INFO    : Updated Thermal Rating: on line 60584-60586 : Rate B, Rate C - 0.0, 0.0 -> 160.54, 160.54
% INFO    : Updated Thermal Rating: on line 60587-60832 : Rate B, Rate C - 0.0, 0.0 -> 172.48, 172.48
% INFO    : Updated Thermal Rating: on line 60588-60593 : Rate B, Rate C - 0.0, 0.0 -> 153.25, 153.25
% INFO    : Updated Thermal Rating: on line 60589-60591 : Rate B, Rate C - 0.0, 0.0 -> 152.38, 152.38
% INFO    : Updated Thermal Rating: on line 60589-60650 : Rate B, Rate C - 0.0, 0.0 -> 197.21, 197.21
% INFO    : Updated Thermal Rating: on line 60590-60595 : Rate B, Rate C - 0.0, 0.0 -> 182.7, 182.7
% INFO    : Updated Thermal Rating: on line 60591-60596 : Rate B, Rate C - 0.0, 0.0 -> 147.79, 147.79
% INFO    : Updated Thermal Rating: on line 60593-60595 : Rate B, Rate C - 0.0, 0.0 -> 161.72, 161.72
% INFO    : Updated Thermal Rating: on line 60594-60787 : Rate B, Rate C - 0.0, 0.0 -> 176.99, 176.99
% INFO    : Updated Thermal Rating: on line 60595-60597 : Rate B, Rate C - 0.0, 0.0 -> 292.31, 292.31
% INFO    : Updated Thermal Rating: on line 60596-60599 : Rate B, Rate C - 0.0, 0.0 -> 138.1, 138.1
% INFO    : Updated Thermal Rating: on line 60597-60603 : Rate B, Rate C - 0.0, 0.0 -> 127.55, 127.55
% INFO    : Updated Thermal Rating: on line 60597-60813 : Rate B, Rate C - 0.0, 0.0 -> 202.7, 202.7
% INFO    : Updated Thermal Rating: on line 60597-60813 : Rate B, Rate C - 0.0, 0.0 -> 202.7, 202.7
% INFO    : Updated Thermal Rating: on line 60598-60599 : Rate B, Rate C - 0.0, 0.0 -> 110.32, 110.32
% INFO    : Updated Thermal Rating: on line 60604-60598 : Rate B, Rate C - 0.0, 0.0 -> 144.07, 144.07
% INFO    : Updated Thermal Rating: on line 60650-60600 : Rate B, Rate C - 0.0, 0.0 -> 164.99, 164.99
% INFO    : Updated Thermal Rating: on line 60600-60779 : Rate B, Rate C - 0.0, 0.0 -> 170.09, 170.09
% INFO    : Updated Thermal Rating: on line 60606-60603 : Rate B, Rate C - 0.0, 0.0 -> 143.79, 143.79
% INFO    : Updated Thermal Rating: on line 60604-60608 : Rate B, Rate C - 0.0, 0.0 -> 166.31, 166.31
% INFO    : Updated Thermal Rating: on line 60605-60628 : Rate B, Rate C - 0.0, 0.0 -> 146.26, 146.26
% INFO    : Updated Thermal Rating: on line 60605-60866 : Rate B, Rate C - 0.0, 0.0 -> 162.19, 162.19
% INFO    : Updated Thermal Rating: on line 60606-60732 : Rate B, Rate C - 0.0, 0.0 -> 150.84, 150.84
% INFO    : Updated Thermal Rating: on line 60608-60615 : Rate B, Rate C - 0.0, 0.0 -> 173.68, 173.68
% INFO    : Updated Thermal Rating: on line 60610-60667 : Rate B, Rate C - 0.0, 0.0 -> 146.26, 146.26
% INFO    : Updated Thermal Rating: on line 60823-60610 : Rate B, Rate C - 0.0, 0.0 -> 154.61, 154.61
% INFO    : Updated Thermal Rating: on line 60611-60622 : Rate B, Rate C - 0.0, 0.0 -> 127.02, 127.02
% INFO    : Updated Thermal Rating: on line 60611-60698 : Rate B, Rate C - 0.0, 0.0 -> 140.71, 140.71
% INFO    : Updated Thermal Rating: on line 60616-60613 : Rate B, Rate C - 0.0, 0.0 -> 146.58, 146.58
% INFO    : Updated Thermal Rating: on line 60623-60613 : Rate B, Rate C - 0.0, 0.0 -> 115.7, 115.7
% INFO    : Updated Thermal Rating: on line 60615-60625 : Rate B, Rate C - 0.0, 0.0 -> 140.42, 140.42
% INFO    : Updated Thermal Rating: on line 60615-60696 : Rate B, Rate C - 0.0, 0.0 -> 182.29, 182.29
% INFO    : Updated Thermal Rating: on line 60616-60817 : Rate B, Rate C - 0.0, 0.0 -> 153.82, 153.82
% INFO    : Updated Thermal Rating: on line 60618-60621 : Rate B, Rate C - 0.0, 0.0 -> 139.98, 139.98
% INFO    : Updated Thermal Rating: on line 60618-60823 : Rate B, Rate C - 0.0, 0.0 -> 144.26, 144.26
% INFO    : Updated Thermal Rating: on line 60623-60619 : Rate B, Rate C - 0.0, 0.0 -> 138.9, 138.9
% INFO    : Updated Thermal Rating: on line 60619-60624 : Rate B, Rate C - 0.0, 0.0 -> 146.79, 146.79
% INFO    : Updated Thermal Rating: on line 60681-60621 : Rate B, Rate C - 0.0, 0.0 -> 120.65, 120.65
% INFO    : Updated Thermal Rating: on line 60622-60759 : Rate B, Rate C - 0.0, 0.0 -> 115.54, 115.54
% INFO    : Updated Thermal Rating: on line 60624-60875 : Rate B, Rate C - 0.0, 0.0 -> 153.91, 153.91
% INFO    : Updated Thermal Rating: on line 60696-60625 : Rate B, Rate C - 0.0, 0.0 -> 145.94, 145.94
% INFO    : Updated Thermal Rating: on transformer 60627-60626 : Rate B, Rate C - 0.0, 0.0 -> 480.11, 480.11
% INFO    : Updated Thermal Rating: on transformer 60626-60629 : Rate B, Rate C - 0.0, 0.0 -> 915.95, 915.95
% INFO    : Updated Thermal Rating: on line 60626-60709 : Rate B, Rate C - 0.0, 0.0 -> 1984.69, 1984.69
% INFO    : Updated Thermal Rating: on transformer 60628-60627 : Rate B, Rate C - 0.0, 0.0 -> 147.77, 147.77
% INFO    : Updated Thermal Rating: on line 60628-60655 : Rate B, Rate C - 0.0, 0.0 -> 116.23, 116.23
% INFO    : Updated Thermal Rating: on line 60630-60632 : Rate B, Rate C - 0.0, 0.0 -> 432.68, 432.68
% INFO    : Updated Thermal Rating: on transformer 60632-60631 : Rate B, Rate C - 0.0, 0.0 -> 505.42, 505.42
% INFO    : Updated Thermal Rating: on line 60631-60653 : Rate B, Rate C - 0.0, 0.0 -> 2307.2, 2307.2
% INFO    : Updated Thermal Rating: on transformer 60633-60632 : Rate B, Rate C - 0.0, 0.0 -> 109.55, 109.55
% INFO    : Updated Thermal Rating: on line 60632-60821 : Rate B, Rate C - 0.0, 0.0 -> 424.06, 424.06
% INFO    : Updated Thermal Rating: on line 60866-60633 : Rate B, Rate C - 0.0, 0.0 -> 132.66, 132.66
% INFO    : Updated Thermal Rating: on transformer 60635-60634 : Rate B, Rate C - 0.0, 0.0 -> 860.75, 860.75
% INFO    : Updated Thermal Rating: on line 60634-60657 : Rate B, Rate C - 0.0, 0.0 -> 2762.76, 2762.76
% INFO    : Updated Thermal Rating: on line 60634-60785 : Rate B, Rate C - 0.0, 0.0 -> 2450.34, 2450.34
% INFO    : Updated Thermal Rating: on line 60876-60634 : Rate B, Rate C - 0.0, 0.0 -> 2701.73, 2701.73
% INFO    : Updated Thermal Rating: on transformer 60635-60638 : Rate B, Rate C - 0.0, 0.0 -> 256.0, 256.0
% INFO    : Updated Thermal Rating: on transformer 60636-60638 : Rate B, Rate C - 0.0, 0.0 -> 181.0, 181.0
% INFO    : Updated Thermal Rating: on transformer 60637-60638 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 60877-60639 : Rate B, Rate C - 0.0, 0.0 -> 527.91, 527.91
% INFO    : Updated Thermal Rating: on transformer 60641-60640 : Rate B, Rate C - 0.0, 0.0 -> 725.24, 725.24
% INFO    : Updated Thermal Rating: on transformer 60640-60646 : Rate B, Rate C - 0.0, 0.0 -> 1129.49, 1129.49
% INFO    : Updated Thermal Rating: on line 60640-60653 : Rate B, Rate C - 0.0, 0.0 -> 2435.01, 2435.01
% INFO    : Updated Thermal Rating: on line 60709-60640 : Rate B, Rate C - 0.0, 0.0 -> 2371.77, 2371.77
% INFO    : Updated Thermal Rating: on line 60830-60640 : Rate B, Rate C - 0.0, 0.0 -> 2756.9, 2756.9
% INFO    : Updated Thermal Rating: on transformer 60641-60645 : Rate B, Rate C - 0.0, 0.0 -> 161.78, 161.78
% INFO    : Updated Thermal Rating: on line 60641-60783 : Rate B, Rate C - 0.0, 0.0 -> 560.55, 560.55
% INFO    : Updated Thermal Rating: on transformer 60643-60642 : Rate B, Rate C - 0.0, 0.0 -> 82.14, 82.14
% INFO    : Updated Thermal Rating: on transformer 60643-60642 : Rate B, Rate C - 0.0, 0.0 -> 82.14, 82.14
% INFO    : Updated Thermal Rating: on transformer 60642-60645 : Rate B, Rate C - 0.0, 0.0 -> 111.78, 111.78
% INFO    : Updated Thermal Rating: on line 60642-70092 : Rate B, Rate C - 0.0, 0.0 -> 229.1, 229.1
% INFO    : Updated Thermal Rating: on line 60711-60643 : Rate B, Rate C - 0.0, 0.0 -> 160.21, 160.21
% INFO    : Updated Thermal Rating: on transformer 60644-60645 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 60649-60648 : Rate B, Rate C - 0.0, 0.0 -> 729.96, 729.96
% INFO    : Updated Thermal Rating: on transformer 60648-60651 : Rate B, Rate C - 0.0, 0.0 -> 1094.8, 1094.8
% INFO    : Updated Thermal Rating: on transformer 60650-60649 : Rate B, Rate C - 0.0, 0.0 -> 163.27, 163.27
% INFO    : Updated Thermal Rating: on line 60666-60649 : Rate B, Rate C - 0.0, 0.0 -> 524.87, 524.87
% INFO    : Updated Thermal Rating: on line 60667-60650 : Rate B, Rate C - 0.0, 0.0 -> 174.4, 174.4
% INFO    : Updated Thermal Rating: on line 60652-60669 : Rate B, Rate C - 0.0, 0.0 -> 2319.97, 2319.97
% INFO    : Updated Thermal Rating: on line 60652-60679 : Rate B, Rate C - 0.0, 0.0 -> 2146.69, 2146.69
% INFO    : Updated Thermal Rating: on line 60652-60766 : Rate B, Rate C - 0.0, 0.0 -> 2145.39, 2145.39
% INFO    : Updated Thermal Rating: on transformer 60654-60653 : Rate B, Rate C - 0.0, 0.0 -> 582.74, 582.74
% INFO    : Updated Thermal Rating: on transformer 60653-60656 : Rate B, Rate C - 0.0, 0.0 -> 907.94, 907.94
% INFO    : Updated Thermal Rating: on transformer 60655-60654 : Rate B, Rate C - 0.0, 0.0 -> 145.28, 145.28
% INFO    : Updated Thermal Rating: on line 60654-60710 : Rate B, Rate C - 0.0, 0.0 -> 486.25, 486.25
% INFO    : Updated Thermal Rating: on line 60711-60655 : Rate B, Rate C - 0.0, 0.0 -> 144.04, 144.04
% INFO    : Updated Thermal Rating: on transformer 60657-60661 : Rate B, Rate C - 0.0, 0.0 -> 1072.15, 1072.15
% INFO    : Updated Thermal Rating: on transformer 60657-60662 : Rate B, Rate C - 0.0, 0.0 -> 1241.99, 1241.99
% INFO    : Updated Thermal Rating: on transformer 60657-60663 : Rate B, Rate C - 0.0, 0.0 -> 1237.06, 1237.06
% INFO    : Updated Thermal Rating: on transformer 60657-60664 : Rate B, Rate C - 0.0, 0.0 -> 1201.9, 1201.9
% INFO    : Updated Thermal Rating: on line 60657-60785 : Rate B, Rate C - 0.0, 0.0 -> 3177.74, 3177.74
% INFO    : Updated Thermal Rating: on transformer 60659-60658 : Rate B, Rate C - 0.0, 0.0 -> 264.06, 264.06
% INFO    : Updated Thermal Rating: on transformer 60659-60658 : Rate B, Rate C - 0.0, 0.0 -> 264.06, 264.06
% INFO    : Updated Thermal Rating: on transformer 60659-60658 : Rate B, Rate C - 0.0, 0.0 -> 264.06, 264.06
% INFO    : Updated Thermal Rating: on transformer 60658-60661 : Rate B, Rate C - 0.0, 0.0 -> 922.15, 922.15
% INFO    : Updated Thermal Rating: on line 60658-60703 : Rate B, Rate C - 0.0, 0.0 -> 514.47, 514.47
% INFO    : Updated Thermal Rating: on line 60658-60853 : Rate B, Rate C - 0.0, 0.0 -> 542.88, 542.88
% INFO    : Updated Thermal Rating: on transformer 60660-60661 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 60666-60665 : Rate B, Rate C - 0.0, 0.0 -> 523.44, 523.44
% INFO    : Updated Thermal Rating: on transformer 60665-60668 : Rate B, Rate C - 0.0, 0.0 -> 915.75, 915.75
% INFO    : Updated Thermal Rating: on transformer 60667-60666 : Rate B, Rate C - 0.0, 0.0 -> 164.27, 164.27
% INFO    : Updated Thermal Rating: on line 60719-60666 : Rate B, Rate C - 0.0, 0.0 -> 432.34, 432.34
% INFO    : Updated Thermal Rating: on line 60781-60666 : Rate B, Rate C - 0.0, 0.0 -> 501.87, 501.87
% INFO    : Updated Thermal Rating: on line 60669-60843 : Rate B, Rate C - 0.0, 0.0 -> 2609.0, 2609.0
% INFO    : Updated Thermal Rating: on transformer 60671-60670 : Rate B, Rate C - 0.0, 0.0 -> 845.55, 845.55
% INFO    : Updated Thermal Rating: on line 60670-60724 : Rate B, Rate C - 0.0, 0.0 -> 2537.06, 2537.06
% INFO    : Updated Thermal Rating: on line 60670-60830 : Rate B, Rate C - 0.0, 0.0 -> 2391.54, 2391.54
% INFO    : Updated Thermal Rating: on line 60858-60670 : Rate B, Rate C - 0.0, 0.0 -> 1842.04, 1842.04
% INFO    : Updated Thermal Rating: on transformer 60672-60671 : Rate B, Rate C - 0.0, 0.0 -> 180.57, 180.57
% INFO    : Updated Thermal Rating: on line 60672-60845 : Rate B, Rate C - 0.0, 0.0 -> 188.77, 188.77
% INFO    : Updated Thermal Rating: on line 60673-60863 : Rate B, Rate C - 0.0, 0.0 -> 503.8, 503.8
% INFO    : Updated Thermal Rating: on transformer 60675-60674 : Rate B, Rate C - 0.0, 0.0 -> 1260.22, 1260.22
% INFO    : Updated Thermal Rating: on transformer 60675-60674 : Rate B, Rate C - 0.0, 0.0 -> 1260.22, 1260.22
% INFO    : Updated Thermal Rating: on transformer 60675-60674 : Rate B, Rate C - 0.0, 0.0 -> 1260.22, 1260.22
% INFO    : Updated Thermal Rating: on transformer 60674-60677 : Rate B, Rate C - 0.0, 0.0 -> 868.91, 868.91
% INFO    : Updated Thermal Rating: on transformer 60674-60678 : Rate B, Rate C - 0.0, 0.0 -> 546.76, 546.76
% INFO    : Updated Thermal Rating: on line 60682-60674 : Rate B, Rate C - 0.0, 0.0 -> 2847.43, 2847.43
% INFO    : Updated Thermal Rating: on line 60674-60738 : Rate B, Rate C - 0.0, 0.0 -> 2593.97, 2593.97
% INFO    : Updated Thermal Rating: on line 60674-60858 : Rate B, Rate C - 0.0, 0.0 -> 2803.66, 2803.66
% INFO    : Updated Thermal Rating: on transformer 60676-60675 : Rate B, Rate C - 0.0, 0.0 -> 284.09, 284.09
% INFO    : Updated Thermal Rating: on transformer 60676-60675 : Rate B, Rate C - 0.0, 0.0 -> 284.09, 284.09
% INFO    : Updated Thermal Rating: on transformer 60676-60675 : Rate B, Rate C - 0.0, 0.0 -> 284.09, 284.09
% INFO    : Updated Thermal Rating: on transformer 60676-60675 : Rate B, Rate C - 0.0, 0.0 -> 284.09, 284.09
% INFO    : Updated Thermal Rating: on line 60675-60850 : Rate B, Rate C - 0.0, 0.0 -> 680.98, 680.98
% INFO    : Updated Thermal Rating: on line 60826-60676 : Rate B, Rate C - 0.0, 0.0 -> 180.33, 180.33
% INFO    : Updated Thermal Rating: on transformer 60680-60679 : Rate B, Rate C - 0.0, 0.0 -> 629.79, 629.79
% INFO    : Updated Thermal Rating: on transformer 60681-60680 : Rate B, Rate C - 0.0, 0.0 -> 122.68, 122.68
% INFO    : Updated Thermal Rating: on line 60680-60714 : Rate B, Rate C - 0.0, 0.0 -> 509.51, 509.51
% INFO    : Updated Thermal Rating: on transformer 60683-60682 : Rate B, Rate C - 0.0, 0.0 -> 709.04, 709.04
% INFO    : Updated Thermal Rating: on transformer 60682-60686 : Rate B, Rate C - 0.0, 0.0 -> 966.3, 966.3
% INFO    : Updated Thermal Rating: on transformer 60682-60687 : Rate B, Rate C - 0.0, 0.0 -> 962.85, 962.85
% INFO    : Updated Thermal Rating: on transformer 60682-60688 : Rate B, Rate C - 0.0, 0.0 -> 950.7, 950.7
% INFO    : Updated Thermal Rating: on transformer 60682-60689 : Rate B, Rate C - 0.0, 0.0 -> 949.62, 949.62
% INFO    : Updated Thermal Rating: on transformer 60682-60690 : Rate B, Rate C - 0.0, 0.0 -> 777.19, 777.19
% INFO    : Updated Thermal Rating: on transformer 60682-60691 : Rate B, Rate C - 0.0, 0.0 -> 775.68, 775.68
% INFO    : Updated Thermal Rating: on line 60682-60858 : Rate B, Rate C - 0.0, 0.0 -> 2495.05, 2495.05
% INFO    : Updated Thermal Rating: on line 60884-60682 : Rate B, Rate C - 0.0, 0.0 -> 2755.05, 2755.05
% INFO    : Updated Thermal Rating: on transformer 60684-60683 : Rate B, Rate C - 0.0, 0.0 -> 522.65, 522.65
% INFO    : Updated Thermal Rating: on transformer 60683-60692 : Rate B, Rate C - 0.0, 0.0 -> 318.1, 318.1
% INFO    : Updated Thermal Rating: on transformer 60685-60684 : Rate B, Rate C - 0.0, 0.0 -> 247.78, 247.78
% INFO    : Updated Thermal Rating: on transformer 60685-60684 : Rate B, Rate C - 0.0, 0.0 -> 247.78, 247.78
% INFO    : Updated Thermal Rating: on transformer 60685-60684 : Rate B, Rate C - 0.0, 0.0 -> 247.78, 247.78
% INFO    : Updated Thermal Rating: on line 60684-60863 : Rate B, Rate C - 0.0, 0.0 -> 491.8, 491.8
% INFO    : Updated Thermal Rating: on line 60693-60885 : Rate B, Rate C - 0.0, 0.0 -> 1290.28, 1290.28
% INFO    : Updated Thermal Rating: on transformer 60695-60694 : Rate B, Rate C - 0.0, 0.0 -> 176.27, 176.27
% INFO    : Updated Thermal Rating: on line 60694-60802 : Rate B, Rate C - 0.0, 0.0 -> 519.32, 519.32
% INFO    : Updated Thermal Rating: on line 60759-60696 : Rate B, Rate C - 0.0, 0.0 -> 170.65, 170.65
% INFO    : Updated Thermal Rating: on transformer 60697-60700 : Rate B, Rate C - 0.0, 0.0 -> 242.91, 242.91
% INFO    : Updated Thermal Rating: on transformer 60697-60701 : Rate B, Rate C - 0.0, 0.0 -> 205.56, 205.56
% INFO    : Updated Thermal Rating: on transformer 60697-60702 : Rate B, Rate C - 0.0, 0.0 -> 148.64, 148.64
% INFO    : Updated Thermal Rating: on transformer 60698-60700 : Rate B, Rate C - 0.0, 0.0 -> 142.15, 142.15
% INFO    : Updated Thermal Rating: on transformer 60699-60700 : Rate B, Rate C - 0.0, 0.0 -> 100.76, 100.76
% INFO    : Updated Thermal Rating: on line 60703-60758 : Rate B, Rate C - 0.0, 0.0 -> 388.12, 388.12
% INFO    : Updated Thermal Rating: on transformer 60705-60704 : Rate B, Rate C - 0.0, 0.0 -> 758.44, 758.44
% INFO    : Updated Thermal Rating: on transformer 60704-60707 : Rate B, Rate C - 0.0, 0.0 -> 1074.75, 1074.75
% INFO    : Updated Thermal Rating: on transformer 60704-60708 : Rate B, Rate C - 0.0, 0.0 -> 1074.28, 1074.28
% INFO    : Updated Thermal Rating: on line 60738-60704 : Rate B, Rate C - 0.0, 0.0 -> 2640.73, 2640.73
% INFO    : Updated Thermal Rating: on line 60827-60704 : Rate B, Rate C - 0.0, 0.0 -> 2710.11, 2710.11
% INFO    : Updated Thermal Rating: on line 60867-60704 : Rate B, Rate C - 0.0, 0.0 -> 2799.16, 2799.16
% INFO    : Updated Thermal Rating: on transformer 60706-60705 : Rate B, Rate C - 0.0, 0.0 -> 181.97, 181.97
% INFO    : Updated Thermal Rating: on line 60705-60868 : Rate B, Rate C - 0.0, 0.0 -> 484.58, 484.58
% INFO    : Updated Thermal Rating: on transformer 60710-60709 : Rate B, Rate C - 0.0, 0.0 -> 653.92, 653.92
% INFO    : Updated Thermal Rating: on transformer 60709-60712 : Rate B, Rate C - 0.0, 0.0 -> 1094.64, 1094.64
% INFO    : Updated Thermal Rating: on transformer 60711-60710 : Rate B, Rate C - 0.0, 0.0 -> 147.14, 147.14
% INFO    : Updated Thermal Rating: on transformer 60714-60713 : Rate B, Rate C - 0.0, 0.0 -> 981.09, 981.09
% INFO    : Updated Thermal Rating: on transformer 60713-60716 : Rate B, Rate C - 0.0, 0.0 -> 906.56, 906.56
% INFO    : Updated Thermal Rating: on transformer 60713-60717 : Rate B, Rate C - 0.0, 0.0 -> 891.66, 891.66
% INFO    : Updated Thermal Rating: on transformer 60715-60714 : Rate B, Rate C - 0.0, 0.0 -> 284.97, 284.97
% INFO    : Updated Thermal Rating: on transformer 60715-60714 : Rate B, Rate C - 0.0, 0.0 -> 284.97, 284.97
% INFO    : Updated Thermal Rating: on transformer 60715-60714 : Rate B, Rate C - 0.0, 0.0 -> 284.97, 284.97
% INFO    : Updated Thermal Rating: on transformer 60715-60714 : Rate B, Rate C - 0.0, 0.0 -> 284.97, 284.97
% INFO    : Updated Thermal Rating: on line 60714-60831 : Rate B, Rate C - 0.0, 0.0 -> 580.04, 580.04
% INFO    : Updated Thermal Rating: on line 60724-60718 : Rate B, Rate C - 0.0, 0.0 -> 2474.74, 2474.74
% INFO    : Updated Thermal Rating: on line 60718-60748 : Rate B, Rate C - 0.0, 0.0 -> 2830.13, 2830.13
% INFO    : Updated Thermal Rating: on transformer 60720-60719 : Rate B, Rate C - 0.0, 0.0 -> 148.04, 148.04
% INFO    : Updated Thermal Rating: on transformer 60719-60721 : Rate B, Rate C - 0.0, 0.0 -> 284.47, 284.47
% INFO    : Updated Thermal Rating: on line 60771-60719 : Rate B, Rate C - 0.0, 0.0 -> 521.01, 521.01
% INFO    : Updated Thermal Rating: on line 60779-60720 : Rate B, Rate C - 0.0, 0.0 -> 151.16, 151.16
% INFO    : Updated Thermal Rating: on transformer 60725-60724 : Rate B, Rate C - 0.0, 0.0 -> 1181.62, 1181.62
% INFO    : Updated Thermal Rating: on transformer 60725-60724 : Rate B, Rate C - 0.0, 0.0 -> 1181.62, 1181.62
% INFO    : Updated Thermal Rating: on transformer 60725-60724 : Rate B, Rate C - 0.0, 0.0 -> 1181.62, 1181.62
% INFO    : Updated Thermal Rating: on transformer 60724-60727 : Rate B, Rate C - 0.0, 0.0 -> 1120.14, 1120.14
% INFO    : Updated Thermal Rating: on transformer 60724-60728 : Rate B, Rate C - 0.0, 0.0 -> 1108.24, 1108.24
% INFO    : Updated Thermal Rating: on line 60752-60724 : Rate B, Rate C - 0.0, 0.0 -> 2649.53, 2649.53
% INFO    : Updated Thermal Rating: on line 60843-60724 : Rate B, Rate C - 0.0, 0.0 -> 1990.42, 1990.42
% INFO    : Updated Thermal Rating: on transformer 60726-60725 : Rate B, Rate C - 0.0, 0.0 -> 260.71, 260.71
% INFO    : Updated Thermal Rating: on transformer 60726-60725 : Rate B, Rate C - 0.0, 0.0 -> 260.71, 260.71
% INFO    : Updated Thermal Rating: on transformer 60726-60725 : Rate B, Rate C - 0.0, 0.0 -> 260.71, 260.71
% INFO    : Updated Thermal Rating: on transformer 60725-60729 : Rate B, Rate C - 0.0, 0.0 -> 109.62, 109.62
% INFO    : Updated Thermal Rating: on transformer 60725-60730 : Rate B, Rate C - 0.0, 0.0 -> 134.87, 134.87
% INFO    : Updated Thermal Rating: on line 60842-60725 : Rate B, Rate C - 0.0, 0.0 -> 577.02, 577.02
% INFO    : Updated Thermal Rating: on transformer 60732-60731 : Rate B, Rate C - 0.0, 0.0 -> 128.5, 128.5
% INFO    : Updated Thermal Rating: on line 60750-60732 : Rate B, Rate C - 0.0, 0.0 -> 168.74, 168.74
% INFO    : Updated Thermal Rating: on line 60732-60813 : Rate B, Rate C - 0.0, 0.0 -> 188.85, 188.85
% INFO    : Updated Thermal Rating: on line 60749-60733 : Rate B, Rate C - 0.0, 0.0 -> 498.17, 498.17
% INFO    : Updated Thermal Rating: on transformer 60735-60734 : Rate B, Rate C - 0.0, 0.0 -> 449.19, 449.19
% INFO    : Updated Thermal Rating: on line 60734-60804 : Rate B, Rate C - 0.0, 0.0 -> 2373.07, 2373.07
% INFO    : Updated Thermal Rating: on transformer 60736-60735 : Rate B, Rate C - 0.0, 0.0 -> 169.44, 169.44
% INFO    : Updated Thermal Rating: on line 60735-60805 : Rate B, Rate C - 0.0, 0.0 -> 383.14, 383.14
% INFO    : Updated Thermal Rating: on transformer 60737-60736 : Rate B, Rate C - 0.0, 0.0 -> 115.51, 115.51
% INFO    : Updated Thermal Rating: on transformer 60739-60738 : Rate B, Rate C - 0.0, 0.0 -> 841.89, 841.89
% INFO    : Updated Thermal Rating: on transformer 60738-60745 : Rate B, Rate C - 0.0, 0.0 -> 1180.1, 1180.1
% INFO    : Updated Thermal Rating: on transformer 60738-60746 : Rate B, Rate C - 0.0, 0.0 -> 813.36, 813.36
% INFO    : Updated Thermal Rating: on transformer 60738-60747 : Rate B, Rate C - 0.0, 0.0 -> 796.24, 796.24
% INFO    : Updated Thermal Rating: on transformer 60739-60742 : Rate B, Rate C - 0.0, 0.0 -> 252.61, 252.61
% INFO    : Updated Thermal Rating: on transformer 60740-60742 : Rate B, Rate C - 0.0, 0.0 -> 202.61, 202.61
% INFO    : Updated Thermal Rating: on transformer 60741-60742 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 60743-60745 : Rate B, Rate C - 0.0, 0.0 -> 590.05, 590.05
% INFO    : Updated Thermal Rating: on transformer 60744-60745 : Rate B, Rate C - 0.0, 0.0 -> 590.05, 590.05
% INFO    : Updated Thermal Rating: on transformer 60749-60748 : Rate B, Rate C - 0.0, 0.0 -> 608.58, 608.58
% INFO    : Updated Thermal Rating: on transformer 60748-60751 : Rate B, Rate C - 0.0, 0.0 -> 1247.83, 1247.83
% INFO    : Updated Thermal Rating: on transformer 60750-60749 : Rate B, Rate C - 0.0, 0.0 -> 161.04, 161.04
% INFO    : Updated Thermal Rating: on line 60749-60821 : Rate B, Rate C - 0.0, 0.0 -> 451.41, 451.41
% INFO    : Updated Thermal Rating: on line 60813-60750 : Rate B, Rate C - 0.0, 0.0 -> 186.15, 186.15
% INFO    : Updated Thermal Rating: on transformer 60753-60752 : Rate B, Rate C - 0.0, 0.0 -> 848.55, 848.55
% INFO    : Updated Thermal Rating: on line 60752-60830 : Rate B, Rate C - 0.0, 0.0 -> 2395.44, 2395.44
% INFO    : Updated Thermal Rating: on line 60752-60884 : Rate B, Rate C - 0.0, 0.0 -> 2614.17, 2614.17
% INFO    : Updated Thermal Rating: on transformer 60753-60756 : Rate B, Rate C - 0.0, 0.0 -> 258.93, 258.93
% INFO    : Updated Thermal Rating: on line 60753-60831 : Rate B, Rate C - 0.0, 0.0 -> 554.13, 554.13
% INFO    : Updated Thermal Rating: on transformer 60754-60756 : Rate B, Rate C - 0.0, 0.0 -> 208.93, 208.93
% INFO    : Updated Thermal Rating: on transformer 60755-60756 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on transformer 60758-60757 : Rate B, Rate C - 0.0, 0.0 -> 526.64, 526.64
% INFO    : Updated Thermal Rating: on transformer 60758-60757 : Rate B, Rate C - 0.0, 0.0 -> 526.64, 526.64
% INFO    : Updated Thermal Rating: on transformer 60757-60760 : Rate B, Rate C - 0.0, 0.0 -> 813.56, 813.56
% INFO    : Updated Thermal Rating: on transformer 60759-60758 : Rate B, Rate C - 0.0, 0.0 -> 165.74, 165.74
% INFO    : Updated Thermal Rating: on line 60761-60766 : Rate B, Rate C - 0.0, 0.0 -> 2272.33, 2272.33
% INFO    : Updated Thermal Rating: on transformer 60762-60763 : Rate B, Rate C - 0.0, 0.0 -> 51.65, 51.65
% INFO    : Updated Thermal Rating: on transformer 60762-60764 : Rate B, Rate C - 0.0, 0.0 -> 25.83, 25.83
% INFO    : Updated Thermal Rating: on line 60854-60762 : Rate B, Rate C - 0.0, 0.0 -> 183.77, 183.77
% INFO    : Updated Thermal Rating: on line 60806-60765 : Rate B, Rate C - 0.0, 0.0 -> 160.69, 160.69
% INFO    : Updated Thermal Rating: on transformer 60766-60770 : Rate B, Rate C - 0.0, 0.0 -> 784.78, 784.78
% INFO    : Updated Thermal Rating: on transformer 60768-60767 : Rate B, Rate C - 0.0, 0.0 -> 243.17, 243.17
% INFO    : Updated Thermal Rating: on transformer 60768-60767 : Rate B, Rate C - 0.0, 0.0 -> 243.17, 243.17
% INFO    : Updated Thermal Rating: on transformer 60768-60767 : Rate B, Rate C - 0.0, 0.0 -> 243.17, 243.17
% INFO    : Updated Thermal Rating: on transformer 60767-60770 : Rate B, Rate C - 0.0, 0.0 -> 684.78, 684.78
% INFO    : Updated Thermal Rating: on transformer 60769-60770 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 60771-60781 : Rate B, Rate C - 0.0, 0.0 -> 521.43, 521.43
% INFO    : Updated Thermal Rating: on line 60851-60773 : Rate B, Rate C - 0.0, 0.0 -> 200.35, 200.35
% INFO    : Updated Thermal Rating: on line 60851-60773 : Rate B, Rate C - 0.0, 0.0 -> 200.35, 200.35
% INFO    : Updated Thermal Rating: on transformer 60774-60775 : Rate B, Rate C - 0.0, 0.0 -> 269.1, 269.1
% INFO    : Updated Thermal Rating: on transformer 60774-60776 : Rate B, Rate C - 0.0, 0.0 -> 98.28, 98.28
% INFO    : Updated Thermal Rating: on line 60878-60777 : Rate B, Rate C - 0.0, 0.0 -> 204.51, 204.51
% INFO    : Updated Thermal Rating: on line 60878-60777 : Rate B, Rate C - 0.0, 0.0 -> 204.51, 204.51
% INFO    : Updated Thermal Rating: on line 60878-60777 : Rate B, Rate C - 0.0, 0.0 -> 204.51, 204.51
% INFO    : Updated Thermal Rating: on transformer 60779-60778 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on transformer 60778-60780 : Rate B, Rate C - 0.0, 0.0 -> 279.33, 279.33
% INFO    : Updated Thermal Rating: on transformer 60784-60783 : Rate B, Rate C - 0.0, 0.0 -> 194.12, 194.12
% INFO    : Updated Thermal Rating: on transformer 60786-60785 : Rate B, Rate C - 0.0, 0.0 -> 903.98, 903.98
% INFO    : Updated Thermal Rating: on transformer 60785-60790 : Rate B, Rate C - 0.0, 0.0 -> 1529.24, 1529.24
% INFO    : Updated Thermal Rating: on transformer 60785-60791 : Rate B, Rate C - 0.0, 0.0 -> 682.15, 682.15
% INFO    : Updated Thermal Rating: on transformer 60785-60792 : Rate B, Rate C - 0.0, 0.0 -> 676.87, 676.87
% INFO    : Updated Thermal Rating: on transformer 60785-60794 : Rate B, Rate C - 0.0, 0.0 -> 589.74, 589.74
% INFO    : Updated Thermal Rating: on transformer 60785-60795 : Rate B, Rate C - 0.0, 0.0 -> 315.32, 315.32
% INFO    : Updated Thermal Rating: on line 60785-60801 : Rate B, Rate C - 0.0, 0.0 -> 2873.74, 2873.74
% INFO    : Updated Thermal Rating: on transformer 60787-60786 : Rate B, Rate C - 0.0, 0.0 -> 220.3, 220.3
% INFO    : Updated Thermal Rating: on transformer 60787-60786 : Rate B, Rate C - 0.0, 0.0 -> 220.3, 220.3
% INFO    : Updated Thermal Rating: on transformer 60787-60786 : Rate B, Rate C - 0.0, 0.0 -> 220.3, 220.3
% INFO    : Updated Thermal Rating: on transformer 60786-60793 : Rate B, Rate C - 0.0, 0.0 -> 149.62, 149.62
% INFO    : Updated Thermal Rating: on transformer 60788-60790 : Rate B, Rate C - 0.0, 0.0 -> 764.62, 764.62
% INFO    : Updated Thermal Rating: on transformer 60789-60790 : Rate B, Rate C - 0.0, 0.0 -> 764.62, 764.62
% INFO    : Updated Thermal Rating: on transformer 60797-60798 : Rate B, Rate C - 0.0, 0.0 -> 38.39, 38.39
% INFO    : Updated Thermal Rating: on transformer 60797-60799 : Rate B, Rate C - 0.0, 0.0 -> 18.72, 18.72
% INFO    : Updated Thermal Rating: on transformer 60802-60801 : Rate B, Rate C - 0.0, 0.0 -> 733.27, 733.27
% INFO    : Updated Thermal Rating: on line 60801-60827 : Rate B, Rate C - 0.0, 0.0 -> 2519.51, 2519.51
% INFO    : Updated Thermal Rating: on transformer 60803-60802 : Rate B, Rate C - 0.0, 0.0 -> 192.97, 192.97
% INFO    : Updated Thermal Rating: on transformer 60805-60804 : Rate B, Rate C - 0.0, 0.0 -> 740.43, 740.43
% INFO    : Updated Thermal Rating: on transformer 60804-60807 : Rate B, Rate C - 0.0, 0.0 -> 622.03, 622.03
% INFO    : Updated Thermal Rating: on transformer 60804-60808 : Rate B, Rate C - 0.0, 0.0 -> 619.8, 619.8
% INFO    : Updated Thermal Rating: on line 60804-60847 : Rate B, Rate C - 0.0, 0.0 -> 2506.12, 2506.12
% INFO    : Updated Thermal Rating: on transformer 60806-60805 : Rate B, Rate C - 0.0, 0.0 -> 173.88, 173.88
% INFO    : Updated Thermal Rating: on transformer 60805-60809 : Rate B, Rate C - 0.0, 0.0 -> 100.24, 100.24
% INFO    : Updated Thermal Rating: on line 60812-60806 : Rate B, Rate C - 0.0, 0.0 -> 157.66, 157.66
% INFO    : Updated Thermal Rating: on transformer 60813-60814 : Rate B, Rate C - 0.0, 0.0 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on transformer 60813-60815 : Rate B, Rate C - 0.0, 0.0 -> 195.0, 195.0
% INFO    : Updated Thermal Rating: on transformer 60816-60819 : Rate B, Rate C - 0.0, 0.0 -> 299.27, 299.27
% INFO    : Updated Thermal Rating: on transformer 60816-60820 : Rate B, Rate C - 0.0, 0.0 -> 213.84, 213.84
% INFO    : Updated Thermal Rating: on transformer 60817-60819 : Rate B, Rate C - 0.0, 0.0 -> 149.27, 149.27
% INFO    : Updated Thermal Rating: on transformer 60818-60819 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 60828-60827 : Rate B, Rate C - 0.0, 0.0 -> 785.97, 785.97
% INFO    : Updated Thermal Rating: on transformer 60829-60828 : Rate B, Rate C - 0.0, 0.0 -> 214.07, 214.07
% INFO    : Updated Thermal Rating: on transformer 60829-60828 : Rate B, Rate C - 0.0, 0.0 -> 214.07, 214.07
% INFO    : Updated Thermal Rating: on transformer 60831-60830 : Rate B, Rate C - 0.0, 0.0 -> 1063.34, 1063.34
% INFO    : Updated Thermal Rating: on transformer 60830-60833 : Rate B, Rate C - 0.0, 0.0 -> 1019.58, 1019.58
% INFO    : Updated Thermal Rating: on transformer 60830-60834 : Rate B, Rate C - 0.0, 0.0 -> 1014.14, 1014.14
% INFO    : Updated Thermal Rating: on transformer 60830-60835 : Rate B, Rate C - 0.0, 0.0 -> 1008.4, 1008.4
% INFO    : Updated Thermal Rating: on transformer 60832-60831 : Rate B, Rate C - 0.0, 0.0 -> 267.35, 267.35
% INFO    : Updated Thermal Rating: on transformer 60832-60831 : Rate B, Rate C - 0.0, 0.0 -> 267.35, 267.35
% INFO    : Updated Thermal Rating: on transformer 60832-60831 : Rate B, Rate C - 0.0, 0.0 -> 267.35, 267.35
% INFO    : Updated Thermal Rating: on transformer 60837-60836 : Rate B, Rate C - 0.0, 0.0 -> 939.3, 939.3
% INFO    : Updated Thermal Rating: on transformer 60836-60839 : Rate B, Rate C - 0.0, 0.0 -> 572.56, 572.56
% INFO    : Updated Thermal Rating: on transformer 60836-60840 : Rate B, Rate C - 0.0, 0.0 -> 567.77, 567.77
% INFO    : Updated Thermal Rating: on transformer 60836-60841 : Rate B, Rate C - 0.0, 0.0 -> 551.55, 551.55
% INFO    : Updated Thermal Rating: on transformer 60838-60837 : Rate B, Rate C - 0.0, 0.0 -> 284.59, 284.59
% INFO    : Updated Thermal Rating: on transformer 60838-60837 : Rate B, Rate C - 0.0, 0.0 -> 284.59, 284.59
% INFO    : Updated Thermal Rating: on transformer 60838-60837 : Rate B, Rate C - 0.0, 0.0 -> 284.59, 284.59
% INFO    : Updated Thermal Rating: on transformer 60838-60837 : Rate B, Rate C - 0.0, 0.0 -> 284.59, 284.59
% INFO    : Updated Thermal Rating: on transformer 60848-60847 : Rate B, Rate C - 0.0, 0.0 -> 947.36, 947.36
% INFO    : Updated Thermal Rating: on line 60847-60867 : Rate B, Rate C - 0.0, 0.0 -> 2959.51, 2959.51
% INFO    : Updated Thermal Rating: on transformer 60849-60848 : Rate B, Rate C - 0.0, 0.0 -> 222.9, 222.9
% INFO    : Updated Thermal Rating: on transformer 60849-60848 : Rate B, Rate C - 0.0, 0.0 -> 222.9, 222.9
% INFO    : Updated Thermal Rating: on transformer 60849-60848 : Rate B, Rate C - 0.0, 0.0 -> 222.9, 222.9
% INFO    : Updated Thermal Rating: on transformer 60851-60850 : Rate B, Rate C - 0.0, 0.0 -> 230.3, 230.3
% INFO    : Updated Thermal Rating: on transformer 60851-60850 : Rate B, Rate C - 0.0, 0.0 -> 230.3, 230.3
% INFO    : Updated Thermal Rating: on transformer 60851-60850 : Rate B, Rate C - 0.0, 0.0 -> 230.3, 230.3
% INFO    : Updated Thermal Rating: on transformer 60853-60852 : Rate B, Rate C - 0.0, 0.0 -> 1024.74, 1024.74
% INFO    : Updated Thermal Rating: on line 60876-60852 : Rate B, Rate C - 0.0, 0.0 -> 2538.2, 2538.2
% INFO    : Updated Thermal Rating: on transformer 60854-60853 : Rate B, Rate C - 0.0, 0.0 -> 317.49, 317.49
% INFO    : Updated Thermal Rating: on transformer 60854-60853 : Rate B, Rate C - 0.0, 0.0 -> 317.49, 317.49
% INFO    : Updated Thermal Rating: on transformer 60854-60853 : Rate B, Rate C - 0.0, 0.0 -> 317.49, 317.49
% INFO    : Updated Thermal Rating: on transformer 60854-60853 : Rate B, Rate C - 0.0, 0.0 -> 317.49, 317.49
% INFO    : Updated Thermal Rating: on line 60877-60853 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on transformer 60855-60856 : Rate B, Rate C - 0.0, 0.0 -> 39.72, 39.72
% INFO    : Updated Thermal Rating: on transformer 60855-60857 : Rate B, Rate C - 0.0, 0.0 -> 37.28, 37.28
% INFO    : Updated Thermal Rating: on transformer 60859-60858 : Rate B, Rate C - 0.0, 0.0 -> 861.41, 861.41
% INFO    : Updated Thermal Rating: on transformer 60858-60861 : Rate B, Rate C - 0.0, 0.0 -> 891.44, 891.44
% INFO    : Updated Thermal Rating: on transformer 60858-60862 : Rate B, Rate C - 0.0, 0.0 -> 888.14, 888.14
% INFO    : Updated Thermal Rating: on line 60858-60884 : Rate B, Rate C - 0.0, 0.0 -> 2830.25, 2830.25
% INFO    : Updated Thermal Rating: on transformer 60860-60859 : Rate B, Rate C - 0.0, 0.0 -> 222.39, 222.39
% INFO    : Updated Thermal Rating: on transformer 60860-60859 : Rate B, Rate C - 0.0, 0.0 -> 222.39, 222.39
% INFO    : Updated Thermal Rating: on transformer 60860-60859 : Rate B, Rate C - 0.0, 0.0 -> 222.39, 222.39
% INFO    : Updated Thermal Rating: on line 60875-60866 : Rate B, Rate C - 0.0, 0.0 -> 165.74, 165.74
% INFO    : Updated Thermal Rating: on transformer 60868-60867 : Rate B, Rate C - 0.0, 0.0 -> 895.69, 895.69
% INFO    : Updated Thermal Rating: on transformer 60867-60872 : Rate B, Rate C - 0.0, 0.0 -> 1157.23, 1157.23
% INFO    : Updated Thermal Rating: on transformer 60867-60873 : Rate B, Rate C - 0.0, 0.0 -> 1156.27, 1156.27
% INFO    : Updated Thermal Rating: on transformer 60867-60874 : Rate B, Rate C - 0.0, 0.0 -> 1137.83, 1137.83
% INFO    : Updated Thermal Rating: on transformer 60868-60871 : Rate B, Rate C - 0.0, 0.0 -> 274.22, 274.22
% INFO    : Updated Thermal Rating: on transformer 60869-60871 : Rate B, Rate C - 0.0, 0.0 -> 199.22, 199.22
% INFO    : Updated Thermal Rating: on transformer 60870-60871 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 60877-60876 : Rate B, Rate C - 0.0, 0.0 -> 903.55, 903.55
% INFO    : Updated Thermal Rating: on transformer 60876-60881 : Rate B, Rate C - 0.0, 0.0 -> 824.05, 824.05
% INFO    : Updated Thermal Rating: on transformer 60876-60882 : Rate B, Rate C - 0.0, 0.0 -> 823.21, 823.21
% INFO    : Updated Thermal Rating: on transformer 60876-60883 : Rate B, Rate C - 0.0, 0.0 -> 814.67, 814.67
% INFO    : Updated Thermal Rating: on transformer 60877-60880 : Rate B, Rate C - 0.0, 0.0 -> 437.28, 437.28
% INFO    : Updated Thermal Rating: on transformer 60878-60880 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 60879-60880 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 60884-60890 : Rate B, Rate C - 0.0, 0.0 -> 1053.11, 1053.11
% INFO    : Updated Thermal Rating: on transformer 60884-60891 : Rate B, Rate C - 0.0, 0.0 -> 1126.1, 1126.1
% INFO    : Updated Thermal Rating: on transformer 60884-60892 : Rate B, Rate C - 0.0, 0.0 -> 714.23, 714.23
% INFO    : Updated Thermal Rating: on transformer 60884-60893 : Rate B, Rate C - 0.0, 0.0 -> 711.72, 711.72
% INFO    : Updated Thermal Rating: on transformer 60884-60894 : Rate B, Rate C - 0.0, 0.0 -> 705.6, 705.6
% INFO    : Updated Thermal Rating: on transformer 60884-60895 : Rate B, Rate C - 0.0, 0.0 -> 704.83, 704.83
% INFO    : Updated Thermal Rating: on transformer 60884-60896 : Rate B, Rate C - 0.0, 0.0 -> 704.32, 704.32
% INFO    : Updated Thermal Rating: on transformer 60886-60885 : Rate B, Rate C - 0.0, 0.0 -> 587.82, 587.82
% INFO    : Updated Thermal Rating: on transformer 60886-60885 : Rate B, Rate C - 0.0, 0.0 -> 587.82, 587.82
% INFO    : Updated Thermal Rating: on transformer 60886-60885 : Rate B, Rate C - 0.0, 0.0 -> 587.82, 587.82
% INFO    : Updated Thermal Rating: on transformer 60885-60890 : Rate B, Rate C - 0.0, 0.0 -> 1003.11, 1003.11
% INFO    : Updated Thermal Rating: on line 60885-70116 : Rate B, Rate C - 0.0, 0.0 -> 1379.75, 1379.75
% INFO    : Updated Thermal Rating: on line 70135-60885 : Rate B, Rate C - 0.0, 0.0 -> 1235.86, 1235.86
% INFO    : Updated Thermal Rating: on line 60885-70170 : Rate B, Rate C - 0.0, 0.0 -> 1452.33, 1452.33
% INFO    : Updated Thermal Rating: on transformer 60887-60886 : Rate B, Rate C - 0.0, 0.0 -> 210.44, 210.44
% INFO    : Updated Thermal Rating: on transformer 60887-60886 : Rate B, Rate C - 0.0, 0.0 -> 210.44, 210.44
% INFO    : Updated Thermal Rating: on line 70136-60886 : Rate B, Rate C - 0.0, 0.0 -> 451.06, 451.06
% INFO    : Updated Thermal Rating: on transformer 60888-60887 : Rate B, Rate C - 0.0, 0.0 -> 88.03, 88.03
% INFO    : Updated Thermal Rating: on transformer 60888-60887 : Rate B, Rate C - 0.0, 0.0 -> 88.03, 88.03
% INFO    : Updated Thermal Rating: on transformer 60888-60887 : Rate B, Rate C - 0.0, 0.0 -> 88.03, 88.03
% INFO    : Updated Thermal Rating: on transformer 60888-60887 : Rate B, Rate C - 0.0, 0.0 -> 88.03, 88.03
% INFO    : Updated Thermal Rating: on line 60887-70109 : Rate B, Rate C - 0.0, 0.0 -> 265.66, 265.66
% INFO    : Updated Thermal Rating: on transformer 60889-60890 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 74191-70000 : Rate B, Rate C - 0.0, 0.0 -> 196.18, 196.18
% INFO    : Updated Thermal Rating: on line 70000-74193 : Rate B, Rate C - 0.0, 0.0 -> 166.87, 166.87
% INFO    : Updated Thermal Rating: on line 70004-70001 : Rate B, Rate C - 0.0, 0.0 -> 231.98, 231.98
% INFO    : Updated Thermal Rating: on line 70001-74191 : Rate B, Rate C - 0.0, 0.0 -> 219.69, 219.69
% INFO    : Updated Thermal Rating: on line 70003-70004 : Rate B, Rate C - 0.0, 0.0 -> 187.99, 187.99
% INFO    : Updated Thermal Rating: on line 70003-70009 : Rate B, Rate C - 0.0, 0.0 -> 209.06, 209.06
% INFO    : Updated Thermal Rating: on line 70004-70006 : Rate B, Rate C - 0.0, 0.0 -> 231.03, 231.03
% INFO    : Updated Thermal Rating: on line 70011-70006 : Rate B, Rate C - 0.0, 0.0 -> 250.88, 250.88
% INFO    : Updated Thermal Rating: on line 70007-70124 : Rate B, Rate C - 0.0, 0.0 -> 221.02, 221.02
% INFO    : Updated Thermal Rating: on line 70007-70190 : Rate B, Rate C - 0.0, 0.0 -> 228.19, 228.19
% INFO    : Updated Thermal Rating: on line 74190-70007 : Rate B, Rate C - 0.0, 0.0 -> 180.89, 180.89
% INFO    : Updated Thermal Rating: on line 70008-70130 : Rate B, Rate C - 0.0, 0.0 -> 202.8, 202.8
% INFO    : Updated Thermal Rating: on line 70008-70147 : Rate B, Rate C - 0.0, 0.0 -> 218.07, 218.07
% INFO    : Updated Thermal Rating: on line 70010-70009 : Rate B, Rate C - 0.0, 0.0 -> 266.65, 266.65
% INFO    : Updated Thermal Rating: on line 70009-70026 : Rate B, Rate C - 0.0, 0.0 -> 271.0, 271.0
% INFO    : Updated Thermal Rating: on line 70009-74190 : Rate B, Rate C - 0.0, 0.0 -> 255.21, 255.21
% INFO    : Updated Thermal Rating: on line 70010-70011 : Rate B, Rate C - 0.0, 0.0 -> 192.71, 192.71
% INFO    : Updated Thermal Rating: on line 70023-70010 : Rate B, Rate C - 0.0, 0.0 -> 268.25, 268.25
% INFO    : Updated Thermal Rating: on line 70011-70015 : Rate B, Rate C - 0.0, 0.0 -> 258.85, 258.85
% INFO    : Updated Thermal Rating: on line 70013-70147 : Rate B, Rate C - 0.0, 0.0 -> 218.81, 218.81
% INFO    : Updated Thermal Rating: on line 70190-70013 : Rate B, Rate C - 0.0, 0.0 -> 183.55, 183.55
% INFO    : Updated Thermal Rating: on line 70015-77038 : Rate B, Rate C - 0.0, 0.0 -> 271.92, 271.92
% INFO    : Updated Thermal Rating: on line 70017-70020 : Rate B, Rate C - 0.0, 0.0 -> 227.42, 227.42
% INFO    : Updated Thermal Rating: on line 70017-70152 : Rate B, Rate C - 0.0, 0.0 -> 250.81, 250.81
% INFO    : Updated Thermal Rating: on line 70020-70147 : Rate B, Rate C - 0.0, 0.0 -> 173.95, 173.95
% INFO    : Updated Thermal Rating: on line 70023-70026 : Rate B, Rate C - 0.0, 0.0 -> 175.61, 175.61
% INFO    : Updated Thermal Rating: on line 70023-70028 : Rate B, Rate C - 0.0, 0.0 -> 271.05, 271.05
% INFO    : Updated Thermal Rating: on line 70032-70024 : Rate B, Rate C - 0.0, 0.0 -> 246.65, 246.65
% INFO    : Updated Thermal Rating: on line 77038-70024 : Rate B, Rate C - 0.0, 0.0 -> 227.63, 227.63
% INFO    : Updated Thermal Rating: on line 70030-70026 : Rate B, Rate C - 0.0, 0.0 -> 222.39, 222.39
% INFO    : Updated Thermal Rating: on line 70034-70027 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 70030-70028 : Rate B, Rate C - 0.0, 0.0 -> 251.43, 251.43
% INFO    : Updated Thermal Rating: on line 70028-70033 : Rate B, Rate C - 0.0, 0.0 -> 190.46, 190.46
% INFO    : Updated Thermal Rating: on line 70034-70032 : Rate B, Rate C - 0.0, 0.0 -> 275.51, 275.51
% INFO    : Updated Thermal Rating: on line 70032-77020 : Rate B, Rate C - 0.0, 0.0 -> 181.36, 181.36
% INFO    : Updated Thermal Rating: on line 70032-77215 : Rate B, Rate C - 0.0, 0.0 -> 279.4, 279.4
% INFO    : Updated Thermal Rating: on line 70034-70033 : Rate B, Rate C - 0.0, 0.0 -> 197.94, 197.94
% INFO    : Updated Thermal Rating: on line 70034-70036 : Rate B, Rate C - 0.0, 0.0 -> 205.83, 205.83
% INFO    : Updated Thermal Rating: on line 70036-70040 : Rate B, Rate C - 0.0, 0.0 -> 218.57, 218.57
% INFO    : Updated Thermal Rating: on line 70037-70042 : Rate B, Rate C - 0.0, 0.0 -> 215.67, 215.67
% INFO    : Updated Thermal Rating: on line 70037-70182 : Rate B, Rate C - 0.0, 0.0 -> 239.35, 239.35
% INFO    : Updated Thermal Rating: on line 77003-70039 : Rate B, Rate C - 0.0, 0.0 -> 233.2, 233.2
% INFO    : Updated Thermal Rating: on line 70039-77005 : Rate B, Rate C - 0.0, 0.0 -> 238.93, 238.93
% INFO    : Updated Thermal Rating: on line 70047-70040 : Rate B, Rate C - 0.0, 0.0 -> 239.84, 239.84
% INFO    : Updated Thermal Rating: on line 70040-77003 : Rate B, Rate C - 0.0, 0.0 -> 254.21, 254.21
% INFO    : Updated Thermal Rating: on line 70042-70061 : Rate B, Rate C - 0.0, 0.0 -> 237.8, 237.8
% INFO    : Updated Thermal Rating: on line 70129-70042 : Rate B, Rate C - 0.0, 0.0 -> 221.59, 221.59
% INFO    : Updated Thermal Rating: on line 70046-70044 : Rate B, Rate C - 0.0, 0.0 -> 182.51, 182.51
% INFO    : Updated Thermal Rating: on line 70162-70044 : Rate B, Rate C - 0.0, 0.0 -> 217.96, 217.96
% INFO    : Updated Thermal Rating: on line 70046-70052 : Rate B, Rate C - 0.0, 0.0 -> 228.92, 228.92
% INFO    : Updated Thermal Rating: on line 70065-70047 : Rate B, Rate C - 0.0, 0.0 -> 220.52, 220.52
% INFO    : Updated Thermal Rating: on line 70051-70052 : Rate B, Rate C - 0.0, 0.0 -> 199.33, 199.33
% INFO    : Updated Thermal Rating: on line 70051-70058 : Rate B, Rate C - 0.0, 0.0 -> 238.59, 238.59
% INFO    : Updated Thermal Rating: on line 70148-70052 : Rate B, Rate C - 0.0, 0.0 -> 242.97, 242.97
% INFO    : Updated Thermal Rating: on transformer 70053-70056 : Rate B, Rate C - 0.0, 0.0 -> 259.95, 259.95
% INFO    : Updated Thermal Rating: on transformer 70054-70056 : Rate B, Rate C - 0.0, 0.0 -> 129.98, 129.98
% INFO    : Updated Thermal Rating: on transformer 70055-70056 : Rate B, Rate C - 0.0, 0.0 -> 129.98, 129.98
% INFO    : Updated Thermal Rating: on line 70057-70058 : Rate B, Rate C - 0.0, 0.0 -> 195.92, 195.92
% INFO    : Updated Thermal Rating: on line 70057-70059 : Rate B, Rate C - 0.0, 0.0 -> 219.49, 219.49
% INFO    : Updated Thermal Rating: on line 70058-70103 : Rate B, Rate C - 0.0, 0.0 -> 246.69, 246.69
% INFO    : Updated Thermal Rating: on line 70096-70059 : Rate B, Rate C - 0.0, 0.0 -> 222.3, 222.3
% INFO    : Updated Thermal Rating: on line 70059-70179 : Rate B, Rate C - 0.0, 0.0 -> 248.1, 248.1
% INFO    : Updated Thermal Rating: on line 70109-70061 : Rate B, Rate C - 0.0, 0.0 -> 249.98, 249.98
% INFO    : Updated Thermal Rating: on line 70061-70113 : Rate B, Rate C - 0.0, 0.0 -> 250.74, 250.74
% INFO    : Updated Thermal Rating: on line 70064-70065 : Rate B, Rate C - 0.0, 0.0 -> 212.2, 212.2
% INFO    : Updated Thermal Rating: on line 70118-70064 : Rate B, Rate C - 0.0, 0.0 -> 247.94, 247.94
% INFO    : Updated Thermal Rating: on line 70065-70066 : Rate B, Rate C - 0.0, 0.0 -> 262.26, 262.26
% INFO    : Updated Thermal Rating: on line 70065-70175 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 70066-70096 : Rate B, Rate C - 0.0, 0.0 -> 261.28, 261.28
% INFO    : Updated Thermal Rating: on line 70067-70082 : Rate B, Rate C - 0.0, 0.0 -> 255.39, 255.39
% INFO    : Updated Thermal Rating: on line 70067-70129 : Rate B, Rate C - 0.0, 0.0 -> 267.69, 267.69
% INFO    : Updated Thermal Rating: on line 70068-70103 : Rate B, Rate C - 0.0, 0.0 -> 183.54, 183.54
% INFO    : Updated Thermal Rating: on line 70068-70159 : Rate B, Rate C - 0.0, 0.0 -> 204.97, 204.97
% INFO    : Updated Thermal Rating: on line 70069-70094 : Rate B, Rate C - 0.0, 0.0 -> 235.02, 235.02
% INFO    : Updated Thermal Rating: on line 70069-70171 : Rate B, Rate C - 0.0, 0.0 -> 213.37, 213.37
% INFO    : Updated Thermal Rating: on transformer 70071-70074 : Rate B, Rate C - 0.0, 0.0 -> 167.33, 167.33
% INFO    : Updated Thermal Rating: on line 70071-70075 : Rate B, Rate C - 0.0, 0.0 -> 252.14, 252.14
% INFO    : Updated Thermal Rating: on line 70071-70109 : Rate B, Rate C - 0.0, 0.0 -> 269.45, 269.45
% INFO    : Updated Thermal Rating: on transformer 70072-70074 : Rate B, Rate C - 0.0, 0.0 -> 90.0, 90.0
% INFO    : Updated Thermal Rating: on line 70072-70076 : Rate B, Rate C - 0.0, 0.0 -> 171.07, 171.07
% INFO    : Updated Thermal Rating: on transformer 70073-70074 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 70076-70075 : Rate B, Rate C - 0.0, 0.0 -> 102.77, 102.77
% INFO    : Updated Thermal Rating: on transformer 70076-70075 : Rate B, Rate C - 0.0, 0.0 -> 102.77, 102.77
% INFO    : Updated Thermal Rating: on transformer 70076-70075 : Rate B, Rate C - 0.0, 0.0 -> 102.77, 102.77
% INFO    : Updated Thermal Rating: on transformer 70076-70075 : Rate B, Rate C - 0.0, 0.0 -> 102.77, 102.77
% INFO    : Updated Thermal Rating: on line 70075-70109 : Rate B, Rate C - 0.0, 0.0 -> 260.76, 260.76
% INFO    : Updated Thermal Rating: on line 70076-70138 : Rate B, Rate C - 0.0, 0.0 -> 140.37, 140.37
% INFO    : Updated Thermal Rating: on line 70090-70077 : Rate B, Rate C - 0.0, 0.0 -> 222.83, 222.83
% INFO    : Updated Thermal Rating: on line 70077-70185 : Rate B, Rate C - 0.0, 0.0 -> 235.72, 235.72
% INFO    : Updated Thermal Rating: on line 70080-70086 : Rate B, Rate C - 0.0, 0.0 -> 276.35, 276.35
% INFO    : Updated Thermal Rating: on line 70080-70109 : Rate B, Rate C - 0.0, 0.0 -> 276.46, 276.46
% INFO    : Updated Thermal Rating: on line 70080-70109 : Rate B, Rate C - 0.0, 0.0 -> 276.46, 276.46
% INFO    : Updated Thermal Rating: on line 70080-70109 : Rate B, Rate C - 0.0, 0.0 -> 276.46, 276.46
% INFO    : Updated Thermal Rating: on line 70080-70171 : Rate B, Rate C - 0.0, 0.0 -> 282.72, 282.72
% INFO    : Updated Thermal Rating: on line 70080-70171 : Rate B, Rate C - 0.0, 0.0 -> 282.72, 282.72
% INFO    : Updated Thermal Rating: on line 70080-70171 : Rate B, Rate C - 0.0, 0.0 -> 282.72, 282.72
% INFO    : Updated Thermal Rating: on line 70092-70082 : Rate B, Rate C - 0.0, 0.0 -> 236.49, 236.49
% INFO    : Updated Thermal Rating: on line 70083-70094 : Rate B, Rate C - 0.0, 0.0 -> 225.31, 225.31
% INFO    : Updated Thermal Rating: on line 70171-70083 : Rate B, Rate C - 0.0, 0.0 -> 216.0, 216.0
% INFO    : Updated Thermal Rating: on transformer 70085-70084 : Rate B, Rate C - 0.0, 0.0 -> 72.89, 72.89
% INFO    : Updated Thermal Rating: on line 70138-70085 : Rate B, Rate C - 0.0, 0.0 -> 142.0, 142.0
% INFO    : Updated Thermal Rating: on line 70086-70109 : Rate B, Rate C - 0.0, 0.0 -> 240.55, 240.55
% INFO    : Updated Thermal Rating: on line 70137-70086 : Rate B, Rate C - 0.0, 0.0 -> 260.88, 260.88
% INFO    : Updated Thermal Rating: on line 70090-70089 : Rate B, Rate C - 0.0, 0.0 -> 216.08, 216.08
% INFO    : Updated Thermal Rating: on line 70089-70093 : Rate B, Rate C - 0.0, 0.0 -> 265.22, 265.22
% INFO    : Updated Thermal Rating: on line 70089-70167 : Rate B, Rate C - 0.0, 0.0 -> 255.57, 255.57
% INFO    : Updated Thermal Rating: on line 70093-70094 : Rate B, Rate C - 0.0, 0.0 -> 261.44, 261.44
% INFO    : Updated Thermal Rating: on transformer 70096-70095 : Rate B, Rate C - 0.0, 0.0 -> 520.94, 520.94
% INFO    : Updated Thermal Rating: on transformer 70095-70097 : Rate B, Rate C - 0.0, 0.0 -> 545.38, 545.38
% INFO    : Updated Thermal Rating: on transformer 70095-70098 : Rate B, Rate C - 0.0, 0.0 -> 544.36, 544.36
% INFO    : Updated Thermal Rating: on transformer 70095-70099 : Rate B, Rate C - 0.0, 0.0 -> 542.58, 542.58
% INFO    : Updated Thermal Rating: on transformer 70095-70100 : Rate B, Rate C - 0.0, 0.0 -> 541.78, 541.78
% INFO    : Updated Thermal Rating: on line 70103-70096 : Rate B, Rate C - 0.0, 0.0 -> 260.5, 260.5
% INFO    : Updated Thermal Rating: on line 70116-70101 : Rate B, Rate C - 0.0, 0.0 -> 1380.92, 1380.92
% INFO    : Updated Thermal Rating: on line 70117-70101 : Rate B, Rate C - 0.0, 0.0 -> 1370.14, 1370.14
% INFO    : Updated Thermal Rating: on line 70132-70101 : Rate B, Rate C - 0.0, 0.0 -> 1461.7, 1461.7
% INFO    : Updated Thermal Rating: on line 70101-70161 : Rate B, Rate C - 0.0, 0.0 -> 1223.49, 1223.49
% INFO    : Updated Thermal Rating: on line 70170-70101 : Rate B, Rate C - 0.0, 0.0 -> 1378.84, 1378.84
% INFO    : Updated Thermal Rating: on transformer 70103-70104 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 70110-70106 : Rate B, Rate C - 0.0, 0.0 -> 212.85, 212.85
% INFO    : Updated Thermal Rating: on line 70167-70106 : Rate B, Rate C - 0.0, 0.0 -> 215.12, 215.12
% INFO    : Updated Thermal Rating: on line 70106-70185 : Rate B, Rate C - 0.0, 0.0 -> 225.23, 225.23
% INFO    : Updated Thermal Rating: on line 70110-70133 : Rate B, Rate C - 0.0, 0.0 -> 177.1, 177.1
% INFO    : Updated Thermal Rating: on line 70111-70162 : Rate B, Rate C - 0.0, 0.0 -> 243.38, 243.38
% INFO    : Updated Thermal Rating: on line 70182-70111 : Rate B, Rate C - 0.0, 0.0 -> 191.7, 191.7
% INFO    : Updated Thermal Rating: on transformer 70113-70112 : Rate B, Rate C - 0.0, 0.0 -> 266.17, 266.17
% INFO    : Updated Thermal Rating: on transformer 70112-70114 : Rate B, Rate C - 0.0, 0.0 -> 421.85, 421.85
% INFO    : Updated Thermal Rating: on transformer 70112-70115 : Rate B, Rate C - 0.0, 0.0 -> 303.35, 303.35
% INFO    : Updated Thermal Rating: on line 70113-70178 : Rate B, Rate C - 0.0, 0.0 -> 251.89, 251.89
% INFO    : Updated Thermal Rating: on line 70116-70135 : Rate B, Rate C - 0.0, 0.0 -> 1371.02, 1371.02
% INFO    : Updated Thermal Rating: on line 70161-70116 : Rate B, Rate C - 0.0, 0.0 -> 1293.28, 1293.28
% INFO    : Updated Thermal Rating: on transformer 70117-70120 : Rate B, Rate C - 0.0, 0.0 -> 518.51, 518.51
% INFO    : Updated Thermal Rating: on transformer 70117-70121 : Rate B, Rate C - 0.0, 0.0 -> 628.81, 628.81
% INFO    : Updated Thermal Rating: on line 70132-70117 : Rate B, Rate C - 0.0, 0.0 -> 1077.12, 1077.12
% INFO    : Updated Thermal Rating: on line 70117-77262 : Rate B, Rate C - 0.0, 0.0 -> 1372.84, 1372.84
% INFO    : Updated Thermal Rating: on transformer 70118-70120 : Rate B, Rate C - 0.0, 0.0 -> 393.05, 393.05
% INFO    : Updated Thermal Rating: on transformer 70119-70120 : Rate B, Rate C - 0.0, 0.0 -> 125.46, 125.46
% INFO    : Updated Thermal Rating: on transformer 70123-70122 : Rate B, Rate C - 0.0, 0.0 -> 445.77, 445.77
% INFO    : Updated Thermal Rating: on transformer 70122-70125 : Rate B, Rate C - 0.0, 0.0 -> 588.19, 588.19
% INFO    : Updated Thermal Rating: on transformer 70122-70126 : Rate B, Rate C - 0.0, 0.0 -> 587.37, 587.37
% INFO    : Updated Thermal Rating: on transformer 70122-70127 : Rate B, Rate C - 0.0, 0.0 -> 585.62, 585.62
% INFO    : Updated Thermal Rating: on line 70157-70122 : Rate B, Rate C - 0.0, 0.0 -> 1257.18, 1257.18
% INFO    : Updated Thermal Rating: on transformer 70124-70123 : Rate B, Rate C - 0.0, 0.0 -> 92.9, 92.9
% INFO    : Updated Thermal Rating: on line 70145-70129 : Rate B, Rate C - 0.0, 0.0 -> 229.6, 229.6
% INFO    : Updated Thermal Rating: on line 70178-70129 : Rate B, Rate C - 0.0, 0.0 -> 230.7, 230.7
% INFO    : Updated Thermal Rating: on transformer 70130-70131 : Rate B, Rate C - 0.0, 0.0 -> 100.34, 100.34
% INFO    : Updated Thermal Rating: on line 70130-70169 : Rate B, Rate C - 0.0, 0.0 -> 219.3, 219.3
% INFO    : Updated Thermal Rating: on transformer 70133-70132 : Rate B, Rate C - 0.0, 0.0 -> 433.4, 433.4
% INFO    : Updated Thermal Rating: on transformer 70132-70134 : Rate B, Rate C - 0.0, 0.0 -> 601.3, 601.3
% INFO    : Updated Thermal Rating: on line 70132-77262 : Rate B, Rate C - 0.0, 0.0 -> 1418.83, 1418.83
% INFO    : Updated Thermal Rating: on line 70167-70133 : Rate B, Rate C - 0.0, 0.0 -> 229.97, 229.97
% INFO    : Updated Thermal Rating: on line 70133-70175 : Rate B, Rate C - 0.0, 0.0 -> 252.7, 252.7
% INFO    : Updated Thermal Rating: on transformer 70135-70140 : Rate B, Rate C - 0.0, 0.0 -> 596.12, 596.12
% INFO    : Updated Thermal Rating: on transformer 70135-70143 : Rate B, Rate C - 0.0, 0.0 -> 926.3, 926.3
% INFO    : Updated Thermal Rating: on transformer 70135-70144 : Rate B, Rate C - 0.0, 0.0 -> 395.58, 395.58
% INFO    : Updated Thermal Rating: on transformer 70137-70136 : Rate B, Rate C - 0.0, 0.0 -> 122.83, 122.83
% INFO    : Updated Thermal Rating: on transformer 70136-70140 : Rate B, Rate C - 0.0, 0.0 -> 496.12, 496.12
% INFO    : Updated Thermal Rating: on transformer 70138-70137 : Rate B, Rate C - 0.0, 0.0 -> 83.92, 83.92
% INFO    : Updated Thermal Rating: on transformer 70138-70137 : Rate B, Rate C - 0.0, 0.0 -> 83.92, 83.92
% INFO    : Updated Thermal Rating: on transformer 70138-70137 : Rate B, Rate C - 0.0, 0.0 -> 83.92, 83.92
% INFO    : Updated Thermal Rating: on transformer 70139-70140 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 70141-70143 : Rate B, Rate C - 0.0, 0.0 -> 463.15, 463.15
% INFO    : Updated Thermal Rating: on transformer 70142-70143 : Rate B, Rate C - 0.0, 0.0 -> 463.15, 463.15
% INFO    : Updated Thermal Rating: on transformer 70145-70146 : Rate B, Rate C - 0.0, 0.0 -> 150.54, 150.54
% INFO    : Updated Thermal Rating: on line 70178-70145 : Rate B, Rate C - 0.0, 0.0 -> 219.84, 219.84
% INFO    : Updated Thermal Rating: on line 70147-70152 : Rate B, Rate C - 0.0, 0.0 -> 237.52, 237.52
% INFO    : Updated Thermal Rating: on transformer 70148-70149 : Rate B, Rate C - 0.0, 0.0 -> 128.7, 128.7
% INFO    : Updated Thermal Rating: on transformer 70148-70150 : Rate B, Rate C - 0.0, 0.0 -> 23.36, 23.36
% INFO    : Updated Thermal Rating: on line 70179-70148 : Rate B, Rate C - 0.0, 0.0 -> 242.78, 242.78
% INFO    : Updated Thermal Rating: on transformer 70152-70151 : Rate B, Rate C - 0.0, 0.0 -> 434.23, 434.23
% INFO    : Updated Thermal Rating: on transformer 70151-70153 : Rate B, Rate C - 0.0, 0.0 -> 793.62, 793.62
% INFO    : Updated Thermal Rating: on transformer 70151-70154 : Rate B, Rate C - 0.0, 0.0 -> 793.62, 793.62
% INFO    : Updated Thermal Rating: on transformer 70151-70155 : Rate B, Rate C - 0.0, 0.0 -> 793.62, 793.62
% INFO    : Updated Thermal Rating: on transformer 70151-70156 : Rate B, Rate C - 0.0, 0.0 -> 793.62, 793.62
% INFO    : Updated Thermal Rating: on transformer 70159-70160 : Rate B, Rate C - 0.0, 0.0 -> 134.29, 134.29
% INFO    : Updated Thermal Rating: on line 70159-70179 : Rate B, Rate C - 0.0, 0.0 -> 243.92, 243.92
% INFO    : Updated Thermal Rating: on transformer 70162-70161 : Rate B, Rate C - 0.0, 0.0 -> 394.69, 394.69
% INFO    : Updated Thermal Rating: on transformer 70161-70166 : Rate B, Rate C - 0.0, 0.0 -> 262.28, 262.28
% INFO    : Updated Thermal Rating: on transformer 70162-70163 : Rate B, Rate C - 0.0, 0.0 -> 38.93, 38.93
% INFO    : Updated Thermal Rating: on transformer 70162-70164 : Rate B, Rate C - 0.0, 0.0 -> 75.17, 75.17
% INFO    : Updated Thermal Rating: on transformer 70162-70165 : Rate B, Rate C - 0.0, 0.0 -> 65.0, 65.0
% INFO    : Updated Thermal Rating: on transformer 70171-70170 : Rate B, Rate C - 0.0, 0.0 -> 684.9, 684.9
% INFO    : Updated Thermal Rating: on transformer 70170-70172 : Rate B, Rate C - 0.0, 0.0 -> 741.0, 741.0
% INFO    : Updated Thermal Rating: on transformer 70170-70173 : Rate B, Rate C - 0.0, 0.0 -> 741.0, 741.0
% INFO    : Updated Thermal Rating: on transformer 70170-70174 : Rate B, Rate C - 0.0, 0.0 -> 741.0, 741.0
% INFO    : Updated Thermal Rating: on transformer 70175-70176 : Rate B, Rate C - 0.0, 0.0 -> 151.06, 151.06
% INFO    : Updated Thermal Rating: on line 70185-70175 : Rate B, Rate C - 0.0, 0.0 -> 195.63, 195.63
% INFO    : Updated Thermal Rating: on transformer 70179-70180 : Rate B, Rate C - 0.0, 0.0 -> 106.24, 106.24
% INFO    : Updated Thermal Rating: on transformer 70179-70181 : Rate B, Rate C - 0.0, 0.0 -> 105.72, 105.72
% INFO    : Updated Thermal Rating: on transformer 70183-70184 : Rate B, Rate C - 0.0, 0.0 -> 123.5, 123.5
% INFO    : Updated Thermal Rating: on transformer 70187-70188 : Rate B, Rate C - 0.0, 0.0 -> 105.4, 105.4
% INFO    : Updated Thermal Rating: on transformer 70187-70189 : Rate B, Rate C - 0.0, 0.0 -> 70.36, 70.36
% INFO    : Updated Thermal Rating: on line 74000-74001 : Rate B, Rate C - 0.0, 0.0 -> 242.42, 242.42
% INFO    : Updated Thermal Rating: on line 74019-74001 : Rate B, Rate C - 0.0, 0.0 -> 218.81, 218.81
% INFO    : Updated Thermal Rating: on line 74001-74228 : Rate B, Rate C - 0.0, 0.0 -> 200.25, 200.25
% INFO    : Updated Thermal Rating: on line 74002-74033 : Rate B, Rate C - 0.0, 0.0 -> 234.09, 234.09
% INFO    : Updated Thermal Rating: on line 74002-74208 : Rate B, Rate C - 0.0, 0.0 -> 243.8, 243.8
% INFO    : Updated Thermal Rating: on line 74002-74241 : Rate B, Rate C - 0.0, 0.0 -> 249.64, 249.64
% INFO    : Updated Thermal Rating: on line 74003-74208 : Rate B, Rate C - 0.0, 0.0 -> 241.99, 241.99
% INFO    : Updated Thermal Rating: on line 74251-74004 : Rate B, Rate C - 0.0, 0.0 -> 246.75, 246.75
% INFO    : Updated Thermal Rating: on line 74208-74006 : Rate B, Rate C - 0.0, 0.0 -> 243.34, 243.34
% INFO    : Updated Thermal Rating: on line 74008-74011 : Rate B, Rate C - 0.0, 0.0 -> 218.88, 218.88
% INFO    : Updated Thermal Rating: on line 74008-74022 : Rate B, Rate C - 0.0, 0.0 -> 188.01, 188.01
% INFO    : Updated Thermal Rating: on line 74008-74027 : Rate B, Rate C - 0.0, 0.0 -> 178.8, 178.8
% INFO    : Updated Thermal Rating: on line 74011-74214 : Rate B, Rate C - 0.0, 0.0 -> 234.36, 234.36
% INFO    : Updated Thermal Rating: on line 74012-74034 : Rate B, Rate C - 0.0, 0.0 -> 245.03, 245.03
% INFO    : Updated Thermal Rating: on line 74013-74214 : Rate B, Rate C - 0.0, 0.0 -> 245.52, 245.52
% INFO    : Updated Thermal Rating: on line 74014-74214 : Rate B, Rate C - 0.0, 0.0 -> 241.67, 241.67
% INFO    : Updated Thermal Rating: on line 74016-74040 : Rate B, Rate C - 0.0, 0.0 -> 177.83, 177.83
% INFO    : Updated Thermal Rating: on line 74016-74054 : Rate B, Rate C - 0.0, 0.0 -> 180.53, 180.53
% INFO    : Updated Thermal Rating: on line 74017-74029 : Rate B, Rate C - 0.0, 0.0 -> 210.85, 210.85
% INFO    : Updated Thermal Rating: on line 74327-74017 : Rate B, Rate C - 0.0, 0.0 -> 237.42, 237.42
% INFO    : Updated Thermal Rating: on line 74018-74056 : Rate B, Rate C - 0.0, 0.0 -> 217.83, 217.83
% INFO    : Updated Thermal Rating: on line 74300-74018 : Rate B, Rate C - 0.0, 0.0 -> 194.88, 194.88
% INFO    : Updated Thermal Rating: on line 74019-74049 : Rate B, Rate C - 0.0, 0.0 -> 201.04, 201.04
% INFO    : Updated Thermal Rating: on line 74021-74030 : Rate B, Rate C - 0.0, 0.0 -> 235.7, 235.7
% INFO    : Updated Thermal Rating: on line 74054-74022 : Rate B, Rate C - 0.0, 0.0 -> 199.21, 199.21
% INFO    : Updated Thermal Rating: on line 74033-74024 : Rate B, Rate C - 0.0, 0.0 -> 242.21, 242.21
% INFO    : Updated Thermal Rating: on line 74025-74208 : Rate B, Rate C - 0.0, 0.0 -> 244.65, 244.65
% INFO    : Updated Thermal Rating: on line 74026-74034 : Rate B, Rate C - 0.0, 0.0 -> 218.33, 218.33
% INFO    : Updated Thermal Rating: on line 74026-74058 : Rate B, Rate C - 0.0, 0.0 -> 206.34, 206.34
% INFO    : Updated Thermal Rating: on line 74029-74065 : Rate B, Rate C - 0.0, 0.0 -> 242.65, 242.65
% INFO    : Updated Thermal Rating: on line 74327-74029 : Rate B, Rate C - 0.0, 0.0 -> 242.14, 242.14
% INFO    : Updated Thermal Rating: on line 74030-74056 : Rate B, Rate C - 0.0, 0.0 -> 242.65, 242.65
% INFO    : Updated Thermal Rating: on line 74040-74033 : Rate B, Rate C - 0.0, 0.0 -> 242.66, 242.66
% INFO    : Updated Thermal Rating: on line 74035-74042 : Rate B, Rate C - 0.0, 0.0 -> 196.38, 196.38
% INFO    : Updated Thermal Rating: on line 74045-74035 : Rate B, Rate C - 0.0, 0.0 -> 240.23, 240.23
% INFO    : Updated Thermal Rating: on transformer 74036-74039 : Rate B, Rate C - 0.0, 0.0 -> 279.48, 279.48
% INFO    : Updated Thermal Rating: on transformer 74037-74039 : Rate B, Rate C - 0.0, 0.0 -> 139.74, 139.74
% INFO    : Updated Thermal Rating: on transformer 74038-74039 : Rate B, Rate C - 0.0, 0.0 -> 139.74, 139.74
% INFO    : Updated Thermal Rating: on line 74040-77179 : Rate B, Rate C - 0.0, 0.0 -> 266.36, 266.36
% INFO    : Updated Thermal Rating: on line 74058-74042 : Rate B, Rate C - 0.0, 0.0 -> 233.73, 233.73
% INFO    : Updated Thermal Rating: on line 74042-74070 : Rate B, Rate C - 0.0, 0.0 -> 209.54, 209.54
% INFO    : Updated Thermal Rating: on line 74047-74045 : Rate B, Rate C - 0.0, 0.0 -> 250.9, 250.9
% INFO    : Updated Thermal Rating: on transformer 74047-74046 : Rate B, Rate C - 0.0, 0.0 -> 451.6, 451.6
% INFO    : Updated Thermal Rating: on line 74083-74046 : Rate B, Rate C - 0.0, 0.0 -> 1126.2, 1126.2
% INFO    : Updated Thermal Rating: on line 74330-74046 : Rate B, Rate C - 0.0, 0.0 -> 1284.36, 1284.36
% INFO    : Updated Thermal Rating: on line 74049-74047 : Rate B, Rate C - 0.0, 0.0 -> 221.83, 221.83
% INFO    : Updated Thermal Rating: on line 74047-74061 : Rate B, Rate C - 0.0, 0.0 -> 228.22, 228.22
% INFO    : Updated Thermal Rating: on line 74050-74066 : Rate B, Rate C - 0.0, 0.0 -> 227.42, 227.42
% INFO    : Updated Thermal Rating: on line 74050-74327 : Rate B, Rate C - 0.0, 0.0 -> 240.96, 240.96
% INFO    : Updated Thermal Rating: on line 74052-74063 : Rate B, Rate C - 0.0, 0.0 -> 201.41, 201.41
% INFO    : Updated Thermal Rating: on line 74267-74052 : Rate B, Rate C - 0.0, 0.0 -> 206.15, 206.15
% INFO    : Updated Thermal Rating: on line 74052-77174 : Rate B, Rate C - 0.0, 0.0 -> 198.57, 198.57
% INFO    : Updated Thermal Rating: on line 74111-74054 : Rate B, Rate C - 0.0, 0.0 -> 226.97, 226.97
% INFO    : Updated Thermal Rating: on line 74056-74063 : Rate B, Rate C - 0.0, 0.0 -> 224.57, 224.57
% INFO    : Updated Thermal Rating: on line 74235-74056 : Rate B, Rate C - 0.0, 0.0 -> 247.14, 247.14
% INFO    : Updated Thermal Rating: on line 74058-74327 : Rate B, Rate C - 0.0, 0.0 -> 257.34, 257.34
% INFO    : Updated Thermal Rating: on line 74061-74078 : Rate B, Rate C - 0.0, 0.0 -> 182.89, 182.89
% INFO    : Updated Thermal Rating: on line 74235-74063 : Rate B, Rate C - 0.0, 0.0 -> 240.77, 240.77
% INFO    : Updated Thermal Rating: on line 74073-74065 : Rate B, Rate C - 0.0, 0.0 -> 218.77, 218.77
% INFO    : Updated Thermal Rating: on line 74073-74066 : Rate B, Rate C - 0.0, 0.0 -> 218.61, 218.61
% INFO    : Updated Thermal Rating: on line 74066-74093 : Rate B, Rate C - 0.0, 0.0 -> 237.72, 237.72
% INFO    : Updated Thermal Rating: on line 74067-74069 : Rate B, Rate C - 0.0, 0.0 -> 204.38, 204.38
% INFO    : Updated Thermal Rating: on line 74075-74067 : Rate B, Rate C - 0.0, 0.0 -> 221.36, 221.36
% INFO    : Updated Thermal Rating: on line 74069-74073 : Rate B, Rate C - 0.0, 0.0 -> 244.13, 244.13
% INFO    : Updated Thermal Rating: on line 74070-74084 : Rate B, Rate C - 0.0, 0.0 -> 202.14, 202.14
% INFO    : Updated Thermal Rating: on line 74093-74071 : Rate B, Rate C - 0.0, 0.0 -> 185.08, 185.08
% INFO    : Updated Thermal Rating: on line 74071-74109 : Rate B, Rate C - 0.0, 0.0 -> 222.11, 222.11
% INFO    : Updated Thermal Rating: on transformer 74073-74072 : Rate B, Rate C - 0.0, 0.0 -> 449.47, 449.47
% INFO    : Updated Thermal Rating: on line 74083-74072 : Rate B, Rate C - 0.0, 0.0 -> 1163.31, 1163.31
% INFO    : Updated Thermal Rating: on line 74072-74330 : Rate B, Rate C - 0.0, 0.0 -> 1321.35, 1321.35
% INFO    : Updated Thermal Rating: on line 74073-74087 : Rate B, Rate C - 0.0, 0.0 -> 242.47, 242.47
% INFO    : Updated Thermal Rating: on line 74073-74105 : Rate B, Rate C - 0.0, 0.0 -> 213.16, 213.16
% INFO    : Updated Thermal Rating: on line 74075-74084 : Rate B, Rate C - 0.0, 0.0 -> 242.93, 242.93
% INFO    : Updated Thermal Rating: on line 74098-74078 : Rate B, Rate C - 0.0, 0.0 -> 199.94, 199.94
% INFO    : Updated Thermal Rating: on line 74078-74112 : Rate B, Rate C - 0.0, 0.0 -> 230.15, 230.15
% INFO    : Updated Thermal Rating: on line 74080-74089 : Rate B, Rate C - 0.0, 0.0 -> 206.2, 206.2
% INFO    : Updated Thermal Rating: on line 74228-74080 : Rate B, Rate C - 0.0, 0.0 -> 221.34, 221.34
% INFO    : Updated Thermal Rating: on transformer 74084-74083 : Rate B, Rate C - 0.0, 0.0 -> 433.52, 433.52
% INFO    : Updated Thermal Rating: on line 74218-74083 : Rate B, Rate C - 0.0, 0.0 -> 1149.93, 1149.93
% INFO    : Updated Thermal Rating: on line 74223-74083 : Rate B, Rate C - 0.0, 0.0 -> 1256.69, 1256.69
% INFO    : Updated Thermal Rating: on line 74084-74088 : Rate B, Rate C - 0.0, 0.0 -> 171.91, 171.91
% INFO    : Updated Thermal Rating: on line 74089-74085 : Rate B, Rate C - 0.0, 0.0 -> 197.54, 197.54
% INFO    : Updated Thermal Rating: on line 74102-74085 : Rate B, Rate C - 0.0, 0.0 -> 212.94, 212.94
% INFO    : Updated Thermal Rating: on line 74085-74103 : Rate B, Rate C - 0.0, 0.0 -> 231.31, 231.31
% INFO    : Updated Thermal Rating: on line 74093-74087 : Rate B, Rate C - 0.0, 0.0 -> 204.37, 204.37
% INFO    : Updated Thermal Rating: on line 74088-74219 : Rate B, Rate C - 0.0, 0.0 -> 235.47, 235.47
% INFO    : Updated Thermal Rating: on line 74089-74093 : Rate B, Rate C - 0.0, 0.0 -> 212.71, 212.71
% INFO    : Updated Thermal Rating: on line 74089-74307 : Rate B, Rate C - 0.0, 0.0 -> 215.19, 215.19
% INFO    : Updated Thermal Rating: on transformer 74094-74097 : Rate B, Rate C - 0.0, 0.0 -> 306.25, 306.25
% INFO    : Updated Thermal Rating: on transformer 74095-74097 : Rate B, Rate C - 0.0, 0.0 -> 153.13, 153.13
% INFO    : Updated Thermal Rating: on transformer 74096-74097 : Rate B, Rate C - 0.0, 0.0 -> 153.13, 153.13
% INFO    : Updated Thermal Rating: on line 74098-74219 : Rate B, Rate C - 0.0, 0.0 -> 234.84, 234.84
% INFO    : Updated Thermal Rating: on line 74118-74102 : Rate B, Rate C - 0.0, 0.0 -> 201.79, 201.79
% INFO    : Updated Thermal Rating: on line 74219-74102 : Rate B, Rate C - 0.0, 0.0 -> 231.1, 231.1
% INFO    : Updated Thermal Rating: on line 74103-74112 : Rate B, Rate C - 0.0, 0.0 -> 247.47, 247.47
% INFO    : Updated Thermal Rating: on line 74104-74281 : Rate B, Rate C - 0.0, 0.0 -> 236.7, 236.7
% INFO    : Updated Thermal Rating: on line 74112-74105 : Rate B, Rate C - 0.0, 0.0 -> 210.25, 210.25
% INFO    : Updated Thermal Rating: on line 74115-74106 : Rate B, Rate C - 0.0, 0.0 -> 228.26, 228.26
% INFO    : Updated Thermal Rating: on line 74273-74106 : Rate B, Rate C - 0.0, 0.0 -> 239.25, 239.25
% INFO    : Updated Thermal Rating: on line 74111-77170 : Rate B, Rate C - 0.0, 0.0 -> 207.49, 207.49
% INFO    : Updated Thermal Rating: on line 77183-74111 : Rate B, Rate C - 0.0, 0.0 -> 231.37, 231.37
% INFO    : Updated Thermal Rating: on line 74112-74114 : Rate B, Rate C - 0.0, 0.0 -> 273.18, 273.18
% INFO    : Updated Thermal Rating: on line 74116-74113 : Rate B, Rate C - 0.0, 0.0 -> 218.07, 218.07
% INFO    : Updated Thermal Rating: on line 74114-74121 : Rate B, Rate C - 0.0, 0.0 -> 180.29, 180.29
% INFO    : Updated Thermal Rating: on line 74251-74114 : Rate B, Rate C - 0.0, 0.0 -> 254.77, 254.77
% INFO    : Updated Thermal Rating: on line 74121-74116 : Rate B, Rate C - 0.0, 0.0 -> 192.36, 192.36
% INFO    : Updated Thermal Rating: on line 74118-74219 : Rate B, Rate C - 0.0, 0.0 -> 237.23, 237.23
% INFO    : Updated Thermal Rating: on line 74119-74224 : Rate B, Rate C - 0.0, 0.0 -> 209.23, 209.23
% INFO    : Updated Thermal Rating: on line 74299-74119 : Rate B, Rate C - 0.0, 0.0 -> 210.0, 210.0
% INFO    : Updated Thermal Rating: on line 77155-74122 : Rate B, Rate C - 0.0, 0.0 -> 189.32, 189.32
% INFO    : Updated Thermal Rating: on line 74122-77159 : Rate B, Rate C - 0.0, 0.0 -> 193.03, 193.03
% INFO    : Updated Thermal Rating: on line 74122-77160 : Rate B, Rate C - 0.0, 0.0 -> 198.15, 198.15
% INFO    : Updated Thermal Rating: on line 74123-74128 : Rate B, Rate C - 0.0, 0.0 -> 231.59, 231.59
% INFO    : Updated Thermal Rating: on line 74123-74227 : Rate B, Rate C - 0.0, 0.0 -> 236.08, 236.08
% INFO    : Updated Thermal Rating: on line 74331-74123 : Rate B, Rate C - 0.0, 0.0 -> 199.62, 199.62
% INFO    : Updated Thermal Rating: on line 74134-74124 : Rate B, Rate C - 0.0, 0.0 -> 205.12, 205.12
% INFO    : Updated Thermal Rating: on line 74124-74137 : Rate B, Rate C - 0.0, 0.0 -> 215.6, 215.6
% INFO    : Updated Thermal Rating: on line 74124-74199 : Rate B, Rate C - 0.0, 0.0 -> 240.26, 240.26
% INFO    : Updated Thermal Rating: on line 74125-74135 : Rate B, Rate C - 0.0, 0.0 -> 203.52, 203.52
% INFO    : Updated Thermal Rating: on line 74125-74229 : Rate B, Rate C - 0.0, 0.0 -> 222.26, 222.26
% INFO    : Updated Thermal Rating: on line 74127-74139 : Rate B, Rate C - 0.0, 0.0 -> 177.22, 177.22
% INFO    : Updated Thermal Rating: on line 74127-74299 : Rate B, Rate C - 0.0, 0.0 -> 200.24, 200.24
% INFO    : Updated Thermal Rating: on line 74128-74134 : Rate B, Rate C - 0.0, 0.0 -> 216.2, 216.2
% INFO    : Updated Thermal Rating: on line 74131-74129 : Rate B, Rate C - 0.0, 0.0 -> 233.48, 233.48
% INFO    : Updated Thermal Rating: on line 74129-74270 : Rate B, Rate C - 0.0, 0.0 -> 260.37, 260.37
% INFO    : Updated Thermal Rating: on transformer 74131-74130 : Rate B, Rate C - 0.0, 0.0 -> 278.12, 278.12
% INFO    : Updated Thermal Rating: on line 74257-74130 : Rate B, Rate C - 0.0, 0.0 -> 1205.7, 1205.7
% INFO    : Updated Thermal Rating: on line 74130-74325 : Rate B, Rate C - 0.0, 0.0 -> 1198.91, 1198.91
% INFO    : Updated Thermal Rating: on line 74137-74131 : Rate B, Rate C - 0.0, 0.0 -> 189.2, 189.2
% INFO    : Updated Thermal Rating: on line 74132-77126 : Rate B, Rate C - 0.0, 0.0 -> 200.09, 200.09
% INFO    : Updated Thermal Rating: on line 74132-77142 : Rate B, Rate C - 0.0, 0.0 -> 192.12, 192.12
% INFO    : Updated Thermal Rating: on line 77159-74132 : Rate B, Rate C - 0.0, 0.0 -> 208.92, 208.92
% INFO    : Updated Thermal Rating: on line 74132-77163 : Rate B, Rate C - 0.0, 0.0 -> 196.03, 196.03
% INFO    : Updated Thermal Rating: on line 74132-77177 : Rate B, Rate C - 0.0, 0.0 -> 173.37, 173.37
% INFO    : Updated Thermal Rating: on line 74140-74135 : Rate B, Rate C - 0.0, 0.0 -> 191.71, 191.71
% INFO    : Updated Thermal Rating: on line 74139-74138 : Rate B, Rate C - 0.0, 0.0 -> 248.02, 248.02
% INFO    : Updated Thermal Rating: on line 74138-74146 : Rate B, Rate C - 0.0, 0.0 -> 248.61, 248.61
% INFO    : Updated Thermal Rating: on line 74140-74139 : Rate B, Rate C - 0.0, 0.0 -> 235.78, 235.78
% INFO    : Updated Thermal Rating: on line 74155-74140 : Rate B, Rate C - 0.0, 0.0 -> 236.12, 236.12
% INFO    : Updated Thermal Rating: on line 74144-74149 : Rate B, Rate C - 0.0, 0.0 -> 202.17, 202.17
% INFO    : Updated Thermal Rating: on line 74321-74144 : Rate B, Rate C - 0.0, 0.0 -> 210.93, 210.93
% INFO    : Updated Thermal Rating: on line 74146-77114 : Rate B, Rate C - 0.0, 0.0 -> 229.78, 229.78
% INFO    : Updated Thermal Rating: on line 77120-74146 : Rate B, Rate C - 0.0, 0.0 -> 225.93, 225.93
% INFO    : Updated Thermal Rating: on line 74146-77160 : Rate B, Rate C - 0.0, 0.0 -> 211.39, 211.39
% INFO    : Updated Thermal Rating: on line 74149-74152 : Rate B, Rate C - 0.0, 0.0 -> 183.62, 183.62
% INFO    : Updated Thermal Rating: on line 74150-74321 : Rate B, Rate C - 0.0, 0.0 -> 204.76, 204.76
% INFO    : Updated Thermal Rating: on line 74150-74336 : Rate B, Rate C - 0.0, 0.0 -> 207.56, 207.56
% INFO    : Updated Thermal Rating: on line 74153-74152 : Rate B, Rate C - 0.0, 0.0 -> 222.4, 222.4
% INFO    : Updated Thermal Rating: on line 74152-74324 : Rate B, Rate C - 0.0, 0.0 -> 222.74, 222.74
% INFO    : Updated Thermal Rating: on line 74249-74153 : Rate B, Rate C - 0.0, 0.0 -> 186.38, 186.38
% INFO    : Updated Thermal Rating: on line 74154-74249 : Rate B, Rate C - 0.0, 0.0 -> 200.13, 200.13
% INFO    : Updated Thermal Rating: on line 74154-74306 : Rate B, Rate C - 0.0, 0.0 -> 186.24, 186.24
% INFO    : Updated Thermal Rating: on line 74161-74155 : Rate B, Rate C - 0.0, 0.0 -> 230.16, 230.16
% INFO    : Updated Thermal Rating: on line 74262-74156 : Rate B, Rate C - 0.0, 0.0 -> 209.36, 209.36
% INFO    : Updated Thermal Rating: on line 74312-74156 : Rate B, Rate C - 0.0, 0.0 -> 227.03, 227.03
% INFO    : Updated Thermal Rating: on line 74160-74158 : Rate B, Rate C - 0.0, 0.0 -> 201.72, 201.72
% INFO    : Updated Thermal Rating: on line 74158-74303 : Rate B, Rate C - 0.0, 0.0 -> 211.84, 211.84
% INFO    : Updated Thermal Rating: on line 74160-74165 : Rate B, Rate C - 0.0, 0.0 -> 225.75, 225.75
% INFO    : Updated Thermal Rating: on line 74160-74262 : Rate B, Rate C - 0.0, 0.0 -> 208.35, 208.35
% INFO    : Updated Thermal Rating: on line 74303-74160 : Rate B, Rate C - 0.0, 0.0 -> 228.43, 228.43
% INFO    : Updated Thermal Rating: on line 74161-74162 : Rate B, Rate C - 0.0, 0.0 -> 195.62, 195.62
% INFO    : Updated Thermal Rating: on line 74164-74162 : Rate B, Rate C - 0.0, 0.0 -> 209.89, 209.89
% INFO    : Updated Thermal Rating: on line 74306-74163 : Rate B, Rate C - 0.0, 0.0 -> 221.08, 221.08
% INFO    : Updated Thermal Rating: on line 74169-74164 : Rate B, Rate C - 0.0, 0.0 -> 199.07, 199.07
% INFO    : Updated Thermal Rating: on line 74164-74312 : Rate B, Rate C - 0.0, 0.0 -> 237.95, 237.95
% INFO    : Updated Thermal Rating: on line 74165-74169 : Rate B, Rate C - 0.0, 0.0 -> 182.06, 182.06
% INFO    : Updated Thermal Rating: on line 74166-74186 : Rate B, Rate C - 0.0, 0.0 -> 167.4, 167.4
% INFO    : Updated Thermal Rating: on line 74166-74271 : Rate B, Rate C - 0.0, 0.0 -> 198.72, 198.72
% INFO    : Updated Thermal Rating: on transformer 74168-74167 : Rate B, Rate C - 0.0, 0.0 -> 350.27, 350.27
% INFO    : Updated Thermal Rating: on line 74167-74308 : Rate B, Rate C - 0.0, 0.0 -> 1107.68, 1107.68
% INFO    : Updated Thermal Rating: on line 74167-74317 : Rate B, Rate C - 0.0, 0.0 -> 1055.19, 1055.19
% INFO    : Updated Thermal Rating: on transformer 74169-74168 : Rate B, Rate C - 0.0, 0.0 -> 107.0, 107.0
% INFO    : Updated Thermal Rating: on line 74320-74168 : Rate B, Rate C - 0.0, 0.0 -> 231.86, 231.86
% INFO    : Updated Thermal Rating: on line 74169-74178 : Rate B, Rate C - 0.0, 0.0 -> 228.92, 228.92
% INFO    : Updated Thermal Rating: on line 74170-74176 : Rate B, Rate C - 0.0, 0.0 -> 197.77, 197.77
% INFO    : Updated Thermal Rating: on line 74185-74170 : Rate B, Rate C - 0.0, 0.0 -> 210.88, 210.88
% INFO    : Updated Thermal Rating: on line 74172-74171 : Rate B, Rate C - 0.0, 0.0 -> 190.6, 190.6
% INFO    : Updated Thermal Rating: on line 74171-74269 : Rate B, Rate C - 0.0, 0.0 -> 206.5, 206.5
% INFO    : Updated Thermal Rating: on line 74172-74182 : Rate B, Rate C - 0.0, 0.0 -> 218.58, 218.58
% INFO    : Updated Thermal Rating: on line 74177-74173 : Rate B, Rate C - 0.0, 0.0 -> 216.11, 216.11
% INFO    : Updated Thermal Rating: on line 74173-74269 : Rate B, Rate C - 0.0, 0.0 -> 205.6, 205.6
% INFO    : Updated Thermal Rating: on line 74174-74179 : Rate B, Rate C - 0.0, 0.0 -> 240.15, 240.15
% INFO    : Updated Thermal Rating: on line 74174-74181 : Rate B, Rate C - 0.0, 0.0 -> 199.05, 199.05
% INFO    : Updated Thermal Rating: on line 74174-74279 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 74181-74176 : Rate B, Rate C - 0.0, 0.0 -> 183.8, 183.8
% INFO    : Updated Thermal Rating: on line 74176-74182 : Rate B, Rate C - 0.0, 0.0 -> 263.27, 263.27
% INFO    : Updated Thermal Rating: on line 74177-74271 : Rate B, Rate C - 0.0, 0.0 -> 224.21, 224.21
% INFO    : Updated Thermal Rating: on line 74279-74177 : Rate B, Rate C - 0.0, 0.0 -> 226.04, 226.04
% INFO    : Updated Thermal Rating: on line 74178-74279 : Rate B, Rate C - 0.0, 0.0 -> 235.49, 235.49
% INFO    : Updated Thermal Rating: on line 74179-74189 : Rate B, Rate C - 0.0, 0.0 -> 258.72, 258.72
% INFO    : Updated Thermal Rating: on line 74185-74181 : Rate B, Rate C - 0.0, 0.0 -> 224.76, 224.76
% INFO    : Updated Thermal Rating: on line 74225-74182 : Rate B, Rate C - 0.0, 0.0 -> 209.4, 209.4
% INFO    : Updated Thermal Rating: on line 74182-74309 : Rate B, Rate C - 0.0, 0.0 -> 282.09, 282.09
% INFO    : Updated Thermal Rating: on line 74189-74185 : Rate B, Rate C - 0.0, 0.0 -> 250.88, 250.88
% INFO    : Updated Thermal Rating: on line 74186-74319 : Rate B, Rate C - 0.0, 0.0 -> 188.77, 188.77
% INFO    : Updated Thermal Rating: on line 74187-74286 : Rate B, Rate C - 0.0, 0.0 -> 239.21, 239.21
% INFO    : Updated Thermal Rating: on line 74188-74190 : Rate B, Rate C - 0.0, 0.0 -> 220.1, 220.1
% INFO    : Updated Thermal Rating: on line 74319-74188 : Rate B, Rate C - 0.0, 0.0 -> 206.79, 206.79
% INFO    : Updated Thermal Rating: on line 74189-77065 : Rate B, Rate C - 0.0, 0.0 -> 273.87, 273.87
% INFO    : Updated Thermal Rating: on line 74286-74190 : Rate B, Rate C - 0.0, 0.0 -> 234.62, 234.62
% INFO    : Updated Thermal Rating: on transformer 74192-74195 : Rate B, Rate C - 0.0, 0.0 -> 276.78, 276.78
% INFO    : Updated Thermal Rating: on transformer 74192-74196 : Rate B, Rate C - 0.0, 0.0 -> 407.68, 407.68
% INFO    : Updated Thermal Rating: on transformer 74192-74197 : Rate B, Rate C - 0.0, 0.0 -> 404.37, 404.37
% INFO    : Updated Thermal Rating: on transformer 74193-74195 : Rate B, Rate C - 0.0, 0.0 -> 251.78, 251.78
% INFO    : Updated Thermal Rating: on transformer 74194-74195 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 74198-74308 : Rate B, Rate C - 0.0, 0.0 -> 1098.93, 1098.93
% INFO    : Updated Thermal Rating: on transformer 74199-74202 : Rate B, Rate C - 0.0, 0.0 -> 154.45, 154.45
% INFO    : Updated Thermal Rating: on line 74199-74293 : Rate B, Rate C - 0.0, 0.0 -> 166.77, 166.77
% INFO    : Updated Thermal Rating: on transformer 74200-74202 : Rate B, Rate C - 0.0, 0.0 -> 77.23, 77.23
% INFO    : Updated Thermal Rating: on transformer 74201-74202 : Rate B, Rate C - 0.0, 0.0 -> 77.23, 77.23
% INFO    : Updated Thermal Rating: on transformer 74203-74204 : Rate B, Rate C - 0.0, 0.0 -> 224.64, 224.64
% INFO    : Updated Thermal Rating: on transformer 74203-74205 : Rate B, Rate C - 0.0, 0.0 -> 39.35, 39.35
% INFO    : Updated Thermal Rating: on line 74206-74224 : Rate B, Rate C - 0.0, 0.0 -> 247.56, 247.56
% INFO    : Updated Thermal Rating: on line 74206-74296 : Rate B, Rate C - 0.0, 0.0 -> 251.16, 251.16
% INFO    : Updated Thermal Rating: on line 74299-74206 : Rate B, Rate C - 0.0, 0.0 -> 209.5, 209.5
% INFO    : Updated Thermal Rating: on transformer 74207-74210 : Rate B, Rate C - 0.0, 0.0 -> 607.73, 607.73
% INFO    : Updated Thermal Rating: on transformer 74207-74211 : Rate B, Rate C - 0.0, 0.0 -> 489.14, 489.14
% INFO    : Updated Thermal Rating: on transformer 74207-74212 : Rate B, Rate C - 0.0, 0.0 -> 488.13, 488.13
% INFO    : Updated Thermal Rating: on transformer 74208-74210 : Rate B, Rate C - 0.0, 0.0 -> 532.73, 532.73
% INFO    : Updated Thermal Rating: on transformer 74209-74210 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 74213-74216 : Rate B, Rate C - 0.0, 0.0 -> 529.88, 529.88
% INFO    : Updated Thermal Rating: on transformer 74214-74216 : Rate B, Rate C - 0.0, 0.0 -> 427.05, 427.05
% INFO    : Updated Thermal Rating: on transformer 74215-74216 : Rate B, Rate C - 0.0, 0.0 -> 102.83, 102.83
% INFO    : Updated Thermal Rating: on line 74217-74272 : Rate B, Rate C - 0.0, 0.0 -> 1151.02, 1151.02
% INFO    : Updated Thermal Rating: on transformer 74219-74218 : Rate B, Rate C - 0.0, 0.0 -> 467.85, 467.85
% INFO    : Updated Thermal Rating: on transformer 74218-74220 : Rate B, Rate C - 0.0, 0.0 -> 383.93, 383.93
% INFO    : Updated Thermal Rating: on transformer 74218-74221 : Rate B, Rate C - 0.0, 0.0 -> 325.43, 325.43
% INFO    : Updated Thermal Rating: on transformer 74218-74222 : Rate B, Rate C - 0.0, 0.0 -> 121.43, 121.43
% INFO    : Updated Thermal Rating: on transformer 74224-74223 : Rate B, Rate C - 0.0, 0.0 -> 347.21, 347.21
% INFO    : Updated Thermal Rating: on line 74295-74223 : Rate B, Rate C - 0.0, 0.0 -> 1127.56, 1127.56
% INFO    : Updated Thermal Rating: on line 74225-74269 : Rate B, Rate C - 0.0, 0.0 -> 217.06, 217.06
% INFO    : Updated Thermal Rating: on line 74258-74227 : Rate B, Rate C - 0.0, 0.0 -> 180.86, 180.86
% INFO    : Updated Thermal Rating: on line 74227-74334 : Rate B, Rate C - 0.0, 0.0 -> 224.96, 224.96
% INFO    : Updated Thermal Rating: on transformer 74229-74232 : Rate B, Rate C - 0.0, 0.0 -> 204.47, 204.47
% INFO    : Updated Thermal Rating: on transformer 74229-74233 : Rate B, Rate C - 0.0, 0.0 -> 40.21, 40.21
% INFO    : Updated Thermal Rating: on line 74229-74331 : Rate B, Rate C - 0.0, 0.0 -> 191.83, 191.83
% INFO    : Updated Thermal Rating: on transformer 74230-74232 : Rate B, Rate C - 0.0, 0.0 -> 102.24, 102.24
% INFO    : Updated Thermal Rating: on transformer 74231-74232 : Rate B, Rate C - 0.0, 0.0 -> 102.24, 102.24
% INFO    : Updated Thermal Rating: on transformer 74235-74234 : Rate B, Rate C - 0.0, 0.0 -> 432.27, 432.27
% INFO    : Updated Thermal Rating: on transformer 74234-74236 : Rate B, Rate C - 0.0, 0.0 -> 382.75, 382.75
% INFO    : Updated Thermal Rating: on transformer 74234-74237 : Rate B, Rate C - 0.0, 0.0 -> 381.0, 381.0
% INFO    : Updated Thermal Rating: on transformer 74234-74238 : Rate B, Rate C - 0.0, 0.0 -> 380.07, 380.07
% INFO    : Updated Thermal Rating: on transformer 74234-74239 : Rate B, Rate C - 0.0, 0.0 -> 379.79, 379.79
% INFO    : Updated Thermal Rating: on line 77192-74234 : Rate B, Rate C - 0.0, 0.0 -> 1240.59, 1240.59
% INFO    : Updated Thermal Rating: on line 77272-74234 : Rate B, Rate C - 0.0, 0.0 -> 1142.46, 1142.46
% INFO    : Updated Thermal Rating: on line 74235-77168 : Rate B, Rate C - 0.0, 0.0 -> 180.2, 180.2
% INFO    : Updated Thermal Rating: on line 74235-77169 : Rate B, Rate C - 0.0, 0.0 -> 199.48, 199.48
% INFO    : Updated Thermal Rating: on line 74235-77180 : Rate B, Rate C - 0.0, 0.0 -> 204.16, 204.16
% INFO    : Updated Thermal Rating: on transformer 74244-74247 : Rate B, Rate C - 0.0, 0.0 -> 127.82, 127.82
% INFO    : Updated Thermal Rating: on transformer 74244-74248 : Rate B, Rate C - 0.0, 0.0 -> 18.01, 18.01
% INFO    : Updated Thermal Rating: on transformer 74245-74247 : Rate B, Rate C - 0.0, 0.0 -> 63.91, 63.91
% INFO    : Updated Thermal Rating: on transformer 74246-74247 : Rate B, Rate C - 0.0, 0.0 -> 63.91, 63.91
% INFO    : Updated Thermal Rating: on transformer 74251-74250 : Rate B, Rate C - 0.0, 0.0 -> 405.27, 405.27
% INFO    : Updated Thermal Rating: on transformer 74250-74252 : Rate B, Rate C - 0.0, 0.0 -> 455.8, 455.8
% INFO    : Updated Thermal Rating: on transformer 74250-74253 : Rate B, Rate C - 0.0, 0.0 -> 454.74, 454.74
% INFO    : Updated Thermal Rating: on transformer 74250-74254 : Rate B, Rate C - 0.0, 0.0 -> 453.63, 453.63
% INFO    : Updated Thermal Rating: on transformer 74250-74255 : Rate B, Rate C - 0.0, 0.0 -> 451.78, 451.78
% INFO    : Updated Thermal Rating: on transformer 74250-74256 : Rate B, Rate C - 0.0, 0.0 -> 451.2, 451.2
% INFO    : Updated Thermal Rating: on transformer 74258-74257 : Rate B, Rate C - 0.0, 0.0 -> 380.77, 380.77
% INFO    : Updated Thermal Rating: on transformer 74257-74260 : Rate B, Rate C - 0.0, 0.0 -> 230.1, 230.1
% INFO    : Updated Thermal Rating: on line 74295-74257 : Rate B, Rate C - 0.0, 0.0 -> 1157.4, 1157.4
% INFO    : Updated Thermal Rating: on transformer 74258-74259 : Rate B, Rate C - 0.0, 0.0 -> 77.18, 77.18
% INFO    : Updated Thermal Rating: on line 74258-74293 : Rate B, Rate C - 0.0, 0.0 -> 207.04, 207.04
% INFO    : Updated Thermal Rating: on line 74261-74334 : Rate B, Rate C - 0.0, 0.0 -> 190.86, 190.86
% INFO    : Updated Thermal Rating: on transformer 74262-74263 : Rate B, Rate C - 0.0, 0.0 -> 109.49, 109.49
% INFO    : Updated Thermal Rating: on transformer 74264-74265 : Rate B, Rate C - 0.0, 0.0 -> 16.51, 16.51
% INFO    : Updated Thermal Rating: on transformer 74264-74266 : Rate B, Rate C - 0.0, 0.0 -> 59.87, 59.87
% INFO    : Updated Thermal Rating: on line 74270-74281 : Rate B, Rate C - 0.0, 0.0 -> 166.4, 166.4
% INFO    : Updated Thermal Rating: on line 74296-74270 : Rate B, Rate C - 0.0, 0.0 -> 235.21, 235.21
% INFO    : Updated Thermal Rating: on transformer 74272-74275 : Rate B, Rate C - 0.0, 0.0 -> 436.78, 436.78
% INFO    : Updated Thermal Rating: on transformer 74272-74276 : Rate B, Rate C - 0.0, 0.0 -> 463.08, 463.08
% INFO    : Updated Thermal Rating: on transformer 74272-74277 : Rate B, Rate C - 0.0, 0.0 -> 462.78, 462.78
% INFO    : Updated Thermal Rating: on transformer 74272-74278 : Rate B, Rate C - 0.0, 0.0 -> 461.18, 461.18
% INFO    : Updated Thermal Rating: on transformer 74273-74275 : Rate B, Rate C - 0.0, 0.0 -> 378.85, 378.85
% INFO    : Updated Thermal Rating: on transformer 74274-74275 : Rate B, Rate C - 0.0, 0.0 -> 57.93, 57.93
% INFO    : Updated Thermal Rating: on transformer 74279-74280 : Rate B, Rate C - 0.0, 0.0 -> 155.61, 155.61
% INFO    : Updated Thermal Rating: on line 74309-74279 : Rate B, Rate C - 0.0, 0.0 -> 204.73, 204.73
% INFO    : Updated Thermal Rating: on transformer 74281-74282 : Rate B, Rate C - 0.0, 0.0 -> 43.38, 43.38
% INFO    : Updated Thermal Rating: on transformer 74281-74283 : Rate B, Rate C - 0.0, 0.0 -> 43.33, 43.33
% INFO    : Updated Thermal Rating: on line 74281-74296 : Rate B, Rate C - 0.0, 0.0 -> 238.07, 238.07
% INFO    : Updated Thermal Rating: on transformer 74287-74290 : Rate B, Rate C - 0.0, 0.0 -> 152.33, 152.33
% INFO    : Updated Thermal Rating: on transformer 74287-74291 : Rate B, Rate C - 0.0, 0.0 -> 17.55, 17.55
% INFO    : Updated Thermal Rating: on transformer 74287-74292 : Rate B, Rate C - 0.0, 0.0 -> 15.6, 15.6
% INFO    : Updated Thermal Rating: on transformer 74288-74290 : Rate B, Rate C - 0.0, 0.0 -> 76.17, 76.17
% INFO    : Updated Thermal Rating: on transformer 74289-74290 : Rate B, Rate C - 0.0, 0.0 -> 76.17, 76.17
% INFO    : Updated Thermal Rating: on transformer 74296-74295 : Rate B, Rate C - 0.0, 0.0 -> 315.63, 315.63
% INFO    : Updated Thermal Rating: on transformer 74297-74298 : Rate B, Rate C - 0.0, 0.0 -> 75.59, 75.59
% INFO    : Updated Thermal Rating: on transformer 74300-74301 : Rate B, Rate C - 0.0, 0.0 -> 18.2, 18.2
% INFO    : Updated Thermal Rating: on transformer 74300-74302 : Rate B, Rate C - 0.0, 0.0 -> 64.36, 64.36
% INFO    : Updated Thermal Rating: on line 74303-74312 : Rate B, Rate C - 0.0, 0.0 -> 215.84, 215.84
% INFO    : Updated Thermal Rating: on transformer 74304-74305 : Rate B, Rate C - 0.0, 0.0 -> 66.07, 66.07
% INFO    : Updated Thermal Rating: on transformer 74309-74308 : Rate B, Rate C - 0.0, 0.0 -> 392.87, 392.87
% INFO    : Updated Thermal Rating: on transformer 74308-74310 : Rate B, Rate C - 0.0, 0.0 -> 457.72, 457.72
% INFO    : Updated Thermal Rating: on transformer 74312-74311 : Rate B, Rate C - 0.0, 0.0 -> 406.31, 406.31
% INFO    : Updated Thermal Rating: on transformer 74311-74315 : Rate B, Rate C - 0.0, 0.0 -> 914.82, 914.82
% INFO    : Updated Thermal Rating: on line 74325-74311 : Rate B, Rate C - 0.0, 0.0 -> 1062.75, 1062.75
% INFO    : Updated Thermal Rating: on transformer 74312-74316 : Rate B, Rate C - 0.0, 0.0 -> 65.34, 65.34
% INFO    : Updated Thermal Rating: on transformer 74313-74315 : Rate B, Rate C - 0.0, 0.0 -> 457.41, 457.41
% INFO    : Updated Thermal Rating: on transformer 74314-74315 : Rate B, Rate C - 0.0, 0.0 -> 457.41, 457.41
% INFO    : Updated Thermal Rating: on transformer 74318-74317 : Rate B, Rate C - 0.0, 0.0 -> 275.05, 275.05
% INFO    : Updated Thermal Rating: on transformer 74319-74318 : Rate B, Rate C - 0.0, 0.0 -> 81.15, 81.15
% INFO    : Updated Thermal Rating: on transformer 74321-74322 : Rate B, Rate C - 0.0, 0.0 -> 93.8, 93.8
% INFO    : Updated Thermal Rating: on transformer 74324-74323 : Rate B, Rate C - 0.0, 0.0 -> 238.62, 238.62
% INFO    : Updated Thermal Rating: on transformer 74327-74326 : Rate B, Rate C - 0.0, 0.0 -> 461.62, 461.62
% INFO    : Updated Thermal Rating: on transformer 74326-74328 : Rate B, Rate C - 0.0, 0.0 -> 502.71, 502.71
% INFO    : Updated Thermal Rating: on transformer 74326-74329 : Rate B, Rate C - 0.0, 0.0 -> 502.59, 502.59
% INFO    : Updated Thermal Rating: on transformer 74331-74332 : Rate B, Rate C - 0.0, 0.0 -> 26.02, 26.02
% INFO    : Updated Thermal Rating: on transformer 74331-74333 : Rate B, Rate C - 0.0, 0.0 -> 21.45, 21.45
% INFO    : Updated Thermal Rating: on line 77003-77000 : Rate B, Rate C - 0.0, 0.0 -> 269.3, 269.3
% INFO    : Updated Thermal Rating: on line 77000-77255 : Rate B, Rate C - 0.0, 0.0 -> 274.54, 274.54
% INFO    : Updated Thermal Rating: on line 77001-77198 : Rate B, Rate C - 0.0, 0.0 -> 193.0, 193.0
% INFO    : Updated Thermal Rating: on line 77240-77001 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 77240-77001 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 77255-77001 : Rate B, Rate C - 0.0, 0.0 -> 205.39, 205.39
% INFO    : Updated Thermal Rating: on line 77004-77009 : Rate B, Rate C - 0.0, 0.0 -> 249.17, 249.17
% INFO    : Updated Thermal Rating: on line 77240-77004 : Rate B, Rate C - 0.0, 0.0 -> 252.75, 252.75
% INFO    : Updated Thermal Rating: on line 77005-77008 : Rate B, Rate C - 0.0, 0.0 -> 214.18, 214.18
% INFO    : Updated Thermal Rating: on line 77198-77005 : Rate B, Rate C - 0.0, 0.0 -> 265.27, 265.27
% INFO    : Updated Thermal Rating: on line 77007-77017 : Rate B, Rate C - 0.0, 0.0 -> 238.63, 238.63
% INFO    : Updated Thermal Rating: on line 77007-77283 : Rate B, Rate C - 0.0, 0.0 -> 242.26, 242.26
% INFO    : Updated Thermal Rating: on line 77017-77008 : Rate B, Rate C - 0.0, 0.0 -> 265.89, 265.89
% INFO    : Updated Thermal Rating: on line 77283-77008 : Rate B, Rate C - 0.0, 0.0 -> 255.29, 255.29
% INFO    : Updated Thermal Rating: on line 77009-77028 : Rate B, Rate C - 0.0, 0.0 -> 241.46, 241.46
% INFO    : Updated Thermal Rating: on line 77010-77013 : Rate B, Rate C - 0.0, 0.0 -> 209.98, 209.98
% INFO    : Updated Thermal Rating: on line 77010-77018 : Rate B, Rate C - 0.0, 0.0 -> 238.47, 238.47
% INFO    : Updated Thermal Rating: on line 77283-77010 : Rate B, Rate C - 0.0, 0.0 -> 260.3, 260.3
% INFO    : Updated Thermal Rating: on line 77013-77018 : Rate B, Rate C - 0.0, 0.0 -> 200.41, 200.41
% INFO    : Updated Thermal Rating: on line 77017-77014 : Rate B, Rate C - 0.0, 0.0 -> 248.46, 248.46
% INFO    : Updated Thermal Rating: on line 77014-77031 : Rate B, Rate C - 0.0, 0.0 -> 251.43, 251.43
% INFO    : Updated Thermal Rating: on line 77014-77210 : Rate B, Rate C - 0.0, 0.0 -> 238.76, 238.76
% INFO    : Updated Thermal Rating: on line 77026-77017 : Rate B, Rate C - 0.0, 0.0 -> 235.09, 235.09
% INFO    : Updated Thermal Rating: on line 77018-77024 : Rate B, Rate C - 0.0, 0.0 -> 227.23, 227.23
% INFO    : Updated Thermal Rating: on line 77247-77020 : Rate B, Rate C - 0.0, 0.0 -> 225.33, 225.33
% INFO    : Updated Thermal Rating: on line 77021-77210 : Rate B, Rate C - 0.0, 0.0 -> 247.93, 247.93
% INFO    : Updated Thermal Rating: on line 77021-77249 : Rate B, Rate C - 0.0, 0.0 -> 237.94, 237.94
% INFO    : Updated Thermal Rating: on line 77022-77023 : Rate B, Rate C - 0.0, 0.0 -> 210.63, 210.63
% INFO    : Updated Thermal Rating: on line 77022-77032 : Rate B, Rate C - 0.0, 0.0 -> 241.89, 241.89
% INFO    : Updated Thermal Rating: on line 77210-77022 : Rate B, Rate C - 0.0, 0.0 -> 259.42, 259.42
% INFO    : Updated Thermal Rating: on line 77247-77022 : Rate B, Rate C - 0.0, 0.0 -> 237.85, 237.85
% INFO    : Updated Thermal Rating: on line 77024-77023 : Rate B, Rate C - 0.0, 0.0 -> 191.18, 191.18
% INFO    : Updated Thermal Rating: on line 77023-77032 : Rate B, Rate C - 0.0, 0.0 -> 249.61, 249.61
% INFO    : Updated Thermal Rating: on line 77023-77210 : Rate B, Rate C - 0.0, 0.0 -> 253.15, 253.15
% INFO    : Updated Thermal Rating: on line 77028-77025 : Rate B, Rate C - 0.0, 0.0 -> 238.14, 238.14
% INFO    : Updated Thermal Rating: on line 77025-77033 : Rate B, Rate C - 0.0, 0.0 -> 232.49, 232.49
% INFO    : Updated Thermal Rating: on line 77026-77030 : Rate B, Rate C - 0.0, 0.0 -> 221.19, 221.19
% INFO    : Updated Thermal Rating: on line 77026-77031 : Rate B, Rate C - 0.0, 0.0 -> 245.37, 245.37
% INFO    : Updated Thermal Rating: on line 77026-77247 : Rate B, Rate C - 0.0, 0.0 -> 251.4, 251.4
% INFO    : Updated Thermal Rating: on line 77031-77029 : Rate B, Rate C - 0.0, 0.0 -> 284.0, 284.0
% INFO    : Updated Thermal Rating: on line 77029-77038 : Rate B, Rate C - 0.0, 0.0 -> 280.97, 280.97
% INFO    : Updated Thermal Rating: on line 77030-77032 : Rate B, Rate C - 0.0, 0.0 -> 211.07, 211.07
% INFO    : Updated Thermal Rating: on line 77039-77032 : Rate B, Rate C - 0.0, 0.0 -> 250.67, 250.67
% INFO    : Updated Thermal Rating: on line 77032-77044 : Rate B, Rate C - 0.0, 0.0 -> 253.75, 253.75
% INFO    : Updated Thermal Rating: on line 77033-77040 : Rate B, Rate C - 0.0, 0.0 -> 228.53, 228.53
% INFO    : Updated Thermal Rating: on line 77035-77043 : Rate B, Rate C - 0.0, 0.0 -> 174.48, 174.48
% INFO    : Updated Thermal Rating: on line 77249-77035 : Rate B, Rate C - 0.0, 0.0 -> 202.54, 202.54
% INFO    : Updated Thermal Rating: on line 77039-77208 : Rate B, Rate C - 0.0, 0.0 -> 249.97, 249.97
% INFO    : Updated Thermal Rating: on line 77040-77042 : Rate B, Rate C - 0.0, 0.0 -> 191.78, 191.78
% INFO    : Updated Thermal Rating: on line 77042-77049 : Rate B, Rate C - 0.0, 0.0 -> 178.77, 178.77
% INFO    : Updated Thermal Rating: on line 77043-77208 : Rate B, Rate C - 0.0, 0.0 -> 191.15, 191.15
% INFO    : Updated Thermal Rating: on line 77249-77043 : Rate B, Rate C - 0.0, 0.0 -> 205.67, 205.67
% INFO    : Updated Thermal Rating: on line 77044-77046 : Rate B, Rate C - 0.0, 0.0 -> 262.37, 262.37
% INFO    : Updated Thermal Rating: on line 77249-77044 : Rate B, Rate C - 0.0, 0.0 -> 206.04, 206.04
% INFO    : Updated Thermal Rating: on line 77065-77046 : Rate B, Rate C - 0.0, 0.0 -> 259.84, 259.84
% INFO    : Updated Thermal Rating: on line 77048-77052 : Rate B, Rate C - 0.0, 0.0 -> 233.46, 233.46
% INFO    : Updated Thermal Rating: on line 77061-77048 : Rate B, Rate C - 0.0, 0.0 -> 204.44, 204.44
% INFO    : Updated Thermal Rating: on line 77049-77267 : Rate B, Rate C - 0.0, 0.0 -> 174.34, 174.34
% INFO    : Updated Thermal Rating: on line 77069-77050 : Rate B, Rate C - 0.0, 0.0 -> 189.67, 189.67
% INFO    : Updated Thermal Rating: on line 77050-77201 : Rate B, Rate C - 0.0, 0.0 -> 200.87, 200.87
% INFO    : Updated Thermal Rating: on transformer 77052-77051 : Rate B, Rate C - 0.0, 0.0 -> 493.71, 493.71
% INFO    : Updated Thermal Rating: on line 77209-77051 : Rate B, Rate C - 0.0, 0.0 -> 1331.96, 1331.96
% INFO    : Updated Thermal Rating: on line 77051-77230 : Rate B, Rate C - 0.0, 0.0 -> 1135.51, 1135.51
% INFO    : Updated Thermal Rating: on line 77052-77055 : Rate B, Rate C - 0.0, 0.0 -> 264.8, 264.8
% INFO    : Updated Thermal Rating: on line 77052-77064 : Rate B, Rate C - 0.0, 0.0 -> 250.16, 250.16
% INFO    : Updated Thermal Rating: on line 77052-77083 : Rate B, Rate C - 0.0, 0.0 -> 203.85, 203.85
% INFO    : Updated Thermal Rating: on line 77055-77058 : Rate B, Rate C - 0.0, 0.0 -> 246.81, 246.81
% INFO    : Updated Thermal Rating: on line 77056-77093 : Rate B, Rate C - 0.0, 0.0 -> 163.54, 163.54
% INFO    : Updated Thermal Rating: on line 77056-77203 : Rate B, Rate C - 0.0, 0.0 -> 185.42, 185.42
% INFO    : Updated Thermal Rating: on line 77081-77057 : Rate B, Rate C - 0.0, 0.0 -> 219.73, 219.73
% INFO    : Updated Thermal Rating: on line 77057-77201 : Rate B, Rate C - 0.0, 0.0 -> 223.38, 223.38
% INFO    : Updated Thermal Rating: on line 77061-77058 : Rate B, Rate C - 0.0, 0.0 -> 215.75, 215.75
% INFO    : Updated Thermal Rating: on line 77061-77078 : Rate B, Rate C - 0.0, 0.0 -> 231.92, 231.92
% INFO    : Updated Thermal Rating: on line 77061-77091 : Rate B, Rate C - 0.0, 0.0 -> 253.06, 253.06
% INFO    : Updated Thermal Rating: on line 77063-77078 : Rate B, Rate C - 0.0, 0.0 -> 229.61, 229.61
% INFO    : Updated Thermal Rating: on line 77208-77063 : Rate B, Rate C - 0.0, 0.0 -> 258.51, 258.51
% INFO    : Updated Thermal Rating: on line 77065-77064 : Rate B, Rate C - 0.0, 0.0 -> 247.69, 247.69
% INFO    : Updated Thermal Rating: on line 77065-77091 : Rate B, Rate C - 0.0, 0.0 -> 244.24, 244.24
% INFO    : Updated Thermal Rating: on line 77067-77069 : Rate B, Rate C - 0.0, 0.0 -> 239.63, 239.63
% INFO    : Updated Thermal Rating: on line 77067-77086 : Rate B, Rate C - 0.0, 0.0 -> 166.48, 166.48
% INFO    : Updated Thermal Rating: on line 77267-77067 : Rate B, Rate C - 0.0, 0.0 -> 232.72, 232.72
% INFO    : Updated Thermal Rating: on line 77067-77292 : Rate B, Rate C - 0.0, 0.0 -> 225.35, 225.35
% INFO    : Updated Thermal Rating: on line 77069-77096 : Rate B, Rate C - 0.0, 0.0 -> 219.02, 219.02
% INFO    : Updated Thermal Rating: on line 77070-77269 : Rate B, Rate C - 0.0, 0.0 -> 193.9, 193.9
% INFO    : Updated Thermal Rating: on line 77070-77292 : Rate B, Rate C - 0.0, 0.0 -> 201.49, 201.49
% INFO    : Updated Thermal Rating: on transformer 77072-77075 : Rate B, Rate C - 0.0, 0.0 -> 87.24, 87.24
% INFO    : Updated Thermal Rating: on transformer 77073-77075 : Rate B, Rate C - 0.0, 0.0 -> 43.62, 43.62
% INFO    : Updated Thermal Rating: on transformer 77074-77075 : Rate B, Rate C - 0.0, 0.0 -> 43.62, 43.62
% INFO    : Updated Thermal Rating: on line 77076-77267 : Rate B, Rate C - 0.0, 0.0 -> 191.94, 191.94
% INFO    : Updated Thermal Rating: on line 77292-77076 : Rate B, Rate C - 0.0, 0.0 -> 198.52, 198.52
% INFO    : Updated Thermal Rating: on line 77077-77201 : Rate B, Rate C - 0.0, 0.0 -> 179.31, 179.31
% INFO    : Updated Thermal Rating: on line 77077-77290 : Rate B, Rate C - 0.0, 0.0 -> 223.86, 223.86
% INFO    : Updated Thermal Rating: on line 77078-77083 : Rate B, Rate C - 0.0, 0.0 -> 195.45, 195.45
% INFO    : Updated Thermal Rating: on line 77102-77081 : Rate B, Rate C - 0.0, 0.0 -> 205.65, 205.65
% INFO    : Updated Thermal Rating: on line 77086-77231 : Rate B, Rate C - 0.0, 0.0 -> 185.97, 185.97
% INFO    : Updated Thermal Rating: on transformer 77087-77090 : Rate B, Rate C - 0.0, 0.0 -> 153.38, 153.38
% INFO    : Updated Thermal Rating: on transformer 77088-77090 : Rate B, Rate C - 0.0, 0.0 -> 76.69, 76.69
% INFO    : Updated Thermal Rating: on transformer 77089-77090 : Rate B, Rate C - 0.0, 0.0 -> 76.69, 76.69
% INFO    : Updated Thermal Rating: on line 77104-77091 : Rate B, Rate C - 0.0, 0.0 -> 170.77, 170.77
% INFO    : Updated Thermal Rating: on line 77203-77093 : Rate B, Rate C - 0.0, 0.0 -> 181.85, 181.85
% INFO    : Updated Thermal Rating: on line 77093-77281 : Rate B, Rate C - 0.0, 0.0 -> 180.7, 180.7
% INFO    : Updated Thermal Rating: on line 77096-77271 : Rate B, Rate C - 0.0, 0.0 -> 208.93, 208.93
% INFO    : Updated Thermal Rating: on line 77099-77101 : Rate B, Rate C - 0.0, 0.0 -> 222.08, 222.08
% INFO    : Updated Thermal Rating: on line 77229-77099 : Rate B, Rate C - 0.0, 0.0 -> 234.23, 234.23
% INFO    : Updated Thermal Rating: on line 77112-77100 : Rate B, Rate C - 0.0, 0.0 -> 197.92, 197.92
% INFO    : Updated Thermal Rating: on line 77100-77281 : Rate B, Rate C - 0.0, 0.0 -> 208.89, 208.89
% INFO    : Updated Thermal Rating: on line 77101-77110 : Rate B, Rate C - 0.0, 0.0 -> 218.31, 218.31
% INFO    : Updated Thermal Rating: on line 77229-77101 : Rate B, Rate C - 0.0, 0.0 -> 230.62, 230.62
% INFO    : Updated Thermal Rating: on line 77110-77102 : Rate B, Rate C - 0.0, 0.0 -> 186.35, 186.35
% INFO    : Updated Thermal Rating: on line 77108-77104 : Rate B, Rate C - 0.0, 0.0 -> 243.66, 243.66
% INFO    : Updated Thermal Rating: on line 77104-77120 : Rate B, Rate C - 0.0, 0.0 -> 238.83, 238.83
% INFO    : Updated Thermal Rating: on line 77115-77108 : Rate B, Rate C - 0.0, 0.0 -> 210.19, 210.19
% INFO    : Updated Thermal Rating: on line 77108-77264 : Rate B, Rate C - 0.0, 0.0 -> 229.59, 229.59
% INFO    : Updated Thermal Rating: on line 77110-77109 : Rate B, Rate C - 0.0, 0.0 -> 186.89, 186.89
% INFO    : Updated Thermal Rating: on line 77109-77229 : Rate B, Rate C - 0.0, 0.0 -> 210.14, 210.14
% INFO    : Updated Thermal Rating: on line 77113-77112 : Rate B, Rate C - 0.0, 0.0 -> 189.37, 189.37
% INFO    : Updated Thermal Rating: on line 77231-77113 : Rate B, Rate C - 0.0, 0.0 -> 181.71, 181.71
% INFO    : Updated Thermal Rating: on line 77115-77114 : Rate B, Rate C - 0.0, 0.0 -> 198.78, 198.78
% INFO    : Updated Thermal Rating: on line 77114-77119 : Rate B, Rate C - 0.0, 0.0 -> 198.32, 198.32
% INFO    : Updated Thermal Rating: on line 77194-77114 : Rate B, Rate C - 0.0, 0.0 -> 229.85, 229.85
% INFO    : Updated Thermal Rating: on line 77115-77264 : Rate B, Rate C - 0.0, 0.0 -> 253.77, 253.77
% INFO    : Updated Thermal Rating: on line 77281-77116 : Rate B, Rate C - 0.0, 0.0 -> 168.85, 168.85
% INFO    : Updated Thermal Rating: on line 77288-77116 : Rate B, Rate C - 0.0, 0.0 -> 188.49, 188.49
% INFO    : Updated Thermal Rating: on line 77118-77125 : Rate B, Rate C - 0.0, 0.0 -> 240.23, 240.23
% INFO    : Updated Thermal Rating: on line 77118-77271 : Rate B, Rate C - 0.0, 0.0 -> 244.47, 244.47
% INFO    : Updated Thermal Rating: on line 77119-77194 : Rate B, Rate C - 0.0, 0.0 -> 212.43, 212.43
% INFO    : Updated Thermal Rating: on line 77121-77222 : Rate B, Rate C - 0.0, 0.0 -> 220.84, 220.84
% INFO    : Updated Thermal Rating: on line 77121-77281 : Rate B, Rate C - 0.0, 0.0 -> 237.09, 237.09
% INFO    : Updated Thermal Rating: on line 77122-77123 : Rate B, Rate C - 0.0, 0.0 -> 247.36, 247.36
% INFO    : Updated Thermal Rating: on line 77122-77194 : Rate B, Rate C - 0.0, 0.0 -> 254.13, 254.13
% INFO    : Updated Thermal Rating: on line 77123-77163 : Rate B, Rate C - 0.0, 0.0 -> 243.51, 243.51
% INFO    : Updated Thermal Rating: on line 77125-77128 : Rate B, Rate C - 0.0, 0.0 -> 176.19, 176.19
% INFO    : Updated Thermal Rating: on line 77125-77141 : Rate B, Rate C - 0.0, 0.0 -> 232.72, 232.72
% INFO    : Updated Thermal Rating: on line 77126-77134 : Rate B, Rate C - 0.0, 0.0 -> 206.88, 206.88
% INFO    : Updated Thermal Rating: on line 77128-77165 : Rate B, Rate C - 0.0, 0.0 -> 197.4, 197.4
% INFO    : Updated Thermal Rating: on line 77131-77140 : Rate B, Rate C - 0.0, 0.0 -> 190.06, 190.06
% INFO    : Updated Thermal Rating: on line 77131-77141 : Rate B, Rate C - 0.0, 0.0 -> 196.87, 196.87
% INFO    : Updated Thermal Rating: on line 77131-77142 : Rate B, Rate C - 0.0, 0.0 -> 197.78, 197.78
% INFO    : Updated Thermal Rating: on transformer 77134-77133 : Rate B, Rate C - 0.0, 0.0 -> 476.74, 476.74
% INFO    : Updated Thermal Rating: on line 77133-77227 : Rate B, Rate C - 0.0, 0.0 -> 1183.97, 1183.97
% INFO    : Updated Thermal Rating: on line 77140-77134 : Rate B, Rate C - 0.0, 0.0 -> 241.79, 241.79
% INFO    : Updated Thermal Rating: on line 77142-77134 : Rate B, Rate C - 0.0, 0.0 -> 223.73, 223.73
% INFO    : Updated Thermal Rating: on line 77144-77134 : Rate B, Rate C - 0.0, 0.0 -> 235.26, 235.26
% INFO    : Updated Thermal Rating: on line 77155-77135 : Rate B, Rate C - 0.0, 0.0 -> 213.26, 213.26
% INFO    : Updated Thermal Rating: on line 77160-77135 : Rate B, Rate C - 0.0, 0.0 -> 200.41, 200.41
% INFO    : Updated Thermal Rating: on line 77146-77139 : Rate B, Rate C - 0.0, 0.0 -> 212.79, 212.79
% INFO    : Updated Thermal Rating: on line 77139-77148 : Rate B, Rate C - 0.0, 0.0 -> 225.22, 225.22
% INFO    : Updated Thermal Rating: on line 77147-77140 : Rate B, Rate C - 0.0, 0.0 -> 193.03, 193.03
% INFO    : Updated Thermal Rating: on line 77144-77155 : Rate B, Rate C - 0.0, 0.0 -> 218.49, 218.49
% INFO    : Updated Thermal Rating: on line 77146-77147 : Rate B, Rate C - 0.0, 0.0 -> 208.66, 208.66
% INFO    : Updated Thermal Rating: on line 77152-77148 : Rate B, Rate C - 0.0, 0.0 -> 220.01, 220.01
% INFO    : Updated Thermal Rating: on line 77148-77157 : Rate B, Rate C - 0.0, 0.0 -> 202.52, 202.52
% INFO    : Updated Thermal Rating: on line 77233-77148 : Rate B, Rate C - 0.0, 0.0 -> 230.11, 230.11
% INFO    : Updated Thermal Rating: on line 77150-77164 : Rate B, Rate C - 0.0, 0.0 -> 226.1, 226.1
% INFO    : Updated Thermal Rating: on line 77222-77150 : Rate B, Rate C - 0.0, 0.0 -> 249.28, 249.28
% INFO    : Updated Thermal Rating: on line 77154-77152 : Rate B, Rate C - 0.0, 0.0 -> 171.99, 171.99
% INFO    : Updated Thermal Rating: on line 77233-77152 : Rate B, Rate C - 0.0, 0.0 -> 240.16, 240.16
% INFO    : Updated Thermal Rating: on line 77169-77154 : Rate B, Rate C - 0.0, 0.0 -> 187.85, 187.85
% INFO    : Updated Thermal Rating: on line 77163-77155 : Rate B, Rate C - 0.0, 0.0 -> 226.44, 226.44
% INFO    : Updated Thermal Rating: on line 77157-77167 : Rate B, Rate C - 0.0, 0.0 -> 196.36, 196.36
% INFO    : Updated Thermal Rating: on line 77165-77164 : Rate B, Rate C - 0.0, 0.0 -> 196.44, 196.44
% INFO    : Updated Thermal Rating: on line 77165-77222 : Rate B, Rate C - 0.0, 0.0 -> 255.97, 255.97
% INFO    : Updated Thermal Rating: on line 77167-77177 : Rate B, Rate C - 0.0, 0.0 -> 186.93, 186.93
% INFO    : Updated Thermal Rating: on line 77222-77168 : Rate B, Rate C - 0.0, 0.0 -> 214.9, 214.9
% INFO    : Updated Thermal Rating: on line 77253-77170 : Rate B, Rate C - 0.0, 0.0 -> 220.94, 220.94
% INFO    : Updated Thermal Rating: on line 77186-77174 : Rate B, Rate C - 0.0, 0.0 -> 210.57, 210.57
% INFO    : Updated Thermal Rating: on line 77253-77179 : Rate B, Rate C - 0.0, 0.0 -> 296.65, 296.65
% INFO    : Updated Thermal Rating: on line 77184-77180 : Rate B, Rate C - 0.0, 0.0 -> 248.91, 248.91
% INFO    : Updated Thermal Rating: on line 77180-77186 : Rate B, Rate C - 0.0, 0.0 -> 408.31, 408.31
% INFO    : Updated Thermal Rating: on line 77273-77183 : Rate B, Rate C - 0.0, 0.0 -> 238.43, 238.43
% INFO    : Updated Thermal Rating: on transformer 77186-77185 : Rate B, Rate C - 0.0, 0.0 -> 426.67, 426.67
% INFO    : Updated Thermal Rating: on transformer 77185-77187 : Rate B, Rate C - 0.0, 0.0 -> 431.37, 431.37
% INFO    : Updated Thermal Rating: on transformer 77185-77188 : Rate B, Rate C - 0.0, 0.0 -> 425.28, 425.28
% INFO    : Updated Thermal Rating: on transformer 77185-77189 : Rate B, Rate C - 0.0, 0.0 -> 423.52, 423.52
% INFO    : Updated Thermal Rating: on transformer 77185-77190 : Rate B, Rate C - 0.0, 0.0 -> 423.11, 423.11
% INFO    : Updated Thermal Rating: on transformer 77185-77191 : Rate B, Rate C - 0.0, 0.0 -> 422.71, 422.71
% INFO    : Updated Thermal Rating: on transformer 77194-77193 : Rate B, Rate C - 0.0, 0.0 -> 447.9, 447.9
% INFO    : Updated Thermal Rating: on transformer 77193-77195 : Rate B, Rate C - 0.0, 0.0 -> 386.79, 386.79
% INFO    : Updated Thermal Rating: on transformer 77193-77196 : Rate B, Rate C - 0.0, 0.0 -> 386.61, 386.61
% INFO    : Updated Thermal Rating: on transformer 77193-77197 : Rate B, Rate C - 0.0, 0.0 -> 386.32, 386.32
% INFO    : Updated Thermal Rating: on line 77230-77193 : Rate B, Rate C - 0.0, 0.0 -> 994.38, 994.38
% INFO    : Updated Thermal Rating: on transformer 77198-77199 : Rate B, Rate C - 0.0, 0.0 -> 80.58, 80.58
% INFO    : Updated Thermal Rating: on line 77255-77198 : Rate B, Rate C - 0.0, 0.0 -> 256.54, 256.54
% INFO    : Updated Thermal Rating: on line 77201-77269 : Rate B, Rate C - 0.0, 0.0 -> 226.83, 226.83
% INFO    : Updated Thermal Rating: on transformer 77203-77202 : Rate B, Rate C - 0.0, 0.0 -> 286.09, 286.09
% INFO    : Updated Thermal Rating: on transformer 77202-77204 : Rate B, Rate C - 0.0, 0.0 -> 436.07, 436.07
% INFO    : Updated Thermal Rating: on line 77268-77202 : Rate B, Rate C - 0.0, 0.0 -> 1057.28, 1057.28
% INFO    : Updated Thermal Rating: on line 77202-77287 : Rate B, Rate C - 0.0, 0.0 -> 1066.18, 1066.18
% INFO    : Updated Thermal Rating: on line 77281-77203 : Rate B, Rate C - 0.0, 0.0 -> 161.66, 161.66
% INFO    : Updated Thermal Rating: on transformer 77206-77207 : Rate B, Rate C - 0.0, 0.0 -> 32.18, 32.18
% INFO    : Updated Thermal Rating: on transformer 77209-77212 : Rate B, Rate C - 0.0, 0.0 -> 668.47, 668.47
% INFO    : Updated Thermal Rating: on transformer 77209-77213 : Rate B, Rate C - 0.0, 0.0 -> 506.74, 506.74
% INFO    : Updated Thermal Rating: on line 77209-77220 : Rate B, Rate C - 0.0, 0.0 -> 1198.99, 1198.99
% INFO    : Updated Thermal Rating: on line 77282-77209 : Rate B, Rate C - 0.0, 0.0 -> 1288.28, 1288.28
% INFO    : Updated Thermal Rating: on transformer 77210-77212 : Rate B, Rate C - 0.0, 0.0 -> 568.47, 568.47
% INFO    : Updated Thermal Rating: on line 77247-77210 : Rate B, Rate C - 0.0, 0.0 -> 258.68, 258.68
% INFO    : Updated Thermal Rating: on transformer 77211-77212 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 77215-77214 : Rate B, Rate C - 0.0, 0.0 -> 562.43, 562.43
% INFO    : Updated Thermal Rating: on transformer 77214-77216 : Rate B, Rate C - 0.0, 0.0 -> 375.93, 375.93
% INFO    : Updated Thermal Rating: on transformer 77214-77217 : Rate B, Rate C - 0.0, 0.0 -> 374.67, 374.67
% INFO    : Updated Thermal Rating: on transformer 77214-77218 : Rate B, Rate C - 0.0, 0.0 -> 373.59, 373.59
% INFO    : Updated Thermal Rating: on transformer 77214-77219 : Rate B, Rate C - 0.0, 0.0 -> 373.39, 373.39
% INFO    : Updated Thermal Rating: on line 77220-77254 : Rate B, Rate C - 0.0, 0.0 -> 1348.35, 1348.35
% INFO    : Updated Thermal Rating: on transformer 77222-77221 : Rate B, Rate C - 0.0, 0.0 -> 439.99, 439.99
% INFO    : Updated Thermal Rating: on transformer 77221-77223 : Rate B, Rate C - 0.0, 0.0 -> 439.3, 439.3
% INFO    : Updated Thermal Rating: on transformer 77221-77224 : Rate B, Rate C - 0.0, 0.0 -> 437.49, 437.49
% INFO    : Updated Thermal Rating: on transformer 77221-77225 : Rate B, Rate C - 0.0, 0.0 -> 436.7, 436.7
% INFO    : Updated Thermal Rating: on transformer 77221-77226 : Rate B, Rate C - 0.0, 0.0 -> 436.53, 436.53
% INFO    : Updated Thermal Rating: on line 77227-77252 : Rate B, Rate C - 0.0, 0.0 -> 1075.67, 1075.67
% INFO    : Updated Thermal Rating: on line 77227-77287 : Rate B, Rate C - 0.0, 0.0 -> 1124.28, 1124.28
% INFO    : Updated Thermal Rating: on transformer 77229-77228 : Rate B, Rate C - 0.0, 0.0 -> 403.96, 403.96
% INFO    : Updated Thermal Rating: on line 77230-77263 : Rate B, Rate C - 0.0, 0.0 -> 1085.2, 1085.2
% INFO    : Updated Thermal Rating: on line 77268-77230 : Rate B, Rate C - 0.0, 0.0 -> 1046.22, 1046.22
% INFO    : Updated Thermal Rating: on transformer 77232-77235 : Rate B, Rate C - 0.0, 0.0 -> 529.83, 529.83
% INFO    : Updated Thermal Rating: on transformer 77232-77236 : Rate B, Rate C - 0.0, 0.0 -> 393.26, 393.26
% INFO    : Updated Thermal Rating: on transformer 77232-77237 : Rate B, Rate C - 0.0, 0.0 -> 393.05, 393.05
% INFO    : Updated Thermal Rating: on transformer 77232-77238 : Rate B, Rate C - 0.0, 0.0 -> 392.7, 392.7
% INFO    : Updated Thermal Rating: on line 77252-77232 : Rate B, Rate C - 0.0, 0.0 -> 1079.28, 1079.28
% INFO    : Updated Thermal Rating: on transformer 77233-77235 : Rate B, Rate C - 0.0, 0.0 -> 404.83, 404.83
% INFO    : Updated Thermal Rating: on transformer 77234-77235 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 77239-77242 : Rate B, Rate C - 0.0, 0.0 -> 515.29, 515.29
% INFO    : Updated Thermal Rating: on transformer 77239-77243 : Rate B, Rate C - 0.0, 0.0 -> 396.26, 396.26
% INFO    : Updated Thermal Rating: on transformer 77239-77244 : Rate B, Rate C - 0.0, 0.0 -> 395.94, 395.94
% INFO    : Updated Thermal Rating: on transformer 77239-77245 : Rate B, Rate C - 0.0, 0.0 -> 318.44, 318.44
% INFO    : Updated Thermal Rating: on transformer 77240-77242 : Rate B, Rate C - 0.0, 0.0 -> 390.29, 390.29
% INFO    : Updated Thermal Rating: on transformer 77241-77242 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on transformer 77247-77248 : Rate B, Rate C - 0.0, 0.0 -> 103.93, 103.93
% INFO    : Updated Thermal Rating: on transformer 77249-77250 : Rate B, Rate C - 0.0, 0.0 -> 13.0, 13.0
% INFO    : Updated Thermal Rating: on transformer 77249-77251 : Rate B, Rate C - 0.0, 0.0 -> 13.0, 13.0
% INFO    : Updated Thermal Rating: on transformer 77253-77252 : Rate B, Rate C - 0.0, 0.0 -> 408.5, 408.5
% INFO    : Updated Thermal Rating: on line 77252-77272 : Rate B, Rate C - 0.0, 0.0 -> 1036.92, 1036.92
% INFO    : Updated Thermal Rating: on transformer 77254-77257 : Rate B, Rate C - 0.0, 0.0 -> 583.2, 583.2
% INFO    : Updated Thermal Rating: on transformer 77254-77258 : Rate B, Rate C - 0.0, 0.0 -> 738.4, 738.4
% INFO    : Updated Thermal Rating: on transformer 77254-77259 : Rate B, Rate C - 0.0, 0.0 -> 738.4, 738.4
% INFO    : Updated Thermal Rating: on transformer 77254-77260 : Rate B, Rate C - 0.0, 0.0 -> 738.4, 738.4
% INFO    : Updated Thermal Rating: on transformer 77254-77261 : Rate B, Rate C - 0.0, 0.0 -> 738.4, 738.4
% INFO    : Updated Thermal Rating: on line 77254-77282 : Rate B, Rate C - 0.0, 0.0 -> 1310.31, 1310.31
% INFO    : Updated Thermal Rating: on transformer 77255-77257 : Rate B, Rate C - 0.0, 0.0 -> 483.2, 483.2
% INFO    : Updated Thermal Rating: on transformer 77256-77257 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 77263-77266 : Rate B, Rate C - 0.0, 0.0 -> 433.25, 433.25
% INFO    : Updated Thermal Rating: on transformer 77264-77266 : Rate B, Rate C - 0.0, 0.0 -> 383.25, 383.25
% INFO    : Updated Thermal Rating: on transformer 77265-77266 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 77269-77267 : Rate B, Rate C - 0.0, 0.0 -> 174.02, 174.02
% INFO    : Updated Thermal Rating: on transformer 77269-77268 : Rate B, Rate C - 0.0, 0.0 -> 339.01, 339.01
% INFO    : Updated Thermal Rating: on transformer 77273-77272 : Rate B, Rate C - 0.0, 0.0 -> 364.4, 364.4
% INFO    : Updated Thermal Rating: on transformer 77272-77274 : Rate B, Rate C - 0.0, 0.0 -> 435.22, 435.22
% INFO    : Updated Thermal Rating: on transformer 77272-77275 : Rate B, Rate C - 0.0, 0.0 -> 435.05, 435.05
% INFO    : Updated Thermal Rating: on transformer 77272-77276 : Rate B, Rate C - 0.0, 0.0 -> 434.95, 434.95
% INFO    : Updated Thermal Rating: on transformer 77272-77277 : Rate B, Rate C - 0.0, 0.0 -> 434.5, 434.5
% INFO    : Updated Thermal Rating: on transformer 77272-77278 : Rate B, Rate C - 0.0, 0.0 -> 434.25, 434.25
% INFO    : Updated Thermal Rating: on transformer 77279-77280 : Rate B, Rate C - 0.0, 0.0 -> 134.55, 134.55
% INFO    : Updated Thermal Rating: on transformer 77282-77285 : Rate B, Rate C - 0.0, 0.0 -> 567.7, 567.7
% INFO    : Updated Thermal Rating: on transformer 77282-77286 : Rate B, Rate C - 0.0, 0.0 -> 450.47, 450.47
% INFO    : Updated Thermal Rating: on transformer 77283-77285 : Rate B, Rate C - 0.0, 0.0 -> 492.7, 492.7
% INFO    : Updated Thermal Rating: on transformer 77284-77285 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 77288-77287 : Rate B, Rate C - 0.0, 0.0 -> 279.82, 279.82
% INFO    : Updated Thermal Rating: on transformer 77287-77289 : Rate B, Rate C - 0.0, 0.0 -> 516.95, 516.95
% INFO    : Updated Thermal Rating: on line 77290-77295 : Rate B, Rate C - 0.0, 0.0 -> 188.83, 188.83
% INFO    : Updated Thermal Rating: on line 77295-77292 : Rate B, Rate C - 0.0, 0.0 -> 220.52, 220.52
% INFO    : Updated Thermal Rating: on line 80021-80003 : Rate B, Rate C - 0.0, 0.0 -> 162.7, 162.7
% INFO    : Updated Thermal Rating: on line 80012-80004 : Rate B, Rate C - 0.0, 0.0 -> 115.35, 115.35
% INFO    : Updated Thermal Rating: on line 80005-80085 : Rate B, Rate C - 0.0, 0.0 -> 168.55, 168.55
% INFO    : Updated Thermal Rating: on transformer 80007-80006 : Rate B, Rate C - 0.0, 0.0 -> 261.1, 261.1
% INFO    : Updated Thermal Rating: on transformer 80007-80006 : Rate B, Rate C - 0.0, 0.0 -> 261.1, 261.1
% INFO    : Updated Thermal Rating: on transformer 80007-80006 : Rate B, Rate C - 0.0, 0.0 -> 261.1, 261.1
% INFO    : Updated Thermal Rating: on line 80087-80006 : Rate B, Rate C - 0.0, 0.0 -> 509.43, 509.43
% INFO    : Updated Thermal Rating: on line 80007-80011 : Rate B, Rate C - 0.0, 0.0 -> 205.73, 205.73
% INFO    : Updated Thermal Rating: on line 80012-80007 : Rate B, Rate C - 0.0, 0.0 -> 158.34, 158.34
% INFO    : Updated Thermal Rating: on line 80007-80025 : Rate B, Rate C - 0.0, 0.0 -> 183.24, 183.24
% INFO    : Updated Thermal Rating: on line 80007-80030 : Rate B, Rate C - 0.0, 0.0 -> 191.24, 191.24
% INFO    : Updated Thermal Rating: on line 80008-80010 : Rate B, Rate C - 0.0, 0.0 -> 169.05, 169.05
% INFO    : Updated Thermal Rating: on line 80008-80025 : Rate B, Rate C - 0.0, 0.0 -> 174.72, 174.72
% INFO    : Updated Thermal Rating: on line 80008-80032 : Rate B, Rate C - 0.0, 0.0 -> 160.13, 160.13
% INFO    : Updated Thermal Rating: on line 80011-80036 : Rate B, Rate C - 0.0, 0.0 -> 180.88, 180.88
% INFO    : Updated Thermal Rating: on line 80013-80032 : Rate B, Rate C - 0.0, 0.0 -> 154.0, 154.0
% INFO    : Updated Thermal Rating: on line 80016-80024 : Rate B, Rate C - 0.0, 0.0 -> 140.14, 140.14
% INFO    : Updated Thermal Rating: on line 80016-80085 : Rate B, Rate C - 0.0, 0.0 -> 167.16, 167.16
% INFO    : Updated Thermal Rating: on line 80026-80017 : Rate B, Rate C - 0.0, 0.0 -> 115.31, 115.31
% INFO    : Updated Thermal Rating: on line 80037-80017 : Rate B, Rate C - 0.0, 0.0 -> 151.68, 151.68
% INFO    : Updated Thermal Rating: on line 80036-80018 : Rate B, Rate C - 0.0, 0.0 -> 157.07, 157.07
% INFO    : Updated Thermal Rating: on line 80018-80100 : Rate B, Rate C - 0.0, 0.0 -> 191.25, 191.25
% INFO    : Updated Thermal Rating: on line 80020-80030 : Rate B, Rate C - 0.0, 0.0 -> 181.24, 181.24
% INFO    : Updated Thermal Rating: on line 80020-80033 : Rate B, Rate C - 0.0, 0.0 -> 172.04, 172.04
% INFO    : Updated Thermal Rating: on line 80020-80050 : Rate B, Rate C - 0.0, 0.0 -> 157.63, 157.63
% INFO    : Updated Thermal Rating: on line 80021-80025 : Rate B, Rate C - 0.0, 0.0 -> 135.93, 135.93
% INFO    : Updated Thermal Rating: on line 80022-80037 : Rate B, Rate C - 0.0, 0.0 -> 155.21, 155.21
% INFO    : Updated Thermal Rating: on line 80050-80022 : Rate B, Rate C - 0.0, 0.0 -> 116.14, 116.14
% INFO    : Updated Thermal Rating: on line 80024-80054 : Rate B, Rate C - 0.0, 0.0 -> 154.81, 154.81
% INFO    : Updated Thermal Rating: on line 80024-80058 : Rate B, Rate C - 0.0, 0.0 -> 134.54, 134.54
% INFO    : Updated Thermal Rating: on line 80026-80028 : Rate B, Rate C - 0.0, 0.0 -> 155.75, 155.75
% INFO    : Updated Thermal Rating: on line 80026-80036 : Rate B, Rate C - 0.0, 0.0 -> 167.48, 167.48
% INFO    : Updated Thermal Rating: on line 80028-80088 : Rate B, Rate C - 0.0, 0.0 -> 198.24, 198.24
% INFO    : Updated Thermal Rating: on line 80032-80043 : Rate B, Rate C - 0.0, 0.0 -> 173.37, 173.37
% INFO    : Updated Thermal Rating: on line 80035-80033 : Rate B, Rate C - 0.0, 0.0 -> 158.77, 158.77
% INFO    : Updated Thermal Rating: on line 80033-80044 : Rate B, Rate C - 0.0, 0.0 -> 157.77, 157.77
% INFO    : Updated Thermal Rating: on line 80035-80046 : Rate B, Rate C - 0.0, 0.0 -> 192.75, 192.75
% INFO    : Updated Thermal Rating: on line 80040-80046 : Rate B, Rate C - 0.0, 0.0 -> 203.29, 203.29
% INFO    : Updated Thermal Rating: on line 80047-80040 : Rate B, Rate C - 0.0, 0.0 -> 183.76, 183.76
% INFO    : Updated Thermal Rating: on line 80054-80043 : Rate B, Rate C - 0.0, 0.0 -> 145.79, 145.79
% INFO    : Updated Thermal Rating: on line 80058-80044 : Rate B, Rate C - 0.0, 0.0 -> 159.2, 159.2
% INFO    : Updated Thermal Rating: on line 80044-80073 : Rate B, Rate C - 0.0, 0.0 -> 114.85, 114.85
% INFO    : Updated Thermal Rating: on transformer 80046-80045 : Rate B, Rate C - 0.0, 0.0 -> 255.54, 255.54
% INFO    : Updated Thermal Rating: on transformer 80046-80045 : Rate B, Rate C - 0.0, 0.0 -> 255.54, 255.54
% INFO    : Updated Thermal Rating: on transformer 80046-80045 : Rate B, Rate C - 0.0, 0.0 -> 255.54, 255.54
% INFO    : Updated Thermal Rating: on line 80049-80045 : Rate B, Rate C - 0.0, 0.0 -> 644.61, 644.61
% INFO    : Updated Thermal Rating: on line 80045-80087 : Rate B, Rate C - 0.0, 0.0 -> 557.93, 557.93
% INFO    : Updated Thermal Rating: on line 80046-80062 : Rate B, Rate C - 0.0, 0.0 -> 175.67, 175.67
% INFO    : Updated Thermal Rating: on line 80047-80058 : Rate B, Rate C - 0.0, 0.0 -> 189.25, 189.25
% INFO    : Updated Thermal Rating: on transformer 80049-80048 : Rate B, Rate C - 0.0, 0.0 -> 1028.67, 1028.67
% INFO    : Updated Thermal Rating: on line 80048-80086 : Rate B, Rate C - 0.0, 0.0 -> 2701.0, 2701.0
% INFO    : Updated Thermal Rating: on transformer 80049-80052 : Rate B, Rate C - 0.0, 0.0 -> 273.39, 273.39
% INFO    : Updated Thermal Rating: on line 80049-80057 : Rate B, Rate C - 0.0, 0.0 -> 582.42, 582.42
% INFO    : Updated Thermal Rating: on line 80049-80071 : Rate B, Rate C - 0.0, 0.0 -> 529.41, 529.41
% INFO    : Updated Thermal Rating: on transformer 80050-80052 : Rate B, Rate C - 0.0, 0.0 -> 198.39, 198.39
% INFO    : Updated Thermal Rating: on transformer 80051-80052 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on transformer 80053-80056 : Rate B, Rate C - 0.0, 0.0 -> 288.93, 288.93
% INFO    : Updated Thermal Rating: on transformer 80054-80056 : Rate B, Rate C - 0.0, 0.0 -> 180.6, 180.6
% INFO    : Updated Thermal Rating: on transformer 80055-80056 : Rate B, Rate C - 0.0, 0.0 -> 108.33, 108.33
% INFO    : Updated Thermal Rating: on line 80057-80071 : Rate B, Rate C - 0.0, 0.0 -> 492.28, 492.28
% INFO    : Updated Thermal Rating: on line 80072-80062 : Rate B, Rate C - 0.0, 0.0 -> 148.11, 148.11
% INFO    : Updated Thermal Rating: on line 80065-80067 : Rate B, Rate C - 0.0, 0.0 -> 127.1, 127.1
% INFO    : Updated Thermal Rating: on line 80065-80069 : Rate B, Rate C - 0.0, 0.0 -> 129.37, 129.37
% INFO    : Updated Thermal Rating: on line 80067-80069 : Rate B, Rate C - 0.0, 0.0 -> 182.59, 182.59
% INFO    : Updated Thermal Rating: on line 80067-80072 : Rate B, Rate C - 0.0, 0.0 -> 163.49, 163.49
% INFO    : Updated Thermal Rating: on transformer 80069-80068 : Rate B, Rate C - 0.0, 0.0 -> 177.75, 177.75
% INFO    : Updated Thermal Rating: on line 80069-80082 : Rate B, Rate C - 0.0, 0.0 -> 142.37, 142.37
% INFO    : Updated Thermal Rating: on line 80082-80073 : Rate B, Rate C - 0.0, 0.0 -> 137.5, 137.5
% INFO    : Updated Thermal Rating: on line 80073-80083 : Rate B, Rate C - 0.0, 0.0 -> 100.36, 100.36
% INFO    : Updated Thermal Rating: on line 80077-80074 : Rate B, Rate C - 0.0, 0.0 -> 160.44, 160.44
% INFO    : Updated Thermal Rating: on transformer 80076-80079 : Rate B, Rate C - 0.0, 0.0 -> 386.51, 386.51
% INFO    : Updated Thermal Rating: on transformer 80077-80079 : Rate B, Rate C - 0.0, 0.0 -> 181.5, 181.5
% INFO    : Updated Thermal Rating: on transformer 80078-80079 : Rate B, Rate C - 0.0, 0.0 -> 205.01, 205.01
% INFO    : Updated Thermal Rating: on line 80080-80087 : Rate B, Rate C - 0.0, 0.0 -> 536.51, 536.51
% INFO    : Updated Thermal Rating: on line 80082-80083 : Rate B, Rate C - 0.0, 0.0 -> 103.08, 103.08
% INFO    : Updated Thermal Rating: on transformer 80087-80086 : Rate B, Rate C - 0.0, 0.0 -> 995.95, 995.95
% INFO    : Updated Thermal Rating: on transformer 80086-80091 : Rate B, Rate C - 0.0, 0.0 -> 740.7, 740.7
% INFO    : Updated Thermal Rating: on transformer 80086-80092 : Rate B, Rate C - 0.0, 0.0 -> 739.74, 739.74
% INFO    : Updated Thermal Rating: on transformer 80086-80093 : Rate B, Rate C - 0.0, 0.0 -> 739.0, 739.0
% INFO    : Updated Thermal Rating: on transformer 80086-80094 : Rate B, Rate C - 0.0, 0.0 -> 736.7, 736.7
% INFO    : Updated Thermal Rating: on transformer 80086-80095 : Rate B, Rate C - 0.0, 0.0 -> 731.63, 731.63
% INFO    : Updated Thermal Rating: on transformer 80086-80096 : Rate B, Rate C - 0.0, 0.0 -> 726.09, 726.09
% INFO    : Updated Thermal Rating: on transformer 80086-80097 : Rate B, Rate C - 0.0, 0.0 -> 665.03, 665.03
% INFO    : Updated Thermal Rating: on transformer 80086-80098 : Rate B, Rate C - 0.0, 0.0 -> 664.84, 664.84
% INFO    : Updated Thermal Rating: on transformer 80086-80099 : Rate B, Rate C - 0.0, 0.0 -> 660.89, 660.89
% INFO    : Updated Thermal Rating: on transformer 80087-80090 : Rate B, Rate C - 0.0, 0.0 -> 266.35, 266.35
% INFO    : Updated Thermal Rating: on transformer 80088-80090 : Rate B, Rate C - 0.0, 0.0 -> 216.35, 216.35
% INFO    : Updated Thermal Rating: on line 80088-80100 : Rate B, Rate C - 0.0, 0.0 -> 184.7, 184.7
% INFO    : Updated Thermal Rating: on transformer 80089-80090 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 10001	: V=1.0116409, theta=-39.843601 -> V=1.0, theta=0.0
% INFO    : Bus 10002	: V=1.0170252, theta=-37.043319 -> V=1.0, theta=0.0
% INFO    : Bus 10003	: V=1.0314498, theta=-34.039098 -> V=1.0, theta=0.0
% INFO    : Bus 10004	: V=1.0324589, theta=-33.926182 -> V=1.0, theta=0.0
% INFO    : Bus 10005	: V=1.0324073, theta=-33.932471 -> V=1.0, theta=0.0
% INFO    : Bus 10006	: V=1.0255915, theta=-35.816633 -> V=1.0, theta=0.0
% INFO    : Bus 10007	: V=1.0256414, theta=-35.808499 -> V=1.0, theta=0.0
% INFO    : Bus 10008	: V=1.0243111, theta=-34.741944 -> V=1.0, theta=0.0
% INFO    : Bus 10009	: V=1.0242459, theta=-34.751218 -> V=1.0, theta=0.0
% INFO    : Bus 10010	: V=1.0230199, theta=-34.84581 -> V=1.0, theta=0.0
% INFO    : Bus 10011	: V=1.0073858, theta=-40.603606 -> V=1.0, theta=0.0
% INFO    : Bus 10012	: V=1.0354328, theta=-32.265236 -> V=1.0, theta=0.0
% INFO    : Bus 10013	: V=1.0281891, theta=-34.327064 -> V=1.0, theta=0.0
% INFO    : Bus 10014	: V=1.0256878, theta=-34.64117 -> V=1.0, theta=0.0
% INFO    : Bus 10015	: V=1.0254965, theta=-34.654275 -> V=1.0, theta=0.0
% INFO    : Bus 10016	: V=1.0266137, theta=-32.284026 -> V=1.0, theta=0.0
% INFO    : Bus 10017	: V=1.0264701, theta=-32.299269 -> V=1.0, theta=0.0
% INFO    : Bus 10018	: V=1.0320894, theta=-35.370085 -> V=1.0, theta=0.0
% INFO    : Bus 10019	: V=1.038592, theta=-36.540823 -> V=1.0, theta=0.0
% INFO    : Bus 10020	: V=1.0163177, theta=-39.074648 -> V=1.0, theta=0.0
% INFO    : Bus 10021	: V=1.027115, theta=-31.899164 -> V=1.0, theta=0.0
% INFO    : Bus 10022	: V=1.0405375, theta=-35.691866 -> V=1.0, theta=0.0
% INFO    : Bus 10023	: V=1.032395, theta=-33.232508 -> V=1.0, theta=0.0
% INFO    : Bus 10024	: V=1.0439774, theta=-35.612977 -> V=1.0, theta=0.0
% INFO    : Bus 10025	: V=1.0333372, theta=-32.720484 -> V=1.0, theta=0.0
% INFO    : Bus 10026	: V=1.0116824, theta=-41.072887 -> V=1.0, theta=0.0
% INFO    : Bus 10027	: V=1.0038997, theta=-41.072378 -> V=1.0, theta=0.0
% INFO    : Bus 10028	: V=1.0036898, theta=-41.089378 -> V=1.0, theta=0.0
% INFO    : Bus 10029	: V=1.0089477, theta=-40.455574 -> V=1.0, theta=0.0
% INFO    : Bus 10030	: V=1.0372316, theta=-35.052342 -> V=1.0, theta=0.0
% INFO    : Bus 10031	: V=1.0370651, theta=-35.073682 -> V=1.0, theta=0.0
% INFO    : Bus 10032	: V=1.0307508, theta=-36.117109 -> V=1.0, theta=0.0
% INFO    : Bus 10033	: V=1.016838, theta=-32.557944 -> V=1.0, theta=0.0
% INFO    : Bus 10034	: V=1.015676, theta=-32.426001 -> V=1.0, theta=0.0
% INFO    : Bus 10035	: V=1.0151295, theta=-32.454759 -> V=1.0, theta=0.0
% INFO    : Bus 10036	: V=1.0163185, theta=-32.393034 -> V=1.0, theta=0.0
% INFO    : Bus 10037	: V=1.0338033, theta=-32.093125 -> V=1.0, theta=0.0
% INFO    : Bus 10038	: V=1.0356734, theta=-36.400225 -> V=1.0, theta=0.0
% INFO    : Bus 10039	: V=1.0359091, theta=-36.38095 -> V=1.0, theta=0.0
% INFO    : Bus 10040	: V=1.030238, theta=-37.084123 -> V=1.0, theta=0.0
% INFO    : Bus 10041	: V=1.0323228, theta=-31.342346 -> V=1.0, theta=0.0
% INFO    : Bus 10042	: V=1.0328935, theta=-33.190059 -> V=1.0, theta=0.0
% INFO    : Bus 10043	: V=1.0218061, theta=-38.811021 -> V=1.0, theta=0.0
% INFO    : Bus 10044	: V=1.0216999, theta=-38.834832 -> V=1.0, theta=0.0
% INFO    : Bus 10045	: V=1.0227844, theta=-32.151262 -> V=1.0, theta=0.0
% INFO    : Bus 10046	: V=1.0222881, theta=-34.51371 -> V=1.0, theta=0.0
% INFO    : Bus 10047	: V=1.0221304, theta=-34.5383 -> V=1.0, theta=0.0
% INFO    : Bus 10048	: V=1.0226376, theta=-34.487889 -> V=1.0, theta=0.0
% INFO    : Bus 10049	: V=1.0228477, theta=-34.462782 -> V=1.0, theta=0.0
% INFO    : Bus 10050	: V=1.0226376, theta=-34.487889 -> V=1.0, theta=0.0
% INFO    : Bus 10051	: V=1.0136499, theta=-40.814996 -> V=1.0, theta=0.0
% INFO    : Bus 10052	: V=1.0135818, theta=-40.825956 -> V=1.0, theta=0.0
% INFO    : Bus 10053	: V=1.0269065, theta=-33.681628 -> V=1.0, theta=0.0
% INFO    : Bus 10054	: V=1.0046601, theta=-41.058556 -> V=1.0, theta=0.0
% INFO    : Bus 10055	: V=1.0267267, theta=-34.746926 -> V=1.0, theta=0.0
% INFO    : Bus 10056	: V=1.0268289, theta=-34.738068 -> V=1.0, theta=0.0
% INFO    : Bus 10057	: V=1.0309544, theta=-32.301317 -> V=1.0, theta=0.0
% INFO    : Bus 10058	: V=1.022309, theta=-34.670766 -> V=1.0, theta=0.0
% INFO    : Bus 10059	: V=1.0317222, theta=-32.205262 -> V=1.0, theta=0.0
% INFO    : Bus 10060	: V=1.0200555, theta=-34.755574 -> V=1.0, theta=0.0
% INFO    : Bus 10061	: V=1.0261269, theta=-38.072955 -> V=1.0, theta=0.0
% INFO    : Bus 10062	: V=1.0206114, theta=-39.86985 -> V=1.0, theta=0.0
% INFO    : Bus 10063	: V=1.0207945, theta=-39.850744 -> V=1.0, theta=0.0
% INFO    : Bus 10064	: V=1.0204151, theta=-39.891009 -> V=1.0, theta=0.0
% INFO    : Bus 10065	: V=1.0197883, theta=-39.702987 -> V=1.0, theta=0.0
% INFO    : Bus 10066	: V=1.0197883, theta=-39.702987 -> V=1.0, theta=0.0
% INFO    : Bus 10067	: V=1.0197883, theta=-39.702987 -> V=1.0, theta=0.0
% INFO    : Bus 10068	: V=1.0197883, theta=-39.702987 -> V=1.0, theta=0.0
% INFO    : Bus 10069	: V=1.0127526, theta=-33.015071 -> V=1.0, theta=0.0
% INFO    : Bus 10070	: V=1.0241138, theta=-39.019209 -> V=1.0, theta=0.0
% INFO    : Bus 10071	: V=1.0257891, theta=-35.009419 -> V=1.0, theta=0.0
% INFO    : Bus 10072	: V=1.0200845, theta=-35.099512 -> V=1.0, theta=0.0
% INFO    : Bus 10073	: V=1.019747, theta=-35.120206 -> V=1.0, theta=0.0
% INFO    : Bus 10074	: V=1.0142579, theta=-33.366167 -> V=1.0, theta=0.0
% INFO    : Bus 10075	: V=1.0141746, theta=-33.374569 -> V=1.0, theta=0.0
% INFO    : Bus 10076	: V=1.0245081, theta=-38.174506 -> V=1.0, theta=0.0
% INFO    : Bus 10077	: V=1.0263241, theta=-34.86003 -> V=1.0, theta=0.0
% INFO    : Bus 10078	: V=1.0323963, theta=-34.304647 -> V=1.0, theta=0.0
% INFO    : Bus 10079	: V=1.0223918, theta=-38.194635 -> V=1.0, theta=0.0
% INFO    : Bus 10080	: V=1.0164502, theta=-43.75875 -> V=1.0, theta=0.0
% INFO    : Bus 10081	: V=1.0164502, theta=-43.75875 -> V=1.0, theta=0.0
% INFO    : Bus 10082	: V=1.0201843, theta=-39.061951 -> V=1.0, theta=0.0
% INFO    : Bus 10083	: V=1.0200317, theta=-39.073656 -> V=1.0, theta=0.0
% INFO    : Bus 10084	: V=1.0299458, theta=-38.147505 -> V=1.0, theta=0.0
% INFO    : Bus 10085	: V=1.0297888, theta=-38.172812 -> V=1.0, theta=0.0
% INFO    : Bus 10086	: V=1.0300854, theta=-38.125976 -> V=1.0, theta=0.0
% INFO    : Bus 10087	: V=1.0159507, theta=-39.839459 -> V=1.0, theta=0.0
% INFO    : Bus 10088	: V=1.0293828, theta=-39.37408 -> V=1.0, theta=0.0
% INFO    : Bus 10089	: V=1.029255, theta=-39.393691 -> V=1.0, theta=0.0
% INFO    : Bus 10090	: V=1.0239085, theta=-39.445412 -> V=1.0, theta=0.0
% INFO    : Bus 10091	: V=1.0257154, theta=-33.716736 -> V=1.0, theta=0.0
% INFO    : Bus 10092	: V=1.0251786, theta=-34.96772 -> V=1.0, theta=0.0
% INFO    : Bus 10093	: V=1.0241716, theta=-35.703976 -> V=1.0, theta=0.0
% INFO    : Bus 10094	: V=1.0245425, theta=-38.368017 -> V=1.0, theta=0.0
% INFO    : Bus 10095	: V=1.0246287, theta=-38.358101 -> V=1.0, theta=0.0
% INFO    : Bus 10096	: V=1.0244613, theta=-38.377859 -> V=1.0, theta=0.0
% INFO    : Bus 10097	: V=1.0266602, theta=-34.230127 -> V=1.0, theta=0.0
% INFO    : Bus 10098	: V=1.0217068, theta=-35.309703 -> V=1.0, theta=0.0
% INFO    : Bus 10099	: V=1.0218257, theta=-35.298217 -> V=1.0, theta=0.0
% INFO    : Bus 10100	: V=1.0338955, theta=-35.540866 -> V=1.0, theta=0.0
% INFO    : Bus 10101	: V=1.0340507, theta=-35.52283 -> V=1.0, theta=0.0
% INFO    : Bus 10102	: V=1.0337126, theta=-35.56075 -> V=1.0, theta=0.0
% INFO    : Bus 10103	: V=1.0284028, theta=-35.422526 -> V=1.0, theta=0.0
% INFO    : Bus 10104	: V=1.0280648, theta=-35.452356 -> V=1.0, theta=0.0
% INFO    : Bus 10105	: V=1.0287312, theta=-35.389824 -> V=1.0, theta=0.0
% INFO    : Bus 10106	: V=1.0192143, theta=-39.776461 -> V=1.0, theta=0.0
% INFO    : Bus 10107	: V=1.0245852, theta=-37.648532 -> V=1.0, theta=0.0
% INFO    : Bus 10108	: V=1.0246615, theta=-37.631602 -> V=1.0, theta=0.0
% INFO    : Bus 10109	: V=1.0245852, theta=-37.648532 -> V=1.0, theta=0.0
% INFO    : Bus 10110	: V=1.0311561, theta=-33.816421 -> V=1.0, theta=0.0
% INFO    : Bus 10111	: V=1.0312285, theta=-33.809593 -> V=1.0, theta=0.0
% INFO    : Bus 10112	: V=1.0277943, theta=-34.460854 -> V=1.0, theta=0.0
% INFO    : Bus 10113	: V=1.0259636, theta=-38.991283 -> V=1.0, theta=0.0
% INFO    : Bus 10114	: V=1.025748, theta=-39.008558 -> V=1.0, theta=0.0
% INFO    : Bus 10115	: V=1.0251626, theta=-38.961182 -> V=1.0, theta=0.0
% INFO    : Bus 10116	: V=1.0362135, theta=-33.812278 -> V=1.0, theta=0.0
% INFO    : Bus 10117	: V=1.0371168, theta=-29.973999 -> V=1.0, theta=0.0
% INFO    : Bus 10118	: V=1.0360956, theta=-33.838935 -> V=1.0, theta=0.0
% INFO    : Bus 10119	: V=1.0362398, theta=-34.19728 -> V=1.0, theta=0.0
% INFO    : Bus 10120	: V=1.0362398, theta=-34.19728 -> V=1.0, theta=0.0
% INFO    : Bus 10121	: V=1.0177915, theta=-38.974238 -> V=1.0, theta=0.0
% INFO    : Bus 10122	: V=1.0174988, theta=-38.994027 -> V=1.0, theta=0.0
% INFO    : Bus 10123	: V=1.01872, theta=-38.794751 -> V=1.0, theta=0.0
% INFO    : Bus 10124	: V=1.0188713, theta=-38.773023 -> V=1.0, theta=0.0
% INFO    : Bus 10125	: V=1.0185632, theta=-38.816167 -> V=1.0, theta=0.0
% INFO    : Bus 10126	: V=1.01872, theta=-38.794751 -> V=1.0, theta=0.0
% INFO    : Bus 10127	: V=1.0194055, theta=-34.785477 -> V=1.0, theta=0.0
% INFO    : Bus 10128	: V=1.0349271, theta=-38.678305 -> V=1.0, theta=0.0
% INFO    : Bus 10129	: V=1.034663, theta=-35.348336 -> V=1.0, theta=0.0
% INFO    : Bus 10130	: V=1.0211984, theta=-35.08454 -> V=1.0, theta=0.0
% INFO    : Bus 10131	: V=1.0287552, theta=-35.358406 -> V=1.0, theta=0.0
% INFO    : Bus 10132	: V=1.0285157, theta=-35.382846 -> V=1.0, theta=0.0
% INFO    : Bus 10133	: V=1.0242636, theta=-38.318841 -> V=1.0, theta=0.0
% INFO    : Bus 10134	: V=1.0239863, theta=-38.357531 -> V=1.0, theta=0.0
% INFO    : Bus 10135	: V=1.0312205, theta=-37.929885 -> V=1.0, theta=0.0
% INFO    : Bus 10136	: V=1.031523, theta=-37.894015 -> V=1.0, theta=0.0
% INFO    : Bus 10137	: V=1.025873, theta=-34.068553 -> V=1.0, theta=0.0
% INFO    : Bus 10138	: V=1.0245317, theta=-39.476173 -> V=1.0, theta=0.0
% INFO    : Bus 10139	: V=1.0595043, theta=-36.36937 -> V=1.0, theta=0.0
% INFO    : Bus 10140	: V=1.0205742, theta=-38.999097 -> V=1.0, theta=0.0
% INFO    : Bus 10141	: V=1.0202832, theta=-39.022624 -> V=1.0, theta=0.0
% INFO    : Bus 10142	: V=1.0175076, theta=-39.26695 -> V=1.0, theta=0.0
% INFO    : Bus 10143	: V=1.0176258, theta=-39.241299 -> V=1.0, theta=0.0
% INFO    : Bus 10144	: V=1.0175076, theta=-39.26695 -> V=1.0, theta=0.0
% INFO    : Bus 10145	: V=1.0191744, theta=-34.50934 -> V=1.0, theta=0.0
% INFO    : Bus 10146	: V=1.0198485, theta=-35.015836 -> V=1.0, theta=0.0
% INFO    : Bus 10147	: V=1.0200417, theta=-34.993253 -> V=1.0, theta=0.0
% INFO    : Bus 10148	: V=1.0260568, theta=-35.392693 -> V=1.0, theta=0.0
% INFO    : Bus 10149	: V=1.0254475, theta=-39.581735 -> V=1.0, theta=0.0
% INFO    : Bus 10150	: V=1.0168054, theta=-40.400752 -> V=1.0, theta=0.0
% INFO    : Bus 10151	: V=1.02179, theta=-40.727861 -> V=1.0, theta=0.0
% INFO    : Bus 10152	: V=1.0245018, theta=-39.728968 -> V=1.0, theta=0.0
% INFO    : Bus 10153	: V=1.0241439, theta=-35.521611 -> V=1.0, theta=0.0
% INFO    : Bus 10154	: V=1.0580155, theta=-36.510186 -> V=1.0, theta=0.0
% INFO    : Bus 10155	: V=1.0221174, theta=-35.479842 -> V=1.0, theta=0.0
% INFO    : Bus 10156	: V=1.0219881, theta=-35.499119 -> V=1.0, theta=0.0
% INFO    : Bus 10157	: V=1.0366085, theta=-38.691661 -> V=1.0, theta=0.0
% INFO    : Bus 10158	: V=1.0358222, theta=-38.662844 -> V=1.0, theta=0.0
% INFO    : Bus 10159	: V=1.0290963, theta=-38.622225 -> V=1.0, theta=0.0
% INFO    : Bus 10160	: V=1.0143835, theta=-39.13101 -> V=1.0, theta=0.0
% INFO    : Bus 10161	: V=1.0221209, theta=-41.464357 -> V=1.0, theta=0.0
% INFO    : Bus 10162	: V=1.0219846, theta=-41.479494 -> V=1.0, theta=0.0
% INFO    : Bus 10163	: V=1.0222462, theta=-41.450146 -> V=1.0, theta=0.0
% INFO    : Bus 10164	: V=1.0238143, theta=-35.618254 -> V=1.0, theta=0.0
% INFO    : Bus 10165	: V=1.0163883, theta=-39.773845 -> V=1.0, theta=0.0
% INFO    : Bus 10166	: V=1.0162035, theta=-39.803841 -> V=1.0, theta=0.0
% INFO    : Bus 10167	: V=1.0381633, theta=-35.103536 -> V=1.0, theta=0.0
% INFO    : Bus 10168	: V=1.0316972, theta=-35.311606 -> V=1.0, theta=0.0
% INFO    : Bus 10169	: V=1.0258799, theta=-35.733086 -> V=1.0, theta=0.0
% INFO    : Bus 10170	: V=1.0258332, theta=-35.741176 -> V=1.0, theta=0.0
% INFO    : Bus 10171	: V=1.0190226, theta=-38.613559 -> V=1.0, theta=0.0
% INFO    : Bus 10172	: V=1.0227985, theta=-34.045764 -> V=1.0, theta=0.0
% INFO    : Bus 10173	: V=1.0229568, theta=-34.021428 -> V=1.0, theta=0.0
% INFO    : Bus 10174	: V=1.0226317, theta=-34.071844 -> V=1.0, theta=0.0
% INFO    : Bus 10175	: V=1.0243398, theta=-33.404556 -> V=1.0, theta=0.0
% INFO    : Bus 10176	: V=1.0245927, theta=-33.379987 -> V=1.0, theta=0.0
% INFO    : Bus 10177	: V=1.0387846, theta=-34.873806 -> V=1.0, theta=0.0
% INFO    : Bus 10178	: V=1.0232512, theta=-35.187729 -> V=1.0, theta=0.0
% INFO    : Bus 10179	: V=1.0309787, theta=-38.077904 -> V=1.0, theta=0.0
% INFO    : Bus 10180	: V=1.0309945, theta=-37.885481 -> V=1.0, theta=0.0
% INFO    : Bus 10181	: V=1.0311672, theta=-37.855068 -> V=1.0, theta=0.0
% INFO    : Bus 10182	: V=1.0308317, theta=-37.918544 -> V=1.0, theta=0.0
% INFO    : Bus 10183	: V=1.0214786, theta=-38.544159 -> V=1.0, theta=0.0
% INFO    : Bus 10184	: V=1.0391734, theta=-38.350568 -> V=1.0, theta=0.0
% INFO    : Bus 10185	: V=1.038682, theta=-38.387617 -> V=1.0, theta=0.0
% INFO    : Bus 10186	: V=1.0296091, theta=-35.492642 -> V=1.0, theta=0.0
% INFO    : Bus 10187	: V=1.0294303, theta=-35.513367 -> V=1.0, theta=0.0
% INFO    : Bus 10188	: V=1.0307217, theta=-33.162378 -> V=1.0, theta=0.0
% INFO    : Bus 10189	: V=1.0310525, theta=-33.132025 -> V=1.0, theta=0.0
% INFO    : Bus 10190	: V=1.0199622, theta=-34.306139 -> V=1.0, theta=0.0
% INFO    : Bus 10191	: V=1.0197114, theta=-34.344261 -> V=1.0, theta=0.0
% INFO    : Bus 10192	: V=1.0097532, theta=-32.008878 -> V=1.0, theta=0.0
% INFO    : Bus 10193	: V=1.0188744, theta=-34.672169 -> V=1.0, theta=0.0
% INFO    : Bus 10194	: V=1.0188709, theta=-34.671273 -> V=1.0, theta=0.0
% INFO    : Bus 10195	: V=1.0188709, theta=-34.671273 -> V=1.0, theta=0.0
% INFO    : Bus 10196	: V=1.036513, theta=-32.165948 -> V=1.0, theta=0.0
% INFO    : Bus 10197	: V=1.0635547, theta=-35.997317 -> V=1.0, theta=0.0
% INFO    : Bus 10198	: V=1.036068, theta=-32.192758 -> V=1.0, theta=0.0
% INFO    : Bus 10199	: V=1.0178039, theta=-39.788112 -> V=1.0, theta=0.0
% INFO    : Bus 10200	: V=1.0221392, theta=-38.849075 -> V=1.0, theta=0.0
% INFO    : Bus 10201	: V=1.028482, theta=-37.285627 -> V=1.0, theta=0.0
% INFO    : Bus 10202	: V=1.0262407, theta=-35.473749 -> V=1.0, theta=0.0
% INFO    : Bus 10203	: V=1.0232504, theta=-39.688541 -> V=1.0, theta=0.0
% INFO    : Bus 10204	: V=1.0231902, theta=-39.696402 -> V=1.0, theta=0.0
% INFO    : Bus 10205	: V=1.0219078, theta=-37.002327 -> V=1.0, theta=0.0
% INFO    : Bus 10206	: V=1.0217238, theta=-37.025005 -> V=1.0, theta=0.0
% INFO    : Bus 10207	: V=1.0252948, theta=-38.952647 -> V=1.0, theta=0.0
% INFO    : Bus 10208	: V=1.0278604, theta=-38.591477 -> V=1.0, theta=0.0
% INFO    : Bus 10209	: V=1.0183453, theta=-37.187623 -> V=1.0, theta=0.0
% INFO    : Bus 10210	: V=1.0292738, theta=-38.169185 -> V=1.0, theta=0.0
% INFO    : Bus 10211	: V=1.0284339, theta=-38.048349 -> V=1.0, theta=0.0
% INFO    : Bus 10212	: V=1.0286776, theta=-38.018156 -> V=1.0, theta=0.0
% INFO    : Bus 10213	: V=1.0390587, theta=-31.65064 -> V=1.0, theta=0.0
% INFO    : Bus 10214	: V=1.0389932, theta=-31.657357 -> V=1.0, theta=0.0
% INFO    : Bus 10215	: V=1.0315993, theta=-37.482328 -> V=1.0, theta=0.0
% INFO    : Bus 10216	: V=1.0309497, theta=-37.636288 -> V=1.0, theta=0.0
% INFO    : Bus 10217	: V=1.0308336, theta=-37.657609 -> V=1.0, theta=0.0
% INFO    : Bus 10218	: V=1.0303626, theta=-40.875393 -> V=1.0, theta=0.0
% INFO    : Bus 10219	: V=1.0297292, theta=-38.917974 -> V=1.0, theta=0.0
% INFO    : Bus 10220	: V=1.029936, theta=-38.895576 -> V=1.0, theta=0.0
% INFO    : Bus 10221	: V=1.028033, theta=-36.71998 -> V=1.0, theta=0.0
% INFO    : Bus 10222	: V=1.0318376, theta=-37.462216 -> V=1.0, theta=0.0
% INFO    : Bus 10223	: V=1.0317857, theta=-37.466957 -> V=1.0, theta=0.0
% INFO    : Bus 10224	: V=1.0252124, theta=-36.458405 -> V=1.0, theta=0.0
% INFO    : Bus 10225	: V=1.0248657, theta=-36.476248 -> V=1.0, theta=0.0
% INFO    : Bus 10226	: V=1.0210349, theta=-37.029741 -> V=1.0, theta=0.0
% INFO    : Bus 10227	: V=1.0237587, theta=-40.59113 -> V=1.0, theta=0.0
% INFO    : Bus 10228	: V=1.0329023, theta=-38.102186 -> V=1.0, theta=0.0
% INFO    : Bus 10229	: V=1.032465, theta=-38.757536 -> V=1.0, theta=0.0
% INFO    : Bus 10230	: V=1.0321633, theta=-36.274512 -> V=1.0, theta=0.0
% INFO    : Bus 10231	: V=1.0305393, theta=-36.841138 -> V=1.0, theta=0.0
% INFO    : Bus 10232	: V=1.0166545, theta=-38.033067 -> V=1.0, theta=0.0
% INFO    : Bus 10233	: V=1.0269711, theta=-38.051968 -> V=1.0, theta=0.0
% INFO    : Bus 10234	: V=1.0268269, theta=-38.07461 -> V=1.0, theta=0.0
% INFO    : Bus 10235	: V=1.0241854, theta=-41.196093 -> V=1.0, theta=0.0
% INFO    : Bus 10236	: V=1.0239647, theta=-41.217518 -> V=1.0, theta=0.0
% INFO    : Bus 10237	: V=1.0255355, theta=-35.682551 -> V=1.0, theta=0.0
% INFO    : Bus 10238	: V=1.0253048, theta=-35.625381 -> V=1.0, theta=0.0
% INFO    : Bus 10239	: V=1.0346344, theta=-38.530763 -> V=1.0, theta=0.0
% INFO    : Bus 10240	: V=1.0348605, theta=-38.503153 -> V=1.0, theta=0.0
% INFO    : Bus 10241	: V=1.0358036, theta=-37.707453 -> V=1.0, theta=0.0
% INFO    : Bus 10242	: V=1.0315108, theta=-38.027924 -> V=1.0, theta=0.0
% INFO    : Bus 10243	: V=1.0313574, theta=-38.053286 -> V=1.0, theta=0.0
% INFO    : Bus 10244	: V=1.0496185, theta=-32.905028 -> V=1.0, theta=0.0
% INFO    : Bus 10245	: V=1.0504942, theta=-32.872209 -> V=1.0, theta=0.0
% INFO    : Bus 10246	: V=1.0506588, theta=-32.851715 -> V=1.0, theta=0.0
% INFO    : Bus 10247	: V=1.0208945, theta=-36.92838 -> V=1.0, theta=0.0
% INFO    : Bus 10248	: V=1.0234519, theta=-40.684195 -> V=1.0, theta=0.0
% INFO    : Bus 10249	: V=1.0225298, theta=-38.192519 -> V=1.0, theta=0.0
% INFO    : Bus 10250	: V=1.0173637, theta=-39.062542 -> V=1.0, theta=0.0
% INFO    : Bus 10251	: V=1.0217446, theta=-38.593314 -> V=1.0, theta=0.0
% INFO    : Bus 10252	: V=1.018442, theta=-38.564001 -> V=1.0, theta=0.0
% INFO    : Bus 10253	: V=1.0186082, theta=-38.547043 -> V=1.0, theta=0.0
% INFO    : Bus 10254	: V=1.0172092, theta=-38.990685 -> V=1.0, theta=0.0
% INFO    : Bus 10255	: V=1.0174886, theta=-38.973339 -> V=1.0, theta=0.0
% INFO    : Bus 10256	: V=1.0187975, theta=-38.708193 -> V=1.0, theta=0.0
% INFO    : Bus 10257	: V=1.0185994, theta=-38.721747 -> V=1.0, theta=0.0
% INFO    : Bus 10258	: V=1.0190105, theta=-38.694482 -> V=1.0, theta=0.0
% INFO    : Bus 10259	: V=1.0163802, theta=-38.564933 -> V=1.0, theta=0.0
% INFO    : Bus 10260	: V=1.0342304, theta=-37.664882 -> V=1.0, theta=0.0
% INFO    : Bus 10261	: V=1.0192151, theta=-38.468471 -> V=1.0, theta=0.0
% INFO    : Bus 10262	: V=1.01892, theta=-38.501703 -> V=1.0, theta=0.0
% INFO    : Bus 10263	: V=1.0557666, theta=-32.183808 -> V=1.0, theta=0.0
% INFO    : Bus 10264	: V=1.0276149, theta=-38.267992 -> V=1.0, theta=0.0
% INFO    : Bus 10265	: V=1.0277538, theta=-38.238369 -> V=1.0, theta=0.0
% INFO    : Bus 10266	: V=1.0274814, theta=-38.297366 -> V=1.0, theta=0.0
% INFO    : Bus 10267	: V=1.0097628, theta=-34.325497 -> V=1.0, theta=0.0
% INFO    : Bus 10268	: V=1.0189451, theta=-37.027058 -> V=1.0, theta=0.0
% INFO    : Bus 10269	: V=1.0186792, theta=-37.058869 -> V=1.0, theta=0.0
% INFO    : Bus 10270	: V=1.0304329, theta=-37.715572 -> V=1.0, theta=0.0
% INFO    : Bus 10271	: V=1.0302429, theta=-37.745014 -> V=1.0, theta=0.0
% INFO    : Bus 10272	: V=1.0177324, theta=-38.493395 -> V=1.0, theta=0.0
% INFO    : Bus 10273	: V=1.0182052, theta=-37.978935 -> V=1.0, theta=0.0
% INFO    : Bus 10274	: V=1.0300576, theta=-37.764237 -> V=1.0, theta=0.0
% INFO    : Bus 10275	: V=1.0180023, theta=-33.470741 -> V=1.0, theta=0.0
% INFO    : Bus 10276	: V=1.0208713, theta=-36.116008 -> V=1.0, theta=0.0
% INFO    : Bus 10277	: V=1.0158859, theta=-37.276349 -> V=1.0, theta=0.0
% INFO    : Bus 10278	: V=1.0262513, theta=-36.984576 -> V=1.0, theta=0.0
% INFO    : Bus 10279	: V=1.0260919, theta=-37.000382 -> V=1.0, theta=0.0
% INFO    : Bus 10280	: V=1.0264034, theta=-36.967366 -> V=1.0, theta=0.0
% INFO    : Bus 10281	: V=1.0262513, theta=-36.984576 -> V=1.0, theta=0.0
% INFO    : Bus 10282	: V=1.0262513, theta=-36.984576 -> V=1.0, theta=0.0
% INFO    : Bus 10283	: V=1.034856, theta=-38.506954 -> V=1.0, theta=0.0
% INFO    : Bus 10284	: V=1.0350222, theta=-38.486793 -> V=1.0, theta=0.0
% INFO    : Bus 10285	: V=1.0184078, theta=-38.537691 -> V=1.0, theta=0.0
% INFO    : Bus 10286	: V=1.0296712, theta=-36.555986 -> V=1.0, theta=0.0
% INFO    : Bus 10287	: V=1.0198596, theta=-37.962068 -> V=1.0, theta=0.0
% INFO    : Bus 10288	: V=1.0196241, theta=-37.99265 -> V=1.0, theta=0.0
% INFO    : Bus 10289	: V=1.0251667, theta=-36.507828 -> V=1.0, theta=0.0
% INFO    : Bus 10290	: V=1.0211123, theta=-37.115457 -> V=1.0, theta=0.0
% INFO    : Bus 10291	: V=1.0203147, theta=-38.164466 -> V=1.0, theta=0.0
% INFO    : Bus 10292	: V=1.02015, theta=-38.196427 -> V=1.0, theta=0.0
% INFO    : Bus 10293	: V=1.0117324, theta=-38.422822 -> V=1.0, theta=0.0
% INFO    : Bus 10294	: V=1.0212528, theta=-37.376948 -> V=1.0, theta=0.0
% INFO    : Bus 10295	: V=1.0215, theta=-37.349105 -> V=1.0, theta=0.0
% INFO    : Bus 10296	: V=1.0162831, theta=-38.356231 -> V=1.0, theta=0.0
% INFO    : Bus 10297	: V=1.0165179, theta=-38.324395 -> V=1.0, theta=0.0
% INFO    : Bus 10298	: V=1.0156559, theta=-38.313669 -> V=1.0, theta=0.0
% INFO    : Bus 10299	: V=1.0152414, theta=-38.332798 -> V=1.0, theta=0.0
% INFO    : Bus 10300	: V=1.0266594, theta=-34.857961 -> V=1.0, theta=0.0
% INFO    : Bus 10301	: V=1.0264672, theta=-34.887036 -> V=1.0, theta=0.0
% INFO    : Bus 10302	: V=1.0249654, theta=-36.98956 -> V=1.0, theta=0.0
% INFO    : Bus 10303	: V=1.0247428, theta=-36.9559 -> V=1.0, theta=0.0
% INFO    : Bus 10304	: V=1.0249654, theta=-36.98956 -> V=1.0, theta=0.0
% INFO    : Bus 10305	: V=1.0246227, theta=-37.017712 -> V=1.0, theta=0.0
% INFO    : Bus 10306	: V=1.037163, theta=-38.159383 -> V=1.0, theta=0.0
% INFO    : Bus 10307	: V=1.0212396, theta=-36.541965 -> V=1.0, theta=0.0
% INFO    : Bus 10308	: V=1.0215834, theta=-36.516679 -> V=1.0, theta=0.0
% INFO    : Bus 10309	: V=1.029003, theta=-37.8702 -> V=1.0, theta=0.0
% INFO    : Bus 10310	: V=1.0269968, theta=-37.101391 -> V=1.0, theta=0.0
% INFO    : Bus 10311	: V=1.0148335, theta=-38.919856 -> V=1.0, theta=0.0
% INFO    : Bus 10312	: V=1.014457, theta=-38.943301 -> V=1.0, theta=0.0
% INFO    : Bus 10313	: V=1.0151433, theta=-38.899808 -> V=1.0, theta=0.0
% INFO    : Bus 10314	: V=1.0260162, theta=-38.901184 -> V=1.0, theta=0.0
% INFO    : Bus 10315	: V=1.02407, theta=-38.103603 -> V=1.0, theta=0.0
% INFO    : Bus 10316	: V=1.0426295, theta=-37.622022 -> V=1.0, theta=0.0
% INFO    : Bus 10317	: V=1.0427958, theta=-37.596666 -> V=1.0, theta=0.0
% INFO    : Bus 10318	: V=1.0323085, theta=-37.456222 -> V=1.0, theta=0.0
% INFO    : Bus 10319	: V=1.0297508, theta=-38.242718 -> V=1.0, theta=0.0
% INFO    : Bus 10320	: V=1.0295731, theta=-38.262094 -> V=1.0, theta=0.0
% INFO    : Bus 10321	: V=1.0245319, theta=-38.215947 -> V=1.0, theta=0.0
% INFO    : Bus 10322	: V=1.0384902, theta=-37.657166 -> V=1.0, theta=0.0
% INFO    : Bus 10323	: V=1.0271287, theta=-38.135099 -> V=1.0, theta=0.0
% INFO    : Bus 10324	: V=1.0154109, theta=-37.939408 -> V=1.0, theta=0.0
% INFO    : Bus 10325	: V=1.015545, theta=-37.920023 -> V=1.0, theta=0.0
% INFO    : Bus 10326	: V=1.02024, theta=-37.104407 -> V=1.0, theta=0.0
% INFO    : Bus 10327	: V=1.0285566, theta=-38.089072 -> V=1.0, theta=0.0
% INFO    : Bus 10328	: V=1.0283638, theta=-38.122043 -> V=1.0, theta=0.0
% INFO    : Bus 10329	: V=1.0287532, theta=-38.057496 -> V=1.0, theta=0.0
% INFO    : Bus 10330	: V=1.0071563, theta=-34.579041 -> V=1.0, theta=0.0
% INFO    : Bus 10331	: V=1.0444386, theta=-37.415548 -> V=1.0, theta=0.0
% INFO    : Bus 10332	: V=1.0068835, theta=-34.610939 -> V=1.0, theta=0.0
% INFO    : Bus 10333	: V=1.0115623, theta=-34.049333 -> V=1.0, theta=0.0
% INFO    : Bus 10334	: V=1.0178501, theta=-37.837851 -> V=1.0, theta=0.0
% INFO    : Bus 10335	: V=1.0178501, theta=-37.837851 -> V=1.0, theta=0.0
% INFO    : Bus 10336	: V=1.0178501, theta=-37.837851 -> V=1.0, theta=0.0
% INFO    : Bus 10337	: V=1.0178501, theta=-37.837851 -> V=1.0, theta=0.0
% INFO    : Bus 10338	: V=1.0290314, theta=-38.091452 -> V=1.0, theta=0.0
% INFO    : Bus 10339	: V=1.0170896, theta=-37.541611 -> V=1.0, theta=0.0
% INFO    : Bus 10340	: V=1.0187489, theta=-36.849112 -> V=1.0, theta=0.0
% INFO    : Bus 10341	: V=1.0189442, theta=-36.825912 -> V=1.0, theta=0.0
% INFO    : Bus 10342	: V=1.0185415, theta=-36.87458 -> V=1.0, theta=0.0
% INFO    : Bus 10343	: V=1.021796, theta=-36.720821 -> V=1.0, theta=0.0
% INFO    : Bus 10344	: V=1.0214487, theta=-36.770798 -> V=1.0, theta=0.0
% INFO    : Bus 10345	: V=1.0221595, theta=-36.669686 -> V=1.0, theta=0.0
% INFO    : Bus 10346	: V=1.0145491, theta=-34.364653 -> V=1.0, theta=0.0
% INFO    : Bus 10347	: V=1.022642, theta=-38.180641 -> V=1.0, theta=0.0
% INFO    : Bus 10348	: V=0.995232, theta=-45.336878 -> V=1.0, theta=0.0
% INFO    : Bus 10349	: V=1.0248894, theta=-38.501219 -> V=1.0, theta=0.0
% INFO    : Bus 10350	: V=1.022642, theta=-38.180641 -> V=1.0, theta=0.0
% INFO    : Bus 10351	: V=1.022642, theta=-38.180641 -> V=1.0, theta=0.0
% INFO    : Bus 10352	: V=1.022642, theta=-38.180641 -> V=1.0, theta=0.0
% INFO    : Bus 10353	: V=1.0147793, theta=-34.249261 -> V=1.0, theta=0.0
% INFO    : Bus 10354	: V=1.0217434, theta=-38.516919 -> V=1.0, theta=0.0
% INFO    : Bus 10355	: V=1.0172083, theta=-38.746164 -> V=1.0, theta=0.0
% INFO    : Bus 10356	: V=1.0263662, theta=-36.848311 -> V=1.0, theta=0.0
% INFO    : Bus 10357	: V=1.0203062, theta=-36.299832 -> V=1.0, theta=0.0
% INFO    : Bus 10358	: V=1.0115547, theta=-39.371343 -> V=1.0, theta=0.0
% INFO    : Bus 10359	: V=1.0193867, theta=-36.577917 -> V=1.0, theta=0.0
% INFO    : Bus 10360	: V=1.0193867, theta=-36.577917 -> V=1.0, theta=0.0
% INFO    : Bus 10361	: V=1.0270841, theta=-36.759788 -> V=1.0, theta=0.0
% INFO    : Bus 10362	: V=1.0155994, theta=-38.507851 -> V=1.0, theta=0.0
% INFO    : Bus 10363	: V=1.0187105, theta=-37.510131 -> V=1.0, theta=0.0
% INFO    : Bus 10364	: V=1.0191266, theta=-37.492828 -> V=1.0, theta=0.0
% INFO    : Bus 10365	: V=1.0317838, theta=-36.279445 -> V=1.0, theta=0.0
% INFO    : Bus 10366	: V=1.0315441, theta=-36.303042 -> V=1.0, theta=0.0
% INFO    : Bus 10367	: V=1.0190511, theta=-37.383924 -> V=1.0, theta=0.0
% INFO    : Bus 10368	: V=1.0188753, theta=-36.755862 -> V=1.0, theta=0.0
% INFO    : Bus 10369	: V=1.0217088, theta=-32.737215 -> V=1.0, theta=0.0
% INFO    : Bus 10370	: V=1.0234834, theta=-35.305408 -> V=1.0, theta=0.0
% INFO    : Bus 10371	: V=1.0160199, theta=-38.456825 -> V=1.0, theta=0.0
% INFO    : Bus 10372	: V=1.0158594, theta=-38.481417 -> V=1.0, theta=0.0
% INFO    : Bus 10373	: V=1.0161944, theta=-38.43208 -> V=1.0, theta=0.0
% INFO    : Bus 10374	: V=1.0236628, theta=-38.866144 -> V=1.0, theta=0.0
% INFO    : Bus 10375	: V=1.0318425, theta=-36.973389 -> V=1.0, theta=0.0
% INFO    : Bus 10376	: V=1.0316249, theta=-37.002685 -> V=1.0, theta=0.0
% INFO    : Bus 10377	: V=1.0242239, theta=-38.57736 -> V=1.0, theta=0.0
% INFO    : Bus 10378	: V=1.0056754, theta=-35.477464 -> V=1.0, theta=0.0
% INFO    : Bus 10379	: V=1.005429, theta=-35.509336 -> V=1.0, theta=0.0
% INFO    : Bus 10380	: V=1.0229687, theta=-35.020828 -> V=1.0, theta=0.0
% INFO    : Bus 10381	: V=1.0221532, theta=-35.812336 -> V=1.0, theta=0.0
% INFO    : Bus 10382	: V=1.0223247, theta=-35.794334 -> V=1.0, theta=0.0
% INFO    : Bus 10383	: V=1.0401137, theta=-37.611163 -> V=1.0, theta=0.0
% INFO    : Bus 10384	: V=1.0395949, theta=-37.63776 -> V=1.0, theta=0.0
% INFO    : Bus 10385	: V=1.0192945, theta=-36.373259 -> V=1.0, theta=0.0
% INFO    : Bus 10386	: V=1.0195021, theta=-36.350561 -> V=1.0, theta=0.0
% INFO    : Bus 10387	: V=1.0166695, theta=-37.035955 -> V=1.0, theta=0.0
% INFO    : Bus 10388	: V=1.016989, theta=-37.013753 -> V=1.0, theta=0.0
% INFO    : Bus 10389	: V=1.0163272, theta=-37.059507 -> V=1.0, theta=0.0
% INFO    : Bus 10390	: V=1.0186062, theta=-36.781302 -> V=1.0, theta=0.0
% INFO    : Bus 10391	: V=1.0174445, theta=-38.709492 -> V=1.0, theta=0.0
% INFO    : Bus 10392	: V=1.0173435, theta=-38.725308 -> V=1.0, theta=0.0
% INFO    : Bus 10393	: V=1.0157948, theta=-38.355208 -> V=1.0, theta=0.0
% INFO    : Bus 10394	: V=1.0179762, theta=-37.260794 -> V=1.0, theta=0.0
% INFO    : Bus 10395	: V=1.0363443, theta=-36.46882 -> V=1.0, theta=0.0
% INFO    : Bus 10396	: V=1.0379485, theta=-36.494094 -> V=1.0, theta=0.0
% INFO    : Bus 10397	: V=1.0294633, theta=-34.663774 -> V=1.0, theta=0.0
% INFO    : Bus 10398	: V=1.0243601, theta=-35.985009 -> V=1.0, theta=0.0
% INFO    : Bus 10399	: V=1.0183612, theta=-37.053056 -> V=1.0, theta=0.0
% INFO    : Bus 10400	: V=1.0182078, theta=-37.072653 -> V=1.0, theta=0.0
% INFO    : Bus 10401	: V=1.0185107, theta=-37.036104 -> V=1.0, theta=0.0
% INFO    : Bus 10402	: V=1.0220577, theta=-36.577768 -> V=1.0, theta=0.0
% INFO    : Bus 10403	: V=1.0222566, theta=-36.558433 -> V=1.0, theta=0.0
% INFO    : Bus 10404	: V=1.021852, theta=-36.594801 -> V=1.0, theta=0.0
% INFO    : Bus 10405	: V=1.0220577, theta=-36.577768 -> V=1.0, theta=0.0
% INFO    : Bus 10406	: V=1.0268109, theta=-38.572156 -> V=1.0, theta=0.0
% INFO    : Bus 10407	: V=1.0218253, theta=-38.542805 -> V=1.0, theta=0.0
% INFO    : Bus 10408	: V=1.0330693, theta=-37.20144 -> V=1.0, theta=0.0
% INFO    : Bus 10409	: V=1.0355438, theta=-36.838046 -> V=1.0, theta=0.0
% INFO    : Bus 10410	: V=1.0163472, theta=-38.634328 -> V=1.0, theta=0.0
% INFO    : Bus 10411	: V=1.0313735, theta=-36.728911 -> V=1.0, theta=0.0
% INFO    : Bus 10412	: V=1.029346, theta=-37.306172 -> V=1.0, theta=0.0
% INFO    : Bus 10413	: V=1.0291012, theta=-37.340718 -> V=1.0, theta=0.0
% INFO    : Bus 10414	: V=1.0268868, theta=-33.547313 -> V=1.0, theta=0.0
% INFO    : Bus 10415	: V=1.0165519, theta=-38.313425 -> V=1.0, theta=0.0
% INFO    : Bus 10416	: V=1.013831, theta=-38.36162 -> V=1.0, theta=0.0
% INFO    : Bus 10417	: V=1.0167002, theta=-38.093866 -> V=1.0, theta=0.0
% INFO    : Bus 10418	: V=1.0210659, theta=-38.793431 -> V=1.0, theta=0.0
% INFO    : Bus 10419	: V=1.0207676, theta=-38.818878 -> V=1.0, theta=0.0
% INFO    : Bus 10420	: V=1.0389763, theta=-36.145702 -> V=1.0, theta=0.0
% INFO    : Bus 10421	: V=1.0336622, theta=-36.785035 -> V=1.0, theta=0.0
% INFO    : Bus 10422	: V=1.0190205, theta=-38.517754 -> V=1.0, theta=0.0
% INFO    : Bus 10423	: V=1.018839, theta=-38.540146 -> V=1.0, theta=0.0
% INFO    : Bus 10424	: V=1.0177461, theta=-37.990221 -> V=1.0, theta=0.0
% INFO    : Bus 10425	: V=1.0175487, theta=-38.01456 -> V=1.0, theta=0.0
% INFO    : Bus 10426	: V=1.0306898, theta=-37.239702 -> V=1.0, theta=0.0
% INFO    : Bus 10427	: V=1.0135634, theta=-33.644541 -> V=1.0, theta=0.0
% INFO    : Bus 10428	: V=1.0364063, theta=-36.502186 -> V=1.0, theta=0.0
% INFO    : Bus 10429	: V=1.0132572, theta=-33.680068 -> V=1.0, theta=0.0
% INFO    : Bus 10430	: V=1.0287261, theta=-38.536004 -> V=1.0, theta=0.0
% INFO    : Bus 10431	: V=1.0283716, theta=-38.504389 -> V=1.0, theta=0.0
% INFO    : Bus 10432	: V=1.0327552, theta=-32.326818 -> V=1.0, theta=0.0
% INFO    : Bus 10433	: V=1.0341252, theta=-34.798226 -> V=1.0, theta=0.0
% INFO    : Bus 10434	: V=1.0273564, theta=-35.937847 -> V=1.0, theta=0.0
% INFO    : Bus 10435	: V=1.0269126, theta=-34.851474 -> V=1.0, theta=0.0
% INFO    : Bus 10436	: V=1.0237884, theta=-38.283237 -> V=1.0, theta=0.0
% INFO    : Bus 10437	: V=1.0219915, theta=-38.469691 -> V=1.0, theta=0.0
% INFO    : Bus 10438	: V=1.0217868, theta=-38.495292 -> V=1.0, theta=0.0
% INFO    : Bus 10439	: V=1.0224385, theta=-35.649903 -> V=1.0, theta=0.0
% INFO    : Bus 10440	: V=1.0200376, theta=-35.551659 -> V=1.0, theta=0.0
% INFO    : Bus 10441	: V=1.0230366, theta=-35.829092 -> V=1.0, theta=0.0
% INFO    : Bus 10442	: V=1.0156604, theta=-34.000368 -> V=1.0, theta=0.0
% INFO    : Bus 10443	: V=1.0159024, theta=-33.975416 -> V=1.0, theta=0.0
% INFO    : Bus 10444	: V=1.0156604, theta=-34.000368 -> V=1.0, theta=0.0
% INFO    : Bus 10445	: V=1.033759, theta=-37.192425 -> V=1.0, theta=0.0
% INFO    : Bus 10446	: V=1.0340421, theta=-37.159332 -> V=1.0, theta=0.0
% INFO    : Bus 10447	: V=1.034824, theta=-36.691514 -> V=1.0, theta=0.0
% INFO    : Bus 10448	: V=1.0345241, theta=-36.721678 -> V=1.0, theta=0.0
% INFO    : Bus 10449	: V=1.0187739, theta=-36.83718 -> V=1.0, theta=0.0
% INFO    : Bus 10450	: V=1.0195658, theta=-36.577133 -> V=1.0, theta=0.0
% INFO    : Bus 10451	: V=1.0192107, theta=-36.604869 -> V=1.0, theta=0.0
% INFO    : Bus 10452	: V=1.0173182, theta=-38.417094 -> V=1.0, theta=0.0
% INFO    : Bus 10453	: V=1.0182626, theta=-38.664721 -> V=1.0, theta=0.0
% INFO    : Bus 10454	: V=1.0185312, theta=-38.638828 -> V=1.0, theta=0.0
% INFO    : Bus 10455	: V=1.0182626, theta=-38.664721 -> V=1.0, theta=0.0
% INFO    : Bus 10456	: V=1.0081299, theta=-33.650774 -> V=1.0, theta=0.0
% INFO    : Bus 10457	: V=1.0239805, theta=-34.479157 -> V=1.0, theta=0.0
% INFO    : Bus 10458	: V=1.0396924, theta=-36.213565 -> V=1.0, theta=0.0
% INFO    : Bus 10459	: V=1.0096566, theta=-33.846527 -> V=1.0, theta=0.0
% INFO    : Bus 10460	: V=1.0432743, theta=-35.694179 -> V=1.0, theta=0.0
% INFO    : Bus 10461	: V=1.0193159, theta=-38.304738 -> V=1.0, theta=0.0
% INFO    : Bus 10462	: V=1.0228399, theta=-34.14712 -> V=1.0, theta=0.0
% INFO    : Bus 10463	: V=1.0205043, theta=-36.181988 -> V=1.0, theta=0.0
% INFO    : Bus 10464	: V=1.0243953, theta=-38.499604 -> V=1.0, theta=0.0
% INFO    : Bus 10465	: V=1.0236961, theta=-38.358839 -> V=1.0, theta=0.0
% INFO    : Bus 10466	: V=1.0242286, theta=-37.731964 -> V=1.0, theta=0.0
% INFO    : Bus 10467	: V=1.0235816, theta=-37.380197 -> V=1.0, theta=0.0
% INFO    : Bus 10468	: V=1.0137003, theta=-33.83624 -> V=1.0, theta=0.0
% INFO    : Bus 10469	: V=1.0270826, theta=-38.096161 -> V=1.0, theta=0.0
% INFO    : Bus 10470	: V=1.0181071, theta=-34.867635 -> V=1.0, theta=0.0
% INFO    : Bus 10471	: V=1.0182231, theta=-34.845058 -> V=1.0, theta=0.0
% INFO    : Bus 10472	: V=1.0181071, theta=-34.867635 -> V=1.0, theta=0.0
% INFO    : Bus 10473	: V=1.0208583, theta=-36.047272 -> V=1.0, theta=0.0
% INFO    : Bus 10474	: V=1.0207018, theta=-36.06689 -> V=1.0, theta=0.0
% INFO    : Bus 10475	: V=1.016546, theta=-37.658572 -> V=1.0, theta=0.0
% INFO    : Bus 10476	: V=1.02229, theta=-32.656719 -> V=1.0, theta=0.0
% INFO    : Bus 10477	: V=1.0306585, theta=-37.073543 -> V=1.0, theta=0.0
% INFO    : Bus 10478	: V=1.0287157, theta=-36.891302 -> V=1.0, theta=0.0
% INFO    : Bus 10479	: V=1.028543, theta=-36.907341 -> V=1.0, theta=0.0
% INFO    : Bus 10480	: V=1.0288989, theta=-36.87295 -> V=1.0, theta=0.0
% INFO    : Bus 10481	: V=1.0291459, theta=-37.001037 -> V=1.0, theta=0.0
% INFO    : Bus 10482	: V=1.0290343, theta=-37.019996 -> V=1.0, theta=0.0
% INFO    : Bus 10483	: V=1.0140287, theta=-38.205178 -> V=1.0, theta=0.0
% INFO    : Bus 10484	: V=1.0310636, theta=-37.181994 -> V=1.0, theta=0.0
% INFO    : Bus 10485	: V=1.0118633, theta=-38.085788 -> V=1.0, theta=0.0
% INFO    : Bus 10486	: V=1.0125805, theta=-37.276441 -> V=1.0, theta=0.0
% INFO    : Bus 10487	: V=1.0125193, theta=-37.803744 -> V=1.0, theta=0.0
% INFO    : Bus 10488	: V=1.0314371, theta=-36.922944 -> V=1.0, theta=0.0
% INFO    : Bus 10489	: V=1.025558, theta=-36.965242 -> V=1.0, theta=0.0
% INFO    : Bus 10490	: V=1.0186684, theta=-37.851682 -> V=1.0, theta=0.0
% INFO    : Bus 10491	: V=1.0184613, theta=-37.876696 -> V=1.0, theta=0.0
% INFO    : Bus 10492	: V=1.0116683, theta=-38.059032 -> V=1.0, theta=0.0
% INFO    : Bus 10493	: V=1.0362709, theta=-33.196678 -> V=1.0, theta=0.0
% INFO    : Bus 10494	: V=1.0362296, theta=-33.202305 -> V=1.0, theta=0.0
% INFO    : Bus 10495	: V=1.0143745, theta=-35.303922 -> V=1.0, theta=0.0
% INFO    : Bus 10496	: V=1.0131282, theta=-33.465891 -> V=1.0, theta=0.0
% INFO    : Bus 10497	: V=1.0128045, theta=-33.49575 -> V=1.0, theta=0.0
% INFO    : Bus 10498	: V=1.0260751, theta=-34.84101 -> V=1.0, theta=0.0
% INFO    : Bus 10499	: V=1.0250625, theta=-35.016223 -> V=1.0, theta=0.0
% INFO    : Bus 10500	: V=1.0153591, theta=-37.046939 -> V=1.0, theta=0.0
% INFO    : Bus 10501	: V=1.0255165, theta=-34.946881 -> V=1.0, theta=0.0
% INFO    : Bus 10502	: V=1.0174929, theta=-37.92648 -> V=1.0, theta=0.0
% INFO    : Bus 10503	: V=1.0286893, theta=-36.413614 -> V=1.0, theta=0.0
% INFO    : Bus 10504	: V=1.0381967, theta=-36.026236 -> V=1.0, theta=0.0
% INFO    : Bus 10505	: V=1.0288704, theta=-36.813076 -> V=1.0, theta=0.0
% INFO    : Bus 10506	: V=1.0264486, theta=-35.955433 -> V=1.0, theta=0.0
% INFO    : Bus 10507	: V=1.0263546, theta=-35.96997 -> V=1.0, theta=0.0
% INFO    : Bus 10508	: V=1.0273802, theta=-36.457193 -> V=1.0, theta=0.0
% INFO    : Bus 10509	: V=1.0272374, theta=-36.474472 -> V=1.0, theta=0.0
% INFO    : Bus 10510	: V=1.0275155, theta=-36.438623 -> V=1.0, theta=0.0
% INFO    : Bus 10511	: V=1.0273802, theta=-36.457193 -> V=1.0, theta=0.0
% INFO    : Bus 10512	: V=1.0301294, theta=-36.120478 -> V=1.0, theta=0.0
% INFO    : Bus 10513	: V=1.0300655, theta=-36.129936 -> V=1.0, theta=0.0
% INFO    : Bus 10514	: V=1.0261485, theta=-33.724016 -> V=1.0, theta=0.0
% INFO    : Bus 10515	: V=1.0207205, theta=-34.52672 -> V=1.0, theta=0.0
% INFO    : Bus 10516	: V=1.0287763, theta=-35.647875 -> V=1.0, theta=0.0
% INFO    : Bus 10517	: V=1.0238572, theta=-28.764159 -> V=1.0, theta=0.0
% INFO    : Bus 10518	: V=1.0316694, theta=-30.306538 -> V=1.0, theta=0.0
% INFO    : Bus 10519	: V=1.01812, theta=-29.463124 -> V=1.0, theta=0.0
% INFO    : Bus 10520	: V=1.0388048, theta=-27.321296 -> V=1.0, theta=0.0
% INFO    : Bus 10521	: V=1.038768, theta=-27.326042 -> V=1.0, theta=0.0
% INFO    : Bus 10522	: V=1.0388369, theta=-27.316558 -> V=1.0, theta=0.0
% INFO    : Bus 10523	: V=1.0139853, theta=-28.221058 -> V=1.0, theta=0.0
% INFO    : Bus 10524	: V=1.0303666, theta=-29.661871 -> V=1.0, theta=0.0
% INFO    : Bus 10525	: V=1.0226295, theta=-32.157888 -> V=1.0, theta=0.0
% INFO    : Bus 10526	: V=1.0417189, theta=-23.356082 -> V=1.0, theta=0.0
% INFO    : Bus 10527	: V=1.026324, theta=-25.992031 -> V=1.0, theta=0.0
% INFO    : Bus 10528	: V=1.0263036, theta=-25.99514 -> V=1.0, theta=0.0
% INFO    : Bus 10529	: V=1.025942, theta=-25.524994 -> V=1.0, theta=0.0
% INFO    : Bus 10530	: V=1.0221294, theta=-27.275237 -> V=1.0, theta=0.0
% INFO    : Bus 10531	: V=1.0156939, theta=-28.680648 -> V=1.0, theta=0.0
% INFO    : Bus 10532	: V=1.0230427, theta=-26.523053 -> V=1.0, theta=0.0
% INFO    : Bus 10533	: V=1.0227164, theta=-26.551258 -> V=1.0, theta=0.0
% INFO    : Bus 10534	: V=1.0321423, theta=-22.001879 -> V=1.0, theta=0.0
% INFO    : Bus 10535	: V=1.0304295, theta=-25.933967 -> V=1.0, theta=0.0
% INFO    : Bus 10536	: V=1.0217625, theta=-26.436716 -> V=1.0, theta=0.0
% INFO    : Bus 10537	: V=1.0347984, theta=-27.492773 -> V=1.0, theta=0.0
% INFO    : Bus 10538	: V=1.0349144, theta=-27.48205 -> V=1.0, theta=0.0
% INFO    : Bus 10539	: V=1.0346634, theta=-27.504157 -> V=1.0, theta=0.0
% INFO    : Bus 10540	: V=1.027539, theta=-26.147722 -> V=1.0, theta=0.0
% INFO    : Bus 10541	: V=1.0305095, theta=-25.484231 -> V=1.0, theta=0.0
% INFO    : Bus 10542	: V=1.0209365, theta=-27.07451 -> V=1.0, theta=0.0
% INFO    : Bus 10543	: V=1.0249578, theta=-26.489619 -> V=1.0, theta=0.0
% INFO    : Bus 10544	: V=1.0251039, theta=-26.468756 -> V=1.0, theta=0.0
% INFO    : Bus 10545	: V=1.0249578, theta=-26.489619 -> V=1.0, theta=0.0
% INFO    : Bus 10546	: V=1.039769, theta=-23.831369 -> V=1.0, theta=0.0
% INFO    : Bus 10547	: V=1.0396382, theta=-23.839793 -> V=1.0, theta=0.0
% INFO    : Bus 10548	: V=1.0261741, theta=-24.783035 -> V=1.0, theta=0.0
% INFO    : Bus 10549	: V=1.0259363, theta=-24.80982 -> V=1.0, theta=0.0
% INFO    : Bus 10550	: V=1.0287637, theta=-24.692868 -> V=1.0, theta=0.0
% INFO    : Bus 10551	: V=1.0405991, theta=-23.776084 -> V=1.0, theta=0.0
% INFO    : Bus 10552	: V=1.0405753, theta=-23.779059 -> V=1.0, theta=0.0
% INFO    : Bus 10553	: V=1.0406224, theta=-23.773034 -> V=1.0, theta=0.0
% INFO    : Bus 10554	: V=1.0356691, theta=-23.366966 -> V=1.0, theta=0.0
% INFO    : Bus 10555	: V=1.0392319, theta=-24.943068 -> V=1.0, theta=0.0
% INFO    : Bus 10556	: V=1.0392677, theta=-24.939076 -> V=1.0, theta=0.0
% INFO    : Bus 10557	: V=1.0250491, theta=-25.182672 -> V=1.0, theta=0.0
% INFO    : Bus 10558	: V=1.0277215, theta=-23.392146 -> V=1.0, theta=0.0
% INFO    : Bus 10559	: V=1.0275735, theta=-23.302539 -> V=1.0, theta=0.0
% INFO    : Bus 10560	: V=1.0282542, theta=-24.133323 -> V=1.0, theta=0.0
% INFO    : Bus 10561	: V=1.0282169, theta=-24.138414 -> V=1.0, theta=0.0
% INFO    : Bus 10562	: V=1.0282875, theta=-24.128384 -> V=1.0, theta=0.0
% INFO    : Bus 10563	: V=1.0441356, theta=-20.309215 -> V=1.0, theta=0.0
% INFO    : Bus 10564	: V=1.0440724, theta=-20.318215 -> V=1.0, theta=0.0
% INFO    : Bus 10565	: V=1.0442011, theta=-20.299294 -> V=1.0, theta=0.0
% INFO    : Bus 10566	: V=1.0339567, theta=-23.745289 -> V=1.0, theta=0.0
% INFO    : Bus 10567	: V=1.0274944, theta=-21.272468 -> V=1.0, theta=0.0
% INFO    : Bus 10568	: V=1.0277662, theta=-21.251072 -> V=1.0, theta=0.0
% INFO    : Bus 10569	: V=1.0361538, theta=-24.092257 -> V=1.0, theta=0.0
% INFO    : Bus 10570	: V=1.0360419, theta=-24.107664 -> V=1.0, theta=0.0
% INFO    : Bus 10571	: V=1.0415608, theta=-20.016659 -> V=1.0, theta=0.0
% INFO    : Bus 10572	: V=1.0296151, theta=-21.100819 -> V=1.0, theta=0.0
% INFO    : Bus 10573	: V=1.029534, theta=-21.113158 -> V=1.0, theta=0.0
% INFO    : Bus 10574	: V=1.0304905, theta=-20.467446 -> V=1.0, theta=0.0
% INFO    : Bus 10575	: V=1.0306714, theta=-20.448958 -> V=1.0, theta=0.0
% INFO    : Bus 10576	: V=1.0411164, theta=-23.080948 -> V=1.0, theta=0.0
% INFO    : Bus 10577	: V=1.0267241, theta=-20.894424 -> V=1.0, theta=0.0
% INFO    : Bus 10578	: V=1.0356627, theta=-21.373803 -> V=1.0, theta=0.0
% INFO    : Bus 10579	: V=1.0401792, theta=-21.067661 -> V=1.0, theta=0.0
% INFO    : Bus 10580	: V=1.0401021, theta=-21.074463 -> V=1.0, theta=0.0
% INFO    : Bus 10581	: V=1.0263219, theta=-20.712569 -> V=1.0, theta=0.0
% INFO    : Bus 10582	: V=1.0370985, theta=-21.000199 -> V=1.0, theta=0.0
% INFO    : Bus 10583	: V=1.0284974, theta=-20.320012 -> V=1.0, theta=0.0
% INFO    : Bus 10584	: V=1.0283967, theta=-20.340399 -> V=1.0, theta=0.0
% INFO    : Bus 10585	: V=1.037636, theta=-22.402332 -> V=1.0, theta=0.0
% INFO    : Bus 10586	: V=1.0344217, theta=-20.590281 -> V=1.0, theta=0.0
% INFO    : Bus 10587	: V=1.0423895, theta=-22.088591 -> V=1.0, theta=0.0
% INFO    : Bus 10588	: V=1.0341654, theta=-20.615045 -> V=1.0, theta=0.0
% INFO    : Bus 10589	: V=1.0250373, theta=-20.4214 -> V=1.0, theta=0.0
% INFO    : Bus 10590	: V=1.0245041, theta=-20.458217 -> V=1.0, theta=0.0
% INFO    : Bus 10591	: V=1.0303751, theta=-20.099334 -> V=1.0, theta=0.0
% INFO    : Bus 10592	: V=1.0301987, theta=-20.118436 -> V=1.0, theta=0.0
% INFO    : Bus 10593	: V=1.0305395, theta=-20.080194 -> V=1.0, theta=0.0
% INFO    : Bus 10594	: V=1.0289153, theta=-19.275718 -> V=1.0, theta=0.0
% INFO    : Bus 10595	: V=1.0379327, theta=-20.437309 -> V=1.0, theta=0.0
% INFO    : Bus 10596	: V=1.0378121, theta=-20.449463 -> V=1.0, theta=0.0
% INFO    : Bus 10597	: V=1.0243003, theta=-21.113103 -> V=1.0, theta=0.0
% INFO    : Bus 10598	: V=1.0144428, theta=-20.932463 -> V=1.0, theta=0.0
% INFO    : Bus 10599	: V=1.0335424, theta=-20.406666 -> V=1.0, theta=0.0
% INFO    : Bus 10600	: V=1.0313718, theta=-21.740885 -> V=1.0, theta=0.0
% INFO    : Bus 10601	: V=1.0287978, theta=-19.400389 -> V=1.0, theta=0.0
% INFO    : Bus 10602	: V=1.0141662, theta=-20.583901 -> V=1.0, theta=0.0
% INFO    : Bus 10603	: V=1.0147143, theta=-20.551175 -> V=1.0, theta=0.0
% INFO    : Bus 10604	: V=1.0313348, theta=-19.836145 -> V=1.0, theta=0.0
% INFO    : Bus 10605	: V=1.029478, theta=-20.07704 -> V=1.0, theta=0.0
% INFO    : Bus 10606	: V=1.0339784, theta=-22.144422 -> V=1.0, theta=0.0
% INFO    : Bus 10607	: V=1.0284949, theta=-19.599624 -> V=1.0, theta=0.0
% INFO    : Bus 10608	: V=1.0289701, theta=-19.555853 -> V=1.0, theta=0.0
% INFO    : Bus 10609	: V=1.0302068, theta=-20.507036 -> V=1.0, theta=0.0
% INFO    : Bus 10610	: V=1.0392954, theta=-19.138861 -> V=1.0, theta=0.0
% INFO    : Bus 10611	: V=1.0393762, theta=-19.127272 -> V=1.0, theta=0.0
% INFO    : Bus 10612	: V=1.0392954, theta=-19.138861 -> V=1.0, theta=0.0
% INFO    : Bus 10613	: V=1.0233453, theta=-19.865286 -> V=1.0, theta=0.0
% INFO    : Bus 10614	: V=1.0353214, theta=-19.885181 -> V=1.0, theta=0.0
% INFO    : Bus 10615	: V=1.0258365, theta=-20.354308 -> V=1.0, theta=0.0
% INFO    : Bus 10616	: V=1.0257913, theta=-20.360313 -> V=1.0, theta=0.0
% INFO    : Bus 10617	: V=1.0386812, theta=-19.108318 -> V=1.0, theta=0.0
% INFO    : Bus 10618	: V=1.0316535, theta=-19.986257 -> V=1.0, theta=0.0
% INFO    : Bus 10619	: V=1.0323337, theta=-19.037622 -> V=1.0, theta=0.0
% INFO    : Bus 10620	: V=1.0322702, theta=-19.048694 -> V=1.0, theta=0.0
% INFO    : Bus 10621	: V=1.0378993, theta=-17.501432 -> V=1.0, theta=0.0
% INFO    : Bus 10622	: V=1.0378276, theta=-17.510931 -> V=1.0, theta=0.0
% INFO    : Bus 10623	: V=1.0379767, theta=-17.491638 -> V=1.0, theta=0.0
% INFO    : Bus 10624	: V=1.0310686, theta=-15.876377 -> V=1.0, theta=0.0
% INFO    : Bus 10625	: V=1.0310013, theta=-15.884216 -> V=1.0, theta=0.0
% INFO    : Bus 10626	: V=1.0126108, theta=-20.513879 -> V=1.0, theta=0.0
% INFO    : Bus 10627	: V=1.0308916, theta=-18.505344 -> V=1.0, theta=0.0
% INFO    : Bus 10628	: V=1.0039998, theta=-21.294392 -> V=1.0, theta=0.0
% INFO    : Bus 10629	: V=1.0219284, theta=-19.50166 -> V=1.0, theta=0.0
% INFO    : Bus 10630	: V=1.0029399, theta=-21.244059 -> V=1.0, theta=0.0
% INFO    : Bus 10631	: V=0.992828, theta=-21.602746 -> V=1.0, theta=0.0
% INFO    : Bus 10632	: V=0.9928532, theta=-21.599685 -> V=1.0, theta=0.0
% INFO    : Bus 10633	: V=1.0040193, theta=-21.334359 -> V=1.0, theta=0.0
% INFO    : Bus 10634	: V=1.0122818, theta=-19.804954 -> V=1.0, theta=0.0
% INFO    : Bus 10635	: V=0.9818924, theta=-23.069354 -> V=1.0, theta=0.0
% INFO    : Bus 10636	: V=0.9848486, theta=-22.669135 -> V=1.0, theta=0.0
% INFO    : Bus 10637	: V=0.9843716, theta=-22.702941 -> V=1.0, theta=0.0
% INFO    : Bus 10638	: V=1.0252049, theta=-21.795412 -> V=1.0, theta=0.0
% INFO    : Bus 10639	: V=0.9945934, theta=-22.608228 -> V=1.0, theta=0.0
% INFO    : Bus 10640	: V=0.9948459, theta=-22.575192 -> V=1.0, theta=0.0
% INFO    : Bus 10641	: V=0.9953512, theta=-22.120865 -> V=1.0, theta=0.0
% INFO    : Bus 10642	: V=1.0260024, theta=-21.700571 -> V=1.0, theta=0.0
% INFO    : Bus 10643	: V=1.0259028, theta=-21.709936 -> V=1.0, theta=0.0
% INFO    : Bus 10644	: V=1.0261056, theta=-21.691126 -> V=1.0, theta=0.0
% INFO    : Bus 10645	: V=1.0180892, theta=-16.619287 -> V=1.0, theta=0.0
% INFO    : Bus 10646	: V=1.0179934, theta=-16.626082 -> V=1.0, theta=0.0
% INFO    : Bus 10647	: V=0.9855902, theta=-22.935579 -> V=1.0, theta=0.0
% INFO    : Bus 10648	: V=1.0283153, theta=-21.548702 -> V=1.0, theta=0.0
% INFO    : Bus 10649	: V=1.0262434, theta=-21.92504 -> V=1.0, theta=0.0
% INFO    : Bus 10650	: V=0.9879874, theta=-22.465436 -> V=1.0, theta=0.0
% INFO    : Bus 10651	: V=1.0254446, theta=-22.018994 -> V=1.0, theta=0.0
% INFO    : Bus 10652	: V=0.9934728, theta=-22.194713 -> V=1.0, theta=0.0
% INFO    : Bus 10653	: V=1.023984, theta=-21.27186 -> V=1.0, theta=0.0
% INFO    : Bus 10654	: V=1.0242489, theta=-21.254654 -> V=1.0, theta=0.0
% INFO    : Bus 10655	: V=1.0270488, theta=-21.663671 -> V=1.0, theta=0.0
% INFO    : Bus 10656	: V=1.0273029, theta=-21.64241 -> V=1.0, theta=0.0
% INFO    : Bus 10657	: V=0.9984233, theta=-22.515631 -> V=1.0, theta=0.0
% INFO    : Bus 10658	: V=0.9990422, theta=-21.513549 -> V=1.0, theta=0.0
% INFO    : Bus 10659	: V=1.0228491, theta=-17.38545 -> V=1.0, theta=0.0
% INFO    : Bus 10660	: V=0.9942749, theta=-22.138444 -> V=1.0, theta=0.0
% INFO    : Bus 10661	: V=1.003645, theta=-17.090327 -> V=1.0, theta=0.0
% INFO    : Bus 10662	: V=1.0317049, theta=-21.194954 -> V=1.0, theta=0.0
% INFO    : Bus 10663	: V=1.0054233, theta=-16.961647 -> V=1.0, theta=0.0
% INFO    : Bus 10664	: V=1.003645, theta=-17.090327 -> V=1.0, theta=0.0
% INFO    : Bus 10665	: V=0.9960663, theta=-22.530639 -> V=1.0, theta=0.0
% INFO    : Bus 10666	: V=1.0044418, theta=-20.894669 -> V=1.0, theta=0.0
% INFO    : Bus 10667	: V=1.0043968, theta=-20.900299 -> V=1.0, theta=0.0
% INFO    : Bus 10668	: V=0.9994665, theta=-21.821238 -> V=1.0, theta=0.0
% INFO    : Bus 10669	: V=1.015338, theta=-16.977849 -> V=1.0, theta=0.0
% INFO    : Bus 10670	: V=1.0036837, theta=-17.421765 -> V=1.0, theta=0.0
% INFO    : Bus 10671	: V=1.0131327, theta=-21.728586 -> V=1.0, theta=0.0
% INFO    : Bus 10672	: V=1.0197679, theta=-19.025674 -> V=1.0, theta=0.0
% INFO    : Bus 10673	: V=1.0015469, theta=-21.559094 -> V=1.0, theta=0.0
% INFO    : Bus 10674	: V=0.999263, theta=-21.862179 -> V=1.0, theta=0.0
% INFO    : Bus 10675	: V=0.9992035, theta=-21.871804 -> V=1.0, theta=0.0
% INFO    : Bus 10676	: V=1.0087654, theta=-20.573969 -> V=1.0, theta=0.0
% INFO    : Bus 10677	: V=1.0085607, theta=-20.594404 -> V=1.0, theta=0.0
% INFO    : Bus 10678	: V=1.0056347, theta=-20.975406 -> V=1.0, theta=0.0
% INFO    : Bus 10679	: V=0.9997515, theta=-21.761845 -> V=1.0, theta=0.0
% INFO    : Bus 10680	: V=1.0464451, theta=-19.462121 -> V=1.0, theta=0.0
% INFO    : Bus 10681	: V=1.0427191, theta=-20.794436 -> V=1.0, theta=0.0
% INFO    : Bus 10682	: V=1.0442648, theta=-22.46401 -> V=1.0, theta=0.0
% INFO    : Bus 10683	: V=1.0464451, theta=-19.462121 -> V=1.0, theta=0.0
% INFO    : Bus 10684	: V=1.0202696, theta=-19.018584 -> V=1.0, theta=0.0
% INFO    : Bus 10685	: V=1.0203248, theta=-18.733188 -> V=1.0, theta=0.0
% INFO    : Bus 10686	: V=1.0464451, theta=-19.462121 -> V=1.0, theta=0.0
% INFO    : Bus 10687	: V=1.0189806, theta=-18.983294 -> V=1.0, theta=0.0
% INFO    : Bus 10688	: V=1.0208299, theta=-18.834942 -> V=1.0, theta=0.0
% INFO    : Bus 10689	: V=1.0014392, theta=-20.54935 -> V=1.0, theta=0.0
% INFO    : Bus 10690	: V=1.0466426, theta=-21.151117 -> V=1.0, theta=0.0
% INFO    : Bus 10691	: V=1.0062542, theta=-17.742063 -> V=1.0, theta=0.0
% INFO    : Bus 10692	: V=1.0466386, theta=-21.151521 -> V=1.0, theta=0.0
% INFO    : Bus 10693	: V=1.0440061, theta=-30.498052 -> V=1.0, theta=0.0
% INFO    : Bus 10694	: V=1.048344, theta=-29.39072 -> V=1.0, theta=0.0
% INFO    : Bus 10695	: V=1.048378, theta=-29.261014 -> V=1.0, theta=0.0
% INFO    : Bus 10696	: V=1.043879, theta=-30.561542 -> V=1.0, theta=0.0
% INFO    : Bus 10697	: V=1.039324, theta=-23.860539 -> V=1.0, theta=0.0
% INFO    : Bus 10698	: V=1.0403376, theta=-26.293085 -> V=1.0, theta=0.0
% INFO    : Bus 10699	: V=1.001869, theta=-21.986501 -> V=1.0, theta=0.0
% INFO    : Bus 10700	: V=1.0393169, theta=-23.861117 -> V=1.0, theta=0.0
% INFO    : Bus 10701	: V=1.0395537, theta=-23.843753 -> V=1.0, theta=0.0
% INFO    : Bus 10702	: V=1.043, theta=-23.156187 -> V=1.0, theta=0.0
% INFO    : Bus 10703	: V=1.0605482, theta=-17.617373 -> V=1.0, theta=0.0
% INFO    : Bus 10704	: V=1.042987, theta=-23.157212 -> V=1.0, theta=0.0
% INFO    : Bus 10705	: V=1.0425587, theta=-23.23034 -> V=1.0, theta=0.0
% INFO    : Bus 10706	: V=1.043, theta=-23.156187 -> V=1.0, theta=0.0
% INFO    : Bus 10707	: V=1.0296075, theta=-19.511376 -> V=1.0, theta=0.0
% INFO    : Bus 10708	: V=1.0384437, theta=-22.048274 -> V=1.0, theta=0.0
% INFO    : Bus 10709	: V=1.0404228, theta=-26.040944 -> V=1.0, theta=0.0
% INFO    : Bus 10710	: V=1.0095772, theta=-18.47539 -> V=1.0, theta=0.0
% INFO    : Bus 10711	: V=1.0099543, theta=-18.710823 -> V=1.0, theta=0.0
% INFO    : Bus 10712	: V=1.0096973, theta=-18.749662 -> V=1.0, theta=0.0
% INFO    : Bus 10713	: V=1.0100231, theta=-18.790871 -> V=1.0, theta=0.0
% INFO    : Bus 10714	: V=1.0296075, theta=-19.511376 -> V=1.0, theta=0.0
% INFO    : Bus 10715	: V=1.0165861, theta=-19.166713 -> V=1.0, theta=0.0
% INFO    : Bus 10716	: V=1.0340041, theta=-19.793465 -> V=1.0, theta=0.0
% INFO    : Bus 10717	: V=1.0344018, theta=-20.107049 -> V=1.0, theta=0.0
% INFO    : Bus 10718	: V=1.0377647, theta=-21.673083 -> V=1.0, theta=0.0
% INFO    : Bus 10719	: V=1.0333697, theta=-22.956794 -> V=1.0, theta=0.0
% INFO    : Bus 10720	: V=1.0296684, theta=-24.189561 -> V=1.0, theta=0.0
% INFO    : Bus 10721	: V=1.0296684, theta=-24.189561 -> V=1.0, theta=0.0
% INFO    : Bus 10722	: V=1.0344018, theta=-20.107049 -> V=1.0, theta=0.0
% INFO    : Bus 10723	: V=1.0007151, theta=-19.683244 -> V=1.0, theta=0.0
% INFO    : Bus 10724	: V=1.0017941, theta=-19.408101 -> V=1.0, theta=0.0
% INFO    : Bus 10725	: V=1.0025794, theta=-19.5555 -> V=1.0, theta=0.0
% INFO    : Bus 10726	: V=1.0028828, theta=-19.524648 -> V=1.0, theta=0.0
% INFO    : Bus 10727	: V=1.0344018, theta=-20.107049 -> V=1.0, theta=0.0
% INFO    : Bus 10728	: V=1.0177121, theta=-32.151968 -> V=1.0, theta=0.0
% INFO    : Bus 10729	: V=1.0433796, theta=-35.519866 -> V=1.0, theta=0.0
% INFO    : Bus 10730	: V=1.0313019, theta=-34.444679 -> V=1.0, theta=0.0
% INFO    : Bus 10731	: V=1.0301187, theta=-36.188122 -> V=1.0, theta=0.0
% INFO    : Bus 10732	: V=1.0304491, theta=-35.536311 -> V=1.0, theta=0.0
% INFO    : Bus 10733	: V=1.0304491, theta=-35.536311 -> V=1.0, theta=0.0
% INFO    : Bus 10734	: V=1.0279786, theta=-28.719917 -> V=1.0, theta=0.0
% INFO    : Bus 10735	: V=1.0444724, theta=-31.406601 -> V=1.0, theta=0.0
% INFO    : Bus 10736	: V=1.0355211, theta=-35.90841 -> V=1.0, theta=0.0
% INFO    : Bus 10737	: V=1.0342534, theta=-28.049547 -> V=1.0, theta=0.0
% INFO    : Bus 10738	: V=1.0343807, theta=-28.033577 -> V=1.0, theta=0.0
% INFO    : Bus 10739	: V=1.026539, theta=-27.056181 -> V=1.0, theta=0.0
% INFO    : Bus 10740	: V=1.029357, theta=-29.592075 -> V=1.0, theta=0.0
% INFO    : Bus 10741	: V=1.0295479, theta=-31.271248 -> V=1.0, theta=0.0
% INFO    : Bus 10742	: V=1.0263439, theta=-26.760875 -> V=1.0, theta=0.0
% INFO    : Bus 10743	: V=1.026539, theta=-27.056181 -> V=1.0, theta=0.0
% INFO    : Bus 10744	: V=1.02621, theta=-26.693709 -> V=1.0, theta=0.0
% INFO    : Bus 10745	: V=1.0346824, theta=-20.927109 -> V=1.0, theta=0.0
% INFO    : Bus 10746	: V=1.0204915, theta=-16.97907 -> V=1.0, theta=0.0
% INFO    : Bus 10747	: V=1.0433189, theta=-16.81014 -> V=1.0, theta=0.0
% INFO    : Bus 10748	: V=1.0434257, theta=-18.171043 -> V=1.0, theta=0.0
% INFO    : Bus 10749	: V=1.0431807, theta=-19.352706 -> V=1.0, theta=0.0
% INFO    : Bus 10750	: V=1.0418685, theta=-15.244608 -> V=1.0, theta=0.0
% INFO    : Bus 10751	: V=1.0433189, theta=-16.81014 -> V=1.0, theta=0.0
% INFO    : Bus 10752	: V=1.0420871, theta=-15.782711 -> V=1.0, theta=0.0
% INFO    : Bus 10753	: V=1.0433189, theta=-16.81014 -> V=1.0, theta=0.0
% INFO    : Bus 10754	: V=1.0416722, theta=-15.376081 -> V=1.0, theta=0.0
% INFO    : Bus 10755	: V=1.0412538, theta=-14.985437 -> V=1.0, theta=0.0
% INFO    : Bus 10756	: V=1.0392262, theta=-29.471526 -> V=1.0, theta=0.0
% INFO    : Bus 10757	: V=1.0374279, theta=-29.943559 -> V=1.0, theta=0.0
% INFO    : Bus 10758	: V=1.0308452, theta=-28.120488 -> V=1.0, theta=0.0
% INFO    : Bus 10759	: V=1.0289493, theta=-29.582099 -> V=1.0, theta=0.0
% INFO    : Bus 10760	: V=1.0054052, theta=-32.050927 -> V=1.0, theta=0.0
% INFO    : Bus 10761	: V=1.0286687, theta=-34.973394 -> V=1.0, theta=0.0
% INFO    : Bus 10762	: V=1.0058085, theta=-31.907278 -> V=1.0, theta=0.0
% INFO    : Bus 10763	: V=1.0054052, theta=-32.050927 -> V=1.0, theta=0.0
% INFO    : Bus 10764	: V=1.0054052, theta=-32.050927 -> V=1.0, theta=0.0
% INFO    : Bus 10765	: V=1.0054052, theta=-32.050927 -> V=1.0, theta=0.0
% INFO    : Bus 10766	: V=1.0379977, theta=-14.275846 -> V=1.0, theta=0.0
% INFO    : Bus 10767	: V=1.0438662, theta=-15.124804 -> V=1.0, theta=0.0
% INFO    : Bus 10768	: V=1.0303911, theta=-11.797155 -> V=1.0, theta=0.0
% INFO    : Bus 10769	: V=1.0317207, theta=-26.521275 -> V=1.0, theta=0.0
% INFO    : Bus 10770	: V=1.0310916, theta=-27.537337 -> V=1.0, theta=0.0
% INFO    : Bus 10771	: V=1.0384184, theta=-25.577221 -> V=1.0, theta=0.0
% INFO    : Bus 10772	: V=1.0393928, theta=-25.658789 -> V=1.0, theta=0.0
% INFO    : Bus 10773	: V=1.0317207, theta=-26.521275 -> V=1.0, theta=0.0
% INFO    : Bus 10774	: V=1.037304, theta=-25.899177 -> V=1.0, theta=0.0
% INFO    : Bus 10775	: V=1.0570094, theta=-32.250619 -> V=1.0, theta=0.0
% INFO    : Bus 10776	: V=1.0317984, theta=-31.099772 -> V=1.0, theta=0.0
% INFO    : Bus 10777	: V=1.0569756, theta=-32.258486 -> V=1.0, theta=0.0
% INFO    : Bus 10778	: V=1.0256751, theta=-21.812674 -> V=1.0, theta=0.0
% INFO    : Bus 10779	: V=1.025635, theta=-21.827584 -> V=1.0, theta=0.0
% INFO    : Bus 10780	: V=1.0256751, theta=-21.812674 -> V=1.0, theta=0.0
% INFO    : Bus 10781	: V=1.0157918, theta=-32.44078 -> V=1.0, theta=0.0
% INFO    : Bus 10782	: V=1.0162156, theta=-29.778002 -> V=1.0, theta=0.0
% INFO    : Bus 10783	: V=1.0154759, theta=-28.540841 -> V=1.0, theta=0.0
% INFO    : Bus 10784	: V=1.0324591, theta=-37.268797 -> V=1.0, theta=0.0
% INFO    : Bus 10785	: V=1.0308924, theta=-37.518189 -> V=1.0, theta=0.0
% INFO    : Bus 10786	: V=1.0317165, theta=-37.086924 -> V=1.0, theta=0.0
% INFO    : Bus 10787	: V=1.0324591, theta=-37.268797 -> V=1.0, theta=0.0
% INFO    : Bus 10788	: V=1.0330408, theta=-25.474021 -> V=1.0, theta=0.0
% INFO    : Bus 10789	: V=1.0123101, theta=-16.26659 -> V=1.0, theta=0.0
% INFO    : Bus 10790	: V=1.01384, theta=-17.876317 -> V=1.0, theta=0.0
% INFO    : Bus 10791	: V=0.9959739, theta=-15.033939 -> V=1.0, theta=0.0
% INFO    : Bus 10792	: V=1.012246, theta=-16.274418 -> V=1.0, theta=0.0
% INFO    : Bus 10793	: V=1.0132808, theta=-16.22734 -> V=1.0, theta=0.0
% INFO    : Bus 10794	: V=1.0429952, theta=-28.695403 -> V=1.0, theta=0.0
% INFO    : Bus 10795	: V=1.0512353, theta=-31.066763 -> V=1.0, theta=0.0
% INFO    : Bus 10796	: V=1.0429952, theta=-28.695403 -> V=1.0, theta=0.0
% INFO    : Bus 10797	: V=1.044544, theta=-26.975273 -> V=1.0, theta=0.0
% INFO    : Bus 10798	: V=1.0269418, theta=-26.027509 -> V=1.0, theta=0.0
% INFO    : Bus 10799	: V=1.0428589, theta=-28.667164 -> V=1.0, theta=0.0
% INFO    : Bus 10800	: V=1.0459541, theta=-22.432905 -> V=1.0, theta=0.0
% INFO    : Bus 10801	: V=1.0190892, theta=-35.681932 -> V=1.0, theta=0.0
% INFO    : Bus 10802	: V=1.0443252, theta=-35.031033 -> V=1.0, theta=0.0
% INFO    : Bus 10803	: V=1.0443667, theta=-34.902631 -> V=1.0, theta=0.0
% INFO    : Bus 10804	: V=1.0379619, theta=-35.757803 -> V=1.0, theta=0.0
% INFO    : Bus 10805	: V=1.0288505, theta=-25.901682 -> V=1.0, theta=0.0
% INFO    : Bus 10806	: V=1.0234518, theta=-21.113366 -> V=1.0, theta=0.0
% INFO    : Bus 10807	: V=1.0260685, theta=-23.408935 -> V=1.0, theta=0.0
% INFO    : Bus 10808	: V=1.0420001, theta=-17.448164 -> V=1.0, theta=0.0
% INFO    : Bus 10809	: V=1.0402519, theta=-17.910176 -> V=1.0, theta=0.0
% INFO    : Bus 10810	: V=1.0340261, theta=-19.832423 -> V=1.0, theta=0.0
% INFO    : Bus 10811	: V=1.065347, theta=-11.188121 -> V=1.0, theta=0.0
% INFO    : Bus 10812	: V=1.0409389, theta=-18.099123 -> V=1.0, theta=0.0
% INFO    : Bus 10813	: V=1.0215274, theta=-30.761628 -> V=1.0, theta=0.0
% INFO    : Bus 10814	: V=1.0184866, theta=-32.577088 -> V=1.0, theta=0.0
% INFO    : Bus 10815	: V=1.0154788, theta=-36.014268 -> V=1.0, theta=0.0
% INFO    : Bus 10816	: V=1.0160924, theta=-35.761526 -> V=1.0, theta=0.0
% INFO    : Bus 10817	: V=1.0463312, theta=-15.693358 -> V=1.0, theta=0.0
% INFO    : Bus 10818	: V=1.042288, theta=-16.809235 -> V=1.0, theta=0.0
% INFO    : Bus 10819	: V=1.0465777, theta=-15.678506 -> V=1.0, theta=0.0
% INFO    : Bus 10820	: V=1.0422919, theta=-21.720327 -> V=1.0, theta=0.0
% INFO    : Bus 10821	: V=1.0422919, theta=-21.720327 -> V=1.0, theta=0.0
% INFO    : Bus 10822	: V=1.0422896, theta=-21.720624 -> V=1.0, theta=0.0
% INFO    : Bus 10823	: V=1.0422942, theta=-21.720054 -> V=1.0, theta=0.0
% INFO    : Bus 10824	: V=1.023977, theta=-13.94142 -> V=1.0, theta=0.0
% INFO    : Bus 10825	: V=1.0263992, theta=-14.704199 -> V=1.0, theta=0.0
% INFO    : Bus 10826	: V=1.0196784, theta=-16.133897 -> V=1.0, theta=0.0
% INFO    : Bus 10827	: V=1.028887, theta=-15.616133 -> V=1.0, theta=0.0
% INFO    : Bus 10828	: V=1.0295757, theta=-15.471532 -> V=1.0, theta=0.0
% INFO    : Bus 10829	: V=1.0231794, theta=-13.398411 -> V=1.0, theta=0.0
% INFO    : Bus 10830	: V=1.0234947, theta=-13.297899 -> V=1.0, theta=0.0
% INFO    : Bus 10831	: V=1.0233487, theta=-13.307251 -> V=1.0, theta=0.0
% INFO    : Bus 10832	: V=1.0236322, theta=-13.47398 -> V=1.0, theta=0.0
% INFO    : Bus 10833	: V=1.0233833, theta=-13.438432 -> V=1.0, theta=0.0
% INFO    : Bus 10834	: V=1.0234509, theta=-13.569617 -> V=1.0, theta=0.0
% INFO    : Bus 10835	: V=1.0289141, theta=-14.310036 -> V=1.0, theta=0.0
% INFO    : Bus 10836	: V=1.033122, theta=-35.730613 -> V=1.0, theta=0.0
% INFO    : Bus 10837	: V=1.0328282, theta=-35.837005 -> V=1.0, theta=0.0
% INFO    : Bus 10838	: V=1.0339641, theta=-33.014141 -> V=1.0, theta=0.0
% INFO    : Bus 10839	: V=1.0224995, theta=-38.171412 -> V=1.0, theta=0.0
% INFO    : Bus 10840	: V=1.0271336, theta=-35.604133 -> V=1.0, theta=0.0
% INFO    : Bus 10841	: V=1.0271336, theta=-35.604133 -> V=1.0, theta=0.0
% INFO    : Bus 10842	: V=1.0376655, theta=-30.63212 -> V=1.0, theta=0.0
% INFO    : Bus 10843	: V=1.034726, theta=-33.207113 -> V=1.0, theta=0.0
% INFO    : Bus 10844	: V=1.0372255, theta=-16.446863 -> V=1.0, theta=0.0
% INFO    : Bus 10845	: V=1.0380193, theta=-16.943477 -> V=1.0, theta=0.0
% INFO    : Bus 10846	: V=1.031334, theta=-19.238769 -> V=1.0, theta=0.0
% INFO    : Bus 10847	: V=1.0367424, theta=-15.800647 -> V=1.0, theta=0.0
% INFO    : Bus 10848	: V=1.0367385, theta=-15.948076 -> V=1.0, theta=0.0
% INFO    : Bus 10849	: V=1.036747, theta=-15.934315 -> V=1.0, theta=0.0
% INFO    : Bus 10850	: V=1.0365479, theta=-15.699913 -> V=1.0, theta=0.0
% INFO    : Bus 10851	: V=1.0367622, theta=-15.950527 -> V=1.0, theta=0.0
% INFO    : Bus 10852	: V=1.0368039, theta=-15.873462 -> V=1.0, theta=0.0
% INFO    : Bus 10853	: V=1.0372255, theta=-16.446863 -> V=1.0, theta=0.0
% INFO    : Bus 10854	: V=1.0385112, theta=-16.943502 -> V=1.0, theta=0.0
% INFO    : Bus 10855	: V=1.0365737, theta=-16.702375 -> V=1.0, theta=0.0
% INFO    : Bus 10856	: V=1.0395141, theta=-27.718211 -> V=1.0, theta=0.0
% INFO    : Bus 10857	: V=1.0391714, theta=-30.069146 -> V=1.0, theta=0.0
% INFO    : Bus 10858	: V=1.034961, theta=-32.931052 -> V=1.0, theta=0.0
% INFO    : Bus 10859	: V=1.0395141, theta=-27.718211 -> V=1.0, theta=0.0
% INFO    : Bus 10860	: V=1.0340624, theta=-26.613426 -> V=1.0, theta=0.0
% INFO    : Bus 10861	: V=1.041109, theta=-27.615676 -> V=1.0, theta=0.0
% INFO    : Bus 10862	: V=1.0411826, theta=-29.617523 -> V=1.0, theta=0.0
% INFO    : Bus 10863	: V=1.0419428, theta=-30.351091 -> V=1.0, theta=0.0
% INFO    : Bus 10864	: V=1.0058408, theta=-28.153433 -> V=1.0, theta=0.0
% INFO    : Bus 10865	: V=1.006183, theta=-27.33079 -> V=1.0, theta=0.0
% INFO    : Bus 10866	: V=1.0170196, theta=-36.464009 -> V=1.0, theta=0.0
% INFO    : Bus 10867	: V=0.9782139, theta=-33.762795 -> V=1.0, theta=0.0
% INFO    : Bus 10868	: V=1.0096299, theta=-20.926461 -> V=1.0, theta=0.0
% INFO    : Bus 10869	: V=1.0066943, theta=-19.569097 -> V=1.0, theta=0.0
% INFO    : Bus 10870	: V=1.0154974, theta=-17.567608 -> V=1.0, theta=0.0
% INFO    : Bus 10871	: V=0.9957567, theta=-21.908144 -> V=1.0, theta=0.0
% INFO    : Bus 10872	: V=1.0229334, theta=-16.771725 -> V=1.0, theta=0.0
% INFO    : Bus 10873	: V=1.0426322, theta=-21.197436 -> V=1.0, theta=0.0
% INFO    : Bus 10874	: V=1.0369219, theta=-14.420514 -> V=1.0, theta=0.0
% INFO    : Bus 10875	: V=1.0393134, theta=-15.13496 -> V=1.0, theta=0.0
% INFO    : Bus 10876	: V=1.0393814, theta=-15.546717 -> V=1.0, theta=0.0
% INFO    : Bus 10877	: V=1.0417975, theta=-15.827619 -> V=1.0, theta=0.0
% INFO    : Bus 10878	: V=1.0417975, theta=-15.827619 -> V=1.0, theta=0.0
% INFO    : Bus 10879	: V=1.0364384, theta=-14.105034 -> V=1.0, theta=0.0
% INFO    : Bus 10880	: V=1.0366226, theta=-14.090763 -> V=1.0, theta=0.0
% INFO    : Bus 10881	: V=1.0363584, theta=-14.036108 -> V=1.0, theta=0.0
% INFO    : Bus 10882	: V=1.0369219, theta=-14.420514 -> V=1.0, theta=0.0
% INFO    : Bus 10883	: V=1.0369219, theta=-14.420514 -> V=1.0, theta=0.0
% INFO    : Bus 10884	: V=1.0363651, theta=-13.802104 -> V=1.0, theta=0.0
% INFO    : Bus 10885	: V=1.0364826, theta=-14.561729 -> V=1.0, theta=0.0
% INFO    : Bus 10886	: V=1.0369219, theta=-14.420514 -> V=1.0, theta=0.0
% INFO    : Bus 10887	: V=1.0327044, theta=-35.979462 -> V=1.0, theta=0.0
% INFO    : Bus 10888	: V=1.0358681, theta=-36.720475 -> V=1.0, theta=0.0
% INFO    : Bus 10889	: V=1.0385751, theta=-34.590242 -> V=1.0, theta=0.0
% INFO    : Bus 10890	: V=1.0327044, theta=-35.979462 -> V=1.0, theta=0.0
% INFO    : Bus 10891	: V=1.0323143, theta=-35.999369 -> V=1.0, theta=0.0
% INFO    : Bus 10892	: V=1.0256632, theta=-25.392807 -> V=1.0, theta=0.0
% INFO    : Bus 10893	: V=1.0441463, theta=-28.037462 -> V=1.0, theta=0.0
% INFO    : Bus 10894	: V=1.0598805, theta=-32.190669 -> V=1.0, theta=0.0
% INFO    : Bus 10895	: V=1.0245792, theta=-24.805939 -> V=1.0, theta=0.0
% INFO    : Bus 10896	: V=1.0245008, theta=-24.765732 -> V=1.0, theta=0.0
% INFO    : Bus 10897	: V=1.0249178, theta=-24.985818 -> V=1.0, theta=0.0
% INFO    : Bus 10898	: V=1.0247816, theta=-24.903717 -> V=1.0, theta=0.0
% INFO    : Bus 10899	: V=1.039589, theta=-19.373836 -> V=1.0, theta=0.0
% INFO    : Bus 10900	: V=1.0414139, theta=-20.043085 -> V=1.0, theta=0.0
% INFO    : Bus 10901	: V=1.0380327, theta=-16.721662 -> V=1.0, theta=0.0
% INFO    : Bus 10902	: V=1.039589, theta=-19.373836 -> V=1.0, theta=0.0
% INFO    : Bus 10903	: V=1.0455258, theta=-21.468874 -> V=1.0, theta=0.0
% INFO    : Bus 10904	: V=1.0489372, theta=-19.321622 -> V=1.0, theta=0.0
% INFO    : Bus 10905	: V=1.0437949, theta=-19.624786 -> V=1.0, theta=0.0
% INFO    : Bus 10906	: V=1.0441164, theta=-20.632373 -> V=1.0, theta=0.0
% INFO    : Bus 10907	: V=1.0388568, theta=-20.847945 -> V=1.0, theta=0.0
% INFO    : Bus 10908	: V=1.0366572, theta=-19.063509 -> V=1.0, theta=0.0
% INFO    : Bus 10909	: V=1.0437949, theta=-19.624786 -> V=1.0, theta=0.0
% INFO    : Bus 10910	: V=1.0304781, theta=-19.303465 -> V=1.0, theta=0.0
% INFO    : Bus 10911	: V=1.0437949, theta=-19.624786 -> V=1.0, theta=0.0
% INFO    : Bus 10912	: V=1.0303882, theta=-19.164473 -> V=1.0, theta=0.0
% INFO    : Bus 10913	: V=1.0437949, theta=-19.624786 -> V=1.0, theta=0.0
% INFO    : Bus 10914	: V=1.0308431, theta=-19.555327 -> V=1.0, theta=0.0
% INFO    : Bus 10915	: V=1.0438512, theta=-20.760499 -> V=1.0, theta=0.0
% INFO    : Bus 10916	: V=1.0263431, theta=-23.045422 -> V=1.0, theta=0.0
% INFO    : Bus 10917	: V=1.0302291, theta=-25.111854 -> V=1.0, theta=0.0
% INFO    : Bus 10918	: V=1.0301312, theta=-25.579889 -> V=1.0, theta=0.0
% INFO    : Bus 10919	: V=1.0320429, theta=-22.069537 -> V=1.0, theta=0.0
% INFO    : Bus 10920	: V=1.0263431, theta=-23.045422 -> V=1.0, theta=0.0
% INFO    : Bus 10921	: V=1.0322785, theta=-22.472166 -> V=1.0, theta=0.0
% INFO    : Bus 10922	: V=1.0263431, theta=-23.045422 -> V=1.0, theta=0.0
% INFO    : Bus 10923	: V=1.0391834, theta=-36.872029 -> V=1.0, theta=0.0
% INFO    : Bus 10924	: V=1.0271861, theta=-36.154114 -> V=1.0, theta=0.0
% INFO    : Bus 10925	: V=1.0245404, theta=-32.820372 -> V=1.0, theta=0.0
% INFO    : Bus 10926	: V=1.0271607, theta=-36.16931 -> V=1.0, theta=0.0
% INFO    : Bus 10927	: V=1.0271861, theta=-36.154114 -> V=1.0, theta=0.0
% INFO    : Bus 10928	: V=1.044, theta=-29.173961 -> V=1.0, theta=0.0
% INFO    : Bus 10929	: V=1.0412579, theta=-31.297051 -> V=1.0, theta=0.0
% INFO    : Bus 10930	: V=1.0619549, theta=-27.711987 -> V=1.0, theta=0.0
% INFO    : Bus 10931	: V=1.0517603, theta=-27.481069 -> V=1.0, theta=0.0
% INFO    : Bus 10932	: V=1.0590248, theta=-25.716835 -> V=1.0, theta=0.0
% INFO    : Bus 10933	: V=1.0436355, theta=-23.547471 -> V=1.0, theta=0.0
% INFO    : Bus 10934	: V=1.028291, theta=-31.704664 -> V=1.0, theta=0.0
% INFO    : Bus 10935	: V=1.0281789, theta=-31.74949 -> V=1.0, theta=0.0
% INFO    : Bus 10936	: V=1.028291, theta=-31.704664 -> V=1.0, theta=0.0
% INFO    : Bus 10937	: V=1.036948, theta=-33.220982 -> V=1.0, theta=0.0
% INFO    : Bus 10938	: V=1.0374325, theta=-30.422454 -> V=1.0, theta=0.0
% INFO    : Bus 10939	: V=1.036232, theta=-28.63666 -> V=1.0, theta=0.0
% INFO    : Bus 10940	: V=1.0349612, theta=-27.243556 -> V=1.0, theta=0.0
% INFO    : Bus 10941	: V=1.0387319, theta=-15.144569 -> V=1.0, theta=0.0
% INFO    : Bus 10942	: V=1.0398958, theta=-16.100236 -> V=1.0, theta=0.0
% INFO    : Bus 10943	: V=1.0392712, theta=-18.311216 -> V=1.0, theta=0.0
% INFO    : Bus 10944	: V=1.0380607, theta=-14.3805 -> V=1.0, theta=0.0
% INFO    : Bus 10945	: V=1.0379644, theta=-14.316821 -> V=1.0, theta=0.0
% INFO    : Bus 10946	: V=1.038316, theta=-14.583257 -> V=1.0, theta=0.0
% INFO    : Bus 10947	: V=1.0381815, theta=-14.565816 -> V=1.0, theta=0.0
% INFO    : Bus 10948	: V=1.0387319, theta=-15.144569 -> V=1.0, theta=0.0
% INFO    : Bus 10949	: V=1.0382486, theta=-14.726887 -> V=1.0, theta=0.0
% INFO    : Bus 10950	: V=1.0311896, theta=-35.371558 -> V=1.0, theta=0.0
% INFO    : Bus 10951	: V=1.0311896, theta=-35.371558 -> V=1.0, theta=0.0
% INFO    : Bus 10952	: V=1.0311896, theta=-35.371558 -> V=1.0, theta=0.0
% INFO    : Bus 10953	: V=1.0208602, theta=-30.993436 -> V=1.0, theta=0.0
% INFO    : Bus 10954	: V=1.0281822, theta=-33.062696 -> V=1.0, theta=0.0
% INFO    : Bus 10955	: V=1.0202647, theta=-30.398324 -> V=1.0, theta=0.0
% INFO    : Bus 10956	: V=1.0208602, theta=-30.993436 -> V=1.0, theta=0.0
% INFO    : Bus 10957	: V=1.0421217, theta=-22.817281 -> V=1.0, theta=0.0
% INFO    : Bus 10958	: V=1.0436073, theta=-24.898377 -> V=1.0, theta=0.0
% INFO    : Bus 10959	: V=1.0088292, theta=-20.447931 -> V=1.0, theta=0.0
% INFO    : Bus 10960	: V=1.0414586, theta=-22.854663 -> V=1.0, theta=0.0
% INFO    : Bus 10961	: V=1.0351309, theta=-14.33691 -> V=1.0, theta=0.0
% INFO    : Bus 10962	: V=1.0359744, theta=-15.012372 -> V=1.0, theta=0.0
% INFO    : Bus 10963	: V=1.0367036, theta=-15.519635 -> V=1.0, theta=0.0
% INFO    : Bus 10964	: V=1.0367036, theta=-15.519635 -> V=1.0, theta=0.0
% INFO    : Bus 10965	: V=1.0351309, theta=-14.33691 -> V=1.0, theta=0.0
% INFO    : Bus 10966	: V=1.0228635, theta=-29.656913 -> V=1.0, theta=0.0
% INFO    : Bus 10967	: V=1.0228326, theta=-29.673026 -> V=1.0, theta=0.0
% INFO    : Bus 10968	: V=1.0283694, theta=-21.465783 -> V=1.0, theta=0.0
% INFO    : Bus 10969	: V=1.0283694, theta=-21.465783 -> V=1.0, theta=0.0
% INFO    : Bus 10970	: V=1.012341, theta=-16.927002 -> V=1.0, theta=0.0
% INFO    : Bus 10971	: V=1.0129785, theta=-18.700758 -> V=1.0, theta=0.0
% INFO    : Bus 10972	: V=1.0105386, theta=-15.728909 -> V=1.0, theta=0.0
% INFO    : Bus 10973	: V=1.0123342, theta=-17.353818 -> V=1.0, theta=0.0
% INFO    : Bus 10974	: V=1.039978, theta=-17.400882 -> V=1.0, theta=0.0
% INFO    : Bus 10975	: V=1.0361899, theta=-18.368231 -> V=1.0, theta=0.0
% INFO    : Bus 10976	: V=1.0348875, theta=-18.721294 -> V=1.0, theta=0.0
% INFO    : Bus 10977	: V=1.0348875, theta=-18.721294 -> V=1.0, theta=0.0
% INFO    : Bus 10978	: V=1.0423146, theta=-16.517471 -> V=1.0, theta=0.0
% INFO    : Bus 10979	: V=1.0438629, theta=-21.513838 -> V=1.0, theta=0.0
% INFO    : Bus 10980	: V=1.0417311, theta=-23.617428 -> V=1.0, theta=0.0
% INFO    : Bus 10981	: V=1.0484609, theta=-20.340179 -> V=1.0, theta=0.0
% INFO    : Bus 10982	: V=1.0469225, theta=-20.791449 -> V=1.0, theta=0.0
% INFO    : Bus 10983	: V=1.0432934, theta=-21.528185 -> V=1.0, theta=0.0
% INFO    : Bus 10984	: V=1.045426, theta=-21.391841 -> V=1.0, theta=0.0
% INFO    : Bus 10985	: V=1.038012, theta=-19.546915 -> V=1.0, theta=0.0
% INFO    : Bus 10986	: V=1.0392671, theta=-28.011957 -> V=1.0, theta=0.0
% INFO    : Bus 10987	: V=1.0406363, theta=-30.736138 -> V=1.0, theta=0.0
% INFO    : Bus 10988	: V=1.0398634, theta=-32.932942 -> V=1.0, theta=0.0
% INFO    : Bus 10989	: V=1.0371105, theta=-26.928295 -> V=1.0, theta=0.0
% INFO    : Bus 10990	: V=1.0372562, theta=-26.975567 -> V=1.0, theta=0.0
% INFO    : Bus 10991	: V=1.0376604, theta=-27.168694 -> V=1.0, theta=0.0
% INFO    : Bus 10992	: V=1.043499, theta=-14.04096 -> V=1.0, theta=0.0
% INFO    : Bus 10993	: V=1.043499, theta=-14.04096 -> V=1.0, theta=0.0
% INFO    : Bus 10994	: V=1.043499, theta=-14.04096 -> V=1.0, theta=0.0
% INFO    : Bus 10995	: V=1.0416374, theta=-11.346144 -> V=1.0, theta=0.0
% INFO    : Bus 10996	: V=1.0434627, theta=-14.053624 -> V=1.0, theta=0.0
% INFO    : Bus 10997	: V=1.0332297, theta=-33.40896 -> V=1.0, theta=0.0
% INFO    : Bus 10998	: V=1.0258476, theta=-32.077293 -> V=1.0, theta=0.0
% INFO    : Bus 10999	: V=1.0331819, theta=-33.433335 -> V=1.0, theta=0.0
% INFO    : Bus 11000	: V=1.0345363, theta=-23.041566 -> V=1.0, theta=0.0
% INFO    : Bus 11001	: V=1.0384737, theta=-23.329109 -> V=1.0, theta=0.0
% INFO    : Bus 11002	: V=1.0406872, theta=-23.267334 -> V=1.0, theta=0.0
% INFO    : Bus 11003	: V=1.0428598, theta=-23.206989 -> V=1.0, theta=0.0
% INFO    : Bus 11004	: V=1.0428598, theta=-23.206989 -> V=1.0, theta=0.0
% INFO    : Bus 11005	: V=1.0257454, theta=-22.613165 -> V=1.0, theta=0.0
% INFO    : Bus 11006	: V=1.0270607, theta=-22.47173 -> V=1.0, theta=0.0
% INFO    : Bus 11007	: V=1.0292815, theta=-36.477698 -> V=1.0, theta=0.0
% INFO    : Bus 11008	: V=0.9754948, theta=-31.941034 -> V=1.0, theta=0.0
% INFO    : Bus 11009	: V=0.9969519, theta=-35.262368 -> V=1.0, theta=0.0
% INFO    : Bus 11010	: V=1.0292049, theta=-36.503338 -> V=1.0, theta=0.0
% INFO    : Bus 11011	: V=1.041, theta=-14.743096 -> V=1.0, theta=0.0
% INFO    : Bus 11012	: V=1.0410715, theta=-16.873702 -> V=1.0, theta=0.0
% INFO    : Bus 11013	: V=1.0406572, theta=-18.259463 -> V=1.0, theta=0.0
% INFO    : Bus 11014	: V=1.069422, theta=-10.58309 -> V=1.0, theta=0.0
% INFO    : Bus 11015	: V=1.041, theta=-14.743096 -> V=1.0, theta=0.0
% INFO    : Bus 11016	: V=1.0633187, theta=-10.226674 -> V=1.0, theta=0.0
% INFO    : Bus 11017	: V=1.041, theta=-14.743096 -> V=1.0, theta=0.0
% INFO    : Bus 11018	: V=1.0618356, theta=-11.47905 -> V=1.0, theta=0.0
% INFO    : Bus 11019	: V=1.0614943, theta=-12.053543 -> V=1.0, theta=0.0
% INFO    : Bus 11020	: V=1.0430581, theta=-14.456719 -> V=1.0, theta=0.0
% INFO    : Bus 11021	: V=1.0435997, theta=-14.558841 -> V=1.0, theta=0.0
% INFO    : Bus 11022	: V=1.041, theta=-14.743096 -> V=1.0, theta=0.0
% INFO    : Bus 11023	: V=1.0431438, theta=-14.509292 -> V=1.0, theta=0.0
% INFO    : Bus 11024	: V=1.041, theta=-14.743096 -> V=1.0, theta=0.0
% INFO    : Bus 11025	: V=1.0431373, theta=-14.509986 -> V=1.0, theta=0.0
% INFO    : Bus 11026	: V=1.041524, theta=-17.061657 -> V=1.0, theta=0.0
% INFO    : Bus 11027	: V=1.0249177, theta=-36.058603 -> V=1.0, theta=0.0
% INFO    : Bus 11028	: V=1.0385012, theta=-36.908473 -> V=1.0, theta=0.0
% INFO    : Bus 11029	: V=1.0499205, theta=-37.595595 -> V=1.0, theta=0.0
% INFO    : Bus 11030	: V=1.0499205, theta=-37.595595 -> V=1.0, theta=0.0
% INFO    : Bus 11031	: V=1.042151, theta=-34.8186 -> V=1.0, theta=0.0
% INFO    : Bus 11032	: V=1.0411454, theta=-34.394512 -> V=1.0, theta=0.0
% INFO    : Bus 11033	: V=1.0411003, theta=-34.38419 -> V=1.0, theta=0.0
% INFO    : Bus 11034	: V=1.0263978, theta=-36.228594 -> V=1.0, theta=0.0
% INFO    : Bus 11035	: V=1.0169342, theta=-32.280704 -> V=1.0, theta=0.0
% INFO    : Bus 11036	: V=1.0168841, theta=-32.29454 -> V=1.0, theta=0.0
% INFO    : Bus 11037	: V=1.0219734, theta=-30.973805 -> V=1.0, theta=0.0
% INFO    : Bus 11038	: V=1.0358252, theta=-13.723471 -> V=1.0, theta=0.0
% INFO    : Bus 11039	: V=1.0400845, theta=-14.126262 -> V=1.0, theta=0.0
% INFO    : Bus 11040	: V=1.0426172, theta=-14.166671 -> V=1.0, theta=0.0
% INFO    : Bus 11041	: V=1.0358252, theta=-13.723471 -> V=1.0, theta=0.0
% INFO    : Bus 11042	: V=1.0358252, theta=-13.723471 -> V=1.0, theta=0.0
% INFO    : Bus 11043	: V=1.0358252, theta=-13.723471 -> V=1.0, theta=0.0
% INFO    : Bus 11044	: V=1.0358252, theta=-13.723471 -> V=1.0, theta=0.0
% INFO    : Bus 11045	: V=1.035203, theta=-13.100519 -> V=1.0, theta=0.0
% INFO    : Bus 11046	: V=1.0351095, theta=-13.042442 -> V=1.0, theta=0.0
% INFO    : Bus 11047	: V=1.04, theta=-20.471412 -> V=1.0, theta=0.0
% INFO    : Bus 11048	: V=1.0052341, theta=-32.504172 -> V=1.0, theta=0.0
% INFO    : Bus 11049	: V=1.0382953, theta=-35.075995 -> V=1.0, theta=0.0
% INFO    : Bus 11050	: V=1.0399248, theta=-28.527044 -> V=1.0, theta=0.0
% INFO    : Bus 11051	: V=1.0305937, theta=-15.155979 -> V=1.0, theta=0.0
% INFO    : Bus 11052	: V=1.0141548, theta=-11.541996 -> V=1.0, theta=0.0
% INFO    : Bus 11053	: V=1.0131423, theta=-10.71993 -> V=1.0, theta=0.0
% INFO    : Bus 11054	: V=1.0161272, theta=-18.919074 -> V=1.0, theta=0.0
% INFO    : Bus 11055	: V=1.0159852, theta=-18.929071 -> V=1.0, theta=0.0
% INFO    : Bus 11056	: V=1.0386376, theta=-14.012977 -> V=1.0, theta=0.0
% INFO    : Bus 11057	: V=1.0364518, theta=-14.857381 -> V=1.0, theta=0.0
% INFO    : Bus 11058	: V=1.039093, theta=-13.847695 -> V=1.0, theta=0.0
% INFO    : Bus 11059	: V=1.039093, theta=-13.847695 -> V=1.0, theta=0.0
% INFO    : Bus 11060	: V=1.0428361, theta=-12.947403 -> V=1.0, theta=0.0
% INFO    : Bus 11061	: V=1.0424817, theta=-13.046618 -> V=1.0, theta=0.0
% INFO    : Bus 11062	: V=1.0214292, theta=-20.377805 -> V=1.0, theta=0.0
% INFO    : Bus 11063	: V=1.0419215, theta=-17.033163 -> V=1.0, theta=0.0
% INFO    : Bus 11064	: V=1.0424372, theta=-18.324418 -> V=1.0, theta=0.0
% INFO    : Bus 11065	: V=1.0680829, theta=-14.558182 -> V=1.0, theta=0.0
% INFO    : Bus 11066	: V=1.0416059, theta=-17.068144 -> V=1.0, theta=0.0
% INFO    : Bus 11067	: V=1.0442004, theta=-21.511552 -> V=1.0, theta=0.0
% INFO    : Bus 11068	: V=1.0460217, theta=-21.207696 -> V=1.0, theta=0.0
% INFO    : Bus 11069	: V=1.0482474, theta=-19.579395 -> V=1.0, theta=0.0
% INFO    : Bus 11070	: V=1.0277176, theta=-29.046101 -> V=1.0, theta=0.0
% INFO    : Bus 11071	: V=1.0174188, theta=-32.258291 -> V=1.0, theta=0.0
% INFO    : Bus 11072	: V=1.0249303, theta=-27.640215 -> V=1.0, theta=0.0
% INFO    : Bus 11073	: V=1.0232171, theta=-26.904174 -> V=1.0, theta=0.0
% INFO    : Bus 11074	: V=1.0432127, theta=-17.04789 -> V=1.0, theta=0.0
% INFO    : Bus 11075	: V=1.0427994, theta=-18.879927 -> V=1.0, theta=0.0
% INFO    : Bus 11076	: V=1.0446708, theta=-19.862965 -> V=1.0, theta=0.0
% INFO    : Bus 11077	: V=1.0428034, theta=-16.629015 -> V=1.0, theta=0.0
% INFO    : Bus 11078	: V=1.0432127, theta=-17.04789 -> V=1.0, theta=0.0
% INFO    : Bus 11079	: V=1.0426951, theta=-16.615235 -> V=1.0, theta=0.0
% INFO    : Bus 11080	: V=1.0427411, theta=-16.530912 -> V=1.0, theta=0.0
% INFO    : Bus 11081	: V=1.0432127, theta=-17.04789 -> V=1.0, theta=0.0
% INFO    : Bus 11082	: V=1.0426713, theta=-16.516349 -> V=1.0, theta=0.0
% INFO    : Bus 13000	: V=1.0310077, theta=-46.833535 -> V=1.0, theta=0.0
% INFO    : Bus 13001	: V=1.0325375, theta=-48.141169 -> V=1.0, theta=0.0
% INFO    : Bus 13002	: V=1.0330544, theta=-49.571349 -> V=1.0, theta=0.0
% INFO    : Bus 13003	: V=1.0329964, theta=-49.577847 -> V=1.0, theta=0.0
% INFO    : Bus 13004	: V=1.0276641, theta=-45.738951 -> V=1.0, theta=0.0
% INFO    : Bus 13005	: V=1.0211094, theta=-51.130227 -> V=1.0, theta=0.0
% INFO    : Bus 13006	: V=1.0208362, theta=-51.149545 -> V=1.0, theta=0.0
% INFO    : Bus 13007	: V=1.0310439, theta=-45.179379 -> V=1.0, theta=0.0
% INFO    : Bus 13008	: V=1.0309704, theta=-45.188253 -> V=1.0, theta=0.0
% INFO    : Bus 13009	: V=1.0351549, theta=-41.136824 -> V=1.0, theta=0.0
% INFO    : Bus 13010	: V=1.035813, theta=-43.509338 -> V=1.0, theta=0.0
% INFO    : Bus 13011	: V=1.037365, theta=-44.765024 -> V=1.0, theta=0.0
% INFO    : Bus 13012	: V=1.0371118, theta=-44.786001 -> V=1.0, theta=0.0
% INFO    : Bus 13013	: V=1.0144423, theta=-45.458662 -> V=1.0, theta=0.0
% INFO    : Bus 13014	: V=1.0320698, theta=-42.067503 -> V=1.0, theta=0.0
% INFO    : Bus 13015	: V=1.0321952, theta=-42.051325 -> V=1.0, theta=0.0
% INFO    : Bus 13016	: V=1.0254361, theta=-45.989752 -> V=1.0, theta=0.0
% INFO    : Bus 13017	: V=1.0309301, theta=-42.175213 -> V=1.0, theta=0.0
% INFO    : Bus 13018	: V=1.0308391, theta=-42.19265 -> V=1.0, theta=0.0
% INFO    : Bus 13019	: V=1.0230305, theta=-34.983517 -> V=1.0, theta=0.0
% INFO    : Bus 13020	: V=1.0287643, theta=-43.362362 -> V=1.0, theta=0.0
% INFO    : Bus 13021	: V=1.0296564, theta=-41.074568 -> V=1.0, theta=0.0
% INFO    : Bus 13022	: V=1.0329538, theta=-42.089919 -> V=1.0, theta=0.0
% INFO    : Bus 13023	: V=1.0215928, theta=-38.909388 -> V=1.0, theta=0.0
% INFO    : Bus 13024	: V=1.0194477, theta=-45.818571 -> V=1.0, theta=0.0
% INFO    : Bus 13025	: V=1.0193613, theta=-45.827545 -> V=1.0, theta=0.0
% INFO    : Bus 13026	: V=1.0257309, theta=-40.133217 -> V=1.0, theta=0.0
% INFO    : Bus 13027	: V=1.0258644, theta=-38.896225 -> V=1.0, theta=0.0
% INFO    : Bus 13028	: V=1.0259924, theta=-38.87795 -> V=1.0, theta=0.0
% INFO    : Bus 13029	: V=1.0220059, theta=-33.823708 -> V=1.0, theta=0.0
% INFO    : Bus 13030	: V=1.020852, theta=-32.792426 -> V=1.0, theta=0.0
% INFO    : Bus 13031	: V=1.0411177, theta=-53.076937 -> V=1.0, theta=0.0
% INFO    : Bus 13032	: V=1.0410203, theta=-53.088942 -> V=1.0, theta=0.0
% INFO    : Bus 13033	: V=1.0412278, theta=-53.064583 -> V=1.0, theta=0.0
% INFO    : Bus 13034	: V=1.0325401, theta=-40.747666 -> V=1.0, theta=0.0
% INFO    : Bus 13035	: V=1.0598613, theta=-48.434783 -> V=1.0, theta=0.0
% INFO    : Bus 13036	: V=1.0192699, theta=-46.256456 -> V=1.0, theta=0.0
% INFO    : Bus 13037	: V=1.0185205, theta=-46.434745 -> V=1.0, theta=0.0
% INFO    : Bus 13038	: V=1.0187253, theta=-46.412988 -> V=1.0, theta=0.0
% INFO    : Bus 13039	: V=1.0572052, theta=-46.262475 -> V=1.0, theta=0.0
% INFO    : Bus 13040	: V=1.0089258, theta=-42.939044 -> V=1.0, theta=0.0
% INFO    : Bus 13041	: V=1.0087697, theta=-42.951701 -> V=1.0, theta=0.0
% INFO    : Bus 13042	: V=1.0090534, theta=-42.928016 -> V=1.0, theta=0.0
% INFO    : Bus 13043	: V=1.0531813, theta=-48.152287 -> V=1.0, theta=0.0
% INFO    : Bus 13044	: V=1.0530756, theta=-48.162011 -> V=1.0, theta=0.0
% INFO    : Bus 13045	: V=1.0532866, theta=-48.142878 -> V=1.0, theta=0.0
% INFO    : Bus 13046	: V=1.0373536, theta=-40.700451 -> V=1.0, theta=0.0
% INFO    : Bus 13047	: V=1.037211, theta=-40.711644 -> V=1.0, theta=0.0
% INFO    : Bus 13048	: V=1.0467602, theta=-50.73036 -> V=1.0, theta=0.0
% INFO    : Bus 13049	: V=1.0465703, theta=-50.752565 -> V=1.0, theta=0.0
% INFO    : Bus 13050	: V=1.0507006, theta=-50.262238 -> V=1.0, theta=0.0
% INFO    : Bus 13051	: V=1.0508434, theta=-50.23771 -> V=1.0, theta=0.0
% INFO    : Bus 13052	: V=1.0196808, theta=-40.409342 -> V=1.0, theta=0.0
% INFO    : Bus 13053	: V=1.0194937, theta=-40.41899 -> V=1.0, theta=0.0
% INFO    : Bus 13054	: V=1.0172535, theta=-40.21322 -> V=1.0, theta=0.0
% INFO    : Bus 13055	: V=1.0135161, theta=-42.620289 -> V=1.0, theta=0.0
% INFO    : Bus 13056	: V=0.9981803, theta=-42.303916 -> V=1.0, theta=0.0
% INFO    : Bus 13057	: V=0.998386, theta=-42.285386 -> V=1.0, theta=0.0
% INFO    : Bus 13058	: V=1.0101079, theta=-46.776433 -> V=1.0, theta=0.0
% INFO    : Bus 13059	: V=1.0575962, theta=-49.160463 -> V=1.0, theta=0.0
% INFO    : Bus 13060	: V=1.0535541, theta=-49.225515 -> V=1.0, theta=0.0
% INFO    : Bus 13061	: V=1.0170274, theta=-43.702637 -> V=1.0, theta=0.0
% INFO    : Bus 13062	: V=0.9898375, theta=-43.390462 -> V=1.0, theta=0.0
% INFO    : Bus 13063	: V=0.989471, theta=-43.420407 -> V=1.0, theta=0.0
% INFO    : Bus 13064	: V=1.0243191, theta=-38.880576 -> V=1.0, theta=0.0
% INFO    : Bus 13065	: V=1.011603, theta=-40.028264 -> V=1.0, theta=0.0
% INFO    : Bus 13066	: V=1.0067206, theta=-41.246968 -> V=1.0, theta=0.0
% INFO    : Bus 13067	: V=1.0247598, theta=-31.45152 -> V=1.0, theta=0.0
% INFO    : Bus 13068	: V=1.0021242, theta=-42.714766 -> V=1.0, theta=0.0
% INFO    : Bus 13069	: V=0.9869132, theta=-42.727892 -> V=1.0, theta=0.0
% INFO    : Bus 13070	: V=1.0303717, theta=-44.650506 -> V=1.0, theta=0.0
% INFO    : Bus 13071	: V=1.0303717, theta=-44.650506 -> V=1.0, theta=0.0
% INFO    : Bus 13072	: V=1.0303717, theta=-44.650506 -> V=1.0, theta=0.0
% INFO    : Bus 13073	: V=1.0303717, theta=-44.650506 -> V=1.0, theta=0.0
% INFO    : Bus 13074	: V=1.0225356, theta=-33.635678 -> V=1.0, theta=0.0
% INFO    : Bus 13075	: V=1.0054654, theta=-41.473604 -> V=1.0, theta=0.0
% INFO    : Bus 13076	: V=1.0309615, theta=-37.125909 -> V=1.0, theta=0.0
% INFO    : Bus 13077	: V=1.0342075, theta=-39.69566 -> V=1.0, theta=0.0
% INFO    : Bus 13078	: V=1.0548306, theta=-46.763019 -> V=1.0, theta=0.0
% INFO    : Bus 13079	: V=1.0550445, theta=-46.7461 -> V=1.0, theta=0.0
% INFO    : Bus 13080	: V=1.0232093, theta=-44.590301 -> V=1.0, theta=0.0
% INFO    : Bus 13081	: V=1.0231959, theta=-38.237076 -> V=1.0, theta=0.0
% INFO    : Bus 13082	: V=1.0114708, theta=-41.773005 -> V=1.0, theta=0.0
% INFO    : Bus 13083	: V=1.0236842, theta=-40.255637 -> V=1.0, theta=0.0
% INFO    : Bus 13084	: V=1.0090654, theta=-37.324461 -> V=1.0, theta=0.0
% INFO    : Bus 13085	: V=1.0087907, theta=-37.358358 -> V=1.0, theta=0.0
% INFO    : Bus 13086	: V=0.9979357, theta=-38.112844 -> V=1.0, theta=0.0
% INFO    : Bus 13087	: V=0.9969036, theta=-40.870135 -> V=1.0, theta=0.0
% INFO    : Bus 13088	: V=0.9987812, theta=-44.240054 -> V=1.0, theta=0.0
% INFO    : Bus 13089	: V=0.9987812, theta=-44.240054 -> V=1.0, theta=0.0
% INFO    : Bus 13090	: V=1.0515743, theta=-49.207945 -> V=1.0, theta=0.0
% INFO    : Bus 13091	: V=1.0514948, theta=-49.216839 -> V=1.0, theta=0.0
% INFO    : Bus 13092	: V=1.0211583, theta=-42.244577 -> V=1.0, theta=0.0
% INFO    : Bus 13093	: V=1.0104931, theta=-40.754429 -> V=1.0, theta=0.0
% INFO    : Bus 13094	: V=1.0103056, theta=-40.776381 -> V=1.0, theta=0.0
% INFO    : Bus 13095	: V=1.0092595, theta=-40.902029 -> V=1.0, theta=0.0
% INFO    : Bus 13096	: V=1.0150234, theta=-35.812933 -> V=1.0, theta=0.0
% INFO    : Bus 13097	: V=1.0116372, theta=-39.740539 -> V=1.0, theta=0.0
% INFO    : Bus 13098	: V=1.0091615, theta=-39.988792 -> V=1.0, theta=0.0
% INFO    : Bus 13099	: V=0.9960012, theta=-41.072815 -> V=1.0, theta=0.0
% INFO    : Bus 13100	: V=0.9973193, theta=-41.012611 -> V=1.0, theta=0.0
% INFO    : Bus 13101	: V=1.0146881, theta=-39.999819 -> V=1.0, theta=0.0
% INFO    : Bus 13102	: V=1.0109761, theta=-40.60812 -> V=1.0, theta=0.0
% INFO    : Bus 13103	: V=1.011196, theta=-40.579525 -> V=1.0, theta=0.0
% INFO    : Bus 13104	: V=1.0255739, theta=-38.904759 -> V=1.0, theta=0.0
% INFO    : Bus 13105	: V=1.0468548, theta=-40.406041 -> V=1.0, theta=0.0
% INFO    : Bus 13106	: V=1.0350351, theta=-41.438747 -> V=1.0, theta=0.0
% INFO    : Bus 13107	: V=1.03548, theta=-48.988227 -> V=1.0, theta=0.0
% INFO    : Bus 13108	: V=1.0354103, theta=-48.993909 -> V=1.0, theta=0.0
% INFO    : Bus 13109	: V=1.0096501, theta=-40.771994 -> V=1.0, theta=0.0
% INFO    : Bus 13110	: V=1.0357887, theta=-52.719435 -> V=1.0, theta=0.0
% INFO    : Bus 13111	: V=1.0217095, theta=-39.196751 -> V=1.0, theta=0.0
% INFO    : Bus 13112	: V=1.0207908, theta=-40.051475 -> V=1.0, theta=0.0
% INFO    : Bus 13113	: V=1.0209188, theta=-40.036828 -> V=1.0, theta=0.0
% INFO    : Bus 13114	: V=1.0109249, theta=-37.434279 -> V=1.0, theta=0.0
% INFO    : Bus 13115	: V=1.0112016, theta=-37.416479 -> V=1.0, theta=0.0
% INFO    : Bus 13116	: V=1.0195791, theta=-39.701085 -> V=1.0, theta=0.0
% INFO    : Bus 13117	: V=0.9946756, theta=-41.122949 -> V=1.0, theta=0.0
% INFO    : Bus 13118	: V=1.0111112, theta=-39.853396 -> V=1.0, theta=0.0
% INFO    : Bus 13119	: V=1.0444735, theta=-40.919439 -> V=1.0, theta=0.0
% INFO    : Bus 13120	: V=1.0443184, theta=-40.94575 -> V=1.0, theta=0.0
% INFO    : Bus 13121	: V=1.0446412, theta=-40.893206 -> V=1.0, theta=0.0
% INFO    : Bus 13122	: V=1.0297873, theta=-35.715792 -> V=1.0, theta=0.0
% INFO    : Bus 13123	: V=1.0298453, theta=-35.709982 -> V=1.0, theta=0.0
% INFO    : Bus 13124	: V=0.9906275, theta=-41.01724 -> V=1.0, theta=0.0
% INFO    : Bus 13125	: V=0.9824405, theta=-43.013354 -> V=1.0, theta=0.0
% INFO    : Bus 13126	: V=0.9909872, theta=-40.936436 -> V=1.0, theta=0.0
% INFO    : Bus 13127	: V=0.9909872, theta=-40.936436 -> V=1.0, theta=0.0
% INFO    : Bus 13128	: V=0.989662, theta=-41.181091 -> V=1.0, theta=0.0
% INFO    : Bus 13129	: V=1.0340242, theta=-41.679639 -> V=1.0, theta=0.0
% INFO    : Bus 13130	: V=1.018066, theta=-40.05876 -> V=1.0, theta=0.0
% INFO    : Bus 13131	: V=1.0141504, theta=-40.047595 -> V=1.0, theta=0.0
% INFO    : Bus 13132	: V=1.0141504, theta=-40.047595 -> V=1.0, theta=0.0
% INFO    : Bus 13133	: V=1.0141504, theta=-40.047595 -> V=1.0, theta=0.0
% INFO    : Bus 13134	: V=1.0141504, theta=-40.047595 -> V=1.0, theta=0.0
% INFO    : Bus 13135	: V=1.0211907, theta=-39.477514 -> V=1.0, theta=0.0
% INFO    : Bus 13136	: V=0.9957022, theta=-36.965068 -> V=1.0, theta=0.0
% INFO    : Bus 13137	: V=1.0544261, theta=-40.175142 -> V=1.0, theta=0.0
% INFO    : Bus 13138	: V=1.0406463, theta=-40.460136 -> V=1.0, theta=0.0
% INFO    : Bus 13139	: V=1.0261778, theta=-38.517802 -> V=1.0, theta=0.0
% INFO    : Bus 13140	: V=1.0263286, theta=-38.488311 -> V=1.0, theta=0.0
% INFO    : Bus 13141	: V=1.0209178, theta=-38.175804 -> V=1.0, theta=0.0
% INFO    : Bus 13142	: V=1.0206812, theta=-38.192397 -> V=1.0, theta=0.0
% INFO    : Bus 13143	: V=1.0222923, theta=-32.379745 -> V=1.0, theta=0.0
% INFO    : Bus 13144	: V=1.0121028, theta=-37.115168 -> V=1.0, theta=0.0
% INFO    : Bus 13145	: V=1.0118746, theta=-37.146053 -> V=1.0, theta=0.0
% INFO    : Bus 13146	: V=1.0316614, theta=-38.343569 -> V=1.0, theta=0.0
% INFO    : Bus 13147	: V=1.0210584, theta=-34.784924 -> V=1.0, theta=0.0
% INFO    : Bus 13148	: V=1.0235846, theta=-39.645898 -> V=1.0, theta=0.0
% INFO    : Bus 13149	: V=1.0235184, theta=-39.652561 -> V=1.0, theta=0.0
% INFO    : Bus 13150	: V=1.0378703, theta=-50.800533 -> V=1.0, theta=0.0
% INFO    : Bus 13151	: V=1.0377417, theta=-50.820996 -> V=1.0, theta=0.0
% INFO    : Bus 13152	: V=1.0269184, theta=-48.72364 -> V=1.0, theta=0.0
% INFO    : Bus 13153	: V=1.0267611, theta=-48.74411 -> V=1.0, theta=0.0
% INFO    : Bus 13154	: V=1.0194856, theta=-33.488399 -> V=1.0, theta=0.0
% INFO    : Bus 13155	: V=1.0147648, theta=-36.869064 -> V=1.0, theta=0.0
% INFO    : Bus 13156	: V=1.0104813, theta=-33.364243 -> V=1.0, theta=0.0
% INFO    : Bus 13157	: V=1.0121971, theta=-36.929591 -> V=1.0, theta=0.0
% INFO    : Bus 13158	: V=1.0477523, theta=-42.725482 -> V=1.0, theta=0.0
% INFO    : Bus 13159	: V=1.0904352, theta=-39.186364 -> V=1.0, theta=0.0
% INFO    : Bus 13160	: V=1.0098658, theta=-33.273015 -> V=1.0, theta=0.0
% INFO    : Bus 13161	: V=1.0104813, theta=-33.364243 -> V=1.0, theta=0.0
% INFO    : Bus 13162	: V=1.0188646, theta=-39.541179 -> V=1.0, theta=0.0
% INFO    : Bus 13163	: V=0.9921012, theta=-40.644582 -> V=1.0, theta=0.0
% INFO    : Bus 13164	: V=0.9920532, theta=-40.653029 -> V=1.0, theta=0.0
% INFO    : Bus 13165	: V=1.0135723, theta=-39.37742 -> V=1.0, theta=0.0
% INFO    : Bus 13166	: V=1.0132696, theta=-39.40464 -> V=1.0, theta=0.0
% INFO    : Bus 13167	: V=1.0208597, theta=-39.211027 -> V=1.0, theta=0.0
% INFO    : Bus 13168	: V=1.020269, theta=-46.403098 -> V=1.0, theta=0.0
% INFO    : Bus 13169	: V=1.0220183, theta=-39.505005 -> V=1.0, theta=0.0
% INFO    : Bus 13170	: V=1.0222228, theta=-39.473752 -> V=1.0, theta=0.0
% INFO    : Bus 13171	: V=1.0061575, theta=-47.258984 -> V=1.0, theta=0.0
% INFO    : Bus 13172	: V=1.0387889, theta=-50.472407 -> V=1.0, theta=0.0
% INFO    : Bus 13173	: V=1.0352618, theta=-52.06399 -> V=1.0, theta=0.0
% INFO    : Bus 13174	: V=1.0050247, theta=-34.236239 -> V=1.0, theta=0.0
% INFO    : Bus 13175	: V=1.0430552, theta=-37.901312 -> V=1.0, theta=0.0
% INFO    : Bus 13176	: V=1.0237699, theta=-37.681273 -> V=1.0, theta=0.0
% INFO    : Bus 13177	: V=1.0233862, theta=-37.730304 -> V=1.0, theta=0.0
% INFO    : Bus 13178	: V=1.0181503, theta=-38.1605 -> V=1.0, theta=0.0
% INFO    : Bus 13179	: V=1.0179204, theta=-38.192891 -> V=1.0, theta=0.0
% INFO    : Bus 13180	: V=1.0045834, theta=-32.784419 -> V=1.0, theta=0.0
% INFO    : Bus 13181	: V=1.0337272, theta=-36.195457 -> V=1.0, theta=0.0
% INFO    : Bus 13182	: V=1.0257967, theta=-36.418242 -> V=1.0, theta=0.0
% INFO    : Bus 13183	: V=1.0253519, theta=-36.462582 -> V=1.0, theta=0.0
% INFO    : Bus 13184	: V=1.0309442, theta=-39.524339 -> V=1.0, theta=0.0
% INFO    : Bus 13185	: V=1.0185156, theta=-39.705761 -> V=1.0, theta=0.0
% INFO    : Bus 13186	: V=1.0183709, theta=-39.730477 -> V=1.0, theta=0.0
% INFO    : Bus 13187	: V=1.0186583, theta=-39.677861 -> V=1.0, theta=0.0
% INFO    : Bus 13188	: V=1.0185156, theta=-39.705761 -> V=1.0, theta=0.0
% INFO    : Bus 13189	: V=1.0114101, theta=-40.048128 -> V=1.0, theta=0.0
% INFO    : Bus 13190	: V=1.0243668, theta=-38.591447 -> V=1.0, theta=0.0
% INFO    : Bus 13191	: V=1.0243399, theta=-38.594519 -> V=1.0, theta=0.0
% INFO    : Bus 13192	: V=1.0223824, theta=-37.111852 -> V=1.0, theta=0.0
% INFO    : Bus 13193	: V=1.0221093, theta=-37.130598 -> V=1.0, theta=0.0
% INFO    : Bus 13194	: V=1.0226286, theta=-37.094147 -> V=1.0, theta=0.0
% INFO    : Bus 13195	: V=1.0223824, theta=-37.111852 -> V=1.0, theta=0.0
% INFO    : Bus 13196	: V=1.0192346, theta=-38.769037 -> V=1.0, theta=0.0
% INFO    : Bus 13197	: V=1.0167959, theta=-39.406673 -> V=1.0, theta=0.0
% INFO    : Bus 13198	: V=1.0106486, theta=-40.068692 -> V=1.0, theta=0.0
% INFO    : Bus 13199	: V=1.0104864, theta=-40.087175 -> V=1.0, theta=0.0
% INFO    : Bus 13200	: V=1.015533, theta=-49.689522 -> V=1.0, theta=0.0
% INFO    : Bus 13201	: V=1.0163526, theta=-50.095273 -> V=1.0, theta=0.0
% INFO    : Bus 13202	: V=1.0299704, theta=-37.319241 -> V=1.0, theta=0.0
% INFO    : Bus 13203	: V=1.0295512, theta=-37.354162 -> V=1.0, theta=0.0
% INFO    : Bus 13204	: V=1.02373, theta=-36.056167 -> V=1.0, theta=0.0
% INFO    : Bus 13205	: V=1.0233475, theta=-36.098099 -> V=1.0, theta=0.0
% INFO    : Bus 13206	: V=1.0232627, theta=-37.388158 -> V=1.0, theta=0.0
% INFO    : Bus 13207	: V=1.0234943, theta=-37.369802 -> V=1.0, theta=0.0
% INFO    : Bus 13208	: V=1.0230207, theta=-37.407598 -> V=1.0, theta=0.0
% INFO    : Bus 13209	: V=1.0296881, theta=-36.941373 -> V=1.0, theta=0.0
% INFO    : Bus 13210	: V=1.029925, theta=-36.923076 -> V=1.0, theta=0.0
% INFO    : Bus 13211	: V=1.0294541, theta=-36.960522 -> V=1.0, theta=0.0
% INFO    : Bus 13212	: V=1.0291364, theta=-37.055895 -> V=1.0, theta=0.0
% INFO    : Bus 13213	: V=1.0184703, theta=-50.544927 -> V=1.0, theta=0.0
% INFO    : Bus 13214	: V=1.0144361, theta=-48.251406 -> V=1.0, theta=0.0
% INFO    : Bus 13215	: V=1.0141809, theta=-48.280736 -> V=1.0, theta=0.0
% INFO    : Bus 13216	: V=1.0250155, theta=-37.864086 -> V=1.0, theta=0.0
% INFO    : Bus 13217	: V=1.0248037, theta=-37.88632 -> V=1.0, theta=0.0
% INFO    : Bus 13218	: V=1.0252179, theta=-37.845035 -> V=1.0, theta=0.0
% INFO    : Bus 13219	: V=1.0250155, theta=-37.864086 -> V=1.0, theta=0.0
% INFO    : Bus 13220	: V=1.0241101, theta=-37.514234 -> V=1.0, theta=0.0
% INFO    : Bus 13221	: V=1.0242773, theta=-37.493336 -> V=1.0, theta=0.0
% INFO    : Bus 13222	: V=1.0157778, theta=-46.899781 -> V=1.0, theta=0.0
% INFO    : Bus 13223	: V=1.015689, theta=-46.907589 -> V=1.0, theta=0.0
% INFO    : Bus 13224	: V=1.015877, theta=-46.891603 -> V=1.0, theta=0.0
% INFO    : Bus 13225	: V=1.0157778, theta=-46.899781 -> V=1.0, theta=0.0
% INFO    : Bus 13226	: V=1.0230464, theta=-38.324835 -> V=1.0, theta=0.0
% INFO    : Bus 13227	: V=1.0223937, theta=-38.30766 -> V=1.0, theta=0.0
% INFO    : Bus 13228	: V=1.0230069, theta=-38.332812 -> V=1.0, theta=0.0
% INFO    : Bus 13229	: V=1.0151997, theta=-33.788914 -> V=1.0, theta=0.0
% INFO    : Bus 13230	: V=1.0207892, theta=-36.951881 -> V=1.0, theta=0.0
% INFO    : Bus 13231	: V=1.0176301, theta=-43.714174 -> V=1.0, theta=0.0
% INFO    : Bus 13232	: V=1.0445225, theta=-38.180258 -> V=1.0, theta=0.0
% INFO    : Bus 13233	: V=1.0138258, theta=-33.699775 -> V=1.0, theta=0.0
% INFO    : Bus 13234	: V=1.0186622, theta=-37.698137 -> V=1.0, theta=0.0
% INFO    : Bus 13235	: V=1.018465, theta=-37.729259 -> V=1.0, theta=0.0
% INFO    : Bus 13236	: V=1.0188763, theta=-37.66723 -> V=1.0, theta=0.0
% INFO    : Bus 13237	: V=1.0196844, theta=-36.847654 -> V=1.0, theta=0.0
% INFO    : Bus 13238	: V=1.0195387, theta=-36.879646 -> V=1.0, theta=0.0
% INFO    : Bus 13239	: V=1.028664, theta=-38.077565 -> V=1.0, theta=0.0
% INFO    : Bus 13240	: V=1.0285924, theta=-38.083711 -> V=1.0, theta=0.0
% INFO    : Bus 13241	: V=1.0287246, theta=-36.54974 -> V=1.0, theta=0.0
% INFO    : Bus 13242	: V=1.0259838, theta=-37.048131 -> V=1.0, theta=0.0
% INFO    : Bus 13243	: V=1.0258522, theta=-37.068226 -> V=1.0, theta=0.0
% INFO    : Bus 13244	: V=1.0195387, theta=-37.813255 -> V=1.0, theta=0.0
% INFO    : Bus 13245	: V=1.0192524, theta=-37.832055 -> V=1.0, theta=0.0
% INFO    : Bus 13246	: V=1.0336268, theta=-35.688928 -> V=1.0, theta=0.0
% INFO    : Bus 13247	: V=1.0363322, theta=-35.356422 -> V=1.0, theta=0.0
% INFO    : Bus 13248	: V=1.0360895, theta=-35.377741 -> V=1.0, theta=0.0
% INFO    : Bus 13249	: V=1.0365741, theta=-35.334428 -> V=1.0, theta=0.0
% INFO    : Bus 13250	: V=1.0256338, theta=-36.663229 -> V=1.0, theta=0.0
% INFO    : Bus 13251	: V=1.0203694, theta=-39.075997 -> V=1.0, theta=0.0
% INFO    : Bus 13252	: V=1.0205964, theta=-39.056178 -> V=1.0, theta=0.0
% INFO    : Bus 13253	: V=1.0310831, theta=-36.276901 -> V=1.0, theta=0.0
% INFO    : Bus 13254	: V=1.0229555, theta=-37.558567 -> V=1.0, theta=0.0
% INFO    : Bus 13255	: V=1.0227589, theta=-37.592702 -> V=1.0, theta=0.0
% INFO    : Bus 13256	: V=1.023115, theta=-37.52144 -> V=1.0, theta=0.0
% INFO    : Bus 13257	: V=0.9992385, theta=-39.704213 -> V=1.0, theta=0.0
% INFO    : Bus 13258	: V=0.9990309, theta=-39.730635 -> V=1.0, theta=0.0
% INFO    : Bus 13259	: V=0.9938639, theta=-39.992998 -> V=1.0, theta=0.0
% INFO    : Bus 13260	: V=1.0344145, theta=-35.600614 -> V=1.0, theta=0.0
% INFO    : Bus 13261	: V=1.0315182, theta=-36.29797 -> V=1.0, theta=0.0
% INFO    : Bus 13262	: V=1.0212686, theta=-37.257724 -> V=1.0, theta=0.0
% INFO    : Bus 13263	: V=1.0258755, theta=-29.534452 -> V=1.0, theta=0.0
% INFO    : Bus 13264	: V=1.012941, theta=-32.604659 -> V=1.0, theta=0.0
% INFO    : Bus 13265	: V=1.0267286, theta=-35.405224 -> V=1.0, theta=0.0
% INFO    : Bus 13266	: V=1.0238776, theta=-37.35604 -> V=1.0, theta=0.0
% INFO    : Bus 13267	: V=1.0236283, theta=-37.375812 -> V=1.0, theta=0.0
% INFO    : Bus 13268	: V=1.0240987, theta=-37.33768 -> V=1.0, theta=0.0
% INFO    : Bus 13269	: V=1.0238776, theta=-37.35604 -> V=1.0, theta=0.0
% INFO    : Bus 13270	: V=1.0288323, theta=-36.385713 -> V=1.0, theta=0.0
% INFO    : Bus 13271	: V=1.0286188, theta=-36.407592 -> V=1.0, theta=0.0
% INFO    : Bus 13272	: V=1.0290422, theta=-36.367437 -> V=1.0, theta=0.0
% INFO    : Bus 13273	: V=1.0211103, theta=-35.802079 -> V=1.0, theta=0.0
% INFO    : Bus 13274	: V=1.0230896, theta=-36.944632 -> V=1.0, theta=0.0
% INFO    : Bus 13275	: V=1.021924, theta=-36.817903 -> V=1.0, theta=0.0
% INFO    : Bus 13276	: V=1.0216014, theta=-36.836169 -> V=1.0, theta=0.0
% INFO    : Bus 13277	: V=1.0186073, theta=-36.798282 -> V=1.0, theta=0.0
% INFO    : Bus 13278	: V=1.0183868, theta=-36.828628 -> V=1.0, theta=0.0
% INFO    : Bus 13279	: V=1.0110039, theta=-49.40594 -> V=1.0, theta=0.0
% INFO    : Bus 13280	: V=1.0295873, theta=-36.357194 -> V=1.0, theta=0.0
% INFO    : Bus 13281	: V=1.0298625, theta=-36.330751 -> V=1.0, theta=0.0
% INFO    : Bus 13282	: V=1.0293248, theta=-36.381677 -> V=1.0, theta=0.0
% INFO    : Bus 13283	: V=1.0249041, theta=-35.941946 -> V=1.0, theta=0.0
% INFO    : Bus 13284	: V=1.0220989, theta=-36.867964 -> V=1.0, theta=0.0
% INFO    : Bus 13285	: V=1.0348172, theta=-35.255136 -> V=1.0, theta=0.0
% INFO    : Bus 13286	: V=1.0244632, theta=-36.122045 -> V=1.0, theta=0.0
% INFO    : Bus 13287	: V=1.0389103, theta=-34.855324 -> V=1.0, theta=0.0
% INFO    : Bus 13288	: V=1.0386693, theta=-34.873658 -> V=1.0, theta=0.0
% INFO    : Bus 13289	: V=1.0391891, theta=-34.833841 -> V=1.0, theta=0.0
% INFO    : Bus 13290	: V=1.0389103, theta=-34.855324 -> V=1.0, theta=0.0
% INFO    : Bus 13291	: V=1.0389103, theta=-34.855324 -> V=1.0, theta=0.0
% INFO    : Bus 13292	: V=1.0300515, theta=-35.296425 -> V=1.0, theta=0.0
% INFO    : Bus 13293	: V=1.0204277, theta=-36.106538 -> V=1.0, theta=0.0
% INFO    : Bus 13294	: V=1.0208551, theta=-35.958621 -> V=1.0, theta=0.0
% INFO    : Bus 13295	: V=1.0272936, theta=-35.666109 -> V=1.0, theta=0.0
% INFO    : Bus 13296	: V=1.0253011, theta=-35.813958 -> V=1.0, theta=0.0
% INFO    : Bus 13297	: V=1.0290679, theta=-34.986478 -> V=1.0, theta=0.0
% INFO    : Bus 13298	: V=1.0289044, theta=-35.005903 -> V=1.0, theta=0.0
% INFO    : Bus 13299	: V=1.02701, theta=-35.74743 -> V=1.0, theta=0.0
% INFO    : Bus 13300	: V=1.0323476, theta=-35.209145 -> V=1.0, theta=0.0
% INFO    : Bus 13301	: V=1.0348536, theta=-35.414465 -> V=1.0, theta=0.0
% INFO    : Bus 13302	: V=0.9984795, theta=-33.176284 -> V=1.0, theta=0.0
% INFO    : Bus 13303	: V=1.0428527, theta=-34.632304 -> V=1.0, theta=0.0
% INFO    : Bus 13304	: V=1.036618, theta=-35.315143 -> V=1.0, theta=0.0
% INFO    : Bus 13305	: V=1.0251055, theta=-36.051369 -> V=1.0, theta=0.0
% INFO    : Bus 13306	: V=1.0250109, theta=-36.068451 -> V=1.0, theta=0.0
% INFO    : Bus 13307	: V=1.0117959, theta=-50.325751 -> V=1.0, theta=0.0
% INFO    : Bus 13308	: V=1.0390372, theta=-34.924189 -> V=1.0, theta=0.0
% INFO    : Bus 13309	: V=1.038865, theta=-34.941629 -> V=1.0, theta=0.0
% INFO    : Bus 13310	: V=1.0392213, theta=-34.905852 -> V=1.0, theta=0.0
% INFO    : Bus 13311	: V=1.0270017, theta=-35.080659 -> V=1.0, theta=0.0
% INFO    : Bus 13312	: V=1.0271864, theta=-35.062696 -> V=1.0, theta=0.0
% INFO    : Bus 13313	: V=1.0162476, theta=-37.200227 -> V=1.0, theta=0.0
% INFO    : Bus 13314	: V=1.0339181, theta=-35.479183 -> V=1.0, theta=0.0
% INFO    : Bus 13315	: V=1.0336496, theta=-35.498633 -> V=1.0, theta=0.0
% INFO    : Bus 13316	: V=1.0296628, theta=-35.552343 -> V=1.0, theta=0.0
% INFO    : Bus 13317	: V=1.0294285, theta=-35.574506 -> V=1.0, theta=0.0
% INFO    : Bus 13318	: V=1.0298818, theta=-35.52836 -> V=1.0, theta=0.0
% INFO    : Bus 13319	: V=1.0259772, theta=-35.877141 -> V=1.0, theta=0.0
% INFO    : Bus 13320	: V=1.0274279, theta=-35.768855 -> V=1.0, theta=0.0
% INFO    : Bus 13321	: V=1.0272192, theta=-35.793979 -> V=1.0, theta=0.0
% INFO    : Bus 13322	: V=1.0276375, theta=-35.742077 -> V=1.0, theta=0.0
% INFO    : Bus 13323	: V=1.0204025, theta=-36.050125 -> V=1.0, theta=0.0
% INFO    : Bus 13324	: V=1.0147892, theta=-33.910852 -> V=1.0, theta=0.0
% INFO    : Bus 13325	: V=1.0207465, theta=-35.863861 -> V=1.0, theta=0.0
% INFO    : Bus 13326	: V=1.023406, theta=-36.623808 -> V=1.0, theta=0.0
% INFO    : Bus 13327	: V=1.023406, theta=-36.623808 -> V=1.0, theta=0.0
% INFO    : Bus 13328	: V=1.0319975, theta=-35.459119 -> V=1.0, theta=0.0
% INFO    : Bus 13329	: V=1.0306949, theta=-35.495818 -> V=1.0, theta=0.0
% INFO    : Bus 13330	: V=1.0308082, theta=-35.476528 -> V=1.0, theta=0.0
% INFO    : Bus 13331	: V=1.0265019, theta=-34.775725 -> V=1.0, theta=0.0
% INFO    : Bus 13332	: V=1.0263033, theta=-34.799366 -> V=1.0, theta=0.0
% INFO    : Bus 13333	: V=1.0266765, theta=-34.749514 -> V=1.0, theta=0.0
% INFO    : Bus 13334	: V=1.0295025, theta=-35.534112 -> V=1.0, theta=0.0
% INFO    : Bus 13335	: V=1.0273976, theta=-35.587283 -> V=1.0, theta=0.0
% INFO    : Bus 13336	: V=1.0270543, theta=-35.612081 -> V=1.0, theta=0.0
% INFO    : Bus 13337	: V=1.0324448, theta=-35.309812 -> V=1.0, theta=0.0
% INFO    : Bus 13338	: V=1.0340541, theta=-35.312487 -> V=1.0, theta=0.0
% INFO    : Bus 13339	: V=1.0337133, theta=-35.334967 -> V=1.0, theta=0.0
% INFO    : Bus 13340	: V=0.9984166, theta=-32.469595 -> V=1.0, theta=0.0
% INFO    : Bus 13341	: V=1.0316018, theta=-35.442342 -> V=1.0, theta=0.0
% INFO    : Bus 13342	: V=0.9981793, theta=-32.498968 -> V=1.0, theta=0.0
% INFO    : Bus 13343	: V=1.0262557, theta=-36.086203 -> V=1.0, theta=0.0
% INFO    : Bus 13344	: V=1.0263821, theta=-36.075827 -> V=1.0, theta=0.0
% INFO    : Bus 13345	: V=1.0262557, theta=-36.086203 -> V=1.0, theta=0.0
% INFO    : Bus 13346	: V=1.0157933, theta=-35.366517 -> V=1.0, theta=0.0
% INFO    : Bus 13347	: V=1.0317144, theta=-35.387275 -> V=1.0, theta=0.0
% INFO    : Bus 13348	: V=1.0316277, theta=-35.401118 -> V=1.0, theta=0.0
% INFO    : Bus 13349	: V=1.0271878, theta=-35.51797 -> V=1.0, theta=0.0
% INFO    : Bus 13350	: V=1.0273956, theta=-35.491524 -> V=1.0, theta=0.0
% INFO    : Bus 13351	: V=1.0293091, theta=-35.522883 -> V=1.0, theta=0.0
% INFO    : Bus 13352	: V=1.0291432, theta=-35.550037 -> V=1.0, theta=0.0
% INFO    : Bus 13353	: V=1.0168206, theta=-36.830609 -> V=1.0, theta=0.0
% INFO    : Bus 13354	: V=1.0167452, theta=-36.839287 -> V=1.0, theta=0.0
% INFO    : Bus 13355	: V=1.0168954, theta=-36.822378 -> V=1.0, theta=0.0
% INFO    : Bus 13356	: V=1.0295289, theta=-35.586236 -> V=1.0, theta=0.0
% INFO    : Bus 13357	: V=1.0174595, theta=-34.819172 -> V=1.0, theta=0.0
% INFO    : Bus 13358	: V=1.0308316, theta=-36.640462 -> V=1.0, theta=0.0
% INFO    : Bus 13359	: V=1.0055684, theta=-35.94561 -> V=1.0, theta=0.0
% INFO    : Bus 13360	: V=1.010817, theta=-35.727631 -> V=1.0, theta=0.0
% INFO    : Bus 13361	: V=1.0284193, theta=-34.457359 -> V=1.0, theta=0.0
% INFO    : Bus 13362	: V=1.0283487, theta=-34.470113 -> V=1.0, theta=0.0
% INFO    : Bus 13363	: V=1.0312522, theta=-32.484943 -> V=1.0, theta=0.0
% INFO    : Bus 13364	: V=1.0308983, theta=-32.510365 -> V=1.0, theta=0.0
% INFO    : Bus 13365	: V=1.0315859, theta=-32.457252 -> V=1.0, theta=0.0
% INFO    : Bus 13366	: V=1.0115171, theta=-48.14724 -> V=1.0, theta=0.0
% INFO    : Bus 13367	: V=1.0117287, theta=-48.116521 -> V=1.0, theta=0.0
% INFO    : Bus 13368	: V=1.0367223, theta=-33.226879 -> V=1.0, theta=0.0
% INFO    : Bus 13369	: V=1.036654, theta=-33.235124 -> V=1.0, theta=0.0
% INFO    : Bus 13370	: V=1.0318557, theta=-46.448834 -> V=1.0, theta=0.0
% INFO    : Bus 13371	: V=1.0315365, theta=-46.466818 -> V=1.0, theta=0.0
% INFO    : Bus 13372	: V=1.0323453, theta=-45.949403 -> V=1.0, theta=0.0
% INFO    : Bus 13373	: V=1.0321832, theta=-45.967745 -> V=1.0, theta=0.0
% INFO    : Bus 13374	: V=1.00667, theta=-44.523726 -> V=1.0, theta=0.0
% INFO    : Bus 13375	: V=1.0067216, theta=-44.516953 -> V=1.0, theta=0.0
% INFO    : Bus 13376	: V=1.0329686, theta=-31.875182 -> V=1.0, theta=0.0
% INFO    : Bus 13377	: V=1.0329686, theta=-31.875182 -> V=1.0, theta=0.0
% INFO    : Bus 13378	: V=1.0329686, theta=-31.875182 -> V=1.0, theta=0.0
% INFO    : Bus 13379	: V=1.0329686, theta=-31.875182 -> V=1.0, theta=0.0
% INFO    : Bus 13380	: V=1.0272051, theta=-28.46692 -> V=1.0, theta=0.0
% INFO    : Bus 13381	: V=1.0070412, theta=-38.009737 -> V=1.0, theta=0.0
% INFO    : Bus 13382	: V=1.0032976, theta=-40.931392 -> V=1.0, theta=0.0
% INFO    : Bus 13383	: V=1.0359808, theta=-46.632676 -> V=1.0, theta=0.0
% INFO    : Bus 13384	: V=1.0368215, theta=-46.53701 -> V=1.0, theta=0.0
% INFO    : Bus 13385	: V=1.0275985, theta=-30.625212 -> V=1.0, theta=0.0
% INFO    : Bus 13386	: V=1.0155405, theta=-35.483113 -> V=1.0, theta=0.0
% INFO    : Bus 13387	: V=1.0157269, theta=-35.45668 -> V=1.0, theta=0.0
% INFO    : Bus 13388	: V=1.0124925, theta=-35.352605 -> V=1.0, theta=0.0
% INFO    : Bus 13389	: V=1.0122002, theta=-35.380643 -> V=1.0, theta=0.0
% INFO    : Bus 13390	: V=1.0298905, theta=-31.394601 -> V=1.0, theta=0.0
% INFO    : Bus 13391	: V=1.0298273, theta=-31.404155 -> V=1.0, theta=0.0
% INFO    : Bus 13392	: V=1.0188538, theta=-33.817714 -> V=1.0, theta=0.0
% INFO    : Bus 13393	: V=1.0186765, theta=-33.840659 -> V=1.0, theta=0.0
% INFO    : Bus 13394	: V=1.0250359, theta=-32.516704 -> V=1.0, theta=0.0
% INFO    : Bus 13395	: V=1.0247924, theta=-32.538142 -> V=1.0, theta=0.0
% INFO    : Bus 13396	: V=1.0378133, theta=-30.99991 -> V=1.0, theta=0.0
% INFO    : Bus 13397	: V=1.0221942, theta=-33.393211 -> V=1.0, theta=0.0
% INFO    : Bus 13398	: V=1.0387874, theta=-30.910683 -> V=1.0, theta=0.0
% INFO    : Bus 13399	: V=1.0158104, theta=-34.415272 -> V=1.0, theta=0.0
% INFO    : Bus 13400	: V=1.038337, theta=-28.152792 -> V=1.0, theta=0.0
% INFO    : Bus 13401	: V=1.038588, theta=-28.121873 -> V=1.0, theta=0.0
% INFO    : Bus 13402	: V=1.0390452, theta=-29.260107 -> V=1.0, theta=0.0
% INFO    : Bus 13403	: V=1.0204239, theta=-33.978337 -> V=1.0, theta=0.0
% INFO    : Bus 13404	: V=1.020255, theta=-34.002579 -> V=1.0, theta=0.0
% INFO    : Bus 13405	: V=1.028296, theta=-42.517013 -> V=1.0, theta=0.0
% INFO    : Bus 13406	: V=1.0284125, theta=-42.515021 -> V=1.0, theta=0.0
% INFO    : Bus 13407	: V=1.0334776, theta=-46.293551 -> V=1.0, theta=0.0
% INFO    : Bus 13408	: V=1.033839, theta=-46.288989 -> V=1.0, theta=0.0
% INFO    : Bus 13409	: V=1.0373574, theta=-21.275619 -> V=1.0, theta=0.0
% INFO    : Bus 13410	: V=1.0373961, theta=-21.269841 -> V=1.0, theta=0.0
% INFO    : Bus 13411	: V=1.0385748, theta=-19.382604 -> V=1.0, theta=0.0
% INFO    : Bus 13412	: V=1.0276355, theta=-20.20273 -> V=1.0, theta=0.0
% INFO    : Bus 13413	: V=1.0276198, theta=-20.205596 -> V=1.0, theta=0.0
% INFO    : Bus 13414	: V=1.0326921, theta=-19.800948 -> V=1.0, theta=0.0
% INFO    : Bus 13415	: V=1.0259672, theta=-19.762441 -> V=1.0, theta=0.0
% INFO    : Bus 13416	: V=1.0261524, theta=-19.744471 -> V=1.0, theta=0.0
% INFO    : Bus 13417	: V=1.0307403, theta=-19.423484 -> V=1.0, theta=0.0
% INFO    : Bus 13418	: V=1.0308916, theta=-19.402224 -> V=1.0, theta=0.0
% INFO    : Bus 13419	: V=1.0250468, theta=-27.603535 -> V=1.0, theta=0.0
% INFO    : Bus 13420	: V=1.0249372, theta=-27.614517 -> V=1.0, theta=0.0
% INFO    : Bus 13421	: V=1.0176048, theta=-30.607265 -> V=1.0, theta=0.0
% INFO    : Bus 13422	: V=1.0175066, theta=-30.617392 -> V=1.0, theta=0.0
% INFO    : Bus 13423	: V=1.0180186, theta=-30.602116 -> V=1.0, theta=0.0
% INFO    : Bus 13424	: V=1.0176048, theta=-30.607265 -> V=1.0, theta=0.0
% INFO    : Bus 13425	: V=1.0307779, theta=-22.176492 -> V=1.0, theta=0.0
% INFO    : Bus 13426	: V=1.0245007, theta=-20.65111 -> V=1.0, theta=0.0
% INFO    : Bus 13427	: V=1.036691, theta=-17.659538 -> V=1.0, theta=0.0
% INFO    : Bus 13428	: V=1.0353343, theta=-17.413279 -> V=1.0, theta=0.0
% INFO    : Bus 13429	: V=1.0351116, theta=-17.439889 -> V=1.0, theta=0.0
% INFO    : Bus 13430	: V=1.0355881, theta=-17.385303 -> V=1.0, theta=0.0
% INFO    : Bus 13431	: V=1.0407098, theta=-15.969172 -> V=1.0, theta=0.0
% INFO    : Bus 13432	: V=1.0368623, theta=-17.130969 -> V=1.0, theta=0.0
% INFO    : Bus 13433	: V=1.0392229, theta=-16.402075 -> V=1.0, theta=0.0
% INFO    : Bus 13434	: V=1.0392229, theta=-16.402075 -> V=1.0, theta=0.0
% INFO    : Bus 13435	: V=1.0368623, theta=-17.130969 -> V=1.0, theta=0.0
% INFO    : Bus 13436	: V=1.0368623, theta=-17.130969 -> V=1.0, theta=0.0
% INFO    : Bus 13437	: V=1.0368623, theta=-17.130969 -> V=1.0, theta=0.0
% INFO    : Bus 13438	: V=1.0410761, theta=-15.921181 -> V=1.0, theta=0.0
% INFO    : Bus 13439	: V=1.0372344, theta=-20.793859 -> V=1.0, theta=0.0
% INFO    : Bus 13440	: V=1.042593, theta=-19.373657 -> V=1.0, theta=0.0
% INFO    : Bus 13441	: V=1.0319753, theta=-22.585682 -> V=1.0, theta=0.0
% INFO    : Bus 13442	: V=1.0355174, theta=-19.937435 -> V=1.0, theta=0.0
% INFO    : Bus 13443	: V=1.0288269, theta=-28.570795 -> V=1.0, theta=0.0
% INFO    : Bus 13444	: V=1.0287306, theta=-28.577478 -> V=1.0, theta=0.0
% INFO    : Bus 13445	: V=1.0289286, theta=-28.56397 -> V=1.0, theta=0.0
% INFO    : Bus 13446	: V=1.0374038, theta=-19.672627 -> V=1.0, theta=0.0
% INFO    : Bus 13447	: V=1.0224432, theta=-27.988775 -> V=1.0, theta=0.0
% INFO    : Bus 13448	: V=1.0228301, theta=-30.762061 -> V=1.0, theta=0.0
% INFO    : Bus 13449	: V=1.0364963, theta=-20.1235 -> V=1.0, theta=0.0
% INFO    : Bus 13450	: V=1.0364963, theta=-20.1235 -> V=1.0, theta=0.0
% INFO    : Bus 13451	: V=1.0364963, theta=-20.1235 -> V=1.0, theta=0.0
% INFO    : Bus 13452	: V=1.0364963, theta=-20.1235 -> V=1.0, theta=0.0
% INFO    : Bus 13453	: V=1.0320674, theta=-32.816034 -> V=1.0, theta=0.0
% INFO    : Bus 13454	: V=1.036, theta=-32.788374 -> V=1.0, theta=0.0
% INFO    : Bus 13455	: V=1.0349136, theta=-32.795994 -> V=1.0, theta=0.0
% INFO    : Bus 13456	: V=1.0349136, theta=-32.795994 -> V=1.0, theta=0.0
% INFO    : Bus 13457	: V=1.0328289, theta=-32.828955 -> V=1.0, theta=0.0
% INFO    : Bus 13458	: V=1.0470605, theta=-21.162532 -> V=1.0, theta=0.0
% INFO    : Bus 13459	: V=1.0145718, theta=-45.184361 -> V=1.0, theta=0.0
% INFO    : Bus 13460	: V=1.0192, theta=-45.364939 -> V=1.0, theta=0.0
% INFO    : Bus 13461	: V=1.0145616, theta=-45.185381 -> V=1.0, theta=0.0
% INFO    : Bus 13462	: V=1.0300921, theta=-30.149867 -> V=1.0, theta=0.0
% INFO    : Bus 13463	: V=1.0299694, theta=-30.232123 -> V=1.0, theta=0.0
% INFO    : Bus 13464	: V=1.0418615, theta=-16.901926 -> V=1.0, theta=0.0
% INFO    : Bus 13465	: V=1.0402244, theta=-17.62319 -> V=1.0, theta=0.0
% INFO    : Bus 13466	: V=1.0375647, theta=-15.71134 -> V=1.0, theta=0.0
% INFO    : Bus 13467	: V=1.0441696, theta=-20.891165 -> V=1.0, theta=0.0
% INFO    : Bus 13468	: V=1.0067546, theta=-14.721606 -> V=1.0, theta=0.0
% INFO    : Bus 13469	: V=1.0441539, theta=-20.892264 -> V=1.0, theta=0.0
% INFO    : Bus 13470	: V=1.0301455, theta=-18.723431 -> V=1.0, theta=0.0
% INFO    : Bus 13471	: V=1.0324737, theta=-18.292889 -> V=1.0, theta=0.0
% INFO    : Bus 13472	: V=1.0314601, theta=-19.29175 -> V=1.0, theta=0.0
% INFO    : Bus 13473	: V=1.0308498, theta=-20.13476 -> V=1.0, theta=0.0
% INFO    : Bus 13474	: V=1.0308498, theta=-20.13476 -> V=1.0, theta=0.0
% INFO    : Bus 13475	: V=1.029694, theta=-18.108811 -> V=1.0, theta=0.0
% INFO    : Bus 13476	: V=1.0296739, theta=-18.189472 -> V=1.0, theta=0.0
% INFO    : Bus 13477	: V=1.0298022, theta=-18.224722 -> V=1.0, theta=0.0
% INFO    : Bus 13478	: V=1.0301455, theta=-18.723431 -> V=1.0, theta=0.0
% INFO    : Bus 13479	: V=1.0294413, theta=-17.971802 -> V=1.0, theta=0.0
% INFO    : Bus 13480	: V=1.0299368, theta=-18.561249 -> V=1.0, theta=0.0
% INFO    : Bus 13481	: V=1.034953, theta=-19.619827 -> V=1.0, theta=0.0
% INFO    : Bus 13482	: V=1.0352867, theta=-20.306165 -> V=1.0, theta=0.0
% INFO    : Bus 13483	: V=1.034953, theta=-19.619827 -> V=1.0, theta=0.0
% INFO    : Bus 13484	: V=1.0391102, theta=-21.879679 -> V=1.0, theta=0.0
% INFO    : Bus 13485	: V=1.0447067, theta=-23.788696 -> V=1.0, theta=0.0
% INFO    : Bus 13486	: V=1.0367103, theta=-20.914423 -> V=1.0, theta=0.0
% INFO    : Bus 13487	: V=1.0338438, theta=-19.861761 -> V=1.0, theta=0.0
% INFO    : Bus 13488	: V=1.0299449, theta=-33.684216 -> V=1.0, theta=0.0
% INFO    : Bus 13489	: V=1.0312847, theta=-34.783986 -> V=1.0, theta=0.0
% INFO    : Bus 13490	: V=1.0299172, theta=-33.685846 -> V=1.0, theta=0.0
% INFO    : Bus 13491	: V=1.0301978, theta=-33.670943 -> V=1.0, theta=0.0
% INFO    : Bus 13492	: V=1.0198545, theta=-38.415178 -> V=1.0, theta=0.0
% INFO    : Bus 13493	: V=1.0204044, theta=-37.266468 -> V=1.0, theta=0.0
% INFO    : Bus 13494	: V=1.0198873, theta=-38.31167 -> V=1.0, theta=0.0
% INFO    : Bus 13495	: V=1.0198873, theta=-38.31167 -> V=1.0, theta=0.0
% INFO    : Bus 13496	: V=1.0294586, theta=-22.650806 -> V=1.0, theta=0.0
% INFO    : Bus 13497	: V=1.0372951, theta=-22.723349 -> V=1.0, theta=0.0
% INFO    : Bus 13498	: V=1.042045, theta=-23.255092 -> V=1.0, theta=0.0
% INFO    : Bus 13499	: V=0.9962793, theta=-21.153432 -> V=1.0, theta=0.0
% INFO    : Bus 13500	: V=1.0294586, theta=-22.650806 -> V=1.0, theta=0.0
% INFO    : Bus 13501	: V=1.0035249, theta=-21.794532 -> V=1.0, theta=0.0
% INFO    : Bus 13502	: V=0.9968155, theta=-21.214437 -> V=1.0, theta=0.0
% INFO    : Bus 13503	: V=1.0031449, theta=-21.697934 -> V=1.0, theta=0.0
% INFO    : Bus 13504	: V=1.0038069, theta=-21.983443 -> V=1.0, theta=0.0
% INFO    : Bus 13505	: V=1.038221, theta=-22.724209 -> V=1.0, theta=0.0
% INFO    : Bus 13506	: V=1.031791, theta=-18.885208 -> V=1.0, theta=0.0
% INFO    : Bus 13507	: V=1.033873, theta=-18.158997 -> V=1.0, theta=0.0
% INFO    : Bus 13508	: V=1.031731, theta=-18.966717 -> V=1.0, theta=0.0
% INFO    : Bus 13509	: V=1.0300297, theta=-17.960999 -> V=1.0, theta=0.0
% INFO    : Bus 13510	: V=1.0296979, theta=-17.823925 -> V=1.0, theta=0.0
% INFO    : Bus 13511	: V=1.0302372, theta=-18.082137 -> V=1.0, theta=0.0
% INFO    : Bus 13512	: V=1.0270162, theta=-31.730046 -> V=1.0, theta=0.0
% INFO    : Bus 13513	: V=1.0313065, theta=-36.737935 -> V=1.0, theta=0.0
% INFO    : Bus 13514	: V=1.0473958, theta=-21.339401 -> V=1.0, theta=0.0
% INFO    : Bus 13515	: V=1.0368947, theta=-17.714773 -> V=1.0, theta=0.0
% INFO    : Bus 13516	: V=1.0394651, theta=-21.996322 -> V=1.0, theta=0.0
% INFO    : Bus 13517	: V=1.04526, theta=-23.470221 -> V=1.0, theta=0.0
% INFO    : Bus 13518	: V=1.036263, theta=-20.983069 -> V=1.0, theta=0.0
% INFO    : Bus 13519	: V=1.0362282, theta=-20.83198 -> V=1.0, theta=0.0
% INFO    : Bus 13520	: V=1.0335254, theta=-19.760665 -> V=1.0, theta=0.0
% INFO    : Bus 13521	: V=1.0386057, theta=-21.693365 -> V=1.0, theta=0.0
% INFO    : Bus 13522	: V=1.0334826, theta=-45.286649 -> V=1.0, theta=0.0
% INFO    : Bus 13523	: V=1.0561825, theta=-27.926184 -> V=1.0, theta=0.0
% INFO    : Bus 13524	: V=1.0506585, theta=-29.23742 -> V=1.0, theta=0.0
% INFO    : Bus 13525	: V=1.0473224, theta=-29.365923 -> V=1.0, theta=0.0
% INFO    : Bus 13526	: V=1.0558689, theta=-27.476605 -> V=1.0, theta=0.0
% INFO    : Bus 13527	: V=1.0556573, theta=-27.572169 -> V=1.0, theta=0.0
% INFO    : Bus 13528	: V=1.0561825, theta=-27.926184 -> V=1.0, theta=0.0
% INFO    : Bus 13529	: V=1.0483035, theta=-24.744104 -> V=1.0, theta=0.0
% INFO    : Bus 13530	: V=1.0261813, theta=-22.675042 -> V=1.0, theta=0.0
% INFO    : Bus 13531	: V=1.0482974, theta=-24.745204 -> V=1.0, theta=0.0
% INFO    : Bus 13532	: V=1.0286361, theta=-35.48485 -> V=1.0, theta=0.0
% INFO    : Bus 13533	: V=1.027896, theta=-34.444187 -> V=1.0, theta=0.0
% INFO    : Bus 13534	: V=1.0279652, theta=-34.182548 -> V=1.0, theta=0.0
% INFO    : Bus 13535	: V=1.0284821, theta=-35.281293 -> V=1.0, theta=0.0
% INFO    : Bus 13536	: V=1.0286078, theta=-35.487175 -> V=1.0, theta=0.0
% INFO    : Bus 13537	: V=1.033598, theta=-18.003383 -> V=1.0, theta=0.0
% INFO    : Bus 13538	: V=1.0331221, theta=-18.806177 -> V=1.0, theta=0.0
% INFO    : Bus 13539	: V=1.0080612, theta=-15.029704 -> V=1.0, theta=0.0
% INFO    : Bus 13540	: V=1.0123231, theta=-16.775999 -> V=1.0, theta=0.0
% INFO    : Bus 13541	: V=1.0108472, theta=-16.118726 -> V=1.0, theta=0.0
% INFO    : Bus 13542	: V=1.0110572, theta=-16.089363 -> V=1.0, theta=0.0
% INFO    : Bus 13543	: V=1.0198559, theta=-20.752515 -> V=1.0, theta=0.0
% INFO    : Bus 13544	: V=1.0252407, theta=-21.195358 -> V=1.0, theta=0.0
% INFO    : Bus 13545	: V=1.0267379, theta=-21.332375 -> V=1.0, theta=0.0
% INFO    : Bus 13546	: V=1.0267607, theta=-21.31769 -> V=1.0, theta=0.0
% INFO    : Bus 13547	: V=1.0195795, theta=-20.746345 -> V=1.0, theta=0.0
% INFO    : Bus 13548	: V=1.0213892, theta=-42.628715 -> V=1.0, theta=0.0
% INFO    : Bus 13549	: V=1.0597885, theta=-45.562517 -> V=1.0, theta=0.0
% INFO    : Bus 13550	: V=1.0385537, theta=-18.900549 -> V=1.0, theta=0.0
% INFO    : Bus 13551	: V=1.0342076, theta=-13.992621 -> V=1.0, theta=0.0
% INFO    : Bus 13552	: V=1.0318076, theta=-13.25002 -> V=1.0, theta=0.0
% INFO    : Bus 13553	: V=1.0384903, theta=-19.057452 -> V=1.0, theta=0.0
% INFO    : Bus 13554	: V=1.047652, theta=-42.035327 -> V=1.0, theta=0.0
% INFO    : Bus 13555	: V=1.0303556, theta=-43.957445 -> V=1.0, theta=0.0
% INFO    : Bus 13556	: V=1.0334491, theta=-45.300827 -> V=1.0, theta=0.0
% INFO    : Bus 13557	: V=1.0344214, theta=-45.67722 -> V=1.0, theta=0.0
% INFO    : Bus 13558	: V=1.0344214, theta=-45.67722 -> V=1.0, theta=0.0
% INFO    : Bus 13559	: V=1.047652, theta=-42.035327 -> V=1.0, theta=0.0
% INFO    : Bus 13560	: V=1.0204372, theta=-41.152672 -> V=1.0, theta=0.0
% INFO    : Bus 13561	: V=1.0207209, theta=-41.294182 -> V=1.0, theta=0.0
% INFO    : Bus 13562	: V=1.0318182, theta=-35.830762 -> V=1.0, theta=0.0
% INFO    : Bus 13563	: V=1.0195847, theta=-39.325313 -> V=1.0, theta=0.0
% INFO    : Bus 13564	: V=1.0219794, theta=-38.539544 -> V=1.0, theta=0.0
% INFO    : Bus 13565	: V=1.0219794, theta=-38.539544 -> V=1.0, theta=0.0
% INFO    : Bus 13566	: V=1.0006034, theta=-35.684165 -> V=1.0, theta=0.0
% INFO    : Bus 13567	: V=1.0006052, theta=-35.673473 -> V=1.0, theta=0.0
% INFO    : Bus 13568	: V=1.0005752, theta=-35.829366 -> V=1.0, theta=0.0
% INFO    : Bus 13569	: V=1.0472772, theta=-20.401782 -> V=1.0, theta=0.0
% INFO    : Bus 13570	: V=1.0566171, theta=-17.220328 -> V=1.0, theta=0.0
% INFO    : Bus 13571	: V=1.00819, theta=-39.771161 -> V=1.0, theta=0.0
% INFO    : Bus 13572	: V=1.038184, theta=-41.715143 -> V=1.0, theta=0.0
% INFO    : Bus 13573	: V=1.0397292, theta=-18.281127 -> V=1.0, theta=0.0
% INFO    : Bus 13574	: V=1.047094, theta=-21.619901 -> V=1.0, theta=0.0
% INFO    : Bus 13575	: V=1.0470577, theta=-21.660304 -> V=1.0, theta=0.0
% INFO    : Bus 13576	: V=1.034, theta=-34.73898 -> V=1.0, theta=0.0
% INFO    : Bus 13577	: V=1.055432, theta=-30.92519 -> V=1.0, theta=0.0
% INFO    : Bus 13578	: V=1.0481708, theta=-31.412642 -> V=1.0, theta=0.0
% INFO    : Bus 13579	: V=1.0337693, theta=-34.771442 -> V=1.0, theta=0.0
% INFO    : Bus 13580	: V=1.044792, theta=-31.12438 -> V=1.0, theta=0.0
% INFO    : Bus 13581	: V=1.0400154, theta=-33.609592 -> V=1.0, theta=0.0
% INFO    : Bus 13582	: V=1.0303398, theta=-37.555341 -> V=1.0, theta=0.0
% INFO    : Bus 13583	: V=1.0446034, theta=-30.97819 -> V=1.0, theta=0.0
% INFO    : Bus 13584	: V=1.0445104, theta=-30.79615 -> V=1.0, theta=0.0
% INFO    : Bus 13585	: V=1.0446975, theta=-31.001395 -> V=1.0, theta=0.0
% INFO    : Bus 13586	: V=1.0397381, theta=-33.322856 -> V=1.0, theta=0.0
% INFO    : Bus 13587	: V=1.0447297, theta=-31.047298 -> V=1.0, theta=0.0
% INFO    : Bus 13588	: V=1.0376089, theta=-34.153556 -> V=1.0, theta=0.0
% INFO    : Bus 13589	: V=1.0450078, theta=-21.937652 -> V=1.0, theta=0.0
% INFO    : Bus 13590	: V=1.0279388, theta=-16.113961 -> V=1.0, theta=0.0
% INFO    : Bus 13591	: V=1.0449898, theta=-21.998745 -> V=1.0, theta=0.0
% INFO    : Bus 13592	: V=1.0291062, theta=-32.132817 -> V=1.0, theta=0.0
% INFO    : Bus 13593	: V=1.0288455, theta=-34.250074 -> V=1.0, theta=0.0
% INFO    : Bus 13594	: V=1.0192204, theta=-16.557697 -> V=1.0, theta=0.0
% INFO    : Bus 13595	: V=1.0202118, theta=-18.740564 -> V=1.0, theta=0.0
% INFO    : Bus 13596	: V=1.0229882, theta=-19.495946 -> V=1.0, theta=0.0
% INFO    : Bus 13597	: V=1.0192204, theta=-16.557697 -> V=1.0, theta=0.0
% INFO    : Bus 13598	: V=1.0256249, theta=-15.937994 -> V=1.0, theta=0.0
% INFO    : Bus 13599	: V=1.0249657, theta=-15.82998 -> V=1.0, theta=0.0
% INFO    : Bus 13600	: V=1.0417943, theta=-37.867623 -> V=1.0, theta=0.0
% INFO    : Bus 13601	: V=1.0411275, theta=-38.099107 -> V=1.0, theta=0.0
% INFO    : Bus 13602	: V=1.0477367, theta=-37.376163 -> V=1.0, theta=0.0
% INFO    : Bus 13603	: V=1.040612, theta=-38.156662 -> V=1.0, theta=0.0
% INFO    : Bus 13604	: V=1.040612, theta=-38.156662 -> V=1.0, theta=0.0
% INFO    : Bus 13605	: V=1.0410566, theta=-17.484567 -> V=1.0, theta=0.0
% INFO    : Bus 13606	: V=1.024121, theta=-13.319188 -> V=1.0, theta=0.0
% INFO    : Bus 13607	: V=1.0410961, theta=-17.525567 -> V=1.0, theta=0.0
% INFO    : Bus 13608	: V=1.0410566, theta=-17.484567 -> V=1.0, theta=0.0
% INFO    : Bus 13609	: V=1.0410566, theta=-17.484567 -> V=1.0, theta=0.0
% INFO    : Bus 13610	: V=1.0410566, theta=-17.484567 -> V=1.0, theta=0.0
% INFO    : Bus 13611	: V=1.0325183, theta=-41.535141 -> V=1.0, theta=0.0
% INFO    : Bus 13612	: V=1.0245776, theta=-39.342785 -> V=1.0, theta=0.0
% INFO    : Bus 13613	: V=1.0237297, theta=-35.395127 -> V=1.0, theta=0.0
% INFO    : Bus 13614	: V=1.0351408, theta=-20.039859 -> V=1.0, theta=0.0
% INFO    : Bus 13615	: V=1.0351388, theta=-20.044299 -> V=1.0, theta=0.0
% INFO    : Bus 13616	: V=1.0400341, theta=-21.004928 -> V=1.0, theta=0.0
% INFO    : Bus 13617	: V=1.0444118, theta=-20.723569 -> V=1.0, theta=0.0
% INFO    : Bus 13618	: V=1.0340836, theta=-19.071433 -> V=1.0, theta=0.0
% INFO    : Bus 13619	: V=1.0397161, theta=-21.12035 -> V=1.0, theta=0.0
% INFO    : Bus 13620	: V=1.036295, theta=-23.912756 -> V=1.0, theta=0.0
% INFO    : Bus 13621	: V=1.0340692, theta=-25.136303 -> V=1.0, theta=0.0
% INFO    : Bus 13622	: V=1.0382708, theta=-27.178747 -> V=1.0, theta=0.0
% INFO    : Bus 13623	: V=1.0324074, theta=-26.291747 -> V=1.0, theta=0.0
% INFO    : Bus 13624	: V=1.0324074, theta=-26.291747 -> V=1.0, theta=0.0
% INFO    : Bus 13625	: V=1.036295, theta=-23.912756 -> V=1.0, theta=0.0
% INFO    : Bus 13626	: V=1.0357716, theta=-23.371361 -> V=1.0, theta=0.0
% INFO    : Bus 13627	: V=1.0355288, theta=-23.160034 -> V=1.0, theta=0.0
% INFO    : Bus 13628	: V=1.036295, theta=-23.912756 -> V=1.0, theta=0.0
% INFO    : Bus 13629	: V=1.0354003, theta=-22.820286 -> V=1.0, theta=0.0
% INFO    : Bus 13630	: V=1.036295, theta=-23.912756 -> V=1.0, theta=0.0
% INFO    : Bus 13631	: V=1.0360942, theta=-24.243055 -> V=1.0, theta=0.0
% INFO    : Bus 13632	: V=1.0198383, theta=-47.842626 -> V=1.0, theta=0.0
% INFO    : Bus 13633	: V=1.0418927, theta=-38.102243 -> V=1.0, theta=0.0
% INFO    : Bus 13634	: V=1.0497475, theta=-22.58655 -> V=1.0, theta=0.0
% INFO    : Bus 13635	: V=1.0496452, theta=-22.642676 -> V=1.0, theta=0.0
% INFO    : Bus 13636	: V=1.0497475, theta=-22.58655 -> V=1.0, theta=0.0
% INFO    : Bus 13637	: V=1.0424679, theta=-16.790218 -> V=1.0, theta=0.0
% INFO    : Bus 13638	: V=1.041256, theta=-17.735052 -> V=1.0, theta=0.0
% INFO    : Bus 13639	: V=1.0407448, theta=-18.220091 -> V=1.0, theta=0.0
% INFO    : Bus 13640	: V=1.0407448, theta=-18.220091 -> V=1.0, theta=0.0
% INFO    : Bus 13641	: V=1.0084414, theta=-15.991504 -> V=1.0, theta=0.0
% INFO    : Bus 13642	: V=1.0093486, theta=-16.227748 -> V=1.0, theta=0.0
% INFO    : Bus 13643	: V=1.0426027, theta=-16.80672 -> V=1.0, theta=0.0
% INFO    : Bus 13644	: V=1.0424679, theta=-16.790218 -> V=1.0, theta=0.0
% INFO    : Bus 13645	: V=1.0324463, theta=-28.27027 -> V=1.0, theta=0.0
% INFO    : Bus 13646	: V=1.0303772, theta=-28.849147 -> V=1.0, theta=0.0
% INFO    : Bus 13647	: V=1.0294647, theta=-30.382834 -> V=1.0, theta=0.0
% INFO    : Bus 13648	: V=1.0300195, theta=-28.881409 -> V=1.0, theta=0.0
% INFO    : Bus 13649	: V=1.0324297, theta=-28.455806 -> V=1.0, theta=0.0
% INFO    : Bus 13650	: V=1.0293669, theta=-34.534063 -> V=1.0, theta=0.0
% INFO    : Bus 13651	: V=1.0358498, theta=-37.221939 -> V=1.0, theta=0.0
% INFO    : Bus 13652	: V=1.0164397, theta=-34.340134 -> V=1.0, theta=0.0
% INFO    : Bus 13653	: V=1.0164476, theta=-34.312201 -> V=1.0, theta=0.0
% INFO    : Bus 13654	: V=1.0166227, theta=-34.499312 -> V=1.0, theta=0.0
% INFO    : Bus 13655	: V=1.0263133, theta=-43.334122 -> V=1.0, theta=0.0
% INFO    : Bus 13656	: V=1.0265492, theta=-35.850624 -> V=1.0, theta=0.0
% INFO    : Bus 13657	: V=1.0404418, theta=-37.93818 -> V=1.0, theta=0.0
% INFO    : Bus 13658	: V=1.0264099, theta=-35.701165 -> V=1.0, theta=0.0
% INFO    : Bus 13659	: V=1.0262783, theta=-35.520558 -> V=1.0, theta=0.0
% INFO    : Bus 13660	: V=1.0464548, theta=-23.727236 -> V=1.0, theta=0.0
% INFO    : Bus 13661	: V=0.9828267, theta=-19.577944 -> V=1.0, theta=0.0
% INFO    : Bus 13662	: V=0.9885902, theta=-21.5317 -> V=1.0, theta=0.0
% INFO    : Bus 13663	: V=1.0382949, theta=-29.501271 -> V=1.0, theta=0.0
% INFO    : Bus 13664	: V=1.0367494, theta=-33.96287 -> V=1.0, theta=0.0
% INFO    : Bus 13665	: V=1.0419139, theta=-32.71744 -> V=1.0, theta=0.0
% INFO    : Bus 13666	: V=1.0320242, theta=-26.474307 -> V=1.0, theta=0.0
% INFO    : Bus 13667	: V=1.0251875, theta=-29.344959 -> V=1.0, theta=0.0
% INFO    : Bus 13668	: V=1.0260022, theta=-30.475873 -> V=1.0, theta=0.0
% INFO    : Bus 13669	: V=1.0320242, theta=-26.474307 -> V=1.0, theta=0.0
% INFO    : Bus 13670	: V=1.0315739, theta=-25.861698 -> V=1.0, theta=0.0
% INFO    : Bus 13671	: V=1.0314048, theta=-25.960329 -> V=1.0, theta=0.0
% INFO    : Bus 13672	: V=1.0320242, theta=-26.474307 -> V=1.0, theta=0.0
% INFO    : Bus 13673	: V=1.0320242, theta=-26.474307 -> V=1.0, theta=0.0
% INFO    : Bus 13674	: V=1.0310634, theta=-25.325571 -> V=1.0, theta=0.0
% INFO    : Bus 13675	: V=1.03707, theta=-19.284298 -> V=1.0, theta=0.0
% INFO    : Bus 13676	: V=1.0384655, theta=-19.115321 -> V=1.0, theta=0.0
% INFO    : Bus 13677	: V=1.03707, theta=-19.284298 -> V=1.0, theta=0.0
% INFO    : Bus 13678	: V=1.0406453, theta=-17.78187 -> V=1.0, theta=0.0
% INFO    : Bus 13679	: V=1.0416273, theta=-37.909475 -> V=1.0, theta=0.0
% INFO    : Bus 13680	: V=0.9833991, theta=-34.506814 -> V=1.0, theta=0.0
% INFO    : Bus 13681	: V=1.043, theta=-22.08524 -> V=1.0, theta=0.0
% INFO    : Bus 13682	: V=1.0478445, theta=-21.594574 -> V=1.0, theta=0.0
% INFO    : Bus 13683	: V=1.0475371, theta=-21.479843 -> V=1.0, theta=0.0
% INFO    : Bus 13684	: V=1.0191376, theta=-21.660071 -> V=1.0, theta=0.0
% INFO    : Bus 13685	: V=1.0211531, theta=-21.375246 -> V=1.0, theta=0.0
% INFO    : Bus 13686	: V=1.043, theta=-22.08524 -> V=1.0, theta=0.0
% INFO    : Bus 13687	: V=1.028723, theta=-28.7791 -> V=1.0, theta=0.0
% INFO    : Bus 13688	: V=1.0286522, theta=-28.799553 -> V=1.0, theta=0.0
% INFO    : Bus 13689	: V=1.0305352, theta=-28.807067 -> V=1.0, theta=0.0
% INFO    : Bus 13690	: V=1.0300216, theta=-30.221573 -> V=1.0, theta=0.0
% INFO    : Bus 13691	: V=1.0301063, theta=-31.532733 -> V=1.0, theta=0.0
% INFO    : Bus 13692	: V=1.0301063, theta=-31.532733 -> V=1.0, theta=0.0
% INFO    : Bus 13693	: V=1.0512742, theta=-26.165602 -> V=1.0, theta=0.0
% INFO    : Bus 13694	: V=1.0518322, theta=-26.115138 -> V=1.0, theta=0.0
% INFO    : Bus 13695	: V=1.0399981, theta=-20.42047 -> V=1.0, theta=0.0
% INFO    : Bus 13696	: V=1.0402794, theta=-20.129081 -> V=1.0, theta=0.0
% INFO    : Bus 13697	: V=1.0395081, theta=-19.840968 -> V=1.0, theta=0.0
% INFO    : Bus 13698	: V=1.0548541, theta=-18.66843 -> V=1.0, theta=0.0
% INFO    : Bus 13699	: V=1.0405098, theta=-20.090302 -> V=1.0, theta=0.0
% INFO    : Bus 20000	: V=1.0279988, theta=-58.474584 -> V=1.0, theta=0.0
% INFO    : Bus 20001	: V=1.0223533, theta=-55.185456 -> V=1.0, theta=0.0
% INFO    : Bus 20002	: V=1.0245656, theta=-54.726178 -> V=1.0, theta=0.0
% INFO    : Bus 20003	: V=1.0242518, theta=-54.747764 -> V=1.0, theta=0.0
% INFO    : Bus 20004	: V=1.0281468, theta=-58.467772 -> V=1.0, theta=0.0
% INFO    : Bus 20005	: V=1.0194026, theta=-48.984847 -> V=1.0, theta=0.0
% INFO    : Bus 20006	: V=1.0228056, theta=-49.930575 -> V=1.0, theta=0.0
% INFO    : Bus 20007	: V=1.0191911, theta=-49.014081 -> V=1.0, theta=0.0
% INFO    : Bus 20008	: V=1.0279, theta=-57.857579 -> V=1.0, theta=0.0
% INFO    : Bus 20009	: V=1.0276996, theta=-57.878903 -> V=1.0, theta=0.0
% INFO    : Bus 20010	: V=1.0193456, theta=-57.266493 -> V=1.0, theta=0.0
% INFO    : Bus 20011	: V=1.0192494, theta=-57.276054 -> V=1.0, theta=0.0
% INFO    : Bus 20012	: V=1.013424, theta=-63.864729 -> V=1.0, theta=0.0
% INFO    : Bus 20013	: V=1.0135421, theta=-63.85772 -> V=1.0, theta=0.0
% INFO    : Bus 20014	: V=1.0143254, theta=-63.513158 -> V=1.0, theta=0.0
% INFO    : Bus 20015	: V=1.0324936, theta=-57.449359 -> V=1.0, theta=0.0
% INFO    : Bus 20016	: V=1.0324216, theta=-57.456294 -> V=1.0, theta=0.0
% INFO    : Bus 20017	: V=1.0156602, theta=-59.433793 -> V=1.0, theta=0.0
% INFO    : Bus 20018	: V=1.0156186, theta=-59.440204 -> V=1.0, theta=0.0
% INFO    : Bus 20019	: V=1.0169972, theta=-63.871509 -> V=1.0, theta=0.0
% INFO    : Bus 20020	: V=1.0169167, theta=-63.884825 -> V=1.0, theta=0.0
% INFO    : Bus 20021	: V=1.0169157, theta=-64.09091 -> V=1.0, theta=0.0
% INFO    : Bus 20022	: V=1.0172411, theta=-61.685816 -> V=1.0, theta=0.0
% INFO    : Bus 20023	: V=1.0195062, theta=-63.638591 -> V=1.0, theta=0.0
% INFO    : Bus 20024	: V=1.0189836, theta=-61.628905 -> V=1.0, theta=0.0
% INFO    : Bus 20025	: V=1.0173746, theta=-63.862559 -> V=1.0, theta=0.0
% INFO    : Bus 20026	: V=1.0198386, theta=-53.858677 -> V=1.0, theta=0.0
% INFO    : Bus 20027	: V=1.0179369, theta=-64.776918 -> V=1.0, theta=0.0
% INFO    : Bus 20028	: V=1.0335715, theta=-52.727305 -> V=1.0, theta=0.0
% INFO    : Bus 20029	: V=1.0147504, theta=-64.488498 -> V=1.0, theta=0.0
% INFO    : Bus 20030	: V=1.0210388, theta=-50.463859 -> V=1.0, theta=0.0
% INFO    : Bus 20031	: V=1.0157189, theta=-64.476061 -> V=1.0, theta=0.0
% INFO    : Bus 20032	: V=1.0147291, theta=-64.584967 -> V=1.0, theta=0.0
% INFO    : Bus 20033	: V=1.0146465, theta=-64.597884 -> V=1.0, theta=0.0
% INFO    : Bus 20034	: V=1.0176645, theta=-48.60024 -> V=1.0, theta=0.0
% INFO    : Bus 20035	: V=1.0175472, theta=-48.610507 -> V=1.0, theta=0.0
% INFO    : Bus 20036	: V=1.0169085, theta=-64.307889 -> V=1.0, theta=0.0
% INFO    : Bus 20037	: V=1.0177867, theta=-64.473149 -> V=1.0, theta=0.0
% INFO    : Bus 20038	: V=1.0215858, theta=-49.015764 -> V=1.0, theta=0.0
% INFO    : Bus 20039	: V=1.0215409, theta=-49.022896 -> V=1.0, theta=0.0
% INFO    : Bus 20040	: V=1.021589, theta=-52.169143 -> V=1.0, theta=0.0
% INFO    : Bus 20041	: V=1.0214646, theta=-52.187386 -> V=1.0, theta=0.0
% INFO    : Bus 20042	: V=1.0155974, theta=-51.817426 -> V=1.0, theta=0.0
% INFO    : Bus 20043	: V=1.0130579, theta=-53.506181 -> V=1.0, theta=0.0
% INFO    : Bus 20044	: V=1.0083335, theta=-54.731536 -> V=1.0, theta=0.0
% INFO    : Bus 20045	: V=1.0085208, theta=-54.718556 -> V=1.0, theta=0.0
% INFO    : Bus 20046	: V=1.0175828, theta=-54.582088 -> V=1.0, theta=0.0
% INFO    : Bus 20047	: V=1.0263209, theta=-49.007299 -> V=1.0, theta=0.0
% INFO    : Bus 20048	: V=1.0178176, theta=-47.924777 -> V=1.0, theta=0.0
% INFO    : Bus 20049	: V=1.0177873, theta=-47.929955 -> V=1.0, theta=0.0
% INFO    : Bus 20050	: V=1.0179887, theta=-51.623771 -> V=1.0, theta=0.0
% INFO    : Bus 20051	: V=1.0180831, theta=-51.60756 -> V=1.0, theta=0.0
% INFO    : Bus 20052	: V=1.0194431, theta=-52.616126 -> V=1.0, theta=0.0
% INFO    : Bus 20053	: V=1.0247613, theta=-62.593147 -> V=1.0, theta=0.0
% INFO    : Bus 20054	: V=1.0188199, theta=-52.249013 -> V=1.0, theta=0.0
% INFO    : Bus 20055	: V=1.0185859, theta=-52.273617 -> V=1.0, theta=0.0
% INFO    : Bus 20056	: V=1.0090578, theta=-56.976801 -> V=1.0, theta=0.0
% INFO    : Bus 20057	: V=1.0100434, theta=-59.92991 -> V=1.0, theta=0.0
% INFO    : Bus 20058	: V=1.0053892, theta=-58.937089 -> V=1.0, theta=0.0
% INFO    : Bus 20059	: V=1.0150354, theta=-51.663076 -> V=1.0, theta=0.0
% INFO    : Bus 20060	: V=1.0157367, theta=-51.458053 -> V=1.0, theta=0.0
% INFO    : Bus 20061	: V=1.0159467, theta=-51.433045 -> V=1.0, theta=0.0
% INFO    : Bus 20062	: V=1.0227494, theta=-50.581033 -> V=1.0, theta=0.0
% INFO    : Bus 20063	: V=1.0186453, theta=-55.056453 -> V=1.0, theta=0.0
% INFO    : Bus 20064	: V=1.0186026, theta=-55.061812 -> V=1.0, theta=0.0
% INFO    : Bus 20065	: V=1.018693, theta=-55.051237 -> V=1.0, theta=0.0
% INFO    : Bus 20066	: V=1.0118408, theta=-64.532361 -> V=1.0, theta=0.0
% INFO    : Bus 20067	: V=1.0271603, theta=-61.700806 -> V=1.0, theta=0.0
% INFO    : Bus 20068	: V=1.0270669, theta=-61.714156 -> V=1.0, theta=0.0
% INFO    : Bus 20069	: V=1.0312583, theta=-50.556166 -> V=1.0, theta=0.0
% INFO    : Bus 20070	: V=1.0158462, theta=-64.471441 -> V=1.0, theta=0.0
% INFO    : Bus 20071	: V=1.0159796, theta=-64.137082 -> V=1.0, theta=0.0
% INFO    : Bus 20072	: V=1.0161465, theta=-64.119059 -> V=1.0, theta=0.0
% INFO    : Bus 20073	: V=1.0324705, theta=-55.712238 -> V=1.0, theta=0.0
% INFO    : Bus 20074	: V=1.0269478, theta=-56.883277 -> V=1.0, theta=0.0
% INFO    : Bus 20075	: V=1.0200598, theta=-58.175467 -> V=1.0, theta=0.0
% INFO    : Bus 20076	: V=1.0199358, theta=-57.652349 -> V=1.0, theta=0.0
% INFO    : Bus 20077	: V=1.0224194, theta=-57.411868 -> V=1.0, theta=0.0
% INFO    : Bus 20078	: V=1.0222351, theta=-57.431054 -> V=1.0, theta=0.0
% INFO    : Bus 20079	: V=1.0176173, theta=-57.42083 -> V=1.0, theta=0.0
% INFO    : Bus 20080	: V=1.011044, theta=-57.442429 -> V=1.0, theta=0.0
% INFO    : Bus 20081	: V=1.0108684, theta=-57.457598 -> V=1.0, theta=0.0
% INFO    : Bus 20082	: V=1.0158165, theta=-64.442255 -> V=1.0, theta=0.0
% INFO    : Bus 20083	: V=1.0118305, theta=-65.795524 -> V=1.0, theta=0.0
% INFO    : Bus 20084	: V=1.0119624, theta=-65.771018 -> V=1.0, theta=0.0
% INFO    : Bus 20085	: V=1.0250483, theta=-60.427576 -> V=1.0, theta=0.0
% INFO    : Bus 20086	: V=1.0249312, theta=-60.441822 -> V=1.0, theta=0.0
% INFO    : Bus 20087	: V=1.0197943, theta=-60.539207 -> V=1.0, theta=0.0
% INFO    : Bus 20088	: V=1.0209586, theta=-65.029144 -> V=1.0, theta=0.0
% INFO    : Bus 20089	: V=1.0207756, theta=-65.041105 -> V=1.0, theta=0.0
% INFO    : Bus 20090	: V=1.0168467, theta=-63.764339 -> V=1.0, theta=0.0
% INFO    : Bus 20091	: V=1.019236, theta=-62.024293 -> V=1.0, theta=0.0
% INFO    : Bus 20092	: V=1.0305217, theta=-59.188757 -> V=1.0, theta=0.0
% INFO    : Bus 20093	: V=1.0303505, theta=-59.206333 -> V=1.0, theta=0.0
% INFO    : Bus 20094	: V=1.0306971, theta=-59.169384 -> V=1.0, theta=0.0
% INFO    : Bus 20095	: V=1.0102816, theta=-58.012997 -> V=1.0, theta=0.0
% INFO    : Bus 20096	: V=1.0100467, theta=-58.024836 -> V=1.0, theta=0.0
% INFO    : Bus 20097	: V=1.0119727, theta=-57.598397 -> V=1.0, theta=0.0
% INFO    : Bus 20098	: V=1.0186234, theta=-62.249447 -> V=1.0, theta=0.0
% INFO    : Bus 20099	: V=1.0189198, theta=-62.21486 -> V=1.0, theta=0.0
% INFO    : Bus 20100	: V=1.0183545, theta=-62.285443 -> V=1.0, theta=0.0
% INFO    : Bus 20101	: V=1.0047921, theta=-64.074822 -> V=1.0, theta=0.0
% INFO    : Bus 20102	: V=1.0044104, theta=-64.096095 -> V=1.0, theta=0.0
% INFO    : Bus 20103	: V=1.0051646, theta=-64.056088 -> V=1.0, theta=0.0
% INFO    : Bus 20104	: V=1.0047921, theta=-64.074822 -> V=1.0, theta=0.0
% INFO    : Bus 20105	: V=1.010371, theta=-65.381426 -> V=1.0, theta=0.0
% INFO    : Bus 20106	: V=1.012928, theta=-65.182656 -> V=1.0, theta=0.0
% INFO    : Bus 20107	: V=1.0130375, theta=-65.163767 -> V=1.0, theta=0.0
% INFO    : Bus 20108	: V=1.0220524, theta=-56.190208 -> V=1.0, theta=0.0
% INFO    : Bus 20109	: V=1.0221726, theta=-56.175218 -> V=1.0, theta=0.0
% INFO    : Bus 20110	: V=1.0228999, theta=-59.064725 -> V=1.0, theta=0.0
% INFO    : Bus 20111	: V=1.0075341, theta=-63.73266 -> V=1.0, theta=0.0
% INFO    : Bus 20112	: V=1.0076268, theta=-63.718723 -> V=1.0, theta=0.0
% INFO    : Bus 20113	: V=1.0074315, theta=-63.748021 -> V=1.0, theta=0.0
% INFO    : Bus 20114	: V=1.010517, theta=-65.308151 -> V=1.0, theta=0.0
% INFO    : Bus 20115	: V=1.0103898, theta=-65.321692 -> V=1.0, theta=0.0
% INFO    : Bus 20116	: V=1.0160347, theta=-65.810234 -> V=1.0, theta=0.0
% INFO    : Bus 20117	: V=1.0167823, theta=-66.053361 -> V=1.0, theta=0.0
% INFO    : Bus 20118	: V=1.0199294, theta=-65.772877 -> V=1.0, theta=0.0
% INFO    : Bus 20119	: V=1.0201534, theta=-65.757018 -> V=1.0, theta=0.0
% INFO    : Bus 20120	: V=1.0164558, theta=-65.446412 -> V=1.0, theta=0.0
% INFO    : Bus 20121	: V=1.0108506, theta=-65.362414 -> V=1.0, theta=0.0
% INFO    : Bus 20122	: V=1.0223358, theta=-61.217097 -> V=1.0, theta=0.0
% INFO    : Bus 20123	: V=1.0210937, theta=-65.020449 -> V=1.0, theta=0.0
% INFO    : Bus 20124	: V=1.0149276, theta=-65.586113 -> V=1.0, theta=0.0
% INFO    : Bus 20125	: V=1.0235372, theta=-65.64593 -> V=1.0, theta=0.0
% INFO    : Bus 20126	: V=1.0140167, theta=-66.214108 -> V=1.0, theta=0.0
% INFO    : Bus 20127	: V=1.0140167, theta=-66.214108 -> V=1.0, theta=0.0
% INFO    : Bus 20128	: V=1.0140167, theta=-66.214108 -> V=1.0, theta=0.0
% INFO    : Bus 20129	: V=1.0140167, theta=-66.214108 -> V=1.0, theta=0.0
% INFO    : Bus 20130	: V=1.0175794, theta=-61.238168 -> V=1.0, theta=0.0
% INFO    : Bus 20131	: V=1.0153156, theta=-62.170639 -> V=1.0, theta=0.0
% INFO    : Bus 20132	: V=1.0154296, theta=-62.154452 -> V=1.0, theta=0.0
% INFO    : Bus 20133	: V=1.0147393, theta=-65.889496 -> V=1.0, theta=0.0
% INFO    : Bus 20134	: V=1.0152038, theta=-65.862165 -> V=1.0, theta=0.0
% INFO    : Bus 20135	: V=1.0156, theta=-65.501408 -> V=1.0, theta=0.0
% INFO    : Bus 20136	: V=1.013015, theta=-64.800504 -> V=1.0, theta=0.0
% INFO    : Bus 20137	: V=1.020562, theta=-65.372945 -> V=1.0, theta=0.0
% INFO    : Bus 20138	: V=1.0204803, theta=-65.388355 -> V=1.0, theta=0.0
% INFO    : Bus 20139	: V=1.0142539, theta=-65.745443 -> V=1.0, theta=0.0
% INFO    : Bus 20140	: V=1.0140541, theta=-65.770065 -> V=1.0, theta=0.0
% INFO    : Bus 20141	: V=1.01799, theta=-65.287137 -> V=1.0, theta=0.0
% INFO    : Bus 20142	: V=1.0178752, theta=-65.308053 -> V=1.0, theta=0.0
% INFO    : Bus 20143	: V=1.0091802, theta=-65.527493 -> V=1.0, theta=0.0
% INFO    : Bus 20144	: V=1.0150696, theta=-66.338173 -> V=1.0, theta=0.0
% INFO    : Bus 20145	: V=1.0148272, theta=-66.369579 -> V=1.0, theta=0.0
% INFO    : Bus 20146	: V=1.0142127, theta=-66.070275 -> V=1.0, theta=0.0
% INFO    : Bus 20147	: V=1.0138842, theta=-66.103555 -> V=1.0, theta=0.0
% INFO    : Bus 20148	: V=1.0190882, theta=-65.414218 -> V=1.0, theta=0.0
% INFO    : Bus 20149	: V=1.0145873, theta=-66.055196 -> V=1.0, theta=0.0
% INFO    : Bus 20150	: V=1.014416, theta=-66.074155 -> V=1.0, theta=0.0
% INFO    : Bus 20151	: V=1.0132506, theta=-66.186019 -> V=1.0, theta=0.0
% INFO    : Bus 20152	: V=1.015246, theta=-66.306242 -> V=1.0, theta=0.0
% INFO    : Bus 20153	: V=1.0134376, theta=-65.734696 -> V=1.0, theta=0.0
% INFO    : Bus 20154	: V=1.0136639, theta=-65.718748 -> V=1.0, theta=0.0
% INFO    : Bus 20155	: V=1.0131843, theta=-65.75049 -> V=1.0, theta=0.0
% INFO    : Bus 20156	: V=1.0295062, theta=-47.039316 -> V=1.0, theta=0.0
% INFO    : Bus 20157	: V=1.0294908, theta=-47.041721 -> V=1.0, theta=0.0
% INFO    : Bus 20158	: V=1.0174957, theta=-65.774265 -> V=1.0, theta=0.0
% INFO    : Bus 20159	: V=1.0173392, theta=-65.791908 -> V=1.0, theta=0.0
% INFO    : Bus 20160	: V=1.0176622, theta=-65.757372 -> V=1.0, theta=0.0
% INFO    : Bus 20161	: V=1.0154976, theta=-66.123187 -> V=1.0, theta=0.0
% INFO    : Bus 20162	: V=1.0153078, theta=-66.142937 -> V=1.0, theta=0.0
% INFO    : Bus 20163	: V=1.0159007, theta=-66.269439 -> V=1.0, theta=0.0
% INFO    : Bus 20164	: V=1.0157691, theta=-66.289321 -> V=1.0, theta=0.0
% INFO    : Bus 20165	: V=1.0304945, theta=-57.53253 -> V=1.0, theta=0.0
% INFO    : Bus 20166	: V=1.0304051, theta=-57.547686 -> V=1.0, theta=0.0
% INFO    : Bus 20167	: V=1.0306054, theta=-57.515898 -> V=1.0, theta=0.0
% INFO    : Bus 20168	: V=1.0263338, theta=-59.134252 -> V=1.0, theta=0.0
% INFO    : Bus 20169	: V=1.0262446, theta=-59.149894 -> V=1.0, theta=0.0
% INFO    : Bus 20170	: V=1.0212016, theta=-66.016642 -> V=1.0, theta=0.0
% INFO    : Bus 20171	: V=1.0176656, theta=-65.96923 -> V=1.0, theta=0.0
% INFO    : Bus 20172	: V=1.0072809, theta=-65.84132 -> V=1.0, theta=0.0
% INFO    : Bus 20173	: V=1.0150299, theta=-65.771327 -> V=1.0, theta=0.0
% INFO    : Bus 20174	: V=1.0102944, theta=-65.499728 -> V=1.0, theta=0.0
% INFO    : Bus 20175	: V=1.0124671, theta=-65.301819 -> V=1.0, theta=0.0
% INFO    : Bus 20176	: V=1.0261614, theta=-65.895917 -> V=1.0, theta=0.0
% INFO    : Bus 20177	: V=1.0230024, theta=-65.871588 -> V=1.0, theta=0.0
% INFO    : Bus 20178	: V=1.0229014, theta=-65.889006 -> V=1.0, theta=0.0
% INFO    : Bus 20179	: V=1.0154989, theta=-65.88393 -> V=1.0, theta=0.0
% INFO    : Bus 20180	: V=1.0053642, theta=-65.714318 -> V=1.0, theta=0.0
% INFO    : Bus 20181	: V=1.0074812, theta=-65.800528 -> V=1.0, theta=0.0
% INFO    : Bus 20182	: V=1.004477, theta=-65.521319 -> V=1.0, theta=0.0
% INFO    : Bus 20183	: V=1.0054427, theta=-64.595596 -> V=1.0, theta=0.0
% INFO    : Bus 20184	: V=1.0138025, theta=-65.666421 -> V=1.0, theta=0.0
% INFO    : Bus 20185	: V=1.0093935, theta=-65.324025 -> V=1.0, theta=0.0
% INFO    : Bus 20186	: V=1.0121911, theta=-65.115383 -> V=1.0, theta=0.0
% INFO    : Bus 20187	: V=1.0121911, theta=-65.115383 -> V=1.0, theta=0.0
% INFO    : Bus 20188	: V=1.0121911, theta=-65.115383 -> V=1.0, theta=0.0
% INFO    : Bus 20189	: V=1.0121911, theta=-65.115383 -> V=1.0, theta=0.0
% INFO    : Bus 20190	: V=1.0193415, theta=-65.440646 -> V=1.0, theta=0.0
% INFO    : Bus 20191	: V=1.0190894, theta=-65.458311 -> V=1.0, theta=0.0
% INFO    : Bus 20192	: V=1.0055807, theta=-65.812409 -> V=1.0, theta=0.0
% INFO    : Bus 20193	: V=1.005304, theta=-65.846557 -> V=1.0, theta=0.0
% INFO    : Bus 20194	: V=1.0058426, theta=-65.778576 -> V=1.0, theta=0.0
% INFO    : Bus 20195	: V=1.0062012, theta=-65.969789 -> V=1.0, theta=0.0
% INFO    : Bus 20196	: V=1.0058749, theta=-66.000875 -> V=1.0, theta=0.0
% INFO    : Bus 20197	: V=1.0151137, theta=-65.726901 -> V=1.0, theta=0.0
% INFO    : Bus 20198	: V=1.0192009, theta=-65.429578 -> V=1.0, theta=0.0
% INFO    : Bus 20199	: V=1.0189901, theta=-65.453503 -> V=1.0, theta=0.0
% INFO    : Bus 20200	: V=1.0129742, theta=-66.679562 -> V=1.0, theta=0.0
% INFO    : Bus 20201	: V=1.0049626, theta=-66.143089 -> V=1.0, theta=0.0
% INFO    : Bus 20202	: V=1.0051506, theta=-66.103954 -> V=1.0, theta=0.0
% INFO    : Bus 20203	: V=1.0229215, theta=-64.518502 -> V=1.0, theta=0.0
% INFO    : Bus 20204	: V=1.0226637, theta=-64.547882 -> V=1.0, theta=0.0
% INFO    : Bus 20205	: V=1.0212837, theta=-64.989243 -> V=1.0, theta=0.0
% INFO    : Bus 20206	: V=1.0059902, theta=-65.528927 -> V=1.0, theta=0.0
% INFO    : Bus 20207	: V=1.0109383, theta=-64.671131 -> V=1.0, theta=0.0
% INFO    : Bus 20208	: V=1.0312278, theta=-65.122412 -> V=1.0, theta=0.0
% INFO    : Bus 20209	: V=1.0310738, theta=-65.143713 -> V=1.0, theta=0.0
% INFO    : Bus 20210	: V=1.0096143, theta=-64.843366 -> V=1.0, theta=0.0
% INFO    : Bus 20211	: V=1.0063701, theta=-64.950713 -> V=1.0, theta=0.0
% INFO    : Bus 20212	: V=1.006058, theta=-64.977276 -> V=1.0, theta=0.0
% INFO    : Bus 20213	: V=1.0077239, theta=-65.958155 -> V=1.0, theta=0.0
% INFO    : Bus 20214	: V=1.0142716, theta=-64.149652 -> V=1.0, theta=0.0
% INFO    : Bus 20215	: V=1.0134869, theta=-63.964272 -> V=1.0, theta=0.0
% INFO    : Bus 20216	: V=1.0136604, theta=-63.948543 -> V=1.0, theta=0.0
% INFO    : Bus 20217	: V=1.0055914, theta=-64.946176 -> V=1.0, theta=0.0
% INFO    : Bus 20218	: V=1.0057419, theta=-64.921287 -> V=1.0, theta=0.0
% INFO    : Bus 20219	: V=1.0053841, theta=-64.867534 -> V=1.0, theta=0.0
% INFO    : Bus 20220	: V=1.0137124, theta=-64.630689 -> V=1.0, theta=0.0
% INFO    : Bus 20221	: V=1.0135272, theta=-64.645581 -> V=1.0, theta=0.0
% INFO    : Bus 20222	: V=1.0183348, theta=-65.279394 -> V=1.0, theta=0.0
% INFO    : Bus 20223	: V=1.0183348, theta=-65.279394 -> V=1.0, theta=0.0
% INFO    : Bus 20224	: V=1.0183348, theta=-65.279394 -> V=1.0, theta=0.0
% INFO    : Bus 20225	: V=1.0183348, theta=-65.279394 -> V=1.0, theta=0.0
% INFO    : Bus 20226	: V=1.0184393, theta=-65.264824 -> V=1.0, theta=0.0
% INFO    : Bus 20227	: V=1.0182161, theta=-65.295535 -> V=1.0, theta=0.0
% INFO    : Bus 20228	: V=1.0330842, theta=-65.159353 -> V=1.0, theta=0.0
% INFO    : Bus 20229	: V=1.0103293, theta=-65.405618 -> V=1.0, theta=0.0
% INFO    : Bus 20230	: V=1.010579, theta=-65.367824 -> V=1.0, theta=0.0
% INFO    : Bus 20231	: V=1.01114, theta=-64.7016 -> V=1.0, theta=0.0
% INFO    : Bus 20232	: V=1.0082494, theta=-65.744989 -> V=1.0, theta=0.0
% INFO    : Bus 20233	: V=1.0130384, theta=-64.489129 -> V=1.0, theta=0.0
% INFO    : Bus 20234	: V=1.0132576, theta=-64.466916 -> V=1.0, theta=0.0
% INFO    : Bus 20235	: V=1.0130384, theta=-64.489129 -> V=1.0, theta=0.0
% INFO    : Bus 20236	: V=1.0262434, theta=-64.789287 -> V=1.0, theta=0.0
% INFO    : Bus 20237	: V=1.0083074, theta=-65.138208 -> V=1.0, theta=0.0
% INFO    : Bus 20238	: V=1.0230171, theta=-58.446588 -> V=1.0, theta=0.0
% INFO    : Bus 20239	: V=1.0120122, theta=-64.358921 -> V=1.0, theta=0.0
% INFO    : Bus 20240	: V=1.035282, theta=-65.231417 -> V=1.0, theta=0.0
% INFO    : Bus 20241	: V=1.015344, theta=-63.364035 -> V=1.0, theta=0.0
% INFO    : Bus 20242	: V=1.0152091, theta=-63.376916 -> V=1.0, theta=0.0
% INFO    : Bus 20243	: V=1.0201296, theta=-60.739769 -> V=1.0, theta=0.0
% INFO    : Bus 20244	: V=1.005564, theta=-64.763844 -> V=1.0, theta=0.0
% INFO    : Bus 20245	: V=0.9735955, theta=-72.006303 -> V=1.0, theta=0.0
% INFO    : Bus 20246	: V=1.0095096, theta=-66.801503 -> V=1.0, theta=0.0
% INFO    : Bus 20247	: V=1.0218856, theta=-60.629462 -> V=1.0, theta=0.0
% INFO    : Bus 20248	: V=1.0158026, theta=-64.496957 -> V=1.0, theta=0.0
% INFO    : Bus 20249	: V=1.0136643, theta=-60.338049 -> V=1.0, theta=0.0
% INFO    : Bus 20250	: V=1.0134357, theta=-60.357689 -> V=1.0, theta=0.0
% INFO    : Bus 20251	: V=1.0129083, theta=-63.691078 -> V=1.0, theta=0.0
% INFO    : Bus 20252	: V=1.0132848, theta=-63.574246 -> V=1.0, theta=0.0
% INFO    : Bus 20253	: V=1.0165199, theta=-63.431883 -> V=1.0, theta=0.0
% INFO    : Bus 20254	: V=1.0177814, theta=-63.243352 -> V=1.0, theta=0.0
% INFO    : Bus 20255	: V=1.0435726, theta=-55.818764 -> V=1.0, theta=0.0
% INFO    : Bus 20256	: V=1.0434819, theta=-55.82594 -> V=1.0, theta=0.0
% INFO    : Bus 20257	: V=1.0129264, theta=-60.135009 -> V=1.0, theta=0.0
% INFO    : Bus 20258	: V=1.0134418, theta=-63.996781 -> V=1.0, theta=0.0
% INFO    : Bus 20259	: V=1.0132626, theta=-64.010598 -> V=1.0, theta=0.0
% INFO    : Bus 20260	: V=1.0153332, theta=-63.580118 -> V=1.0, theta=0.0
% INFO    : Bus 20261	: V=1.013604, theta=-59.931117 -> V=1.0, theta=0.0
% INFO    : Bus 20262	: V=1.0447491, theta=-56.071001 -> V=1.0, theta=0.0
% INFO    : Bus 20263	: V=1.0446985, theta=-56.077952 -> V=1.0, theta=0.0
% INFO    : Bus 20264	: V=1.0209746, theta=-61.597748 -> V=1.0, theta=0.0
% INFO    : Bus 20265	: V=1.0238573, theta=-60.840705 -> V=1.0, theta=0.0
% INFO    : Bus 20266	: V=1.0285129, theta=-62.559218 -> V=1.0, theta=0.0
% INFO    : Bus 20267	: V=1.0309989, theta=-64.108104 -> V=1.0, theta=0.0
% INFO    : Bus 20268	: V=1.0308224, theta=-64.137855 -> V=1.0, theta=0.0
% INFO    : Bus 20269	: V=1.040677, theta=-54.470735 -> V=1.0, theta=0.0
% INFO    : Bus 20270	: V=1.0405357, theta=-54.496076 -> V=1.0, theta=0.0
% INFO    : Bus 20271	: V=1.0389016, theta=-47.61301 -> V=1.0, theta=0.0
% INFO    : Bus 20272	: V=1.0371241, theta=-60.198486 -> V=1.0, theta=0.0
% INFO    : Bus 20273	: V=1.0420698, theta=-55.185827 -> V=1.0, theta=0.0
% INFO    : Bus 20274	: V=1.0420457, theta=-55.188935 -> V=1.0, theta=0.0
% INFO    : Bus 20275	: V=1.0446399, theta=-58.534187 -> V=1.0, theta=0.0
% INFO    : Bus 20276	: V=1.0294926, theta=-59.974106 -> V=1.0, theta=0.0
% INFO    : Bus 20277	: V=1.0439141, theta=-58.600861 -> V=1.0, theta=0.0
% INFO    : Bus 20278	: V=1.0439141, theta=-58.600861 -> V=1.0, theta=0.0
% INFO    : Bus 20279	: V=1.0110252, theta=-62.426345 -> V=1.0, theta=0.0
% INFO    : Bus 20280	: V=1.0313749, theta=-62.211409 -> V=1.0, theta=0.0
% INFO    : Bus 20281	: V=1.0314869, theta=-62.059217 -> V=1.0, theta=0.0
% INFO    : Bus 20282	: V=1.031371, theta=-62.075574 -> V=1.0, theta=0.0
% INFO    : Bus 20283	: V=1.04, theta=-57.772611 -> V=1.0, theta=0.0
% INFO    : Bus 20284	: V=1.0413661, theta=-58.5538 -> V=1.0, theta=0.0
% INFO    : Bus 20285	: V=1.04228, theta=-59.022215 -> V=1.0, theta=0.0
% INFO    : Bus 20286	: V=1.04228, theta=-59.022215 -> V=1.0, theta=0.0
% INFO    : Bus 20287	: V=1.0399433, theta=-57.776695 -> V=1.0, theta=0.0
% INFO    : Bus 20288	: V=1.0212018, theta=-60.771513 -> V=1.0, theta=0.0
% INFO    : Bus 20289	: V=1.0232401, theta=-65.083451 -> V=1.0, theta=0.0
% INFO    : Bus 20290	: V=1.0225082, theta=-60.694439 -> V=1.0, theta=0.0
% INFO    : Bus 20291	: V=1.013867, theta=-48.617706 -> V=1.0, theta=0.0
% INFO    : Bus 20292	: V=1.0266492, theta=-48.575609 -> V=1.0, theta=0.0
% INFO    : Bus 20293	: V=1.0082049, theta=-47.864885 -> V=1.0, theta=0.0
% INFO    : Bus 20294	: V=1.0432429, theta=-53.887976 -> V=1.0, theta=0.0
% INFO    : Bus 20295	: V=0.9977226, theta=-50.376351 -> V=1.0, theta=0.0
% INFO    : Bus 20296	: V=1.02606, theta=-56.339883 -> V=1.0, theta=0.0
% INFO    : Bus 20297	: V=1.0326333, theta=-57.030377 -> V=1.0, theta=0.0
% INFO    : Bus 20298	: V=1.0328804, theta=-59.446426 -> V=1.0, theta=0.0
% INFO    : Bus 20299	: V=1.030589, theta=-55.181508 -> V=1.0, theta=0.0
% INFO    : Bus 20300	: V=1.0294763, theta=-55.470852 -> V=1.0, theta=0.0
% INFO    : Bus 20301	: V=1.0292837, theta=-55.522732 -> V=1.0, theta=0.0
% INFO    : Bus 20302	: V=1.0278764, theta=-56.146802 -> V=1.0, theta=0.0
% INFO    : Bus 20303	: V=1.0268301, theta=-56.715286 -> V=1.0, theta=0.0
% INFO    : Bus 20304	: V=1.025092, theta=-63.546842 -> V=1.0, theta=0.0
% INFO    : Bus 20305	: V=1.0210904, theta=-63.66929 -> V=1.0, theta=0.0
% INFO    : Bus 20306	: V=1.0212797, theta=-59.794366 -> V=1.0, theta=0.0
% INFO    : Bus 20307	: V=1.0216355, theta=-61.739851 -> V=1.0, theta=0.0
% INFO    : Bus 20308	: V=1.0291532, theta=-57.418675 -> V=1.0, theta=0.0
% INFO    : Bus 20309	: V=1.028912, theta=-59.356063 -> V=1.0, theta=0.0
% INFO    : Bus 20310	: V=1.0288734, theta=-61.44075 -> V=1.0, theta=0.0
% INFO    : Bus 20311	: V=1.0299198, theta=-61.382973 -> V=1.0, theta=0.0
% INFO    : Bus 20312	: V=1.0299198, theta=-61.382973 -> V=1.0, theta=0.0
% INFO    : Bus 20313	: V=1.0291532, theta=-57.418675 -> V=1.0, theta=0.0
% INFO    : Bus 20314	: V=1.0199156, theta=-56.972912 -> V=1.0, theta=0.0
% INFO    : Bus 20315	: V=0.9645604, theta=-57.731409 -> V=1.0, theta=0.0
% INFO    : Bus 20316	: V=1.0377149, theta=-46.021941 -> V=1.0, theta=0.0
% INFO    : Bus 20317	: V=1.0245888, theta=-47.980196 -> V=1.0, theta=0.0
% INFO    : Bus 20318	: V=1.0353868, theta=-47.569855 -> V=1.0, theta=0.0
% INFO    : Bus 20319	: V=1.0373766, theta=-45.745677 -> V=1.0, theta=0.0
% INFO    : Bus 20320	: V=1.0374105, theta=-45.658219 -> V=1.0, theta=0.0
% INFO    : Bus 20321	: V=1.0481841, theta=-45.993164 -> V=1.0, theta=0.0
% INFO    : Bus 20322	: V=1.021729, theta=-48.17431 -> V=1.0, theta=0.0
% INFO    : Bus 20323	: V=1.0289523, theta=-47.809553 -> V=1.0, theta=0.0
% INFO    : Bus 20324	: V=1.0244017, theta=-53.968621 -> V=1.0, theta=0.0
% INFO    : Bus 20325	: V=1.0285092, theta=-54.814284 -> V=1.0, theta=0.0
% INFO    : Bus 20326	: V=1.027213, theta=-54.553067 -> V=1.0, theta=0.0
% INFO    : Bus 20327	: V=1.027213, theta=-54.553067 -> V=1.0, theta=0.0
% INFO    : Bus 20328	: V=0.9895937, theta=-52.767192 -> V=1.0, theta=0.0
% INFO    : Bus 20329	: V=0.9901881, theta=-53.56016 -> V=1.0, theta=0.0
% INFO    : Bus 20330	: V=1.0328578, theta=-54.676883 -> V=1.0, theta=0.0
% INFO    : Bus 20331	: V=1.020291, theta=-61.768678 -> V=1.0, theta=0.0
% INFO    : Bus 20332	: V=1.0105488, theta=-57.125046 -> V=1.0, theta=0.0
% INFO    : Bus 20333	: V=1.0202847, theta=-61.769521 -> V=1.0, theta=0.0
% INFO    : Bus 20334	: V=1.020284, theta=-61.805764 -> V=1.0, theta=0.0
% INFO    : Bus 20335	: V=1.0375623, theta=-58.025533 -> V=1.0, theta=0.0
% INFO    : Bus 20336	: V=1.0415706, theta=-58.844253 -> V=1.0, theta=0.0
% INFO    : Bus 20337	: V=1.0415402, theta=-58.838229 -> V=1.0, theta=0.0
% INFO    : Bus 20338	: V=1.0415402, theta=-58.838229 -> V=1.0, theta=0.0
% INFO    : Bus 20339	: V=1.0221197, theta=-60.346266 -> V=1.0, theta=0.0
% INFO    : Bus 20340	: V=1.0146412, theta=-64.121765 -> V=1.0, theta=0.0
% INFO    : Bus 20341	: V=1.0131346, theta=-65.392261 -> V=1.0, theta=0.0
% INFO    : Bus 20342	: V=1.0131346, theta=-65.392261 -> V=1.0, theta=0.0
% INFO    : Bus 20343	: V=1.0164892, theta=-63.544178 -> V=1.0, theta=0.0
% INFO    : Bus 20344	: V=1.0249169, theta=-60.901349 -> V=1.0, theta=0.0
% INFO    : Bus 20345	: V=1.0164892, theta=-63.544178 -> V=1.0, theta=0.0
% INFO    : Bus 20346	: V=1.0163384, theta=-63.556437 -> V=1.0, theta=0.0
% INFO    : Bus 20347	: V=1.04, theta=-59.440627 -> V=1.0, theta=0.0
% INFO    : Bus 20348	: V=1.0179997, theta=-52.050538 -> V=1.0, theta=0.0
% INFO    : Bus 20349	: V=0.9874753, theta=-48.76036 -> V=1.0, theta=0.0
% INFO    : Bus 20350	: V=0.9929612, theta=-48.649798 -> V=1.0, theta=0.0
% INFO    : Bus 20351	: V=1.0196388, theta=-49.70228 -> V=1.0, theta=0.0
% INFO    : Bus 20352	: V=1.0208667, theta=-50.050231 -> V=1.0, theta=0.0
% INFO    : Bus 20353	: V=1.0283986, theta=-48.09511 -> V=1.0, theta=0.0
% INFO    : Bus 20354	: V=1.0282798, theta=-48.143484 -> V=1.0, theta=0.0
% INFO    : Bus 20355	: V=1.0193992, theta=-60.772566 -> V=1.0, theta=0.0
% INFO    : Bus 20356	: V=1.0215218, theta=-65.69121 -> V=1.0, theta=0.0
% INFO    : Bus 20357	: V=1.0320405, theta=-54.483113 -> V=1.0, theta=0.0
% INFO    : Bus 20358	: V=1.0433818, theta=-54.826007 -> V=1.0, theta=0.0
% INFO    : Bus 20359	: V=1.0433818, theta=-54.826007 -> V=1.0, theta=0.0
% INFO    : Bus 20360	: V=1.0433901, theta=-54.82449 -> V=1.0, theta=0.0
% INFO    : Bus 20361	: V=1.020358, theta=-62.952005 -> V=1.0, theta=0.0
% INFO    : Bus 20362	: V=1.0225849, theta=-65.361898 -> V=1.0, theta=0.0
% INFO    : Bus 20363	: V=1.020358, theta=-62.952005 -> V=1.0, theta=0.0
% INFO    : Bus 20364	: V=1.0210723, theta=-62.875273 -> V=1.0, theta=0.0
% INFO    : Bus 20365	: V=1.0172903, theta=-48.938894 -> V=1.0, theta=0.0
% INFO    : Bus 20366	: V=1.0493681, theta=-48.297445 -> V=1.0, theta=0.0
% INFO    : Bus 20367	: V=1.0118245, theta=-48.120302 -> V=1.0, theta=0.0
% INFO    : Bus 20368	: V=1.0125496, theta=-48.069848 -> V=1.0, theta=0.0
% INFO    : Bus 20369	: V=1.0091548, theta=-48.388252 -> V=1.0, theta=0.0
% INFO    : Bus 20370	: V=1.02606, theta=-45.5321 -> V=1.0, theta=0.0
% INFO    : Bus 20371	: V=1.0291762, theta=-47.372812 -> V=1.0, theta=0.0
% INFO    : Bus 20372	: V=1.0310932, theta=-59.623651 -> V=1.0, theta=0.0
% INFO    : Bus 20373	: V=1.030716, theta=-59.651706 -> V=1.0, theta=0.0
% INFO    : Bus 20374	: V=1.0073052, theta=-54.176112 -> V=1.0, theta=0.0
% INFO    : Bus 20375	: V=1.036425, theta=-54.679964 -> V=1.0, theta=0.0
% INFO    : Bus 20376	: V=1.0073052, theta=-54.176112 -> V=1.0, theta=0.0
% INFO    : Bus 20377	: V=1.0131056, theta=-53.34795 -> V=1.0, theta=0.0
% INFO    : Bus 20378	: V=1.011036, theta=-54.245013 -> V=1.0, theta=0.0
% INFO    : Bus 20379	: V=1.0297462, theta=-55.101084 -> V=1.0, theta=0.0
% INFO    : Bus 20380	: V=1.0320225, theta=-55.501211 -> V=1.0, theta=0.0
% INFO    : Bus 20381	: V=1.0294739, theta=-55.150006 -> V=1.0, theta=0.0
% INFO    : Bus 20382	: V=1.0309949, theta=-58.173449 -> V=1.0, theta=0.0
% INFO    : Bus 20383	: V=1.040776, theta=-54.666089 -> V=1.0, theta=0.0
% INFO    : Bus 20384	: V=1.0154769, theta=-55.495988 -> V=1.0, theta=0.0
% INFO    : Bus 20385	: V=1.0368564, theta=-54.665821 -> V=1.0, theta=0.0
% INFO    : Bus 20386	: V=1.0365767, theta=-54.687133 -> V=1.0, theta=0.0
% INFO    : Bus 20387	: V=1.034788, theta=-48.667755 -> V=1.0, theta=0.0
% INFO    : Bus 20388	: V=1.0245277, theta=-49.686509 -> V=1.0, theta=0.0
% INFO    : Bus 20389	: V=1.0242886, theta=-50.890013 -> V=1.0, theta=0.0
% INFO    : Bus 20390	: V=1.0278596, theta=-48.293015 -> V=1.0, theta=0.0
% INFO    : Bus 20391	: V=1.0280242, theta=-48.334216 -> V=1.0, theta=0.0
% INFO    : Bus 20392	: V=1.0280083, theta=-48.380886 -> V=1.0, theta=0.0
% INFO    : Bus 20393	: V=1.0280246, theta=-48.201395 -> V=1.0, theta=0.0
% INFO    : Bus 20394	: V=1.034788, theta=-48.667755 -> V=1.0, theta=0.0
% INFO    : Bus 20395	: V=1.034788, theta=-48.667755 -> V=1.0, theta=0.0
% INFO    : Bus 20396	: V=1.0263576, theta=-60.206278 -> V=1.0, theta=0.0
% INFO    : Bus 20397	: V=1.0201237, theta=-63.978813 -> V=1.0, theta=0.0
% INFO    : Bus 20398	: V=1.0193595, theta=-64.801616 -> V=1.0, theta=0.0
% INFO    : Bus 20399	: V=1.0193595, theta=-64.801616 -> V=1.0, theta=0.0
% INFO    : Bus 20400	: V=1.0248087, theta=-60.919702 -> V=1.0, theta=0.0
% INFO    : Bus 20401	: V=1.0198003, theta=-63.202315 -> V=1.0, theta=0.0
% INFO    : Bus 20402	: V=1.0182112, theta=-64.148322 -> V=1.0, theta=0.0
% INFO    : Bus 20403	: V=1.0182112, theta=-64.148322 -> V=1.0, theta=0.0
% INFO    : Bus 20404	: V=1.025509, theta=-60.803687 -> V=1.0, theta=0.0
% INFO    : Bus 20405	: V=1.0391768, theta=-59.76724 -> V=1.0, theta=0.0
% INFO    : Bus 20406	: V=1.01981, theta=-59.253643 -> V=1.0, theta=0.0
% INFO    : Bus 20407	: V=1.0191254, theta=-58.39295 -> V=1.0, theta=0.0
% INFO    : Bus 20408	: V=1.0201106, theta=-59.841148 -> V=1.0, theta=0.0
% INFO    : Bus 20409	: V=1.0391336, theta=-59.785114 -> V=1.0, theta=0.0
% INFO    : Bus 20410	: V=1.0358622, theta=-57.584632 -> V=1.0, theta=0.0
% INFO    : Bus 20411	: V=1.0295809, theta=-59.280771 -> V=1.0, theta=0.0
% INFO    : Bus 20412	: V=1.0367128, theta=-57.483626 -> V=1.0, theta=0.0
% INFO    : Bus 20413	: V=1.0367681, theta=-57.46174 -> V=1.0, theta=0.0
% INFO    : Bus 20414	: V=1.0358627, theta=-57.58652 -> V=1.0, theta=0.0
% INFO    : Bus 20415	: V=1.0143259, theta=-45.956636 -> V=1.0, theta=0.0
% INFO    : Bus 20416	: V=1.0192, theta=-46.171486 -> V=1.0, theta=0.0
% INFO    : Bus 20417	: V=1.0143026, theta=-45.958976 -> V=1.0, theta=0.0
% INFO    : Bus 20418	: V=1.0382196, theta=-57.725327 -> V=1.0, theta=0.0
% INFO    : Bus 20419	: V=1.0351415, theta=-58.641748 -> V=1.0, theta=0.0
% INFO    : Bus 20420	: V=1.0321465, theta=-59.626863 -> V=1.0, theta=0.0
% INFO    : Bus 20421	: V=1.0321465, theta=-59.626863 -> V=1.0, theta=0.0
% INFO    : Bus 20422	: V=1.0382927, theta=-57.753787 -> V=1.0, theta=0.0
% INFO    : Bus 20423	: V=1.0268208, theta=-55.691679 -> V=1.0, theta=0.0
% INFO    : Bus 20424	: V=1.0264654, theta=-58.663381 -> V=1.0, theta=0.0
% INFO    : Bus 20425	: V=1.0205796, theta=-61.808031 -> V=1.0, theta=0.0
% INFO    : Bus 20426	: V=1.026357, theta=-58.284393 -> V=1.0, theta=0.0
% INFO    : Bus 20427	: V=1.026357, theta=-58.284393 -> V=1.0, theta=0.0
% INFO    : Bus 20428	: V=1.0268208, theta=-55.691679 -> V=1.0, theta=0.0
% INFO    : Bus 20429	: V=1.0181992, theta=-54.543873 -> V=1.0, theta=0.0
% INFO    : Bus 20430	: V=1.0195889, theta=-55.221582 -> V=1.0, theta=0.0
% INFO    : Bus 20431	: V=1.0263065, theta=-58.951615 -> V=1.0, theta=0.0
% INFO    : Bus 20432	: V=1.032808, theta=-57.925878 -> V=1.0, theta=0.0
% INFO    : Bus 20433	: V=1.0326687, theta=-57.960903 -> V=1.0, theta=0.0
% INFO    : Bus 20434	: V=1.0238345, theta=-59.874696 -> V=1.0, theta=0.0
% INFO    : Bus 20435	: V=1.0099008, theta=-58.957969 -> V=1.0, theta=0.0
% INFO    : Bus 20436	: V=1.0259214, theta=-54.067172 -> V=1.0, theta=0.0
% INFO    : Bus 20437	: V=1.0298597, theta=-56.071096 -> V=1.0, theta=0.0
% INFO    : Bus 20438	: V=1.025876, theta=-58.689121 -> V=1.0, theta=0.0
% INFO    : Bus 20439	: V=0.9943235, theta=-53.485775 -> V=1.0, theta=0.0
% INFO    : Bus 20440	: V=1.0259214, theta=-54.067172 -> V=1.0, theta=0.0
% INFO    : Bus 20441	: V=1.0259214, theta=-54.067172 -> V=1.0, theta=0.0
% INFO    : Bus 20442	: V=0.9944978, theta=-53.582707 -> V=1.0, theta=0.0
% INFO    : Bus 20443	: V=0.988031, theta=-53.034362 -> V=1.0, theta=0.0
% INFO    : Bus 20444	: V=1.0259214, theta=-54.067172 -> V=1.0, theta=0.0
% INFO    : Bus 20445	: V=1.0360583, theta=-55.780654 -> V=1.0, theta=0.0
% INFO    : Bus 20446	: V=1.025547, theta=-63.444761 -> V=1.0, theta=0.0
% INFO    : Bus 20447	: V=1.0072858, theta=-60.749061 -> V=1.0, theta=0.0
% INFO    : Bus 20448	: V=1.0069666, theta=-59.978948 -> V=1.0, theta=0.0
% INFO    : Bus 20449	: V=1.0075199, theta=-62.283958 -> V=1.0, theta=0.0
% INFO    : Bus 20450	: V=1.0226265, theta=-63.601362 -> V=1.0, theta=0.0
% INFO    : Bus 20451	: V=1.0225928, theta=-63.607035 -> V=1.0, theta=0.0
% INFO    : Bus 20452	: V=1.0283106, theta=-59.060472 -> V=1.0, theta=0.0
% INFO    : Bus 20453	: V=1.0313682, theta=-59.355397 -> V=1.0, theta=0.0
% INFO    : Bus 20454	: V=1.0265983, theta=-60.27545 -> V=1.0, theta=0.0
% INFO    : Bus 20455	: V=1.0308204, theta=-59.789035 -> V=1.0, theta=0.0
% INFO    : Bus 20456	: V=1.075402, theta=-53.16449 -> V=1.0, theta=0.0
% INFO    : Bus 20457	: V=1.0305096, theta=-59.813346 -> V=1.0, theta=0.0
% INFO    : Bus 20458	: V=1.0308204, theta=-59.789035 -> V=1.0, theta=0.0
% INFO    : Bus 20459	: V=1.0317706, theta=-59.315396 -> V=1.0, theta=0.0
% INFO    : Bus 20460	: V=1.0544049, theta=-56.95001 -> V=1.0, theta=0.0
% INFO    : Bus 20461	: V=1.0314469, theta=-59.339008 -> V=1.0, theta=0.0
% INFO    : Bus 20462	: V=1.02018, theta=-50.919392 -> V=1.0, theta=0.0
% INFO    : Bus 20463	: V=1.0247941, theta=-63.213954 -> V=1.0, theta=0.0
% INFO    : Bus 20464	: V=1.0244588, theta=-63.286589 -> V=1.0, theta=0.0
% INFO    : Bus 20465	: V=1.0277446, theta=-57.960417 -> V=1.0, theta=0.0
% INFO    : Bus 20466	: V=1.0240406, theta=-60.396865 -> V=1.0, theta=0.0
% INFO    : Bus 20467	: V=1.0219402, theta=-63.216105 -> V=1.0, theta=0.0
% INFO    : Bus 20468	: V=0.9950892, theta=-57.141661 -> V=1.0, theta=0.0
% INFO    : Bus 20469	: V=0.9948285, theta=-57.012242 -> V=1.0, theta=0.0
% INFO    : Bus 20470	: V=0.9883512, theta=-56.764244 -> V=1.0, theta=0.0
% INFO    : Bus 20471	: V=1.031404, theta=-59.336926 -> V=1.0, theta=0.0
% INFO    : Bus 20472	: V=1.04, theta=-53.487313 -> V=1.0, theta=0.0
% INFO    : Bus 20473	: V=1.0265838, theta=-63.044559 -> V=1.0, theta=0.0
% INFO    : Bus 20474	: V=1.0366482, theta=-56.714758 -> V=1.0, theta=0.0
% INFO    : Bus 20475	: V=1.0297605, theta=-47.926742 -> V=1.0, theta=0.0
% INFO    : Bus 20476	: V=1.0170683, theta=-49.800724 -> V=1.0, theta=0.0
% INFO    : Bus 20477	: V=1.0203623, theta=-50.707338 -> V=1.0, theta=0.0
% INFO    : Bus 20478	: V=1.0170683, theta=-49.800724 -> V=1.0, theta=0.0
% INFO    : Bus 20479	: V=1.015709, theta=-48.800394 -> V=1.0, theta=0.0
% INFO    : Bus 20480	: V=1.0161862, theta=-49.862835 -> V=1.0, theta=0.0
% INFO    : Bus 20481	: V=1.0193772, theta=-50.682448 -> V=1.0, theta=0.0
% INFO    : Bus 20482	: V=0.9826974, theta=-48.779083 -> V=1.0, theta=0.0
% INFO    : Bus 20483	: V=0.9808771, theta=-48.054329 -> V=1.0, theta=0.0
% INFO    : Bus 20484	: V=1.0314844, theta=-57.91116 -> V=1.0, theta=0.0
% INFO    : Bus 20485	: V=1.0341296, theta=-59.32945 -> V=1.0, theta=0.0
% INFO    : Bus 20486	: V=1.0280161, theta=-62.995142 -> V=1.0, theta=0.0
% INFO    : Bus 20487	: V=1.0314844, theta=-57.91116 -> V=1.0, theta=0.0
% INFO    : Bus 20488	: V=1.025173, theta=-56.935838 -> V=1.0, theta=0.0
% INFO    : Bus 20489	: V=1.0314844, theta=-57.91116 -> V=1.0, theta=0.0
% INFO    : Bus 20490	: V=1.0251352, theta=-56.989416 -> V=1.0, theta=0.0
% INFO    : Bus 20491	: V=1.0251382, theta=-57.510471 -> V=1.0, theta=0.0
% INFO    : Bus 20492	: V=1.0251638, theta=-57.257361 -> V=1.0, theta=0.0
% INFO    : Bus 20493	: V=1.0305566, theta=-59.957313 -> V=1.0, theta=0.0
% INFO    : Bus 20494	: V=1.0385017, theta=-47.632701 -> V=1.0, theta=0.0
% INFO    : Bus 20495	: V=1.0379624, theta=-47.675327 -> V=1.0, theta=0.0
% INFO    : Bus 20496	: V=1.0528293, theta=-56.706892 -> V=1.0, theta=0.0
% INFO    : Bus 20497	: V=1.021755, theta=-50.35974 -> V=1.0, theta=0.0
% INFO    : Bus 20498	: V=1.02312, theta=-52.215367 -> V=1.0, theta=0.0
% INFO    : Bus 20499	: V=0.981787, theta=-50.183106 -> V=1.0, theta=0.0
% INFO    : Bus 20500	: V=0.9802577, theta=-52.170286 -> V=1.0, theta=0.0
% INFO    : Bus 20501	: V=0.9802577, theta=-52.170286 -> V=1.0, theta=0.0
% INFO    : Bus 20502	: V=1.0352478, theta=-48.921223 -> V=1.0, theta=0.0
% INFO    : Bus 20503	: V=1.0245887, theta=-50.05871 -> V=1.0, theta=0.0
% INFO    : Bus 20504	: V=1.0204331, theta=-59.812131 -> V=1.0, theta=0.0
% INFO    : Bus 20505	: V=1.0201841, theta=-59.489162 -> V=1.0, theta=0.0
% INFO    : Bus 20506	: V=1.019143, theta=-57.853995 -> V=1.0, theta=0.0
% INFO    : Bus 20507	: V=1.0205218, theta=-59.838807 -> V=1.0, theta=0.0
% INFO    : Bus 20508	: V=1.0242841, theta=-58.203072 -> V=1.0, theta=0.0
% INFO    : Bus 20509	: V=1.0234885, theta=-60.48364 -> V=1.0, theta=0.0
% INFO    : Bus 20510	: V=1.016546, theta=-65.502227 -> V=1.0, theta=0.0
% INFO    : Bus 20511	: V=1.0168044, theta=-69.756589 -> V=1.0, theta=0.0
% INFO    : Bus 20512	: V=1.0168044, theta=-69.756589 -> V=1.0, theta=0.0
% INFO    : Bus 20513	: V=1.0263798, theta=-58.00118 -> V=1.0, theta=0.0
% INFO    : Bus 20514	: V=1.0286859, theta=-64.556096 -> V=1.0, theta=0.0
% INFO    : Bus 20515	: V=1.0042222, theta=-62.217799 -> V=1.0, theta=0.0
% INFO    : Bus 20516	: V=1.0041112, theta=-63.161486 -> V=1.0, theta=0.0
% INFO    : Bus 20517	: V=1.0032737, theta=-60.589355 -> V=1.0, theta=0.0
% INFO    : Bus 20518	: V=1.0285808, theta=-64.586879 -> V=1.0, theta=0.0
% INFO    : Bus 20519	: V=1.0245378, theta=-59.111927 -> V=1.0, theta=0.0
% INFO    : Bus 20520	: V=1.028437, theta=-58.864535 -> V=1.0, theta=0.0
% INFO    : Bus 20521	: V=1.028437, theta=-58.864535 -> V=1.0, theta=0.0
% INFO    : Bus 20522	: V=1.028437, theta=-58.864535 -> V=1.0, theta=0.0
% INFO    : Bus 20523	: V=1.0182199, theta=-65.449729 -> V=1.0, theta=0.0
% INFO    : Bus 20524	: V=1.0174029, theta=-65.55799 -> V=1.0, theta=0.0
% INFO    : Bus 20525	: V=1.0200476, theta=-48.615238 -> V=1.0, theta=0.0
% INFO    : Bus 20526	: V=1.0317969, theta=-48.939512 -> V=1.0, theta=0.0
% INFO    : Bus 20527	: V=1.0193786, theta=-48.61137 -> V=1.0, theta=0.0
% INFO    : Bus 20528	: V=1.018316, theta=-55.542345 -> V=1.0, theta=0.0
% INFO    : Bus 20529	: V=1.0181371, theta=-55.555061 -> V=1.0, theta=0.0
% INFO    : Bus 20530	: V=1.0216254, theta=-50.231508 -> V=1.0, theta=0.0
% INFO    : Bus 20531	: V=1.0632953, theta=-51.35274 -> V=1.0, theta=0.0
% INFO    : Bus 20532	: V=1.0414366, theta=-52.877877 -> V=1.0, theta=0.0
% INFO    : Bus 20533	: V=1.0629086, theta=-51.471539 -> V=1.0, theta=0.0
% INFO    : Bus 20534	: V=1.0293168, theta=-59.321854 -> V=1.0, theta=0.0
% INFO    : Bus 20535	: V=1.0366634, theta=-47.500151 -> V=1.0, theta=0.0
% INFO    : Bus 20536	: V=1.0343243, theta=-45.759134 -> V=1.0, theta=0.0
% INFO    : Bus 20537	: V=1.0330019, theta=-44.140885 -> V=1.0, theta=0.0
% INFO    : Bus 20538	: V=1.0350724, theta=-45.260163 -> V=1.0, theta=0.0
% INFO    : Bus 20539	: V=1.0420584, theta=-58.934098 -> V=1.0, theta=0.0
% INFO    : Bus 20540	: V=1.0718052, theta=-56.496666 -> V=1.0, theta=0.0
% INFO    : Bus 20541	: V=1.0780351, theta=-55.94325 -> V=1.0, theta=0.0
% INFO    : Bus 20542	: V=1.0326612, theta=-56.61821 -> V=1.0, theta=0.0
% INFO    : Bus 20543	: V=1.0281731, theta=-57.674196 -> V=1.0, theta=0.0
% INFO    : Bus 20544	: V=1.0244196, theta=-54.845451 -> V=1.0, theta=0.0
% INFO    : Bus 20545	: V=1.0326612, theta=-56.61821 -> V=1.0, theta=0.0
% INFO    : Bus 21000	: V=1.0174039, theta=-64.997847 -> V=1.0, theta=0.0
% INFO    : Bus 21001	: V=1.0174594, theta=-64.987309 -> V=1.0, theta=0.0
% INFO    : Bus 21002	: V=1.0206797, theta=-64.209104 -> V=1.0, theta=0.0
% INFO    : Bus 21003	: V=1.0205519, theta=-64.228139 -> V=1.0, theta=0.0
% INFO    : Bus 21004	: V=1.0124328, theta=-65.811256 -> V=1.0, theta=0.0
% INFO    : Bus 21005	: V=1.0125721, theta=-65.795302 -> V=1.0, theta=0.0
% INFO    : Bus 21006	: V=1.0119801, theta=-65.628038 -> V=1.0, theta=0.0
% INFO    : Bus 21007	: V=1.0118701, theta=-65.643144 -> V=1.0, theta=0.0
% INFO    : Bus 21008	: V=1.0088254, theta=-66.064379 -> V=1.0, theta=0.0
% INFO    : Bus 21009	: V=1.0086295, theta=-66.078029 -> V=1.0, theta=0.0
% INFO    : Bus 21010	: V=1.0090065, theta=-66.05021 -> V=1.0, theta=0.0
% INFO    : Bus 21011	: V=1.0118529, theta=-65.572745 -> V=1.0, theta=0.0
% INFO    : Bus 21012	: V=1.0117606, theta=-65.58778 -> V=1.0, theta=0.0
% INFO    : Bus 21013	: V=1.0116946, theta=-65.457325 -> V=1.0, theta=0.0
% INFO    : Bus 21014	: V=1.0087809, theta=-65.785613 -> V=1.0, theta=0.0
% INFO    : Bus 21015	: V=1.008566, theta=-65.804636 -> V=1.0, theta=0.0
% INFO    : Bus 21016	: V=1.0074769, theta=-68.071243 -> V=1.0, theta=0.0
% INFO    : Bus 21017	: V=1.0072678, theta=-68.088628 -> V=1.0, theta=0.0
% INFO    : Bus 21018	: V=1.019536, theta=-64.302427 -> V=1.0, theta=0.0
% INFO    : Bus 21019	: V=1.0170054, theta=-66.721023 -> V=1.0, theta=0.0
% INFO    : Bus 21020	: V=1.0163121, theta=-69.314501 -> V=1.0, theta=0.0
% INFO    : Bus 21021	: V=1.0163121, theta=-69.314501 -> V=1.0, theta=0.0
% INFO    : Bus 21022	: V=1.0074582, theta=-65.822991 -> V=1.0, theta=0.0
% INFO    : Bus 21023	: V=1.0072882, theta=-65.847291 -> V=1.0, theta=0.0
% INFO    : Bus 21024	: V=1.0076271, theta=-65.797499 -> V=1.0, theta=0.0
% INFO    : Bus 21025	: V=1.0074582, theta=-65.822991 -> V=1.0, theta=0.0
% INFO    : Bus 21026	: V=1.0221606, theta=-63.102234 -> V=1.0, theta=0.0
% INFO    : Bus 21027	: V=1.0123399, theta=-65.44762 -> V=1.0, theta=0.0
% INFO    : Bus 21028	: V=1.007219, theta=-66.892032 -> V=1.0, theta=0.0
% INFO    : Bus 21029	: V=1.007219, theta=-66.892032 -> V=1.0, theta=0.0
% INFO    : Bus 21030	: V=1.0038676, theta=-66.187305 -> V=1.0, theta=0.0
% INFO    : Bus 21031	: V=1.0074565, theta=-66.835192 -> V=1.0, theta=0.0
% INFO    : Bus 21032	: V=1.001645, theta=-66.56096 -> V=1.0, theta=0.0
% INFO    : Bus 21033	: V=1.0018011, theta=-66.539368 -> V=1.0, theta=0.0
% INFO    : Bus 21034	: V=1.0172015, theta=-67.407575 -> V=1.0, theta=0.0
% INFO    : Bus 21035	: V=1.0212028, theta=-63.503706 -> V=1.0, theta=0.0
% INFO    : Bus 21036	: V=1.0089424, theta=-65.660852 -> V=1.0, theta=0.0
% INFO    : Bus 21037	: V=1.0061782, theta=-66.193545 -> V=1.0, theta=0.0
% INFO    : Bus 21038	: V=1.0061782, theta=-66.193545 -> V=1.0, theta=0.0
% INFO    : Bus 21039	: V=1.0210444, theta=-63.524485 -> V=1.0, theta=0.0
% INFO    : Bus 21040	: V=1.0074102, theta=-65.938061 -> V=1.0, theta=0.0
% INFO    : Bus 21041	: V=1.0070701, theta=-65.856708 -> V=1.0, theta=0.0
% INFO    : Bus 21042	: V=1.0067798, theta=-65.877372 -> V=1.0, theta=0.0
% INFO    : Bus 21043	: V=1.0046442, theta=-68.567907 -> V=1.0, theta=0.0
% INFO    : Bus 21044	: V=1.0323613, theta=-69.038806 -> V=1.0, theta=0.0
% INFO    : Bus 21045	: V=1.0232326, theta=-64.684236 -> V=1.0, theta=0.0
% INFO    : Bus 21046	: V=1.0231775, theta=-64.691131 -> V=1.0, theta=0.0
% INFO    : Bus 21047	: V=1.0066752, theta=-65.904289 -> V=1.0, theta=0.0
% INFO    : Bus 21048	: V=1.0065005, theta=-65.91885 -> V=1.0, theta=0.0
% INFO    : Bus 21049	: V=1.0209612, theta=-65.865462 -> V=1.0, theta=0.0
% INFO    : Bus 21050	: V=1.0191784, theta=-68.372318 -> V=1.0, theta=0.0
% INFO    : Bus 21051	: V=1.0171156, theta=-69.515912 -> V=1.0, theta=0.0
% INFO    : Bus 21052	: V=1.0139484, theta=-70.041328 -> V=1.0, theta=0.0
% INFO    : Bus 21053	: V=1.0138383, theta=-70.058716 -> V=1.0, theta=0.0
% INFO    : Bus 21054	: V=1.0140542, theta=-70.026406 -> V=1.0, theta=0.0
% INFO    : Bus 21055	: V=1.024341, theta=-69.196128 -> V=1.0, theta=0.0
% INFO    : Bus 21056	: V=1.0018441, theta=-66.502707 -> V=1.0, theta=0.0
% INFO    : Bus 21057	: V=1.0015899, theta=-66.51933 -> V=1.0, theta=0.0
% INFO    : Bus 21058	: V=1.0059499, theta=-67.867422 -> V=1.0, theta=0.0
% INFO    : Bus 21059	: V=1.0057448, theta=-67.885534 -> V=1.0, theta=0.0
% INFO    : Bus 21060	: V=1.0061788, theta=-67.848142 -> V=1.0, theta=0.0
% INFO    : Bus 21061	: V=1.0059018, theta=-68.248746 -> V=1.0, theta=0.0
% INFO    : Bus 21062	: V=1.0178009, theta=-68.466195 -> V=1.0, theta=0.0
% INFO    : Bus 21063	: V=1.0148459, theta=-69.401401 -> V=1.0, theta=0.0
% INFO    : Bus 21064	: V=1.0150393, theta=-69.390941 -> V=1.0, theta=0.0
% INFO    : Bus 21065	: V=1.0162969, theta=-68.511513 -> V=1.0, theta=0.0
% INFO    : Bus 21066	: V=1.0160746, theta=-68.526929 -> V=1.0, theta=0.0
% INFO    : Bus 21067	: V=1.0078782, theta=-68.793774 -> V=1.0, theta=0.0
% INFO    : Bus 21068	: V=1.0077658, theta=-68.813575 -> V=1.0, theta=0.0
% INFO    : Bus 21069	: V=1.0191494, theta=-69.26423 -> V=1.0, theta=0.0
% INFO    : Bus 21070	: V=1.0183907, theta=-68.250555 -> V=1.0, theta=0.0
% INFO    : Bus 21071	: V=1.0144976, theta=-69.239672 -> V=1.0, theta=0.0
% INFO    : Bus 21072	: V=1.0149116, theta=-70.122883 -> V=1.0, theta=0.0
% INFO    : Bus 21073	: V=1.0236175, theta=-71.410077 -> V=1.0, theta=0.0
% INFO    : Bus 21074	: V=1.01499, theta=-67.26811 -> V=1.0, theta=0.0
% INFO    : Bus 21075	: V=1.0178823, theta=-70.946442 -> V=1.0, theta=0.0
% INFO    : Bus 21076	: V=1.0175353, theta=-70.969129 -> V=1.0, theta=0.0
% INFO    : Bus 21077	: V=1.016846, theta=-70.513149 -> V=1.0, theta=0.0
% INFO    : Bus 21078	: V=1.0170026, theta=-70.489046 -> V=1.0, theta=0.0
% INFO    : Bus 21079	: V=1.0226539, theta=-71.396979 -> V=1.0, theta=0.0
% INFO    : Bus 21080	: V=1.0224411, theta=-71.428072 -> V=1.0, theta=0.0
% INFO    : Bus 21081	: V=1.0037253, theta=-66.448509 -> V=1.0, theta=0.0
% INFO    : Bus 21082	: V=1.0406639, theta=-68.820485 -> V=1.0, theta=0.0
% INFO    : Bus 21083	: V=1.0134446, theta=-70.47582 -> V=1.0, theta=0.0
% INFO    : Bus 21084	: V=1.0132501, theta=-70.489281 -> V=1.0, theta=0.0
% INFO    : Bus 21085	: V=1.0136614, theta=-70.460637 -> V=1.0, theta=0.0
% INFO    : Bus 21086	: V=1.0080001, theta=-71.401756 -> V=1.0, theta=0.0
% INFO    : Bus 21087	: V=1.0055656, theta=-71.507836 -> V=1.0, theta=0.0
% INFO    : Bus 21088	: V=1.0159203, theta=-72.120432 -> V=1.0, theta=0.0
% INFO    : Bus 21089	: V=1.0119799, theta=-71.229027 -> V=1.0, theta=0.0
% INFO    : Bus 21090	: V=1.0117314, theta=-71.245474 -> V=1.0, theta=0.0
% INFO    : Bus 21091	: V=1.0122575, theta=-71.209255 -> V=1.0, theta=0.0
% INFO    : Bus 21092	: V=1.0119799, theta=-71.229027 -> V=1.0, theta=0.0
% INFO    : Bus 21093	: V=1.0104628, theta=-77.618515 -> V=1.0, theta=0.0
% INFO    : Bus 21094	: V=1.0205755, theta=-67.860833 -> V=1.0, theta=0.0
% INFO    : Bus 21095	: V=1.0254351, theta=-68.241029 -> V=1.0, theta=0.0
% INFO    : Bus 21096	: V=1.0108228, theta=-68.896504 -> V=1.0, theta=0.0
% INFO    : Bus 21097	: V=1.0028497, theta=-71.483303 -> V=1.0, theta=0.0
% INFO    : Bus 21098	: V=1.0122035, theta=-71.090502 -> V=1.0, theta=0.0
% INFO    : Bus 21099	: V=1.0145202, theta=-71.254771 -> V=1.0, theta=0.0
% INFO    : Bus 21100	: V=1.003218, theta=-66.988351 -> V=1.0, theta=0.0
% INFO    : Bus 21101	: V=1.0144171, theta=-70.208173 -> V=1.0, theta=0.0
% INFO    : Bus 21102	: V=1.0335628, theta=-74.259062 -> V=1.0, theta=0.0
% INFO    : Bus 21103	: V=1.0335628, theta=-74.259062 -> V=1.0, theta=0.0
% INFO    : Bus 21104	: V=1.0025981, theta=-67.024099 -> V=1.0, theta=0.0
% INFO    : Bus 21105	: V=1.0194176, theta=-70.423795 -> V=1.0, theta=0.0
% INFO    : Bus 21106	: V=0.9996672, theta=-70.846102 -> V=1.0, theta=0.0
% INFO    : Bus 21107	: V=0.9944098, theta=-67.288021 -> V=1.0, theta=0.0
% INFO    : Bus 21108	: V=1.0258804, theta=-71.367748 -> V=1.0, theta=0.0
% INFO    : Bus 21109	: V=1.0139642, theta=-70.465368 -> V=1.0, theta=0.0
% INFO    : Bus 21110	: V=1.0135824, theta=-70.492233 -> V=1.0, theta=0.0
% INFO    : Bus 21111	: V=1.0142985, theta=-70.441778 -> V=1.0, theta=0.0
% INFO    : Bus 21112	: V=1.0139642, theta=-70.465368 -> V=1.0, theta=0.0
% INFO    : Bus 21113	: V=1.0258937, theta=-70.784862 -> V=1.0, theta=0.0
% INFO    : Bus 21114	: V=1.0146091, theta=-71.373826 -> V=1.0, theta=0.0
% INFO    : Bus 21115	: V=1.0163275, theta=-68.888707 -> V=1.0, theta=0.0
% INFO    : Bus 21116	: V=1.0125186, theta=-69.862848 -> V=1.0, theta=0.0
% INFO    : Bus 21117	: V=1.0122831, theta=-69.892414 -> V=1.0, theta=0.0
% INFO    : Bus 21118	: V=1.0127707, theta=-69.831791 -> V=1.0, theta=0.0
% INFO    : Bus 21119	: V=1.0143807, theta=-70.020812 -> V=1.0, theta=0.0
% INFO    : Bus 21120	: V=1.0046784, theta=-66.136336 -> V=1.0, theta=0.0
% INFO    : Bus 21121	: V=1.0163187, theta=-70.088327 -> V=1.0, theta=0.0
% INFO    : Bus 21122	: V=1.0408, theta=-75.491484 -> V=1.0, theta=0.0
% INFO    : Bus 21123	: V=1.0408, theta=-75.491484 -> V=1.0, theta=0.0
% INFO    : Bus 21124	: V=1.017627, theta=-70.318304 -> V=1.0, theta=0.0
% INFO    : Bus 21125	: V=1.0178135, theta=-70.302887 -> V=1.0, theta=0.0
% INFO    : Bus 21126	: V=1.0154466, theta=-70.946803 -> V=1.0, theta=0.0
% INFO    : Bus 21127	: V=1.0131352, theta=-71.832959 -> V=1.0, theta=0.0
% INFO    : Bus 21128	: V=1.0129564, theta=-71.855266 -> V=1.0, theta=0.0
% INFO    : Bus 21129	: V=1.0043426, theta=-69.870188 -> V=1.0, theta=0.0
% INFO    : Bus 21130	: V=1.0210798, theta=-70.649468 -> V=1.0, theta=0.0
% INFO    : Bus 21131	: V=1.0207301, theta=-70.696091 -> V=1.0, theta=0.0
% INFO    : Bus 21132	: V=0.9948414, theta=-68.800043 -> V=1.0, theta=0.0
% INFO    : Bus 21133	: V=1.0070154, theta=-72.245241 -> V=1.0, theta=0.0
% INFO    : Bus 21134	: V=1.0208215, theta=-75.229736 -> V=1.0, theta=0.0
% INFO    : Bus 21135	: V=1.0208215, theta=-75.229736 -> V=1.0, theta=0.0
% INFO    : Bus 21136	: V=1.0125778, theta=-77.412694 -> V=1.0, theta=0.0
% INFO    : Bus 21137	: V=1.0121604, theta=-77.442144 -> V=1.0, theta=0.0
% INFO    : Bus 21138	: V=1.0180325, theta=-65.693315 -> V=1.0, theta=0.0
% INFO    : Bus 21139	: V=1.0181699, theta=-65.679932 -> V=1.0, theta=0.0
% INFO    : Bus 21140	: V=0.9996202, theta=-69.8417 -> V=1.0, theta=0.0
% INFO    : Bus 21141	: V=1.0203454, theta=-71.473343 -> V=1.0, theta=0.0
% INFO    : Bus 21142	: V=1.0200129, theta=-71.510313 -> V=1.0, theta=0.0
% INFO    : Bus 21143	: V=1.0194087, theta=-71.145441 -> V=1.0, theta=0.0
% INFO    : Bus 21144	: V=1.0018709, theta=-75.015805 -> V=1.0, theta=0.0
% INFO    : Bus 21145	: V=1.0086416, theta=-70.196909 -> V=1.0, theta=0.0
% INFO    : Bus 21146	: V=1.0180271, theta=-72.003108 -> V=1.0, theta=0.0
% INFO    : Bus 21147	: V=1.0063885, theta=-68.559982 -> V=1.0, theta=0.0
% INFO    : Bus 21148	: V=0.9991051, theta=-70.673545 -> V=1.0, theta=0.0
% INFO    : Bus 21149	: V=1.0155942, theta=-68.341638 -> V=1.0, theta=0.0
% INFO    : Bus 21150	: V=1.0154574, theta=-68.358332 -> V=1.0, theta=0.0
% INFO    : Bus 21151	: V=1.0157263, theta=-68.325069 -> V=1.0, theta=0.0
% INFO    : Bus 21152	: V=1.0048237, theta=-69.744596 -> V=1.0, theta=0.0
% INFO    : Bus 21153	: V=1.004563, theta=-69.758432 -> V=1.0, theta=0.0
% INFO    : Bus 21154	: V=1.0083066, theta=-76.941835 -> V=1.0, theta=0.0
% INFO    : Bus 21155	: V=1.0081034, theta=-76.961311 -> V=1.0, theta=0.0
% INFO    : Bus 21156	: V=1.009397, theta=-72.240639 -> V=1.0, theta=0.0
% INFO    : Bus 21157	: V=1.009528, theta=-72.21665 -> V=1.0, theta=0.0
% INFO    : Bus 21158	: V=1.0014244, theta=-74.33248 -> V=1.0, theta=0.0
% INFO    : Bus 21159	: V=1.0012026, theta=-74.359343 -> V=1.0, theta=0.0
% INFO    : Bus 21160	: V=1.0081163, theta=-65.511019 -> V=1.0, theta=0.0
% INFO    : Bus 21161	: V=1.0021897, theta=-68.748466 -> V=1.0, theta=0.0
% INFO    : Bus 21162	: V=1.0023409, theta=-68.635948 -> V=1.0, theta=0.0
% INFO    : Bus 21163	: V=1.0023409, theta=-68.635948 -> V=1.0, theta=0.0
% INFO    : Bus 21164	: V=1.0092164, theta=-65.345891 -> V=1.0, theta=0.0
% INFO    : Bus 21165	: V=1.0025669, theta=-69.629021 -> V=1.0, theta=0.0
% INFO    : Bus 21166	: V=1.0133587, theta=-66.457487 -> V=1.0, theta=0.0
% INFO    : Bus 21167	: V=1.0186204, theta=-68.092365 -> V=1.0, theta=0.0
% INFO    : Bus 21168	: V=1.0122098, theta=-67.960371 -> V=1.0, theta=0.0
% INFO    : Bus 21169	: V=1.0120044, theta=-67.995699 -> V=1.0, theta=0.0
% INFO    : Bus 21170	: V=1.0124107, theta=-67.929729 -> V=1.0, theta=0.0
% INFO    : Bus 21171	: V=1.0119231, theta=-68.264362 -> V=1.0, theta=0.0
% INFO    : Bus 21172	: V=1.011832, theta=-68.279994 -> V=1.0, theta=0.0
% INFO    : Bus 21173	: V=1.011997, theta=-68.248755 -> V=1.0, theta=0.0
% INFO    : Bus 21174	: V=1.0119231, theta=-68.264362 -> V=1.0, theta=0.0
% INFO    : Bus 21175	: V=1.0119231, theta=-68.264362 -> V=1.0, theta=0.0
% INFO    : Bus 21176	: V=1.0106836, theta=-72.126726 -> V=1.0, theta=0.0
% INFO    : Bus 21177	: V=1.023173, theta=-68.221109 -> V=1.0, theta=0.0
% INFO    : Bus 21178	: V=1.0203964, theta=-67.183699 -> V=1.0, theta=0.0
% INFO    : Bus 21179	: V=1.0234646, theta=-67.653807 -> V=1.0, theta=0.0
% INFO    : Bus 21180	: V=0.9971377, theta=-73.991871 -> V=1.0, theta=0.0
% INFO    : Bus 21181	: V=0.999273, theta=-66.486735 -> V=1.0, theta=0.0
% INFO    : Bus 21182	: V=1.0276506, theta=-70.680765 -> V=1.0, theta=0.0
% INFO    : Bus 21183	: V=0.9932589, theta=-74.105109 -> V=1.0, theta=0.0
% INFO    : Bus 21184	: V=0.9931091, theta=-74.11886 -> V=1.0, theta=0.0
% INFO    : Bus 21185	: V=1.0021426, theta=-69.426282 -> V=1.0, theta=0.0
% INFO    : Bus 21186	: V=1.0018572, theta=-69.450983 -> V=1.0, theta=0.0
% INFO    : Bus 21187	: V=0.9909543, theta=-72.627635 -> V=1.0, theta=0.0
% INFO    : Bus 21188	: V=0.9917534, theta=-72.521201 -> V=1.0, theta=0.0
% INFO    : Bus 21189	: V=1.0091299, theta=-68.372801 -> V=1.0, theta=0.0
% INFO    : Bus 21190	: V=1.0011087, theta=-68.84783 -> V=1.0, theta=0.0
% INFO    : Bus 21191	: V=1.0083076, theta=-69.174681 -> V=1.0, theta=0.0
% INFO    : Bus 21192	: V=1.0072097, theta=-68.524231 -> V=1.0, theta=0.0
% INFO    : Bus 21193	: V=1.0086661, theta=-68.494392 -> V=1.0, theta=0.0
% INFO    : Bus 21194	: V=1.0084357, theta=-68.525105 -> V=1.0, theta=0.0
% INFO    : Bus 21195	: V=1.0090366, theta=-68.830179 -> V=1.0, theta=0.0
% INFO    : Bus 21196	: V=1.0108178, theta=-68.165717 -> V=1.0, theta=0.0
% INFO    : Bus 21197	: V=1.0103051, theta=-68.095679 -> V=1.0, theta=0.0
% INFO    : Bus 21198	: V=1.0103783, theta=-68.503725 -> V=1.0, theta=0.0
% INFO    : Bus 21199	: V=0.9938958, theta=-73.499191 -> V=1.0, theta=0.0
% INFO    : Bus 21200	: V=0.9940543, theta=-73.48514 -> V=1.0, theta=0.0
% INFO    : Bus 21201	: V=0.9911422, theta=-73.031241 -> V=1.0, theta=0.0
% INFO    : Bus 21202	: V=0.9910175, theta=-73.046336 -> V=1.0, theta=0.0
% INFO    : Bus 21203	: V=0.9934267, theta=-74.095869 -> V=1.0, theta=0.0
% INFO    : Bus 21204	: V=0.9931865, theta=-74.129575 -> V=1.0, theta=0.0
% INFO    : Bus 21205	: V=1.0153981, theta=-67.343385 -> V=1.0, theta=0.0
% INFO    : Bus 21206	: V=1.0083446, theta=-68.535017 -> V=1.0, theta=0.0
% INFO    : Bus 21207	: V=1.0081852, theta=-68.558849 -> V=1.0, theta=0.0
% INFO    : Bus 21208	: V=1.0098514, theta=-68.079284 -> V=1.0, theta=0.0
% INFO    : Bus 21209	: V=1.0095992, theta=-68.1019 -> V=1.0, theta=0.0
% INFO    : Bus 21210	: V=1.0067882, theta=-68.771625 -> V=1.0, theta=0.0
% INFO    : Bus 21211	: V=1.0123488, theta=-67.568188 -> V=1.0, theta=0.0
% INFO    : Bus 21212	: V=1.0126236, theta=-67.647509 -> V=1.0, theta=0.0
% INFO    : Bus 21213	: V=1.01271, theta=-67.626381 -> V=1.0, theta=0.0
% INFO    : Bus 21214	: V=0.9894906, theta=-73.403056 -> V=1.0, theta=0.0
% INFO    : Bus 21215	: V=1.0216821, theta=-67.452378 -> V=1.0, theta=0.0
% INFO    : Bus 21216	: V=1.0215755, theta=-67.467042 -> V=1.0, theta=0.0
% INFO    : Bus 21217	: V=1.0101617, theta=-68.448241 -> V=1.0, theta=0.0
% INFO    : Bus 21218	: V=1.0028736, theta=-68.972278 -> V=1.0, theta=0.0
% INFO    : Bus 21219	: V=1.0105704, theta=-68.017697 -> V=1.0, theta=0.0
% INFO    : Bus 21220	: V=1.0110481, theta=-68.110423 -> V=1.0, theta=0.0
% INFO    : Bus 21221	: V=1.0183845, theta=-64.1042 -> V=1.0, theta=0.0
% INFO    : Bus 21222	: V=1.0136101, theta=-65.879684 -> V=1.0, theta=0.0
% INFO    : Bus 21223	: V=1.0111287, theta=-67.417486 -> V=1.0, theta=0.0
% INFO    : Bus 21224	: V=1.0113711, theta=-68.469474 -> V=1.0, theta=0.0
% INFO    : Bus 21225	: V=1.0038823, theta=-69.066636 -> V=1.0, theta=0.0
% INFO    : Bus 21226	: V=1.0037997, theta=-69.085037 -> V=1.0, theta=0.0
% INFO    : Bus 21227	: V=1.003987, theta=-69.048203 -> V=1.0, theta=0.0
% INFO    : Bus 21228	: V=1.0228409, theta=-67.761268 -> V=1.0, theta=0.0
% INFO    : Bus 21229	: V=1.0224731, theta=-67.777579 -> V=1.0, theta=0.0
% INFO    : Bus 21230	: V=1.0227804, theta=-67.768169 -> V=1.0, theta=0.0
% INFO    : Bus 21231	: V=1.0232692, theta=-67.73915 -> V=1.0, theta=0.0
% INFO    : Bus 21232	: V=0.9936243, theta=-69.21082 -> V=1.0, theta=0.0
% INFO    : Bus 21233	: V=0.9965095, theta=-73.622006 -> V=1.0, theta=0.0
% INFO    : Bus 21234	: V=0.9932806, theta=-69.251962 -> V=1.0, theta=0.0
% INFO    : Bus 21235	: V=1.0164477, theta=-67.523467 -> V=1.0, theta=0.0
% INFO    : Bus 21236	: V=1.0163421, theta=-67.540779 -> V=1.0, theta=0.0
% INFO    : Bus 21237	: V=1.0167232, theta=-67.479141 -> V=1.0, theta=0.0
% INFO    : Bus 21238	: V=1.0033123, theta=-68.980809 -> V=1.0, theta=0.0
% INFO    : Bus 21239	: V=1.0079298, theta=-68.364509 -> V=1.0, theta=0.0
% INFO    : Bus 21240	: V=1.001726, theta=-69.356337 -> V=1.0, theta=0.0
% INFO    : Bus 21241	: V=1.0015179, theta=-69.389347 -> V=1.0, theta=0.0
% INFO    : Bus 21242	: V=1.001898, theta=-69.327998 -> V=1.0, theta=0.0
% INFO    : Bus 21243	: V=1.001726, theta=-69.356337 -> V=1.0, theta=0.0
% INFO    : Bus 21244	: V=1.0107439, theta=-67.867543 -> V=1.0, theta=0.0
% INFO    : Bus 21245	: V=1.0215811, theta=-68.755408 -> V=1.0, theta=0.0
% INFO    : Bus 21246	: V=1.0201435, theta=-68.719108 -> V=1.0, theta=0.0
% INFO    : Bus 21247	: V=1.00341, theta=-69.074469 -> V=1.0, theta=0.0
% INFO    : Bus 21248	: V=1.0032823, theta=-69.094589 -> V=1.0, theta=0.0
% INFO    : Bus 21249	: V=1.0107612, theta=-68.363453 -> V=1.0, theta=0.0
% INFO    : Bus 21250	: V=1.0106289, theta=-68.383548 -> V=1.0, theta=0.0
% INFO    : Bus 21251	: V=1.0109014, theta=-68.344396 -> V=1.0, theta=0.0
% INFO    : Bus 21252	: V=1.0131582, theta=-67.179304 -> V=1.0, theta=0.0
% INFO    : Bus 21253	: V=1.0161363, theta=-64.133314 -> V=1.0, theta=0.0
% INFO    : Bus 21254	: V=1.0212855, theta=-66.651163 -> V=1.0, theta=0.0
% INFO    : Bus 21255	: V=1.0245219, theta=-67.487809 -> V=1.0, theta=0.0
% INFO    : Bus 21256	: V=1.0243549, theta=-67.502239 -> V=1.0, theta=0.0
% INFO    : Bus 21257	: V=0.9930984, theta=-73.085727 -> V=1.0, theta=0.0
% INFO    : Bus 21258	: V=0.992947, theta=-73.102823 -> V=1.0, theta=0.0
% INFO    : Bus 21259	: V=1.0012997, theta=-68.805479 -> V=1.0, theta=0.0
% INFO    : Bus 21260	: V=1.0083583, theta=-67.74315 -> V=1.0, theta=0.0
% INFO    : Bus 21261	: V=1.0213312, theta=-64.315439 -> V=1.0, theta=0.0
% INFO    : Bus 21262	: V=1.011615, theta=-67.755828 -> V=1.0, theta=0.0
% INFO    : Bus 21263	: V=0.9950717, theta=-71.63131 -> V=1.0, theta=0.0
% INFO    : Bus 21264	: V=0.9939133, theta=-74.035734 -> V=1.0, theta=0.0
% INFO    : Bus 21265	: V=0.9882692, theta=-72.976222 -> V=1.0, theta=0.0
% INFO    : Bus 21266	: V=0.9880774, theta=-72.994346 -> V=1.0, theta=0.0
% INFO    : Bus 21267	: V=1.0095561, theta=-68.180259 -> V=1.0, theta=0.0
% INFO    : Bus 21268	: V=1.0097697, theta=-68.155008 -> V=1.0, theta=0.0
% INFO    : Bus 21269	: V=1.0145448, theta=-67.971394 -> V=1.0, theta=0.0
% INFO    : Bus 21270	: V=1.0101113, theta=-68.116208 -> V=1.0, theta=0.0
% INFO    : Bus 21271	: V=1.0123976, theta=-68.525174 -> V=1.0, theta=0.0
% INFO    : Bus 21272	: V=0.9878584, theta=-72.982113 -> V=1.0, theta=0.0
% INFO    : Bus 21273	: V=0.9880849, theta=-72.962733 -> V=1.0, theta=0.0
% INFO    : Bus 21274	: V=0.9992789, theta=-70.277241 -> V=1.0, theta=0.0
% INFO    : Bus 21275	: V=1.0022749, theta=-67.877224 -> V=1.0, theta=0.0
% INFO    : Bus 21276	: V=0.9941203, theta=-71.548575 -> V=1.0, theta=0.0
% INFO    : Bus 21277	: V=1.0176637, theta=-66.800166 -> V=1.0, theta=0.0
% INFO    : Bus 21278	: V=1.0174839, theta=-66.824377 -> V=1.0, theta=0.0
% INFO    : Bus 21279	: V=1.0092388, theta=-67.216471 -> V=1.0, theta=0.0
% INFO    : Bus 21280	: V=1.0090536, theta=-67.242465 -> V=1.0, theta=0.0
% INFO    : Bus 21281	: V=1.0153281, theta=-67.365286 -> V=1.0, theta=0.0
% INFO    : Bus 21282	: V=1.0154527, theta=-67.350634 -> V=1.0, theta=0.0
% INFO    : Bus 21283	: V=1.0117956, theta=-67.69022 -> V=1.0, theta=0.0
% INFO    : Bus 21284	: V=1.0136224, theta=-66.185241 -> V=1.0, theta=0.0
% INFO    : Bus 21285	: V=1.013402, theta=-66.205119 -> V=1.0, theta=0.0
% INFO    : Bus 21286	: V=1.0161139, theta=-66.463436 -> V=1.0, theta=0.0
% INFO    : Bus 21287	: V=1.0140305, theta=-68.414465 -> V=1.0, theta=0.0
% INFO    : Bus 21288	: V=1.0211091, theta=-68.023672 -> V=1.0, theta=0.0
% INFO    : Bus 21289	: V=1.0012363, theta=-68.69576 -> V=1.0, theta=0.0
% INFO    : Bus 21290	: V=1.0015055, theta=-68.670019 -> V=1.0, theta=0.0
% INFO    : Bus 21291	: V=1.0009561, theta=-68.721755 -> V=1.0, theta=0.0
% INFO    : Bus 21292	: V=0.9935103, theta=-71.656103 -> V=1.0, theta=0.0
% INFO    : Bus 21293	: V=1.0214604, theta=-67.640969 -> V=1.0, theta=0.0
% INFO    : Bus 21294	: V=0.9927798, theta=-73.343712 -> V=1.0, theta=0.0
% INFO    : Bus 21295	: V=0.9926898, theta=-73.359865 -> V=1.0, theta=0.0
% INFO    : Bus 21296	: V=1.0126981, theta=-68.267374 -> V=1.0, theta=0.0
% INFO    : Bus 21297	: V=1.0114352, theta=-68.123417 -> V=1.0, theta=0.0
% INFO    : Bus 21298	: V=1.0123158, theta=-65.890748 -> V=1.0, theta=0.0
% INFO    : Bus 21299	: V=1.0102339, theta=-68.203554 -> V=1.0, theta=0.0
% INFO    : Bus 21300	: V=1.0102493, theta=-68.175388 -> V=1.0, theta=0.0
% INFO    : Bus 21301	: V=1.0102493, theta=-68.175388 -> V=1.0, theta=0.0
% INFO    : Bus 21302	: V=1.0107508, theta=-69.108111 -> V=1.0, theta=0.0
% INFO    : Bus 21303	: V=1.0104834, theta=-69.131619 -> V=1.0, theta=0.0
% INFO    : Bus 21304	: V=0.9943358, theta=-72.583644 -> V=1.0, theta=0.0
% INFO    : Bus 21305	: V=1.0173506, theta=-69.289542 -> V=1.0, theta=0.0
% INFO    : Bus 21306	: V=1.0174715, theta=-69.263681 -> V=1.0, theta=0.0
% INFO    : Bus 21307	: V=1.0166728, theta=-68.607876 -> V=1.0, theta=0.0
% INFO    : Bus 21308	: V=1.0109283, theta=-67.636458 -> V=1.0, theta=0.0
% INFO    : Bus 21309	: V=1.0016804, theta=-71.28475 -> V=1.0, theta=0.0
% INFO    : Bus 21310	: V=1.0018347, theta=-71.268164 -> V=1.0, theta=0.0
% INFO    : Bus 21311	: V=1.0016804, theta=-71.28475 -> V=1.0, theta=0.0
% INFO    : Bus 21312	: V=1.0223248, theta=-68.200477 -> V=1.0, theta=0.0
% INFO    : Bus 21313	: V=1.0224932, theta=-68.18364 -> V=1.0, theta=0.0
% INFO    : Bus 21314	: V=0.9981351, theta=-70.824715 -> V=1.0, theta=0.0
% INFO    : Bus 21315	: V=0.9941606, theta=-71.638277 -> V=1.0, theta=0.0
% INFO    : Bus 21316	: V=0.9896923, theta=-72.593054 -> V=1.0, theta=0.0
% INFO    : Bus 21317	: V=1.0139047, theta=-68.097073 -> V=1.0, theta=0.0
% INFO    : Bus 21318	: V=1.0048541, theta=-68.36967 -> V=1.0, theta=0.0
% INFO    : Bus 21319	: V=0.9978387, theta=-71.482771 -> V=1.0, theta=0.0
% INFO    : Bus 21320	: V=0.9976305, theta=-71.517541 -> V=1.0, theta=0.0
% INFO    : Bus 21321	: V=0.9980492, theta=-71.448347 -> V=1.0, theta=0.0
% INFO    : Bus 21322	: V=0.9886848, theta=-72.83934 -> V=1.0, theta=0.0
% INFO    : Bus 21323	: V=1.009505, theta=-66.468025 -> V=1.0, theta=0.0
% INFO    : Bus 21324	: V=1.0096113, theta=-66.457771 -> V=1.0, theta=0.0
% INFO    : Bus 21325	: V=1.0028092, theta=-68.072272 -> V=1.0, theta=0.0
% INFO    : Bus 21326	: V=1.0181863, theta=-64.297767 -> V=1.0, theta=0.0
% INFO    : Bus 21327	: V=1.0108749, theta=-67.499213 -> V=1.0, theta=0.0
% INFO    : Bus 21328	: V=1.0071158, theta=-70.310818 -> V=1.0, theta=0.0
% INFO    : Bus 21329	: V=1.0071158, theta=-70.310818 -> V=1.0, theta=0.0
% INFO    : Bus 21330	: V=1.0080847, theta=-66.705526 -> V=1.0, theta=0.0
% INFO    : Bus 21331	: V=1.0131369, theta=-66.263376 -> V=1.0, theta=0.0
% INFO    : Bus 21332	: V=0.9933011, theta=-71.798035 -> V=1.0, theta=0.0
% INFO    : Bus 21333	: V=1.0116277, theta=-67.88942 -> V=1.0, theta=0.0
% INFO    : Bus 21334	: V=0.9984036, theta=-71.898706 -> V=1.0, theta=0.0
% INFO    : Bus 21335	: V=1.00262, theta=-70.989893 -> V=1.0, theta=0.0
% INFO    : Bus 21336	: V=1.0161224, theta=-68.673188 -> V=1.0, theta=0.0
% INFO    : Bus 21337	: V=1.0063125, theta=-68.747095 -> V=1.0, theta=0.0
% INFO    : Bus 21338	: V=1.0062389, theta=-68.754707 -> V=1.0, theta=0.0
% INFO    : Bus 21339	: V=1.0153301, theta=-64.979468 -> V=1.0, theta=0.0
% INFO    : Bus 21340	: V=1.0249362, theta=-67.883376 -> V=1.0, theta=0.0
% INFO    : Bus 21341	: V=1.0242577, theta=-67.461841 -> V=1.0, theta=0.0
% INFO    : Bus 21342	: V=1.0238101, theta=-67.49939 -> V=1.0, theta=0.0
% INFO    : Bus 21343	: V=1.0003185, theta=-70.594351 -> V=1.0, theta=0.0
% INFO    : Bus 21344	: V=1.0002042, theta=-70.610676 -> V=1.0, theta=0.0
% INFO    : Bus 21345	: V=0.9946255, theta=-71.305679 -> V=1.0, theta=0.0
% INFO    : Bus 21346	: V=0.9948328, theta=-71.288637 -> V=1.0, theta=0.0
% INFO    : Bus 21347	: V=1.0108174, theta=-67.566427 -> V=1.0, theta=0.0
% INFO    : Bus 21348	: V=1.0106662, theta=-67.585113 -> V=1.0, theta=0.0
% INFO    : Bus 21349	: V=1.0109662, theta=-67.545125 -> V=1.0, theta=0.0
% INFO    : Bus 21350	: V=1.0108174, theta=-67.566427 -> V=1.0, theta=0.0
% INFO    : Bus 21351	: V=1.010489, theta=-68.032473 -> V=1.0, theta=0.0
% INFO    : Bus 21352	: V=1.0090358, theta=-68.293612 -> V=1.0, theta=0.0
% INFO    : Bus 21353	: V=1.0092243, theta=-68.272632 -> V=1.0, theta=0.0
% INFO    : Bus 21354	: V=1.0278351, theta=-67.082099 -> V=1.0, theta=0.0
% INFO    : Bus 21355	: V=1.0090452, theta=-70.489287 -> V=1.0, theta=0.0
% INFO    : Bus 21356	: V=1.0088535, theta=-70.519299 -> V=1.0, theta=0.0
% INFO    : Bus 21357	: V=0.9944095, theta=-71.342075 -> V=1.0, theta=0.0
% INFO    : Bus 21358	: V=0.9941048, theta=-71.368873 -> V=1.0, theta=0.0
% INFO    : Bus 21359	: V=1.0212207, theta=-68.35029 -> V=1.0, theta=0.0
% INFO    : Bus 21360	: V=1.0232794, theta=-67.950709 -> V=1.0, theta=0.0
% INFO    : Bus 21361	: V=1.0234276, theta=-67.928366 -> V=1.0, theta=0.0
% INFO    : Bus 21362	: V=1.0005135, theta=-70.56562 -> V=1.0, theta=0.0
% INFO    : Bus 21363	: V=1.0007734, theta=-70.540105 -> V=1.0, theta=0.0
% INFO    : Bus 21364	: V=1.028278, theta=-70.442936 -> V=1.0, theta=0.0
% INFO    : Bus 21365	: V=1.0151956, theta=-65.432784 -> V=1.0, theta=0.0
% INFO    : Bus 21366	: V=1.0151029, theta=-65.450828 -> V=1.0, theta=0.0
% INFO    : Bus 21367	: V=1.0149186, theta=-65.418562 -> V=1.0, theta=0.0
% INFO    : Bus 21368	: V=1.0082037, theta=-66.822485 -> V=1.0, theta=0.0
% INFO    : Bus 21369	: V=1.0106207, theta=-67.170438 -> V=1.0, theta=0.0
% INFO    : Bus 21370	: V=1.0107429, theta=-67.157059 -> V=1.0, theta=0.0
% INFO    : Bus 21371	: V=1.0026494, theta=-68.118803 -> V=1.0, theta=0.0
% INFO    : Bus 21372	: V=1.0063342, theta=-67.554521 -> V=1.0, theta=0.0
% INFO    : Bus 21373	: V=1.0041955, theta=-65.519055 -> V=1.0, theta=0.0
% INFO    : Bus 21374	: V=1.0198062, theta=-68.998238 -> V=1.0, theta=0.0
% INFO    : Bus 21375	: V=1.0112974, theta=-68.496544 -> V=1.0, theta=0.0
% INFO    : Bus 21376	: V=0.9968416, theta=-71.10311 -> V=1.0, theta=0.0
% INFO    : Bus 21377	: V=0.9966196, theta=-71.127444 -> V=1.0, theta=0.0
% INFO    : Bus 21378	: V=0.9970542, theta=-71.080019 -> V=1.0, theta=0.0
% INFO    : Bus 21379	: V=1.0130645, theta=-70.031584 -> V=1.0, theta=0.0
% INFO    : Bus 21380	: V=1.0380954, theta=-70.305455 -> V=1.0, theta=0.0
% INFO    : Bus 21381	: V=1.0379685, theta=-70.319584 -> V=1.0, theta=0.0
% INFO    : Bus 21382	: V=1.0156439, theta=-64.190107 -> V=1.0, theta=0.0
% INFO    : Bus 21383	: V=1.0130579, theta=-67.374482 -> V=1.0, theta=0.0
% INFO    : Bus 21384	: V=1.0153475, theta=-64.225297 -> V=1.0, theta=0.0
% INFO    : Bus 21385	: V=1.0205012, theta=-63.453405 -> V=1.0, theta=0.0
% INFO    : Bus 21386	: V=1.017471, theta=-65.281616 -> V=1.0, theta=0.0
% INFO    : Bus 21387	: V=1.0201915, theta=-63.49039 -> V=1.0, theta=0.0
% INFO    : Bus 21388	: V=1.0195024, theta=-63.733388 -> V=1.0, theta=0.0
% INFO    : Bus 21389	: V=1.0244786, theta=-65.312951 -> V=1.0, theta=0.0
% INFO    : Bus 21390	: V=1.0099845, theta=-70.303903 -> V=1.0, theta=0.0
% INFO    : Bus 21391	: V=1.0031623, theta=-70.79125 -> V=1.0, theta=0.0
% INFO    : Bus 21392	: V=1.0051608, theta=-67.752867 -> V=1.0, theta=0.0
% INFO    : Bus 21393	: V=1.0050005, theta=-67.766298 -> V=1.0, theta=0.0
% INFO    : Bus 21394	: V=1.0040739, theta=-68.12436 -> V=1.0, theta=0.0
% INFO    : Bus 21395	: V=1.003904, theta=-68.140384 -> V=1.0, theta=0.0
% INFO    : Bus 21396	: V=1.0102438, theta=-66.956719 -> V=1.0, theta=0.0
% INFO    : Bus 21397	: V=1.0228198, theta=-68.49213 -> V=1.0, theta=0.0
% INFO    : Bus 21398	: V=1.0137418, theta=-65.134724 -> V=1.0, theta=0.0
% INFO    : Bus 21399	: V=1.0225573, theta=-67.945187 -> V=1.0, theta=0.0
% INFO    : Bus 21400	: V=1.0135614, theta=-65.162085 -> V=1.0, theta=0.0
% INFO    : Bus 21401	: V=0.9961129, theta=-70.968648 -> V=1.0, theta=0.0
% INFO    : Bus 21402	: V=0.996222, theta=-70.952693 -> V=1.0, theta=0.0
% INFO    : Bus 21403	: V=0.996, theta=-70.982575 -> V=1.0, theta=0.0
% INFO    : Bus 21404	: V=1.0013977, theta=-69.84496 -> V=1.0, theta=0.0
% INFO    : Bus 21405	: V=1.0082514, theta=-66.153066 -> V=1.0, theta=0.0
% INFO    : Bus 21406	: V=1.0077353, theta=-70.396623 -> V=1.0, theta=0.0
% INFO    : Bus 21407	: V=1.0084819, theta=-71.470469 -> V=1.0, theta=0.0
% INFO    : Bus 21408	: V=1.0084819, theta=-71.470469 -> V=1.0, theta=0.0
% INFO    : Bus 21409	: V=1.0029607, theta=-67.694229 -> V=1.0, theta=0.0
% INFO    : Bus 21410	: V=0.9993002, theta=-70.627329 -> V=1.0, theta=0.0
% INFO    : Bus 21411	: V=1.0009303, theta=-69.056972 -> V=1.0, theta=0.0
% INFO    : Bus 21412	: V=1.0009303, theta=-69.056972 -> V=1.0, theta=0.0
% INFO    : Bus 21413	: V=1.0268348, theta=-70.112117 -> V=1.0, theta=0.0
% INFO    : Bus 21414	: V=1.0267389, theta=-70.120906 -> V=1.0, theta=0.0
% INFO    : Bus 21415	: V=1.0105923, theta=-70.200365 -> V=1.0, theta=0.0
% INFO    : Bus 21416	: V=1.0216865, theta=-68.261134 -> V=1.0, theta=0.0
% INFO    : Bus 21417	: V=1.0218893, theta=-68.224837 -> V=1.0, theta=0.0
% INFO    : Bus 21418	: V=1.011666, theta=-70.256763 -> V=1.0, theta=0.0
% INFO    : Bus 21419	: V=1.010913, theta=-67.610836 -> V=1.0, theta=0.0
% INFO    : Bus 21420	: V=1.0039084, theta=-68.074297 -> V=1.0, theta=0.0
% INFO    : Bus 21421	: V=1.0037706, theta=-68.092699 -> V=1.0, theta=0.0
% INFO    : Bus 21422	: V=1.0089426, theta=-70.499249 -> V=1.0, theta=0.0
% INFO    : Bus 21423	: V=1.0087886, theta=-70.522668 -> V=1.0, theta=0.0
% INFO    : Bus 21424	: V=1.0091162, theta=-70.474899 -> V=1.0, theta=0.0
% INFO    : Bus 21425	: V=1.0089426, theta=-70.499249 -> V=1.0, theta=0.0
% INFO    : Bus 21426	: V=1.0297713, theta=-70.333159 -> V=1.0, theta=0.0
% INFO    : Bus 21427	: V=1.029446, theta=-70.360568 -> V=1.0, theta=0.0
% INFO    : Bus 21428	: V=1.0300894, theta=-70.304171 -> V=1.0, theta=0.0
% INFO    : Bus 21429	: V=1.0135037, theta=-70.192546 -> V=1.0, theta=0.0
% INFO    : Bus 21430	: V=0.9984535, theta=-71.050395 -> V=1.0, theta=0.0
% INFO    : Bus 21431	: V=1.0204469, theta=-70.431822 -> V=1.0, theta=0.0
% INFO    : Bus 21432	: V=1.0161566, theta=-66.169714 -> V=1.0, theta=0.0
% INFO    : Bus 21433	: V=1.0186583, theta=-65.745994 -> V=1.0, theta=0.0
% INFO    : Bus 21434	: V=0.9995894, theta=-70.507629 -> V=1.0, theta=0.0
% INFO    : Bus 21435	: V=0.999321, theta=-70.530632 -> V=1.0, theta=0.0
% INFO    : Bus 21436	: V=1.0152625, theta=-70.233003 -> V=1.0, theta=0.0
% INFO    : Bus 21437	: V=1.0229362, theta=-69.333796 -> V=1.0, theta=0.0
% INFO    : Bus 21438	: V=1.0044474, theta=-70.875689 -> V=1.0, theta=0.0
% INFO    : Bus 21439	: V=1.0203956, theta=-70.249081 -> V=1.0, theta=0.0
% INFO    : Bus 21440	: V=1.0202947, theta=-70.270204 -> V=1.0, theta=0.0
% INFO    : Bus 21441	: V=1.0282618, theta=-70.358884 -> V=1.0, theta=0.0
% INFO    : Bus 21442	: V=1.0284248, theta=-70.34447 -> V=1.0, theta=0.0
% INFO    : Bus 21443	: V=1.0282618, theta=-70.358884 -> V=1.0, theta=0.0
% INFO    : Bus 21444	: V=1.0205334, theta=-70.390556 -> V=1.0, theta=0.0
% INFO    : Bus 21445	: V=1.0203696, theta=-70.40726 -> V=1.0, theta=0.0
% INFO    : Bus 21446	: V=1.0214721, theta=-70.213092 -> V=1.0, theta=0.0
% INFO    : Bus 21447	: V=1.0213686, theta=-70.223019 -> V=1.0, theta=0.0
% INFO    : Bus 21448	: V=1.0256539, theta=-64.740334 -> V=1.0, theta=0.0
% INFO    : Bus 21449	: V=1.0249361, theta=-65.214528 -> V=1.0, theta=0.0
% INFO    : Bus 21450	: V=1.0250787, theta=-65.201217 -> V=1.0, theta=0.0
% INFO    : Bus 21451	: V=1.0142681, theta=-69.957484 -> V=1.0, theta=0.0
% INFO    : Bus 21452	: V=1.0157662, theta=-69.792091 -> V=1.0, theta=0.0
% INFO    : Bus 21453	: V=1.0156922, theta=-69.805584 -> V=1.0, theta=0.0
% INFO    : Bus 21454	: V=1.0158382, theta=-69.777823 -> V=1.0, theta=0.0
% INFO    : Bus 21455	: V=1.0220331, theta=-70.301012 -> V=1.0, theta=0.0
% INFO    : Bus 21456	: V=1.0218918, theta=-70.326809 -> V=1.0, theta=0.0
% INFO    : Bus 21457	: V=1.0221584, theta=-70.277016 -> V=1.0, theta=0.0
% INFO    : Bus 21458	: V=1.0042351, theta=-67.953665 -> V=1.0, theta=0.0
% INFO    : Bus 21459	: V=1.0139817, theta=-69.773023 -> V=1.0, theta=0.0
% INFO    : Bus 21460	: V=1.0279459, theta=-72.05295 -> V=1.0, theta=0.0
% INFO    : Bus 21461	: V=1.0279459, theta=-72.05295 -> V=1.0, theta=0.0
% INFO    : Bus 21462	: V=1.0174016, theta=-65.806912 -> V=1.0, theta=0.0
% INFO    : Bus 21463	: V=1.0199876, theta=-65.82057 -> V=1.0, theta=0.0
% INFO    : Bus 21464	: V=1.0197509, theta=-65.856073 -> V=1.0, theta=0.0
% INFO    : Bus 21465	: V=1.0201876, theta=-65.785252 -> V=1.0, theta=0.0
% INFO    : Bus 21466	: V=1.0292143, theta=-70.403289 -> V=1.0, theta=0.0
% INFO    : Bus 21467	: V=1.029112, theta=-70.419788 -> V=1.0, theta=0.0
% INFO    : Bus 21468	: V=1.0094119, theta=-70.427864 -> V=1.0, theta=0.0
% INFO    : Bus 21469	: V=1.0102943, theta=-67.83273 -> V=1.0, theta=0.0
% INFO    : Bus 21470	: V=1.0056186, theta=-67.425583 -> V=1.0, theta=0.0
% INFO    : Bus 21471	: V=1.0093273, theta=-68.059654 -> V=1.0, theta=0.0
% INFO    : Bus 21472	: V=1.0144162, theta=-68.529546 -> V=1.0, theta=0.0
% INFO    : Bus 21473	: V=1.0142204, theta=-68.554207 -> V=1.0, theta=0.0
% INFO    : Bus 21474	: V=1.0104625, theta=-65.185944 -> V=1.0, theta=0.0
% INFO    : Bus 21475	: V=1.0117702, theta=-67.399202 -> V=1.0, theta=0.0
% INFO    : Bus 21476	: V=1.0065481, theta=-70.787769 -> V=1.0, theta=0.0
% INFO    : Bus 21477	: V=1.00996, theta=-70.440637 -> V=1.0, theta=0.0
% INFO    : Bus 21478	: V=1.0097328, theta=-70.465775 -> V=1.0, theta=0.0
% INFO    : Bus 21479	: V=1.0020969, theta=-70.870037 -> V=1.0, theta=0.0
% INFO    : Bus 21480	: V=1.0234279, theta=-65.094743 -> V=1.0, theta=0.0
% INFO    : Bus 21481	: V=1.0184674, theta=-65.858113 -> V=1.0, theta=0.0
% INFO    : Bus 21482	: V=1.0203124, theta=-65.905307 -> V=1.0, theta=0.0
% INFO    : Bus 21483	: V=1.0201283, theta=-65.938125 -> V=1.0, theta=0.0
% INFO    : Bus 21484	: V=1.0037521, theta=-70.499671 -> V=1.0, theta=0.0
% INFO    : Bus 21485	: V=1.0192125, theta=-70.54417 -> V=1.0, theta=0.0
% INFO    : Bus 21486	: V=1.0192125, theta=-70.54417 -> V=1.0, theta=0.0
% INFO    : Bus 21487	: V=1.0192125, theta=-70.54417 -> V=1.0, theta=0.0
% INFO    : Bus 21488	: V=1.0192125, theta=-70.54417 -> V=1.0, theta=0.0
% INFO    : Bus 21489	: V=1.0190502, theta=-70.558898 -> V=1.0, theta=0.0
% INFO    : Bus 21490	: V=1.0034387, theta=-70.229408 -> V=1.0, theta=0.0
% INFO    : Bus 21491	: V=1.0037706, theta=-70.201212 -> V=1.0, theta=0.0
% INFO    : Bus 21492	: V=1.0076686, theta=-70.468209 -> V=1.0, theta=0.0
% INFO    : Bus 21493	: V=1.0043145, theta=-70.272524 -> V=1.0, theta=0.0
% INFO    : Bus 21494	: V=1.0206086, theta=-70.431068 -> V=1.0, theta=0.0
% INFO    : Bus 21495	: V=1.0041163, theta=-70.342122 -> V=1.0, theta=0.0
% INFO    : Bus 21496	: V=1.0121174, theta=-65.689714 -> V=1.0, theta=0.0
% INFO    : Bus 21497	: V=1.0056325, theta=-70.015129 -> V=1.0, theta=0.0
% INFO    : Bus 21498	: V=1.0239639, theta=-69.769695 -> V=1.0, theta=0.0
% INFO    : Bus 21499	: V=1.0071191, theta=-67.035537 -> V=1.0, theta=0.0
% INFO    : Bus 21500	: V=1.0068356, theta=-70.701276 -> V=1.0, theta=0.0
% INFO    : Bus 21501	: V=1.0070469, theta=-70.663874 -> V=1.0, theta=0.0
% INFO    : Bus 21502	: V=1.0066427, theta=-70.739288 -> V=1.0, theta=0.0
% INFO    : Bus 21503	: V=1.0082227, theta=-70.734 -> V=1.0, theta=0.0
% INFO    : Bus 21504	: V=1.0084318, theta=-70.696577 -> V=1.0, theta=0.0
% INFO    : Bus 21505	: V=1.0080366, theta=-70.768159 -> V=1.0, theta=0.0
% INFO    : Bus 21506	: V=1.0067378, theta=-70.333483 -> V=1.0, theta=0.0
% INFO    : Bus 21507	: V=1.0067378, theta=-70.333483 -> V=1.0, theta=0.0
% INFO    : Bus 21508	: V=1.0067378, theta=-70.333483 -> V=1.0, theta=0.0
% INFO    : Bus 21509	: V=1.0067378, theta=-70.333483 -> V=1.0, theta=0.0
% INFO    : Bus 21510	: V=1.0075608, theta=-68.014907 -> V=1.0, theta=0.0
% INFO    : Bus 21511	: V=1.0074033, theta=-68.031143 -> V=1.0, theta=0.0
% INFO    : Bus 21512	: V=1.0060223, theta=-70.313061 -> V=1.0, theta=0.0
% INFO    : Bus 21513	: V=1.0061837, theta=-70.286702 -> V=1.0, theta=0.0
% INFO    : Bus 21514	: V=1.0127728, theta=-70.703126 -> V=1.0, theta=0.0
% INFO    : Bus 21515	: V=1.0124637, theta=-70.728608 -> V=1.0, theta=0.0
% INFO    : Bus 21516	: V=1.0131025, theta=-70.679659 -> V=1.0, theta=0.0
% INFO    : Bus 21517	: V=1.0285916, theta=-70.167294 -> V=1.0, theta=0.0
% INFO    : Bus 21518	: V=1.0244878, theta=-70.431808 -> V=1.0, theta=0.0
% INFO    : Bus 21519	: V=1.0246194, theta=-70.410829 -> V=1.0, theta=0.0
% INFO    : Bus 21520	: V=1.0116596, theta=-68.414481 -> V=1.0, theta=0.0
% INFO    : Bus 21521	: V=1.010036, theta=-68.106331 -> V=1.0, theta=0.0
% INFO    : Bus 21522	: V=1.0096915, theta=-68.142704 -> V=1.0, theta=0.0
% INFO    : Bus 21523	: V=1.0078381, theta=-70.282883 -> V=1.0, theta=0.0
% INFO    : Bus 21524	: V=1.0075286, theta=-70.299385 -> V=1.0, theta=0.0
% INFO    : Bus 21525	: V=1.0108153, theta=-70.190401 -> V=1.0, theta=0.0
% INFO    : Bus 21526	: V=1.010622, theta=-70.210895 -> V=1.0, theta=0.0
% INFO    : Bus 21527	: V=1.0140156, theta=-65.440667 -> V=1.0, theta=0.0
% INFO    : Bus 21528	: V=1.0105358, theta=-69.785415 -> V=1.0, theta=0.0
% INFO    : Bus 21529	: V=1.0257281, theta=-70.399777 -> V=1.0, theta=0.0
% INFO    : Bus 21530	: V=1.0166624, theta=-70.087442 -> V=1.0, theta=0.0
% INFO    : Bus 21531	: V=0.9985694, theta=-65.718032 -> V=1.0, theta=0.0
% INFO    : Bus 21532	: V=1.0301145, theta=-70.076703 -> V=1.0, theta=0.0
% INFO    : Bus 21533	: V=1.0049476, theta=-70.312192 -> V=1.0, theta=0.0
% INFO    : Bus 21534	: V=1.0105644, theta=-70.453356 -> V=1.0, theta=0.0
% INFO    : Bus 21535	: V=1.0108222, theta=-70.41844 -> V=1.0, theta=0.0
% INFO    : Bus 21536	: V=1.0125544, theta=-66.151563 -> V=1.0, theta=0.0
% INFO    : Bus 21537	: V=1.0121995, theta=-66.185887 -> V=1.0, theta=0.0
% INFO    : Bus 21538	: V=1.0128934, theta=-66.118805 -> V=1.0, theta=0.0
% INFO    : Bus 21539	: V=1.0157212, theta=-66.336453 -> V=1.0, theta=0.0
% INFO    : Bus 21540	: V=1.0114563, theta=-70.497483 -> V=1.0, theta=0.0
% INFO    : Bus 21541	: V=1.0111851, theta=-70.515768 -> V=1.0, theta=0.0
% INFO    : Bus 21542	: V=1.0111552, theta=-70.413566 -> V=1.0, theta=0.0
% INFO    : Bus 21543	: V=1.0110339, theta=-70.432772 -> V=1.0, theta=0.0
% INFO    : Bus 21544	: V=1.0084307, theta=-70.067728 -> V=1.0, theta=0.0
% INFO    : Bus 21545	: V=1.0081352, theta=-70.09948 -> V=1.0, theta=0.0
% INFO    : Bus 21546	: V=1.0041903, theta=-70.659811 -> V=1.0, theta=0.0
% INFO    : Bus 21547	: V=1.0124395, theta=-70.470097 -> V=1.0, theta=0.0
% INFO    : Bus 21548	: V=1.0061736, theta=-69.960637 -> V=1.0, theta=0.0
% INFO    : Bus 21549	: V=1.0059771, theta=-69.983075 -> V=1.0, theta=0.0
% INFO    : Bus 21550	: V=1.0064093, theta=-69.934735 -> V=1.0, theta=0.0
% INFO    : Bus 21551	: V=1.0131496, theta=-70.544312 -> V=1.0, theta=0.0
% INFO    : Bus 21552	: V=1.0130119, theta=-70.571023 -> V=1.0, theta=0.0
% INFO    : Bus 21553	: V=1.0078817, theta=-66.985632 -> V=1.0, theta=0.0
% INFO    : Bus 21554	: V=1.0076839, theta=-67.006539 -> V=1.0, theta=0.0
% INFO    : Bus 21555	: V=1.0080893, theta=-66.963399 -> V=1.0, theta=0.0
% INFO    : Bus 21556	: V=1.0078817, theta=-66.985632 -> V=1.0, theta=0.0
% INFO    : Bus 21557	: V=1.0156986, theta=-65.591274 -> V=1.0, theta=0.0
% INFO    : Bus 21558	: V=1.0100892, theta=-65.939307 -> V=1.0, theta=0.0
% INFO    : Bus 21559	: V=1.0064372, theta=-68.8229 -> V=1.0, theta=0.0
% INFO    : Bus 21560	: V=1.0196238, theta=-65.937779 -> V=1.0, theta=0.0
% INFO    : Bus 21561	: V=1.0039193, theta=-70.745123 -> V=1.0, theta=0.0
% INFO    : Bus 21562	: V=1.00984, theta=-70.655644 -> V=1.0, theta=0.0
% INFO    : Bus 21563	: V=1.003746, theta=-70.6635 -> V=1.0, theta=0.0
% INFO    : Bus 21564	: V=1.011862, theta=-66.507448 -> V=1.0, theta=0.0
% INFO    : Bus 21565	: V=1.015435, theta=-65.754559 -> V=1.0, theta=0.0
% INFO    : Bus 21566	: V=1.0153273, theta=-65.775441 -> V=1.0, theta=0.0
% INFO    : Bus 21567	: V=1.0029448, theta=-70.780432 -> V=1.0, theta=0.0
% INFO    : Bus 21568	: V=1.0031583, theta=-70.758342 -> V=1.0, theta=0.0
% INFO    : Bus 21569	: V=1.0139107, theta=-65.478918 -> V=1.0, theta=0.0
% INFO    : Bus 21570	: V=1.0145243, theta=-65.284575 -> V=1.0, theta=0.0
% INFO    : Bus 21571	: V=1.0140866, theta=-65.818765 -> V=1.0, theta=0.0
% INFO    : Bus 21572	: V=1.0138295, theta=-65.8473 -> V=1.0, theta=0.0
% INFO    : Bus 21573	: V=1.011656, theta=-66.420184 -> V=1.0, theta=0.0
% INFO    : Bus 21574	: V=1.0213358, theta=-65.974273 -> V=1.0, theta=0.0
% INFO    : Bus 21575	: V=1.0149302, theta=-69.356108 -> V=1.0, theta=0.0
% INFO    : Bus 21576	: V=1.0150005, theta=-69.349195 -> V=1.0, theta=0.0
% INFO    : Bus 21577	: V=1.0074701, theta=-70.323061 -> V=1.0, theta=0.0
% INFO    : Bus 21578	: V=1.0072252, theta=-70.345554 -> V=1.0, theta=0.0
% INFO    : Bus 21579	: V=1.0084041, theta=-70.578363 -> V=1.0, theta=0.0
% INFO    : Bus 21580	: V=1.0118993, theta=-66.355928 -> V=1.0, theta=0.0
% INFO    : Bus 21581	: V=1.0040592, theta=-67.467292 -> V=1.0, theta=0.0
% INFO    : Bus 21582	: V=1.010427, theta=-69.29259 -> V=1.0, theta=0.0
% INFO    : Bus 21583	: V=1.0117232, theta=-69.112021 -> V=1.0, theta=0.0
% INFO    : Bus 21584	: V=1.0131257, theta=-68.678634 -> V=1.0, theta=0.0
% INFO    : Bus 21585	: V=1.0109166, theta=-66.630394 -> V=1.0, theta=0.0
% INFO    : Bus 21586	: V=1.0080052, theta=-67.202716 -> V=1.0, theta=0.0
% INFO    : Bus 21587	: V=0.9962385, theta=-68.844511 -> V=1.0, theta=0.0
% INFO    : Bus 21588	: V=1.0074214, theta=-67.280675 -> V=1.0, theta=0.0
% INFO    : Bus 21589	: V=1.0074214, theta=-67.280675 -> V=1.0, theta=0.0
% INFO    : Bus 21590	: V=1.0163499, theta=-66.25898 -> V=1.0, theta=0.0
% INFO    : Bus 21591	: V=1.016441, theta=-66.244569 -> V=1.0, theta=0.0
% INFO    : Bus 21592	: V=1.0174646, theta=-66.233124 -> V=1.0, theta=0.0
% INFO    : Bus 21593	: V=1.02, theta=-60.096789 -> V=1.0, theta=0.0
% INFO    : Bus 21594	: V=1.0195028, theta=-62.46513 -> V=1.0, theta=0.0
% INFO    : Bus 21595	: V=1.0199872, theta=-64.708747 -> V=1.0, theta=0.0
% INFO    : Bus 21596	: V=0.9997398, theta=-59.213671 -> V=1.0, theta=0.0
% INFO    : Bus 21597	: V=0.9993742, theta=-59.293584 -> V=1.0, theta=0.0
% INFO    : Bus 21598	: V=0.9995251, theta=-59.255849 -> V=1.0, theta=0.0
% INFO    : Bus 21599	: V=0.9947443, theta=-59.004136 -> V=1.0, theta=0.0
% INFO    : Bus 21600	: V=1.0213707, theta=-62.595431 -> V=1.0, theta=0.0
% INFO    : Bus 21601	: V=1.0221987, theta=-65.046733 -> V=1.0, theta=0.0
% INFO    : Bus 21602	: V=1.0376905, theta=-61.736872 -> V=1.0, theta=0.0
% INFO    : Bus 21603	: V=1.0396221, theta=-61.740783 -> V=1.0, theta=0.0
% INFO    : Bus 21604	: V=1.0379574, theta=-61.968024 -> V=1.0, theta=0.0
% INFO    : Bus 21605	: V=1.0370811, theta=-62.156038 -> V=1.0, theta=0.0
% INFO    : Bus 21606	: V=1.0212082, theta=-62.614434 -> V=1.0, theta=0.0
% INFO    : Bus 21607	: V=1.02116, theta=-62.563064 -> V=1.0, theta=0.0
% INFO    : Bus 21608	: V=1.0202454, theta=-64.643764 -> V=1.0, theta=0.0
% INFO    : Bus 21609	: V=1.0209306, theta=-67.148935 -> V=1.0, theta=0.0
% INFO    : Bus 21610	: V=1.0209306, theta=-67.148935 -> V=1.0, theta=0.0
% INFO    : Bus 21611	: V=0.9820538, theta=-60.560386 -> V=1.0, theta=0.0
% INFO    : Bus 21612	: V=0.9673715, theta=-57.63809 -> V=1.0, theta=0.0
% INFO    : Bus 21613	: V=0.9719302, theta=-59.114842 -> V=1.0, theta=0.0
% INFO    : Bus 21614	: V=1.02116, theta=-62.563064 -> V=1.0, theta=0.0
% INFO    : Bus 21615	: V=1.0160127, theta=-63.965136 -> V=1.0, theta=0.0
% INFO    : Bus 21616	: V=1.0122323, theta=-66.74418 -> V=1.0, theta=0.0
% INFO    : Bus 21617	: V=0.9964765, theta=-61.29075 -> V=1.0, theta=0.0
% INFO    : Bus 21618	: V=0.9881452, theta=-65.665378 -> V=1.0, theta=0.0
% INFO    : Bus 21619	: V=0.9927905, theta=-63.562089 -> V=1.0, theta=0.0
% INFO    : Bus 21620	: V=0.9940476, theta=-63.236614 -> V=1.0, theta=0.0
% INFO    : Bus 21621	: V=1.0192, theta=-62.222088 -> V=1.0, theta=0.0
% INFO    : Bus 21622	: V=1.0196016, theta=-64.877574 -> V=1.0, theta=0.0
% INFO    : Bus 21623	: V=1.0169783, theta=-58.844059 -> V=1.0, theta=0.0
% INFO    : Bus 21624	: V=1.0179705, theta=-59.56575 -> V=1.0, theta=0.0
% INFO    : Bus 21625	: V=1.018093, theta=-59.930303 -> V=1.0, theta=0.0
% INFO    : Bus 21626	: V=1.0192642, theta=-62.47706 -> V=1.0, theta=0.0
% INFO    : Bus 21627	: V=1.0018819, theta=-66.770222 -> V=1.0, theta=0.0
% INFO    : Bus 21628	: V=1.011311, theta=-70.064181 -> V=1.0, theta=0.0
% INFO    : Bus 21629	: V=1.00263, theta=-66.688863 -> V=1.0, theta=0.0
% INFO    : Bus 21630	: V=1.0137621, theta=-70.109186 -> V=1.0, theta=0.0
% INFO    : Bus 21631	: V=1.0327769, theta=-67.89857 -> V=1.0, theta=0.0
% INFO    : Bus 21632	: V=0.9984873, theta=-68.786134 -> V=1.0, theta=0.0
% INFO    : Bus 21633	: V=0.994975, theta=-71.83318 -> V=1.0, theta=0.0
% INFO    : Bus 21634	: V=0.9946658, theta=-72.33971 -> V=1.0, theta=0.0
% INFO    : Bus 21635	: V=0.9946658, theta=-72.33971 -> V=1.0, theta=0.0
% INFO    : Bus 21636	: V=0.9692006, theta=-68.012882 -> V=1.0, theta=0.0
% INFO    : Bus 21637	: V=1.0010521, theta=-69.162607 -> V=1.0, theta=0.0
% INFO    : Bus 21638	: V=0.9988106, theta=-68.690174 -> V=1.0, theta=0.0
% INFO    : Bus 21639	: V=1.01626, theta=-68.269341 -> V=1.0, theta=0.0
% INFO    : Bus 21640	: V=1.0158673, theta=-68.303002 -> V=1.0, theta=0.0
% INFO    : Bus 21641	: V=1.0249734, theta=-60.483386 -> V=1.0, theta=0.0
% INFO    : Bus 21642	: V=1.0214775, theta=-62.47683 -> V=1.0, theta=0.0
% INFO    : Bus 21643	: V=1.0161186, theta=-65.41354 -> V=1.0, theta=0.0
% INFO    : Bus 21644	: V=1.0160605, theta=-65.456396 -> V=1.0, theta=0.0
% INFO    : Bus 21645	: V=1.0160605, theta=-65.456396 -> V=1.0, theta=0.0
% INFO    : Bus 21646	: V=1.045768, theta=-59.267038 -> V=1.0, theta=0.0
% INFO    : Bus 21647	: V=1.0462617, theta=-58.122731 -> V=1.0, theta=0.0
% INFO    : Bus 21648	: V=1.0249734, theta=-60.483386 -> V=1.0, theta=0.0
% INFO    : Bus 21649	: V=1.02116, theta=-62.647537 -> V=1.0, theta=0.0
% INFO    : Bus 21650	: V=1.023838, theta=-65.039708 -> V=1.0, theta=0.0
% INFO    : Bus 21651	: V=1.016214, theta=-61.114672 -> V=1.0, theta=0.0
% INFO    : Bus 21652	: V=1.0157536, theta=-59.903358 -> V=1.0, theta=0.0
% INFO    : Bus 21653	: V=1.0165224, theta=-59.64642 -> V=1.0, theta=0.0
% INFO    : Bus 21654	: V=1.011028, theta=-68.139249 -> V=1.0, theta=0.0
% INFO    : Bus 21655	: V=1.0218809, theta=-63.254522 -> V=1.0, theta=0.0
% INFO    : Bus 21656	: V=1.0309588, theta=-64.202064 -> V=1.0, theta=0.0
% INFO    : Bus 21657	: V=1.0216463, theta=-63.215609 -> V=1.0, theta=0.0
% INFO    : Bus 21658	: V=1.0218809, theta=-63.254522 -> V=1.0, theta=0.0
% INFO    : Bus 21659	: V=1.0218809, theta=-63.254522 -> V=1.0, theta=0.0
% INFO    : Bus 21660	: V=1.0177597, theta=-63.61987 -> V=1.0, theta=0.0
% INFO    : Bus 21661	: V=1.023523, theta=-65.562148 -> V=1.0, theta=0.0
% INFO    : Bus 21662	: V=1.0273351, theta=-62.584566 -> V=1.0, theta=0.0
% INFO    : Bus 21663	: V=1.0281121, theta=-62.51378 -> V=1.0, theta=0.0
% INFO    : Bus 21664	: V=1.007643, theta=-65.665975 -> V=1.0, theta=0.0
% INFO    : Bus 21665	: V=1.0043733, theta=-68.745678 -> V=1.0, theta=0.0
% INFO    : Bus 21666	: V=1.0038605, theta=-70.088344 -> V=1.0, theta=0.0
% INFO    : Bus 21667	: V=1.0038605, theta=-70.088344 -> V=1.0, theta=0.0
% INFO    : Bus 21668	: V=1.0338236, theta=-64.858297 -> V=1.0, theta=0.0
% INFO    : Bus 21669	: V=1.0312769, theta=-64.369905 -> V=1.0, theta=0.0
% INFO    : Bus 21670	: V=1.007643, theta=-65.665975 -> V=1.0, theta=0.0
% INFO    : Bus 21671	: V=1.0074455, theta=-65.578878 -> V=1.0, theta=0.0
% INFO    : Bus 21672	: V=1.007643, theta=-65.665975 -> V=1.0, theta=0.0
% INFO    : Bus 21673	: V=1.01626, theta=-65.101292 -> V=1.0, theta=0.0
% INFO    : Bus 21674	: V=1.0160638, theta=-65.135837 -> V=1.0, theta=0.0
% INFO    : Bus 21675	: V=1.0166528, theta=-66.015321 -> V=1.0, theta=0.0
% INFO    : Bus 21676	: V=1.0227119, theta=-62.690876 -> V=1.0, theta=0.0
% INFO    : Bus 21677	: V=1.0229023, theta=-64.382797 -> V=1.0, theta=0.0
% INFO    : Bus 21678	: V=1.0220263, theta=-62.734475 -> V=1.0, theta=0.0
% INFO    : Bus 21679	: V=1.0221493, theta=-62.921879 -> V=1.0, theta=0.0
% INFO    : Bus 21680	: V=1.020754, theta=-64.303199 -> V=1.0, theta=0.0
% INFO    : Bus 21681	: V=1.0122942, theta=-61.159784 -> V=1.0, theta=0.0
% INFO    : Bus 21682	: V=1.0218502, theta=-62.93231 -> V=1.0, theta=0.0
% INFO    : Bus 21683	: V=1.0221493, theta=-62.921879 -> V=1.0, theta=0.0
% INFO    : Bus 21684	: V=1.028252, theta=-60.415446 -> V=1.0, theta=0.0
% INFO    : Bus 21685	: V=1.0118966, theta=-64.98028 -> V=1.0, theta=0.0
% INFO    : Bus 21686	: V=1.0189754, theta=-69.736 -> V=1.0, theta=0.0
% INFO    : Bus 21687	: V=1.0020717, theta=-69.722616 -> V=1.0, theta=0.0
% INFO    : Bus 21688	: V=1.0020717, theta=-69.722616 -> V=1.0, theta=0.0
% INFO    : Bus 21689	: V=1.0433571, theta=-59.491122 -> V=1.0, theta=0.0
% INFO    : Bus 21690	: V=1.0443644, theta=-59.385202 -> V=1.0, theta=0.0
% INFO    : Bus 21691	: V=1.0458757, theta=-59.219061 -> V=1.0, theta=0.0
% INFO    : Bus 21692	: V=1.0205568, theta=-64.362627 -> V=1.0, theta=0.0
% INFO    : Bus 21693	: V=1.0205568, theta=-64.362627 -> V=1.0, theta=0.0
% INFO    : Bus 21694	: V=1.0184317, theta=-67.120362 -> V=1.0, theta=0.0
% INFO    : Bus 21695	: V=1.0175651, theta=-67.176194 -> V=1.0, theta=0.0
% INFO    : Bus 21696	: V=1.0184317, theta=-67.120362 -> V=1.0, theta=0.0
% INFO    : Bus 21697	: V=1.0184317, theta=-67.120362 -> V=1.0, theta=0.0
% INFO    : Bus 21698	: V=1.0193054, theta=-63.777244 -> V=1.0, theta=0.0
% INFO    : Bus 21699	: V=1.0143, theta=-66.005769 -> V=1.0, theta=0.0
% INFO    : Bus 21700	: V=1.01626, theta=-63.668129 -> V=1.0, theta=0.0
% INFO    : Bus 21701	: V=1.017256, theta=-65.91946 -> V=1.0, theta=0.0
% INFO    : Bus 21702	: V=1.0168548, theta=-62.231088 -> V=1.0, theta=0.0
% INFO    : Bus 21703	: V=1.0167941, theta=-62.093625 -> V=1.0, theta=0.0
% INFO    : Bus 21704	: V=1.0168777, theta=-62.25471 -> V=1.0, theta=0.0
% INFO    : Bus 21705	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21706	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21707	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21708	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21709	: V=1.0242763, theta=-67.492764 -> V=1.0, theta=0.0
% INFO    : Bus 21710	: V=1.0242733, theta=-67.492755 -> V=1.0, theta=0.0
% INFO    : Bus 21711	: V=1.0113036, theta=-68.844777 -> V=1.0, theta=0.0
% INFO    : Bus 21712	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21713	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21714	: V=1.0046025, theta=-68.88202 -> V=1.0, theta=0.0
% INFO    : Bus 21715	: V=1.0041655, theta=-68.914094 -> V=1.0, theta=0.0
% INFO    : Bus 21716	: V=1.02312, theta=-65.353713 -> V=1.0, theta=0.0
% INFO    : Bus 21717	: V=1.0152931, theta=-67.483651 -> V=1.0, theta=0.0
% INFO    : Bus 21718	: V=1.0398946, theta=-63.410237 -> V=1.0, theta=0.0
% INFO    : Bus 21719	: V=1.0428446, theta=-65.25113 -> V=1.0, theta=0.0
% INFO    : Bus 21720	: V=1.0088233, theta=-70.260614 -> V=1.0, theta=0.0
% INFO    : Bus 21721	: V=1.008547, theta=-70.279604 -> V=1.0, theta=0.0
% INFO    : Bus 21722	: V=1.0182199, theta=-64.607656 -> V=1.0, theta=0.0
% INFO    : Bus 21723	: V=1.0151887, theta=-67.344123 -> V=1.0, theta=0.0
% INFO    : Bus 21724	: V=1.0162021, theta=-66.170959 -> V=1.0, theta=0.0
% INFO    : Bus 21725	: V=1.0162021, theta=-66.170959 -> V=1.0, theta=0.0
% INFO    : Bus 21726	: V=0.989882, theta=-61.976336 -> V=1.0, theta=0.0
% INFO    : Bus 21727	: V=1.0161546, theta=-61.45822 -> V=1.0, theta=0.0
% INFO    : Bus 21728	: V=1.0262408, theta=-63.748687 -> V=1.0, theta=0.0
% INFO    : Bus 21729	: V=1.0292823, theta=-66.853959 -> V=1.0, theta=0.0
% INFO    : Bus 21730	: V=1.0239659, theta=-60.608434 -> V=1.0, theta=0.0
% INFO    : Bus 21731	: V=1.0308493, theta=-59.832879 -> V=1.0, theta=0.0
% INFO    : Bus 21732	: V=1.0237149, theta=-60.638636 -> V=1.0, theta=0.0
% INFO    : Bus 21733	: V=0.9974685, theta=-66.427136 -> V=1.0, theta=0.0
% INFO    : Bus 21734	: V=1.0313153, theta=-70.162132 -> V=1.0, theta=0.0
% INFO    : Bus 21735	: V=0.9830545, theta=-65.313819 -> V=1.0, theta=0.0
% INFO    : Bus 21736	: V=0.9974685, theta=-66.427136 -> V=1.0, theta=0.0
% INFO    : Bus 21737	: V=0.9831313, theta=-65.309589 -> V=1.0, theta=0.0
% INFO    : Bus 21738	: V=0.9974685, theta=-66.427136 -> V=1.0, theta=0.0
% INFO    : Bus 21739	: V=0.9825958, theta=-64.65742 -> V=1.0, theta=0.0
% INFO    : Bus 21740	: V=0.9974685, theta=-66.427136 -> V=1.0, theta=0.0
% INFO    : Bus 21741	: V=1.0002433, theta=-66.370466 -> V=1.0, theta=0.0
% INFO    : Bus 21742	: V=1.0163336, theta=-63.901026 -> V=1.0, theta=0.0
% INFO    : Bus 21743	: V=1.018624, theta=-65.704123 -> V=1.0, theta=0.0
% INFO    : Bus 21744	: V=1.0182199, theta=-65.407762 -> V=1.0, theta=0.0
% INFO    : Bus 21745	: V=1.0154129, theta=-68.288852 -> V=1.0, theta=0.0
% INFO    : Bus 21746	: V=1.0175143, theta=-65.933666 -> V=1.0, theta=0.0
% INFO    : Bus 21747	: V=1.0175143, theta=-65.933666 -> V=1.0, theta=0.0
% INFO    : Bus 21748	: V=1.020358, theta=-65.05878 -> V=1.0, theta=0.0
% INFO    : Bus 21749	: V=1.020358, theta=-65.05878 -> V=1.0, theta=0.0
% INFO    : Bus 21750	: V=1.0186061, theta=-65.355186 -> V=1.0, theta=0.0
% INFO    : Bus 21751	: V=1.0180602, theta=-65.368652 -> V=1.0, theta=0.0
% INFO    : Bus 21752	: V=1.0182199, theta=-65.407762 -> V=1.0, theta=0.0
% INFO    : Bus 21753	: V=1.0130894, theta=-65.760003 -> V=1.0, theta=0.0
% INFO    : Bus 21754	: V=1.0185797, theta=-67.996792 -> V=1.0, theta=0.0
% INFO    : Bus 21755	: V=1.0128538, theta=-68.051366 -> V=1.0, theta=0.0
% INFO    : Bus 21756	: V=1.0128538, theta=-68.051366 -> V=1.0, theta=0.0
% INFO    : Bus 21757	: V=1.022731, theta=-60.950149 -> V=1.0, theta=0.0
% INFO    : Bus 21758	: V=1.0109125, theta=-70.263718 -> V=1.0, theta=0.0
% INFO    : Bus 21759	: V=1.0239714, theta=-64.952764 -> V=1.0, theta=0.0
% INFO    : Bus 21760	: V=0.973044, theta=-62.579314 -> V=1.0, theta=0.0
% INFO    : Bus 23000	: V=1.0298358, theta=-70.140305 -> V=1.0, theta=0.0
% INFO    : Bus 23001	: V=1.0277744, theta=-70.55189 -> V=1.0, theta=0.0
% INFO    : Bus 23002	: V=1.0271228, theta=-70.613962 -> V=1.0, theta=0.0
% INFO    : Bus 23003	: V=1.0297079, theta=-70.470537 -> V=1.0, theta=0.0
% INFO    : Bus 23004	: V=1.0406641, theta=-69.392091 -> V=1.0, theta=0.0
% INFO    : Bus 23005	: V=1.0355026, theta=-69.325922 -> V=1.0, theta=0.0
% INFO    : Bus 23006	: V=1.0356651, theta=-69.303472 -> V=1.0, theta=0.0
% INFO    : Bus 23007	: V=1.0353327, theta=-69.346916 -> V=1.0, theta=0.0
% INFO    : Bus 23008	: V=1.0221246, theta=-69.599265 -> V=1.0, theta=0.0
% INFO    : Bus 23009	: V=1.0159051, theta=-69.98457 -> V=1.0, theta=0.0
% INFO    : Bus 23010	: V=1.0244228, theta=-69.516501 -> V=1.0, theta=0.0
% INFO    : Bus 23011	: V=1.0327376, theta=-70.220753 -> V=1.0, theta=0.0
% INFO    : Bus 23012	: V=1.0218676, theta=-68.995483 -> V=1.0, theta=0.0
% INFO    : Bus 23013	: V=1.0253803, theta=-70.946479 -> V=1.0, theta=0.0
% INFO    : Bus 23014	: V=1.0407442, theta=-69.580665 -> V=1.0, theta=0.0
% INFO    : Bus 23015	: V=1.0273323, theta=-70.521002 -> V=1.0, theta=0.0
% INFO    : Bus 23016	: V=1.0080202, theta=-64.700704 -> V=1.0, theta=0.0
% INFO    : Bus 23017	: V=1.0463205, theta=-68.967024 -> V=1.0, theta=0.0
% INFO    : Bus 23018	: V=1.0251515, theta=-70.868059 -> V=1.0, theta=0.0
% INFO    : Bus 23019	: V=1.0059161, theta=-67.434964 -> V=1.0, theta=0.0
% INFO    : Bus 23020	: V=1.0056817, theta=-67.46125 -> V=1.0, theta=0.0
% INFO    : Bus 23021	: V=1.0054026, theta=-67.50328 -> V=1.0, theta=0.0
% INFO    : Bus 23022	: V=1.0123857, theta=-66.863332 -> V=1.0, theta=0.0
% INFO    : Bus 23023	: V=1.0111361, theta=-67.651737 -> V=1.0, theta=0.0
% INFO    : Bus 23024	: V=1.0089485, theta=-67.014862 -> V=1.0, theta=0.0
% INFO    : Bus 23025	: V=1.0287278, theta=-67.942766 -> V=1.0, theta=0.0
% INFO    : Bus 23026	: V=1.0288604, theta=-67.923595 -> V=1.0, theta=0.0
% INFO    : Bus 23027	: V=1.0208057, theta=-65.966853 -> V=1.0, theta=0.0
% INFO    : Bus 23028	: V=1.0208057, theta=-65.966853 -> V=1.0, theta=0.0
% INFO    : Bus 23029	: V=1.0208057, theta=-65.966853 -> V=1.0, theta=0.0
% INFO    : Bus 23030	: V=1.0208057, theta=-65.966853 -> V=1.0, theta=0.0
% INFO    : Bus 23031	: V=1.020951, theta=-65.951421 -> V=1.0, theta=0.0
% INFO    : Bus 23032	: V=1.0135384, theta=-67.20321 -> V=1.0, theta=0.0
% INFO    : Bus 23033	: V=1.0133318, theta=-67.235969 -> V=1.0, theta=0.0
% INFO    : Bus 23034	: V=1.0089203, theta=-69.002218 -> V=1.0, theta=0.0
% INFO    : Bus 23035	: V=1.0085818, theta=-69.029139 -> V=1.0, theta=0.0
% INFO    : Bus 23036	: V=1.0081665, theta=-69.092148 -> V=1.0, theta=0.0
% INFO    : Bus 23037	: V=1.0228069, theta=-68.117682 -> V=1.0, theta=0.0
% INFO    : Bus 23038	: V=1.0227136, theta=-68.131804 -> V=1.0, theta=0.0
% INFO    : Bus 23039	: V=1.0227612, theta=-68.595034 -> V=1.0, theta=0.0
% INFO    : Bus 23040	: V=1.0115517, theta=-67.970197 -> V=1.0, theta=0.0
% INFO    : Bus 23041	: V=1.0164439, theta=-66.673018 -> V=1.0, theta=0.0
% INFO    : Bus 23042	: V=1.0134251, theta=-67.259414 -> V=1.0, theta=0.0
% INFO    : Bus 23043	: V=1.0143019, theta=-67.799808 -> V=1.0, theta=0.0
% INFO    : Bus 23044	: V=1.0161296, theta=-67.37765 -> V=1.0, theta=0.0
% INFO    : Bus 23045	: V=1.0159819, theta=-67.39227 -> V=1.0, theta=0.0
% INFO    : Bus 23046	: V=1.0109166, theta=-66.891269 -> V=1.0, theta=0.0
% INFO    : Bus 23047	: V=1.0107382, theta=-66.909638 -> V=1.0, theta=0.0
% INFO    : Bus 23048	: V=1.0251048, theta=-67.620992 -> V=1.0, theta=0.0
% INFO    : Bus 23049	: V=1.0223832, theta=-69.461488 -> V=1.0, theta=0.0
% INFO    : Bus 23050	: V=1.0214149, theta=-69.498862 -> V=1.0, theta=0.0
% INFO    : Bus 23051	: V=1.0244682, theta=-67.944358 -> V=1.0, theta=0.0
% INFO    : Bus 23052	: V=1.0191319, theta=-66.849163 -> V=1.0, theta=0.0
% INFO    : Bus 23053	: V=1.0193316, theta=-66.831251 -> V=1.0, theta=0.0
% INFO    : Bus 23054	: V=1.0070849, theta=-67.260535 -> V=1.0, theta=0.0
% INFO    : Bus 23055	: V=1.0089962, theta=-67.025863 -> V=1.0, theta=0.0
% INFO    : Bus 23056	: V=1.0090987, theta=-67.010162 -> V=1.0, theta=0.0
% INFO    : Bus 23057	: V=1.0089028, theta=-67.04253 -> V=1.0, theta=0.0
% INFO    : Bus 23058	: V=1.0185931, theta=-66.409303 -> V=1.0, theta=0.0
% INFO    : Bus 23059	: V=1.01506, theta=-67.00161 -> V=1.0, theta=0.0
% INFO    : Bus 23060	: V=1.0120505, theta=-66.721324 -> V=1.0, theta=0.0
% INFO    : Bus 23061	: V=1.005438, theta=-67.78292 -> V=1.0, theta=0.0
% INFO    : Bus 23062	: V=1.0117651, theta=-67.287011 -> V=1.0, theta=0.0
% INFO    : Bus 23063	: V=1.0119615, theta=-67.266612 -> V=1.0, theta=0.0
% INFO    : Bus 23064	: V=1.0115555, theta=-67.308067 -> V=1.0, theta=0.0
% INFO    : Bus 23065	: V=1.0126613, theta=-68.14659 -> V=1.0, theta=0.0
% INFO    : Bus 23066	: V=1.0122113, theta=-68.191259 -> V=1.0, theta=0.0
% INFO    : Bus 23067	: V=1.0130764, theta=-68.106525 -> V=1.0, theta=0.0
% INFO    : Bus 23068	: V=1.0073951, theta=-67.563154 -> V=1.0, theta=0.0
% INFO    : Bus 23069	: V=1.0074853, theta=-67.549811 -> V=1.0, theta=0.0
% INFO    : Bus 23070	: V=1.0330658, theta=-68.010368 -> V=1.0, theta=0.0
% INFO    : Bus 23071	: V=1.0322216, theta=-67.969638 -> V=1.0, theta=0.0
% INFO    : Bus 23072	: V=1.0179162, theta=-64.233305 -> V=1.0, theta=0.0
% INFO    : Bus 23073	: V=1.0176589, theta=-64.256727 -> V=1.0, theta=0.0
% INFO    : Bus 23074	: V=1.0117399, theta=-65.798135 -> V=1.0, theta=0.0
% INFO    : Bus 23075	: V=1.011019, theta=-66.191144 -> V=1.0, theta=0.0
% INFO    : Bus 23076	: V=1.0133326, theta=-67.118008 -> V=1.0, theta=0.0
% INFO    : Bus 23077	: V=1.0132369, theta=-67.135966 -> V=1.0, theta=0.0
% INFO    : Bus 23078	: V=1.0146866, theta=-66.547332 -> V=1.0, theta=0.0
% INFO    : Bus 23079	: V=1.0106052, theta=-66.042543 -> V=1.0, theta=0.0
% INFO    : Bus 23080	: V=1.0103721, theta=-66.073917 -> V=1.0, theta=0.0
% INFO    : Bus 23081	: V=1.0346249, theta=-67.358778 -> V=1.0, theta=0.0
% INFO    : Bus 23082	: V=1.0344792, theta=-67.376618 -> V=1.0, theta=0.0
% INFO    : Bus 23083	: V=1.0119883, theta=-66.343605 -> V=1.0, theta=0.0
% INFO    : Bus 23084	: V=1.0122564, theta=-66.351518 -> V=1.0, theta=0.0
% INFO    : Bus 23085	: V=1.0119197, theta=-66.389858 -> V=1.0, theta=0.0
% INFO    : Bus 23086	: V=1.0126427, theta=-66.311716 -> V=1.0, theta=0.0
% INFO    : Bus 23087	: V=1.0094177, theta=-68.211457 -> V=1.0, theta=0.0
% INFO    : Bus 23088	: V=1.0095743, theta=-68.198286 -> V=1.0, theta=0.0
% INFO    : Bus 23089	: V=1.0102122, theta=-66.198388 -> V=1.0, theta=0.0
% INFO    : Bus 23090	: V=1.0100405, theta=-66.222679 -> V=1.0, theta=0.0
% INFO    : Bus 23091	: V=1.0153322, theta=-66.667955 -> V=1.0, theta=0.0
% INFO    : Bus 23092	: V=1.0260799, theta=-63.599653 -> V=1.0, theta=0.0
% INFO    : Bus 23093	: V=1.0115575, theta=-66.596879 -> V=1.0, theta=0.0
% INFO    : Bus 23094	: V=1.0104215, theta=-66.247842 -> V=1.0, theta=0.0
% INFO    : Bus 23095	: V=1.0114128, theta=-65.81255 -> V=1.0, theta=0.0
% INFO    : Bus 23096	: V=1.011023, theta=-65.856882 -> V=1.0, theta=0.0
% INFO    : Bus 23097	: V=1.0118232, theta=-65.771556 -> V=1.0, theta=0.0
% INFO    : Bus 23098	: V=1.010274, theta=-66.663382 -> V=1.0, theta=0.0
% INFO    : Bus 23099	: V=1.0097596, theta=-66.707298 -> V=1.0, theta=0.0
% INFO    : Bus 23100	: V=1.0107333, theta=-66.619867 -> V=1.0, theta=0.0
% INFO    : Bus 23101	: V=1.0127045, theta=-65.435681 -> V=1.0, theta=0.0
% INFO    : Bus 23102	: V=1.0130501, theta=-65.411759 -> V=1.0, theta=0.0
% INFO    : Bus 23103	: V=1.0100749, theta=-66.63554 -> V=1.0, theta=0.0
% INFO    : Bus 23104	: V=1.0108119, theta=-66.568115 -> V=1.0, theta=0.0
% INFO    : Bus 23105	: V=1.0123696, theta=-65.65546 -> V=1.0, theta=0.0
% INFO    : Bus 23106	: V=1.010133, theta=-66.187023 -> V=1.0, theta=0.0
% INFO    : Bus 23107	: V=1.0103555, theta=-66.166864 -> V=1.0, theta=0.0
% INFO    : Bus 23108	: V=1.0120823, theta=-66.031648 -> V=1.0, theta=0.0
% INFO    : Bus 23109	: V=1.0224927, theta=-63.996743 -> V=1.0, theta=0.0
% INFO    : Bus 23110	: V=1.0057664, theta=-67.326386 -> V=1.0, theta=0.0
% INFO    : Bus 23111	: V=1.0055884, theta=-67.483167 -> V=1.0, theta=0.0
% INFO    : Bus 23112	: V=1.0090645, theta=-66.544005 -> V=1.0, theta=0.0
% INFO    : Bus 23113	: V=1.009003, theta=-66.55767 -> V=1.0, theta=0.0
% INFO    : Bus 23114	: V=1.0241888, theta=-64.280345 -> V=1.0, theta=0.0
% INFO    : Bus 23115	: V=1.024031, theta=-64.295443 -> V=1.0, theta=0.0
% INFO    : Bus 23116	: V=1.0126052, theta=-65.839895 -> V=1.0, theta=0.0
% INFO    : Bus 23117	: V=1.0122431, theta=-65.874621 -> V=1.0, theta=0.0
% INFO    : Bus 23118	: V=1.0129935, theta=-65.804365 -> V=1.0, theta=0.0
% INFO    : Bus 23119	: V=1.0077337, theta=-67.738047 -> V=1.0, theta=0.0
% INFO    : Bus 23120	: V=1.0090256, theta=-66.523791 -> V=1.0, theta=0.0
% INFO    : Bus 23121	: V=1.0116571, theta=-66.927113 -> V=1.0, theta=0.0
% INFO    : Bus 23122	: V=1.0114247, theta=-66.944937 -> V=1.0, theta=0.0
% INFO    : Bus 23123	: V=1.023287, theta=-63.63864 -> V=1.0, theta=0.0
% INFO    : Bus 23124	: V=1.0141391, theta=-65.957127 -> V=1.0, theta=0.0
% INFO    : Bus 23125	: V=1.0175678, theta=-66.601429 -> V=1.0, theta=0.0
% INFO    : Bus 23126	: V=1.024414, theta=-63.358304 -> V=1.0, theta=0.0
% INFO    : Bus 23127	: V=1.0186052, theta=-65.735011 -> V=1.0, theta=0.0
% INFO    : Bus 23128	: V=1.0035589, theta=-68.171977 -> V=1.0, theta=0.0
% INFO    : Bus 23129	: V=1.0197227, theta=-65.932049 -> V=1.0, theta=0.0
% INFO    : Bus 23130	: V=1.0217068, theta=-66.388653 -> V=1.0, theta=0.0
% INFO    : Bus 23131	: V=1.0093699, theta=-67.346608 -> V=1.0, theta=0.0
% INFO    : Bus 23132	: V=1.0077129, theta=-67.675654 -> V=1.0, theta=0.0
% INFO    : Bus 23133	: V=1.0075261, theta=-67.691954 -> V=1.0, theta=0.0
% INFO    : Bus 23134	: V=1.0151311, theta=-66.532925 -> V=1.0, theta=0.0
% INFO    : Bus 23135	: V=1.0150157, theta=-66.550582 -> V=1.0, theta=0.0
% INFO    : Bus 23136	: V=1.0212544, theta=-63.222708 -> V=1.0, theta=0.0
% INFO    : Bus 23137	: V=1.0263896, theta=-66.159101 -> V=1.0, theta=0.0
% INFO    : Bus 23138	: V=1.0395448, theta=-66.461194 -> V=1.0, theta=0.0
% INFO    : Bus 23139	: V=1.0100884, theta=-66.798586 -> V=1.0, theta=0.0
% INFO    : Bus 23140	: V=1.0100817, theta=-66.455718 -> V=1.0, theta=0.0
% INFO    : Bus 23141	: V=1.0100817, theta=-66.455718 -> V=1.0, theta=0.0
% INFO    : Bus 23142	: V=1.0100817, theta=-66.455718 -> V=1.0, theta=0.0
% INFO    : Bus 23143	: V=1.0100817, theta=-66.455718 -> V=1.0, theta=0.0
% INFO    : Bus 23144	: V=1.0410512, theta=-63.385298 -> V=1.0, theta=0.0
% INFO    : Bus 23145	: V=1.0211439, theta=-63.764053 -> V=1.0, theta=0.0
% INFO    : Bus 23146	: V=1.018846, theta=-63.233883 -> V=1.0, theta=0.0
% INFO    : Bus 23147	: V=1.0183139, theta=-66.521663 -> V=1.0, theta=0.0
% INFO    : Bus 23148	: V=1.0110207, theta=-67.697659 -> V=1.0, theta=0.0
% INFO    : Bus 23149	: V=1.0107874, theta=-67.722241 -> V=1.0, theta=0.0
% INFO    : Bus 23150	: V=1.0111012, theta=-68.147299 -> V=1.0, theta=0.0
% INFO    : Bus 23151	: V=1.0109727, theta=-68.009925 -> V=1.0, theta=0.0
% INFO    : Bus 23152	: V=1.0111751, theta=-67.992518 -> V=1.0, theta=0.0
% INFO    : Bus 23153	: V=1.0142405, theta=-68.222975 -> V=1.0, theta=0.0
% INFO    : Bus 23154	: V=1.0371941, theta=-67.621016 -> V=1.0, theta=0.0
% INFO    : Bus 23155	: V=1.0185988, theta=-68.481655 -> V=1.0, theta=0.0
% INFO    : Bus 23156	: V=1.0183985, theta=-68.509086 -> V=1.0, theta=0.0
% INFO    : Bus 23157	: V=1.0164065, theta=-65.837912 -> V=1.0, theta=0.0
% INFO    : Bus 23158	: V=1.0212782, theta=-68.297933 -> V=1.0, theta=0.0
% INFO    : Bus 23159	: V=1.0175288, theta=-65.762732 -> V=1.0, theta=0.0
% INFO    : Bus 23160	: V=1.0180727, theta=-65.673129 -> V=1.0, theta=0.0
% INFO    : Bus 23161	: V=1.0182034, theta=-68.527827 -> V=1.0, theta=0.0
% INFO    : Bus 23162	: V=1.0106437, theta=-68.450833 -> V=1.0, theta=0.0
% INFO    : Bus 23163	: V=1.011968, theta=-68.094359 -> V=1.0, theta=0.0
% INFO    : Bus 23164	: V=1.0117298, theta=-68.114866 -> V=1.0, theta=0.0
% INFO    : Bus 23165	: V=1.0053869, theta=-69.642679 -> V=1.0, theta=0.0
% INFO    : Bus 23166	: V=1.0052256, theta=-69.672408 -> V=1.0, theta=0.0
% INFO    : Bus 23167	: V=1.0064895, theta=-68.318391 -> V=1.0, theta=0.0
% INFO    : Bus 23168	: V=1.0042402, theta=-68.765622 -> V=1.0, theta=0.0
% INFO    : Bus 23169	: V=1.0046584, theta=-68.723884 -> V=1.0, theta=0.0
% INFO    : Bus 23170	: V=1.0083373, theta=-67.994506 -> V=1.0, theta=0.0
% INFO    : Bus 23171	: V=1.0082373, theta=-68.007527 -> V=1.0, theta=0.0
% INFO    : Bus 23172	: V=1.009469, theta=-67.872443 -> V=1.0, theta=0.0
% INFO    : Bus 23173	: V=1.010123, theta=-67.322174 -> V=1.0, theta=0.0
% INFO    : Bus 23174	: V=1.0327404, theta=-67.657739 -> V=1.0, theta=0.0
% INFO    : Bus 23175	: V=1.0283212, theta=-68.2135 -> V=1.0, theta=0.0
% INFO    : Bus 23176	: V=1.028165, theta=-68.232826 -> V=1.0, theta=0.0
% INFO    : Bus 23177	: V=1.0104751, theta=-69.271453 -> V=1.0, theta=0.0
% INFO    : Bus 23178	: V=1.0102424, theta=-69.287941 -> V=1.0, theta=0.0
% INFO    : Bus 23179	: V=1.0073064, theta=-68.282357 -> V=1.0, theta=0.0
% INFO    : Bus 23180	: V=1.0025024, theta=-69.617324 -> V=1.0, theta=0.0
% INFO    : Bus 23181	: V=1.002059, theta=-69.035895 -> V=1.0, theta=0.0
% INFO    : Bus 23182	: V=1.0017319, theta=-69.212689 -> V=1.0, theta=0.0
% INFO    : Bus 23183	: V=1.00903, theta=-68.087631 -> V=1.0, theta=0.0
% INFO    : Bus 23184	: V=1.0190818, theta=-66.11986 -> V=1.0, theta=0.0
% INFO    : Bus 23185	: V=1.0099798, theta=-67.888273 -> V=1.0, theta=0.0
% INFO    : Bus 23186	: V=1.0119562, theta=-67.485049 -> V=1.0, theta=0.0
% INFO    : Bus 23187	: V=1.0119562, theta=-67.485049 -> V=1.0, theta=0.0
% INFO    : Bus 23188	: V=1.0186072, theta=-66.156756 -> V=1.0, theta=0.0
% INFO    : Bus 23189	: V=1.0011364, theta=-68.792154 -> V=1.0, theta=0.0
% INFO    : Bus 23190	: V=1.016881, theta=-66.977008 -> V=1.0, theta=0.0
% INFO    : Bus 23191	: V=1.0007976, theta=-68.91273 -> V=1.0, theta=0.0
% INFO    : Bus 23192	: V=1.0005927, theta=-68.940502 -> V=1.0, theta=0.0
% INFO    : Bus 23193	: V=1.0003538, theta=-68.961235 -> V=1.0, theta=0.0
% INFO    : Bus 23194	: V=1.0101945, theta=-67.415112 -> V=1.0, theta=0.0
% INFO    : Bus 23195	: V=1.0063661, theta=-69.005835 -> V=1.0, theta=0.0
% INFO    : Bus 23196	: V=1.006104, theta=-69.038305 -> V=1.0, theta=0.0
% INFO    : Bus 23197	: V=1.0066527, theta=-68.972457 -> V=1.0, theta=0.0
% INFO    : Bus 23198	: V=1.006709, theta=-68.239743 -> V=1.0, theta=0.0
% INFO    : Bus 23199	: V=1.0063446, theta=-68.256166 -> V=1.0, theta=0.0
% INFO    : Bus 23200	: V=1.0070594, theta=-68.220605 -> V=1.0, theta=0.0
% INFO    : Bus 23201	: V=0.9996317, theta=-68.98434 -> V=1.0, theta=0.0
% INFO    : Bus 23202	: V=1.0135132, theta=-67.844235 -> V=1.0, theta=0.0
% INFO    : Bus 23203	: V=1.0131274, theta=-67.878173 -> V=1.0, theta=0.0
% INFO    : Bus 23204	: V=1.0050532, theta=-68.528862 -> V=1.0, theta=0.0
% INFO    : Bus 23205	: V=1.0047107, theta=-68.56487 -> V=1.0, theta=0.0
% INFO    : Bus 23206	: V=1.0081914, theta=-67.723527 -> V=1.0, theta=0.0
% INFO    : Bus 23207	: V=1.0079348, theta=-67.747999 -> V=1.0, theta=0.0
% INFO    : Bus 23208	: V=1.0026701, theta=-68.475092 -> V=1.0, theta=0.0
% INFO    : Bus 23209	: V=1.0028653, theta=-68.45285 -> V=1.0, theta=0.0
% INFO    : Bus 23210	: V=1.007278, theta=-68.845947 -> V=1.0, theta=0.0
% INFO    : Bus 23211	: V=1.0070561, theta=-68.860752 -> V=1.0, theta=0.0
% INFO    : Bus 23212	: V=1.0133031, theta=-68.033518 -> V=1.0, theta=0.0
% INFO    : Bus 23213	: V=1.0416708, theta=-62.701414 -> V=1.0, theta=0.0
% INFO    : Bus 23214	: V=1.0417583, theta=-62.690801 -> V=1.0, theta=0.0
% INFO    : Bus 23215	: V=1.0340173, theta=-68.069973 -> V=1.0, theta=0.0
% INFO    : Bus 23216	: V=1.0154026, theta=-69.700584 -> V=1.0, theta=0.0
% INFO    : Bus 23217	: V=1.0058511, theta=-68.009965 -> V=1.0, theta=0.0
% INFO    : Bus 23218	: V=1.0088758, theta=-67.786323 -> V=1.0, theta=0.0
% INFO    : Bus 23219	: V=1.0086008, theta=-67.805478 -> V=1.0, theta=0.0
% INFO    : Bus 23220	: V=1.0166371, theta=-69.619689 -> V=1.0, theta=0.0
% INFO    : Bus 23221	: V=1.0197138, theta=-68.726054 -> V=1.0, theta=0.0
% INFO    : Bus 23222	: V=1.0123971, theta=-67.543105 -> V=1.0, theta=0.0
% INFO    : Bus 23223	: V=1.0133506, theta=-67.582202 -> V=1.0, theta=0.0
% INFO    : Bus 23224	: V=1.0112116, theta=-68.296246 -> V=1.0, theta=0.0
% INFO    : Bus 23225	: V=1.0169501, theta=-67.319298 -> V=1.0, theta=0.0
% INFO    : Bus 23226	: V=1.0168069, theta=-67.335278 -> V=1.0, theta=0.0
% INFO    : Bus 23227	: V=1.0132088, theta=-68.0891 -> V=1.0, theta=0.0
% INFO    : Bus 23228	: V=1.0239461, theta=-70.116226 -> V=1.0, theta=0.0
% INFO    : Bus 23229	: V=1.0242399, theta=-70.093898 -> V=1.0, theta=0.0
% INFO    : Bus 23230	: V=1.0215062, theta=-69.182665 -> V=1.0, theta=0.0
% INFO    : Bus 23231	: V=1.0219552, theta=-69.132056 -> V=1.0, theta=0.0
% INFO    : Bus 23232	: V=1.0201373, theta=-67.710331 -> V=1.0, theta=0.0
% INFO    : Bus 23233	: V=1.0336435, theta=-67.192187 -> V=1.0, theta=0.0
% INFO    : Bus 23234	: V=1.0292593, theta=-69.429371 -> V=1.0, theta=0.0
% INFO    : Bus 23235	: V=1.0251357, theta=-69.865442 -> V=1.0, theta=0.0
% INFO    : Bus 23236	: V=1.0248213, theta=-69.904334 -> V=1.0, theta=0.0
% INFO    : Bus 23237	: V=1.0292112, theta=-70.365195 -> V=1.0, theta=0.0
% INFO    : Bus 23238	: V=1.0136386, theta=-67.627516 -> V=1.0, theta=0.0
% INFO    : Bus 23239	: V=1.0137822, theta=-67.616763 -> V=1.0, theta=0.0
% INFO    : Bus 23240	: V=1.0343433, theta=-68.936209 -> V=1.0, theta=0.0
% INFO    : Bus 23241	: V=1.0344526, theta=-68.925833 -> V=1.0, theta=0.0
% INFO    : Bus 23242	: V=1.0245331, theta=-69.329301 -> V=1.0, theta=0.0
% INFO    : Bus 23243	: V=1.0218804, theta=-67.521659 -> V=1.0, theta=0.0
% INFO    : Bus 23244	: V=1.0238992, theta=-68.962806 -> V=1.0, theta=0.0
% INFO    : Bus 23245	: V=1.0239781, theta=-68.950935 -> V=1.0, theta=0.0
% INFO    : Bus 23246	: V=1.0238137, theta=-68.974374 -> V=1.0, theta=0.0
% INFO    : Bus 23247	: V=1.0168033, theta=-67.055091 -> V=1.0, theta=0.0
% INFO    : Bus 23248	: V=1.0218583, theta=-66.744583 -> V=1.0, theta=0.0
% INFO    : Bus 23249	: V=1.0225131, theta=-71.284274 -> V=1.0, theta=0.0
% INFO    : Bus 23250	: V=1.0253854, theta=-67.911377 -> V=1.0, theta=0.0
% INFO    : Bus 23251	: V=1.0230824, theta=-71.790531 -> V=1.0, theta=0.0
% INFO    : Bus 23252	: V=1.0230824, theta=-71.790531 -> V=1.0, theta=0.0
% INFO    : Bus 23253	: V=1.0230824, theta=-71.790531 -> V=1.0, theta=0.0
% INFO    : Bus 23254	: V=1.0230824, theta=-71.790531 -> V=1.0, theta=0.0
% INFO    : Bus 23255	: V=1.0282474, theta=-71.357035 -> V=1.0, theta=0.0
% INFO    : Bus 23256	: V=1.0279683, theta=-71.388713 -> V=1.0, theta=0.0
% INFO    : Bus 23257	: V=1.0289104, theta=-68.711755 -> V=1.0, theta=0.0
% INFO    : Bus 23258	: V=1.0331554, theta=-70.984037 -> V=1.0, theta=0.0
% INFO    : Bus 23259	: V=1.0286268, theta=-62.504948 -> V=1.0, theta=0.0
% INFO    : Bus 23260	: V=1.0287169, theta=-62.49385 -> V=1.0, theta=0.0
% INFO    : Bus 23261	: V=1.026017, theta=-62.709043 -> V=1.0, theta=0.0
% INFO    : Bus 23262	: V=1.0258413, theta=-62.724838 -> V=1.0, theta=0.0
% INFO    : Bus 23263	: V=1.0240098, theta=-63.02576 -> V=1.0, theta=0.0
% INFO    : Bus 23264	: V=1.0243111, theta=-62.792699 -> V=1.0, theta=0.0
% INFO    : Bus 23265	: V=1.0397461, theta=-66.322367 -> V=1.0, theta=0.0
% INFO    : Bus 23266	: V=1.0353585, theta=-67.475769 -> V=1.0, theta=0.0
% INFO    : Bus 23267	: V=1.0457315, theta=-65.716099 -> V=1.0, theta=0.0
% INFO    : Bus 23268	: V=1.0457315, theta=-65.716099 -> V=1.0, theta=0.0
% INFO    : Bus 23269	: V=1.0390279, theta=-66.415042 -> V=1.0, theta=0.0
% INFO    : Bus 23270	: V=1.0248248, theta=-65.496203 -> V=1.0, theta=0.0
% INFO    : Bus 23271	: V=1.0247632, theta=-65.544672 -> V=1.0, theta=0.0
% INFO    : Bus 23272	: V=1.0379141, theta=-61.408982 -> V=1.0, theta=0.0
% INFO    : Bus 23273	: V=1.0350065, theta=-62.030282 -> V=1.0, theta=0.0
% INFO    : Bus 23274	: V=1.0309664, theta=-62.960653 -> V=1.0, theta=0.0
% INFO    : Bus 23275	: V=1.0340539, theta=-62.238891 -> V=1.0, theta=0.0
% INFO    : Bus 23276	: V=1.038104, theta=-61.419012 -> V=1.0, theta=0.0
% INFO    : Bus 23277	: V=1.0260687, theta=-61.068069 -> V=1.0, theta=0.0
% INFO    : Bus 23278	: V=1.0304866, theta=-63.154184 -> V=1.0, theta=0.0
% INFO    : Bus 23279	: V=1.025979, theta=-61.074381 -> V=1.0, theta=0.0
% INFO    : Bus 23280	: V=1.0265916, theta=-60.969243 -> V=1.0, theta=0.0
% INFO    : Bus 23281	: V=1.0262678, theta=-63.300398 -> V=1.0, theta=0.0
% INFO    : Bus 23282	: V=1.0312443, theta=-67.887608 -> V=1.0, theta=0.0
% INFO    : Bus 23283	: V=1.0311178, theta=-67.916114 -> V=1.0, theta=0.0
% INFO    : Bus 23284	: V=1.02214, theta=-61.669369 -> V=1.0, theta=0.0
% INFO    : Bus 23285	: V=1.0294143, theta=-63.28764 -> V=1.0, theta=0.0
% INFO    : Bus 23286	: V=1.0308845, theta=-64.95312 -> V=1.0, theta=0.0
% INFO    : Bus 23287	: V=1.0222178, theta=-61.199358 -> V=1.0, theta=0.0
% INFO    : Bus 23288	: V=1.022242, theta=-61.052988 -> V=1.0, theta=0.0
% INFO    : Bus 23289	: V=1.0222355, theta=-60.839105 -> V=1.0, theta=0.0
% INFO    : Bus 23290	: V=1.0222311, theta=-61.13467 -> V=1.0, theta=0.0
% INFO    : Bus 23291	: V=1.0325576, theta=-64.139314 -> V=1.0, theta=0.0
% INFO    : Bus 23292	: V=1.0336496, theta=-64.469111 -> V=1.0, theta=0.0
% INFO    : Bus 23293	: V=0.968984, theta=-61.50233 -> V=1.0, theta=0.0
% INFO    : Bus 23294	: V=1.0336496, theta=-64.469111 -> V=1.0, theta=0.0
% INFO    : Bus 23295	: V=1.0268711, theta=-62.115842 -> V=1.0, theta=0.0
% INFO    : Bus 23296	: V=0.9890376, theta=-63.977311 -> V=1.0, theta=0.0
% INFO    : Bus 23297	: V=0.9890858, theta=-63.837108 -> V=1.0, theta=0.0
% INFO    : Bus 23298	: V=1.0463902, theta=-67.060681 -> V=1.0, theta=0.0
% INFO    : Bus 23299	: V=1.0462232, theta=-67.107933 -> V=1.0, theta=0.0
% INFO    : Bus 23300	: V=1.0385678, theta=-67.932681 -> V=1.0, theta=0.0
% INFO    : Bus 23301	: V=1.0366862, theta=-68.457022 -> V=1.0, theta=0.0
% INFO    : Bus 23302	: V=1.038795, theta=-67.114747 -> V=1.0, theta=0.0
% INFO    : Bus 23303	: V=1.0387134, theta=-67.309676 -> V=1.0, theta=0.0
% INFO    : Bus 23304	: V=0.9993412, theta=-64.941182 -> V=1.0, theta=0.0
% INFO    : Bus 23305	: V=1.0385678, theta=-67.932681 -> V=1.0, theta=0.0
% INFO    : Bus 23306	: V=1.038, theta=-63.188887 -> V=1.0, theta=0.0
% INFO    : Bus 23307	: V=1.0326798, theta=-64.948463 -> V=1.0, theta=0.0
% INFO    : Bus 23308	: V=1.0326564, theta=-64.957029 -> V=1.0, theta=0.0
% INFO    : Bus 23309	: V=1.0199109, theta=-62.137017 -> V=1.0, theta=0.0
% INFO    : Bus 23310	: V=1.0169686, theta=-66.341712 -> V=1.0, theta=0.0
% INFO    : Bus 23311	: V=1.035582, theta=-63.07199 -> V=1.0, theta=0.0
% INFO    : Bus 23312	: V=1.0400802, theta=-66.714424 -> V=1.0, theta=0.0
% INFO    : Bus 23313	: V=1.0406487, theta=-65.176076 -> V=1.0, theta=0.0
% INFO    : Bus 23314	: V=1.0400683, theta=-66.716253 -> V=1.0, theta=0.0
% INFO    : Bus 23315	: V=1.04, theta=-67.52107 -> V=1.0, theta=0.0
% INFO    : Bus 23316	: V=1.0398184, theta=-67.535407 -> V=1.0, theta=0.0
% INFO    : Bus 23317	: V=1.0399381, theta=-67.527049 -> V=1.0, theta=0.0
% INFO    : Bus 23318	: V=1.0143991, theta=-64.340246 -> V=1.0, theta=0.0
% INFO    : Bus 23319	: V=1.0350125, theta=-64.523862 -> V=1.0, theta=0.0
% INFO    : Bus 23320	: V=1.0385535, theta=-62.597695 -> V=1.0, theta=0.0
% INFO    : Bus 23321	: V=1.0449114, theta=-62.060745 -> V=1.0, theta=0.0
% INFO    : Bus 23322	: V=1.044416, theta=-61.587466 -> V=1.0, theta=0.0
% INFO    : Bus 23323	: V=1.0451912, theta=-62.748176 -> V=1.0, theta=0.0
% INFO    : Bus 23324	: V=1.0436849, theta=-60.301602 -> V=1.0, theta=0.0
% INFO    : Bus 23325	: V=1.0415565, theta=-59.875382 -> V=1.0, theta=0.0
% INFO    : Bus 23326	: V=1.0432311, theta=-59.964473 -> V=1.0, theta=0.0
% INFO    : Bus 23327	: V=1.0385463, theta=-62.598414 -> V=1.0, theta=0.0
% INFO    : Bus 23328	: V=1.0384564, theta=-62.64861 -> V=1.0, theta=0.0
% INFO    : Bus 23329	: V=1.04, theta=-64.446042 -> V=1.0, theta=0.0
% INFO    : Bus 23330	: V=1.0376402, theta=-66.835621 -> V=1.0, theta=0.0
% INFO    : Bus 23331	: V=1.0447871, theta=-67.4395 -> V=1.0, theta=0.0
% INFO    : Bus 23332	: V=1.045374, theta=-67.246543 -> V=1.0, theta=0.0
% INFO    : Bus 23333	: V=1.0448625, theta=-67.123379 -> V=1.0, theta=0.0
% INFO    : Bus 23334	: V=1.0447871, theta=-67.4395 -> V=1.0, theta=0.0
% INFO    : Bus 23335	: V=1.0454811, theta=-67.49665 -> V=1.0, theta=0.0
% INFO    : Bus 23336	: V=1.0333423, theta=-62.125726 -> V=1.0, theta=0.0
% INFO    : Bus 23337	: V=1.0375651, theta=-59.936873 -> V=1.0, theta=0.0
% INFO    : Bus 23338	: V=1.0388427, theta=-61.52212 -> V=1.0, theta=0.0
% INFO    : Bus 23339	: V=1.0390375, theta=-61.773192 -> V=1.0, theta=0.0
% INFO    : Bus 23340	: V=1.0224421, theta=-63.559717 -> V=1.0, theta=0.0
% INFO    : Bus 23341	: V=1.0146533, theta=-65.906917 -> V=1.0, theta=0.0
% INFO    : Bus 23342	: V=0.9956509, theta=-68.812542 -> V=1.0, theta=0.0
% INFO    : Bus 23343	: V=1.0144168, theta=-66.841055 -> V=1.0, theta=0.0
% INFO    : Bus 23344	: V=1.0229195, theta=-63.51009 -> V=1.0, theta=0.0
% INFO    : Bus 23345	: V=1.0318533, theta=-65.477585 -> V=1.0, theta=0.0
% INFO    : Bus 23346	: V=1.0182028, theta=-67.470077 -> V=1.0, theta=0.0
% INFO    : Bus 23347	: V=1.0383852, theta=-61.768303 -> V=1.0, theta=0.0
% INFO    : Bus 23348	: V=1.0143, theta=-65.371171 -> V=1.0, theta=0.0
% INFO    : Bus 23349	: V=1.0137534, theta=-65.448354 -> V=1.0, theta=0.0
% INFO    : Bus 23350	: V=1.014197, theta=-65.667328 -> V=1.0, theta=0.0
% INFO    : Bus 23351	: V=0.9975459, theta=-63.500378 -> V=1.0, theta=0.0
% INFO    : Bus 23352	: V=0.9958467, theta=-63.660763 -> V=1.0, theta=0.0
% INFO    : Bus 23353	: V=1.0384497, theta=-62.749234 -> V=1.0, theta=0.0
% INFO    : Bus 23354	: V=1.0205217, theta=-65.444814 -> V=1.0, theta=0.0
% INFO    : Bus 23355	: V=1.0116249, theta=-66.890784 -> V=1.0, theta=0.0
% INFO    : Bus 23356	: V=0.9943894, theta=-69.123796 -> V=1.0, theta=0.0
% INFO    : Bus 23357	: V=1.0088719, theta=-67.6126 -> V=1.0, theta=0.0
% INFO    : Bus 23358	: V=1.0205052, theta=-65.439798 -> V=1.0, theta=0.0
% INFO    : Bus 23359	: V=1.0236463, theta=-68.581736 -> V=1.0, theta=0.0
% INFO    : Bus 23360	: V=1.0240155, theta=-64.229556 -> V=1.0, theta=0.0
% INFO    : Bus 23361	: V=1.0243075, theta=-66.463171 -> V=1.0, theta=0.0
% INFO    : Bus 23362	: V=1.0236037, theta=-68.59842 -> V=1.0, theta=0.0
% INFO    : Bus 23363	: V=1.0381307, theta=-62.068186 -> V=1.0, theta=0.0
% INFO    : Bus 23364	: V=1.03812, theta=-62.070008 -> V=1.0, theta=0.0
% INFO    : Bus 23365	: V=1.0309351, theta=-64.574324 -> V=1.0, theta=0.0
% INFO    : Bus 23366	: V=1.0255885, theta=-66.491421 -> V=1.0, theta=0.0
% INFO    : Bus 23367	: V=1.0255735, theta=-66.607316 -> V=1.0, theta=0.0
% INFO    : Bus 23368	: V=1.0261235, theta=-65.054667 -> V=1.0, theta=0.0
% INFO    : Bus 23369	: V=1.0255735, theta=-66.607316 -> V=1.0, theta=0.0
% INFO    : Bus 23370	: V=1.0348836, theta=-63.91632 -> V=1.0, theta=0.0
% INFO    : Bus 23371	: V=1.0349312, theta=-63.912679 -> V=1.0, theta=0.0
% INFO    : Bus 23372	: V=1.0390668, theta=-62.485812 -> V=1.0, theta=0.0
% INFO    : Bus 23373	: V=1.0388576, theta=-62.536528 -> V=1.0, theta=0.0
% INFO    : Bus 23374	: V=1.02312, theta=-60.003827 -> V=1.0, theta=0.0
% INFO    : Bus 23375	: V=1.0167223, theta=-63.751798 -> V=1.0, theta=0.0
% INFO    : Bus 23376	: V=1.0399317, theta=-68.500011 -> V=1.0, theta=0.0
% INFO    : Bus 23377	: V=1.0214623, theta=-59.086875 -> V=1.0, theta=0.0
% INFO    : Bus 23378	: V=1.02312, theta=-60.003827 -> V=1.0, theta=0.0
% INFO    : Bus 23379	: V=1.021589, theta=-59.19386 -> V=1.0, theta=0.0
% INFO    : Bus 23380	: V=1.0219635, theta=-59.38097 -> V=1.0, theta=0.0
% INFO    : Bus 23381	: V=1.0202565, theta=-58.561308 -> V=1.0, theta=0.0
% INFO    : Bus 23382	: V=1.0207208, theta=-58.879798 -> V=1.0, theta=0.0
% INFO    : Bus 23383	: V=1.0213136, theta=-59.06992 -> V=1.0, theta=0.0
% INFO    : Bus 23384	: V=1.0204985, theta=-58.673752 -> V=1.0, theta=0.0
% INFO    : Bus 23385	: V=1.0464402, theta=-67.130578 -> V=1.0, theta=0.0
% INFO    : Bus 23386	: V=1.0312033, theta=-64.882941 -> V=1.0, theta=0.0
% INFO    : Bus 23387	: V=1.0311314, theta=-64.910537 -> V=1.0, theta=0.0
% INFO    : Bus 23388	: V=1.0312033, theta=-64.882941 -> V=1.0, theta=0.0
% INFO    : Bus 23389	: V=1.0247032, theta=-63.128027 -> V=1.0, theta=0.0
% INFO    : Bus 23390	: V=1.023469, theta=-66.531462 -> V=1.0, theta=0.0
% INFO    : Bus 23391	: V=1.0168414, theta=-62.253708 -> V=1.0, theta=0.0
% INFO    : Bus 23392	: V=1.0264363, theta=-62.458592 -> V=1.0, theta=0.0
% INFO    : Bus 23393	: V=1.0213709, theta=-61.695309 -> V=1.0, theta=0.0
% INFO    : Bus 23394	: V=1.0182176, theta=-62.282194 -> V=1.0, theta=0.0
% INFO    : Bus 23395	: V=1.0243587, theta=-61.845803 -> V=1.0, theta=0.0
% INFO    : Bus 23396	: V=1.0243587, theta=-61.845803 -> V=1.0, theta=0.0
% INFO    : Bus 23397	: V=1.0243587, theta=-61.845803 -> V=1.0, theta=0.0
% INFO    : Bus 23398	: V=1.02214, theta=-66.574606 -> V=1.0, theta=0.0
% INFO    : Bus 23399	: V=1.0248164, theta=-63.79756 -> V=1.0, theta=0.0
% INFO    : Bus 23400	: V=1.0258869, theta=-62.789058 -> V=1.0, theta=0.0
% INFO    : Bus 23401	: V=1.0243927, theta=-64.048248 -> V=1.0, theta=0.0
% INFO    : Bus 23402	: V=1.0139039, theta=-66.844752 -> V=1.0, theta=0.0
% INFO    : Bus 23403	: V=1.004918, theta=-63.727375 -> V=1.0, theta=0.0
% INFO    : Bus 23404	: V=1.0138771, theta=-66.849892 -> V=1.0, theta=0.0
% INFO    : Bus 23405	: V=1.0374748, theta=-66.823357 -> V=1.0, theta=0.0
% INFO    : Bus 23406	: V=1.0169181, theta=-66.650948 -> V=1.0, theta=0.0
% INFO    : Bus 23407	: V=1.0069566, theta=-68.456084 -> V=1.0, theta=0.0
% INFO    : Bus 23408	: V=1.0174588, theta=-66.575434 -> V=1.0, theta=0.0
% INFO    : Bus 23409	: V=1.0390341, theta=-62.896261 -> V=1.0, theta=0.0
% INFO    : Bus 23410	: V=1.0387745, theta=-62.640812 -> V=1.0, theta=0.0
% INFO    : Bus 23411	: V=1.0473334, theta=-61.298435 -> V=1.0, theta=0.0
% INFO    : Bus 23412	: V=1.02508, theta=-59.734945 -> V=1.0, theta=0.0
% INFO    : Bus 23413	: V=1.031177, theta=-61.66946 -> V=1.0, theta=0.0
% INFO    : Bus 23414	: V=1.032685, theta=-63.124661 -> V=1.0, theta=0.0
% INFO    : Bus 23415	: V=1.025479, theta=-59.874729 -> V=1.0, theta=0.0
% INFO    : Bus 23416	: V=1.025479, theta=-59.874729 -> V=1.0, theta=0.0
% INFO    : Bus 23417	: V=1.0349383, theta=-58.43468 -> V=1.0, theta=0.0
% INFO    : Bus 23418	: V=1.0358529, theta=-57.65634 -> V=1.0, theta=0.0
% INFO    : Bus 23419	: V=1.0336646, theta=-58.816556 -> V=1.0, theta=0.0
% INFO    : Bus 23420	: V=1.0282547, theta=-59.952284 -> V=1.0, theta=0.0
% INFO    : Bus 23421	: V=1.014649, theta=-65.946088 -> V=1.0, theta=0.0
% INFO    : Bus 23422	: V=1.04, theta=-66.413252 -> V=1.0, theta=0.0
% INFO    : Bus 23423	: V=1.0177408, theta=-62.150379 -> V=1.0, theta=0.0
% INFO    : Bus 23424	: V=1.0172263, theta=-62.19281 -> V=1.0, theta=0.0
% INFO    : Bus 23425	: V=1.0399818, theta=-66.527156 -> V=1.0, theta=0.0
% INFO    : Bus 23426	: V=1.0363366, theta=-67.953588 -> V=1.0, theta=0.0
% INFO    : Bus 23427	: V=1.0336857, theta=-69.204935 -> V=1.0, theta=0.0
% INFO    : Bus 23428	: V=1.0336857, theta=-69.204935 -> V=1.0, theta=0.0
% INFO    : Bus 23429	: V=1.040148, theta=-66.520496 -> V=1.0, theta=0.0
% INFO    : Bus 23430	: V=1.0399818, theta=-66.527156 -> V=1.0, theta=0.0
% INFO    : Bus 23431	: V=1.0244234, theta=-59.023392 -> V=1.0, theta=0.0
% INFO    : Bus 23432	: V=1.0265406, theta=-62.12515 -> V=1.0, theta=0.0
% INFO    : Bus 23433	: V=1.0252028, theta=-65.519376 -> V=1.0, theta=0.0
% INFO    : Bus 23434	: V=1.0238755, theta=-58.347613 -> V=1.0, theta=0.0
% INFO    : Bus 23435	: V=1.0235552, theta=-58.46454 -> V=1.0, theta=0.0
% INFO    : Bus 23436	: V=1.0331744, theta=-63.954346 -> V=1.0, theta=0.0
% INFO    : Bus 23437	: V=1.0313937, theta=-65.867633 -> V=1.0, theta=0.0
% INFO    : Bus 23438	: V=1.0369415, theta=-66.902501 -> V=1.0, theta=0.0
% INFO    : Bus 23439	: V=1.0368077, theta=-66.939406 -> V=1.0, theta=0.0
% INFO    : Bus 23440	: V=1.0369415, theta=-66.902501 -> V=1.0, theta=0.0
% INFO    : Bus 23441	: V=1.0195619, theta=-66.609177 -> V=1.0, theta=0.0
% INFO    : Bus 23442	: V=1.0277987, theta=-60.263983 -> V=1.0, theta=0.0
% INFO    : Bus 23443	: V=1.0222235, theta=-62.256088 -> V=1.0, theta=0.0
% INFO    : Bus 23444	: V=1.0142028, theta=-65.599783 -> V=1.0, theta=0.0
% INFO    : Bus 23445	: V=0.9949908, theta=-59.783512 -> V=1.0, theta=0.0
% INFO    : Bus 23446	: V=0.9919644, theta=-59.451757 -> V=1.0, theta=0.0
% INFO    : Bus 23447	: V=0.9897214, theta=-59.703681 -> V=1.0, theta=0.0
% INFO    : Bus 23448	: V=1.0293271, theta=-60.253329 -> V=1.0, theta=0.0
% INFO    : Bus 23449	: V=1.0310396, theta=-64.931103 -> V=1.0, theta=0.0
% INFO    : Bus 23450	: V=1.0233268, theta=-59.243312 -> V=1.0, theta=0.0
% INFO    : Bus 23451	: V=1.0271209, theta=-60.821175 -> V=1.0, theta=0.0
% INFO    : Bus 23452	: V=1.0256843, theta=-62.221895 -> V=1.0, theta=0.0
% INFO    : Bus 23453	: V=1.0227526, theta=-58.789361 -> V=1.0, theta=0.0
% INFO    : Bus 23454	: V=1.0226954, theta=-58.521824 -> V=1.0, theta=0.0
% INFO    : Bus 23455	: V=1.0232726, theta=-59.188558 -> V=1.0, theta=0.0
% INFO    : Bus 23456	: V=1.0267917, theta=-60.495103 -> V=1.0, theta=0.0
% INFO    : Bus 23457	: V=1.0270729, theta=-59.238733 -> V=1.0, theta=0.0
% INFO    : Bus 23458	: V=1.0389123, theta=-62.515386 -> V=1.0, theta=0.0
% INFO    : Bus 23459	: V=1.0189202, theta=-61.193674 -> V=1.0, theta=0.0
% INFO    : Bus 23460	: V=1.0198716, theta=-62.606696 -> V=1.0, theta=0.0
% INFO    : Bus 23461	: V=1.0198716, theta=-62.606696 -> V=1.0, theta=0.0
% INFO    : Bus 23462	: V=1.0189734, theta=-61.567594 -> V=1.0, theta=0.0
% INFO    : Bus 23463	: V=1.0189626, theta=-61.628333 -> V=1.0, theta=0.0
% INFO    : Bus 23464	: V=1.0199909, theta=-62.701924 -> V=1.0, theta=0.0
% INFO    : Bus 23465	: V=1.0389123, theta=-62.515386 -> V=1.0, theta=0.0
% INFO    : Bus 23466	: V=1.0389123, theta=-62.515386 -> V=1.0, theta=0.0
% INFO    : Bus 23467	: V=1.0389123, theta=-62.515386 -> V=1.0, theta=0.0
% INFO    : Bus 23468	: V=1.0388546, theta=-62.537795 -> V=1.0, theta=0.0
% INFO    : Bus 23469	: V=1.022803, theta=-64.707965 -> V=1.0, theta=0.0
% INFO    : Bus 23470	: V=1.0392225, theta=-67.43074 -> V=1.0, theta=0.0
% INFO    : Bus 23471	: V=1.0361593, theta=-65.513883 -> V=1.0, theta=0.0
% INFO    : Bus 23472	: V=1.039196, theta=-67.453045 -> V=1.0, theta=0.0
% INFO    : Bus 23473	: V=1.02214, theta=-62.017305 -> V=1.0, theta=0.0
% INFO    : Bus 23474	: V=1.0132754, theta=-65.941509 -> V=1.0, theta=0.0
% INFO    : Bus 23475	: V=1.0114693, theta=-67.196813 -> V=1.0, theta=0.0
% INFO    : Bus 23476	: V=1.0114693, theta=-67.196813 -> V=1.0, theta=0.0
% INFO    : Bus 23477	: V=1.0025044, theta=-60.759928 -> V=1.0, theta=0.0
% INFO    : Bus 23478	: V=0.9934576, theta=-60.399481 -> V=1.0, theta=0.0
% INFO    : Bus 23479	: V=0.999653, theta=-61.753711 -> V=1.0, theta=0.0
% INFO    : Bus 23480	: V=1.0132754, theta=-65.941509 -> V=1.0, theta=0.0
% INFO    : Bus 23481	: V=1.0132754, theta=-65.941509 -> V=1.0, theta=0.0
% INFO    : Bus 23482	: V=1.0340153, theta=-62.87148 -> V=1.0, theta=0.0
% INFO    : Bus 23483	: V=1.0331243, theta=-64.416663 -> V=1.0, theta=0.0
% INFO    : Bus 23484	: V=1.0338317, theta=-62.507921 -> V=1.0, theta=0.0
% INFO    : Bus 23485	: V=1.033691, theta=-62.406025 -> V=1.0, theta=0.0
% INFO    : Bus 23486	: V=1.0340342, theta=-62.825325 -> V=1.0, theta=0.0
% INFO    : Bus 23487	: V=1.0314914, theta=-62.63631 -> V=1.0, theta=0.0
% INFO    : Bus 23488	: V=1.0341655, theta=-62.855783 -> V=1.0, theta=0.0
% INFO    : Bus 23489	: V=1.04958, theta=-62.656802 -> V=1.0, theta=0.0
% INFO    : Bus 23490	: V=0.9771521, theta=-61.929406 -> V=1.0, theta=0.0
% INFO    : Bus 23491	: V=0.9772721, theta=-61.377492 -> V=1.0, theta=0.0
% INFO    : Bus 23492	: V=0.9762625, theta=-62.7916 -> V=1.0, theta=0.0
% INFO    : Bus 23493	: V=1.0384797, theta=-62.623374 -> V=1.0, theta=0.0
% INFO    : Bus 23494	: V=1.0386013, theta=-62.954934 -> V=1.0, theta=0.0
% INFO    : Bus 23495	: V=1.0171954, theta=-67.886411 -> V=1.0, theta=0.0
% INFO    : Bus 23496	: V=1.0171238, theta=-67.890947 -> V=1.0, theta=0.0
% INFO    : Bus 23497	: V=1.0171954, theta=-67.886411 -> V=1.0, theta=0.0
% INFO    : Bus 23498	: V=1.0171954, theta=-67.886411 -> V=1.0, theta=0.0
% INFO    : Bus 23499	: V=1.031009, theta=-64.890502 -> V=1.0, theta=0.0
% INFO    : Bus 23500	: V=1.0297207, theta=-61.936696 -> V=1.0, theta=0.0
% INFO    : Bus 23501	: V=1.0240628, theta=-63.927755 -> V=1.0, theta=0.0
% INFO    : Bus 23502	: V=1.0297644, theta=-61.947786 -> V=1.0, theta=0.0
% INFO    : Bus 23503	: V=1.0292477, theta=-61.508023 -> V=1.0, theta=0.0
% INFO    : Bus 23504	: V=1.0297644, theta=-61.947786 -> V=1.0, theta=0.0
% INFO    : Bus 23505	: V=1.02606, theta=-57.822529 -> V=1.0, theta=0.0
% INFO    : Bus 23506	: V=1.0267355, theta=-59.335081 -> V=1.0, theta=0.0
% INFO    : Bus 23507	: V=1.0308681, theta=-60.486882 -> V=1.0, theta=0.0
% INFO    : Bus 23508	: V=1.0287823, theta=-61.373595 -> V=1.0, theta=0.0
% INFO    : Bus 23509	: V=1.0287823, theta=-61.373595 -> V=1.0, theta=0.0
% INFO    : Bus 23510	: V=1.0273625, theta=-56.85722 -> V=1.0, theta=0.0
% INFO    : Bus 23511	: V=1.0278262, theta=-56.464368 -> V=1.0, theta=0.0
% INFO    : Bus 23512	: V=1.0272803, theta=-57.365525 -> V=1.0, theta=0.0
% INFO    : Bus 23513	: V=1.02606, theta=-57.822529 -> V=1.0, theta=0.0
% INFO    : Bus 23514	: V=1.024974, theta=-57.963873 -> V=1.0, theta=0.0
% INFO    : Bus 23515	: V=1.02606, theta=-57.822529 -> V=1.0, theta=0.0
% INFO    : Bus 25000	: V=1.0355578, theta=-67.932656 -> V=1.0, theta=0.0
% INFO    : Bus 25001	: V=1.0310689, theta=-69.002137 -> V=1.0, theta=0.0
% INFO    : Bus 25002	: V=1.031111, theta=-69.055844 -> V=1.0, theta=0.0
% INFO    : Bus 25003	: V=1.0312008, theta=-68.951707 -> V=1.0, theta=0.0
% INFO    : Bus 25004	: V=1.033222, theta=-65.900872 -> V=1.0, theta=0.0
% INFO    : Bus 25005	: V=1.0341681, theta=-67.912695 -> V=1.0, theta=0.0
% INFO    : Bus 25006	: V=1.0295425, theta=-68.025438 -> V=1.0, theta=0.0
% INFO    : Bus 25007	: V=1.0297431, theta=-68.006574 -> V=1.0, theta=0.0
% INFO    : Bus 25008	: V=1.0326609, theta=-68.006852 -> V=1.0, theta=0.0
% INFO    : Bus 25009	: V=1.0373835, theta=-65.862445 -> V=1.0, theta=0.0
% INFO    : Bus 25010	: V=1.0336853, theta=-67.640647 -> V=1.0, theta=0.0
% INFO    : Bus 25011	: V=1.0311842, theta=-69.273573 -> V=1.0, theta=0.0
% INFO    : Bus 25012	: V=1.0311842, theta=-69.273573 -> V=1.0, theta=0.0
% INFO    : Bus 25013	: V=1.0305423, theta=-68.904655 -> V=1.0, theta=0.0
% INFO    : Bus 25014	: V=1.030399, theta=-68.921507 -> V=1.0, theta=0.0
% INFO    : Bus 25015	: V=1.0306695, theta=-68.887497 -> V=1.0, theta=0.0
% INFO    : Bus 25016	: V=1.0311845, theta=-68.25536 -> V=1.0, theta=0.0
% INFO    : Bus 25017	: V=1.0310622, theta=-68.271151 -> V=1.0, theta=0.0
% INFO    : Bus 25018	: V=1.0298231, theta=-67.775644 -> V=1.0, theta=0.0
% INFO    : Bus 25019	: V=1.027506, theta=-69.233186 -> V=1.0, theta=0.0
% INFO    : Bus 25020	: V=1.027506, theta=-69.233186 -> V=1.0, theta=0.0
% INFO    : Bus 25021	: V=1.027506, theta=-69.233186 -> V=1.0, theta=0.0
% INFO    : Bus 25022	: V=1.027506, theta=-69.233186 -> V=1.0, theta=0.0
% INFO    : Bus 25023	: V=1.0274361, theta=-69.247491 -> V=1.0, theta=0.0
% INFO    : Bus 25024	: V=1.0303626, theta=-68.864096 -> V=1.0, theta=0.0
% INFO    : Bus 25025	: V=1.030264, theta=-68.878942 -> V=1.0, theta=0.0
% INFO    : Bus 25026	: V=1.0292388, theta=-68.283101 -> V=1.0, theta=0.0
% INFO    : Bus 25027	: V=1.0265018, theta=-70.287205 -> V=1.0, theta=0.0
% INFO    : Bus 25028	: V=1.0240717, theta=-70.377397 -> V=1.0, theta=0.0
% INFO    : Bus 25029	: V=1.023985, theta=-70.397122 -> V=1.0, theta=0.0
% INFO    : Bus 25030	: V=1.0325524, theta=-66.950709 -> V=1.0, theta=0.0
% INFO    : Bus 25031	: V=1.0314321, theta=-69.848988 -> V=1.0, theta=0.0
% INFO    : Bus 25032	: V=1.0209293, theta=-70.167311 -> V=1.0, theta=0.0
% INFO    : Bus 25033	: V=1.020548, theta=-70.199246 -> V=1.0, theta=0.0
% INFO    : Bus 25034	: V=1.0283807, theta=-68.733542 -> V=1.0, theta=0.0
% INFO    : Bus 25035	: V=1.0277109, theta=-69.551882 -> V=1.0, theta=0.0
% INFO    : Bus 25036	: V=1.0275869, theta=-69.566397 -> V=1.0, theta=0.0
% INFO    : Bus 25037	: V=1.0278436, theta=-69.536348 -> V=1.0, theta=0.0
% INFO    : Bus 25038	: V=1.026463, theta=-70.396672 -> V=1.0, theta=0.0
% INFO    : Bus 25039	: V=1.0284051, theta=-70.507484 -> V=1.0, theta=0.0
% INFO    : Bus 25040	: V=1.0190776, theta=-71.100412 -> V=1.0, theta=0.0
% INFO    : Bus 25041	: V=1.0186223, theta=-71.127354 -> V=1.0, theta=0.0
% INFO    : Bus 25042	: V=1.0233715, theta=-70.95483 -> V=1.0, theta=0.0
% INFO    : Bus 25043	: V=1.0235295, theta=-70.925397 -> V=1.0, theta=0.0
% INFO    : Bus 25044	: V=1.0306529, theta=-70.554426 -> V=1.0, theta=0.0
% INFO    : Bus 25045	: V=1.0299997, theta=-69.741871 -> V=1.0, theta=0.0
% INFO    : Bus 25046	: V=1.0311926, theta=-71.137369 -> V=1.0, theta=0.0
% INFO    : Bus 25047	: V=1.0287428, theta=-71.528674 -> V=1.0, theta=0.0
% INFO    : Bus 25048	: V=1.0352237, theta=-69.690001 -> V=1.0, theta=0.0
% INFO    : Bus 25049	: V=1.0333744, theta=-70.958517 -> V=1.0, theta=0.0
% INFO    : Bus 25050	: V=1.0332642, theta=-71.047328 -> V=1.0, theta=0.0
% INFO    : Bus 25051	: V=1.0332642, theta=-71.047328 -> V=1.0, theta=0.0
% INFO    : Bus 25052	: V=1.0331941, theta=-71.073546 -> V=1.0, theta=0.0
% INFO    : Bus 25053	: V=1.031316, theta=-74.715437 -> V=1.0, theta=0.0
% INFO    : Bus 25054	: V=1.0311384, theta=-74.733249 -> V=1.0, theta=0.0
% INFO    : Bus 25055	: V=1.0260643, theta=-72.52776 -> V=1.0, theta=0.0
% INFO    : Bus 25056	: V=1.0309238, theta=-71.668932 -> V=1.0, theta=0.0
% INFO    : Bus 25057	: V=1.0316752, theta=-74.859689 -> V=1.0, theta=0.0
% INFO    : Bus 25058	: V=1.033191, theta=-73.05804 -> V=1.0, theta=0.0
% INFO    : Bus 25059	: V=1.0355561, theta=-70.955653 -> V=1.0, theta=0.0
% INFO    : Bus 25060	: V=1.0349554, theta=-72.062425 -> V=1.0, theta=0.0
% INFO    : Bus 25061	: V=1.0350166, theta=-71.906488 -> V=1.0, theta=0.0
% INFO    : Bus 25062	: V=1.0350166, theta=-71.906488 -> V=1.0, theta=0.0
% INFO    : Bus 25063	: V=1.0339481, theta=-73.303325 -> V=1.0, theta=0.0
% INFO    : Bus 25064	: V=1.0332879, theta=-72.452185 -> V=1.0, theta=0.0
% INFO    : Bus 25065	: V=1.0327917, theta=-74.911806 -> V=1.0, theta=0.0
% INFO    : Bus 25066	: V=1.0189268, theta=-70.091094 -> V=1.0, theta=0.0
% INFO    : Bus 25067	: V=1.0187933, theta=-70.104991 -> V=1.0, theta=0.0
% INFO    : Bus 25068	: V=1.0185753, theta=-69.141105 -> V=1.0, theta=0.0
% INFO    : Bus 25069	: V=1.0188359, theta=-69.128191 -> V=1.0, theta=0.0
% INFO    : Bus 25070	: V=1.0183339, theta=-69.151968 -> V=1.0, theta=0.0
% INFO    : Bus 25071	: V=1.0349109, theta=-68.112845 -> V=1.0, theta=0.0
% INFO    : Bus 25072	: V=1.0350578, theta=-68.094416 -> V=1.0, theta=0.0
% INFO    : Bus 25073	: V=1.0303257, theta=-74.680429 -> V=1.0, theta=0.0
% INFO    : Bus 25074	: V=1.0239273, theta=-76.252561 -> V=1.0, theta=0.0
% INFO    : Bus 25075	: V=1.0238624, theta=-76.258519 -> V=1.0, theta=0.0
% INFO    : Bus 25076	: V=1.0311679, theta=-70.066106 -> V=1.0, theta=0.0
% INFO    : Bus 25077	: V=1.0310227, theta=-70.088384 -> V=1.0, theta=0.0
% INFO    : Bus 25078	: V=1.0267505, theta=-70.022824 -> V=1.0, theta=0.0
% INFO    : Bus 25079	: V=1.0294841, theta=-73.744035 -> V=1.0, theta=0.0
% INFO    : Bus 25080	: V=1.0345185, theta=-76.294693 -> V=1.0, theta=0.0
% INFO    : Bus 25081	: V=1.0303574, theta=-76.728071 -> V=1.0, theta=0.0
% INFO    : Bus 25082	: V=1.0300487, theta=-76.754113 -> V=1.0, theta=0.0
% INFO    : Bus 25083	: V=1.0306513, theta=-76.702124 -> V=1.0, theta=0.0
% INFO    : Bus 25084	: V=1.0211756, theta=-76.73637 -> V=1.0, theta=0.0
% INFO    : Bus 25085	: V=1.0261149, theta=-71.26747 -> V=1.0, theta=0.0
% INFO    : Bus 25086	: V=1.0263157, theta=-71.240158 -> V=1.0, theta=0.0
% INFO    : Bus 25087	: V=1.0308865, theta=-70.86059 -> V=1.0, theta=0.0
% INFO    : Bus 25088	: V=1.0331845, theta=-70.147152 -> V=1.0, theta=0.0
% INFO    : Bus 25089	: V=1.0419672, theta=-76.177425 -> V=1.0, theta=0.0
% INFO    : Bus 25090	: V=1.0266342, theta=-76.752896 -> V=1.0, theta=0.0
% INFO    : Bus 25091	: V=1.0204651, theta=-71.786323 -> V=1.0, theta=0.0
% INFO    : Bus 25092	: V=1.0202953, theta=-71.808666 -> V=1.0, theta=0.0
% INFO    : Bus 25093	: V=1.0226932, theta=-71.545718 -> V=1.0, theta=0.0
% INFO    : Bus 25094	: V=1.0228756, theta=-71.525533 -> V=1.0, theta=0.0
% INFO    : Bus 25095	: V=1.0225323, theta=-71.567003 -> V=1.0, theta=0.0
% INFO    : Bus 25096	: V=1.024661, theta=-76.697015 -> V=1.0, theta=0.0
% INFO    : Bus 25097	: V=1.0349832, theta=-76.491369 -> V=1.0, theta=0.0
% INFO    : Bus 25098	: V=1.0277548, theta=-76.617027 -> V=1.0, theta=0.0
% INFO    : Bus 25099	: V=1.0279473, theta=-76.602965 -> V=1.0, theta=0.0
% INFO    : Bus 25100	: V=1.0275518, theta=-76.629675 -> V=1.0, theta=0.0
% INFO    : Bus 25101	: V=1.0277548, theta=-76.617027 -> V=1.0, theta=0.0
% INFO    : Bus 25102	: V=1.0202732, theta=-76.757535 -> V=1.0, theta=0.0
% INFO    : Bus 25103	: V=1.032492, theta=-73.738726 -> V=1.0, theta=0.0
% INFO    : Bus 25104	: V=1.0241877, theta=-76.079816 -> V=1.0, theta=0.0
% INFO    : Bus 25105	: V=1.022747, theta=-76.355265 -> V=1.0, theta=0.0
% INFO    : Bus 25106	: V=1.0224855, theta=-76.382749 -> V=1.0, theta=0.0
% INFO    : Bus 25107	: V=1.027867, theta=-76.681735 -> V=1.0, theta=0.0
% INFO    : Bus 25108	: V=1.0254029, theta=-69.523591 -> V=1.0, theta=0.0
% INFO    : Bus 25109	: V=1.0277714, theta=-70.207562 -> V=1.0, theta=0.0
% INFO    : Bus 25110	: V=1.0249636, theta=-69.563221 -> V=1.0, theta=0.0
% INFO    : Bus 25111	: V=1.0263115, theta=-70.381311 -> V=1.0, theta=0.0
% INFO    : Bus 25112	: V=1.0173953, theta=-78.20831 -> V=1.0, theta=0.0
% INFO    : Bus 25113	: V=1.0193922, theta=-77.012547 -> V=1.0, theta=0.0
% INFO    : Bus 25114	: V=1.0199393, theta=-77.014991 -> V=1.0, theta=0.0
% INFO    : Bus 25115	: V=1.0300655, theta=-76.328329 -> V=1.0, theta=0.0
% INFO    : Bus 25116	: V=1.0231167, theta=-77.543211 -> V=1.0, theta=0.0
% INFO    : Bus 25117	: V=1.0263112, theta=-70.32674 -> V=1.0, theta=0.0
% INFO    : Bus 25118	: V=1.0261068, theta=-70.355592 -> V=1.0, theta=0.0
% INFO    : Bus 25119	: V=1.0212316, theta=-71.131539 -> V=1.0, theta=0.0
% INFO    : Bus 25120	: V=1.0214333, theta=-71.102975 -> V=1.0, theta=0.0
% INFO    : Bus 25121	: V=1.0164776, theta=-72.609443 -> V=1.0, theta=0.0
% INFO    : Bus 25122	: V=1.0162256, theta=-72.630747 -> V=1.0, theta=0.0
% INFO    : Bus 25123	: V=1.019279, theta=-72.153854 -> V=1.0, theta=0.0
% INFO    : Bus 25124	: V=1.0165918, theta=-74.19284 -> V=1.0, theta=0.0
% INFO    : Bus 25125	: V=1.0166686, theta=-74.184443 -> V=1.0, theta=0.0
% INFO    : Bus 25126	: V=1.0165173, theta=-74.202058 -> V=1.0, theta=0.0
% INFO    : Bus 25127	: V=1.0224588, theta=-70.790024 -> V=1.0, theta=0.0
% INFO    : Bus 25128	: V=1.0220696, theta=-71.172641 -> V=1.0, theta=0.0
% INFO    : Bus 25129	: V=1.0189721, theta=-77.164027 -> V=1.0, theta=0.0
% INFO    : Bus 25130	: V=1.0190952, theta=-77.14413 -> V=1.0, theta=0.0
% INFO    : Bus 25131	: V=1.0161098, theta=-77.878388 -> V=1.0, theta=0.0
% INFO    : Bus 25132	: V=1.0283023, theta=-71.079139 -> V=1.0, theta=0.0
% INFO    : Bus 25133	: V=1.0232111, theta=-70.692424 -> V=1.0, theta=0.0
% INFO    : Bus 25134	: V=1.0275034, theta=-77.007171 -> V=1.0, theta=0.0
% INFO    : Bus 25135	: V=1.0277924, theta=-76.983636 -> V=1.0, theta=0.0
% INFO    : Bus 25136	: V=1.0272129, theta=-77.030149 -> V=1.0, theta=0.0
% INFO    : Bus 25137	: V=1.0193774, theta=-77.405706 -> V=1.0, theta=0.0
% INFO    : Bus 25138	: V=1.0265223, theta=-69.794256 -> V=1.0, theta=0.0
% INFO    : Bus 25139	: V=1.0304499, theta=-70.98079 -> V=1.0, theta=0.0
% INFO    : Bus 25140	: V=1.0113773, theta=-73.568708 -> V=1.0, theta=0.0
% INFO    : Bus 25141	: V=1.0116541, theta=-73.542424 -> V=1.0, theta=0.0
% INFO    : Bus 25142	: V=1.0258221, theta=-70.045966 -> V=1.0, theta=0.0
% INFO    : Bus 25143	: V=1.0204316, theta=-72.095589 -> V=1.0, theta=0.0
% INFO    : Bus 25144	: V=1.0269346, theta=-70.918468 -> V=1.0, theta=0.0
% INFO    : Bus 25145	: V=1.0267476, theta=-70.937287 -> V=1.0, theta=0.0
% INFO    : Bus 25146	: V=1.0154233, theta=-77.206762 -> V=1.0, theta=0.0
% INFO    : Bus 25147	: V=1.0123426, theta=-77.596343 -> V=1.0, theta=0.0
% INFO    : Bus 25148	: V=1.0125464, theta=-77.578965 -> V=1.0, theta=0.0
% INFO    : Bus 25149	: V=1.0215668, theta=-77.451492 -> V=1.0, theta=0.0
% INFO    : Bus 25150	: V=1.0217286, theta=-77.435213 -> V=1.0, theta=0.0
% INFO    : Bus 25151	: V=1.0214167, theta=-77.469009 -> V=1.0, theta=0.0
% INFO    : Bus 25152	: V=1.0173346, theta=-78.108006 -> V=1.0, theta=0.0
% INFO    : Bus 25153	: V=1.0171575, theta=-78.129661 -> V=1.0, theta=0.0
% INFO    : Bus 25154	: V=1.0136358, theta=-78.459103 -> V=1.0, theta=0.0
% INFO    : Bus 25155	: V=1.0133863, theta=-78.480706 -> V=1.0, theta=0.0
% INFO    : Bus 25156	: V=1.0235628, theta=-74.607487 -> V=1.0, theta=0.0
% INFO    : Bus 25157	: V=1.0197302, theta=-77.336993 -> V=1.0, theta=0.0
% INFO    : Bus 25158	: V=1.0198914, theta=-77.175864 -> V=1.0, theta=0.0
% INFO    : Bus 25159	: V=1.0198914, theta=-77.175864 -> V=1.0, theta=0.0
% INFO    : Bus 25160	: V=1.0154221, theta=-79.752071 -> V=1.0, theta=0.0
% INFO    : Bus 25161	: V=1.009691, theta=-73.442078 -> V=1.0, theta=0.0
% INFO    : Bus 25162	: V=1.0099972, theta=-73.423236 -> V=1.0, theta=0.0
% INFO    : Bus 25163	: V=1.0210511, theta=-78.011304 -> V=1.0, theta=0.0
% INFO    : Bus 25164	: V=1.0137669, theta=-78.039449 -> V=1.0, theta=0.0
% INFO    : Bus 25165	: V=1.0028041, theta=-73.227766 -> V=1.0, theta=0.0
% INFO    : Bus 25166	: V=1.0047573, theta=-72.993467 -> V=1.0, theta=0.0
% INFO    : Bus 25167	: V=1.0043871, theta=-73.017765 -> V=1.0, theta=0.0
% INFO    : Bus 25168	: V=1.0246228, theta=-69.986911 -> V=1.0, theta=0.0
% INFO    : Bus 25169	: V=1.0260707, theta=-71.036277 -> V=1.0, theta=0.0
% INFO    : Bus 25170	: V=1.0280027, theta=-71.001529 -> V=1.0, theta=0.0
% INFO    : Bus 25171	: V=1.0129851, theta=-78.497713 -> V=1.0, theta=0.0
% INFO    : Bus 25172	: V=1.0132954, theta=-78.458999 -> V=1.0, theta=0.0
% INFO    : Bus 25173	: V=1.0130307, theta=-77.994717 -> V=1.0, theta=0.0
% INFO    : Bus 25174	: V=1.0126709, theta=-78.034622 -> V=1.0, theta=0.0
% INFO    : Bus 25175	: V=1.0133699, theta=-77.956706 -> V=1.0, theta=0.0
% INFO    : Bus 25176	: V=1.0179014, theta=-77.875608 -> V=1.0, theta=0.0
% INFO    : Bus 25177	: V=1.013819, theta=-78.343399 -> V=1.0, theta=0.0
% INFO    : Bus 25178	: V=1.0157563, theta=-78.353689 -> V=1.0, theta=0.0
% INFO    : Bus 25179	: V=1.0158393, theta=-78.340116 -> V=1.0, theta=0.0
% INFO    : Bus 25180	: V=1.0181035, theta=-77.107728 -> V=1.0, theta=0.0
% INFO    : Bus 25181	: V=1.020316, theta=-76.506991 -> V=1.0, theta=0.0
% INFO    : Bus 25182	: V=1.0097001, theta=-78.134362 -> V=1.0, theta=0.0
% INFO    : Bus 25183	: V=1.0093469, theta=-78.164481 -> V=1.0, theta=0.0
% INFO    : Bus 25184	: V=1.0191768, theta=-73.930806 -> V=1.0, theta=0.0
% INFO    : Bus 25185	: V=1.0226034, theta=-77.037076 -> V=1.0, theta=0.0
% INFO    : Bus 25186	: V=1.0188722, theta=-73.956285 -> V=1.0, theta=0.0
% INFO    : Bus 25187	: V=1.016032, theta=-78.697846 -> V=1.0, theta=0.0
% INFO    : Bus 25188	: V=1.0248969, theta=-77.605608 -> V=1.0, theta=0.0
% INFO    : Bus 25189	: V=1.0210775, theta=-78.24082 -> V=1.0, theta=0.0
% INFO    : Bus 25190	: V=1.0203907, theta=-77.339338 -> V=1.0, theta=0.0
% INFO    : Bus 25191	: V=1.0205976, theta=-77.319611 -> V=1.0, theta=0.0
% INFO    : Bus 25192	: V=1.01826, theta=-77.03704 -> V=1.0, theta=0.0
% INFO    : Bus 25193	: V=1.0199962, theta=-77.555711 -> V=1.0, theta=0.0
% INFO    : Bus 25194	: V=1.0117767, theta=-74.813054 -> V=1.0, theta=0.0
% INFO    : Bus 25195	: V=1.0406504, theta=-79.144575 -> V=1.0, theta=0.0
% INFO    : Bus 25196	: V=1.0152567, theta=-74.690975 -> V=1.0, theta=0.0
% INFO    : Bus 25197	: V=1.0174187, theta=-74.716709 -> V=1.0, theta=0.0
% INFO    : Bus 25198	: V=1.0155561, theta=-77.759861 -> V=1.0, theta=0.0
% INFO    : Bus 25199	: V=1.0179957, theta=-74.595011 -> V=1.0, theta=0.0
% INFO    : Bus 25200	: V=1.0271679, theta=-79.18546 -> V=1.0, theta=0.0
% INFO    : Bus 25201	: V=1.0270236, theta=-79.204088 -> V=1.0, theta=0.0
% INFO    : Bus 25202	: V=1.022558, theta=-77.961249 -> V=1.0, theta=0.0
% INFO    : Bus 25203	: V=1.0216608, theta=-77.289262 -> V=1.0, theta=0.0
% INFO    : Bus 25204	: V=1.0214867, theta=-77.306925 -> V=1.0, theta=0.0
% INFO    : Bus 25205	: V=1.0213624, theta=-77.266233 -> V=1.0, theta=0.0
% INFO    : Bus 25206	: V=1.0272687, theta=-79.722572 -> V=1.0, theta=0.0
% INFO    : Bus 25207	: V=1.0271485, theta=-79.736667 -> V=1.0, theta=0.0
% INFO    : Bus 25208	: V=1.0151004, theta=-79.372381 -> V=1.0, theta=0.0
% INFO    : Bus 25209	: V=1.0210308, theta=-78.963693 -> V=1.0, theta=0.0
% INFO    : Bus 25210	: V=1.0210809, theta=-78.949342 -> V=1.0, theta=0.0
% INFO    : Bus 25211	: V=1.0209607, theta=-78.976906 -> V=1.0, theta=0.0
% INFO    : Bus 25212	: V=1.0156615, theta=-78.505077 -> V=1.0, theta=0.0
% INFO    : Bus 25213	: V=1.0155017, theta=-78.528166 -> V=1.0, theta=0.0
% INFO    : Bus 25214	: V=1.0178221, theta=-78.154236 -> V=1.0, theta=0.0
% INFO    : Bus 25215	: V=1.0179788, theta=-78.126229 -> V=1.0, theta=0.0
% INFO    : Bus 25216	: V=1.0184067, theta=-77.798535 -> V=1.0, theta=0.0
% INFO    : Bus 25217	: V=1.0196821, theta=-78.051969 -> V=1.0, theta=0.0
% INFO    : Bus 25218	: V=1.019501, theta=-78.070031 -> V=1.0, theta=0.0
% INFO    : Bus 25219	: V=1.0311913, theta=-79.644344 -> V=1.0, theta=0.0
% INFO    : Bus 25220	: V=1.0332921, theta=-79.772775 -> V=1.0, theta=0.0
% INFO    : Bus 25221	: V=1.0200824, theta=-78.329498 -> V=1.0, theta=0.0
% INFO    : Bus 25222	: V=1.0379474, theta=-79.339303 -> V=1.0, theta=0.0
% INFO    : Bus 25223	: V=1.0208164, theta=-78.663597 -> V=1.0, theta=0.0
% INFO    : Bus 25224	: V=1.0282863, theta=-80.101461 -> V=1.0, theta=0.0
% INFO    : Bus 25225	: V=1.0279646, theta=-80.139706 -> V=1.0, theta=0.0
% INFO    : Bus 25226	: V=1.0282315, theta=-80.107651 -> V=1.0, theta=0.0
% INFO    : Bus 25227	: V=1.0282594, theta=-80.053894 -> V=1.0, theta=0.0
% INFO    : Bus 25228	: V=1.0276106, theta=-79.494442 -> V=1.0, theta=0.0
% INFO    : Bus 25229	: V=1.0273034, theta=-79.523353 -> V=1.0, theta=0.0
% INFO    : Bus 25230	: V=1.0301949, theta=-79.981978 -> V=1.0, theta=0.0
% INFO    : Bus 25231	: V=1.0240758, theta=-79.518026 -> V=1.0, theta=0.0
% INFO    : Bus 25232	: V=1.0223765, theta=-79.549547 -> V=1.0, theta=0.0
% INFO    : Bus 25233	: V=1.0160497, theta=-78.683201 -> V=1.0, theta=0.0
% INFO    : Bus 25234	: V=1.0162354, theta=-78.65793 -> V=1.0, theta=0.0
% INFO    : Bus 25235	: V=1.0206315, theta=-77.256507 -> V=1.0, theta=0.0
% INFO    : Bus 25236	: V=1.0202555, theta=-77.29855 -> V=1.0, theta=0.0
% INFO    : Bus 25237	: V=1.0227174, theta=-76.903563 -> V=1.0, theta=0.0
% INFO    : Bus 25238	: V=1.0145384, theta=-76.153419 -> V=1.0, theta=0.0
% INFO    : Bus 25239	: V=1.0309693, theta=-71.063 -> V=1.0, theta=0.0
% INFO    : Bus 25240	: V=1.0310575, theta=-71.043574 -> V=1.0, theta=0.0
% INFO    : Bus 25241	: V=1.0337517, theta=-69.3205 -> V=1.0, theta=0.0
% INFO    : Bus 25242	: V=1.024744, theta=-79.260494 -> V=1.0, theta=0.0
% INFO    : Bus 25243	: V=1.0227669, theta=-79.729742 -> V=1.0, theta=0.0
% INFO    : Bus 25244	: V=1.0241702, theta=-79.710638 -> V=1.0, theta=0.0
% INFO    : Bus 25245	: V=1.023978, theta=-79.728557 -> V=1.0, theta=0.0
% INFO    : Bus 25246	: V=1.0202028, theta=-78.528893 -> V=1.0, theta=0.0
% INFO    : Bus 25247	: V=1.0228341, theta=-77.679891 -> V=1.0, theta=0.0
% INFO    : Bus 25248	: V=1.0226688, theta=-77.706807 -> V=1.0, theta=0.0
% INFO    : Bus 25249	: V=1.0127816, theta=-78.538876 -> V=1.0, theta=0.0
% INFO    : Bus 25250	: V=1.0126895, theta=-77.40005 -> V=1.0, theta=0.0
% INFO    : Bus 25251	: V=1.0124913, theta=-77.418925 -> V=1.0, theta=0.0
% INFO    : Bus 25252	: V=1.0187955, theta=-78.162754 -> V=1.0, theta=0.0
% INFO    : Bus 25253	: V=1.0320662, theta=-79.252692 -> V=1.0, theta=0.0
% INFO    : Bus 25254	: V=1.0222186, theta=-79.649224 -> V=1.0, theta=0.0
% INFO    : Bus 25255	: V=1.020004, theta=-79.404224 -> V=1.0, theta=0.0
% INFO    : Bus 25256	: V=1.0241937, theta=-78.687282 -> V=1.0, theta=0.0
% INFO    : Bus 25257	: V=1.024072, theta=-78.702159 -> V=1.0, theta=0.0
% INFO    : Bus 25258	: V=1.0149195, theta=-79.770678 -> V=1.0, theta=0.0
% INFO    : Bus 25259	: V=1.0148072, theta=-79.785198 -> V=1.0, theta=0.0
% INFO    : Bus 25260	: V=1.0253473, theta=-78.980592 -> V=1.0, theta=0.0
% INFO    : Bus 25261	: V=1.0237145, theta=-79.693402 -> V=1.0, theta=0.0
% INFO    : Bus 25262	: V=1.0237145, theta=-79.693402 -> V=1.0, theta=0.0
% INFO    : Bus 25263	: V=1.0237145, theta=-79.693402 -> V=1.0, theta=0.0
% INFO    : Bus 25264	: V=1.0237145, theta=-79.693402 -> V=1.0, theta=0.0
% INFO    : Bus 25265	: V=1.0235816, theta=-79.718915 -> V=1.0, theta=0.0
% INFO    : Bus 25266	: V=1.0209049, theta=-75.836583 -> V=1.0, theta=0.0
% INFO    : Bus 25267	: V=1.0283741, theta=-79.534965 -> V=1.0, theta=0.0
% INFO    : Bus 25268	: V=1.0205479, theta=-75.876981 -> V=1.0, theta=0.0
% INFO    : Bus 25269	: V=1.0217232, theta=-71.480142 -> V=1.0, theta=0.0
% INFO    : Bus 25270	: V=1.013606, theta=-76.397942 -> V=1.0, theta=0.0
% INFO    : Bus 25271	: V=1.0136977, theta=-76.379846 -> V=1.0, theta=0.0
% INFO    : Bus 25272	: V=1.0202556, theta=-77.114874 -> V=1.0, theta=0.0
% INFO    : Bus 25273	: V=1.0201101, theta=-77.131424 -> V=1.0, theta=0.0
% INFO    : Bus 25274	: V=1.0204187, theta=-77.097991 -> V=1.0, theta=0.0
% INFO    : Bus 25275	: V=1.0285972, theta=-78.876083 -> V=1.0, theta=0.0
% INFO    : Bus 25276	: V=1.0282236, theta=-78.920104 -> V=1.0, theta=0.0
% INFO    : Bus 25277	: V=1.0252714, theta=-79.0365 -> V=1.0, theta=0.0
% INFO    : Bus 25278	: V=1.0250823, theta=-79.065291 -> V=1.0, theta=0.0
% INFO    : Bus 25279	: V=1.0254699, theta=-79.008821 -> V=1.0, theta=0.0
% INFO    : Bus 25280	: V=1.0252714, theta=-79.0365 -> V=1.0, theta=0.0
% INFO    : Bus 25281	: V=1.0215305, theta=-80.19152 -> V=1.0, theta=0.0
% INFO    : Bus 25282	: V=1.0213628, theta=-80.214867 -> V=1.0, theta=0.0
% INFO    : Bus 25283	: V=1.02169, theta=-80.168035 -> V=1.0, theta=0.0
% INFO    : Bus 25284	: V=1.0278529, theta=-78.742699 -> V=1.0, theta=0.0
% INFO    : Bus 25285	: V=1.0282163, theta=-78.688882 -> V=1.0, theta=0.0
% INFO    : Bus 25286	: V=1.0278529, theta=-78.742699 -> V=1.0, theta=0.0
% INFO    : Bus 25287	: V=1.030215, theta=-75.072627 -> V=1.0, theta=0.0
% INFO    : Bus 25288	: V=1.0256356, theta=-78.949448 -> V=1.0, theta=0.0
% INFO    : Bus 25289	: V=1.0296054, theta=-75.139827 -> V=1.0, theta=0.0
% INFO    : Bus 25290	: V=1.0305165, theta=-77.990916 -> V=1.0, theta=0.0
% INFO    : Bus 25291	: V=1.0287919, theta=-79.624079 -> V=1.0, theta=0.0
% INFO    : Bus 25292	: V=1.0285274, theta=-79.645084 -> V=1.0, theta=0.0
% INFO    : Bus 25293	: V=1.0198225, theta=-79.513331 -> V=1.0, theta=0.0
% INFO    : Bus 25294	: V=1.0193435, theta=-79.55475 -> V=1.0, theta=0.0
% INFO    : Bus 25295	: V=1.0238263, theta=-79.797334 -> V=1.0, theta=0.0
% INFO    : Bus 25296	: V=1.0236919, theta=-79.812522 -> V=1.0, theta=0.0
% INFO    : Bus 25297	: V=1.0239885, theta=-79.780599 -> V=1.0, theta=0.0
% INFO    : Bus 25298	: V=1.0178997, theta=-79.528484 -> V=1.0, theta=0.0
% INFO    : Bus 25299	: V=1.0196505, theta=-78.411366 -> V=1.0, theta=0.0
% INFO    : Bus 25300	: V=1.0160252, theta=-79.523766 -> V=1.0, theta=0.0
% INFO    : Bus 25301	: V=1.0156949, theta=-79.553333 -> V=1.0, theta=0.0
% INFO    : Bus 25302	: V=1.0218701, theta=-75.389789 -> V=1.0, theta=0.0
% INFO    : Bus 25303	: V=1.0270443, theta=-79.090493 -> V=1.0, theta=0.0
% INFO    : Bus 25304	: V=1.0245091, theta=-79.837354 -> V=1.0, theta=0.0
% INFO    : Bus 25305	: V=1.0244316, theta=-79.849738 -> V=1.0, theta=0.0
% INFO    : Bus 25306	: V=1.0142268, theta=-78.908811 -> V=1.0, theta=0.0
% INFO    : Bus 25307	: V=1.0138464, theta=-78.941612 -> V=1.0, theta=0.0
% INFO    : Bus 25308	: V=1.0275698, theta=-78.633335 -> V=1.0, theta=0.0
% INFO    : Bus 25309	: V=1.0224326, theta=-74.927406 -> V=1.0, theta=0.0
% INFO    : Bus 25310	: V=1.0321443, theta=-77.729172 -> V=1.0, theta=0.0
% INFO    : Bus 25311	: V=1.0218117, theta=-74.211776 -> V=1.0, theta=0.0
% INFO    : Bus 25312	: V=1.022048, theta=-74.194184 -> V=1.0, theta=0.0
% INFO    : Bus 25313	: V=1.0277367, theta=-78.7658 -> V=1.0, theta=0.0
% INFO    : Bus 25314	: V=1.0229168, theta=-80.089804 -> V=1.0, theta=0.0
% INFO    : Bus 25315	: V=1.0227415, theta=-80.108161 -> V=1.0, theta=0.0
% INFO    : Bus 25316	: V=1.0230988, theta=-80.071137 -> V=1.0, theta=0.0
% INFO    : Bus 25317	: V=1.0240303, theta=-80.002271 -> V=1.0, theta=0.0
% INFO    : Bus 25318	: V=1.0238811, theta=-80.024647 -> V=1.0, theta=0.0
% INFO    : Bus 25319	: V=1.0241816, theta=-79.979565 -> V=1.0, theta=0.0
% INFO    : Bus 25320	: V=1.0240303, theta=-80.002271 -> V=1.0, theta=0.0
% INFO    : Bus 25321	: V=1.0207629, theta=-79.633995 -> V=1.0, theta=0.0
% INFO    : Bus 25322	: V=1.0206528, theta=-78.936845 -> V=1.0, theta=0.0
% INFO    : Bus 25323	: V=1.0204134, theta=-78.968344 -> V=1.0, theta=0.0
% INFO    : Bus 25324	: V=1.0220923, theta=-79.783879 -> V=1.0, theta=0.0
% INFO    : Bus 25325	: V=1.0222891, theta=-79.769682 -> V=1.0, theta=0.0
% INFO    : Bus 25326	: V=1.0267604, theta=-79.619833 -> V=1.0, theta=0.0
% INFO    : Bus 25327	: V=1.0217437, theta=-80.24291 -> V=1.0, theta=0.0
% INFO    : Bus 25328	: V=1.0205152, theta=-78.85166 -> V=1.0, theta=0.0
% INFO    : Bus 25329	: V=1.0233332, theta=-79.704593 -> V=1.0, theta=0.0
% INFO    : Bus 25330	: V=1.024786, theta=-79.100808 -> V=1.0, theta=0.0
% INFO    : Bus 25331	: V=1.0206019, theta=-79.662087 -> V=1.0, theta=0.0
% INFO    : Bus 25332	: V=1.0232747, theta=-74.901593 -> V=1.0, theta=0.0
% INFO    : Bus 25333	: V=1.0226142, theta=-77.930379 -> V=1.0, theta=0.0
% INFO    : Bus 25334	: V=1.0245628, theta=-74.73997 -> V=1.0, theta=0.0
% INFO    : Bus 25335	: V=1.0229585, theta=-74.942282 -> V=1.0, theta=0.0
% INFO    : Bus 25336	: V=1.0232747, theta=-74.901593 -> V=1.0, theta=0.0
% INFO    : Bus 25337	: V=1.0214044, theta=-79.824663 -> V=1.0, theta=0.0
% INFO    : Bus 25338	: V=1.0275009, theta=-78.858361 -> V=1.0, theta=0.0
% INFO    : Bus 25339	: V=1.0172992, theta=-79.587662 -> V=1.0, theta=0.0
% INFO    : Bus 25340	: V=1.0169814, theta=-79.63322 -> V=1.0, theta=0.0
% INFO    : Bus 25341	: V=1.0266657, theta=-78.824272 -> V=1.0, theta=0.0
% INFO    : Bus 25342	: V=1.0228579, theta=-78.789355 -> V=1.0, theta=0.0
% INFO    : Bus 25343	: V=1.0225585, theta=-78.820173 -> V=1.0, theta=0.0
% INFO    : Bus 25344	: V=1.0231671, theta=-78.758432 -> V=1.0, theta=0.0
% INFO    : Bus 25345	: V=1.0125559, theta=-77.796282 -> V=1.0, theta=0.0
% INFO    : Bus 25346	: V=1.0226794, theta=-80.096025 -> V=1.0, theta=0.0
% INFO    : Bus 25347	: V=1.0348586, theta=-79.477597 -> V=1.0, theta=0.0
% INFO    : Bus 25348	: V=1.0304516, theta=-78.063988 -> V=1.0, theta=0.0
% INFO    : Bus 25349	: V=1.0136894, theta=-76.367016 -> V=1.0, theta=0.0
% INFO    : Bus 25350	: V=1.0243472, theta=-78.878427 -> V=1.0, theta=0.0
% INFO    : Bus 25351	: V=1.0245778, theta=-78.859471 -> V=1.0, theta=0.0
% INFO    : Bus 25352	: V=1.0211628, theta=-80.088228 -> V=1.0, theta=0.0
% INFO    : Bus 25353	: V=1.0269607, theta=-72.520772 -> V=1.0, theta=0.0
% INFO    : Bus 25354	: V=1.0265337, theta=-72.555667 -> V=1.0, theta=0.0
% INFO    : Bus 25355	: V=1.0241171, theta=-73.010349 -> V=1.0, theta=0.0
% INFO    : Bus 25356	: V=1.0316624, theta=-79.604572 -> V=1.0, theta=0.0
% INFO    : Bus 25357	: V=1.0220445, theta=-78.422101 -> V=1.0, theta=0.0
% INFO    : Bus 25358	: V=1.0282596, theta=-78.247372 -> V=1.0, theta=0.0
% INFO    : Bus 25359	: V=1.0281059, theta=-78.273816 -> V=1.0, theta=0.0
% INFO    : Bus 25360	: V=1.0284337, theta=-78.221998 -> V=1.0, theta=0.0
% INFO    : Bus 25361	: V=1.0319298, theta=-79.590658 -> V=1.0, theta=0.0
% INFO    : Bus 25362	: V=1.0252125, theta=-79.377626 -> V=1.0, theta=0.0
% INFO    : Bus 25363	: V=1.024309, theta=-79.156875 -> V=1.0, theta=0.0
% INFO    : Bus 25364	: V=1.0259006, theta=-79.108016 -> V=1.0, theta=0.0
% INFO    : Bus 25365	: V=1.0211653, theta=-79.45845 -> V=1.0, theta=0.0
% INFO    : Bus 25366	: V=1.0197084, theta=-79.321003 -> V=1.0, theta=0.0
% INFO    : Bus 25367	: V=1.0195659, theta=-79.335528 -> V=1.0, theta=0.0
% INFO    : Bus 25368	: V=1.019866, theta=-79.304663 -> V=1.0, theta=0.0
% INFO    : Bus 25369	: V=1.021834, theta=-79.075099 -> V=1.0, theta=0.0
% INFO    : Bus 25370	: V=1.0217087, theta=-79.100095 -> V=1.0, theta=0.0
% INFO    : Bus 25371	: V=1.0218253, theta=-79.075611 -> V=1.0, theta=0.0
% INFO    : Bus 25372	: V=1.0316488, theta=-80.021854 -> V=1.0, theta=0.0
% INFO    : Bus 25373	: V=1.0314621, theta=-80.04528 -> V=1.0, theta=0.0
% INFO    : Bus 25374	: V=1.0249383, theta=-78.89685 -> V=1.0, theta=0.0
% INFO    : Bus 25375	: V=1.0197628, theta=-78.833027 -> V=1.0, theta=0.0
% INFO    : Bus 25376	: V=1.0262965, theta=-79.16906 -> V=1.0, theta=0.0
% INFO    : Bus 25377	: V=1.022759, theta=-79.840189 -> V=1.0, theta=0.0
% INFO    : Bus 25378	: V=1.0230661, theta=-79.804437 -> V=1.0, theta=0.0
% INFO    : Bus 25379	: V=1.0225362, theta=-79.856284 -> V=1.0, theta=0.0
% INFO    : Bus 25380	: V=1.0201475, theta=-79.936557 -> V=1.0, theta=0.0
% INFO    : Bus 25381	: V=1.0252408, theta=-79.766679 -> V=1.0, theta=0.0
% INFO    : Bus 25382	: V=1.0251959, theta=-79.890912 -> V=1.0, theta=0.0
% INFO    : Bus 25383	: V=1.0214663, theta=-80.312825 -> V=1.0, theta=0.0
% INFO    : Bus 25384	: V=1.0270002, theta=-78.72297 -> V=1.0, theta=0.0
% INFO    : Bus 25385	: V=1.0265331, theta=-78.779356 -> V=1.0, theta=0.0
% INFO    : Bus 25386	: V=1.0239884, theta=-78.745232 -> V=1.0, theta=0.0
% INFO    : Bus 25387	: V=1.0237948, theta=-78.761948 -> V=1.0, theta=0.0
% INFO    : Bus 25388	: V=1.0222454, theta=-78.567005 -> V=1.0, theta=0.0
% INFO    : Bus 25389	: V=1.0396119, theta=-79.504126 -> V=1.0, theta=0.0
% INFO    : Bus 25390	: V=1.039925, theta=-79.476161 -> V=1.0, theta=0.0
% INFO    : Bus 25391	: V=1.0394702, theta=-79.51812 -> V=1.0, theta=0.0
% INFO    : Bus 25392	: V=1.0394401, theta=-79.518836 -> V=1.0, theta=0.0
% INFO    : Bus 25393	: V=1.0396119, theta=-79.504126 -> V=1.0, theta=0.0
% INFO    : Bus 25394	: V=1.0219072, theta=-79.453647 -> V=1.0, theta=0.0
% INFO    : Bus 25395	: V=1.0217244, theta=-79.470237 -> V=1.0, theta=0.0
% INFO    : Bus 25396	: V=1.0281207, theta=-80.068015 -> V=1.0, theta=0.0
% INFO    : Bus 25397	: V=1.0256061, theta=-72.522612 -> V=1.0, theta=0.0
% INFO    : Bus 25398	: V=1.0253682, theta=-72.541283 -> V=1.0, theta=0.0
% INFO    : Bus 25399	: V=1.0193457, theta=-79.433882 -> V=1.0, theta=0.0
% INFO    : Bus 25400	: V=1.0363533, theta=-79.796638 -> V=1.0, theta=0.0
% INFO    : Bus 25401	: V=1.019734, theta=-75.950192 -> V=1.0, theta=0.0
% INFO    : Bus 25402	: V=1.0275239, theta=-79.440564 -> V=1.0, theta=0.0
% INFO    : Bus 25403	: V=1.0191135, theta=-76.011291 -> V=1.0, theta=0.0
% INFO    : Bus 25404	: V=1.0273045, theta=-78.580569 -> V=1.0, theta=0.0
% INFO    : Bus 25405	: V=1.0242767, theta=-79.442399 -> V=1.0, theta=0.0
% INFO    : Bus 25406	: V=1.0292752, theta=-80.064442 -> V=1.0, theta=0.0
% INFO    : Bus 25407	: V=1.0260947, theta=-79.012168 -> V=1.0, theta=0.0
% INFO    : Bus 25408	: V=1.0259998, theta=-79.029677 -> V=1.0, theta=0.0
% INFO    : Bus 25409	: V=1.0199678, theta=-80.097111 -> V=1.0, theta=0.0
% INFO    : Bus 25410	: V=1.0201266, theta=-80.079886 -> V=1.0, theta=0.0
% INFO    : Bus 25411	: V=1.0291322, theta=-79.621278 -> V=1.0, theta=0.0
% INFO    : Bus 25412	: V=1.0295031, theta=-79.580421 -> V=1.0, theta=0.0
% INFO    : Bus 25413	: V=1.0291322, theta=-79.621278 -> V=1.0, theta=0.0
% INFO    : Bus 25414	: V=1.0261963, theta=-80.060321 -> V=1.0, theta=0.0
% INFO    : Bus 25415	: V=1.0259829, theta=-80.093084 -> V=1.0, theta=0.0
% INFO    : Bus 25416	: V=1.0272829, theta=-79.1337 -> V=1.0, theta=0.0
% INFO    : Bus 25417	: V=1.0227099, theta=-80.1448 -> V=1.0, theta=0.0
% INFO    : Bus 25418	: V=1.0329732, theta=-79.954287 -> V=1.0, theta=0.0
% INFO    : Bus 25419	: V=1.0216459, theta=-78.78423 -> V=1.0, theta=0.0
% INFO    : Bus 25420	: V=1.0213585, theta=-78.804024 -> V=1.0, theta=0.0
% INFO    : Bus 25421	: V=1.025278, theta=-78.381842 -> V=1.0, theta=0.0
% INFO    : Bus 25422	: V=1.0260939, theta=-80.155238 -> V=1.0, theta=0.0
% INFO    : Bus 25423	: V=1.0260416, theta=-79.80904 -> V=1.0, theta=0.0
% INFO    : Bus 25424	: V=1.0258253, theta=-79.844247 -> V=1.0, theta=0.0
% INFO    : Bus 25425	: V=1.0258514, theta=-76.104176 -> V=1.0, theta=0.0
% INFO    : Bus 25426	: V=1.0236518, theta=-80.062484 -> V=1.0, theta=0.0
% INFO    : Bus 25427	: V=1.0267245, theta=-75.936184 -> V=1.0, theta=0.0
% INFO    : Bus 25428	: V=1.0258514, theta=-76.104176 -> V=1.0, theta=0.0
% INFO    : Bus 25429	: V=1.0192897, theta=-79.808394 -> V=1.0, theta=0.0
% INFO    : Bus 25430	: V=1.0190592, theta=-79.83458 -> V=1.0, theta=0.0
% INFO    : Bus 25431	: V=1.0213393, theta=-80.493686 -> V=1.0, theta=0.0
% INFO    : Bus 25432	: V=1.0210506, theta=-80.516635 -> V=1.0, theta=0.0
% INFO    : Bus 25433	: V=1.0231696, theta=-80.167069 -> V=1.0, theta=0.0
% INFO    : Bus 25434	: V=1.0230743, theta=-80.187113 -> V=1.0, theta=0.0
% INFO    : Bus 25435	: V=1.0211764, theta=-78.751543 -> V=1.0, theta=0.0
% INFO    : Bus 25436	: V=1.0237506, theta=-78.455341 -> V=1.0, theta=0.0
% INFO    : Bus 25437	: V=1.0208491, theta=-76.488663 -> V=1.0, theta=0.0
% INFO    : Bus 25438	: V=1.0254517, theta=-79.701478 -> V=1.0, theta=0.0
% INFO    : Bus 25439	: V=1.0201511, theta=-76.561152 -> V=1.0, theta=0.0
% INFO    : Bus 25440	: V=1.0219945, theta=-76.311479 -> V=1.0, theta=0.0
% INFO    : Bus 25441	: V=1.0208491, theta=-76.488663 -> V=1.0, theta=0.0
% INFO    : Bus 25442	: V=1.0195473, theta=-79.952793 -> V=1.0, theta=0.0
% INFO    : Bus 25443	: V=1.0248832, theta=-79.161989 -> V=1.0, theta=0.0
% INFO    : Bus 25444	: V=1.0325988, theta=-79.082196 -> V=1.0, theta=0.0
% INFO    : Bus 25445	: V=1.0245374, theta=-80.215853 -> V=1.0, theta=0.0
% INFO    : Bus 25446	: V=1.0247461, theta=-80.192249 -> V=1.0, theta=0.0
% INFO    : Bus 25447	: V=1.0217732, theta=-79.90538 -> V=1.0, theta=0.0
% INFO    : Bus 25448	: V=1.0198688, theta=-79.679035 -> V=1.0, theta=0.0
% INFO    : Bus 25449	: V=1.0200922, theta=-79.646138 -> V=1.0, theta=0.0
% INFO    : Bus 25450	: V=1.0198688, theta=-79.679035 -> V=1.0, theta=0.0
% INFO    : Bus 25451	: V=1.0342961, theta=-79.52522 -> V=1.0, theta=0.0
% INFO    : Bus 25452	: V=1.0232104, theta=-80.458618 -> V=1.0, theta=0.0
% INFO    : Bus 25453	: V=1.0232895, theta=-80.364093 -> V=1.0, theta=0.0
% INFO    : Bus 25454	: V=1.0228555, theta=-79.991806 -> V=1.0, theta=0.0
% INFO    : Bus 25455	: V=1.0224907, theta=-80.037731 -> V=1.0, theta=0.0
% INFO    : Bus 25456	: V=1.0189038, theta=-80.597133 -> V=1.0, theta=0.0
% INFO    : Bus 25457	: V=1.0288871, theta=-80.200471 -> V=1.0, theta=0.0
% INFO    : Bus 25458	: V=1.0217757, theta=-76.18682 -> V=1.0, theta=0.0
% INFO    : Bus 25459	: V=1.0206641, theta=-79.360937 -> V=1.0, theta=0.0
% INFO    : Bus 25460	: V=1.0207312, theta=-79.702233 -> V=1.0, theta=0.0
% INFO    : Bus 25461	: V=1.0207312, theta=-79.702233 -> V=1.0, theta=0.0
% INFO    : Bus 25462	: V=1.0214979, theta=-76.222643 -> V=1.0, theta=0.0
% INFO    : Bus 25463	: V=1.0227316, theta=-75.996154 -> V=1.0, theta=0.0
% INFO    : Bus 25464	: V=1.0217757, theta=-76.18682 -> V=1.0, theta=0.0
% INFO    : Bus 25465	: V=1.0201952, theta=-79.367076 -> V=1.0, theta=0.0
% INFO    : Bus 25466	: V=1.0200873, theta=-79.388714 -> V=1.0, theta=0.0
% INFO    : Bus 25467	: V=1.022054, theta=-80.04868 -> V=1.0, theta=0.0
% INFO    : Bus 25468	: V=1.0216487, theta=-80.084106 -> V=1.0, theta=0.0
% INFO    : Bus 25469	: V=1.0226072, theta=-78.323342 -> V=1.0, theta=0.0
% INFO    : Bus 25470	: V=1.0250522, theta=-78.954354 -> V=1.0, theta=0.0
% INFO    : Bus 25471	: V=1.0333842, theta=-79.58485 -> V=1.0, theta=0.0
% INFO    : Bus 25472	: V=1.0328706, theta=-79.620652 -> V=1.0, theta=0.0
% INFO    : Bus 25473	: V=1.0065732, theta=-76.98687 -> V=1.0, theta=0.0
% INFO    : Bus 25474	: V=1.0322755, theta=-79.780972 -> V=1.0, theta=0.0
% INFO    : Bus 25475	: V=1.0151436, theta=-76.568516 -> V=1.0, theta=0.0
% INFO    : Bus 25476	: V=1.0289222, theta=-79.980804 -> V=1.0, theta=0.0
% INFO    : Bus 25477	: V=1.0292056, theta=-79.949983 -> V=1.0, theta=0.0
% INFO    : Bus 25478	: V=1.0340202, theta=-79.341877 -> V=1.0, theta=0.0
% INFO    : Bus 25479	: V=1.0338527, theta=-79.367166 -> V=1.0, theta=0.0
% INFO    : Bus 25480	: V=1.0309275, theta=-80.773854 -> V=1.0, theta=0.0
% INFO    : Bus 25481	: V=1.0137171, theta=-75.859209 -> V=1.0, theta=0.0
% INFO    : Bus 25482	: V=1.0254546, theta=-79.841124 -> V=1.0, theta=0.0
% INFO    : Bus 25483	: V=1.0159406, theta=-75.662654 -> V=1.0, theta=0.0
% INFO    : Bus 25484	: V=1.0194995, theta=-78.822142 -> V=1.0, theta=0.0
% INFO    : Bus 25485	: V=1.0197688, theta=-78.791606 -> V=1.0, theta=0.0
% INFO    : Bus 25486	: V=1.0240027, theta=-78.199526 -> V=1.0, theta=0.0
% INFO    : Bus 25487	: V=1.0238136, theta=-78.230685 -> V=1.0, theta=0.0
% INFO    : Bus 25488	: V=1.0235069, theta=-80.487576 -> V=1.0, theta=0.0
% INFO    : Bus 25489	: V=1.0212861, theta=-75.566128 -> V=1.0, theta=0.0
% INFO    : Bus 25490	: V=1.0451554, theta=-79.133464 -> V=1.0, theta=0.0
% INFO    : Bus 25491	: V=1.0234047, theta=-78.267626 -> V=1.0, theta=0.0
% INFO    : Bus 25492	: V=1.0234047, theta=-78.267626 -> V=1.0, theta=0.0
% INFO    : Bus 25493	: V=1.0234047, theta=-78.267626 -> V=1.0, theta=0.0
% INFO    : Bus 25494	: V=1.0234047, theta=-78.267626 -> V=1.0, theta=0.0
% INFO    : Bus 25495	: V=1.0226188, theta=-78.154596 -> V=1.0, theta=0.0
% INFO    : Bus 25496	: V=1.0224141, theta=-78.182685 -> V=1.0, theta=0.0
% INFO    : Bus 25497	: V=1.018033, theta=-80.278836 -> V=1.0, theta=0.0
% INFO    : Bus 25498	: V=1.0203111, theta=-80.448055 -> V=1.0, theta=0.0
% INFO    : Bus 25499	: V=1.0243321, theta=-80.115746 -> V=1.0, theta=0.0
% INFO    : Bus 25500	: V=1.0224622, theta=-80.212462 -> V=1.0, theta=0.0
% INFO    : Bus 25501	: V=1.0259118, theta=-79.628587 -> V=1.0, theta=0.0
% INFO    : Bus 25502	: V=1.0255884, theta=-79.667009 -> V=1.0, theta=0.0
% INFO    : Bus 25503	: V=1.0226615, theta=-80.137955 -> V=1.0, theta=0.0
% INFO    : Bus 25504	: V=1.022514, theta=-80.150613 -> V=1.0, theta=0.0
% INFO    : Bus 25505	: V=1.0215899, theta=-79.329365 -> V=1.0, theta=0.0
% INFO    : Bus 25506	: V=1.0213723, theta=-79.34806 -> V=1.0, theta=0.0
% INFO    : Bus 25507	: V=1.0211422, theta=-80.517104 -> V=1.0, theta=0.0
% INFO    : Bus 25508	: V=1.0129334, theta=-78.503834 -> V=1.0, theta=0.0
% INFO    : Bus 25509	: V=1.0227792, theta=-79.217912 -> V=1.0, theta=0.0
% INFO    : Bus 25510	: V=1.0241255, theta=-79.943607 -> V=1.0, theta=0.0
% INFO    : Bus 25511	: V=1.0196607, theta=-79.040488 -> V=1.0, theta=0.0
% INFO    : Bus 25512	: V=1.03077, theta=-80.677602 -> V=1.0, theta=0.0
% INFO    : Bus 25513	: V=1.0306388, theta=-80.696129 -> V=1.0, theta=0.0
% INFO    : Bus 25514	: V=1.0162059, theta=-75.808568 -> V=1.0, theta=0.0
% INFO    : Bus 25515	: V=1.0197603, theta=-75.260728 -> V=1.0, theta=0.0
% INFO    : Bus 25516	: V=1.0232384, theta=-80.664584 -> V=1.0, theta=0.0
% INFO    : Bus 25517	: V=1.0200111, theta=-79.015089 -> V=1.0, theta=0.0
% INFO    : Bus 25518	: V=1.0163016, theta=-76.811258 -> V=1.0, theta=0.0
% INFO    : Bus 25519	: V=1.0162089, theta=-76.825282 -> V=1.0, theta=0.0
% INFO    : Bus 25520	: V=1.0231997, theta=-79.974484 -> V=1.0, theta=0.0
% INFO    : Bus 25521	: V=1.0194421, theta=-80.39816 -> V=1.0, theta=0.0
% INFO    : Bus 25522	: V=1.0164467, theta=-79.339466 -> V=1.0, theta=0.0
% INFO    : Bus 25523	: V=1.0166283, theta=-79.312736 -> V=1.0, theta=0.0
% INFO    : Bus 25524	: V=1.018318, theta=-80.831067 -> V=1.0, theta=0.0
% INFO    : Bus 25525	: V=1.019901, theta=-80.034745 -> V=1.0, theta=0.0
% INFO    : Bus 25526	: V=1.0196545, theta=-80.056601 -> V=1.0, theta=0.0
% INFO    : Bus 25527	: V=1.0201098, theta=-80.013016 -> V=1.0, theta=0.0
% INFO    : Bus 25528	: V=1.0244166, theta=-78.240235 -> V=1.0, theta=0.0
% INFO    : Bus 25529	: V=1.0241541, theta=-78.258345 -> V=1.0, theta=0.0
% INFO    : Bus 25530	: V=1.0222007, theta=-78.332536 -> V=1.0, theta=0.0
% INFO    : Bus 25531	: V=1.0097414, theta=-77.271769 -> V=1.0, theta=0.0
% INFO    : Bus 25532	: V=1.0261081, theta=-79.937201 -> V=1.0, theta=0.0
% INFO    : Bus 25533	: V=1.026225, theta=-79.907963 -> V=1.0, theta=0.0
% INFO    : Bus 25534	: V=1.0285331, theta=-79.951498 -> V=1.0, theta=0.0
% INFO    : Bus 25535	: V=1.0287621, theta=-79.928116 -> V=1.0, theta=0.0
% INFO    : Bus 25536	: V=1.019698, theta=-80.064618 -> V=1.0, theta=0.0
% INFO    : Bus 25537	: V=1.0270508, theta=-78.985471 -> V=1.0, theta=0.0
% INFO    : Bus 25538	: V=1.0230502, theta=-79.164737 -> V=1.0, theta=0.0
% INFO    : Bus 25539	: V=1.0228738, theta=-79.180422 -> V=1.0, theta=0.0
% INFO    : Bus 25540	: V=1.0368472, theta=-79.498528 -> V=1.0, theta=0.0
% INFO    : Bus 25541	: V=1.037104, theta=-79.474044 -> V=1.0, theta=0.0
% INFO    : Bus 25542	: V=1.0249262, theta=-80.439786 -> V=1.0, theta=0.0
% INFO    : Bus 25543	: V=1.024678, theta=-80.464355 -> V=1.0, theta=0.0
% INFO    : Bus 25544	: V=1.0194769, theta=-78.652588 -> V=1.0, theta=0.0
% INFO    : Bus 25545	: V=1.0156061, theta=-79.341159 -> V=1.0, theta=0.0
% INFO    : Bus 25546	: V=1.0217386, theta=-80.157939 -> V=1.0, theta=0.0
% INFO    : Bus 25547	: V=1.0203159, theta=-80.098612 -> V=1.0, theta=0.0
% INFO    : Bus 25548	: V=1.0284252, theta=-80.005864 -> V=1.0, theta=0.0
% INFO    : Bus 25549	: V=1.0250766, theta=-78.103956 -> V=1.0, theta=0.0
% INFO    : Bus 25550	: V=1.0231488, theta=-79.276018 -> V=1.0, theta=0.0
% INFO    : Bus 25551	: V=1.0278266, theta=-80.028691 -> V=1.0, theta=0.0
% INFO    : Bus 25552	: V=1.0207153, theta=-80.50893 -> V=1.0, theta=0.0
% INFO    : Bus 25553	: V=1.020461, theta=-80.542913 -> V=1.0, theta=0.0
% INFO    : Bus 25554	: V=1.022243, theta=-80.51811 -> V=1.0, theta=0.0
% INFO    : Bus 25555	: V=1.0225232, theta=-80.468747 -> V=1.0, theta=0.0
% INFO    : Bus 25556	: V=1.0202528, theta=-80.632778 -> V=1.0, theta=0.0
% INFO    : Bus 25557	: V=1.0177675, theta=-76.344562 -> V=1.0, theta=0.0
% INFO    : Bus 25558	: V=1.0251602, theta=-79.928221 -> V=1.0, theta=0.0
% INFO    : Bus 25559	: V=1.0175147, theta=-76.374068 -> V=1.0, theta=0.0
% INFO    : Bus 25560	: V=1.0230889, theta=-78.64399 -> V=1.0, theta=0.0
% INFO    : Bus 25561	: V=1.021167, theta=-79.776321 -> V=1.0, theta=0.0
% INFO    : Bus 25562	: V=1.0241736, theta=-80.98352 -> V=1.0, theta=0.0
% INFO    : Bus 25563	: V=1.0259662, theta=-79.96614 -> V=1.0, theta=0.0
% INFO    : Bus 25564	: V=1.0194122, theta=-80.186989 -> V=1.0, theta=0.0
% INFO    : Bus 25565	: V=1.0215411, theta=-80.804881 -> V=1.0, theta=0.0
% INFO    : Bus 25566	: V=1.0237782, theta=-78.396723 -> V=1.0, theta=0.0
% INFO    : Bus 25567	: V=1.020166, theta=-78.350678 -> V=1.0, theta=0.0
% INFO    : Bus 25568	: V=1.0198738, theta=-78.370687 -> V=1.0, theta=0.0
% INFO    : Bus 25569	: V=1.024216, theta=-80.425762 -> V=1.0, theta=0.0
% INFO    : Bus 25570	: V=1.0198066, theta=-80.579938 -> V=1.0, theta=0.0
% INFO    : Bus 25571	: V=1.0124136, theta=-80.148938 -> V=1.0, theta=0.0
% INFO    : Bus 25572	: V=1.0120447, theta=-80.1778 -> V=1.0, theta=0.0
% INFO    : Bus 25573	: V=1.0243601, theta=-80.103534 -> V=1.0, theta=0.0
% INFO    : Bus 25574	: V=1.0234147, theta=-79.148933 -> V=1.0, theta=0.0
% INFO    : Bus 25575	: V=1.0192259, theta=-76.361454 -> V=1.0, theta=0.0
% INFO    : Bus 25576	: V=1.0280496, theta=-79.758169 -> V=1.0, theta=0.0
% INFO    : Bus 25577	: V=1.0163322, theta=-79.666449 -> V=1.0, theta=0.0
% INFO    : Bus 25578	: V=1.0168222, theta=-79.635091 -> V=1.0, theta=0.0
% INFO    : Bus 25579	: V=1.023933, theta=-78.871482 -> V=1.0, theta=0.0
% INFO    : Bus 25580	: V=1.0219445, theta=-79.950845 -> V=1.0, theta=0.0
% INFO    : Bus 25581	: V=1.0209285, theta=-79.655269 -> V=1.0, theta=0.0
% INFO    : Bus 25582	: V=1.0242062, theta=-79.729401 -> V=1.0, theta=0.0
% INFO    : Bus 25583	: V=1.0235836, theta=-79.758534 -> V=1.0, theta=0.0
% INFO    : Bus 25584	: V=1.0248356, theta=-79.700597 -> V=1.0, theta=0.0
% INFO    : Bus 25585	: V=1.0242062, theta=-79.729401 -> V=1.0, theta=0.0
% INFO    : Bus 25586	: V=1.0085508, theta=-80.199169 -> V=1.0, theta=0.0
% INFO    : Bus 25587	: V=1.0263876, theta=-80.292087 -> V=1.0, theta=0.0
% INFO    : Bus 25588	: V=1.0241009, theta=-80.238481 -> V=1.0, theta=0.0
% INFO    : Bus 25589	: V=1.0238189, theta=-80.266356 -> V=1.0, theta=0.0
% INFO    : Bus 25590	: V=1.0251863, theta=-78.571263 -> V=1.0, theta=0.0
% INFO    : Bus 25591	: V=1.0151107, theta=-80.253927 -> V=1.0, theta=0.0
% INFO    : Bus 25592	: V=1.0148494, theta=-80.267091 -> V=1.0, theta=0.0
% INFO    : Bus 25593	: V=1.0181832, theta=-80.351451 -> V=1.0, theta=0.0
% INFO    : Bus 25594	: V=1.0205254, theta=-76.016223 -> V=1.0, theta=0.0
% INFO    : Bus 25595	: V=1.0167302, theta=-79.904338 -> V=1.0, theta=0.0
% INFO    : Bus 25596	: V=1.0173019, theta=-78.83834 -> V=1.0, theta=0.0
% INFO    : Bus 25597	: V=1.0173019, theta=-78.83834 -> V=1.0, theta=0.0
% INFO    : Bus 25598	: V=1.0296124, theta=-79.911291 -> V=1.0, theta=0.0
% INFO    : Bus 25599	: V=1.009684, theta=-74.44775 -> V=1.0, theta=0.0
% INFO    : Bus 25600	: V=1.0099901, theta=-74.428624 -> V=1.0, theta=0.0
% INFO    : Bus 25601	: V=1.0016987, theta=-75.999486 -> V=1.0, theta=0.0
% INFO    : Bus 25602	: V=1.0019334, theta=-75.976971 -> V=1.0, theta=0.0
% INFO    : Bus 25603	: V=1.0231563, theta=-80.102472 -> V=1.0, theta=0.0
% INFO    : Bus 25604	: V=1.0233396, theta=-80.08229 -> V=1.0, theta=0.0
% INFO    : Bus 25605	: V=1.0220109, theta=-79.637338 -> V=1.0, theta=0.0
% INFO    : Bus 25606	: V=1.018753, theta=-79.030776 -> V=1.0, theta=0.0
% INFO    : Bus 25607	: V=1.0232398, theta=-80.20793 -> V=1.0, theta=0.0
% INFO    : Bus 25608	: V=1.0213042, theta=-80.268685 -> V=1.0, theta=0.0
% INFO    : Bus 25609	: V=1.0219055, theta=-79.643867 -> V=1.0, theta=0.0
% INFO    : Bus 25610	: V=1.0237287, theta=-80.810586 -> V=1.0, theta=0.0
% INFO    : Bus 25611	: V=1.0235743, theta=-80.826368 -> V=1.0, theta=0.0
% INFO    : Bus 25612	: V=1.0211703, theta=-80.447245 -> V=1.0, theta=0.0
% INFO    : Bus 25613	: V=1.0207857, theta=-80.486342 -> V=1.0, theta=0.0
% INFO    : Bus 25614	: V=1.0074209, theta=-80.58114 -> V=1.0, theta=0.0
% INFO    : Bus 25615	: V=1.0080095, theta=-80.541887 -> V=1.0, theta=0.0
% INFO    : Bus 25616	: V=1.0074209, theta=-80.58114 -> V=1.0, theta=0.0
% INFO    : Bus 25617	: V=1.0180415, theta=-80.120528 -> V=1.0, theta=0.0
% INFO    : Bus 25618	: V=1.0175652, theta=-80.176314 -> V=1.0, theta=0.0
% INFO    : Bus 25619	: V=1.0113602, theta=-80.794373 -> V=1.0, theta=0.0
% INFO    : Bus 25620	: V=1.0177788, theta=-78.828918 -> V=1.0, theta=0.0
% INFO    : Bus 25621	: V=1.0176663, theta=-80.086198 -> V=1.0, theta=0.0
% INFO    : Bus 25622	: V=1.0222418, theta=-80.236894 -> V=1.0, theta=0.0
% INFO    : Bus 25623	: V=1.022131, theta=-80.252683 -> V=1.0, theta=0.0
% INFO    : Bus 25624	: V=1.0220065, theta=-80.70668 -> V=1.0, theta=0.0
% INFO    : Bus 25625	: V=1.0219714, theta=-80.544802 -> V=1.0, theta=0.0
% INFO    : Bus 25626	: V=1.0221231, theta=-80.521615 -> V=1.0, theta=0.0
% INFO    : Bus 25627	: V=1.0219714, theta=-80.544802 -> V=1.0, theta=0.0
% INFO    : Bus 25628	: V=1.0192403, theta=-80.87205 -> V=1.0, theta=0.0
% INFO    : Bus 25629	: V=1.0093414, theta=-80.067419 -> V=1.0, theta=0.0
% INFO    : Bus 25630	: V=1.0089845, theta=-80.092767 -> V=1.0, theta=0.0
% INFO    : Bus 25631	: V=1.0097212, theta=-80.038653 -> V=1.0, theta=0.0
% INFO    : Bus 25632	: V=1.0183993, theta=-76.183478 -> V=1.0, theta=0.0
% INFO    : Bus 25633	: V=1.0343087, theta=-80.592562 -> V=1.0, theta=0.0
% INFO    : Bus 25634	: V=1.0301143, theta=-80.333701 -> V=1.0, theta=0.0
% INFO    : Bus 25635	: V=1.0152638, theta=-79.26576 -> V=1.0, theta=0.0
% INFO    : Bus 25636	: V=1.0154933, theta=-79.238367 -> V=1.0, theta=0.0
% INFO    : Bus 25637	: V=1.0156084, theta=-80.514559 -> V=1.0, theta=0.0
% INFO    : Bus 25638	: V=1.0153865, theta=-80.534542 -> V=1.0, theta=0.0
% INFO    : Bus 25639	: V=1.0232855, theta=-74.659962 -> V=1.0, theta=0.0
% INFO    : Bus 25640	: V=1.0140422, theta=-77.737489 -> V=1.0, theta=0.0
% INFO    : Bus 25641	: V=1.0228787, theta=-74.694845 -> V=1.0, theta=0.0
% INFO    : Bus 25642	: V=1.0105915, theta=-79.575298 -> V=1.0, theta=0.0
% INFO    : Bus 25643	: V=1.0190257, theta=-80.140941 -> V=1.0, theta=0.0
% INFO    : Bus 25644	: V=1.0211223, theta=-80.003069 -> V=1.0, theta=0.0
% INFO    : Bus 25645	: V=1.021021, theta=-80.025779 -> V=1.0, theta=0.0
% INFO    : Bus 25646	: V=1.0247131, theta=-78.683066 -> V=1.0, theta=0.0
% INFO    : Bus 25647	: V=1.0225462, theta=-79.102043 -> V=1.0, theta=0.0
% INFO    : Bus 25648	: V=1.0224504, theta=-79.115956 -> V=1.0, theta=0.0
% INFO    : Bus 25649	: V=1.0226399, theta=-79.087141 -> V=1.0, theta=0.0
% INFO    : Bus 25650	: V=1.0225462, theta=-79.102043 -> V=1.0, theta=0.0
% INFO    : Bus 25651	: V=1.0197807, theta=-80.360957 -> V=1.0, theta=0.0
% INFO    : Bus 25652	: V=1.0174894, theta=-80.257392 -> V=1.0, theta=0.0
% INFO    : Bus 25653	: V=1.0172697, theta=-80.275377 -> V=1.0, theta=0.0
% INFO    : Bus 25654	: V=1.0261771, theta=-80.177251 -> V=1.0, theta=0.0
% INFO    : Bus 25655	: V=1.0258845, theta=-80.206918 -> V=1.0, theta=0.0
% INFO    : Bus 25656	: V=1.0264617, theta=-80.147435 -> V=1.0, theta=0.0
% INFO    : Bus 25657	: V=0.9954868, theta=-80.876325 -> V=1.0, theta=0.0
% INFO    : Bus 25658	: V=1.0213919, theta=-80.835184 -> V=1.0, theta=0.0
% INFO    : Bus 25659	: V=1.0203682, theta=-80.984547 -> V=1.0, theta=0.0
% INFO    : Bus 25660	: V=1.0228851, theta=-80.427616 -> V=1.0, theta=0.0
% INFO    : Bus 25661	: V=1.0265753, theta=-81.030763 -> V=1.0, theta=0.0
% INFO    : Bus 25662	: V=1.0263764, theta=-81.060879 -> V=1.0, theta=0.0
% INFO    : Bus 25663	: V=1.0274711, theta=-80.828268 -> V=1.0, theta=0.0
% INFO    : Bus 25664	: V=1.0105662, theta=-80.240886 -> V=1.0, theta=0.0
% INFO    : Bus 25665	: V=1.0226274, theta=-80.952639 -> V=1.0, theta=0.0
% INFO    : Bus 25666	: V=1.0161607, theta=-80.83203 -> V=1.0, theta=0.0
% INFO    : Bus 25667	: V=1.0161607, theta=-80.83203 -> V=1.0, theta=0.0
% INFO    : Bus 25668	: V=1.0161607, theta=-80.83203 -> V=1.0, theta=0.0
% INFO    : Bus 25669	: V=1.0161607, theta=-80.83203 -> V=1.0, theta=0.0
% INFO    : Bus 25670	: V=1.0157257, theta=-80.859661 -> V=1.0, theta=0.0
% INFO    : Bus 25671	: V=1.0165912, theta=-80.804329 -> V=1.0, theta=0.0
% INFO    : Bus 25672	: V=1.0127118, theta=-80.041966 -> V=1.0, theta=0.0
% INFO    : Bus 25673	: V=1.0160691, theta=-80.062412 -> V=1.0, theta=0.0
% INFO    : Bus 25674	: V=1.0243041, theta=-76.531088 -> V=1.0, theta=0.0
% INFO    : Bus 25675	: V=0.9967043, theta=-80.755134 -> V=1.0, theta=0.0
% INFO    : Bus 25676	: V=0.9610112, theta=-89.096611 -> V=1.0, theta=0.0
% INFO    : Bus 25677	: V=0.9610112, theta=-89.096611 -> V=1.0, theta=0.0
% INFO    : Bus 25678	: V=1.0121101, theta=-80.860362 -> V=1.0, theta=0.0
% INFO    : Bus 25679	: V=1.0119637, theta=-80.87724 -> V=1.0, theta=0.0
% INFO    : Bus 25680	: V=1.0122428, theta=-80.844457 -> V=1.0, theta=0.0
% INFO    : Bus 25681	: V=1.0187943, theta=-79.014747 -> V=1.0, theta=0.0
% INFO    : Bus 25682	: V=1.0186852, theta=-79.037173 -> V=1.0, theta=0.0
% INFO    : Bus 25683	: V=1.0189199, theta=-78.991763 -> V=1.0, theta=0.0
% INFO    : Bus 25684	: V=1.02047, theta=-79.915921 -> V=1.0, theta=0.0
% INFO    : Bus 25685	: V=1.0188757, theta=-79.122527 -> V=1.0, theta=0.0
% INFO    : Bus 25686	: V=1.0198418, theta=-80.176305 -> V=1.0, theta=0.0
% INFO    : Bus 25687	: V=1.0203006, theta=-80.99123 -> V=1.0, theta=0.0
% INFO    : Bus 25688	: V=1.0141759, theta=-80.082658 -> V=1.0, theta=0.0
% INFO    : Bus 25689	: V=1.0139957, theta=-80.097662 -> V=1.0, theta=0.0
% INFO    : Bus 25690	: V=1.0216373, theta=-80.974097 -> V=1.0, theta=0.0
% INFO    : Bus 25691	: V=1.016421, theta=-81.005072 -> V=1.0, theta=0.0
% INFO    : Bus 25692	: V=1.0165343, theta=-80.986715 -> V=1.0, theta=0.0
% INFO    : Bus 25693	: V=1.0181761, theta=-80.353717 -> V=1.0, theta=0.0
% INFO    : Bus 25694	: V=1.0158624, theta=-80.728332 -> V=1.0, theta=0.0
% INFO    : Bus 25695	: V=1.0131868, theta=-80.913209 -> V=1.0, theta=0.0
% INFO    : Bus 25696	: V=1.0246801, theta=-81.001522 -> V=1.0, theta=0.0
% INFO    : Bus 25697	: V=1.0245186, theta=-81.02031 -> V=1.0, theta=0.0
% INFO    : Bus 25698	: V=1.0228634, theta=-81.109315 -> V=1.0, theta=0.0
% INFO    : Bus 25699	: V=1.010436, theta=-79.933196 -> V=1.0, theta=0.0
% INFO    : Bus 25700	: V=1.0191008, theta=-79.551731 -> V=1.0, theta=0.0
% INFO    : Bus 25701	: V=1.0188665, theta=-79.577023 -> V=1.0, theta=0.0
% INFO    : Bus 25702	: V=1.0127398, theta=-81.395111 -> V=1.0, theta=0.0
% INFO    : Bus 25703	: V=1.0258016, theta=-81.159364 -> V=1.0, theta=0.0
% INFO    : Bus 25704	: V=1.0255925, theta=-81.173168 -> V=1.0, theta=0.0
% INFO    : Bus 25705	: V=1.0173094, theta=-80.547388 -> V=1.0, theta=0.0
% INFO    : Bus 25706	: V=1.0228461, theta=-81.305366 -> V=1.0, theta=0.0
% INFO    : Bus 25707	: V=1.0227063, theta=-81.323272 -> V=1.0, theta=0.0
% INFO    : Bus 25708	: V=1.0236416, theta=-80.885545 -> V=1.0, theta=0.0
% INFO    : Bus 25709	: V=1.0085649, theta=-80.27523 -> V=1.0, theta=0.0
% INFO    : Bus 25710	: V=0.99319, theta=-75.578625 -> V=1.0, theta=0.0
% INFO    : Bus 25711	: V=0.9929063, theta=-75.598095 -> V=1.0, theta=0.0
% INFO    : Bus 25712	: V=1.0115447, theta=-77.628731 -> V=1.0, theta=0.0
% INFO    : Bus 25713	: V=1.0082956, theta=-76.490639 -> V=1.0, theta=0.0
% INFO    : Bus 25714	: V=1.030876, theta=-80.795402 -> V=1.0, theta=0.0
% INFO    : Bus 25715	: V=1.0122327, theta=-80.12904 -> V=1.0, theta=0.0
% INFO    : Bus 25716	: V=1.0236105, theta=-80.913803 -> V=1.0, theta=0.0
% INFO    : Bus 25717	: V=1.0118441, theta=-81.255267 -> V=1.0, theta=0.0
% INFO    : Bus 25718	: V=1.0236231, theta=-81.009757 -> V=1.0, theta=0.0
% INFO    : Bus 25719	: V=1.0156807, theta=-80.437851 -> V=1.0, theta=0.0
% INFO    : Bus 25720	: V=1.0158338, theta=-80.414314 -> V=1.0, theta=0.0
% INFO    : Bus 25721	: V=1.0230348, theta=-81.279133 -> V=1.0, theta=0.0
% INFO    : Bus 25722	: V=1.0225721, theta=-81.310797 -> V=1.0, theta=0.0
% INFO    : Bus 25723	: V=1.0191884, theta=-81.290018 -> V=1.0, theta=0.0
% INFO    : Bus 25724	: V=1.0186598, theta=-80.675369 -> V=1.0, theta=0.0
% INFO    : Bus 25725	: V=1.0185388, theta=-80.691563 -> V=1.0, theta=0.0
% INFO    : Bus 25726	: V=1.0169174, theta=-80.421658 -> V=1.0, theta=0.0
% INFO    : Bus 25727	: V=1.0222196, theta=-74.384863 -> V=1.0, theta=0.0
% INFO    : Bus 25728	: V=1.0194042, theta=-81.617934 -> V=1.0, theta=0.0
% INFO    : Bus 25729	: V=1.0192407, theta=-76.60637 -> V=1.0, theta=0.0
% INFO    : Bus 25730	: V=1.0129325, theta=-80.365905 -> V=1.0, theta=0.0
% INFO    : Bus 25731	: V=1.0202868, theta=-81.409948 -> V=1.0, theta=0.0
% INFO    : Bus 25732	: V=1.0199005, theta=-81.450012 -> V=1.0, theta=0.0
% INFO    : Bus 25733	: V=1.0206883, theta=-81.374823 -> V=1.0, theta=0.0
% INFO    : Bus 25734	: V=1.0170488, theta=-81.092932 -> V=1.0, theta=0.0
% INFO    : Bus 25735	: V=1.0166292, theta=-81.133128 -> V=1.0, theta=0.0
% INFO    : Bus 25736	: V=1.0155974, theta=-80.991592 -> V=1.0, theta=0.0
% INFO    : Bus 25737	: V=1.0234551, theta=-80.767792 -> V=1.0, theta=0.0
% INFO    : Bus 25738	: V=1.0147356, theta=-80.31057 -> V=1.0, theta=0.0
% INFO    : Bus 25739	: V=1.0148768, theta=-81.399144 -> V=1.0, theta=0.0
% INFO    : Bus 25740	: V=0.9978379, theta=-80.750344 -> V=1.0, theta=0.0
% INFO    : Bus 25741	: V=0.997405, theta=-80.782586 -> V=1.0, theta=0.0
% INFO    : Bus 25742	: V=0.9983217, theta=-80.712823 -> V=1.0, theta=0.0
% INFO    : Bus 25743	: V=1.0163251, theta=-80.709932 -> V=1.0, theta=0.0
% INFO    : Bus 25744	: V=1.0212373, theta=-81.324425 -> V=1.0, theta=0.0
% INFO    : Bus 25745	: V=1.0164446, theta=-80.845326 -> V=1.0, theta=0.0
% INFO    : Bus 25746	: V=1.0161447, theta=-80.875319 -> V=1.0, theta=0.0
% INFO    : Bus 25747	: V=1.025423, theta=-81.237124 -> V=1.0, theta=0.0
% INFO    : Bus 25748	: V=1.0156662, theta=-80.989113 -> V=1.0, theta=0.0
% INFO    : Bus 25749	: V=1.0161599, theta=-80.601545 -> V=1.0, theta=0.0
% INFO    : Bus 25750	: V=1.0208729, theta=-81.395758 -> V=1.0, theta=0.0
% INFO    : Bus 25751	: V=1.0209823, theta=-81.380145 -> V=1.0, theta=0.0
% INFO    : Bus 25752	: V=1.02138, theta=-81.205757 -> V=1.0, theta=0.0
% INFO    : Bus 25753	: V=1.0041653, theta=-80.931092 -> V=1.0, theta=0.0
% INFO    : Bus 25754	: V=1.0157698, theta=-81.479583 -> V=1.0, theta=0.0
% INFO    : Bus 25755	: V=1.0198137, theta=-81.16436 -> V=1.0, theta=0.0
% INFO    : Bus 25756	: V=1.0196427, theta=-81.182375 -> V=1.0, theta=0.0
% INFO    : Bus 25757	: V=1.0199681, theta=-81.148486 -> V=1.0, theta=0.0
% INFO    : Bus 25758	: V=1.0198137, theta=-81.16436 -> V=1.0, theta=0.0
% INFO    : Bus 25759	: V=1.0214242, theta=-81.315927 -> V=1.0, theta=0.0
% INFO    : Bus 25760	: V=1.0082727, theta=-83.639563 -> V=1.0, theta=0.0
% INFO    : Bus 25761	: V=1.0215459, theta=-81.287453 -> V=1.0, theta=0.0
% INFO    : Bus 25762	: V=1.0215459, theta=-81.287453 -> V=1.0, theta=0.0
% INFO    : Bus 25763	: V=1.0267842, theta=-81.100144 -> V=1.0, theta=0.0
% INFO    : Bus 25764	: V=1.0365746, theta=-70.007614 -> V=1.0, theta=0.0
% INFO    : Bus 25765	: V=1.0031945, theta=-79.672393 -> V=1.0, theta=0.0
% INFO    : Bus 25766	: V=1.0034613, theta=-79.641042 -> V=1.0, theta=0.0
% INFO    : Bus 25767	: V=1.015153, theta=-75.635895 -> V=1.0, theta=0.0
% INFO    : Bus 25768	: V=1.0128187, theta=-79.800396 -> V=1.0, theta=0.0
% INFO    : Bus 25769	: V=0.9940189, theta=-88.338985 -> V=1.0, theta=0.0
% INFO    : Bus 25770	: V=1.0193977, theta=-80.91976 -> V=1.0, theta=0.0
% INFO    : Bus 25771	: V=1.0156221, theta=-75.517922 -> V=1.0, theta=0.0
% INFO    : Bus 25772	: V=1.015153, theta=-75.635895 -> V=1.0, theta=0.0
% INFO    : Bus 25773	: V=0.986289, theta=-73.934645 -> V=1.0, theta=0.0
% INFO    : Bus 25774	: V=1.0246019, theta=-73.306154 -> V=1.0, theta=0.0
% INFO    : Bus 25775	: V=1.0257652, theta=-73.424517 -> V=1.0, theta=0.0
% INFO    : Bus 25776	: V=1.0253379, theta=-73.381128 -> V=1.0, theta=0.0
% INFO    : Bus 25777	: V=1.0253379, theta=-73.381128 -> V=1.0, theta=0.0
% INFO    : Bus 25778	: V=1.0242429, theta=-73.3428 -> V=1.0, theta=0.0
% INFO    : Bus 25779	: V=1.0204528, theta=-81.302112 -> V=1.0, theta=0.0
% INFO    : Bus 25780	: V=1.0205603, theta=-81.288672 -> V=1.0, theta=0.0
% INFO    : Bus 25781	: V=1.0207142, theta=-80.803567 -> V=1.0, theta=0.0
% INFO    : Bus 25782	: V=1.0205167, theta=-80.827954 -> V=1.0, theta=0.0
% INFO    : Bus 25783	: V=1.0223597, theta=-81.171885 -> V=1.0, theta=0.0
% INFO    : Bus 25784	: V=1.0169186, theta=-80.283143 -> V=1.0, theta=0.0
% INFO    : Bus 25785	: V=1.0176361, theta=-79.879154 -> V=1.0, theta=0.0
% INFO    : Bus 25786	: V=1.0168959, theta=-79.923243 -> V=1.0, theta=0.0
% INFO    : Bus 25787	: V=1.0212043, theta=-80.650971 -> V=1.0, theta=0.0
% INFO    : Bus 25788	: V=1.0210815, theta=-80.677783 -> V=1.0, theta=0.0
% INFO    : Bus 25789	: V=1.0213326, theta=-80.625203 -> V=1.0, theta=0.0
% INFO    : Bus 25790	: V=1.0184377, theta=-81.727595 -> V=1.0, theta=0.0
% INFO    : Bus 25791	: V=1.0098302, theta=-79.747853 -> V=1.0, theta=0.0
% INFO    : Bus 25792	: V=1.0098933, theta=-79.737399 -> V=1.0, theta=0.0
% INFO    : Bus 25793	: V=1.0142614, theta=-80.365681 -> V=1.0, theta=0.0
% INFO    : Bus 25794	: V=1.0132424, theta=-80.236679 -> V=1.0, theta=0.0
% INFO    : Bus 25795	: V=1.0152567, theta=-80.48275 -> V=1.0, theta=0.0
% INFO    : Bus 25796	: V=1.0151065, theta=-80.499362 -> V=1.0, theta=0.0
% INFO    : Bus 25797	: V=1.0154171, theta=-80.466198 -> V=1.0, theta=0.0
% INFO    : Bus 25798	: V=1.0175434, theta=-81.215425 -> V=1.0, theta=0.0
% INFO    : Bus 25799	: V=1.0176577, theta=-81.19776 -> V=1.0, theta=0.0
% INFO    : Bus 25800	: V=1.0134652, theta=-79.622367 -> V=1.0, theta=0.0
% INFO    : Bus 25801	: V=1.0133356, theta=-79.641982 -> V=1.0, theta=0.0
% INFO    : Bus 25802	: V=1.0128155, theta=-80.381237 -> V=1.0, theta=0.0
% INFO    : Bus 25803	: V=1.0053807, theta=-77.290298 -> V=1.0, theta=0.0
% INFO    : Bus 25804	: V=1.0026764, theta=-80.307489 -> V=1.0, theta=0.0
% INFO    : Bus 25805	: V=1.0027625, theta=-83.331398 -> V=1.0, theta=0.0
% INFO    : Bus 25806	: V=1.0027625, theta=-83.331398 -> V=1.0, theta=0.0
% INFO    : Bus 25807	: V=1.0191961, theta=-81.093633 -> V=1.0, theta=0.0
% INFO    : Bus 25808	: V=1.0189384, theta=-81.134039 -> V=1.0, theta=0.0
% INFO    : Bus 25809	: V=1.0194459, theta=-81.056522 -> V=1.0, theta=0.0
% INFO    : Bus 25810	: V=1.0175839, theta=-80.372296 -> V=1.0, theta=0.0
% INFO    : Bus 25811	: V=1.0088435, theta=-76.422571 -> V=1.0, theta=0.0
% INFO    : Bus 25812	: V=1.0225701, theta=-79.995002 -> V=1.0, theta=0.0
% INFO    : Bus 25813	: V=1.0111836, theta=-76.344425 -> V=1.0, theta=0.0
% INFO    : Bus 25814	: V=1.0188352, theta=-79.959981 -> V=1.0, theta=0.0
% INFO    : Bus 25815	: V=1.0131666, theta=-80.425288 -> V=1.0, theta=0.0
% INFO    : Bus 25816	: V=1.0412791, theta=-67.982291 -> V=1.0, theta=0.0
% INFO    : Bus 25817	: V=1.0411117, theta=-67.996889 -> V=1.0, theta=0.0
% INFO    : Bus 25818	: V=1.0412727, theta=-67.982933 -> V=1.0, theta=0.0
% INFO    : Bus 25819	: V=1.0414855, theta=-67.965274 -> V=1.0, theta=0.0
% INFO    : Bus 25820	: V=1.0406622, theta=-68.201805 -> V=1.0, theta=0.0
% INFO    : Bus 25821	: V=1.0405756, theta=-68.220332 -> V=1.0, theta=0.0
% INFO    : Bus 25822	: V=1.0086885, theta=-78.773812 -> V=1.0, theta=0.0
% INFO    : Bus 25823	: V=1.0087296, theta=-78.768925 -> V=1.0, theta=0.0
% INFO    : Bus 25824	: V=1.0256281, theta=-70.358104 -> V=1.0, theta=0.0
% INFO    : Bus 25825	: V=1.0342615, theta=-72.721466 -> V=1.0, theta=0.0
% INFO    : Bus 25826	: V=1.0261094, theta=-76.367876 -> V=1.0, theta=0.0
% INFO    : Bus 25827	: V=1.0218992, theta=-80.772263 -> V=1.0, theta=0.0
% INFO    : Bus 25828	: V=1.0218992, theta=-80.772263 -> V=1.0, theta=0.0
% INFO    : Bus 25829	: V=1.0256281, theta=-70.358104 -> V=1.0, theta=0.0
% INFO    : Bus 25830	: V=1.0435841, theta=-68.385758 -> V=1.0, theta=0.0
% INFO    : Bus 25831	: V=1.0269086, theta=-70.221967 -> V=1.0, theta=0.0
% INFO    : Bus 25832	: V=1.033442, theta=-70.886878 -> V=1.0, theta=0.0
% INFO    : Bus 25833	: V=1.0309227, theta=-71.106784 -> V=1.0, theta=0.0
% INFO    : Bus 25834	: V=1.0425956, theta=-69.194983 -> V=1.0, theta=0.0
% INFO    : Bus 25835	: V=1.0328834, theta=-69.470536 -> V=1.0, theta=0.0
% INFO    : Bus 25836	: V=1.025637, theta=-79.073419 -> V=1.0, theta=0.0
% INFO    : Bus 25837	: V=1.0326669, theta=-76.978106 -> V=1.0, theta=0.0
% INFO    : Bus 25838	: V=1.0254539, theta=-79.087328 -> V=1.0, theta=0.0
% INFO    : Bus 25839	: V=1.0255941, theta=-70.794207 -> V=1.0, theta=0.0
% INFO    : Bus 25840	: V=1.034113, theta=-76.011543 -> V=1.0, theta=0.0
% INFO    : Bus 25841	: V=1.0335859, theta=-76.045061 -> V=1.0, theta=0.0
% INFO    : Bus 25842	: V=1.034113, theta=-76.011543 -> V=1.0, theta=0.0
% INFO    : Bus 25843	: V=1.0359075, theta=-66.031262 -> V=1.0, theta=0.0
% INFO    : Bus 25844	: V=1.0357167, theta=-65.91394 -> V=1.0, theta=0.0
% INFO    : Bus 25845	: V=1.0359397, theta=-65.993147 -> V=1.0, theta=0.0
% INFO    : Bus 25846	: V=1.0360606, theta=-65.521616 -> V=1.0, theta=0.0
% INFO    : Bus 25847	: V=1.0359397, theta=-65.993147 -> V=1.0, theta=0.0
% INFO    : Bus 25848	: V=1.0357294, theta=-66.087763 -> V=1.0, theta=0.0
% INFO    : Bus 25849	: V=1.0359075, theta=-66.031262 -> V=1.0, theta=0.0
% INFO    : Bus 25850	: V=1.0324047, theta=-71.237249 -> V=1.0, theta=0.0
% INFO    : Bus 25851	: V=1.0284421, theta=-72.17477 -> V=1.0, theta=0.0
% INFO    : Bus 25852	: V=1.0038512, theta=-69.639657 -> V=1.0, theta=0.0
% INFO    : Bus 25853	: V=1.0234344, theta=-78.261061 -> V=1.0, theta=0.0
% INFO    : Bus 25854	: V=1.0367872, theta=-76.686996 -> V=1.0, theta=0.0
% INFO    : Bus 25855	: V=1.0363919, theta=-78.144731 -> V=1.0, theta=0.0
% INFO    : Bus 25856	: V=1.0363919, theta=-78.144731 -> V=1.0, theta=0.0
% INFO    : Bus 25857	: V=1.0226882, theta=-78.140392 -> V=1.0, theta=0.0
% INFO    : Bus 25858	: V=1.0226042, theta=-78.174604 -> V=1.0, theta=0.0
% INFO    : Bus 25859	: V=1.0356956, theta=-69.237441 -> V=1.0, theta=0.0
% INFO    : Bus 25860	: V=1.0364703, theta=-68.838185 -> V=1.0, theta=0.0
% INFO    : Bus 25861	: V=1.0363661, theta=-68.890393 -> V=1.0, theta=0.0
% INFO    : Bus 25862	: V=1.0363661, theta=-68.890393 -> V=1.0, theta=0.0
% INFO    : Bus 25863	: V=1.0356956, theta=-69.237441 -> V=1.0, theta=0.0
% INFO    : Bus 25864	: V=1.0308561, theta=-70.079025 -> V=1.0, theta=0.0
% INFO    : Bus 25865	: V=1.0325088, theta=-70.447867 -> V=1.0, theta=0.0
% INFO    : Bus 25866	: V=1.0307686, theta=-69.853342 -> V=1.0, theta=0.0
% INFO    : Bus 25867	: V=1.0083405, theta=-69.574048 -> V=1.0, theta=0.0
% INFO    : Bus 25868	: V=1.0084124, theta=-69.525815 -> V=1.0, theta=0.0
% INFO    : Bus 25869	: V=1.0330826, theta=-70.58236 -> V=1.0, theta=0.0
% INFO    : Bus 25870	: V=1.0341501, theta=-70.762359 -> V=1.0, theta=0.0
% INFO    : Bus 25871	: V=1.0331961, theta=-70.294312 -> V=1.0, theta=0.0
% INFO    : Bus 25872	: V=1.0332107, theta=-70.222652 -> V=1.0, theta=0.0
% INFO    : Bus 25873	: V=1.0331262, theta=-70.566198 -> V=1.0, theta=0.0
% INFO    : Bus 25874	: V=1.0212074, theta=-75.851775 -> V=1.0, theta=0.0
% INFO    : Bus 25875	: V=1.026062, theta=-78.331335 -> V=1.0, theta=0.0
% INFO    : Bus 25876	: V=1.0095036, theta=-73.54944 -> V=1.0, theta=0.0
% INFO    : Bus 25877	: V=1.0219956, theta=-75.823376 -> V=1.0, theta=0.0
% INFO    : Bus 25878	: V=1.0254982, theta=-80.749321 -> V=1.0, theta=0.0
% INFO    : Bus 25879	: V=1.0184532, theta=-72.866012 -> V=1.0, theta=0.0
% INFO    : Bus 25880	: V=1.0339537, theta=-71.487793 -> V=1.0, theta=0.0
% INFO    : Bus 25881	: V=1.0230981, theta=-66.488379 -> V=1.0, theta=0.0
% INFO    : Bus 25882	: V=1.0339197, theta=-71.522253 -> V=1.0, theta=0.0
% INFO    : Bus 25883	: V=1.0339537, theta=-71.487793 -> V=1.0, theta=0.0
% INFO    : Bus 25884	: V=1.0283248, theta=-70.554309 -> V=1.0, theta=0.0
% INFO    : Bus 25885	: V=1.0283722, theta=-71.572304 -> V=1.0, theta=0.0
% INFO    : Bus 25886	: V=1.0277898, theta=-71.935935 -> V=1.0, theta=0.0
% INFO    : Bus 25887	: V=1.0283248, theta=-70.554309 -> V=1.0, theta=0.0
% INFO    : Bus 25888	: V=1.0212705, theta=-80.096888 -> V=1.0, theta=0.0
% INFO    : Bus 25889	: V=1.0065853, theta=-76.285121 -> V=1.0, theta=0.0
% INFO    : Bus 25890	: V=1.0308483, theta=-69.986055 -> V=1.0, theta=0.0
% INFO    : Bus 25891	: V=1.0453616, theta=-76.02234 -> V=1.0, theta=0.0
% INFO    : Bus 25892	: V=1.0380692, theta=-72.281688 -> V=1.0, theta=0.0
% INFO    : Bus 25893	: V=1.0453325, theta=-76.051577 -> V=1.0, theta=0.0
% INFO    : Bus 25894	: V=1.0341155, theta=-70.563924 -> V=1.0, theta=0.0
% INFO    : Bus 25895	: V=1.0335709, theta=-69.734551 -> V=1.0, theta=0.0
% INFO    : Bus 25896	: V=1.0341155, theta=-70.563924 -> V=1.0, theta=0.0
% INFO    : Bus 25897	: V=1.0339892, theta=-70.602557 -> V=1.0, theta=0.0
% INFO    : Bus 25898	: V=1.0341155, theta=-70.563924 -> V=1.0, theta=0.0
% INFO    : Bus 25899	: V=1.04, theta=-68.195269 -> V=1.0, theta=0.0
% INFO    : Bus 25900	: V=1.0299502, theta=-71.210837 -> V=1.0, theta=0.0
% INFO    : Bus 25901	: V=1.02, theta=-68.7042 -> V=1.0, theta=0.0
% INFO    : Bus 25902	: V=1.0247198, theta=-71.169956 -> V=1.0, theta=0.0
% INFO    : Bus 25903	: V=1.0237393, theta=-72.139772 -> V=1.0, theta=0.0
% INFO    : Bus 25904	: V=0.9982591, theta=-67.961939 -> V=1.0, theta=0.0
% INFO    : Bus 25905	: V=0.9983809, theta=-67.927421 -> V=1.0, theta=0.0
% INFO    : Bus 25906	: V=0.9973302, theta=-68.183284 -> V=1.0, theta=0.0
% INFO    : Bus 25907	: V=0.9984181, theta=-67.925788 -> V=1.0, theta=0.0
% INFO    : Bus 25908	: V=0.997335, theta=-68.183755 -> V=1.0, theta=0.0
% INFO    : Bus 25909	: V=1.0250409, theta=-69.012972 -> V=1.0, theta=0.0
% INFO    : Bus 25910	: V=1.0335967, theta=-70.762118 -> V=1.0, theta=0.0
% INFO    : Bus 25911	: V=1.0335967, theta=-70.762118 -> V=1.0, theta=0.0
% INFO    : Bus 25912	: V=1.0335953, theta=-70.762246 -> V=1.0, theta=0.0
% INFO    : Bus 25913	: V=1.0331345, theta=-66.349878 -> V=1.0, theta=0.0
% INFO    : Bus 25914	: V=1.0606696, theta=-61.447043 -> V=1.0, theta=0.0
% INFO    : Bus 25915	: V=1.0289637, theta=-70.055414 -> V=1.0, theta=0.0
% INFO    : Bus 25916	: V=1.0368353, theta=-78.988179 -> V=1.0, theta=0.0
% INFO    : Bus 25917	: V=1.0324407, theta=-70.06285 -> V=1.0, theta=0.0
% INFO    : Bus 25918	: V=1.0170009, theta=-72.259754 -> V=1.0, theta=0.0
% INFO    : Bus 25919	: V=1.0235708, theta=-75.278368 -> V=1.0, theta=0.0
% INFO    : Bus 25920	: V=1.024958, theta=-78.272938 -> V=1.0, theta=0.0
% INFO    : Bus 25921	: V=1.02563, theta=-78.92291 -> V=1.0, theta=0.0
% INFO    : Bus 25922	: V=1.02563, theta=-78.92291 -> V=1.0, theta=0.0
% INFO    : Bus 25923	: V=1.0405114, theta=-72.710332 -> V=1.0, theta=0.0
% INFO    : Bus 25924	: V=1.0382392, theta=-73.067445 -> V=1.0, theta=0.0
% INFO    : Bus 25925	: V=1.0400348, theta=-72.784891 -> V=1.0, theta=0.0
% INFO    : Bus 25926	: V=1.035204, theta=-73.558916 -> V=1.0, theta=0.0
% INFO    : Bus 25927	: V=1.0232243, theta=-77.962529 -> V=1.0, theta=0.0
% INFO    : Bus 25928	: V=1.0231675, theta=-77.985468 -> V=1.0, theta=0.0
% INFO    : Bus 25929	: V=1.0232243, theta=-77.962529 -> V=1.0, theta=0.0
% INFO    : Bus 25930	: V=1.0212749, theta=-76.517578 -> V=1.0, theta=0.0
% INFO    : Bus 25931	: V=1.0117045, theta=-79.820773 -> V=1.0, theta=0.0
% INFO    : Bus 25932	: V=1.0273321, theta=-75.871891 -> V=1.0, theta=0.0
% INFO    : Bus 25933	: V=1.0117045, theta=-79.820773 -> V=1.0, theta=0.0
% INFO    : Bus 25934	: V=1.0295757, theta=-71.405936 -> V=1.0, theta=0.0
% INFO    : Bus 25935	: V=1.0278663, theta=-72.267936 -> V=1.0, theta=0.0
% INFO    : Bus 25936	: V=1.0300172, theta=-71.432666 -> V=1.0, theta=0.0
% INFO    : Bus 25937	: V=1.0248286, theta=-78.300368 -> V=1.0, theta=0.0
% INFO    : Bus 25938	: V=1.0186243, theta=-75.099442 -> V=1.0, theta=0.0
% INFO    : Bus 25939	: V=1.0344477, theta=-69.086687 -> V=1.0, theta=0.0
% INFO    : Bus 25940	: V=1.0039795, theta=-66.100559 -> V=1.0, theta=0.0
% INFO    : Bus 25941	: V=1.0344477, theta=-69.086687 -> V=1.0, theta=0.0
% INFO    : Bus 25942	: V=1.0343653, theta=-69.111998 -> V=1.0, theta=0.0
% INFO    : Bus 25943	: V=1.038, theta=-70.400289 -> V=1.0, theta=0.0
% INFO    : Bus 25944	: V=1.0209352, theta=-73.941202 -> V=1.0, theta=0.0
% INFO    : Bus 25945	: V=1.0331384, theta=-70.162295 -> V=1.0, theta=0.0
% INFO    : Bus 25946	: V=1.0274705, theta=-69.343985 -> V=1.0, theta=0.0
% INFO    : Bus 25947	: V=1.0264012, theta=-70.063759 -> V=1.0, theta=0.0
% INFO    : Bus 25948	: V=1.0264207, theta=-70.008275 -> V=1.0, theta=0.0
% INFO    : Bus 25949	: V=1.0268192, theta=-70.189157 -> V=1.0, theta=0.0
% INFO    : Bus 25950	: V=1.0299763, theta=-68.945149 -> V=1.0, theta=0.0
% INFO    : Bus 25951	: V=1.0246038, theta=-69.445018 -> V=1.0, theta=0.0
% INFO    : Bus 25952	: V=1.0274705, theta=-69.343985 -> V=1.0, theta=0.0
% INFO    : Bus 25953	: V=1.0076028, theta=-66.783591 -> V=1.0, theta=0.0
% INFO    : Bus 25954	: V=1.0251355, theta=-69.580151 -> V=1.0, theta=0.0
% INFO    : Bus 25955	: V=1.0274705, theta=-69.343985 -> V=1.0, theta=0.0
% INFO    : Bus 25956	: V=1.0331649, theta=-70.285813 -> V=1.0, theta=0.0
% INFO    : Bus 25957	: V=1.0324144, theta=-69.81214 -> V=1.0, theta=0.0
% INFO    : Bus 25958	: V=1.0324019, theta=-69.82725 -> V=1.0, theta=0.0
% INFO    : Bus 25959	: V=1.0310828, theta=-69.778559 -> V=1.0, theta=0.0
% INFO    : Bus 25960	: V=1.0633734, theta=-66.399371 -> V=1.0, theta=0.0
% INFO    : Bus 25961	: V=1.0506885, theta=-67.768648 -> V=1.0, theta=0.0
% INFO    : Bus 25962	: V=1.0309165, theta=-69.787285 -> V=1.0, theta=0.0
% INFO    : Bus 25963	: V=0.9974116, theta=-68.282882 -> V=1.0, theta=0.0
% INFO    : Bus 25964	: V=0.997416, theta=-68.282898 -> V=1.0, theta=0.0
% INFO    : Bus 25965	: V=0.9998557, theta=-69.889458 -> V=1.0, theta=0.0
% INFO    : Bus 25966	: V=1.0341548, theta=-70.30271 -> V=1.0, theta=0.0
% INFO    : Bus 25967	: V=1.0323569, theta=-70.276016 -> V=1.0, theta=0.0
% INFO    : Bus 25968	: V=0.9967794, theta=-68.398339 -> V=1.0, theta=0.0
% INFO    : Bus 25969	: V=0.9951297, theta=-69.207372 -> V=1.0, theta=0.0
% INFO    : Bus 25970	: V=0.9967858, theta=-65.566979 -> V=1.0, theta=0.0
% INFO    : Bus 25971	: V=1.0338293, theta=-70.371126 -> V=1.0, theta=0.0
% INFO    : Bus 25972	: V=1.0204855, theta=-75.667878 -> V=1.0, theta=0.0
% INFO    : Bus 25973	: V=1.0233443, theta=-77.96726 -> V=1.0, theta=0.0
% INFO    : Bus 25974	: V=1.0269507, theta=-69.170339 -> V=1.0, theta=0.0
% INFO    : Bus 25975	: V=1.0151315, theta=-64.756097 -> V=1.0, theta=0.0
% INFO    : Bus 25976	: V=1.0269685, theta=-69.258142 -> V=1.0, theta=0.0
% INFO    : Bus 25977	: V=1.0348904, theta=-68.899235 -> V=1.0, theta=0.0
% INFO    : Bus 25978	: V=1.033935, theta=-70.905659 -> V=1.0, theta=0.0
% INFO    : Bus 25979	: V=1.0309014, theta=-69.603447 -> V=1.0, theta=0.0
% INFO    : Bus 25980	: V=1.0274002, theta=-67.521842 -> V=1.0, theta=0.0
% INFO    : Bus 25981	: V=1.0308804, theta=-69.632451 -> V=1.0, theta=0.0
% INFO    : Bus 25982	: V=1.0383006, theta=-70.819508 -> V=1.0, theta=0.0
% INFO    : Bus 25983	: V=1.0379031, theta=-70.846252 -> V=1.0, theta=0.0
% INFO    : Bus 25984	: V=1.0255125, theta=-75.869312 -> V=1.0, theta=0.0
% INFO    : Bus 25985	: V=1.0211637, theta=-80.115382 -> V=1.0, theta=0.0
% INFO    : Bus 25986	: V=1.0262766, theta=-75.766767 -> V=1.0, theta=0.0
% INFO    : Bus 25987	: V=1.0231875, theta=-71.995522 -> V=1.0, theta=0.0
% INFO    : Bus 25988	: V=1.0249485, theta=-75.479527 -> V=1.0, theta=0.0
% INFO    : Bus 25989	: V=1.0262407, theta=-77.906136 -> V=1.0, theta=0.0
% INFO    : Bus 25990	: V=1.0286548, theta=-72.418969 -> V=1.0, theta=0.0
% INFO    : Bus 25991	: V=1.025432, theta=-73.924654 -> V=1.0, theta=0.0
% INFO    : Bus 25992	: V=1.0242168, theta=-74.603244 -> V=1.0, theta=0.0
% INFO    : Bus 25993	: V=1.0242168, theta=-74.603244 -> V=1.0, theta=0.0
% INFO    : Bus 25994	: V=1.0312051, theta=-69.684739 -> V=1.0, theta=0.0
% INFO    : Bus 25995	: V=0.961586, theta=-64.631946 -> V=1.0, theta=0.0
% INFO    : Bus 25996	: V=1.0323136, theta=-70.038975 -> V=1.0, theta=0.0
% INFO    : Bus 25997	: V=1.0323136, theta=-70.038975 -> V=1.0, theta=0.0
% INFO    : Bus 25998	: V=1.0398131, theta=-67.86051 -> V=1.0, theta=0.0
% INFO    : Bus 25999	: V=1.0212223, theta=-76.21217 -> V=1.0, theta=0.0
% INFO    : Bus 26000	: V=1.0226378, theta=-79.93505 -> V=1.0, theta=0.0
% INFO    : Bus 26001	: V=1.0243994, theta=-81.411679 -> V=1.0, theta=0.0
% INFO    : Bus 26002	: V=1.0243994, theta=-81.411679 -> V=1.0, theta=0.0
% INFO    : Bus 26003	: V=1.0269241, theta=-69.415074 -> V=1.0, theta=0.0
% INFO    : Bus 26004	: V=1.0114985, theta=-64.086195 -> V=1.0, theta=0.0
% INFO    : Bus 26005	: V=1.0358485, theta=-73.104805 -> V=1.0, theta=0.0
% INFO    : Bus 26006	: V=1.032982, theta=-76.050172 -> V=1.0, theta=0.0
% INFO    : Bus 26007	: V=1.0343071, theta=-74.344212 -> V=1.0, theta=0.0
% INFO    : Bus 26008	: V=1.0343071, theta=-74.344212 -> V=1.0, theta=0.0
% INFO    : Bus 26009	: V=1.0281418, theta=-70.050127 -> V=1.0, theta=0.0
% INFO    : Bus 26010	: V=1.0346517, theta=-70.108308 -> V=1.0, theta=0.0
% INFO    : Bus 26011	: V=1.0340418, theta=-69.351602 -> V=1.0, theta=0.0
% INFO    : Bus 26012	: V=1.0090724, theta=-69.304102 -> V=1.0, theta=0.0
% INFO    : Bus 26013	: V=1.0303676, theta=-69.616806 -> V=1.0, theta=0.0
% INFO    : Bus 26014	: V=1.026689, theta=-71.59597 -> V=1.0, theta=0.0
% INFO    : Bus 26015	: V=1.0276006, theta=-75.409896 -> V=1.0, theta=0.0
% INFO    : Bus 26016	: V=1.0285391, theta=-78.666189 -> V=1.0, theta=0.0
% INFO    : Bus 26017	: V=1.0388566, theta=-70.280222 -> V=1.0, theta=0.0
% INFO    : Bus 26018	: V=1.0413614, theta=-70.004328 -> V=1.0, theta=0.0
% INFO    : Bus 26019	: V=1.0403423, theta=-70.110842 -> V=1.0, theta=0.0
% INFO    : Bus 26020	: V=1.0370125, theta=-70.483567 -> V=1.0, theta=0.0
% INFO    : Bus 26021	: V=1.0252744, theta=-75.601783 -> V=1.0, theta=0.0
% INFO    : Bus 26022	: V=1.0063135, theta=-76.841097 -> V=1.0, theta=0.0
% INFO    : Bus 26023	: V=1.0232665, theta=-80.195822 -> V=1.0, theta=0.0
% INFO    : Bus 26024	: V=1.0084189, theta=-76.735675 -> V=1.0, theta=0.0
% INFO    : Bus 26025	: V=1.0063135, theta=-76.841097 -> V=1.0, theta=0.0
% INFO    : Bus 26026	: V=1.0235523, theta=-79.705489 -> V=1.0, theta=0.0
% INFO    : Bus 26027	: V=1.0235371, theta=-79.713899 -> V=1.0, theta=0.0
% INFO    : Bus 26028	: V=1.0235523, theta=-79.705489 -> V=1.0, theta=0.0
% INFO    : Bus 26029	: V=1.0243652, theta=-78.324526 -> V=1.0, theta=0.0
% INFO    : Bus 26030	: V=1.0354037, theta=-77.074963 -> V=1.0, theta=0.0
% INFO    : Bus 26031	: V=1.0354037, theta=-77.074963 -> V=1.0, theta=0.0
% INFO    : Bus 26032	: V=1.0376673, theta=-78.513657 -> V=1.0, theta=0.0
% INFO    : Bus 26033	: V=1.0241379, theta=-78.409194 -> V=1.0, theta=0.0
% INFO    : Bus 26034	: V=1.0302865, theta=-70.247762 -> V=1.0, theta=0.0
% INFO    : Bus 26035	: V=1.02116, theta=-70.349593 -> V=1.0, theta=0.0
% INFO    : Bus 26036	: V=1.0406469, theta=-72.797776 -> V=1.0, theta=0.0
% INFO    : Bus 26037	: V=1.0483614, theta=-75.977963 -> V=1.0, theta=0.0
% INFO    : Bus 26038	: V=1.0264419, theta=-69.643581 -> V=1.0, theta=0.0
% INFO    : Bus 26039	: V=1.025103, theta=-69.822759 -> V=1.0, theta=0.0
% INFO    : Bus 26040	: V=1.0290588, theta=-69.495108 -> V=1.0, theta=0.0
% INFO    : Bus 26041	: V=1.0227253, theta=-78.244713 -> V=1.0, theta=0.0
% INFO    : Bus 26042	: V=1.0194245, theta=-74.681289 -> V=1.0, theta=0.0
% INFO    : Bus 26043	: V=1.0227253, theta=-78.244713 -> V=1.0, theta=0.0
% INFO    : Bus 26044	: V=1.038, theta=-78.933395 -> V=1.0, theta=0.0
% INFO    : Bus 26045	: V=1.0371507, theta=-78.996715 -> V=1.0, theta=0.0
% INFO    : Bus 26046	: V=1.036, theta=-68.790885 -> V=1.0, theta=0.0
% INFO    : Bus 26047	: V=1.0407314, theta=-64.531381 -> V=1.0, theta=0.0
% INFO    : Bus 26048	: V=1.0291873, theta=-66.618274 -> V=1.0, theta=0.0
% INFO    : Bus 26049	: V=1.0318976, theta=-67.917241 -> V=1.0, theta=0.0
% INFO    : Bus 26050	: V=1.0356799, theta=-68.060119 -> V=1.0, theta=0.0
% INFO    : Bus 26051	: V=1.0291873, theta=-66.618274 -> V=1.0, theta=0.0
% INFO    : Bus 26052	: V=0.9905418, theta=-65.443362 -> V=1.0, theta=0.0
% INFO    : Bus 26053	: V=0.9896628, theta=-65.549367 -> V=1.0, theta=0.0
% INFO    : Bus 26054	: V=1.030981, theta=-69.373067 -> V=1.0, theta=0.0
% INFO    : Bus 26055	: V=1.0304778, theta=-69.598116 -> V=1.0, theta=0.0
% INFO    : Bus 26056	: V=0.9976433, theta=-65.625639 -> V=1.0, theta=0.0
% INFO    : Bus 26057	: V=1.0310622, theta=-69.361134 -> V=1.0, theta=0.0
% INFO    : Bus 26058	: V=1.0191743, theta=-72.298599 -> V=1.0, theta=0.0
% INFO    : Bus 26059	: V=1.0283936, theta=-74.724158 -> V=1.0, theta=0.0
% INFO    : Bus 26060	: V=1.0297983, theta=-78.55163 -> V=1.0, theta=0.0
% INFO    : Bus 26061	: V=1.0149835, theta=-71.375613 -> V=1.0, theta=0.0
% INFO    : Bus 26062	: V=1.0191743, theta=-72.298599 -> V=1.0, theta=0.0
% INFO    : Bus 26063	: V=1.0148637, theta=-71.391936 -> V=1.0, theta=0.0
% INFO    : Bus 26064	: V=1.016662, theta=-71.88697 -> V=1.0, theta=0.0
% INFO    : Bus 26065	: V=1.0233445, theta=-78.175152 -> V=1.0, theta=0.0
% INFO    : Bus 26066	: V=1.0233445, theta=-78.175152 -> V=1.0, theta=0.0
% INFO    : Bus 26067	: V=1.0233445, theta=-78.175152 -> V=1.0, theta=0.0
% INFO    : Bus 26068	: V=1.0233445, theta=-78.175152 -> V=1.0, theta=0.0
% INFO    : Bus 26069	: V=1.0203773, theta=-76.3465 -> V=1.0, theta=0.0
% INFO    : Bus 26070	: V=1.0233393, theta=-78.181405 -> V=1.0, theta=0.0
% INFO    : Bus 26071	: V=1.0313763, theta=-68.609803 -> V=1.0, theta=0.0
% INFO    : Bus 26072	: V=1.0317835, theta=-69.624219 -> V=1.0, theta=0.0
% INFO    : Bus 26073	: V=1.0171255, theta=-67.768857 -> V=1.0, theta=0.0
% INFO    : Bus 26074	: V=1.0295812, theta=-65.731069 -> V=1.0, theta=0.0
% INFO    : Bus 26075	: V=1.0169744, theta=-76.225953 -> V=1.0, theta=0.0
% INFO    : Bus 26076	: V=1.0261267, theta=-80.609563 -> V=1.0, theta=0.0
% INFO    : Bus 26077	: V=0.985621, theta=-75.885763 -> V=1.0, theta=0.0
% INFO    : Bus 26078	: V=0.9862337, theta=-76.256254 -> V=1.0, theta=0.0
% INFO    : Bus 26079	: V=0.9862337, theta=-76.256254 -> V=1.0, theta=0.0
% INFO    : Bus 26080	: V=1.0256379, theta=-78.292531 -> V=1.0, theta=0.0
% INFO    : Bus 26081	: V=1.0248692, theta=-78.343729 -> V=1.0, theta=0.0
% INFO    : Bus 26082	: V=1.0256379, theta=-78.292531 -> V=1.0, theta=0.0
% INFO    : Bus 26083	: V=1.0254677, theta=-72.816423 -> V=1.0, theta=0.0
% INFO    : Bus 26084	: V=1.0279698, theta=-74.763859 -> V=1.0, theta=0.0
% INFO    : Bus 26085	: V=1.0254677, theta=-72.816423 -> V=1.0, theta=0.0
% INFO    : Bus 26086	: V=1.0280631, theta=-72.55212 -> V=1.0, theta=0.0
% INFO    : Bus 26087	: V=1.0353678, theta=-68.86759 -> V=1.0, theta=0.0
% INFO    : Bus 26088	: V=1.0368794, theta=-68.607078 -> V=1.0, theta=0.0
% INFO    : Bus 26089	: V=0.980058, theta=-67.038642 -> V=1.0, theta=0.0
% INFO    : Bus 26090	: V=1.0361898, theta=-68.575842 -> V=1.0, theta=0.0
% INFO    : Bus 26091	: V=1.0365339, theta=-69.763687 -> V=1.0, theta=0.0
% INFO    : Bus 26092	: V=1.0330896, theta=-71.169801 -> V=1.0, theta=0.0
% INFO    : Bus 26093	: V=1.032362, theta=-66.596807 -> V=1.0, theta=0.0
% INFO    : Bus 26094	: V=1.02606, theta=-72.664495 -> V=1.0, theta=0.0
% INFO    : Bus 26095	: V=1.0266991, theta=-75.783533 -> V=1.0, theta=0.0
% INFO    : Bus 26096	: V=1.0276701, theta=-78.429344 -> V=1.0, theta=0.0
% INFO    : Bus 26097	: V=1.0204125, theta=-71.082873 -> V=1.0, theta=0.0
% INFO    : Bus 26098	: V=1.0195233, theta=-71.198865 -> V=1.0, theta=0.0
% INFO    : Bus 26099	: V=1.0190097, theta=-71.256019 -> V=1.0, theta=0.0
% INFO    : Bus 26100	: V=1.021661, theta=-71.69707 -> V=1.0, theta=0.0
% INFO    : Bus 26101	: V=1.0243018, theta=-71.376736 -> V=1.0, theta=0.0
% INFO    : Bus 26102	: V=1.02606, theta=-72.664495 -> V=1.0, theta=0.0
% INFO    : Bus 26103	: V=1.0245962, theta=-72.468186 -> V=1.0, theta=0.0
% INFO    : Bus 26104	: V=1.0261675, theta=-74.120308 -> V=1.0, theta=0.0
% INFO    : Bus 26105	: V=1.0245247, theta=-76.587419 -> V=1.0, theta=0.0
% INFO    : Bus 26106	: V=1.0245247, theta=-76.587419 -> V=1.0, theta=0.0
% INFO    : Bus 26107	: V=1.0245247, theta=-76.587419 -> V=1.0, theta=0.0
% INFO    : Bus 26108	: V=1.0245247, theta=-76.587419 -> V=1.0, theta=0.0
% INFO    : Bus 26109	: V=1.0351567, theta=-70.119559 -> V=1.0, theta=0.0
% INFO    : Bus 26110	: V=1.0233641, theta=-64.847697 -> V=1.0, theta=0.0
% INFO    : Bus 26111	: V=1.0351416, theta=-70.148519 -> V=1.0, theta=0.0
% INFO    : Bus 26112	: V=1.0350124, theta=-70.09203 -> V=1.0, theta=0.0
% INFO    : Bus 26113	: V=1.0332779, theta=-69.399323 -> V=1.0, theta=0.0
% INFO    : Bus 26114	: V=1.0328914, theta=-69.235839 -> V=1.0, theta=0.0
% INFO    : Bus 26115	: V=1.0328914, theta=-69.235839 -> V=1.0, theta=0.0
% INFO    : Bus 26116	: V=1.0452092, theta=-67.340627 -> V=1.0, theta=0.0
% INFO    : Bus 26117	: V=1.0404412, theta=-68.987981 -> V=1.0, theta=0.0
% INFO    : Bus 26118	: V=1.0338908, theta=-70.25344 -> V=1.0, theta=0.0
% INFO    : Bus 26119	: V=1.030638, theta=-70.784414 -> V=1.0, theta=0.0
% INFO    : Bus 26120	: V=1.030638, theta=-70.784414 -> V=1.0, theta=0.0
% INFO    : Bus 26121	: V=1.0009305, theta=-65.967641 -> V=1.0, theta=0.0
% INFO    : Bus 26122	: V=1.0026799, theta=-67.507593 -> V=1.0, theta=0.0
% INFO    : Bus 26123	: V=1.0306296, theta=-70.800368 -> V=1.0, theta=0.0
% INFO    : Bus 26124	: V=1.030638, theta=-70.784414 -> V=1.0, theta=0.0
% INFO    : Bus 26125	: V=1.0069507, theta=-73.03069 -> V=1.0, theta=0.0
% INFO    : Bus 26126	: V=1.035856, theta=-74.80394 -> V=1.0, theta=0.0
% INFO    : Bus 26127	: V=1.0374702, theta=-78.979853 -> V=1.0, theta=0.0
% INFO    : Bus 26128	: V=1.0069507, theta=-73.03069 -> V=1.0, theta=0.0
% INFO    : Bus 26129	: V=1.0150472, theta=-72.144605 -> V=1.0, theta=0.0
% INFO    : Bus 26130	: V=1.02312, theta=-62.047529 -> V=1.0, theta=0.0
% INFO    : Bus 26131	: V=1.0295995, theta=-64.386431 -> V=1.0, theta=0.0
% INFO    : Bus 26132	: V=1.0315469, theta=-66.865688 -> V=1.0, theta=0.0
% INFO    : Bus 26133	: V=1.0249633, theta=-58.714788 -> V=1.0, theta=0.0
% INFO    : Bus 26134	: V=1.02491, theta=-58.445913 -> V=1.0, theta=0.0
% INFO    : Bus 26135	: V=1.0233868, theta=-62.549443 -> V=1.0, theta=0.0
% INFO    : Bus 26136	: V=1.0297151, theta=-64.739229 -> V=1.0, theta=0.0
% INFO    : Bus 26137	: V=1.0259261, theta=-79.049547 -> V=1.0, theta=0.0
% INFO    : Bus 26138	: V=1.0259261, theta=-79.049547 -> V=1.0, theta=0.0
% INFO    : Bus 26139	: V=1.0259261, theta=-79.049547 -> V=1.0, theta=0.0
% INFO    : Bus 26140	: V=1.0259261, theta=-79.049547 -> V=1.0, theta=0.0
% INFO    : Bus 26141	: V=1.0411769, theta=-76.069942 -> V=1.0, theta=0.0
% INFO    : Bus 26142	: V=1.0284947, theta=-64.723931 -> V=1.0, theta=0.0
% INFO    : Bus 26143	: V=1.0330662, theta=-65.580733 -> V=1.0, theta=0.0
% INFO    : Bus 26144	: V=1.0355997, theta=-67.079608 -> V=1.0, theta=0.0
% INFO    : Bus 26145	: V=1.0284947, theta=-64.723931 -> V=1.0, theta=0.0
% INFO    : Bus 26146	: V=1.0285818, theta=-64.062583 -> V=1.0, theta=0.0
% INFO    : Bus 26147	: V=1.0285636, theta=-64.107795 -> V=1.0, theta=0.0
% INFO    : Bus 26148	: V=1.0285665, theta=-64.158917 -> V=1.0, theta=0.0
% INFO    : Bus 26149	: V=1.0284947, theta=-64.723931 -> V=1.0, theta=0.0
% INFO    : Bus 26150	: V=1.0253799, theta=-72.679779 -> V=1.0, theta=0.0
% INFO    : Bus 26151	: V=1.0252405, theta=-72.722678 -> V=1.0, theta=0.0
% INFO    : Bus 26152	: V=1.0297182, theta=-66.578852 -> V=1.0, theta=0.0
% INFO    : Bus 26153	: V=1.0301058, theta=-67.895288 -> V=1.0, theta=0.0
% INFO    : Bus 26154	: V=1.0346242, theta=-68.694753 -> V=1.0, theta=0.0
% INFO    : Bus 26155	: V=1.0311741, theta=-69.356591 -> V=1.0, theta=0.0
% INFO    : Bus 26156	: V=1.0311741, theta=-69.356591 -> V=1.0, theta=0.0
% INFO    : Bus 26157	: V=0.9985794, theta=-66.215037 -> V=1.0, theta=0.0
% INFO    : Bus 26158	: V=0.9985825, theta=-65.842507 -> V=1.0, theta=0.0
% INFO    : Bus 26159	: V=1.0297182, theta=-66.578852 -> V=1.0, theta=0.0
% INFO    : Bus 26160	: V=1.0233621, theta=-66.13842 -> V=1.0, theta=0.0
% INFO    : Bus 26161	: V=1.0285329, theta=-67.215882 -> V=1.0, theta=0.0
% INFO    : Bus 26162	: V=1.0348054, theta=-67.618872 -> V=1.0, theta=0.0
% INFO    : Bus 26163	: V=1.0202195, theta=-64.560445 -> V=1.0, theta=0.0
% INFO    : Bus 26164	: V=1.0205494, theta=-64.738239 -> V=1.0, theta=0.0
% INFO    : Bus 26165	: V=1.0204438, theta=-64.677599 -> V=1.0, theta=0.0
% INFO    : Bus 26166	: V=1.02027, theta=-64.605521 -> V=1.0, theta=0.0
% INFO    : Bus 26167	: V=1.0321485, theta=-67.710959 -> V=1.0, theta=0.0
% INFO    : Bus 26168	: V=1.0350763, theta=-68.409186 -> V=1.0, theta=0.0
% INFO    : Bus 26169	: V=1.0351556, theta=-68.42754 -> V=1.0, theta=0.0
% INFO    : Bus 26170	: V=1.0351556, theta=-68.42754 -> V=1.0, theta=0.0
% INFO    : Bus 26171	: V=1.0212842, theta=-75.678408 -> V=1.0, theta=0.0
% INFO    : Bus 26172	: V=1.0246908, theta=-78.518281 -> V=1.0, theta=0.0
% INFO    : Bus 26173	: V=1.0212842, theta=-75.678408 -> V=1.0, theta=0.0
% INFO    : Bus 26174	: V=1.0022805, theta=-72.694799 -> V=1.0, theta=0.0
% INFO    : Bus 26175	: V=1.0212842, theta=-75.678408 -> V=1.0, theta=0.0
% INFO    : Bus 26176	: V=1.0033928, theta=-72.948132 -> V=1.0, theta=0.0
% INFO    : Bus 26177	: V=0.9990465, theta=-73.853897 -> V=1.0, theta=0.0
% INFO    : Bus 26178	: V=1.0000006, theta=-74.37609 -> V=1.0, theta=0.0
% INFO    : Bus 26179	: V=1.0001563, theta=-74.430342 -> V=1.0, theta=0.0
% INFO    : Bus 26180	: V=1.0000458, theta=-74.356921 -> V=1.0, theta=0.0
% INFO    : Bus 26181	: V=1.0000679, theta=-74.390978 -> V=1.0, theta=0.0
% INFO    : Bus 26182	: V=1.004849, theta=-73.738807 -> V=1.0, theta=0.0
% INFO    : Bus 26183	: V=0.999288, theta=-74.030113 -> V=1.0, theta=0.0
% INFO    : Bus 26184	: V=1.0240559, theta=-75.806286 -> V=1.0, theta=0.0
% INFO    : Bus 26185	: V=1.0368135, theta=-67.975237 -> V=1.0, theta=0.0
% INFO    : Bus 26186	: V=1.0234251, theta=-78.149325 -> V=1.0, theta=0.0
% INFO    : Bus 26187	: V=1.0234251, theta=-78.149325 -> V=1.0, theta=0.0
% INFO    : Bus 26188	: V=1.0234251, theta=-78.149325 -> V=1.0, theta=0.0
% INFO    : Bus 26189	: V=1.0234251, theta=-78.149325 -> V=1.0, theta=0.0
% INFO    : Bus 26190	: V=1.0114747, theta=-72.778855 -> V=1.0, theta=0.0
% INFO    : Bus 26191	: V=1.0152091, theta=-74.08814 -> V=1.0, theta=0.0
% INFO    : Bus 26192	: V=1.0233868, theta=-78.211016 -> V=1.0, theta=0.0
% INFO    : Bus 26193	: V=1.0234251, theta=-78.149325 -> V=1.0, theta=0.0
% INFO    : Bus 26194	: V=1.02214, theta=-71.067241 -> V=1.0, theta=0.0
% INFO    : Bus 26195	: V=1.0247234, theta=-72.468289 -> V=1.0, theta=0.0
% INFO    : Bus 26196	: V=1.0222008, theta=-76.035528 -> V=1.0, theta=0.0
% INFO    : Bus 26197	: V=1.0250619, theta=-70.576182 -> V=1.0, theta=0.0
% INFO    : Bus 26198	: V=1.0260013, theta=-70.352659 -> V=1.0, theta=0.0
% INFO    : Bus 26199	: V=1.0285068, theta=-69.971581 -> V=1.0, theta=0.0
% INFO    : Bus 26200	: V=1.0262686, theta=-70.135732 -> V=1.0, theta=0.0
% INFO    : Bus 26201	: V=1.0264832, theta=-70.010694 -> V=1.0, theta=0.0
% INFO    : Bus 26202	: V=1.0277905, theta=-70.017996 -> V=1.0, theta=0.0
% INFO    : Bus 26203	: V=1.02214, theta=-71.067241 -> V=1.0, theta=0.0
% INFO    : Bus 26204	: V=1.0235053, theta=-70.957213 -> V=1.0, theta=0.0
% INFO    : Bus 26205	: V=1.0295961, theta=-69.367399 -> V=1.0, theta=0.0
% INFO    : Bus 26206	: V=1.0272496, theta=-70.098828 -> V=1.0, theta=0.0
% INFO    : Bus 26207	: V=1.0240212, theta=-76.764107 -> V=1.0, theta=0.0
% INFO    : Bus 26208	: V=1.0267248, theta=-73.081932 -> V=1.0, theta=0.0
% INFO    : Bus 26209	: V=1.0330831, theta=-69.398517 -> V=1.0, theta=0.0
% INFO    : Bus 26210	: V=0.9747036, theta=-66.329033 -> V=1.0, theta=0.0
% INFO    : Bus 26211	: V=1.0331001, theta=-69.449514 -> V=1.0, theta=0.0
% INFO    : Bus 26212	: V=1.0225399, theta=-71.455415 -> V=1.0, theta=0.0
% INFO    : Bus 26213	: V=1.0232262, theta=-75.267809 -> V=1.0, theta=0.0
% INFO    : Bus 26214	: V=1.0249855, theta=-78.461981 -> V=1.0, theta=0.0
% INFO    : Bus 26215	: V=1.0090658, theta=-70.988305 -> V=1.0, theta=0.0
% INFO    : Bus 26216	: V=1.0081646, theta=-70.523651 -> V=1.0, theta=0.0
% INFO    : Bus 26217	: V=1.0072913, theta=-70.11857 -> V=1.0, theta=0.0
% INFO    : Bus 26218	: V=1.0309875, theta=-69.700342 -> V=1.0, theta=0.0
% INFO    : Bus 26219	: V=1.0098861, theta=-66.849162 -> V=1.0, theta=0.0
% INFO    : Bus 26220	: V=1.0265289, theta=-73.339496 -> V=1.0, theta=0.0
% INFO    : Bus 26221	: V=1.0331448, theta=-75.210899 -> V=1.0, theta=0.0
% INFO    : Bus 26222	: V=1.0275056, theta=-73.22191 -> V=1.0, theta=0.0
% INFO    : Bus 26223	: V=1.0264747, theta=-73.347485 -> V=1.0, theta=0.0
% INFO    : Bus 26224	: V=1.0264747, theta=-73.347485 -> V=1.0, theta=0.0
% INFO    : Bus 26225	: V=1.0713436, theta=-71.126803 -> V=1.0, theta=0.0
% INFO    : Bus 26226	: V=1.0305529, theta=-72.918776 -> V=1.0, theta=0.0
% INFO    : Bus 26227	: V=1.0282898, theta=-73.155838 -> V=1.0, theta=0.0
% INFO    : Bus 26228	: V=1.0266942, theta=-73.294099 -> V=1.0, theta=0.0
% INFO    : Bus 26229	: V=1.0341024, theta=-67.394215 -> V=1.0, theta=0.0
% INFO    : Bus 26230	: V=1.0329366, theta=-66.310231 -> V=1.0, theta=0.0
% INFO    : Bus 26231	: V=1.0326592, theta=-65.984716 -> V=1.0, theta=0.0
% INFO    : Bus 26232	: V=1.0326592, theta=-65.984716 -> V=1.0, theta=0.0
% INFO    : Bus 26233	: V=1.0342756, theta=-68.812312 -> V=1.0, theta=0.0
% INFO    : Bus 26234	: V=1.0280756, theta=-66.670318 -> V=1.0, theta=0.0
% INFO    : Bus 26235	: V=1.0341924, theta=-68.876418 -> V=1.0, theta=0.0
% INFO    : Bus 26236	: V=1.027094, theta=-72.101977 -> V=1.0, theta=0.0
% INFO    : Bus 26237	: V=1.0306332, theta=-75.335877 -> V=1.0, theta=0.0
% INFO    : Bus 26238	: V=1.0242867, theta=-78.963162 -> V=1.0, theta=0.0
% INFO    : Bus 28000	: V=1.0226694, theta=-80.12101 -> V=1.0, theta=0.0
% INFO    : Bus 28001	: V=1.0205424, theta=-79.925685 -> V=1.0, theta=0.0
% INFO    : Bus 28002	: V=1.0201902, theta=-79.968087 -> V=1.0, theta=0.0
% INFO    : Bus 28003	: V=1.0236313, theta=-78.660234 -> V=1.0, theta=0.0
% INFO    : Bus 28004	: V=1.0102775, theta=-80.575666 -> V=1.0, theta=0.0
% INFO    : Bus 28005	: V=1.0214307, theta=-80.517944 -> V=1.0, theta=0.0
% INFO    : Bus 28006	: V=1.025801, theta=-78.6203 -> V=1.0, theta=0.0
% INFO    : Bus 28007	: V=1.0256434, theta=-78.65268 -> V=1.0, theta=0.0
% INFO    : Bus 28008	: V=1.0222279, theta=-80.272972 -> V=1.0, theta=0.0
% INFO    : Bus 28009	: V=1.0168051, theta=-79.863745 -> V=1.0, theta=0.0
% INFO    : Bus 28010	: V=1.0151483, theta=-80.700341 -> V=1.0, theta=0.0
% INFO    : Bus 28011	: V=1.0216531, theta=-76.50418 -> V=1.0, theta=0.0
% INFO    : Bus 28012	: V=1.0226009, theta=-80.021195 -> V=1.0, theta=0.0
% INFO    : Bus 28013	: V=1.0213889, theta=-76.548409 -> V=1.0, theta=0.0
% INFO    : Bus 28014	: V=1.0170086, theta=-80.746454 -> V=1.0, theta=0.0
% INFO    : Bus 28015	: V=1.0168369, theta=-80.780852 -> V=1.0, theta=0.0
% INFO    : Bus 28016	: V=1.0125881, theta=-80.955476 -> V=1.0, theta=0.0
% INFO    : Bus 28017	: V=1.0123396, theta=-80.990678 -> V=1.0, theta=0.0
% INFO    : Bus 28018	: V=1.0225218, theta=-80.954621 -> V=1.0, theta=0.0
% INFO    : Bus 28019	: V=1.0226694, theta=-80.937875 -> V=1.0, theta=0.0
% INFO    : Bus 28020	: V=1.0225218, theta=-80.954621 -> V=1.0, theta=0.0
% INFO    : Bus 28021	: V=1.0132015, theta=-80.805913 -> V=1.0, theta=0.0
% INFO    : Bus 28022	: V=1.0210625, theta=-79.794349 -> V=1.0, theta=0.0
% INFO    : Bus 28023	: V=1.0153541, theta=-76.07309 -> V=1.0, theta=0.0
% INFO    : Bus 28024	: V=1.0176244, theta=-78.746874 -> V=1.0, theta=0.0
% INFO    : Bus 28025	: V=1.0230202, theta=-80.362767 -> V=1.0, theta=0.0
% INFO    : Bus 28026	: V=1.0228082, theta=-80.39076 -> V=1.0, theta=0.0
% INFO    : Bus 28027	: V=1.0174288, theta=-80.914299 -> V=1.0, theta=0.0
% INFO    : Bus 28028	: V=1.0176082, theta=-80.887808 -> V=1.0, theta=0.0
% INFO    : Bus 28029	: V=1.0204343, theta=-79.815508 -> V=1.0, theta=0.0
% INFO    : Bus 28030	: V=1.0213501, theta=-80.566711 -> V=1.0, theta=0.0
% INFO    : Bus 28031	: V=1.021065, theta=-80.595585 -> V=1.0, theta=0.0
% INFO    : Bus 28032	: V=1.018221, theta=-81.712512 -> V=1.0, theta=0.0
% INFO    : Bus 28033	: V=1.0214854, theta=-80.76155 -> V=1.0, theta=0.0
% INFO    : Bus 28034	: V=1.0213596, theta=-80.789082 -> V=1.0, theta=0.0
% INFO    : Bus 28035	: V=1.0148675, theta=-76.911759 -> V=1.0, theta=0.0
% INFO    : Bus 28036	: V=1.0238228, theta=-80.97821 -> V=1.0, theta=0.0
% INFO    : Bus 28037	: V=1.0146323, theta=-76.944915 -> V=1.0, theta=0.0
% INFO    : Bus 28038	: V=1.0124837, theta=-76.764003 -> V=1.0, theta=0.0
% INFO    : Bus 28039	: V=1.0230549, theta=-80.807711 -> V=1.0, theta=0.0
% INFO    : Bus 28040	: V=1.022149, theta=-80.839594 -> V=1.0, theta=0.0
% INFO    : Bus 28041	: V=1.0219693, theta=-80.868871 -> V=1.0, theta=0.0
% INFO    : Bus 28042	: V=1.0220903, theta=-80.017767 -> V=1.0, theta=0.0
% INFO    : Bus 28043	: V=1.0251596, theta=-81.155406 -> V=1.0, theta=0.0
% INFO    : Bus 28044	: V=1.0249795, theta=-81.178329 -> V=1.0, theta=0.0
% INFO    : Bus 28045	: V=1.021762, theta=-81.102164 -> V=1.0, theta=0.0
% INFO    : Bus 28046	: V=1.0056219, theta=-77.57588 -> V=1.0, theta=0.0
% INFO    : Bus 28047	: V=1.0440145, theta=-80.858509 -> V=1.0, theta=0.0
% INFO    : Bus 28048	: V=1.0050445, theta=-77.61851 -> V=1.0, theta=0.0
% INFO    : Bus 28049	: V=1.0088137, theta=-77.426948 -> V=1.0, theta=0.0
% INFO    : Bus 28050	: V=1.0102048, theta=-81.014935 -> V=1.0, theta=0.0
% INFO    : Bus 28051	: V=1.0100012, theta=-81.03701 -> V=1.0, theta=0.0
% INFO    : Bus 28052	: V=1.022054, theta=-81.048256 -> V=1.0, theta=0.0
% INFO    : Bus 28053	: V=1.0189413, theta=-81.047086 -> V=1.0, theta=0.0
% INFO    : Bus 28054	: V=1.0195147, theta=-81.241879 -> V=1.0, theta=0.0
% INFO    : Bus 28055	: V=1.0104952, theta=-81.18033 -> V=1.0, theta=0.0
% INFO    : Bus 28056	: V=1.0104952, theta=-81.18033 -> V=1.0, theta=0.0
% INFO    : Bus 28057	: V=1.0104952, theta=-81.18033 -> V=1.0, theta=0.0
% INFO    : Bus 28058	: V=1.0104952, theta=-81.18033 -> V=1.0, theta=0.0
% INFO    : Bus 28059	: V=1.0152766, theta=-77.550848 -> V=1.0, theta=0.0
% INFO    : Bus 28060	: V=1.021753, theta=-80.507637 -> V=1.0, theta=0.0
% INFO    : Bus 28061	: V=1.019177, theta=-79.476682 -> V=1.0, theta=0.0
% INFO    : Bus 28062	: V=1.019177, theta=-79.476682 -> V=1.0, theta=0.0
% INFO    : Bus 28063	: V=1.0207976, theta=-80.460998 -> V=1.0, theta=0.0
% INFO    : Bus 28064	: V=1.0203826, theta=-80.507216 -> V=1.0, theta=0.0
% INFO    : Bus 28065	: V=1.014778, theta=-81.091333 -> V=1.0, theta=0.0
% INFO    : Bus 28066	: V=1.0216381, theta=-80.705363 -> V=1.0, theta=0.0
% INFO    : Bus 28067	: V=1.0222427, theta=-80.965634 -> V=1.0, theta=0.0
% INFO    : Bus 28068	: V=1.0276343, theta=-80.917694 -> V=1.0, theta=0.0
% INFO    : Bus 28069	: V=1.0274243, theta=-80.954523 -> V=1.0, theta=0.0
% INFO    : Bus 28070	: V=1.0186554, theta=-80.704907 -> V=1.0, theta=0.0
% INFO    : Bus 28071	: V=1.0184862, theta=-81.379933 -> V=1.0, theta=0.0
% INFO    : Bus 28072	: V=1.0182291, theta=-81.417435 -> V=1.0, theta=0.0
% INFO    : Bus 28073	: V=1.0209882, theta=-80.677606 -> V=1.0, theta=0.0
% INFO    : Bus 28074	: V=1.020002, theta=-77.038089 -> V=1.0, theta=0.0
% INFO    : Bus 28075	: V=1.0222859, theta=-80.424642 -> V=1.0, theta=0.0
% INFO    : Bus 28076	: V=1.0288829, theta=-84.113218 -> V=1.0, theta=0.0
% INFO    : Bus 28077	: V=1.0288829, theta=-84.113218 -> V=1.0, theta=0.0
% INFO    : Bus 28078	: V=1.0194422, theta=-77.112172 -> V=1.0, theta=0.0
% INFO    : Bus 28079	: V=1.0363245, theta=-81.394039 -> V=1.0, theta=0.0
% INFO    : Bus 28080	: V=1.0359836, theta=-81.420408 -> V=1.0, theta=0.0
% INFO    : Bus 28081	: V=1.0058805, theta=-81.039482 -> V=1.0, theta=0.0
% INFO    : Bus 28082	: V=1.0056738, theta=-81.056639 -> V=1.0, theta=0.0
% INFO    : Bus 28083	: V=1.0061017, theta=-81.023561 -> V=1.0, theta=0.0
% INFO    : Bus 28084	: V=1.0172961, theta=-81.380742 -> V=1.0, theta=0.0
% INFO    : Bus 28085	: V=1.0194487, theta=-81.547761 -> V=1.0, theta=0.0
% INFO    : Bus 28086	: V=1.019347, theta=-81.568541 -> V=1.0, theta=0.0
% INFO    : Bus 28087	: V=1.0195589, theta=-81.530009 -> V=1.0, theta=0.0
% INFO    : Bus 28088	: V=1.0289631, theta=-81.174717 -> V=1.0, theta=0.0
% INFO    : Bus 28089	: V=1.0288287, theta=-81.195107 -> V=1.0, theta=0.0
% INFO    : Bus 28090	: V=1.0332683, theta=-81.170743 -> V=1.0, theta=0.0
% INFO    : Bus 28091	: V=1.0038811, theta=-81.178904 -> V=1.0, theta=0.0
% INFO    : Bus 28092	: V=1.0040036, theta=-81.160134 -> V=1.0, theta=0.0
% INFO    : Bus 28093	: V=1.013869, theta=-81.18311 -> V=1.0, theta=0.0
% INFO    : Bus 28094	: V=1.013869, theta=-81.18311 -> V=1.0, theta=0.0
% INFO    : Bus 28095	: V=1.013869, theta=-81.18311 -> V=1.0, theta=0.0
% INFO    : Bus 28096	: V=1.013869, theta=-81.18311 -> V=1.0, theta=0.0
% INFO    : Bus 28097	: V=1.0104225, theta=-77.589697 -> V=1.0, theta=0.0
% INFO    : Bus 28098	: V=1.0608521, theta=-80.604042 -> V=1.0, theta=0.0
% INFO    : Bus 28099	: V=1.0101211, theta=-77.652596 -> V=1.0, theta=0.0
% INFO    : Bus 28100	: V=1.0180996, theta=-80.795114 -> V=1.0, theta=0.0
% INFO    : Bus 28101	: V=1.0177577, theta=-80.827317 -> V=1.0, theta=0.0
% INFO    : Bus 28102	: V=1.0179892, theta=-80.803926 -> V=1.0, theta=0.0
% INFO    : Bus 28103	: V=1.0153864, theta=-80.818021 -> V=1.0, theta=0.0
% INFO    : Bus 28104	: V=1.0182739, theta=-81.436747 -> V=1.0, theta=0.0
% INFO    : Bus 28105	: V=1.0178007, theta=-81.460532 -> V=1.0, theta=0.0
% INFO    : Bus 28106	: V=1.0164938, theta=-81.261624 -> V=1.0, theta=0.0
% INFO    : Bus 28107	: V=1.0212335, theta=-80.889667 -> V=1.0, theta=0.0
% INFO    : Bus 28108	: V=1.0071711, theta=-81.037321 -> V=1.0, theta=0.0
% INFO    : Bus 28109	: V=1.0069716, theta=-81.057669 -> V=1.0, theta=0.0
% INFO    : Bus 28110	: V=1.0215018, theta=-81.050796 -> V=1.0, theta=0.0
% INFO    : Bus 28111	: V=1.0137526, theta=-81.360535 -> V=1.0, theta=0.0
% INFO    : Bus 28112	: V=1.0135962, theta=-81.384913 -> V=1.0, theta=0.0
% INFO    : Bus 28113	: V=1.0467216, theta=-81.341877 -> V=1.0, theta=0.0
% INFO    : Bus 28114	: V=1.0210131, theta=-80.683884 -> V=1.0, theta=0.0
% INFO    : Bus 28115	: V=1.0221603, theta=-81.120265 -> V=1.0, theta=0.0
% INFO    : Bus 28116	: V=1.0526691, theta=-81.074201 -> V=1.0, theta=0.0
% INFO    : Bus 28117	: V=1.0420885, theta=-81.294471 -> V=1.0, theta=0.0
% INFO    : Bus 28118	: V=1.0145532, theta=-77.131016 -> V=1.0, theta=0.0
% INFO    : Bus 28119	: V=1.0133855, theta=-80.885761 -> V=1.0, theta=0.0
% INFO    : Bus 28120	: V=1.020675, theta=-86.921387 -> V=1.0, theta=0.0
% INFO    : Bus 28121	: V=1.020675, theta=-86.921387 -> V=1.0, theta=0.0
% INFO    : Bus 28122	: V=0.984819, theta=-85.719297 -> V=1.0, theta=0.0
% INFO    : Bus 28123	: V=1.0143536, theta=-80.70872 -> V=1.0, theta=0.0
% INFO    : Bus 28124	: V=1.0143536, theta=-80.70872 -> V=1.0, theta=0.0
% INFO    : Bus 28125	: V=1.014549, theta=-81.195316 -> V=1.0, theta=0.0
% INFO    : Bus 28126	: V=1.0143252, theta=-81.21319 -> V=1.0, theta=0.0
% INFO    : Bus 28127	: V=1.0161914, theta=-81.319735 -> V=1.0, theta=0.0
% INFO    : Bus 28128	: V=1.0157291, theta=-81.38064 -> V=1.0, theta=0.0
% INFO    : Bus 28129	: V=1.0167038, theta=-81.255609 -> V=1.0, theta=0.0
% INFO    : Bus 28130	: V=1.0001595, theta=-81.222552 -> V=1.0, theta=0.0
% INFO    : Bus 28131	: V=1.0005026, theta=-81.199294 -> V=1.0, theta=0.0
% INFO    : Bus 28132	: V=1.0053716, theta=-81.021125 -> V=1.0, theta=0.0
% INFO    : Bus 28133	: V=1.0228184, theta=-81.019145 -> V=1.0, theta=0.0
% INFO    : Bus 28134	: V=1.0486348, theta=-80.764501 -> V=1.0, theta=0.0
% INFO    : Bus 28135	: V=1.0423387, theta=-81.088828 -> V=1.0, theta=0.0
% INFO    : Bus 28136	: V=1.0420096, theta=-81.105664 -> V=1.0, theta=0.0
% INFO    : Bus 28137	: V=1.0426457, theta=-81.073381 -> V=1.0, theta=0.0
% INFO    : Bus 28138	: V=1.0210994, theta=-81.418999 -> V=1.0, theta=0.0
% INFO    : Bus 28139	: V=1.0073536, theta=-81.429523 -> V=1.0, theta=0.0
% INFO    : Bus 28140	: V=1.0014027, theta=-80.824499 -> V=1.0, theta=0.0
% INFO    : Bus 28141	: V=1.0060025, theta=-77.026562 -> V=1.0, theta=0.0
% INFO    : Bus 28142	: V=1.0250519, theta=-80.902711 -> V=1.0, theta=0.0
% INFO    : Bus 28143	: V=1.0016321, theta=-80.714653 -> V=1.0, theta=0.0
% INFO    : Bus 28144	: V=1.0019935, theta=-80.672135 -> V=1.0, theta=0.0
% INFO    : Bus 28145	: V=1.0384054, theta=-81.095372 -> V=1.0, theta=0.0
% INFO    : Bus 28146	: V=1.0450101, theta=-81.072956 -> V=1.0, theta=0.0
% INFO    : Bus 28147	: V=1.0448119, theta=-81.088105 -> V=1.0, theta=0.0
% INFO    : Bus 28148	: V=1.0451842, theta=-81.058062 -> V=1.0, theta=0.0
% INFO    : Bus 28149	: V=1.0267733, theta=-81.241709 -> V=1.0, theta=0.0
% INFO    : Bus 28150	: V=1.0265555, theta=-81.267572 -> V=1.0, theta=0.0
% INFO    : Bus 28151	: V=1.026694, theta=-81.253573 -> V=1.0, theta=0.0
% INFO    : Bus 28152	: V=1.0246663, theta=-81.184641 -> V=1.0, theta=0.0
% INFO    : Bus 28153	: V=1.007846, theta=-81.504412 -> V=1.0, theta=0.0
% INFO    : Bus 28154	: V=1.045104, theta=-79.912489 -> V=1.0, theta=0.0
% INFO    : Bus 28155	: V=0.9975828, theta=-77.334936 -> V=1.0, theta=0.0
% INFO    : Bus 28156	: V=1.0526329, theta=-80.470297 -> V=1.0, theta=0.0
% INFO    : Bus 28157	: V=0.9973147, theta=-77.366682 -> V=1.0, theta=0.0
% INFO    : Bus 28158	: V=1.0020364, theta=-77.108001 -> V=1.0, theta=0.0
% INFO    : Bus 28159	: V=1.0459086, theta=-80.904391 -> V=1.0, theta=0.0
% INFO    : Bus 28160	: V=1.0455477, theta=-80.935195 -> V=1.0, theta=0.0
% INFO    : Bus 28161	: V=1.0026533, theta=-80.173413 -> V=1.0, theta=0.0
% INFO    : Bus 28162	: V=1.0025016, theta=-80.19413 -> V=1.0, theta=0.0
% INFO    : Bus 28163	: V=1.0085539, theta=-79.901166 -> V=1.0, theta=0.0
% INFO    : Bus 28164	: V=1.0384198, theta=-81.36932 -> V=1.0, theta=0.0
% INFO    : Bus 28165	: V=1.0385536, theta=-81.353339 -> V=1.0, theta=0.0
% INFO    : Bus 28166	: V=1.0383057, theta=-81.384293 -> V=1.0, theta=0.0
% INFO    : Bus 28167	: V=1.0369765, theta=-81.043763 -> V=1.0, theta=0.0
% INFO    : Bus 28168	: V=1.0066453, theta=-76.78446 -> V=1.0, theta=0.0
% INFO    : Bus 28169	: V=1.0435363, theta=-80.965232 -> V=1.0, theta=0.0
% INFO    : Bus 28170	: V=1.0194551, theta=-81.388187 -> V=1.0, theta=0.0
% INFO    : Bus 28171	: V=1.019983, theta=-81.359106 -> V=1.0, theta=0.0
% INFO    : Bus 28172	: V=1.0027151, theta=-80.703225 -> V=1.0, theta=0.0
% INFO    : Bus 28173	: V=1.0130974, theta=-80.794838 -> V=1.0, theta=0.0
% INFO    : Bus 28174	: V=1.0127196, theta=-80.822883 -> V=1.0, theta=0.0
% INFO    : Bus 28175	: V=1.0062839, theta=-80.134997 -> V=1.0, theta=0.0
% INFO    : Bus 28176	: V=1.0059297, theta=-80.161124 -> V=1.0, theta=0.0
% INFO    : Bus 28177	: V=1.0407577, theta=-81.155706 -> V=1.0, theta=0.0
% INFO    : Bus 28178	: V=1.0406602, theta=-81.167506 -> V=1.0, theta=0.0
% INFO    : Bus 28179	: V=1.040843, theta=-81.14496 -> V=1.0, theta=0.0
% INFO    : Bus 28180	: V=1.0098695, theta=-80.626875 -> V=1.0, theta=0.0
% INFO    : Bus 28181	: V=1.0059362, theta=-80.235058 -> V=1.0, theta=0.0
% INFO    : Bus 28182	: V=1.0056969, theta=-80.26464 -> V=1.0, theta=0.0
% INFO    : Bus 28183	: V=1.0476462, theta=-80.718458 -> V=1.0, theta=0.0
% INFO    : Bus 28184	: V=1.0474218, theta=-80.74227 -> V=1.0, theta=0.0
% INFO    : Bus 28185	: V=1.0481893, theta=-80.701566 -> V=1.0, theta=0.0
% INFO    : Bus 28186	: V=1.0476462, theta=-80.718458 -> V=1.0, theta=0.0
% INFO    : Bus 28187	: V=1.0458567, theta=-80.767434 -> V=1.0, theta=0.0
% INFO    : Bus 28188	: V=1.0457006, theta=-80.791455 -> V=1.0, theta=0.0
% INFO    : Bus 28189	: V=1.0460372, theta=-80.744601 -> V=1.0, theta=0.0
% INFO    : Bus 28190	: V=1.0108359, theta=-79.226652 -> V=1.0, theta=0.0
% INFO    : Bus 28191	: V=1.0062028, theta=-80.39651 -> V=1.0, theta=0.0
% INFO    : Bus 28192	: V=1.0023341, theta=-80.067411 -> V=1.0, theta=0.0
% INFO    : Bus 28193	: V=1.0089053, theta=-79.531251 -> V=1.0, theta=0.0
% INFO    : Bus 28194	: V=1.0088117, theta=-79.544201 -> V=1.0, theta=0.0
% INFO    : Bus 28195	: V=1.0090219, theta=-79.516697 -> V=1.0, theta=0.0
% INFO    : Bus 28196	: V=1.0309212, theta=-81.347101 -> V=1.0, theta=0.0
% INFO    : Bus 28197	: V=1.0375747, theta=-81.114705 -> V=1.0, theta=0.0
% INFO    : Bus 28198	: V=1.0459667, theta=-80.509348 -> V=1.0, theta=0.0
% INFO    : Bus 28199	: V=1.0010981, theta=-81.041657 -> V=1.0, theta=0.0
% INFO    : Bus 28200	: V=1.0098868, theta=-79.637247 -> V=1.0, theta=0.0
% INFO    : Bus 28201	: V=1.0443066, theta=-80.958941 -> V=1.0, theta=0.0
% INFO    : Bus 28202	: V=1.0441355, theta=-80.973416 -> V=1.0, theta=0.0
% INFO    : Bus 28203	: V=1.0444748, theta=-80.945865 -> V=1.0, theta=0.0
% INFO    : Bus 28204	: V=1.0443066, theta=-80.958941 -> V=1.0, theta=0.0
% INFO    : Bus 28205	: V=1.0394106, theta=-81.236479 -> V=1.0, theta=0.0
% INFO    : Bus 28206	: V=1.0392477, theta=-81.259717 -> V=1.0, theta=0.0
% INFO    : Bus 28207	: V=1.0384722, theta=-81.322321 -> V=1.0, theta=0.0
% INFO    : Bus 28208	: V=1.0401123, theta=-81.126088 -> V=1.0, theta=0.0
% INFO    : Bus 28209	: V=1.0399806, theta=-81.142596 -> V=1.0, theta=0.0
% INFO    : Bus 28210	: V=1.0402348, theta=-81.109487 -> V=1.0, theta=0.0
% INFO    : Bus 28211	: V=1.0041325, theta=-76.646271 -> V=1.0, theta=0.0
% INFO    : Bus 28212	: V=1.0527345, theta=-79.239629 -> V=1.0, theta=0.0
% INFO    : Bus 28213	: V=1.0275966, theta=-80.048614 -> V=1.0, theta=0.0
% INFO    : Bus 28214	: V=1.0292734, theta=-80.109983 -> V=1.0, theta=0.0
% INFO    : Bus 28215	: V=1.0294248, theta=-80.092689 -> V=1.0, theta=0.0
% INFO    : Bus 28216	: V=0.9999822, theta=-80.275219 -> V=1.0, theta=0.0
% INFO    : Bus 28217	: V=1.014428, theta=-76.156006 -> V=1.0, theta=0.0
% INFO    : Bus 28218	: V=1.0116102, theta=-79.087002 -> V=1.0, theta=0.0
% INFO    : Bus 28219	: V=1.0364559, theta=-81.27699 -> V=1.0, theta=0.0
% INFO    : Bus 28220	: V=1.0476281, theta=-80.152127 -> V=1.0, theta=0.0
% INFO    : Bus 28221	: V=1.0095958, theta=-81.001382 -> V=1.0, theta=0.0
% INFO    : Bus 28222	: V=1.0059279, theta=-76.331732 -> V=1.0, theta=0.0
% INFO    : Bus 28223	: V=1.0084239, theta=-79.312196 -> V=1.0, theta=0.0
% INFO    : Bus 28224	: V=0.9993105, theta=-80.257886 -> V=1.0, theta=0.0
% INFO    : Bus 28225	: V=1.0080738, theta=-79.594361 -> V=1.0, theta=0.0
% INFO    : Bus 28226	: V=1.007735, theta=-79.613742 -> V=1.0, theta=0.0
% INFO    : Bus 28227	: V=1.0039474, theta=-79.7353 -> V=1.0, theta=0.0
% INFO    : Bus 28228	: V=1.0061227, theta=-79.6215 -> V=1.0, theta=0.0
% INFO    : Bus 28229	: V=1.005863, theta=-79.653903 -> V=1.0, theta=0.0
% INFO    : Bus 28230	: V=1.0099148, theta=-79.165673 -> V=1.0, theta=0.0
% INFO    : Bus 28231	: V=1.0097364, theta=-79.576071 -> V=1.0, theta=0.0
% INFO    : Bus 28232	: V=1.0083303, theta=-80.279247 -> V=1.0, theta=0.0
% INFO    : Bus 28233	: V=1.0087474, theta=-80.685918 -> V=1.0, theta=0.0
% INFO    : Bus 28234	: V=1.0083107, theta=-78.413649 -> V=1.0, theta=0.0
% INFO    : Bus 28235	: V=1.0068707, theta=-80.073893 -> V=1.0, theta=0.0
% INFO    : Bus 28236	: V=1.0067526, theta=-80.091553 -> V=1.0, theta=0.0
% INFO    : Bus 28237	: V=1.0127681, theta=-79.218658 -> V=1.0, theta=0.0
% INFO    : Bus 28238	: V=1.0129208, theta=-79.203092 -> V=1.0, theta=0.0
% INFO    : Bus 28239	: V=1.012492, theta=-79.672815 -> V=1.0, theta=0.0
% INFO    : Bus 28240	: V=1.0126444, theta=-79.645294 -> V=1.0, theta=0.0
% INFO    : Bus 28241	: V=1.0123389, theta=-79.698257 -> V=1.0, theta=0.0
% INFO    : Bus 28242	: V=1.012492, theta=-79.672815 -> V=1.0, theta=0.0
% INFO    : Bus 28243	: V=1.005753, theta=-79.808271 -> V=1.0, theta=0.0
% INFO    : Bus 28244	: V=1.0064812, theta=-80.16117 -> V=1.0, theta=0.0
% INFO    : Bus 28245	: V=1.0074249, theta=-79.424055 -> V=1.0, theta=0.0
% INFO    : Bus 28246	: V=1.0015451, theta=-79.177367 -> V=1.0, theta=0.0
% INFO    : Bus 28247	: V=1.0095235, theta=-79.424837 -> V=1.0, theta=0.0
% INFO    : Bus 28248	: V=1.0049757, theta=-80.428019 -> V=1.0, theta=0.0
% INFO    : Bus 28249	: V=1.0046877, theta=-80.454081 -> V=1.0, theta=0.0
% INFO    : Bus 28250	: V=1.0052292, theta=-80.404991 -> V=1.0, theta=0.0
% INFO    : Bus 28251	: V=1.0083962, theta=-80.048718 -> V=1.0, theta=0.0
% INFO    : Bus 28252	: V=1.0290059, theta=-80.757433 -> V=1.0, theta=0.0
% INFO    : Bus 28253	: V=1.034942, theta=-80.600788 -> V=1.0, theta=0.0
% INFO    : Bus 28254	: V=1.0348228, theta=-80.615041 -> V=1.0, theta=0.0
% INFO    : Bus 28255	: V=1.0084504, theta=-79.18359 -> V=1.0, theta=0.0
% INFO    : Bus 28256	: V=1.0171937, theta=-79.096202 -> V=1.0, theta=0.0
% INFO    : Bus 28257	: V=1.0105526, theta=-79.263584 -> V=1.0, theta=0.0
% INFO    : Bus 28258	: V=1.0101595, theta=-79.297463 -> V=1.0, theta=0.0
% INFO    : Bus 28259	: V=1.0092651, theta=-79.348813 -> V=1.0, theta=0.0
% INFO    : Bus 28260	: V=1.0095142, theta=-79.312788 -> V=1.0, theta=0.0
% INFO    : Bus 28261	: V=1.0090388, theta=-79.381299 -> V=1.0, theta=0.0
% INFO    : Bus 28262	: V=1.0176378, theta=-78.402804 -> V=1.0, theta=0.0
% INFO    : Bus 28263	: V=1.0098816, theta=-79.032776 -> V=1.0, theta=0.0
% INFO    : Bus 28264	: V=1.009538, theta=-79.060434 -> V=1.0, theta=0.0
% INFO    : Bus 28265	: V=1.0148749, theta=-78.342762 -> V=1.0, theta=0.0
% INFO    : Bus 28266	: V=1.01524, theta=-78.31402 -> V=1.0, theta=0.0
% INFO    : Bus 28267	: V=1.0006945, theta=-79.997254 -> V=1.0, theta=0.0
% INFO    : Bus 28268	: V=1.0262791, theta=-74.133162 -> V=1.0, theta=0.0
% INFO    : Bus 28269	: V=1.0261374, theta=-74.150055 -> V=1.0, theta=0.0
% INFO    : Bus 28270	: V=1.0264282, theta=-74.115519 -> V=1.0, theta=0.0
% INFO    : Bus 28271	: V=1.0137649, theta=-77.032753 -> V=1.0, theta=0.0
% INFO    : Bus 28272	: V=1.0367654, theta=-79.895024 -> V=1.0, theta=0.0
% INFO    : Bus 28273	: V=1.0067781, theta=-79.523843 -> V=1.0, theta=0.0
% INFO    : Bus 28274	: V=1.0063521, theta=-79.550846 -> V=1.0, theta=0.0
% INFO    : Bus 28275	: V=1.0078821, theta=-79.627613 -> V=1.0, theta=0.0
% INFO    : Bus 28276	: V=1.0101006, theta=-79.713758 -> V=1.0, theta=0.0
% INFO    : Bus 28277	: V=1.0105776, theta=-79.683609 -> V=1.0, theta=0.0
% INFO    : Bus 28278	: V=1.0096484, theta=-79.741047 -> V=1.0, theta=0.0
% INFO    : Bus 28279	: V=1.0095673, theta=-79.315929 -> V=1.0, theta=0.0
% INFO    : Bus 28280	: V=1.002577, theta=-79.72593 -> V=1.0, theta=0.0
% INFO    : Bus 28281	: V=1.0098177, theta=-79.2382 -> V=1.0, theta=0.0
% INFO    : Bus 28282	: V=1.0100424, theta=-79.213934 -> V=1.0, theta=0.0
% INFO    : Bus 28283	: V=1.0122233, theta=-76.564871 -> V=1.0, theta=0.0
% INFO    : Bus 28284	: V=1.0126168, theta=-76.536363 -> V=1.0, theta=0.0
% INFO    : Bus 28285	: V=1.0122233, theta=-76.564871 -> V=1.0, theta=0.0
% INFO    : Bus 28286	: V=1.0219054, theta=-74.63262 -> V=1.0, theta=0.0
% INFO    : Bus 28287	: V=1.0127277, theta=-77.345484 -> V=1.0, theta=0.0
% INFO    : Bus 28288	: V=1.0125005, theta=-77.367115 -> V=1.0, theta=0.0
% INFO    : Bus 28289	: V=1.012702, theta=-76.470622 -> V=1.0, theta=0.0
% INFO    : Bus 28290	: V=1.0129299, theta=-76.450999 -> V=1.0, theta=0.0
% INFO    : Bus 28291	: V=1.005484, theta=-79.185725 -> V=1.0, theta=0.0
% INFO    : Bus 28292	: V=1.0139362, theta=-79.247637 -> V=1.0, theta=0.0
% INFO    : Bus 28293	: V=1.0163125, theta=-78.818358 -> V=1.0, theta=0.0
% INFO    : Bus 28294	: V=1.0135493, theta=-76.720497 -> V=1.0, theta=0.0
% INFO    : Bus 28295	: V=1.0131986, theta=-78.206245 -> V=1.0, theta=0.0
% INFO    : Bus 28296	: V=1.0248075, theta=-78.255613 -> V=1.0, theta=0.0
% INFO    : Bus 28297	: V=1.0246349, theta=-78.286133 -> V=1.0, theta=0.0
% INFO    : Bus 28298	: V=1.0249457, theta=-78.225983 -> V=1.0, theta=0.0
% INFO    : Bus 28299	: V=1.016348, theta=-78.36404 -> V=1.0, theta=0.0
% INFO    : Bus 28300	: V=1.0176602, theta=-78.353632 -> V=1.0, theta=0.0
% INFO    : Bus 28301	: V=1.017932, theta=-78.324141 -> V=1.0, theta=0.0
% INFO    : Bus 28302	: V=1.0146951, theta=-78.078399 -> V=1.0, theta=0.0
% INFO    : Bus 28303	: V=1.0254814, theta=-79.122883 -> V=1.0, theta=0.0
% INFO    : Bus 28304	: V=1.0324301, theta=-78.957155 -> V=1.0, theta=0.0
% INFO    : Bus 28305	: V=1.032214, theta=-78.981357 -> V=1.0, theta=0.0
% INFO    : Bus 28306	: V=1.0024085, theta=-79.783351 -> V=1.0, theta=0.0
% INFO    : Bus 28307	: V=1.0021642, theta=-79.804483 -> V=1.0, theta=0.0
% INFO    : Bus 28308	: V=1.0158023, theta=-78.865851 -> V=1.0, theta=0.0
% INFO    : Bus 28309	: V=1.0156537, theta=-78.888878 -> V=1.0, theta=0.0
% INFO    : Bus 28310	: V=1.0242224, theta=-79.118751 -> V=1.0, theta=0.0
% INFO    : Bus 28311	: V=1.0251861, theta=-74.165309 -> V=1.0, theta=0.0
% INFO    : Bus 28312	: V=1.026764, theta=-74.06914 -> V=1.0, theta=0.0
% INFO    : Bus 28313	: V=1.0246502, theta=-75.284823 -> V=1.0, theta=0.0
% INFO    : Bus 28314	: V=1.0269743, theta=-73.9613 -> V=1.0, theta=0.0
% INFO    : Bus 28315	: V=1.0269743, theta=-73.9613 -> V=1.0, theta=0.0
% INFO    : Bus 28316	: V=1.0296418, theta=-72.314364 -> V=1.0, theta=0.0
% INFO    : Bus 28317	: V=1.0372908, theta=-75.981885 -> V=1.0, theta=0.0
% INFO    : Bus 28318	: V=1.0269551, theta=-78.359674 -> V=1.0, theta=0.0
% INFO    : Bus 28319	: V=1.0244501, theta=-78.87174 -> V=1.0, theta=0.0
% INFO    : Bus 28320	: V=1.0241352, theta=-78.906245 -> V=1.0, theta=0.0
% INFO    : Bus 28321	: V=1.0136063, theta=-79.536861 -> V=1.0, theta=0.0
% INFO    : Bus 28322	: V=1.013508, theta=-79.557507 -> V=1.0, theta=0.0
% INFO    : Bus 28323	: V=1.0137307, theta=-79.517067 -> V=1.0, theta=0.0
% INFO    : Bus 28324	: V=1.00735, theta=-79.371808 -> V=1.0, theta=0.0
% INFO    : Bus 28325	: V=1.015883, theta=-74.789317 -> V=1.0, theta=0.0
% INFO    : Bus 28326	: V=1.0075059, theta=-78.854841 -> V=1.0, theta=0.0
% INFO    : Bus 28327	: V=1.0256452, theta=-80.452965 -> V=1.0, theta=0.0
% INFO    : Bus 28328	: V=1.0163163, theta=-79.408085 -> V=1.0, theta=0.0
% INFO    : Bus 28329	: V=1.0212779, theta=-78.280983 -> V=1.0, theta=0.0
% INFO    : Bus 28330	: V=1.0145807, theta=-79.363895 -> V=1.0, theta=0.0
% INFO    : Bus 28331	: V=1.0145807, theta=-79.363895 -> V=1.0, theta=0.0
% INFO    : Bus 28332	: V=1.0145807, theta=-79.363895 -> V=1.0, theta=0.0
% INFO    : Bus 28333	: V=1.0145807, theta=-79.363895 -> V=1.0, theta=0.0
% INFO    : Bus 28334	: V=1.0221721, theta=-78.964685 -> V=1.0, theta=0.0
% INFO    : Bus 28335	: V=1.022058, theta=-78.980361 -> V=1.0, theta=0.0
% INFO    : Bus 28336	: V=1.0247225, theta=-78.918253 -> V=1.0, theta=0.0
% INFO    : Bus 28337	: V=1.0250472, theta=-78.898258 -> V=1.0, theta=0.0
% INFO    : Bus 28338	: V=1.0259832, theta=-79.073522 -> V=1.0, theta=0.0
% INFO    : Bus 28339	: V=1.0129644, theta=-77.829154 -> V=1.0, theta=0.0
% INFO    : Bus 28340	: V=1.0127534, theta=-77.843729 -> V=1.0, theta=0.0
% INFO    : Bus 28341	: V=1.0167183, theta=-75.873944 -> V=1.0, theta=0.0
% INFO    : Bus 28342	: V=1.0164548, theta=-75.901049 -> V=1.0, theta=0.0
% INFO    : Bus 28343	: V=1.0156052, theta=-74.184999 -> V=1.0, theta=0.0
% INFO    : Bus 28344	: V=1.0153305, theta=-76.755163 -> V=1.0, theta=0.0
% INFO    : Bus 28345	: V=1.0208684, theta=-81.859377 -> V=1.0, theta=0.0
% INFO    : Bus 28346	: V=1.0208684, theta=-81.859377 -> V=1.0, theta=0.0
% INFO    : Bus 28347	: V=1.0153218, theta=-74.210558 -> V=1.0, theta=0.0
% INFO    : Bus 28348	: V=1.0125641, theta=-76.942933 -> V=1.0, theta=0.0
% INFO    : Bus 28349	: V=1.0154792, theta=-77.945247 -> V=1.0, theta=0.0
% INFO    : Bus 28350	: V=1.0154539, theta=-78.288015 -> V=1.0, theta=0.0
% INFO    : Bus 28351	: V=1.0222855, theta=-78.834196 -> V=1.0, theta=0.0
% INFO    : Bus 28352	: V=1.0220253, theta=-78.859861 -> V=1.0, theta=0.0
% INFO    : Bus 28353	: V=1.0168365, theta=-79.286065 -> V=1.0, theta=0.0
% INFO    : Bus 28354	: V=1.021686, theta=-78.991902 -> V=1.0, theta=0.0
% INFO    : Bus 28355	: V=1.0166134, theta=-75.599177 -> V=1.0, theta=0.0
% INFO    : Bus 28356	: V=1.0163862, theta=-75.618674 -> V=1.0, theta=0.0
% INFO    : Bus 28357	: V=1.0253324, theta=-74.680985 -> V=1.0, theta=0.0
% INFO    : Bus 28358	: V=1.0137337, theta=-78.192522 -> V=1.0, theta=0.0
% INFO    : Bus 28359	: V=1.0133619, theta=-78.219574 -> V=1.0, theta=0.0
% INFO    : Bus 28360	: V=1.0141236, theta=-78.16188 -> V=1.0, theta=0.0
% INFO    : Bus 28361	: V=1.0094112, theta=-78.640673 -> V=1.0, theta=0.0
% INFO    : Bus 28362	: V=1.0098985, theta=-78.59904 -> V=1.0, theta=0.0
% INFO    : Bus 28363	: V=1.0247529, theta=-79.650727 -> V=1.0, theta=0.0
% INFO    : Bus 28364	: V=1.0188104, theta=-74.475107 -> V=1.0, theta=0.0
% INFO    : Bus 28365	: V=1.0259877, theta=-78.751605 -> V=1.0, theta=0.0
% INFO    : Bus 28366	: V=1.0124431, theta=-77.127724 -> V=1.0, theta=0.0
% INFO    : Bus 28367	: V=1.0141615, theta=-77.982901 -> V=1.0, theta=0.0
% INFO    : Bus 28368	: V=1.0185863, theta=-79.19445 -> V=1.0, theta=0.0
% INFO    : Bus 28369	: V=1.0182994, theta=-79.217079 -> V=1.0, theta=0.0
% INFO    : Bus 28370	: V=0.9930454, theta=-80.014429 -> V=1.0, theta=0.0
% INFO    : Bus 28371	: V=1.016372, theta=-80.107227 -> V=1.0, theta=0.0
% INFO    : Bus 28372	: V=1.0279399, theta=-79.225715 -> V=1.0, theta=0.0
% INFO    : Bus 28373	: V=1.0215033, theta=-78.507937 -> V=1.0, theta=0.0
% INFO    : Bus 28374	: V=1.0212703, theta=-78.531808 -> V=1.0, theta=0.0
% INFO    : Bus 28375	: V=1.0076379, theta=-78.902809 -> V=1.0, theta=0.0
% INFO    : Bus 28376	: V=1.0074887, theta=-78.929571 -> V=1.0, theta=0.0
% INFO    : Bus 28377	: V=1.0107532, theta=-78.832736 -> V=1.0, theta=0.0
% INFO    : Bus 28378	: V=1.0104742, theta=-78.873198 -> V=1.0, theta=0.0
% INFO    : Bus 28379	: V=1.0066965, theta=-79.233171 -> V=1.0, theta=0.0
% INFO    : Bus 28380	: V=1.0065148, theta=-79.258856 -> V=1.0, theta=0.0
% INFO    : Bus 28381	: V=1.0366444, theta=-78.291394 -> V=1.0, theta=0.0
% INFO    : Bus 28382	: V=0.9993234, theta=-79.583211 -> V=1.0, theta=0.0
% INFO    : Bus 28383	: V=1.023022, theta=-78.919817 -> V=1.0, theta=0.0
% INFO    : Bus 28384	: V=1.0228625, theta=-78.937333 -> V=1.0, theta=0.0
% INFO    : Bus 28385	: V=1.0170945, theta=-79.219839 -> V=1.0, theta=0.0
% INFO    : Bus 28386	: V=1.0085691, theta=-78.700437 -> V=1.0, theta=0.0
% INFO    : Bus 28387	: V=1.0147129, theta=-79.120034 -> V=1.0, theta=0.0
% INFO    : Bus 28388	: V=1.0149156, theta=-79.085792 -> V=1.0, theta=0.0
% INFO    : Bus 28389	: V=1.0100378, theta=-79.483313 -> V=1.0, theta=0.0
% INFO    : Bus 28390	: V=1.0138659, theta=-79.317227 -> V=1.0, theta=0.0
% INFO    : Bus 28391	: V=1.0140254, theta=-79.302217 -> V=1.0, theta=0.0
% INFO    : Bus 28392	: V=1.01599, theta=-78.952197 -> V=1.0, theta=0.0
% INFO    : Bus 28393	: V=1.0161311, theta=-78.925165 -> V=1.0, theta=0.0
% INFO    : Bus 28394	: V=1.0156069, theta=-78.915413 -> V=1.0, theta=0.0
% INFO    : Bus 28395	: V=1.0154854, theta=-78.93631 -> V=1.0, theta=0.0
% INFO    : Bus 28396	: V=1.0127738, theta=-79.089515 -> V=1.0, theta=0.0
% INFO    : Bus 28397	: V=1.0125729, theta=-79.113052 -> V=1.0, theta=0.0
% INFO    : Bus 28398	: V=1.0122688, theta=-79.178902 -> V=1.0, theta=0.0
% INFO    : Bus 28399	: V=1.0124479, theta=-79.308131 -> V=1.0, theta=0.0
% INFO    : Bus 28400	: V=1.0126281, theta=-79.29346 -> V=1.0, theta=0.0
% INFO    : Bus 28401	: V=1.0122675, theta=-78.412087 -> V=1.0, theta=0.0
% INFO    : Bus 28402	: V=1.0139137, theta=-78.289488 -> V=1.0, theta=0.0
% INFO    : Bus 28403	: V=1.0128633, theta=-74.897453 -> V=1.0, theta=0.0
% INFO    : Bus 28404	: V=1.0088645, theta=-78.78777 -> V=1.0, theta=0.0
% INFO    : Bus 28405	: V=1.0111601, theta=-76.072659 -> V=1.0, theta=0.0
% INFO    : Bus 28406	: V=1.0111601, theta=-76.072659 -> V=1.0, theta=0.0
% INFO    : Bus 28407	: V=1.0125866, theta=-74.922356 -> V=1.0, theta=0.0
% INFO    : Bus 28408	: V=1.0138191, theta=-74.737462 -> V=1.0, theta=0.0
% INFO    : Bus 28409	: V=1.0090323, theta=-78.985065 -> V=1.0, theta=0.0
% INFO    : Bus 28410	: V=1.0152366, theta=-78.734055 -> V=1.0, theta=0.0
% INFO    : Bus 28411	: V=1.0242341, theta=-78.534771 -> V=1.0, theta=0.0
% INFO    : Bus 28412	: V=1.0211326, theta=-78.067389 -> V=1.0, theta=0.0
% INFO    : Bus 28413	: V=1.0213074, theta=-78.043632 -> V=1.0, theta=0.0
% INFO    : Bus 28414	: V=1.0209795, theta=-78.092695 -> V=1.0, theta=0.0
% INFO    : Bus 28415	: V=1.0211326, theta=-78.067389 -> V=1.0, theta=0.0
% INFO    : Bus 28416	: V=1.0106556, theta=-74.872129 -> V=1.0, theta=0.0
% INFO    : Bus 28417	: V=1.024974, theta=-78.224886 -> V=1.0, theta=0.0
% INFO    : Bus 28418	: V=1.0202825, theta=-78.761401 -> V=1.0, theta=0.0
% INFO    : Bus 28419	: V=1.0193666, theta=-78.263765 -> V=1.0, theta=0.0
% INFO    : Bus 28420	: V=1.0192011, theta=-78.290565 -> V=1.0, theta=0.0
% INFO    : Bus 28421	: V=1.0195291, theta=-78.24059 -> V=1.0, theta=0.0
% INFO    : Bus 28422	: V=1.0176536, theta=-78.600159 -> V=1.0, theta=0.0
% INFO    : Bus 28423	: V=1.0120868, theta=-79.072395 -> V=1.0, theta=0.0
% INFO    : Bus 28424	: V=1.0123754, theta=-79.032861 -> V=1.0, theta=0.0
% INFO    : Bus 28425	: V=1.0071593, theta=-79.146413 -> V=1.0, theta=0.0
% INFO    : Bus 28426	: V=1.0069363, theta=-79.176 -> V=1.0, theta=0.0
% INFO    : Bus 28427	: V=1.0176601, theta=-76.840098 -> V=1.0, theta=0.0
% INFO    : Bus 28428	: V=1.041773, theta=-75.204427 -> V=1.0, theta=0.0
% INFO    : Bus 28429	: V=1.0328414, theta=-78.591791 -> V=1.0, theta=0.0
% INFO    : Bus 28430	: V=1.0275587, theta=-82.042795 -> V=1.0, theta=0.0
% INFO    : Bus 28431	: V=1.0275587, theta=-82.042795 -> V=1.0, theta=0.0
% INFO    : Bus 28432	: V=1.0179555, theta=-77.50038 -> V=1.0, theta=0.0
% INFO    : Bus 28433	: V=1.0177968, theta=-77.530211 -> V=1.0, theta=0.0
% INFO    : Bus 28434	: V=1.0208197, theta=-77.981977 -> V=1.0, theta=0.0
% INFO    : Bus 28435	: V=1.0205921, theta=-78.012317 -> V=1.0, theta=0.0
% INFO    : Bus 28436	: V=1.0113883, theta=-79.397317 -> V=1.0, theta=0.0
% INFO    : Bus 28437	: V=1.0175379, theta=-78.604854 -> V=1.0, theta=0.0
% INFO    : Bus 28438	: V=1.0244251, theta=-78.099146 -> V=1.0, theta=0.0
% INFO    : Bus 28439	: V=1.0338939, theta=-78.75172 -> V=1.0, theta=0.0
% INFO    : Bus 28440	: V=1.0124534, theta=-79.172809 -> V=1.0, theta=0.0
% INFO    : Bus 28441	: V=1.0136244, theta=-77.806272 -> V=1.0, theta=0.0
% INFO    : Bus 28442	: V=1.0163997, theta=-77.661472 -> V=1.0, theta=0.0
% INFO    : Bus 28443	: V=1.0086872, theta=-79.046293 -> V=1.0, theta=0.0
% INFO    : Bus 28444	: V=1.0148585, theta=-78.556699 -> V=1.0, theta=0.0
% INFO    : Bus 28445	: V=1.0147366, theta=-78.580916 -> V=1.0, theta=0.0
% INFO    : Bus 28446	: V=1.0149554, theta=-78.532898 -> V=1.0, theta=0.0
% INFO    : Bus 28447	: V=1.0176865, theta=-78.045081 -> V=1.0, theta=0.0
% INFO    : Bus 28448	: V=1.0217785, theta=-78.82673 -> V=1.0, theta=0.0
% INFO    : Bus 28449	: V=1.0214341, theta=-78.862327 -> V=1.0, theta=0.0
% INFO    : Bus 28450	: V=1.0149006, theta=-78.638333 -> V=1.0, theta=0.0
% INFO    : Bus 28451	: V=1.01476, theta=-78.660885 -> V=1.0, theta=0.0
% INFO    : Bus 28452	: V=1.0133776, theta=-78.972268 -> V=1.0, theta=0.0
% INFO    : Bus 28453	: V=1.0136091, theta=-78.950514 -> V=1.0, theta=0.0
% INFO    : Bus 28454	: V=1.0131327, theta=-78.9938 -> V=1.0, theta=0.0
% INFO    : Bus 28455	: V=1.0127501, theta=-79.069391 -> V=1.0, theta=0.0
% INFO    : Bus 28456	: V=1.012155, theta=-79.157314 -> V=1.0, theta=0.0
% INFO    : Bus 28457	: V=1.0120479, theta=-79.175145 -> V=1.0, theta=0.0
% INFO    : Bus 28458	: V=1.0235742, theta=-72.31423 -> V=1.0, theta=0.0
% INFO    : Bus 28459	: V=1.0316162, theta=-73.332532 -> V=1.0, theta=0.0
% INFO    : Bus 28460	: V=1.024552, theta=-72.209333 -> V=1.0, theta=0.0
% INFO    : Bus 28461	: V=1.0235742, theta=-72.31423 -> V=1.0, theta=0.0
% INFO    : Bus 28462	: V=1.0195788, theta=-75.271845 -> V=1.0, theta=0.0
% INFO    : Bus 28463	: V=1.0164899, theta=-77.744713 -> V=1.0, theta=0.0
% INFO    : Bus 28464	: V=1.0152123, theta=-77.959739 -> V=1.0, theta=0.0
% INFO    : Bus 28465	: V=1.0151168, theta=-77.978404 -> V=1.0, theta=0.0
% INFO    : Bus 28466	: V=1.0208386, theta=-78.656499 -> V=1.0, theta=0.0
% INFO    : Bus 28467	: V=1.0105137, theta=-79.383715 -> V=1.0, theta=0.0
% INFO    : Bus 28468	: V=1.0103079, theta=-79.40822 -> V=1.0, theta=0.0
% INFO    : Bus 28469	: V=1.0231727, theta=-78.291242 -> V=1.0, theta=0.0
% INFO    : Bus 28470	: V=1.0229971, theta=-78.317835 -> V=1.0, theta=0.0
% INFO    : Bus 28471	: V=1.0228654, theta=-78.310806 -> V=1.0, theta=0.0
% INFO    : Bus 28472	: V=1.0086091, theta=-78.843323 -> V=1.0, theta=0.0
% INFO    : Bus 28473	: V=1.0060538, theta=-79.420722 -> V=1.0, theta=0.0
% INFO    : Bus 28474	: V=1.0212622, theta=-78.046747 -> V=1.0, theta=0.0
% INFO    : Bus 28475	: V=1.0193025, theta=-77.956887 -> V=1.0, theta=0.0
% INFO    : Bus 28476	: V=1.0274678, theta=-73.543277 -> V=1.0, theta=0.0
% INFO    : Bus 28477	: V=1.023963, theta=-73.479113 -> V=1.0, theta=0.0
% INFO    : Bus 28478	: V=1.0237845, theta=-73.499444 -> V=1.0, theta=0.0
% INFO    : Bus 28479	: V=1.0029433, theta=-79.582653 -> V=1.0, theta=0.0
% INFO    : Bus 28480	: V=1.0044457, theta=-79.894611 -> V=1.0, theta=0.0
% INFO    : Bus 28481	: V=1.0135206, theta=-79.095427 -> V=1.0, theta=0.0
% INFO    : Bus 28482	: V=1.0159253, theta=-78.689771 -> V=1.0, theta=0.0
% INFO    : Bus 28483	: V=1.0157005, theta=-78.712288 -> V=1.0, theta=0.0
% INFO    : Bus 28484	: V=1.0128856, theta=-78.692124 -> V=1.0, theta=0.0
% INFO    : Bus 28485	: V=1.00357, theta=-79.781353 -> V=1.0, theta=0.0
% INFO    : Bus 28486	: V=1.0033789, theta=-79.807328 -> V=1.0, theta=0.0
% INFO    : Bus 28487	: V=1.0058511, theta=-79.818493 -> V=1.0, theta=0.0
% INFO    : Bus 28488	: V=1.0061058, theta=-79.792458 -> V=1.0, theta=0.0
% INFO    : Bus 28489	: V=1.0056252, theta=-79.846424 -> V=1.0, theta=0.0
% INFO    : Bus 28490	: V=1.0194076, theta=-78.645242 -> V=1.0, theta=0.0
% INFO    : Bus 28491	: V=1.0191942, theta=-78.929523 -> V=1.0, theta=0.0
% INFO    : Bus 28492	: V=1.0190871, theta=-78.943631 -> V=1.0, theta=0.0
% INFO    : Bus 28493	: V=1.0121134, theta=-78.514597 -> V=1.0, theta=0.0
% INFO    : Bus 28494	: V=1.0117648, theta=-78.541527 -> V=1.0, theta=0.0
% INFO    : Bus 28495	: V=1.0143949, theta=-78.563424 -> V=1.0, theta=0.0
% INFO    : Bus 28496	: V=1.0141444, theta=-78.594357 -> V=1.0, theta=0.0
% INFO    : Bus 28497	: V=1.0215885, theta=-78.542174 -> V=1.0, theta=0.0
% INFO    : Bus 28498	: V=1.0146857, theta=-78.794694 -> V=1.0, theta=0.0
% INFO    : Bus 28499	: V=1.0143222, theta=-79.000461 -> V=1.0, theta=0.0
% INFO    : Bus 28500	: V=1.0139992, theta=-79.025688 -> V=1.0, theta=0.0
% INFO    : Bus 28501	: V=1.0145989, theta=-78.977099 -> V=1.0, theta=0.0
% INFO    : Bus 28502	: V=1.0207222, theta=-73.843468 -> V=1.0, theta=0.0
% INFO    : Bus 28503	: V=1.0221745, theta=-78.176204 -> V=1.0, theta=0.0
% INFO    : Bus 28504	: V=1.0137739, theta=-79.291952 -> V=1.0, theta=0.0
% INFO    : Bus 28505	: V=1.0135029, theta=-79.310625 -> V=1.0, theta=0.0
% INFO    : Bus 28506	: V=1.0211114, theta=-78.557528 -> V=1.0, theta=0.0
% INFO    : Bus 28507	: V=1.0209056, theta=-78.57801 -> V=1.0, theta=0.0
% INFO    : Bus 28508	: V=1.0213187, theta=-78.536124 -> V=1.0, theta=0.0
% INFO    : Bus 28509	: V=1.0214313, theta=-77.848022 -> V=1.0, theta=0.0
% INFO    : Bus 28510	: V=1.0174428, theta=-78.414078 -> V=1.0, theta=0.0
% INFO    : Bus 28511	: V=1.0142374, theta=-78.69523 -> V=1.0, theta=0.0
% INFO    : Bus 28512	: V=1.0138831, theta=-78.728887 -> V=1.0, theta=0.0
% INFO    : Bus 28513	: V=1.0145629, theta=-78.66735 -> V=1.0, theta=0.0
% INFO    : Bus 28514	: V=1.0117082, theta=-78.547738 -> V=1.0, theta=0.0
% INFO    : Bus 28515	: V=1.0114669, theta=-78.578612 -> V=1.0, theta=0.0
% INFO    : Bus 28516	: V=1.0119877, theta=-78.518375 -> V=1.0, theta=0.0
% INFO    : Bus 28517	: V=1.0117082, theta=-78.547738 -> V=1.0, theta=0.0
% INFO    : Bus 28518	: V=1.0167649, theta=-78.567694 -> V=1.0, theta=0.0
% INFO    : Bus 28519	: V=1.0170883, theta=-78.532864 -> V=1.0, theta=0.0
% INFO    : Bus 28520	: V=1.0096522, theta=-78.696372 -> V=1.0, theta=0.0
% INFO    : Bus 28521	: V=1.009266, theta=-78.729637 -> V=1.0, theta=0.0
% INFO    : Bus 28522	: V=1.0190019, theta=-78.138618 -> V=1.0, theta=0.0
% INFO    : Bus 28523	: V=1.0211116, theta=-78.04096 -> V=1.0, theta=0.0
% INFO    : Bus 28524	: V=1.0134002, theta=-78.955928 -> V=1.0, theta=0.0
% INFO    : Bus 28525	: V=1.0106003, theta=-78.706021 -> V=1.0, theta=0.0
% INFO    : Bus 28526	: V=1.0129013, theta=-78.5123 -> V=1.0, theta=0.0
% INFO    : Bus 28527	: V=1.0124324, theta=-78.555056 -> V=1.0, theta=0.0
% INFO    : Bus 28528	: V=1.0134058, theta=-78.465881 -> V=1.0, theta=0.0
% INFO    : Bus 28529	: V=1.0129013, theta=-78.5123 -> V=1.0, theta=0.0
% INFO    : Bus 28530	: V=1.0211287, theta=-78.352455 -> V=1.0, theta=0.0
% INFO    : Bus 28531	: V=1.0226174, theta=-77.219675 -> V=1.0, theta=0.0
% INFO    : Bus 28532	: V=1.0102633, theta=-77.236742 -> V=1.0, theta=0.0
% INFO    : Bus 28533	: V=1.0100911, theta=-77.262578 -> V=1.0, theta=0.0
% INFO    : Bus 28534	: V=1.0104505, theta=-77.212255 -> V=1.0, theta=0.0
% INFO    : Bus 28535	: V=1.0156965, theta=-74.63185 -> V=1.0, theta=0.0
% INFO    : Bus 28536	: V=1.011369, theta=-77.686988 -> V=1.0, theta=0.0
% INFO    : Bus 28537	: V=1.011369, theta=-77.686988 -> V=1.0, theta=0.0
% INFO    : Bus 28538	: V=1.011369, theta=-77.686988 -> V=1.0, theta=0.0
% INFO    : Bus 28539	: V=1.011369, theta=-77.686988 -> V=1.0, theta=0.0
% INFO    : Bus 28540	: V=1.0154234, theta=-74.657651 -> V=1.0, theta=0.0
% INFO    : Bus 28541	: V=1.0162268, theta=-78.813688 -> V=1.0, theta=0.0
% INFO    : Bus 28542	: V=1.015974, theta=-78.842332 -> V=1.0, theta=0.0
% INFO    : Bus 28543	: V=1.0161444, theta=-74.494277 -> V=1.0, theta=0.0
% INFO    : Bus 28544	: V=1.0123007, theta=-78.465721 -> V=1.0, theta=0.0
% INFO    : Bus 28545	: V=1.0150813, theta=-78.83939 -> V=1.0, theta=0.0
% INFO    : Bus 28546	: V=1.0147948, theta=-78.865077 -> V=1.0, theta=0.0
% INFO    : Bus 28547	: V=1.0147745, theta=-78.767728 -> V=1.0, theta=0.0
% INFO    : Bus 28548	: V=1.0153933, theta=-74.552427 -> V=1.0, theta=0.0
% INFO    : Bus 28549	: V=1.009829, theta=-78.643903 -> V=1.0, theta=0.0
% INFO    : Bus 28550	: V=1.0091053, theta=-80.085688 -> V=1.0, theta=0.0
% INFO    : Bus 28551	: V=1.0091053, theta=-80.085688 -> V=1.0, theta=0.0
% INFO    : Bus 28552	: V=1.0160624, theta=-78.970688 -> V=1.0, theta=0.0
% INFO    : Bus 28553	: V=1.0203019, theta=-78.729961 -> V=1.0, theta=0.0
% INFO    : Bus 28554	: V=1.0174171, theta=-79.15649 -> V=1.0, theta=0.0
% INFO    : Bus 28555	: V=1.0230885, theta=-77.247785 -> V=1.0, theta=0.0
% INFO    : Bus 28556	: V=1.0299637, theta=-78.424982 -> V=1.0, theta=0.0
% INFO    : Bus 28557	: V=1.0166182, theta=-78.91056 -> V=1.0, theta=0.0
% INFO    : Bus 28558	: V=1.0168676, theta=-78.894587 -> V=1.0, theta=0.0
% INFO    : Bus 28559	: V=1.0166182, theta=-78.91056 -> V=1.0, theta=0.0
% INFO    : Bus 28560	: V=1.0102504, theta=-78.869841 -> V=1.0, theta=0.0
% INFO    : Bus 28561	: V=1.010126, theta=-78.887758 -> V=1.0, theta=0.0
% INFO    : Bus 28562	: V=1.0166427, theta=-79.220337 -> V=1.0, theta=0.0
% INFO    : Bus 28563	: V=1.0169607, theta=-79.191102 -> V=1.0, theta=0.0
% INFO    : Bus 28564	: V=1.0163283, theta=-78.509806 -> V=1.0, theta=0.0
% INFO    : Bus 28565	: V=1.0160554, theta=-78.546321 -> V=1.0, theta=0.0
% INFO    : Bus 28566	: V=1.0017725, theta=-75.69689 -> V=1.0, theta=0.0
% INFO    : Bus 28567	: V=1.0307871, theta=-77.200434 -> V=1.0, theta=0.0
% INFO    : Bus 28568	: V=1.0345126, theta=-78.392395 -> V=1.0, theta=0.0
% INFO    : Bus 28569	: V=1.0266926, theta=-77.283294 -> V=1.0, theta=0.0
% INFO    : Bus 28570	: V=1.0253723, theta=-78.898419 -> V=1.0, theta=0.0
% INFO    : Bus 28571	: V=1.025178, theta=-78.92338 -> V=1.0, theta=0.0
% INFO    : Bus 28572	: V=1.0242807, theta=-78.859405 -> V=1.0, theta=0.0
% INFO    : Bus 28573	: V=1.0193777, theta=-78.751139 -> V=1.0, theta=0.0
% INFO    : Bus 28574	: V=1.0125808, theta=-74.414945 -> V=1.0, theta=0.0
% INFO    : Bus 28575	: V=1.0248501, theta=-78.344853 -> V=1.0, theta=0.0
% INFO    : Bus 28576	: V=1.0260249, theta=-77.939842 -> V=1.0, theta=0.0
% INFO    : Bus 28577	: V=1.0063326, theta=-78.738577 -> V=1.0, theta=0.0
% INFO    : Bus 28578	: V=1.0100012, theta=-78.646063 -> V=1.0, theta=0.0
% INFO    : Bus 28579	: V=1.0095955, theta=-78.686659 -> V=1.0, theta=0.0
% INFO    : Bus 28580	: V=1.0153748, theta=-78.977391 -> V=1.0, theta=0.0
% INFO    : Bus 28581	: V=1.020561, theta=-73.96116 -> V=1.0, theta=0.0
% INFO    : Bus 28582	: V=1.0261789, theta=-76.440736 -> V=1.0, theta=0.0
% INFO    : Bus 28583	: V=1.0169375, theta=-78.082937 -> V=1.0, theta=0.0
% INFO    : Bus 28584	: V=1.0166897, theta=-78.112634 -> V=1.0, theta=0.0
% INFO    : Bus 28585	: V=1.0204681, theta=-78.384243 -> V=1.0, theta=0.0
% INFO    : Bus 28586	: V=1.0202931, theta=-78.410367 -> V=1.0, theta=0.0
% INFO    : Bus 28587	: V=1.0224698, theta=-77.996797 -> V=1.0, theta=0.0
% INFO    : Bus 28588	: V=1.0226605, theta=-77.967473 -> V=1.0, theta=0.0
% INFO    : Bus 28589	: V=1.0227981, theta=-78.362977 -> V=1.0, theta=0.0
% INFO    : Bus 28590	: V=1.0213009, theta=-78.404317 -> V=1.0, theta=0.0
% INFO    : Bus 28591	: V=1.021967, theta=-78.551565 -> V=1.0, theta=0.0
% INFO    : Bus 28592	: V=1.0211846, theta=-78.409147 -> V=1.0, theta=0.0
% INFO    : Bus 28593	: V=1.021056, theta=-78.442678 -> V=1.0, theta=0.0
% INFO    : Bus 28594	: V=1.0141766, theta=-78.471242 -> V=1.0, theta=0.0
% INFO    : Bus 28595	: V=1.0126674, theta=-78.611259 -> V=1.0, theta=0.0
% INFO    : Bus 28596	: V=1.0175909, theta=-78.010964 -> V=1.0, theta=0.0
% INFO    : Bus 28597	: V=1.0220764, theta=-76.991463 -> V=1.0, theta=0.0
% INFO    : Bus 28598	: V=1.0153324, theta=-74.135946 -> V=1.0, theta=0.0
% INFO    : Bus 28599	: V=1.0248509, theta=-78.244962 -> V=1.0, theta=0.0
% INFO    : Bus 28600	: V=1.0172848, theta=-78.822663 -> V=1.0, theta=0.0
% INFO    : Bus 28601	: V=1.0175201, theta=-78.801431 -> V=1.0, theta=0.0
% INFO    : Bus 28602	: V=1.0172848, theta=-78.822663 -> V=1.0, theta=0.0
% INFO    : Bus 28603	: V=1.0091734, theta=-78.565968 -> V=1.0, theta=0.0
% INFO    : Bus 28604	: V=1.0154204, theta=-78.525972 -> V=1.0, theta=0.0
% INFO    : Bus 28605	: V=1.0115746, theta=-79.00811 -> V=1.0, theta=0.0
% INFO    : Bus 28606	: V=1.0119034, theta=-78.975828 -> V=1.0, theta=0.0
% INFO    : Bus 28607	: V=1.0112308, theta=-79.039682 -> V=1.0, theta=0.0
% INFO    : Bus 28608	: V=1.0138618, theta=-78.619713 -> V=1.0, theta=0.0
% INFO    : Bus 28609	: V=1.0135871, theta=-78.651422 -> V=1.0, theta=0.0
% INFO    : Bus 28610	: V=1.0183042, theta=-67.758675 -> V=1.0, theta=0.0
% INFO    : Bus 28611	: V=1.0287956, theta=-77.330382 -> V=1.0, theta=0.0
% INFO    : Bus 28612	: V=1.0281894, theta=-77.866311 -> V=1.0, theta=0.0
% INFO    : Bus 28613	: V=1.0220092, theta=-78.340138 -> V=1.0, theta=0.0
% INFO    : Bus 28614	: V=1.0218177, theta=-78.366293 -> V=1.0, theta=0.0
% INFO    : Bus 28615	: V=1.0193214, theta=-78.553593 -> V=1.0, theta=0.0
% INFO    : Bus 28616	: V=1.0284459, theta=-78.205359 -> V=1.0, theta=0.0
% INFO    : Bus 28617	: V=1.028545, theta=-78.188914 -> V=1.0, theta=0.0
% INFO    : Bus 28618	: V=1.025595, theta=-77.844875 -> V=1.0, theta=0.0
% INFO    : Bus 28619	: V=1.0239354, theta=-72.337421 -> V=1.0, theta=0.0
% INFO    : Bus 28620	: V=1.0238772, theta=-72.344433 -> V=1.0, theta=0.0
% INFO    : Bus 28621	: V=1.0155229, theta=-78.128225 -> V=1.0, theta=0.0
% INFO    : Bus 28622	: V=1.0158723, theta=-78.104563 -> V=1.0, theta=0.0
% INFO    : Bus 28623	: V=1.0160802, theta=-78.037916 -> V=1.0, theta=0.0
% INFO    : Bus 28624	: V=1.0210195, theta=-77.273562 -> V=1.0, theta=0.0
% INFO    : Bus 28625	: V=1.0089769, theta=-75.044815 -> V=1.0, theta=0.0
% INFO    : Bus 28626	: V=1.0316551, theta=-77.170423 -> V=1.0, theta=0.0
% INFO    : Bus 28627	: V=1.0087732, theta=-75.066236 -> V=1.0, theta=0.0
% INFO    : Bus 28628	: V=1.022716, theta=-78.521586 -> V=1.0, theta=0.0
% INFO    : Bus 28629	: V=1.0225869, theta=-78.529606 -> V=1.0, theta=0.0
% INFO    : Bus 28630	: V=1.0223766, theta=-78.54927 -> V=1.0, theta=0.0
% INFO    : Bus 28631	: V=1.0137076, theta=-74.792012 -> V=1.0, theta=0.0
% INFO    : Bus 28632	: V=1.0214158, theta=-77.86119 -> V=1.0, theta=0.0
% INFO    : Bus 28633	: V=1.0037478, theta=-78.166306 -> V=1.0, theta=0.0
% INFO    : Bus 28634	: V=1.0039694, theta=-78.129254 -> V=1.0, theta=0.0
% INFO    : Bus 28635	: V=1.009845, theta=-77.684475 -> V=1.0, theta=0.0
% INFO    : Bus 28636	: V=1.009691, theta=-77.703819 -> V=1.0, theta=0.0
% INFO    : Bus 28637	: V=1.0094678, theta=-77.751049 -> V=1.0, theta=0.0
% INFO    : Bus 28638	: V=1.0264834, theta=-76.056895 -> V=1.0, theta=0.0
% INFO    : Bus 28639	: V=1.0263445, theta=-76.076602 -> V=1.0, theta=0.0
% INFO    : Bus 28640	: V=1.0251193, theta=-76.004514 -> V=1.0, theta=0.0
% INFO    : Bus 28641	: V=1.0214247, theta=-73.335532 -> V=1.0, theta=0.0
% INFO    : Bus 28642	: V=1.0119015, theta=-78.844923 -> V=1.0, theta=0.0
% INFO    : Bus 28643	: V=1.0120047, theta=-78.836051 -> V=1.0, theta=0.0
% INFO    : Bus 28644	: V=1.0053045, theta=-78.610885 -> V=1.0, theta=0.0
% INFO    : Bus 28645	: V=1.026507, theta=-69.480912 -> V=1.0, theta=0.0
% INFO    : Bus 28646	: V=1.0232682, theta=-76.251164 -> V=1.0, theta=0.0
% INFO    : Bus 28647	: V=1.0285468, theta=-75.83365 -> V=1.0, theta=0.0
% INFO    : Bus 28648	: V=1.0321587, theta=-74.666855 -> V=1.0, theta=0.0
% INFO    : Bus 28649	: V=1.0318516, theta=-74.709109 -> V=1.0, theta=0.0
% INFO    : Bus 28650	: V=1.0318516, theta=-74.709109 -> V=1.0, theta=0.0
% INFO    : Bus 28651	: V=1.0318516, theta=-74.709109 -> V=1.0, theta=0.0
% INFO    : Bus 28652	: V=1.0318516, theta=-74.709109 -> V=1.0, theta=0.0
% INFO    : Bus 28653	: V=1.0268483, theta=-75.65888 -> V=1.0, theta=0.0
% INFO    : Bus 28654	: V=1.0270629, theta=-75.636417 -> V=1.0, theta=0.0
% INFO    : Bus 28655	: V=1.0231921, theta=-72.798245 -> V=1.0, theta=0.0
% INFO    : Bus 28656	: V=1.0283719, theta=-75.287586 -> V=1.0, theta=0.0
% INFO    : Bus 28657	: V=1.0228517, theta=-72.815805 -> V=1.0, theta=0.0
% INFO    : Bus 28658	: V=1.0314799, theta=-74.887664 -> V=1.0, theta=0.0
% INFO    : Bus 28659	: V=1.0302905, theta=-75.044746 -> V=1.0, theta=0.0
% INFO    : Bus 28660	: V=1.0298205, theta=-73.829684 -> V=1.0, theta=0.0
% INFO    : Bus 28661	: V=1.0296821, theta=-73.842615 -> V=1.0, theta=0.0
% INFO    : Bus 28662	: V=1.0224811, theta=-73.517491 -> V=1.0, theta=0.0
% INFO    : Bus 28663	: V=1.0223329, theta=-73.529235 -> V=1.0, theta=0.0
% INFO    : Bus 28664	: V=1.0287157, theta=-75.337982 -> V=1.0, theta=0.0
% INFO    : Bus 28665	: V=1.028604, theta=-75.359073 -> V=1.0, theta=0.0
% INFO    : Bus 28666	: V=1.0201789, theta=-75.65453 -> V=1.0, theta=0.0
% INFO    : Bus 28667	: V=1.014413, theta=-75.672801 -> V=1.0, theta=0.0
% INFO    : Bus 28668	: V=1.0046194, theta=-75.909477 -> V=1.0, theta=0.0
% INFO    : Bus 28669	: V=1.0046194, theta=-75.909477 -> V=1.0, theta=0.0
% INFO    : Bus 28670	: V=1.0046194, theta=-75.909477 -> V=1.0, theta=0.0
% INFO    : Bus 28671	: V=1.0046194, theta=-75.909477 -> V=1.0, theta=0.0
% INFO    : Bus 28672	: V=1.0062179, theta=-76.07341 -> V=1.0, theta=0.0
% INFO    : Bus 28673	: V=1.0269564, theta=-73.110348 -> V=1.0, theta=0.0
% INFO    : Bus 28674	: V=1.0207223, theta=-72.794722 -> V=1.0, theta=0.0
% INFO    : Bus 28675	: V=1.0126748, theta=-75.546744 -> V=1.0, theta=0.0
% INFO    : Bus 28676	: V=1.0125145, theta=-75.56638 -> V=1.0, theta=0.0
% INFO    : Bus 28677	: V=1.008623, theta=-75.95674 -> V=1.0, theta=0.0
% INFO    : Bus 28678	: V=1.008536, theta=-75.970944 -> V=1.0, theta=0.0
% INFO    : Bus 28679	: V=1.0158138, theta=-74.144883 -> V=1.0, theta=0.0
% INFO    : Bus 28680	: V=1.0188207, theta=-73.633867 -> V=1.0, theta=0.0
% INFO    : Bus 28681	: V=1.0184998, theta=-73.662379 -> V=1.0, theta=0.0
% INFO    : Bus 28682	: V=1.0154913, theta=-74.655406 -> V=1.0, theta=0.0
% INFO    : Bus 28683	: V=1.0152225, theta=-74.673665 -> V=1.0, theta=0.0
% INFO    : Bus 28684	: V=1.0230174, theta=-72.528262 -> V=1.0, theta=0.0
% INFO    : Bus 28685	: V=1.0148467, theta=-75.012042 -> V=1.0, theta=0.0
% INFO    : Bus 28686	: V=1.0105805, theta=-76.642251 -> V=1.0, theta=0.0
% INFO    : Bus 28687	: V=1.0105805, theta=-76.642251 -> V=1.0, theta=0.0
% INFO    : Bus 28688	: V=1.0289811, theta=-70.819589 -> V=1.0, theta=0.0
% INFO    : Bus 28689	: V=1.0232119, theta=-72.14412 -> V=1.0, theta=0.0
% INFO    : Bus 28690	: V=1.0231192, theta=-72.163695 -> V=1.0, theta=0.0
% INFO    : Bus 28691	: V=1.0279331, theta=-72.511165 -> V=1.0, theta=0.0
% INFO    : Bus 28692	: V=1.0279061, theta=-72.51497 -> V=1.0, theta=0.0
% INFO    : Bus 28693	: V=1.0279572, theta=-72.50731 -> V=1.0, theta=0.0
% INFO    : Bus 28694	: V=1.0210746, theta=-72.727785 -> V=1.0, theta=0.0
% INFO    : Bus 28695	: V=1.0315353, theta=-68.018821 -> V=1.0, theta=0.0
% INFO    : Bus 28696	: V=1.0313529, theta=-68.041214 -> V=1.0, theta=0.0
% INFO    : Bus 28697	: V=1.0200553, theta=-72.122285 -> V=1.0, theta=0.0
% INFO    : Bus 28698	: V=1.018653, theta=-67.496984 -> V=1.0, theta=0.0
% INFO    : Bus 28699	: V=1.0202193, theta=-67.580995 -> V=1.0, theta=0.0
% INFO    : Bus 28700	: V=1.0201034, theta=-67.604965 -> V=1.0, theta=0.0
% INFO    : Bus 28701	: V=1.0342398, theta=-68.419107 -> V=1.0, theta=0.0
% INFO    : Bus 28702	: V=1.0341844, theta=-68.42814 -> V=1.0, theta=0.0
% INFO    : Bus 28703	: V=1.0343177, theta=-68.408942 -> V=1.0, theta=0.0
% INFO    : Bus 28704	: V=1.0224039, theta=-66.721808 -> V=1.0, theta=0.0
% INFO    : Bus 28705	: V=1.020504, theta=-66.901171 -> V=1.0, theta=0.0
% INFO    : Bus 28706	: V=1.0206784, theta=-67.681953 -> V=1.0, theta=0.0
% INFO    : Bus 28707	: V=1.0205824, theta=-67.689221 -> V=1.0, theta=0.0
% INFO    : Bus 28708	: V=1.0279128, theta=-67.963805 -> V=1.0, theta=0.0
% INFO    : Bus 28709	: V=1.0278217, theta=-67.978552 -> V=1.0, theta=0.0
% INFO    : Bus 28710	: V=1.0275426, theta=-68.005007 -> V=1.0, theta=0.0
% INFO    : Bus 28711	: V=1.0123921, theta=-67.280801 -> V=1.0, theta=0.0
% INFO    : Bus 28712	: V=1.0495659, theta=-69.843444 -> V=1.0, theta=0.0
% INFO    : Bus 28713	: V=1.0288136, theta=-67.252719 -> V=1.0, theta=0.0
% INFO    : Bus 28714	: V=1.028412, theta=-67.27492 -> V=1.0, theta=0.0
% INFO    : Bus 28715	: V=1.0215992, theta=-62.830551 -> V=1.0, theta=0.0
% INFO    : Bus 28716	: V=1.0216699, theta=-62.824721 -> V=1.0, theta=0.0
% INFO    : Bus 28717	: V=1.0328308, theta=-67.573568 -> V=1.0, theta=0.0
% INFO    : Bus 28718	: V=1.0373787, theta=-68.673792 -> V=1.0, theta=0.0
% INFO    : Bus 28719	: V=1.0387829, theta=-69.429731 -> V=1.0, theta=0.0
% INFO    : Bus 28720	: V=1.0329031, theta=-67.194869 -> V=1.0, theta=0.0
% INFO    : Bus 28721	: V=1.0328308, theta=-67.573568 -> V=1.0, theta=0.0
% INFO    : Bus 28722	: V=1.0328438, theta=-67.511752 -> V=1.0, theta=0.0
% INFO    : Bus 28723	: V=1.0374812, theta=-68.341752 -> V=1.0, theta=0.0
% INFO    : Bus 28724	: V=1.0202968, theta=-78.341365 -> V=1.0, theta=0.0
% INFO    : Bus 28725	: V=1.0131242, theta=-72.041161 -> V=1.0, theta=0.0
% INFO    : Bus 28726	: V=1.034546, theta=-74.265244 -> V=1.0, theta=0.0
% INFO    : Bus 28727	: V=1.0475859, theta=-71.628886 -> V=1.0, theta=0.0
% INFO    : Bus 28728	: V=1.0231519, theta=-77.833584 -> V=1.0, theta=0.0
% INFO    : Bus 28729	: V=1.0600902, theta=-73.811822 -> V=1.0, theta=0.0
% INFO    : Bus 28730	: V=1.026938, theta=-67.066059 -> V=1.0, theta=0.0
% INFO    : Bus 28731	: V=1.0237798, theta=-67.023433 -> V=1.0, theta=0.0
% INFO    : Bus 28732	: V=1.0241007, theta=-66.446312 -> V=1.0, theta=0.0
% INFO    : Bus 28733	: V=1.0242224, theta=-66.103432 -> V=1.0, theta=0.0
% INFO    : Bus 28734	: V=1.02373, theta=-67.159489 -> V=1.0, theta=0.0
% INFO    : Bus 28735	: V=1.0237798, theta=-67.023433 -> V=1.0, theta=0.0
% INFO    : Bus 28736	: V=1.0243585, theta=-65.215168 -> V=1.0, theta=0.0
% INFO    : Bus 28737	: V=1.0524174, theta=-68.840013 -> V=1.0, theta=0.0
% INFO    : Bus 28738	: V=1.037267, theta=-68.558087 -> V=1.0, theta=0.0
% INFO    : Bus 28739	: V=1.0304038, theta=-69.231028 -> V=1.0, theta=0.0
% INFO    : Bus 28740	: V=1.0459227, theta=-68.606034 -> V=1.0, theta=0.0
% INFO    : Bus 28741	: V=1.0524174, theta=-68.840013 -> V=1.0, theta=0.0
% INFO    : Bus 28742	: V=1.0459245, theta=-68.59283 -> V=1.0, theta=0.0
% INFO    : Bus 28743	: V=1.0459231, theta=-68.642674 -> V=1.0, theta=0.0
% INFO    : Bus 28744	: V=1.0459678, theta=-68.3391 -> V=1.0, theta=0.0
% INFO    : Bus 28745	: V=1.0493733, theta=-62.506615 -> V=1.0, theta=0.0
% INFO    : Bus 28746	: V=1.0459252, theta=-68.634942 -> V=1.0, theta=0.0
% INFO    : Bus 28747	: V=1.0459759, theta=-68.327535 -> V=1.0, theta=0.0
% INFO    : Bus 28748	: V=1.045912, theta=-68.64757 -> V=1.0, theta=0.0
% INFO    : Bus 28749	: V=1.0175887, theta=-66.640457 -> V=1.0, theta=0.0
% INFO    : Bus 28750	: V=1.0206081, theta=-66.920769 -> V=1.0, theta=0.0
% INFO    : Bus 28751	: V=0.9929255, theta=-65.636905 -> V=1.0, theta=0.0
% INFO    : Bus 28752	: V=0.9928866, theta=-66.01803 -> V=1.0, theta=0.0
% INFO    : Bus 28753	: V=0.9929581, theta=-65.603335 -> V=1.0, theta=0.0
% INFO    : Bus 28754	: V=0.9928907, theta=-66.166585 -> V=1.0, theta=0.0
% INFO    : Bus 28755	: V=1.0341671, theta=-68.148932 -> V=1.0, theta=0.0
% INFO    : Bus 28756	: V=1.0180757, theta=-72.94883 -> V=1.0, theta=0.0
% INFO    : Bus 28757	: V=1.0283128, theta=-70.900118 -> V=1.0, theta=0.0
% INFO    : Bus 28758	: V=1.0231281, theta=-58.467549 -> V=1.0, theta=0.0
% INFO    : Bus 28759	: V=1.0277875, theta=-59.792565 -> V=1.0, theta=0.0
% INFO    : Bus 28760	: V=1.0295765, theta=-59.994263 -> V=1.0, theta=0.0
% INFO    : Bus 28761	: V=1.0231281, theta=-58.467549 -> V=1.0, theta=0.0
% INFO    : Bus 28762	: V=1.0245099, theta=-69.045822 -> V=1.0, theta=0.0
% INFO    : Bus 28763	: V=1.0286966, theta=-72.227672 -> V=1.0, theta=0.0
% INFO    : Bus 28764	: V=1.0345285, theta=-74.23865 -> V=1.0, theta=0.0
% INFO    : Bus 28765	: V=1.0324166, theta=-68.194929 -> V=1.0, theta=0.0
% INFO    : Bus 28766	: V=1.0306213, theta=-68.388859 -> V=1.0, theta=0.0
% INFO    : Bus 28767	: V=1.0245099, theta=-69.045822 -> V=1.0, theta=0.0
% INFO    : Bus 28768	: V=1.0295396, theta=-68.507204 -> V=1.0, theta=0.0
% INFO    : Bus 28769	: V=1.0284795, theta=-68.620598 -> V=1.0, theta=0.0
% INFO    : Bus 28770	: V=1.0315382, theta=-68.294238 -> V=1.0, theta=0.0
% INFO    : Bus 28771	: V=1.0251799, theta=-68.974608 -> V=1.0, theta=0.0
% INFO    : Bus 28772	: V=1.0266038, theta=-69.043942 -> V=1.0, theta=0.0
% INFO    : Bus 28773	: V=1.0103731, theta=-74.967709 -> V=1.0, theta=0.0
% INFO    : Bus 28774	: V=1.0240193, theta=-77.882306 -> V=1.0, theta=0.0
% INFO    : Bus 28775	: V=1.0240193, theta=-77.882306 -> V=1.0, theta=0.0
% INFO    : Bus 28776	: V=1.0240193, theta=-77.882306 -> V=1.0, theta=0.0
% INFO    : Bus 28777	: V=1.0240193, theta=-77.882306 -> V=1.0, theta=0.0
% INFO    : Bus 28778	: V=0.9968167, theta=-73.733463 -> V=1.0, theta=0.0
% INFO    : Bus 28779	: V=0.9972819, theta=-73.688855 -> V=1.0, theta=0.0
% INFO    : Bus 28780	: V=1.011893, theta=-74.921658 -> V=1.0, theta=0.0
% INFO    : Bus 28781	: V=1.0224824, theta=-71.173906 -> V=1.0, theta=0.0
% INFO    : Bus 28782	: V=1.0189473, theta=-73.872359 -> V=1.0, theta=0.0
% INFO    : Bus 28783	: V=1.0196941, theta=-77.204691 -> V=1.0, theta=0.0
% INFO    : Bus 28784	: V=1.0270478, theta=-70.205887 -> V=1.0, theta=0.0
% INFO    : Bus 28785	: V=1.026657, theta=-70.036834 -> V=1.0, theta=0.0
% INFO    : Bus 28786	: V=1.0274062, theta=-70.375224 -> V=1.0, theta=0.0
% INFO    : Bus 28787	: V=1.0268061, theta=-70.090117 -> V=1.0, theta=0.0
% INFO    : Bus 28788	: V=1.0275259, theta=-70.439216 -> V=1.0, theta=0.0
% INFO    : Bus 28789	: V=1.0271089, theta=-70.234824 -> V=1.0, theta=0.0
% INFO    : Bus 28790	: V=1.0190288, theta=-78.502565 -> V=1.0, theta=0.0
% INFO    : Bus 28791	: V=1.0347173, theta=-76.876237 -> V=1.0, theta=0.0
% INFO    : Bus 28792	: V=1.0347173, theta=-76.876237 -> V=1.0, theta=0.0
% INFO    : Bus 28793	: V=1.0196574, theta=-78.435665 -> V=1.0, theta=0.0
% INFO    : Bus 28794	: V=1.0270395, theta=-71.841239 -> V=1.0, theta=0.0
% INFO    : Bus 28795	: V=1.0166285, theta=-75.015272 -> V=1.0, theta=0.0
% INFO    : Bus 28796	: V=1.011505, theta=-78.915524 -> V=1.0, theta=0.0
% INFO    : Bus 28797	: V=0.9867487, theta=-70.865578 -> V=1.0, theta=0.0
% INFO    : Bus 28798	: V=0.9917483, theta=-70.290417 -> V=1.0, theta=0.0
% INFO    : Bus 28799	: V=1.0152145, theta=-75.775512 -> V=1.0, theta=0.0
% INFO    : Bus 28800	: V=1.0088319, theta=-79.030943 -> V=1.0, theta=0.0
% INFO    : Bus 28801	: V=1.0065104, theta=-81.084292 -> V=1.0, theta=0.0
% INFO    : Bus 28802	: V=1.0065104, theta=-81.084292 -> V=1.0, theta=0.0
% INFO    : Bus 28803	: V=1.0158553, theta=-75.659043 -> V=1.0, theta=0.0
% INFO    : Bus 28804	: V=1.0214059, theta=-66.493409 -> V=1.0, theta=0.0
% INFO    : Bus 28805	: V=1.0220599, theta=-78.232479 -> V=1.0, theta=0.0
% INFO    : Bus 28806	: V=1.021977, theta=-78.260967 -> V=1.0, theta=0.0
% INFO    : Bus 28807	: V=1.0236695, theta=-74.319346 -> V=1.0, theta=0.0
% INFO    : Bus 28808	: V=1.0213476, theta=-77.579493 -> V=1.0, theta=0.0
% INFO    : Bus 28809	: V=1.0213706, theta=-77.474955 -> V=1.0, theta=0.0
% INFO    : Bus 28810	: V=1.0213706, theta=-77.474955 -> V=1.0, theta=0.0
% INFO    : Bus 28811	: V=1.0173751, theta=-73.642158 -> V=1.0, theta=0.0
% INFO    : Bus 28812	: V=1.0177867, theta=-73.589748 -> V=1.0, theta=0.0
% INFO    : Bus 28813	: V=1.0234519, theta=-74.249661 -> V=1.0, theta=0.0
% INFO    : Bus 28814	: V=1.0484013, theta=-67.269445 -> V=1.0, theta=0.0
% INFO    : Bus 28815	: V=1.0481747, theta=-67.02124 -> V=1.0, theta=0.0
% INFO    : Bus 28816	: V=1.0481747, theta=-67.02124 -> V=1.0, theta=0.0
% INFO    : Bus 28817	: V=1.0481747, theta=-67.02124 -> V=1.0, theta=0.0
% INFO    : Bus 28818	: V=1.0481747, theta=-67.02124 -> V=1.0, theta=0.0
% INFO    : Bus 28819	: V=1.0239131, theta=-80.688158 -> V=1.0, theta=0.0
% INFO    : Bus 28820	: V=1.0634693, theta=-76.452842 -> V=1.0, theta=0.0
% INFO    : Bus 28821	: V=1.0677379, theta=-75.908364 -> V=1.0, theta=0.0
% INFO    : Bus 28822	: V=1.0236493, theta=-80.709035 -> V=1.0, theta=0.0
% INFO    : Bus 28823	: V=1.034105, theta=-68.797185 -> V=1.0, theta=0.0
% INFO    : Bus 28824	: V=1.034206, theta=-74.40349 -> V=1.0, theta=0.0
% INFO    : Bus 28825	: V=1.0340157, theta=-74.424898 -> V=1.0, theta=0.0
% INFO    : Bus 28826	: V=1.0310036, theta=-68.235858 -> V=1.0, theta=0.0
% INFO    : Bus 28827	: V=1.0336209, theta=-68.644773 -> V=1.0, theta=0.0
% INFO    : Bus 28828	: V=0.9939675, theta=-67.161851 -> V=1.0, theta=0.0
% INFO    : Bus 28829	: V=1.0211013, theta=-64.104757 -> V=1.0, theta=0.0
% INFO    : Bus 28830	: V=0.9938175, theta=-67.782577 -> V=1.0, theta=0.0
% INFO    : Bus 28831	: V=1.0173184, theta=-74.937592 -> V=1.0, theta=0.0
% INFO    : Bus 28832	: V=1.0119155, theta=-78.696953 -> V=1.0, theta=0.0
% INFO    : Bus 28833	: V=1.0251525, theta=-71.649737 -> V=1.0, theta=0.0
% INFO    : Bus 28834	: V=1.0217823, theta=-72.914366 -> V=1.0, theta=0.0
% INFO    : Bus 28835	: V=1.0327691, theta=-67.346805 -> V=1.0, theta=0.0
% INFO    : Bus 28836	: V=1.0085964, theta=-78.88488 -> V=1.0, theta=0.0
% INFO    : Bus 28837	: V=1.0069705, theta=-77.74659 -> V=1.0, theta=0.0
% INFO    : Bus 28838	: V=1.0100467, theta=-73.221174 -> V=1.0, theta=0.0
% INFO    : Bus 28839	: V=1.0421592, theta=-68.85499 -> V=1.0, theta=0.0
% INFO    : Bus 28840	: V=1.0420092, theta=-68.888219 -> V=1.0, theta=0.0
% INFO    : Bus 28841	: V=1.0244084, theta=-70.900896 -> V=1.0, theta=0.0
% INFO    : Bus 28842	: V=1.0229157, theta=-72.973229 -> V=1.0, theta=0.0
% INFO    : Bus 28843	: V=1.0209902, theta=-78.264007 -> V=1.0, theta=0.0
% INFO    : Bus 28844	: V=1.023353, theta=-70.332111 -> V=1.0, theta=0.0
% INFO    : Bus 28845	: V=1.0221554, theta=-69.737022 -> V=1.0, theta=0.0
% INFO    : Bus 28846	: V=1.0230313, theta=-70.166442 -> V=1.0, theta=0.0
% INFO    : Bus 28847	: V=1.0249551, theta=-69.329548 -> V=1.0, theta=0.0
% INFO    : Bus 28848	: V=1.0276924, theta=-71.796611 -> V=1.0, theta=0.0
% INFO    : Bus 28849	: V=1.0275597, theta=-73.867797 -> V=1.0, theta=0.0
% INFO    : Bus 28850	: V=1.0235433, theta=-68.59264 -> V=1.0, theta=0.0
% INFO    : Bus 28851	: V=1.0231246, theta=-68.36548 -> V=1.0, theta=0.0
% INFO    : Bus 28852	: V=1.0229882, theta=-68.301846 -> V=1.0, theta=0.0
% INFO    : Bus 28853	: V=1.0249551, theta=-69.329548 -> V=1.0, theta=0.0
% INFO    : Bus 28854	: V=1.0245234, theta=-69.093555 -> V=1.0, theta=0.0
% INFO    : Bus 28855	: V=1.0157868, theta=-74.491557 -> V=1.0, theta=0.0
% INFO    : Bus 28856	: V=1.0222228, theta=-78.217074 -> V=1.0, theta=0.0
% INFO    : Bus 28857	: V=1.0163799, theta=-74.403605 -> V=1.0, theta=0.0
% INFO    : Bus 28858	: V=1.0359003, theta=-68.377073 -> V=1.0, theta=0.0
% INFO    : Bus 28859	: V=1.0328813, theta=-74.671012 -> V=1.0, theta=0.0
% INFO    : Bus 28860	: V=1.0128793, theta=-74.51648 -> V=1.0, theta=0.0
% INFO    : Bus 28861	: V=1.0346656, theta=-77.90658 -> V=1.0, theta=0.0
% INFO    : Bus 28862	: V=1.0135484, theta=-74.444353 -> V=1.0, theta=0.0
% INFO    : Bus 28863	: V=1.0149907, theta=-74.285865 -> V=1.0, theta=0.0
% INFO    : Bus 28864	: V=1.0128325, theta=-74.525523 -> V=1.0, theta=0.0
% INFO    : Bus 28865	: V=1.0222211, theta=-73.447803 -> V=1.0, theta=0.0
% INFO    : Bus 28866	: V=1.0128793, theta=-74.51648 -> V=1.0, theta=0.0
% INFO    : Bus 28867	: V=1.0170988, theta=-74.093868 -> V=1.0, theta=0.0
% INFO    : Bus 28868	: V=1.0203424, theta=-73.773652 -> V=1.0, theta=0.0
% INFO    : Bus 28869	: V=1.0407263, theta=-69.113931 -> V=1.0, theta=0.0
% INFO    : Bus 28870	: V=1.0100983, theta=-80.312493 -> V=1.0, theta=0.0
% INFO    : Bus 28871	: V=1.0125055, theta=-78.75919 -> V=1.0, theta=0.0
% INFO    : Bus 28872	: V=1.012505, theta=-78.759188 -> V=1.0, theta=0.0
% INFO    : Bus 28873	: V=0.9993178, theta=-80.129714 -> V=1.0, theta=0.0
% INFO    : Bus 28874	: V=1.0127694, theta=-80.793271 -> V=1.0, theta=0.0
% INFO    : Bus 28875	: V=1.0123425, theta=-80.822294 -> V=1.0, theta=0.0
% INFO    : Bus 28876	: V=1.0127694, theta=-80.793271 -> V=1.0, theta=0.0
% INFO    : Bus 28877	: V=1.0276265, theta=-67.679473 -> V=1.0, theta=0.0
% INFO    : Bus 28878	: V=1.0280434, theta=-67.836729 -> V=1.0, theta=0.0
% INFO    : Bus 28879	: V=1.0387496, theta=-64.584975 -> V=1.0, theta=0.0
% INFO    : Bus 28880	: V=1.0422879, theta=-65.813478 -> V=1.0, theta=0.0
% INFO    : Bus 28881	: V=1.0380945, theta=-66.495981 -> V=1.0, theta=0.0
% INFO    : Bus 28882	: V=1.0368434, theta=-68.488859 -> V=1.0, theta=0.0
% INFO    : Bus 28883	: V=1.0394097, theta=-66.278734 -> V=1.0, theta=0.0
% INFO    : Bus 28884	: V=1.0394097, theta=-66.278734 -> V=1.0, theta=0.0
% INFO    : Bus 28885	: V=1.0375045, theta=-63.931502 -> V=1.0, theta=0.0
% INFO    : Bus 28886	: V=1.0374038, theta=-63.886068 -> V=1.0, theta=0.0
% INFO    : Bus 28887	: V=1.0364163, theta=-63.403162 -> V=1.0, theta=0.0
% INFO    : Bus 28888	: V=1.0440684, theta=-64.864695 -> V=1.0, theta=0.0
% INFO    : Bus 28889	: V=1.0307398, theta=-59.769325 -> V=1.0, theta=0.0
% INFO    : Bus 28890	: V=1.030063, theta=-54.584363 -> V=1.0, theta=0.0
% INFO    : Bus 28891	: V=1.0306216, theta=-59.855298 -> V=1.0, theta=0.0
% INFO    : Bus 28892	: V=1.0296395, theta=-66.932097 -> V=1.0, theta=0.0
% INFO    : Bus 28893	: V=1.0303519, theta=-65.097159 -> V=1.0, theta=0.0
% INFO    : Bus 28894	: V=1.0295816, theta=-66.947238 -> V=1.0, theta=0.0
% INFO    : Bus 28895	: V=1.0296395, theta=-66.932097 -> V=1.0, theta=0.0
% INFO    : Bus 28896	: V=1.0152294, theta=-76.82657 -> V=1.0, theta=0.0
% INFO    : Bus 28897	: V=1.0154698, theta=-76.792663 -> V=1.0, theta=0.0
% INFO    : Bus 28898	: V=1.0223063, theta=-75.854911 -> V=1.0, theta=0.0
% INFO    : Bus 28899	: V=1.0154698, theta=-76.792663 -> V=1.0, theta=0.0
% INFO    : Bus 28900	: V=1.0238652, theta=-77.867898 -> V=1.0, theta=0.0
% INFO    : Bus 28901	: V=1.0170107, theta=-74.411838 -> V=1.0, theta=0.0
% INFO    : Bus 28902	: V=1.0337907, theta=-68.680871 -> V=1.0, theta=0.0
% INFO    : Bus 28903	: V=1.0349678, theta=-68.039347 -> V=1.0, theta=0.0
% INFO    : Bus 28904	: V=1.0265209, theta=-68.548757 -> V=1.0, theta=0.0
% INFO    : Bus 28905	: V=1.0252759, theta=-69.155178 -> V=1.0, theta=0.0
% INFO    : Bus 28906	: V=0.9945303, theta=-66.815906 -> V=1.0, theta=0.0
% INFO    : Bus 28907	: V=1.0101005, theta=-75.251424 -> V=1.0, theta=0.0
% INFO    : Bus 28908	: V=1.0185727, theta=-78.342956 -> V=1.0, theta=0.0
% INFO    : Bus 28909	: V=1.01163, theta=-75.099549 -> V=1.0, theta=0.0
% INFO    : Bus 28910	: V=1.0101005, theta=-75.251424 -> V=1.0, theta=0.0
% INFO    : Bus 28911	: V=1.0155092, theta=-67.20813 -> V=1.0, theta=0.0
% INFO    : Bus 28912	: V=1.0189589, theta=-66.758133 -> V=1.0, theta=0.0
% INFO    : Bus 28913	: V=1.0155092, theta=-67.20813 -> V=1.0, theta=0.0
% INFO    : Bus 28914	: V=1.0354104, theta=-66.870939 -> V=1.0, theta=0.0
% INFO    : Bus 28915	: V=1.0312898, theta=-66.660693 -> V=1.0, theta=0.0
% INFO    : Bus 28916	: V=1.0355212, theta=-66.879085 -> V=1.0, theta=0.0
% INFO    : Bus 28917	: V=1.0318482, theta=-74.678732 -> V=1.0, theta=0.0
% INFO    : Bus 28918	: V=0.9916467, theta=-73.35015 -> V=1.0, theta=0.0
% INFO    : Bus 28919	: V=1.0396924, theta=-66.73775 -> V=1.0, theta=0.0
% INFO    : Bus 28920	: V=1.0272067, theta=-67.084421 -> V=1.0, theta=0.0
% INFO    : Bus 28921	: V=1.023993, theta=-67.294967 -> V=1.0, theta=0.0
% INFO    : Bus 28922	: V=1.0229755, theta=-67.3621 -> V=1.0, theta=0.0
% INFO    : Bus 28923	: V=1.0229755, theta=-67.3621 -> V=1.0, theta=0.0
% INFO    : Bus 28924	: V=1.0280076, theta=-72.426296 -> V=1.0, theta=0.0
% INFO    : Bus 28925	: V=1.0342512, theta=-74.293049 -> V=1.0, theta=0.0
% INFO    : Bus 28926	: V=0.9954734, theta=-71.655891 -> V=1.0, theta=0.0
% INFO    : Bus 28927	: V=1.0070363, theta=-71.24296 -> V=1.0, theta=0.0
% INFO    : Bus 28928	: V=1.0179064, theta=-78.547714 -> V=1.0, theta=0.0
% INFO    : Bus 28929	: V=0.9868799, theta=-77.301254 -> V=1.0, theta=0.0
% INFO    : Bus 28930	: V=0.9868799, theta=-77.301254 -> V=1.0, theta=0.0
% INFO    : Bus 28931	: V=0.9764341, theta=-78.416086 -> V=1.0, theta=0.0
% INFO    : Bus 28932	: V=1.0173854, theta=-78.590223 -> V=1.0, theta=0.0
% INFO    : Bus 28933	: V=1.0108447, theta=-79.432 -> V=1.0, theta=0.0
% INFO    : Bus 28934	: V=1.0432762, theta=-77.379745 -> V=1.0, theta=0.0
% INFO    : Bus 28935	: V=1.0183079, theta=-66.433124 -> V=1.0, theta=0.0
% INFO    : Bus 28936	: V=1.0230304, theta=-66.492266 -> V=1.0, theta=0.0
% INFO    : Bus 28937	: V=1.011915, theta=-78.785324 -> V=1.0, theta=0.0
% INFO    : Bus 28938	: V=1.0127167, theta=-78.700229 -> V=1.0, theta=0.0
% INFO    : Bus 28939	: V=1.0201372, theta=-77.929705 -> V=1.0, theta=0.0
% INFO    : Bus 28940	: V=1.0127167, theta=-78.700229 -> V=1.0, theta=0.0
% INFO    : Bus 28941	: V=1.011915, theta=-78.785324 -> V=1.0, theta=0.0
% INFO    : Bus 28942	: V=1.0583095, theta=-73.695129 -> V=1.0, theta=0.0
% INFO    : Bus 28943	: V=1.0117479, theta=-78.796473 -> V=1.0, theta=0.0
% INFO    : Bus 28944	: V=1.011915, theta=-78.785324 -> V=1.0, theta=0.0
% INFO    : Bus 28945	: V=1.0267939, theta=-80.980644 -> V=1.0, theta=0.0
% INFO    : Bus 28946	: V=1.0603445, theta=-77.42347 -> V=1.0, theta=0.0
% INFO    : Bus 28947	: V=1.0252567, theta=-80.995376 -> V=1.0, theta=0.0
% INFO    : Bus 28948	: V=1.0339725, theta=-68.807503 -> V=1.0, theta=0.0
% INFO    : Bus 28949	: V=1.0434776, theta=-66.441436 -> V=1.0, theta=0.0
% INFO    : Bus 28950	: V=1.0378567, theta=-66.994593 -> V=1.0, theta=0.0
% INFO    : Bus 28951	: V=1.0059045, theta=-65.5626 -> V=1.0, theta=0.0
% INFO    : Bus 28952	: V=1.0434776, theta=-66.441436 -> V=1.0, theta=0.0
% INFO    : Bus 28953	: V=1.0378567, theta=-66.994593 -> V=1.0, theta=0.0
% INFO    : Bus 28954	: V=1.0433534, theta=-66.466614 -> V=1.0, theta=0.0
% INFO    : Bus 28955	: V=1.0434776, theta=-66.441436 -> V=1.0, theta=0.0
% INFO    : Bus 28956	: V=1.0434776, theta=-66.441436 -> V=1.0, theta=0.0
% INFO    : Bus 28957	: V=1.0078557, theta=-78.802336 -> V=1.0, theta=0.0
% INFO    : Bus 28958	: V=1.0078557, theta=-78.802336 -> V=1.0, theta=0.0
% INFO    : Bus 28959	: V=1.0300143, theta=-68.952081 -> V=1.0, theta=0.0
% INFO    : Bus 28960	: V=1.0318117, theta=-69.766863 -> V=1.0, theta=0.0
% INFO    : Bus 28961	: V=1.0049448, theta=-68.720152 -> V=1.0, theta=0.0
% INFO    : Bus 28962	: V=1.0009995, theta=-66.434627 -> V=1.0, theta=0.0
% INFO    : Bus 28963	: V=1.0012511, theta=-68.456454 -> V=1.0, theta=0.0
% INFO    : Bus 28964	: V=1.0300128, theta=-68.933079 -> V=1.0, theta=0.0
% INFO    : Bus 28965	: V=1.0188083, theta=-66.392301 -> V=1.0, theta=0.0
% INFO    : Bus 28966	: V=1.0217472, theta=-66.476523 -> V=1.0, theta=0.0
% INFO    : Bus 28967	: V=1.0207611, theta=-66.448325 -> V=1.0, theta=0.0
% INFO    : Bus 28968	: V=1.0207611, theta=-66.448325 -> V=1.0, theta=0.0
% INFO    : Bus 28969	: V=1.0189129, theta=-66.094552 -> V=1.0, theta=0.0
% INFO    : Bus 28970	: V=1.0189, theta=-66.163148 -> V=1.0, theta=0.0
% INFO    : Bus 28971	: V=1.0188322, theta=-66.442974 -> V=1.0, theta=0.0
% INFO    : Bus 28972	: V=1.0095268, theta=-63.379732 -> V=1.0, theta=0.0
% INFO    : Bus 28973	: V=1.00921, theta=-63.07223 -> V=1.0, theta=0.0
% INFO    : Bus 28974	: V=1.0188083, theta=-66.392301 -> V=1.0, theta=0.0
% INFO    : Bus 28975	: V=1.0188906, theta=-66.163206 -> V=1.0, theta=0.0
% INFO    : Bus 28976	: V=1.0186326, theta=-66.405598 -> V=1.0, theta=0.0
% INFO    : Bus 28977	: V=1.0188083, theta=-66.392301 -> V=1.0, theta=0.0
% INFO    : Bus 28978	: V=1.0126258, theta=-75.07933 -> V=1.0, theta=0.0
% INFO    : Bus 28979	: V=1.0190364, theta=-77.865526 -> V=1.0, theta=0.0
% INFO    : Bus 28980	: V=1.0127824, theta=-79.174721 -> V=1.0, theta=0.0
% INFO    : Bus 28981	: V=1.0346501, theta=-68.634581 -> V=1.0, theta=0.0
% INFO    : Bus 28982	: V=1.0346501, theta=-68.634581 -> V=1.0, theta=0.0
% INFO    : Bus 28983	: V=1.0118903, theta=-79.003352 -> V=1.0, theta=0.0
% INFO    : Bus 28984	: V=1.0058903, theta=-74.856149 -> V=1.0, theta=0.0
% INFO    : Bus 28985	: V=1.0115363, theta=-79.029032 -> V=1.0, theta=0.0
% INFO    : Bus 28986	: V=1.0338079, theta=-68.718504 -> V=1.0, theta=0.0
% INFO    : Bus 28987	: V=1.0338048, theta=-65.357885 -> V=1.0, theta=0.0
% INFO    : Bus 28988	: V=1.0418269, theta=-63.392125 -> V=1.0, theta=0.0
% INFO    : Bus 28989	: V=1.0420958, theta=-63.81209 -> V=1.0, theta=0.0
% INFO    : Bus 28990	: V=1.0323515, theta=-65.708965 -> V=1.0, theta=0.0
% INFO    : Bus 28991	: V=1.0413101, theta=-62.768396 -> V=1.0, theta=0.0
% INFO    : Bus 28992	: V=1.0408812, theta=-62.328263 -> V=1.0, theta=0.0
% INFO    : Bus 28993	: V=1.0212367, theta=-73.810623 -> V=1.0, theta=0.0
% INFO    : Bus 28994	: V=1.0477061, theta=-71.012791 -> V=1.0, theta=0.0
% INFO    : Bus 28995	: V=1.0441586, theta=-71.431703 -> V=1.0, theta=0.0
% INFO    : Bus 28996	: V=1.0205398, theta=-73.864381 -> V=1.0, theta=0.0
% INFO    : Bus 28997	: V=1.0212367, theta=-73.810623 -> V=1.0, theta=0.0
% INFO    : Bus 28998	: V=1.0044804, theta=-75.727648 -> V=1.0, theta=0.0
% INFO    : Bus 28999	: V=1.019932, theta=-78.864642 -> V=1.0, theta=0.0
% INFO    : Bus 29000	: V=1.017903, theta=-74.218184 -> V=1.0, theta=0.0
% INFO    : Bus 29001	: V=1.0131823, theta=-73.787563 -> V=1.0, theta=0.0
% INFO    : Bus 29002	: V=1.0130686, theta=-74.781322 -> V=1.0, theta=0.0
% INFO    : Bus 29003	: V=1.0061852, theta=-75.673759 -> V=1.0, theta=0.0
% INFO    : Bus 29004	: V=1.0193065, theta=-78.440132 -> V=1.0, theta=0.0
% INFO    : Bus 29005	: V=1.0117924, theta=-78.781695 -> V=1.0, theta=0.0
% INFO    : Bus 29006	: V=1.0394516, theta=-75.778889 -> V=1.0, theta=0.0
% INFO    : Bus 29007	: V=1.0440761, theta=-75.338124 -> V=1.0, theta=0.0
% INFO    : Bus 29008	: V=1.0337914, theta=-68.089976 -> V=1.0, theta=0.0
% INFO    : Bus 29009	: V=1.0343338, theta=-68.303696 -> V=1.0, theta=0.0
% INFO    : Bus 29010	: V=1.0337914, theta=-68.089976 -> V=1.0, theta=0.0
% INFO    : Bus 29011	: V=1.0437171, theta=-67.044468 -> V=1.0, theta=0.0
% INFO    : Bus 29012	: V=1.0083939, theta=-79.782089 -> V=1.0, theta=0.0
% INFO    : Bus 29013	: V=1.0083939, theta=-79.782089 -> V=1.0, theta=0.0
% INFO    : Bus 29014	: V=1.0083939, theta=-79.782089 -> V=1.0, theta=0.0
% INFO    : Bus 29015	: V=1.02, theta=-71.233504 -> V=1.0, theta=0.0
% INFO    : Bus 29016	: V=1.0229177, theta=-73.02095 -> V=1.0, theta=0.0
% INFO    : Bus 29017	: V=1.0232002, theta=-77.944574 -> V=1.0, theta=0.0
% INFO    : Bus 29018	: V=1.0245336, theta=-70.080761 -> V=1.0, theta=0.0
% INFO    : Bus 29019	: V=1.0245118, theta=-70.087185 -> V=1.0, theta=0.0
% INFO    : Bus 29020	: V=1.0246568, theta=-70.043459 -> V=1.0, theta=0.0
% INFO    : Bus 29021	: V=1.022078, theta=-66.454575 -> V=1.0, theta=0.0
% INFO    : Bus 29022	: V=1.0216794, theta=-62.122068 -> V=1.0, theta=0.0
% INFO    : Bus 29023	: V=1.0218806, theta=-66.517058 -> V=1.0, theta=0.0
% INFO    : Bus 29024	: V=1.0240999, theta=-70.83517 -> V=1.0, theta=0.0
% INFO    : Bus 29025	: V=1.0236242, theta=-73.840202 -> V=1.0, theta=0.0
% INFO    : Bus 29026	: V=1.023431, theta=-78.826205 -> V=1.0, theta=0.0
% INFO    : Bus 29027	: V=1.0302282, theta=-69.586305 -> V=1.0, theta=0.0
% INFO    : Bus 29028	: V=1.0281001, theta=-70.03287 -> V=1.0, theta=0.0
% INFO    : Bus 29029	: V=1.0280482, theta=-70.040613 -> V=1.0, theta=0.0
% INFO    : Bus 29030	: V=1.0293973, theta=-69.757884 -> V=1.0, theta=0.0
% INFO    : Bus 29031	: V=1.0279811, theta=-70.044855 -> V=1.0, theta=0.0
% INFO    : Bus 29032	: V=1.0264505, theta=-73.540768 -> V=1.0, theta=0.0
% INFO    : Bus 29033	: V=1.0318415, theta=-74.775816 -> V=1.0, theta=0.0
% INFO    : Bus 29034	: V=1.0298216, theta=-73.886537 -> V=1.0, theta=0.0
% INFO    : Bus 29035	: V=1.0285389, theta=-73.560933 -> V=1.0, theta=0.0
% INFO    : Bus 29036	: V=1.0314133, theta=-74.61602 -> V=1.0, theta=0.0
% INFO    : Bus 29037	: V=1.031831, theta=-74.801527 -> V=1.0, theta=0.0
% INFO    : Bus 29038	: V=1.0335485, theta=-74.33319 -> V=1.0, theta=0.0
% INFO    : Bus 29039	: V=1.0231996, theta=-72.829649 -> V=1.0, theta=0.0
% INFO    : Bus 29040	: V=1.0230625, theta=-76.479402 -> V=1.0, theta=0.0
% INFO    : Bus 29041	: V=1.0233901, theta=-80.106609 -> V=1.0, theta=0.0
% INFO    : Bus 29042	: V=1.0231996, theta=-72.829649 -> V=1.0, theta=0.0
% INFO    : Bus 29043	: V=1.0294561, theta=-72.154566 -> V=1.0, theta=0.0
% INFO    : Bus 29044	: V=1.0062779, theta=-80.914507 -> V=1.0, theta=0.0
% INFO    : Bus 29045	: V=1.006096, theta=-80.926417 -> V=1.0, theta=0.0
% INFO    : Bus 29046	: V=1.0336966, theta=-74.227878 -> V=1.0, theta=0.0
% INFO    : Bus 29047	: V=1.0385475, theta=-70.508687 -> V=1.0, theta=0.0
% INFO    : Bus 29048	: V=1.0336966, theta=-74.227878 -> V=1.0, theta=0.0
% INFO    : Bus 29049	: V=1.0337181, theta=-74.256459 -> V=1.0, theta=0.0
% INFO    : Bus 29050	: V=1.0340786, theta=-68.815717 -> V=1.0, theta=0.0
% INFO    : Bus 29051	: V=1.0348226, theta=-65.496548 -> V=1.0, theta=0.0
% INFO    : Bus 29052	: V=1.0340786, theta=-68.815717 -> V=1.0, theta=0.0
% INFO    : Bus 29053	: V=1.0340261, theta=-68.840982 -> V=1.0, theta=0.0
% INFO    : Bus 29054	: V=1.033994, theta=-71.426394 -> V=1.0, theta=0.0
% INFO    : Bus 29055	: V=1.0316326, theta=-72.508408 -> V=1.0, theta=0.0
% INFO    : Bus 29056	: V=1.0005746, theta=-72.141427 -> V=1.0, theta=0.0
% INFO    : Bus 29057	: V=1.0007502, theta=-71.656751 -> V=1.0, theta=0.0
% INFO    : Bus 29058	: V=1.0003322, theta=-72.617943 -> V=1.0, theta=0.0
% INFO    : Bus 29059	: V=1.0230836, theta=-77.817693 -> V=1.0, theta=0.0
% INFO    : Bus 29060	: V=1.0220498, theta=-78.57768 -> V=1.0, theta=0.0
% INFO    : Bus 29061	: V=1.0217302, theta=-78.598853 -> V=1.0, theta=0.0
% INFO    : Bus 29062	: V=1.02848, theta=-74.424842 -> V=1.0, theta=0.0
% INFO    : Bus 29063	: V=1.0284963, theta=-74.423417 -> V=1.0, theta=0.0
% INFO    : Bus 29064	: V=1.024844, theta=-73.273932 -> V=1.0, theta=0.0
% INFO    : Bus 29065	: V=1.0284963, theta=-74.423417 -> V=1.0, theta=0.0
% INFO    : Bus 29066	: V=1.0321983, theta=-74.757882 -> V=1.0, theta=0.0
% INFO    : Bus 29067	: V=1.0321983, theta=-74.757882 -> V=1.0, theta=0.0
% INFO    : Bus 29068	: V=1.0321983, theta=-74.757882 -> V=1.0, theta=0.0
% INFO    : Bus 29069	: V=1.0321983, theta=-74.757882 -> V=1.0, theta=0.0
% INFO    : Bus 29070	: V=1.0456829, theta=-72.247698 -> V=1.0, theta=0.0
% INFO    : Bus 29071	: V=1.0493921, theta=-70.129943 -> V=1.0, theta=0.0
% INFO    : Bus 29072	: V=1.0296414, theta=-59.467269 -> V=1.0, theta=0.0
% INFO    : Bus 29073	: V=1.029954, theta=-56.339065 -> V=1.0, theta=0.0
% INFO    : Bus 29074	: V=1.0295277, theta=-59.518563 -> V=1.0, theta=0.0
% INFO    : Bus 29075	: V=1.0186722, theta=-76.721186 -> V=1.0, theta=0.0
% INFO    : Bus 29076	: V=1.0105795, theta=-80.800814 -> V=1.0, theta=0.0
% INFO    : Bus 29077	: V=1.0082171, theta=-87.038252 -> V=1.0, theta=0.0
% INFO    : Bus 29078	: V=1.0082171, theta=-87.038252 -> V=1.0, theta=0.0
% INFO    : Bus 29079	: V=1.0180382, theta=-76.68982 -> V=1.0, theta=0.0
% INFO    : Bus 29080	: V=1.0141817, theta=-70.41739 -> V=1.0, theta=0.0
% INFO    : Bus 29081	: V=1.0455893, theta=-74.358567 -> V=1.0, theta=0.0
% INFO    : Bus 29082	: V=1.0407481, theta=-78.020299 -> V=1.0, theta=0.0
% INFO    : Bus 29083	: V=1.0329485, theta=-68.331499 -> V=1.0, theta=0.0
% INFO    : Bus 29084	: V=1.0141817, theta=-70.41739 -> V=1.0, theta=0.0
% INFO    : Bus 30000	: V=1.0408179, theta=-61.885427 -> V=1.0, theta=0.0
% INFO    : Bus 30001	: V=1.0062917, theta=-61.359116 -> V=1.0, theta=0.0
% INFO    : Bus 30002	: V=1.0062714, theta=-61.253841 -> V=1.0, theta=0.0
% INFO    : Bus 30003	: V=1.0579765, theta=-59.908795 -> V=1.0, theta=0.0
% INFO    : Bus 30004	: V=1.0061247, theta=-61.283849 -> V=1.0, theta=0.0
% INFO    : Bus 30005	: V=1.0146878, theta=-60.85316 -> V=1.0, theta=0.0
% INFO    : Bus 30006	: V=1.0275096, theta=-62.688602 -> V=1.0, theta=0.0
% INFO    : Bus 30007	: V=1.031011, theta=-62.190161 -> V=1.0, theta=0.0
% INFO    : Bus 30008	: V=1.0343023, theta=-61.734384 -> V=1.0, theta=0.0
% INFO    : Bus 30009	: V=1.0343023, theta=-61.734384 -> V=1.0, theta=0.0
% INFO    : Bus 30010	: V=1.0274668, theta=-62.693597 -> V=1.0, theta=0.0
% INFO    : Bus 30011	: V=1.0275089, theta=-62.687498 -> V=1.0, theta=0.0
% INFO    : Bus 30012	: V=1.017179, theta=-61.718908 -> V=1.0, theta=0.0
% INFO    : Bus 30013	: V=1.0079565, theta=-63.219915 -> V=1.0, theta=0.0
% INFO    : Bus 30014	: V=1.0172573, theta=-61.711077 -> V=1.0, theta=0.0
% INFO    : Bus 30015	: V=1.0181478, theta=-61.710998 -> V=1.0, theta=0.0
% INFO    : Bus 30016	: V=1.0358948, theta=-62.258939 -> V=1.0, theta=0.0
% INFO    : Bus 30017	: V=1.0474139, theta=-62.868064 -> V=1.0, theta=0.0
% INFO    : Bus 30018	: V=1.0116201, theta=-60.718918 -> V=1.0, theta=0.0
% INFO    : Bus 30019	: V=1.0137951, theta=-60.440622 -> V=1.0, theta=0.0
% INFO    : Bus 30020	: V=1.0135972, theta=-60.467277 -> V=1.0, theta=0.0
% INFO    : Bus 30021	: V=1.0131621, theta=-60.520043 -> V=1.0, theta=0.0
% INFO    : Bus 30022	: V=1.013401, theta=-60.49409 -> V=1.0, theta=0.0
% INFO    : Bus 30023	: V=1.0129562, theta=-60.542117 -> V=1.0, theta=0.0
% INFO    : Bus 30024	: V=1.0340678, theta=-62.11463 -> V=1.0, theta=0.0
% INFO    : Bus 30025	: V=1.0339203, theta=-62.1314 -> V=1.0, theta=0.0
% INFO    : Bus 30026	: V=1.0140877, theta=-60.468462 -> V=1.0, theta=0.0
% INFO    : Bus 30027	: V=1.0138511, theta=-60.497523 -> V=1.0, theta=0.0
% INFO    : Bus 30028	: V=1.0061325, theta=-61.174267 -> V=1.0, theta=0.0
% INFO    : Bus 30029	: V=1.0248634, theta=-59.957431 -> V=1.0, theta=0.0
% INFO    : Bus 30030	: V=1.0292821, theta=-60.026735 -> V=1.0, theta=0.0
% INFO    : Bus 30031	: V=1.035279, theta=-61.760645 -> V=1.0, theta=0.0
% INFO    : Bus 30032	: V=1.0089551, theta=-60.941551 -> V=1.0, theta=0.0
% INFO    : Bus 30033	: V=1.0104792, theta=-60.788587 -> V=1.0, theta=0.0
% INFO    : Bus 30034	: V=1.0273885, theta=-62.672286 -> V=1.0, theta=0.0
% INFO    : Bus 30035	: V=1.0269264, theta=-56.992455 -> V=1.0, theta=0.0
% INFO    : Bus 30036	: V=1.0265622, theta=-59.685663 -> V=1.0, theta=0.0
% INFO    : Bus 30037	: V=1.0266058, theta=-57.027879 -> V=1.0, theta=0.0
% INFO    : Bus 30038	: V=1.0308611, theta=-62.419133 -> V=1.0, theta=0.0
% INFO    : Bus 30039	: V=1.0073235, theta=-61.028382 -> V=1.0, theta=0.0
% INFO    : Bus 30040	: V=1.0110847, theta=-60.70031 -> V=1.0, theta=0.0
% INFO    : Bus 30041	: V=1.0055493, theta=-58.777108 -> V=1.0, theta=0.0
% INFO    : Bus 30042	: V=1.0140757, theta=-60.424206 -> V=1.0, theta=0.0
% INFO    : Bus 30043	: V=1.0052743, theta=-58.813255 -> V=1.0, theta=0.0
% INFO    : Bus 30044	: V=1.0119639, theta=-60.654029 -> V=1.0, theta=0.0
% INFO    : Bus 30045	: V=1.0064495, theta=-59.166352 -> V=1.0, theta=0.0
% INFO    : Bus 30046	: V=1.0427849, theta=-61.712025 -> V=1.0, theta=0.0
% INFO    : Bus 30047	: V=1.006208, theta=-59.190143 -> V=1.0, theta=0.0
% INFO    : Bus 30048	: V=1.008569, theta=-59.087342 -> V=1.0, theta=0.0
% INFO    : Bus 30049	: V=1.0313451, theta=-62.137626 -> V=1.0, theta=0.0
% INFO    : Bus 30050	: V=1.0133075, theta=-61.415889 -> V=1.0, theta=0.0
% INFO    : Bus 30051	: V=1.0138437, theta=-61.381455 -> V=1.0, theta=0.0
% INFO    : Bus 30052	: V=1.0127738, theta=-61.450931 -> V=1.0, theta=0.0
% INFO    : Bus 30053	: V=1.0141174, theta=-60.320692 -> V=1.0, theta=0.0
% INFO    : Bus 30054	: V=1.0138878, theta=-60.34346 -> V=1.0, theta=0.0
% INFO    : Bus 30055	: V=1.019817, theta=-60.156027 -> V=1.0, theta=0.0
% INFO    : Bus 30056	: V=1.0200483, theta=-59.872319 -> V=1.0, theta=0.0
% INFO    : Bus 30057	: V=1.0169966, theta=-59.985086 -> V=1.0, theta=0.0
% INFO    : Bus 30058	: V=1.0166167, theta=-60.014475 -> V=1.0, theta=0.0
% INFO    : Bus 30059	: V=1.0206786, theta=-59.954285 -> V=1.0, theta=0.0
% INFO    : Bus 30060	: V=1.0178011, theta=-59.778436 -> V=1.0, theta=0.0
% INFO    : Bus 30061	: V=1.0177003, theta=-59.80306 -> V=1.0, theta=0.0
% INFO    : Bus 30062	: V=1.0179275, theta=-59.75502 -> V=1.0, theta=0.0
% INFO    : Bus 30063	: V=1.0184155, theta=-59.921974 -> V=1.0, theta=0.0
% INFO    : Bus 30064	: V=1.0181983, theta=-59.942879 -> V=1.0, theta=0.0
% INFO    : Bus 30065	: V=1.0146846, theta=-58.237952 -> V=1.0, theta=0.0
% INFO    : Bus 30066	: V=1.0260733, theta=-62.398244 -> V=1.0, theta=0.0
% INFO    : Bus 30067	: V=1.027295, theta=-61.002043 -> V=1.0, theta=0.0
% INFO    : Bus 30068	: V=1.0346474, theta=-59.619964 -> V=1.0, theta=0.0
% INFO    : Bus 30069	: V=1.0268507, theta=-59.898854 -> V=1.0, theta=0.0
% INFO    : Bus 30070	: V=1.0286244, theta=-55.206613 -> V=1.0, theta=0.0
% INFO    : Bus 30071	: V=1.0250402, theta=-56.817071 -> V=1.0, theta=0.0
% INFO    : Bus 30072	: V=1.0313403, theta=-60.078009 -> V=1.0, theta=0.0
% INFO    : Bus 30073	: V=1.0290471, theta=-59.462297 -> V=1.0, theta=0.0
% INFO    : Bus 30074	: V=1.0289734, theta=-59.469534 -> V=1.0, theta=0.0
% INFO    : Bus 30075	: V=0.9950771, theta=-54.179644 -> V=1.0, theta=0.0
% INFO    : Bus 30076	: V=1.0154518, theta=-55.039547 -> V=1.0, theta=0.0
% INFO    : Bus 30077	: V=1.0243534, theta=-53.012924 -> V=1.0, theta=0.0
% INFO    : Bus 30078	: V=1.0288215, theta=-54.564885 -> V=1.0, theta=0.0
% INFO    : Bus 30079	: V=1.0219177, theta=-52.211601 -> V=1.0, theta=0.0
% INFO    : Bus 30080	: V=1.0288952, theta=-49.544315 -> V=1.0, theta=0.0
% INFO    : Bus 30081	: V=1.0162434, theta=-53.726292 -> V=1.0, theta=0.0
% INFO    : Bus 30082	: V=1.0162786, theta=-53.722991 -> V=1.0, theta=0.0
% INFO    : Bus 30083	: V=1.0382754, theta=-63.20539 -> V=1.0, theta=0.0
% INFO    : Bus 30084	: V=1.0329874, theta=-63.49483 -> V=1.0, theta=0.0
% INFO    : Bus 30085	: V=1.0255686, theta=-57.386014 -> V=1.0, theta=0.0
% INFO    : Bus 30086	: V=1.0255353, theta=-57.390369 -> V=1.0, theta=0.0
% INFO    : Bus 30087	: V=1.0256026, theta=-57.381193 -> V=1.0, theta=0.0
% INFO    : Bus 30088	: V=1.0213533, theta=-46.680161 -> V=1.0, theta=0.0
% INFO    : Bus 30089	: V=1.0213209, theta=-46.684262 -> V=1.0, theta=0.0
% INFO    : Bus 30090	: V=1.01618, theta=-60.948443 -> V=1.0, theta=0.0
% INFO    : Bus 30091	: V=1.0263831, theta=-62.580698 -> V=1.0, theta=0.0
% INFO    : Bus 30092	: V=1.0215039, theta=-45.725435 -> V=1.0, theta=0.0
% INFO    : Bus 30093	: V=0.9819124, theta=-42.069084 -> V=1.0, theta=0.0
% INFO    : Bus 30094	: V=0.9913101, theta=-43.123564 -> V=1.0, theta=0.0
% INFO    : Bus 30095	: V=1.0219878, theta=-44.922486 -> V=1.0, theta=0.0
% INFO    : Bus 30096	: V=1.0195368, theta=-46.717501 -> V=1.0, theta=0.0
% INFO    : Bus 30097	: V=1.0198314, theta=-46.693132 -> V=1.0, theta=0.0
% INFO    : Bus 30098	: V=1.0161545, theta=-63.436752 -> V=1.0, theta=0.0
% INFO    : Bus 30099	: V=1.0161821, theta=-63.433131 -> V=1.0, theta=0.0
% INFO    : Bus 30100	: V=1.0220682, theta=-61.584822 -> V=1.0, theta=0.0
% INFO    : Bus 30101	: V=1.0065248, theta=-63.720832 -> V=1.0, theta=0.0
% INFO    : Bus 30102	: V=1.0073094, theta=-63.547285 -> V=1.0, theta=0.0
% INFO    : Bus 30103	: V=1.0074713, theta=-63.525448 -> V=1.0, theta=0.0
% INFO    : Bus 30104	: V=1.0155613, theta=-63.349 -> V=1.0, theta=0.0
% INFO    : Bus 30105	: V=1.0110485, theta=-63.274852 -> V=1.0, theta=0.0
% INFO    : Bus 30106	: V=1.0126384, theta=-63.264471 -> V=1.0, theta=0.0
% INFO    : Bus 30107	: V=1.0113874, theta=-62.953767 -> V=1.0, theta=0.0
% INFO    : Bus 30108	: V=1.018096, theta=-62.14144 -> V=1.0, theta=0.0
% INFO    : Bus 30109	: V=1.0137407, theta=-63.187786 -> V=1.0, theta=0.0
% INFO    : Bus 30110	: V=1.0147281, theta=-62.660725 -> V=1.0, theta=0.0
% INFO    : Bus 30111	: V=1.0145636, theta=-62.688726 -> V=1.0, theta=0.0
% INFO    : Bus 30112	: V=1.0099604, theta=-59.993309 -> V=1.0, theta=0.0
% INFO    : Bus 30113	: V=1.0159004, theta=-62.768518 -> V=1.0, theta=0.0
% INFO    : Bus 30114	: V=1.0115741, theta=-59.888549 -> V=1.0, theta=0.0
% INFO    : Bus 30115	: V=1.0099604, theta=-59.993309 -> V=1.0, theta=0.0
% INFO    : Bus 30116	: V=1.0074808, theta=-63.656366 -> V=1.0, theta=0.0
% INFO    : Bus 30117	: V=1.0121167, theta=-62.814069 -> V=1.0, theta=0.0
% INFO    : Bus 30118	: V=1.0272179, theta=-61.467409 -> V=1.0, theta=0.0
% INFO    : Bus 30119	: V=1.0118848, theta=-62.840598 -> V=1.0, theta=0.0
% INFO    : Bus 30120	: V=1.007179, theta=-63.598558 -> V=1.0, theta=0.0
% INFO    : Bus 30121	: V=1.0070011, theta=-63.622318 -> V=1.0, theta=0.0
% INFO    : Bus 30122	: V=1.0073557, theta=-63.574037 -> V=1.0, theta=0.0
% INFO    : Bus 30123	: V=1.0200315, theta=-60.17607 -> V=1.0, theta=0.0
% INFO    : Bus 30124	: V=1.0084541, theta=-63.316725 -> V=1.0, theta=0.0
% INFO    : Bus 30125	: V=1.0210843, theta=-60.042687 -> V=1.0, theta=0.0
% INFO    : Bus 30126	: V=1.0149461, theta=-63.233328 -> V=1.0, theta=0.0
% INFO    : Bus 30127	: V=1.0136278, theta=-63.057635 -> V=1.0, theta=0.0
% INFO    : Bus 30128	: V=1.0071238, theta=-63.749687 -> V=1.0, theta=0.0
% INFO    : Bus 30129	: V=1.0074672, theta=-63.70215 -> V=1.0, theta=0.0
% INFO    : Bus 30130	: V=1.0105764, theta=-63.400071 -> V=1.0, theta=0.0
% INFO    : Bus 30131	: V=1.010382, theta=-63.441012 -> V=1.0, theta=0.0
% INFO    : Bus 30132	: V=1.0190339, theta=-63.185647 -> V=1.0, theta=0.0
% INFO    : Bus 30133	: V=1.0087907, theta=-63.499631 -> V=1.0, theta=0.0
% INFO    : Bus 30134	: V=1.0069098, theta=-63.642993 -> V=1.0, theta=0.0
% INFO    : Bus 30135	: V=1.0063271, theta=-63.681881 -> V=1.0, theta=0.0
% INFO    : Bus 30136	: V=1.0074173, theta=-63.604718 -> V=1.0, theta=0.0
% INFO    : Bus 30137	: V=1.0167737, theta=-62.698995 -> V=1.0, theta=0.0
% INFO    : Bus 30138	: V=1.0137332, theta=-62.834014 -> V=1.0, theta=0.0
% INFO    : Bus 30139	: V=1.009843, theta=-62.298032 -> V=1.0, theta=0.0
% INFO    : Bus 30140	: V=1.0118091, theta=-63.320348 -> V=1.0, theta=0.0
% INFO    : Bus 30141	: V=1.0116777, theta=-63.351524 -> V=1.0, theta=0.0
% INFO    : Bus 30142	: V=1.0079273, theta=-62.844021 -> V=1.0, theta=0.0
% INFO    : Bus 30143	: V=1.0075019, theta=-62.88606 -> V=1.0, theta=0.0
% INFO    : Bus 30144	: V=1.0163605, theta=-63.439792 -> V=1.0, theta=0.0
% INFO    : Bus 30145	: V=1.00837, theta=-63.034984 -> V=1.0, theta=0.0
% INFO    : Bus 30146	: V=1.0079287, theta=-63.102897 -> V=1.0, theta=0.0
% INFO    : Bus 30147	: V=1.0115575, theta=-63.329222 -> V=1.0, theta=0.0
% INFO    : Bus 30148	: V=1.0114504, theta=-63.11165 -> V=1.0, theta=0.0
% INFO    : Bus 30149	: V=1.0110244, theta=-63.155817 -> V=1.0, theta=0.0
% INFO    : Bus 30150	: V=1.0085407, theta=-62.629311 -> V=1.0, theta=0.0
% INFO    : Bus 30151	: V=1.0082286, theta=-62.678417 -> V=1.0, theta=0.0
% INFO    : Bus 30152	: V=1.0088002, theta=-62.581287 -> V=1.0, theta=0.0
% INFO    : Bus 30153	: V=1.0113925, theta=-63.157369 -> V=1.0, theta=0.0
% INFO    : Bus 30154	: V=1.0183778, theta=-62.95144 -> V=1.0, theta=0.0
% INFO    : Bus 30155	: V=1.0141617, theta=-62.663467 -> V=1.0, theta=0.0
% INFO    : Bus 30156	: V=1.0128461, theta=-62.900151 -> V=1.0, theta=0.0
% INFO    : Bus 30157	: V=1.0124472, theta=-62.932593 -> V=1.0, theta=0.0
% INFO    : Bus 30158	: V=1.0125536, theta=-62.986889 -> V=1.0, theta=0.0
% INFO    : Bus 30159	: V=1.0196475, theta=-62.245019 -> V=1.0, theta=0.0
% INFO    : Bus 30160	: V=1.0158956, theta=-63.087118 -> V=1.0, theta=0.0
% INFO    : Bus 30161	: V=1.0180231, theta=-62.57685 -> V=1.0, theta=0.0
% INFO    : Bus 30162	: V=1.019602, theta=-62.211408 -> V=1.0, theta=0.0
% INFO    : Bus 30163	: V=1.019602, theta=-62.211408 -> V=1.0, theta=0.0
% INFO    : Bus 30164	: V=1.0122546, theta=-63.061491 -> V=1.0, theta=0.0
% INFO    : Bus 30165	: V=1.012055, theta=-63.090763 -> V=1.0, theta=0.0
% INFO    : Bus 30166	: V=1.016086, theta=-62.545395 -> V=1.0, theta=0.0
% INFO    : Bus 30167	: V=1.0167644, theta=-62.423371 -> V=1.0, theta=0.0
% INFO    : Bus 30168	: V=1.0217323, theta=-61.739655 -> V=1.0, theta=0.0
% INFO    : Bus 30169	: V=1.0200028, theta=-61.744781 -> V=1.0, theta=0.0
% INFO    : Bus 30170	: V=1.0161803, theta=-62.395291 -> V=1.0, theta=0.0
% INFO    : Bus 30171	: V=1.0094605, theta=-59.501197 -> V=1.0, theta=0.0
% INFO    : Bus 30172	: V=1.0231947, theta=-61.53836 -> V=1.0, theta=0.0
% INFO    : Bus 30173	: V=1.0093397, theta=-60.005265 -> V=1.0, theta=0.0
% INFO    : Bus 30174	: V=1.0201024, theta=-63.224481 -> V=1.0, theta=0.0
% INFO    : Bus 30175	: V=1.0132071, theta=-63.092417 -> V=1.0, theta=0.0
% INFO    : Bus 30176	: V=1.0132104, theta=-62.942329 -> V=1.0, theta=0.0
% INFO    : Bus 30177	: V=1.0133501, theta=-62.917459 -> V=1.0, theta=0.0
% INFO    : Bus 30178	: V=1.0095632, theta=-62.353796 -> V=1.0, theta=0.0
% INFO    : Bus 30179	: V=1.0210048, theta=-62.690495 -> V=1.0, theta=0.0
% INFO    : Bus 30180	: V=1.0182654, theta=-62.542226 -> V=1.0, theta=0.0
% INFO    : Bus 30181	: V=1.0148338, theta=-62.620191 -> V=1.0, theta=0.0
% INFO    : Bus 30182	: V=1.0089886, theta=-62.766867 -> V=1.0, theta=0.0
% INFO    : Bus 30183	: V=1.0094089, theta=-62.713829 -> V=1.0, theta=0.0
% INFO    : Bus 30184	: V=1.0089968, theta=-62.882593 -> V=1.0, theta=0.0
% INFO    : Bus 30185	: V=1.0161021, theta=-62.682089 -> V=1.0, theta=0.0
% INFO    : Bus 30186	: V=1.0132708, theta=-63.156551 -> V=1.0, theta=0.0
% INFO    : Bus 30187	: V=1.0129593, theta=-63.19757 -> V=1.0, theta=0.0
% INFO    : Bus 30188	: V=1.009371, theta=-63.057229 -> V=1.0, theta=0.0
% INFO    : Bus 30189	: V=1.011913, theta=-62.211581 -> V=1.0, theta=0.0
% INFO    : Bus 30190	: V=1.0220162, theta=-62.334351 -> V=1.0, theta=0.0
% INFO    : Bus 30191	: V=1.0106083, theta=-61.902238 -> V=1.0, theta=0.0
% INFO    : Bus 30192	: V=1.0171491, theta=-62.331375 -> V=1.0, theta=0.0
% INFO    : Bus 30193	: V=1.0131807, theta=-62.569595 -> V=1.0, theta=0.0
% INFO    : Bus 30194	: V=1.012981, theta=-62.603429 -> V=1.0, theta=0.0
% INFO    : Bus 30195	: V=1.0134009, theta=-62.531677 -> V=1.0, theta=0.0
% INFO    : Bus 30196	: V=1.0175699, theta=-60.48623 -> V=1.0, theta=0.0
% INFO    : Bus 30197	: V=1.0136163, theta=-62.793694 -> V=1.0, theta=0.0
% INFO    : Bus 30198	: V=1.015538, theta=-61.41795 -> V=1.0, theta=0.0
% INFO    : Bus 30199	: V=1.0156202, theta=-61.409799 -> V=1.0, theta=0.0
% INFO    : Bus 30200	: V=1.0083354, theta=-62.463504 -> V=1.0, theta=0.0
% INFO    : Bus 30201	: V=1.0079673, theta=-62.4064 -> V=1.0, theta=0.0
% INFO    : Bus 30202	: V=1.0082576, theta=-62.381423 -> V=1.0, theta=0.0
% INFO    : Bus 30203	: V=1.0094021, theta=-62.833666 -> V=1.0, theta=0.0
% INFO    : Bus 30204	: V=1.0144424, theta=-62.162507 -> V=1.0, theta=0.0
% INFO    : Bus 30205	: V=1.0138094, theta=-62.211819 -> V=1.0, theta=0.0
% INFO    : Bus 30206	: V=1.0140808, theta=-62.494421 -> V=1.0, theta=0.0
% INFO    : Bus 30207	: V=1.0135328, theta=-62.546597 -> V=1.0, theta=0.0
% INFO    : Bus 30208	: V=1.0132017, theta=-59.909022 -> V=1.0, theta=0.0
% INFO    : Bus 30209	: V=1.0211396, theta=-62.700879 -> V=1.0, theta=0.0
% INFO    : Bus 30210	: V=1.0133142, theta=-62.074455 -> V=1.0, theta=0.0
% INFO    : Bus 30211	: V=1.0130975, theta=-62.117423 -> V=1.0, theta=0.0
% INFO    : Bus 30212	: V=1.0123703, theta=-62.897166 -> V=1.0, theta=0.0
% INFO    : Bus 30213	: V=1.0126937, theta=-62.867824 -> V=1.0, theta=0.0
% INFO    : Bus 30214	: V=1.0234862, theta=-62.123253 -> V=1.0, theta=0.0
% INFO    : Bus 30215	: V=1.0157313, theta=-62.685375 -> V=1.0, theta=0.0
% INFO    : Bus 30216	: V=1.0136868, theta=-62.45538 -> V=1.0, theta=0.0
% INFO    : Bus 30217	: V=1.0131892, theta=-62.490515 -> V=1.0, theta=0.0
% INFO    : Bus 30218	: V=1.009858, theta=-60.091586 -> V=1.0, theta=0.0
% INFO    : Bus 30219	: V=1.0258161, theta=-61.95738 -> V=1.0, theta=0.0
% INFO    : Bus 30220	: V=1.0092446, theta=-60.14987 -> V=1.0, theta=0.0
% INFO    : Bus 30221	: V=1.0117482, theta=-61.895088 -> V=1.0, theta=0.0
% INFO    : Bus 30222	: V=1.014655, theta=-62.3231 -> V=1.0, theta=0.0
% INFO    : Bus 30223	: V=1.013187, theta=-62.28832 -> V=1.0, theta=0.0
% INFO    : Bus 30224	: V=1.0102835, theta=-62.118234 -> V=1.0, theta=0.0
% INFO    : Bus 30225	: V=1.0099254, theta=-62.173687 -> V=1.0, theta=0.0
% INFO    : Bus 30226	: V=1.0103407, theta=-62.209203 -> V=1.0, theta=0.0
% INFO    : Bus 30227	: V=1.0163446, theta=-62.105704 -> V=1.0, theta=0.0
% INFO    : Bus 30228	: V=1.0158888, theta=-62.14652 -> V=1.0, theta=0.0
% INFO    : Bus 30229	: V=1.0167666, theta=-62.068061 -> V=1.0, theta=0.0
% INFO    : Bus 30230	: V=1.0180439, theta=-62.701956 -> V=1.0, theta=0.0
% INFO    : Bus 30231	: V=1.0153772, theta=-62.354457 -> V=1.0, theta=0.0
% INFO    : Bus 30232	: V=1.0192487, theta=-62.118142 -> V=1.0, theta=0.0
% INFO    : Bus 30233	: V=1.0135877, theta=-62.253185 -> V=1.0, theta=0.0
% INFO    : Bus 30234	: V=1.0161776, theta=-62.387243 -> V=1.0, theta=0.0
% INFO    : Bus 30235	: V=1.0231665, theta=-62.168499 -> V=1.0, theta=0.0
% INFO    : Bus 30236	: V=1.0233884, theta=-62.130927 -> V=1.0, theta=0.0
% INFO    : Bus 30237	: V=1.0092218, theta=-62.515054 -> V=1.0, theta=0.0
% INFO    : Bus 30238	: V=1.0123787, theta=-62.523231 -> V=1.0, theta=0.0
% INFO    : Bus 30239	: V=1.0153203, theta=-62.336141 -> V=1.0, theta=0.0
% INFO    : Bus 30240	: V=1.0127183, theta=-62.462596 -> V=1.0, theta=0.0
% INFO    : Bus 30241	: V=1.0152138, theta=-61.462701 -> V=1.0, theta=0.0
% INFO    : Bus 30242	: V=1.0123289, theta=-59.728952 -> V=1.0, theta=0.0
% INFO    : Bus 30243	: V=1.0260747, theta=-44.986623 -> V=1.0, theta=0.0
% INFO    : Bus 30244	: V=1.0125886, theta=-62.391087 -> V=1.0, theta=0.0
% INFO    : Bus 30245	: V=1.0191214, theta=-60.233095 -> V=1.0, theta=0.0
% INFO    : Bus 30246	: V=0.9882776, theta=-77.489701 -> V=1.0, theta=0.0
% INFO    : Bus 30247	: V=1.0287992, theta=-58.098253 -> V=1.0, theta=0.0
% INFO    : Bus 30248	: V=1.0286069, theta=-40.651582 -> V=1.0, theta=0.0
% INFO    : Bus 30249	: V=1.039902, theta=-36.811695 -> V=1.0, theta=0.0
% INFO    : Bus 30250	: V=1.0574393, theta=-32.731949 -> V=1.0, theta=0.0
% INFO    : Bus 30251	: V=1.0574393, theta=-32.731949 -> V=1.0, theta=0.0
% INFO    : Bus 30252	: V=1.0004478, theta=-43.808565 -> V=1.0, theta=0.0
% INFO    : Bus 30253	: V=0.9809283, theta=-64.224648 -> V=1.0, theta=0.0
% INFO    : Bus 30254	: V=1.0350691, theta=-64.126012 -> V=1.0, theta=0.0
% INFO    : Bus 30255	: V=0.9807304, theta=-64.238134 -> V=1.0, theta=0.0
% INFO    : Bus 30256	: V=1.0182552, theta=-59.397792 -> V=1.0, theta=0.0
% INFO    : Bus 30257	: V=1.0226773, theta=-51.092982 -> V=1.0, theta=0.0
% INFO    : Bus 30258	: V=1.022657, theta=-51.09584 -> V=1.0, theta=0.0
% INFO    : Bus 30259	: V=1.0226994, theta=-51.090173 -> V=1.0, theta=0.0
% INFO    : Bus 30260	: V=1.0226773, theta=-51.092982 -> V=1.0, theta=0.0
% INFO    : Bus 30261	: V=1.0147616, theta=-44.508782 -> V=1.0, theta=0.0
% INFO    : Bus 30262	: V=1.0256977, theta=-59.827289 -> V=1.0, theta=0.0
% INFO    : Bus 30263	: V=1.0257408, theta=-47.178049 -> V=1.0, theta=0.0
% INFO    : Bus 30264	: V=1.0303953, theta=-45.366107 -> V=1.0, theta=0.0
% INFO    : Bus 30265	: V=1.0303799, theta=-45.372935 -> V=1.0, theta=0.0
% INFO    : Bus 30266	: V=1.0303953, theta=-45.366107 -> V=1.0, theta=0.0
% INFO    : Bus 30267	: V=1.0144268, theta=-52.902886 -> V=1.0, theta=0.0
% INFO    : Bus 30268	: V=1.0165911, theta=-60.177397 -> V=1.0, theta=0.0
% INFO    : Bus 30269	: V=1.0107907, theta=-59.337514 -> V=1.0, theta=0.0
% INFO    : Bus 30270	: V=1.0165529, theta=-60.188093 -> V=1.0, theta=0.0
% INFO    : Bus 30271	: V=0.9827416, theta=-50.921433 -> V=1.0, theta=0.0
% INFO    : Bus 30272	: V=0.9918633, theta=-50.904261 -> V=1.0, theta=0.0
% INFO    : Bus 30273	: V=1.015472, theta=-60.48415 -> V=1.0, theta=0.0
% INFO    : Bus 30274	: V=0.9911926, theta=-59.087932 -> V=1.0, theta=0.0
% INFO    : Bus 30275	: V=1.0154423, theta=-60.491158 -> V=1.0, theta=0.0
% INFO    : Bus 30276	: V=1.015472, theta=-60.48415 -> V=1.0, theta=0.0
% INFO    : Bus 30277	: V=1.0152328, theta=-61.681313 -> V=1.0, theta=0.0
% INFO    : Bus 30278	: V=1.0134833, theta=-55.117019 -> V=1.0, theta=0.0
% INFO    : Bus 30279	: V=1.0134833, theta=-55.117019 -> V=1.0, theta=0.0
% INFO    : Bus 30280	: V=1.0138942, theta=-52.870827 -> V=1.0, theta=0.0
% INFO    : Bus 30281	: V=1.0195607, theta=-59.309188 -> V=1.0, theta=0.0
% INFO    : Bus 30282	: V=1.0195385, theta=-59.318623 -> V=1.0, theta=0.0
% INFO    : Bus 30283	: V=1.0195506, theta=-59.311032 -> V=1.0, theta=0.0
% INFO    : Bus 30284	: V=1.006786, theta=-63.503973 -> V=1.0, theta=0.0
% INFO    : Bus 30285	: V=1.0137649, theta=-63.338536 -> V=1.0, theta=0.0
% INFO    : Bus 30286	: V=1.0067137, theta=-63.504969 -> V=1.0, theta=0.0
% INFO    : Bus 30287	: V=1.0129649, theta=-56.891255 -> V=1.0, theta=0.0
% INFO    : Bus 30288	: V=1.0128918, theta=-56.90896 -> V=1.0, theta=0.0
% INFO    : Bus 30289	: V=1.0048914, theta=-42.453449 -> V=1.0, theta=0.0
% INFO    : Bus 30290	: V=1.0207222, theta=-42.687962 -> V=1.0, theta=0.0
% INFO    : Bus 30291	: V=0.9991358, theta=-41.196222 -> V=1.0, theta=0.0
% INFO    : Bus 30292	: V=1.0248851, theta=-61.415452 -> V=1.0, theta=0.0
% INFO    : Bus 30293	: V=1.0331564, theta=-58.727317 -> V=1.0, theta=0.0
% INFO    : Bus 30294	: V=1.0248703, theta=-61.434655 -> V=1.0, theta=0.0
% INFO    : Bus 30295	: V=1.02312, theta=-57.789638 -> V=1.0, theta=0.0
% INFO    : Bus 30296	: V=1.0192695, theta=-59.85766 -> V=1.0, theta=0.0
% INFO    : Bus 30297	: V=1.02312, theta=-57.789638 -> V=1.0, theta=0.0
% INFO    : Bus 30298	: V=1.0044487, theta=-57.067855 -> V=1.0, theta=0.0
% INFO    : Bus 30299	: V=1.0019393, theta=-55.790109 -> V=1.0, theta=0.0
% INFO    : Bus 30300	: V=1.0097222, theta=-56.014424 -> V=1.0, theta=0.0
% INFO    : Bus 30301	: V=1.0098271, theta=-56.020028 -> V=1.0, theta=0.0
% INFO    : Bus 30302	: V=1.020376, theta=-46.912322 -> V=1.0, theta=0.0
% INFO    : Bus 30303	: V=1.0203303, theta=-46.827034 -> V=1.0, theta=0.0
% INFO    : Bus 30304	: V=1.020267, theta=-46.701106 -> V=1.0, theta=0.0
% INFO    : Bus 30305	: V=1.020267, theta=-46.701106 -> V=1.0, theta=0.0
% INFO    : Bus 30306	: V=1.032537, theta=-46.31231 -> V=1.0, theta=0.0
% INFO    : Bus 30307	: V=1.0122217, theta=-51.86991 -> V=1.0, theta=0.0
% INFO    : Bus 30308	: V=1.0180042, theta=-52.987454 -> V=1.0, theta=0.0
% INFO    : Bus 30309	: V=1.0187914, theta=-56.607919 -> V=1.0, theta=0.0
% INFO    : Bus 30310	: V=1.0164256, theta=-60.228825 -> V=1.0, theta=0.0
% INFO    : Bus 30311	: V=1.016371, theta=-60.243617 -> V=1.0, theta=0.0
% INFO    : Bus 30312	: V=1.0164256, theta=-60.228825 -> V=1.0, theta=0.0
% INFO    : Bus 30313	: V=1.02508, theta=-48.45832 -> V=1.0, theta=0.0
% INFO    : Bus 30314	: V=1.0208941, theta=-48.650688 -> V=1.0, theta=0.0
% INFO    : Bus 30315	: V=1.027627, theta=-49.430656 -> V=1.0, theta=0.0
% INFO    : Bus 30316	: V=0.982819, theta=-46.947146 -> V=1.0, theta=0.0
% INFO    : Bus 30317	: V=0.984471, theta=-48.233279 -> V=1.0, theta=0.0
% INFO    : Bus 30318	: V=1.0237016, theta=-47.66238 -> V=1.0, theta=0.0
% INFO    : Bus 30319	: V=1.0113468, theta=-47.145211 -> V=1.0, theta=0.0
% INFO    : Bus 30320	: V=1.0110403, theta=-47.712252 -> V=1.0, theta=0.0
% INFO    : Bus 30321	: V=1.0110403, theta=-47.712252 -> V=1.0, theta=0.0
% INFO    : Bus 30322	: V=1.0165415, theta=-59.623654 -> V=1.0, theta=0.0
% INFO    : Bus 30323	: V=1.015792, theta=-62.150952 -> V=1.0, theta=0.0
% INFO    : Bus 30324	: V=1.0180609, theta=-59.51732 -> V=1.0, theta=0.0
% INFO    : Bus 30325	: V=1.0165415, theta=-59.623654 -> V=1.0, theta=0.0
% INFO    : Bus 30326	: V=1.0156866, theta=-61.612343 -> V=1.0, theta=0.0
% INFO    : Bus 30327	: V=1.0205435, theta=-61.439398 -> V=1.0, theta=0.0
% INFO    : Bus 30328	: V=1.0231887, theta=-61.346035 -> V=1.0, theta=0.0
% INFO    : Bus 30329	: V=1.0231887, theta=-61.346035 -> V=1.0, theta=0.0
% INFO    : Bus 30330	: V=1.0156013, theta=-61.622463 -> V=1.0, theta=0.0
% INFO    : Bus 30331	: V=1.0156866, theta=-61.612343 -> V=1.0, theta=0.0
% INFO    : Bus 30332	: V=1.0195168, theta=-60.589875 -> V=1.0, theta=0.0
% INFO    : Bus 30333	: V=1.0194861, theta=-60.605628 -> V=1.0, theta=0.0
% INFO    : Bus 30334	: V=1.0277569, theta=-56.944945 -> V=1.0, theta=0.0
% INFO    : Bus 30335	: V=1.0218008, theta=-55.716689 -> V=1.0, theta=0.0
% INFO    : Bus 30336	: V=1.0216196, theta=-56.377275 -> V=1.0, theta=0.0
% INFO    : Bus 30337	: V=1.0209563, theta=-53.24299 -> V=1.0, theta=0.0
% INFO    : Bus 30338	: V=1.01724, theta=-59.414395 -> V=1.0, theta=0.0
% INFO    : Bus 30339	: V=1.0154394, theta=-61.644435 -> V=1.0, theta=0.0
% INFO    : Bus 30340	: V=1.0177136, theta=-59.024847 -> V=1.0, theta=0.0
% INFO    : Bus 30341	: V=1.0177136, theta=-59.024847 -> V=1.0, theta=0.0
% INFO    : Bus 30342	: V=1.0334867, theta=-58.966417 -> V=1.0, theta=0.0
% INFO    : Bus 30343	: V=1.0317476, theta=-57.974797 -> V=1.0, theta=0.0
% INFO    : Bus 30344	: V=1.0317088, theta=-58.923539 -> V=1.0, theta=0.0
% INFO    : Bus 30345	: V=1.034158, theta=-57.098083 -> V=1.0, theta=0.0
% INFO    : Bus 30346	: V=1.0306689, theta=-58.796041 -> V=1.0, theta=0.0
% INFO    : Bus 30347	: V=1.0645255, theta=-53.423376 -> V=1.0, theta=0.0
% INFO    : Bus 30348	: V=1.0248532, theta=-61.483009 -> V=1.0, theta=0.0
% INFO    : Bus 30349	: V=1.0446909, theta=-59.392494 -> V=1.0, theta=0.0
% INFO    : Bus 30350	: V=1.033555, theta=-60.584594 -> V=1.0, theta=0.0
% INFO    : Bus 30351	: V=1.0153143, theta=-59.830246 -> V=1.0, theta=0.0
% INFO    : Bus 30352	: V=1.0147981, theta=-61.555587 -> V=1.0, theta=0.0
% INFO    : Bus 30353	: V=1.0153091, theta=-63.481215 -> V=1.0, theta=0.0
% INFO    : Bus 30354	: V=1.0153091, theta=-63.481215 -> V=1.0, theta=0.0
% INFO    : Bus 30355	: V=1.0155407, theta=-59.781517 -> V=1.0, theta=0.0
% INFO    : Bus 30356	: V=1.0328956, theta=-51.921345 -> V=1.0, theta=0.0
% INFO    : Bus 30357	: V=1.0329064, theta=-51.918875 -> V=1.0, theta=0.0
% INFO    : Bus 30358	: V=1.0330337, theta=-51.643245 -> V=1.0, theta=0.0
% INFO    : Bus 30359	: V=1.0329064, theta=-51.918875 -> V=1.0, theta=0.0
% INFO    : Bus 30360	: V=1.0328718, theta=-51.928069 -> V=1.0, theta=0.0
% INFO    : Bus 30361	: V=1.0328956, theta=-51.921345 -> V=1.0, theta=0.0
% INFO    : Bus 30362	: V=0.9972037, theta=-49.015875 -> V=1.0, theta=0.0
% INFO    : Bus 30363	: V=1.0026989, theta=-49.789856 -> V=1.0, theta=0.0
% INFO    : Bus 30364	: V=1.0099047, theta=-48.746321 -> V=1.0, theta=0.0
% INFO    : Bus 30365	: V=1.0098856, theta=-48.831992 -> V=1.0, theta=0.0
% INFO    : Bus 30366	: V=1.0098471, theta=-48.980261 -> V=1.0, theta=0.0
% INFO    : Bus 30367	: V=0.9980887, theta=-49.017901 -> V=1.0, theta=0.0
% INFO    : Bus 30368	: V=1.0150653, theta=-61.734168 -> V=1.0, theta=0.0
% INFO    : Bus 30369	: V=1.02018, theta=-56.094888 -> V=1.0, theta=0.0
% INFO    : Bus 30370	: V=1.0203172, theta=-57.893471 -> V=1.0, theta=0.0
% INFO    : Bus 30371	: V=1.0206615, theta=-60.050366 -> V=1.0, theta=0.0
% INFO    : Bus 30372	: V=1.02018, theta=-56.094888 -> V=1.0, theta=0.0
% INFO    : Bus 30373	: V=1.02018, theta=-56.094888 -> V=1.0, theta=0.0
% INFO    : Bus 30374	: V=1.0247558, theta=-55.337643 -> V=1.0, theta=0.0
% INFO    : Bus 30375	: V=1.0263568, theta=-55.707973 -> V=1.0, theta=0.0
% INFO    : Bus 30376	: V=1.0217498, theta=-55.83702 -> V=1.0, theta=0.0
% INFO    : Bus 30377	: V=1.0244176, theta=-55.867312 -> V=1.0, theta=0.0
% INFO    : Bus 30378	: V=1.0195878, theta=-58.069188 -> V=1.0, theta=0.0
% INFO    : Bus 30379	: V=1.0187782, theta=-60.003258 -> V=1.0, theta=0.0
% INFO    : Bus 30380	: V=1.0243112, theta=-61.902034 -> V=1.0, theta=0.0
% INFO    : Bus 30381	: V=1.0263793, theta=-57.899094 -> V=1.0, theta=0.0
% INFO    : Bus 30382	: V=0.9823289, theta=-39.692678 -> V=1.0, theta=0.0
% INFO    : Bus 30383	: V=0.9948328, theta=-40.359374 -> V=1.0, theta=0.0
% INFO    : Bus 30384	: V=1.0039977, theta=-40.833182 -> V=1.0, theta=0.0
% INFO    : Bus 30385	: V=1.0039977, theta=-40.833182 -> V=1.0, theta=0.0
% INFO    : Bus 30386	: V=0.9935629, theta=-36.434105 -> V=1.0, theta=0.0
% INFO    : Bus 30387	: V=1.0369381, theta=-53.577865 -> V=1.0, theta=0.0
% INFO    : Bus 30388	: V=1.0298421, theta=-55.753822 -> V=1.0, theta=0.0
% INFO    : Bus 30389	: V=1.0190952, theta=-59.217048 -> V=1.0, theta=0.0
% INFO    : Bus 30390	: V=1.0356301, theta=-52.87731 -> V=1.0, theta=0.0
% INFO    : Bus 30391	: V=1.035874, theta=-53.285565 -> V=1.0, theta=0.0
% INFO    : Bus 30392	: V=1.0355048, theta=-52.818632 -> V=1.0, theta=0.0
% INFO    : Bus 30393	: V=1.0362987, theta=-53.231436 -> V=1.0, theta=0.0
% INFO    : Bus 30394	: V=1.0355184, theta=-52.828689 -> V=1.0, theta=0.0
% INFO    : Bus 30395	: V=1.0358938, theta=-53.457532 -> V=1.0, theta=0.0
% INFO    : Bus 30396	: V=1.0359281, theta=-53.040176 -> V=1.0, theta=0.0
% INFO    : Bus 30397	: V=1.0369381, theta=-53.577865 -> V=1.0, theta=0.0
% INFO    : Bus 30398	: V=1.0154896, theta=-60.428875 -> V=1.0, theta=0.0
% INFO    : Bus 30399	: V=1.02606, theta=-56.454807 -> V=1.0, theta=0.0
% INFO    : Bus 30400	: V=1.0291094, theta=-58.361662 -> V=1.0, theta=0.0
% INFO    : Bus 30401	: V=1.0165377, theta=-62.279905 -> V=1.0, theta=0.0
% INFO    : Bus 30402	: V=1.0061103, theta=-70.052937 -> V=1.0, theta=0.0
% INFO    : Bus 30403	: V=1.0061103, theta=-70.052937 -> V=1.0, theta=0.0
% INFO    : Bus 30404	: V=1.0285386, theta=-55.874262 -> V=1.0, theta=0.0
% INFO    : Bus 30405	: V=1.0297445, theta=-56.029683 -> V=1.0, theta=0.0
% INFO    : Bus 30406	: V=1.0268834, theta=-56.264771 -> V=1.0, theta=0.0
% INFO    : Bus 30407	: V=1.0293562, theta=-55.672849 -> V=1.0, theta=0.0
% INFO    : Bus 30408	: V=1.0281967, theta=-56.260407 -> V=1.0, theta=0.0
% INFO    : Bus 30409	: V=1.0283076, theta=-56.388162 -> V=1.0, theta=0.0
% INFO    : Bus 30410	: V=1.0268436, theta=-56.3224 -> V=1.0, theta=0.0
% INFO    : Bus 30411	: V=1.0297807, theta=-55.810388 -> V=1.0, theta=0.0
% INFO    : Bus 30412	: V=1.0293488, theta=-55.890805 -> V=1.0, theta=0.0
% INFO    : Bus 30413	: V=1.0288955, theta=-56.286385 -> V=1.0, theta=0.0
% INFO    : Bus 30414	: V=1.0289267, theta=-56.250696 -> V=1.0, theta=0.0
% INFO    : Bus 30415	: V=1.0306647, theta=-55.66088 -> V=1.0, theta=0.0
% INFO    : Bus 30416	: V=1.0218288, theta=-59.187789 -> V=1.0, theta=0.0
% INFO    : Bus 30417	: V=1.0232495, theta=-58.163397 -> V=1.0, theta=0.0
% INFO    : Bus 30418	: V=1.0196237, theta=-60.153478 -> V=1.0, theta=0.0
% INFO    : Bus 30419	: V=1.0176484, theta=-61.720033 -> V=1.0, theta=0.0
% INFO    : Bus 30420	: V=1.0176484, theta=-61.720033 -> V=1.0, theta=0.0
% INFO    : Bus 30421	: V=1.0232495, theta=-58.163397 -> V=1.0, theta=0.0
% INFO    : Bus 30422	: V=0.9892732, theta=-56.894504 -> V=1.0, theta=0.0
% INFO    : Bus 30423	: V=0.9858478, theta=-57.29772 -> V=1.0, theta=0.0
% INFO    : Bus 30424	: V=1.0214207, theta=-58.109187 -> V=1.0, theta=0.0
% INFO    : Bus 30425	: V=1.0184488, theta=-60.488501 -> V=1.0, theta=0.0
% INFO    : Bus 30426	: V=1.0171033, theta=-57.621562 -> V=1.0, theta=0.0
% INFO    : Bus 30427	: V=1.0188924, theta=-60.451017 -> V=1.0, theta=0.0
% INFO    : Bus 30428	: V=1.0192, theta=-59.275437 -> V=1.0, theta=0.0
% INFO    : Bus 30429	: V=1.0192, theta=-59.373006 -> V=1.0, theta=0.0
% INFO    : Bus 30430	: V=1.0110593, theta=-62.107529 -> V=1.0, theta=0.0
% INFO    : Bus 30431	: V=1.0062035, theta=-64.336083 -> V=1.0, theta=0.0
% INFO    : Bus 30432	: V=1.0062035, theta=-64.336083 -> V=1.0, theta=0.0
% INFO    : Bus 30433	: V=1.0181252, theta=-59.332934 -> V=1.0, theta=0.0
% INFO    : Bus 30434	: V=1.0154137, theta=-61.634141 -> V=1.0, theta=0.0
% INFO    : Bus 30435	: V=1.0244004, theta=-59.00673 -> V=1.0, theta=0.0
% INFO    : Bus 30436	: V=1.024384, theta=-59.010662 -> V=1.0, theta=0.0
% INFO    : Bus 30437	: V=1.0176547, theta=-57.875359 -> V=1.0, theta=0.0
% INFO    : Bus 30438	: V=1.0196467, theta=-60.080586 -> V=1.0, theta=0.0
% INFO    : Bus 30439	: V=1.0202391, theta=-60.529948 -> V=1.0, theta=0.0
% INFO    : Bus 30440	: V=1.0202391, theta=-60.529948 -> V=1.0, theta=0.0
% INFO    : Bus 30441	: V=1.003875, theta=-55.241948 -> V=1.0, theta=0.0
% INFO    : Bus 30442	: V=1.0073438, theta=-56.61246 -> V=1.0, theta=0.0
% INFO    : Bus 30443	: V=1.0041111, theta=-55.924782 -> V=1.0, theta=0.0
% INFO    : Bus 30444	: V=1.0197962, theta=-58.068059 -> V=1.0, theta=0.0
% INFO    : Bus 30445	: V=1.0164525, theta=-60.216478 -> V=1.0, theta=0.0
% INFO    : Bus 30446	: V=1.0231991, theta=-59.760237 -> V=1.0, theta=0.0
% INFO    : Bus 30447	: V=1.0230982, theta=-59.896786 -> V=1.0, theta=0.0
% INFO    : Bus 30448	: V=1.0228808, theta=-60.167636 -> V=1.0, theta=0.0
% INFO    : Bus 30449	: V=1.0348458, theta=-58.129108 -> V=1.0, theta=0.0
% INFO    : Bus 30450	: V=1.0260532, theta=-60.686212 -> V=1.0, theta=0.0
% INFO    : Bus 30451	: V=1.0348458, theta=-58.129108 -> V=1.0, theta=0.0
% INFO    : Bus 30452	: V=1.0582634, theta=-55.693289 -> V=1.0, theta=0.0
% INFO    : Bus 30453	: V=1.053887, theta=-56.347695 -> V=1.0, theta=0.0
% INFO    : Bus 30454	: V=1.05818, theta=-56.235246 -> V=1.0, theta=0.0
% INFO    : Bus 30455	: V=1.0563803, theta=-56.712522 -> V=1.0, theta=0.0
% INFO    : Bus 30456	: V=1.062967, theta=-54.969164 -> V=1.0, theta=0.0
% INFO    : Bus 30457	: V=1.0327481, theta=-58.279532 -> V=1.0, theta=0.0
% INFO    : Bus 30458	: V=1.002424, theta=-56.617512 -> V=1.0, theta=0.0
% INFO    : Bus 30459	: V=1.0396601, theta=-58.349627 -> V=1.0, theta=0.0
% INFO    : Bus 30460	: V=0.9638647, theta=-55.560028 -> V=1.0, theta=0.0
% INFO    : Bus 30461	: V=0.9691068, theta=-54.256835 -> V=1.0, theta=0.0
% INFO    : Bus 40000	: V=1.0071988, theta=-72.119458 -> V=1.0, theta=0.0
% INFO    : Bus 40001	: V=1.0120992, theta=-71.40655 -> V=1.0, theta=0.0
% INFO    : Bus 40002	: V=1.0107322, theta=-71.412843 -> V=1.0, theta=0.0
% INFO    : Bus 40003	: V=1.0193782, theta=-71.079012 -> V=1.0, theta=0.0
% INFO    : Bus 40004	: V=1.0215966, theta=-70.404011 -> V=1.0, theta=0.0
% INFO    : Bus 40005	: V=1.0222671, theta=-70.336665 -> V=1.0, theta=0.0
% INFO    : Bus 40006	: V=1.0131927, theta=-67.401193 -> V=1.0, theta=0.0
% INFO    : Bus 40007	: V=1.0130278, theta=-67.428064 -> V=1.0, theta=0.0
% INFO    : Bus 40008	: V=1.018395, theta=-65.660718 -> V=1.0, theta=0.0
% INFO    : Bus 40009	: V=1.0405274, theta=-64.082107 -> V=1.0, theta=0.0
% INFO    : Bus 40010	: V=1.0156728, theta=-66.468536 -> V=1.0, theta=0.0
% INFO    : Bus 40011	: V=1.0155932, theta=-66.480577 -> V=1.0, theta=0.0
% INFO    : Bus 40012	: V=1.0157493, theta=-66.456921 -> V=1.0, theta=0.0
% INFO    : Bus 40013	: V=1.0318227, theta=-70.059494 -> V=1.0, theta=0.0
% INFO    : Bus 40014	: V=1.0319489, theta=-64.15152 -> V=1.0, theta=0.0
% INFO    : Bus 40015	: V=1.031806, theta=-64.163151 -> V=1.0, theta=0.0
% INFO    : Bus 40016	: V=1.0127895, theta=-70.704642 -> V=1.0, theta=0.0
% INFO    : Bus 40017	: V=1.0124707, theta=-70.736671 -> V=1.0, theta=0.0
% INFO    : Bus 40018	: V=1.0290244, theta=-65.923242 -> V=1.0, theta=0.0
% INFO    : Bus 40019	: V=1.0290512, theta=-65.919309 -> V=1.0, theta=0.0
% INFO    : Bus 40020	: V=1.0190488, theta=-63.339331 -> V=1.0, theta=0.0
% INFO    : Bus 40021	: V=1.0190586, theta=-63.338149 -> V=1.0, theta=0.0
% INFO    : Bus 40022	: V=1.0166707, theta=-67.478734 -> V=1.0, theta=0.0
% INFO    : Bus 40023	: V=1.0246647, theta=-64.676669 -> V=1.0, theta=0.0
% INFO    : Bus 40024	: V=1.024557, theta=-64.697455 -> V=1.0, theta=0.0
% INFO    : Bus 40025	: V=1.0174303, theta=-67.507579 -> V=1.0, theta=0.0
% INFO    : Bus 40026	: V=1.017607, theta=-67.477404 -> V=1.0, theta=0.0
% INFO    : Bus 40027	: V=1.0259245, theta=-66.821396 -> V=1.0, theta=0.0
% INFO    : Bus 40028	: V=1.0075074, theta=-68.553024 -> V=1.0, theta=0.0
% INFO    : Bus 40029	: V=1.0254224, theta=-69.635749 -> V=1.0, theta=0.0
% INFO    : Bus 40030	: V=1.02534, theta=-69.64276 -> V=1.0, theta=0.0
% INFO    : Bus 40031	: V=1.0075012, theta=-65.922266 -> V=1.0, theta=0.0
% INFO    : Bus 40032	: V=1.0071602, theta=-65.962584 -> V=1.0, theta=0.0
% INFO    : Bus 40033	: V=1.0162951, theta=-63.182272 -> V=1.0, theta=0.0
% INFO    : Bus 40034	: V=1.0116055, theta=-65.194765 -> V=1.0, theta=0.0
% INFO    : Bus 40035	: V=1.0005808, theta=-69.69607 -> V=1.0, theta=0.0
% INFO    : Bus 40036	: V=1.0114402, theta=-65.869501 -> V=1.0, theta=0.0
% INFO    : Bus 40037	: V=1.0197893, theta=-63.112687 -> V=1.0, theta=0.0
% INFO    : Bus 40038	: V=1.0412601, theta=-62.40187 -> V=1.0, theta=0.0
% INFO    : Bus 40039	: V=1.0398566, theta=-63.158264 -> V=1.0, theta=0.0
% INFO    : Bus 40040	: V=1.0307335, theta=-65.702706 -> V=1.0, theta=0.0
% INFO    : Bus 40041	: V=1.0192443, theta=-64.03742 -> V=1.0, theta=0.0
% INFO    : Bus 40042	: V=1.0197678, theta=-66.305476 -> V=1.0, theta=0.0
% INFO    : Bus 40043	: V=1.0212502, theta=-66.004317 -> V=1.0, theta=0.0
% INFO    : Bus 40044	: V=1.0244692, theta=-68.123698 -> V=1.0, theta=0.0
% INFO    : Bus 40045	: V=1.0220702, theta=-65.89968 -> V=1.0, theta=0.0
% INFO    : Bus 40046	: V=1.0304977, theta=-66.186963 -> V=1.0, theta=0.0
% INFO    : Bus 40047	: V=1.0193241, theta=-68.300806 -> V=1.0, theta=0.0
% INFO    : Bus 40048	: V=1.0132452, theta=-60.973098 -> V=1.0, theta=0.0
% INFO    : Bus 40049	: V=1.0133215, theta=-60.965048 -> V=1.0, theta=0.0
% INFO    : Bus 40050	: V=1.0112743, theta=-67.339151 -> V=1.0, theta=0.0
% INFO    : Bus 40051	: V=1.0112993, theta=-67.335969 -> V=1.0, theta=0.0
% INFO    : Bus 40052	: V=0.9930492, theta=-69.623179 -> V=1.0, theta=0.0
% INFO    : Bus 40053	: V=0.9930043, theta=-69.628486 -> V=1.0, theta=0.0
% INFO    : Bus 40054	: V=1.0337322, theta=-60.388223 -> V=1.0, theta=0.0
% INFO    : Bus 40055	: V=1.0102885, theta=-69.822196 -> V=1.0, theta=0.0
% INFO    : Bus 40056	: V=1.017735, theta=-51.93712 -> V=1.0, theta=0.0
% INFO    : Bus 40057	: V=0.9936791, theta=-70.935461 -> V=1.0, theta=0.0
% INFO    : Bus 40058	: V=0.9961007, theta=-68.809051 -> V=1.0, theta=0.0
% INFO    : Bus 40059	: V=0.9908541, theta=-69.384299 -> V=1.0, theta=0.0
% INFO    : Bus 40060	: V=0.9907334, theta=-69.398904 -> V=1.0, theta=0.0
% INFO    : Bus 40061	: V=1.0163462, theta=-54.608617 -> V=1.0, theta=0.0
% INFO    : Bus 40062	: V=1.0128104, theta=-59.246807 -> V=1.0, theta=0.0
% INFO    : Bus 40063	: V=1.0128578, theta=-59.242395 -> V=1.0, theta=0.0
% INFO    : Bus 40064	: V=1.023326, theta=-63.990772 -> V=1.0, theta=0.0
% INFO    : Bus 40065	: V=0.9982853, theta=-62.208921 -> V=1.0, theta=0.0
% INFO    : Bus 40066	: V=0.9982276, theta=-62.216964 -> V=1.0, theta=0.0
% INFO    : Bus 40067	: V=1.0034987, theta=-65.900578 -> V=1.0, theta=0.0
% INFO    : Bus 40068	: V=0.995078, theta=-68.37686 -> V=1.0, theta=0.0
% INFO    : Bus 40069	: V=1.0191648, theta=-67.385073 -> V=1.0, theta=0.0
% INFO    : Bus 40070	: V=1.0190295, theta=-67.400082 -> V=1.0, theta=0.0
% INFO    : Bus 40071	: V=1.0192912, theta=-67.37094 -> V=1.0, theta=0.0
% INFO    : Bus 40072	: V=1.0191648, theta=-67.385073 -> V=1.0, theta=0.0
% INFO    : Bus 40073	: V=0.9988601, theta=-61.895234 -> V=1.0, theta=0.0
% INFO    : Bus 40074	: V=1.0212664, theta=-61.317333 -> V=1.0, theta=0.0
% INFO    : Bus 40075	: V=1.0521347, theta=-64.115458 -> V=1.0, theta=0.0
% INFO    : Bus 40076	: V=1.0208907, theta=-61.362981 -> V=1.0, theta=0.0
% INFO    : Bus 40077	: V=0.9940639, theta=-68.550745 -> V=1.0, theta=0.0
% INFO    : Bus 40078	: V=0.9941584, theta=-68.5427 -> V=1.0, theta=0.0
% INFO    : Bus 40079	: V=1.0215533, theta=-66.628519 -> V=1.0, theta=0.0
% INFO    : Bus 40080	: V=1.0216366, theta=-66.613507 -> V=1.0, theta=0.0
% INFO    : Bus 40081	: V=1.0192427, theta=-67.275474 -> V=1.0, theta=0.0
% INFO    : Bus 40082	: V=1.019099, theta=-67.293175 -> V=1.0, theta=0.0
% INFO    : Bus 40083	: V=0.980845, theta=-67.5042 -> V=1.0, theta=0.0
% INFO    : Bus 40084	: V=1.0308723, theta=-66.15514 -> V=1.0, theta=0.0
% INFO    : Bus 40085	: V=1.0305708, theta=-66.194431 -> V=1.0, theta=0.0
% INFO    : Bus 40086	: V=1.0311653, theta=-66.118022 -> V=1.0, theta=0.0
% INFO    : Bus 40087	: V=1.0308723, theta=-66.15514 -> V=1.0, theta=0.0
% INFO    : Bus 40088	: V=1.0059572, theta=-63.345486 -> V=1.0, theta=0.0
% INFO    : Bus 40089	: V=0.9990161, theta=-65.334267 -> V=1.0, theta=0.0
% INFO    : Bus 40090	: V=0.9968731, theta=-65.95368 -> V=1.0, theta=0.0
% INFO    : Bus 40091	: V=0.9972727, theta=-65.906688 -> V=1.0, theta=0.0
% INFO    : Bus 40092	: V=1.0102345, theta=-66.423635 -> V=1.0, theta=0.0
% INFO    : Bus 40093	: V=1.0100881, theta=-66.44811 -> V=1.0, theta=0.0
% INFO    : Bus 40094	: V=1.019699, theta=-66.727021 -> V=1.0, theta=0.0
% INFO    : Bus 40095	: V=1.0033681, theta=-61.545365 -> V=1.0, theta=0.0
% INFO    : Bus 40096	: V=0.9949583, theta=-63.104477 -> V=1.0, theta=0.0
% INFO    : Bus 40097	: V=0.9922185, theta=-66.435847 -> V=1.0, theta=0.0
% INFO    : Bus 40098	: V=0.9919256, theta=-66.463065 -> V=1.0, theta=0.0
% INFO    : Bus 40099	: V=1.0055136, theta=-68.3104 -> V=1.0, theta=0.0
% INFO    : Bus 40100	: V=1.0053706, theta=-68.332886 -> V=1.0, theta=0.0
% INFO    : Bus 40101	: V=1.005414, theta=-68.283919 -> V=1.0, theta=0.0
% INFO    : Bus 40102	: V=1.0055136, theta=-68.3104 -> V=1.0, theta=0.0
% INFO    : Bus 40103	: V=1.0102494, theta=-65.50342 -> V=1.0, theta=0.0
% INFO    : Bus 40104	: V=1.0170938, theta=-66.039336 -> V=1.0, theta=0.0
% INFO    : Bus 40105	: V=1.0167001, theta=-66.078842 -> V=1.0, theta=0.0
% INFO    : Bus 40106	: V=1.0174888, theta=-66.000195 -> V=1.0, theta=0.0
% INFO    : Bus 40107	: V=1.013101, theta=-62.908025 -> V=1.0, theta=0.0
% INFO    : Bus 40108	: V=1.0359608, theta=-65.736202 -> V=1.0, theta=0.0
% INFO    : Bus 40109	: V=1.0108812, theta=-65.385336 -> V=1.0, theta=0.0
% INFO    : Bus 40110	: V=1.0227744, theta=-66.764737 -> V=1.0, theta=0.0
% INFO    : Bus 40111	: V=1.0256261, theta=-66.741158 -> V=1.0, theta=0.0
% INFO    : Bus 40112	: V=1.0295454, theta=-66.317506 -> V=1.0, theta=0.0
% INFO    : Bus 40113	: V=1.029713, theta=-66.295466 -> V=1.0, theta=0.0
% INFO    : Bus 40114	: V=1.0191656, theta=-67.32447 -> V=1.0, theta=0.0
% INFO    : Bus 40115	: V=1.0189101, theta=-67.350198 -> V=1.0, theta=0.0
% INFO    : Bus 40116	: V=1.0314876, theta=-66.133243 -> V=1.0, theta=0.0
% INFO    : Bus 40117	: V=1.0001964, theta=-67.180758 -> V=1.0, theta=0.0
% INFO    : Bus 40118	: V=1.0069997, theta=-68.093755 -> V=1.0, theta=0.0
% INFO    : Bus 40119	: V=1.011631, theta=-67.573663 -> V=1.0, theta=0.0
% INFO    : Bus 40120	: V=1.012955, theta=-67.668587 -> V=1.0, theta=0.0
% INFO    : Bus 40121	: V=1.0133286, theta=-67.640256 -> V=1.0, theta=0.0
% INFO    : Bus 40122	: V=1.0170403, theta=-67.094294 -> V=1.0, theta=0.0
% INFO    : Bus 40123	: V=0.9895653, theta=-67.124965 -> V=1.0, theta=0.0
% INFO    : Bus 40124	: V=0.9931491, theta=-66.737553 -> V=1.0, theta=0.0
% INFO    : Bus 40125	: V=1.0194026, theta=-67.01486 -> V=1.0, theta=0.0
% INFO    : Bus 40126	: V=1.0263672, theta=-66.52243 -> V=1.0, theta=0.0
% INFO    : Bus 40127	: V=1.0266828, theta=-66.493549 -> V=1.0, theta=0.0
% INFO    : Bus 40128	: V=1.0297439, theta=-66.329053 -> V=1.0, theta=0.0
% INFO    : Bus 40129	: V=1.0327482, theta=-66.013138 -> V=1.0, theta=0.0
% INFO    : Bus 40130	: V=1.0264193, theta=-66.82347 -> V=1.0, theta=0.0
% INFO    : Bus 40131	: V=1.026268, theta=-66.848694 -> V=1.0, theta=0.0
% INFO    : Bus 40132	: V=1.0082864, theta=-68.064251 -> V=1.0, theta=0.0
% INFO    : Bus 40133	: V=0.992627, theta=-67.119125 -> V=1.0, theta=0.0
% INFO    : Bus 40134	: V=0.9925173, theta=-67.133019 -> V=1.0, theta=0.0
% INFO    : Bus 40135	: V=0.9984278, theta=-68.093881 -> V=1.0, theta=0.0
% INFO    : Bus 40136	: V=0.9988613, theta=-68.052674 -> V=1.0, theta=0.0
% INFO    : Bus 40137	: V=1.0137156, theta=-67.448312 -> V=1.0, theta=0.0
% INFO    : Bus 40138	: V=1.0182278, theta=-67.483243 -> V=1.0, theta=0.0
% INFO    : Bus 40139	: V=1.019792, theta=-67.434278 -> V=1.0, theta=0.0
% INFO    : Bus 40140	: V=1.0237163, theta=-67.519211 -> V=1.0, theta=0.0
% INFO    : Bus 40141	: V=1.0240341, theta=-67.485926 -> V=1.0, theta=0.0
% INFO    : Bus 40142	: V=1.0105748, theta=-68.188136 -> V=1.0, theta=0.0
% INFO    : Bus 40143	: V=1.00045, theta=-68.638895 -> V=1.0, theta=0.0
% INFO    : Bus 40144	: V=1.0173319, theta=-67.731675 -> V=1.0, theta=0.0
% INFO    : Bus 40145	: V=1.0138549, theta=-67.766253 -> V=1.0, theta=0.0
% INFO    : Bus 40146	: V=1.0212643, theta=-67.041436 -> V=1.0, theta=0.0
% INFO    : Bus 40147	: V=1.0080264, theta=-67.437714 -> V=1.0, theta=0.0
% INFO    : Bus 40148	: V=1.0121324, theta=-66.54922 -> V=1.0, theta=0.0
% INFO    : Bus 40149	: V=1.0118451, theta=-66.576588 -> V=1.0, theta=0.0
% INFO    : Bus 40150	: V=1.0100894, theta=-62.566521 -> V=1.0, theta=0.0
% INFO    : Bus 40151	: V=1.0297522, theta=-66.341214 -> V=1.0, theta=0.0
% INFO    : Bus 40152	: V=1.0127871, theta=-62.326528 -> V=1.0, theta=0.0
% INFO    : Bus 40153	: V=1.006663, theta=-67.158857 -> V=1.0, theta=0.0
% INFO    : Bus 40154	: V=1.0060426, theta=-67.200396 -> V=1.0, theta=0.0
% INFO    : Bus 40155	: V=1.0140532, theta=-66.717304 -> V=1.0, theta=0.0
% INFO    : Bus 40156	: V=1.0099732, theta=-68.022603 -> V=1.0, theta=0.0
% INFO    : Bus 40157	: V=1.0171765, theta=-67.216297 -> V=1.0, theta=0.0
% INFO    : Bus 40158	: V=1.0169463, theta=-67.25727 -> V=1.0, theta=0.0
% INFO    : Bus 40159	: V=1.0159719, theta=-67.168154 -> V=1.0, theta=0.0
% INFO    : Bus 40160	: V=1.0166347, theta=-67.605223 -> V=1.0, theta=0.0
% INFO    : Bus 40161	: V=1.0189769, theta=-67.953874 -> V=1.0, theta=0.0
% INFO    : Bus 40162	: V=1.0184325, theta=-68.008059 -> V=1.0, theta=0.0
% INFO    : Bus 40163	: V=1.0362684, theta=-66.84126 -> V=1.0, theta=0.0
% INFO    : Bus 40164	: V=1.0055364, theta=-67.644549 -> V=1.0, theta=0.0
% INFO    : Bus 40165	: V=1.0058771, theta=-67.621382 -> V=1.0, theta=0.0
% INFO    : Bus 40166	: V=1.0184697, theta=-67.500683 -> V=1.0, theta=0.0
% INFO    : Bus 40167	: V=1.0170478, theta=-67.352797 -> V=1.0, theta=0.0
% INFO    : Bus 40168	: V=1.0170469, theta=-67.195328 -> V=1.0, theta=0.0
% INFO    : Bus 40169	: V=1.0091128, theta=-67.708529 -> V=1.0, theta=0.0
% INFO    : Bus 40170	: V=1.0213033, theta=-66.890361 -> V=1.0, theta=0.0
% INFO    : Bus 40171	: V=1.0088324, theta=-67.72709 -> V=1.0, theta=0.0
% INFO    : Bus 40172	: V=1.019126, theta=-67.825419 -> V=1.0, theta=0.0
% INFO    : Bus 40173	: V=1.0187933, theta=-67.849493 -> V=1.0, theta=0.0
% INFO    : Bus 40174	: V=1.0260521, theta=-66.60853 -> V=1.0, theta=0.0
% INFO    : Bus 40175	: V=1.0031969, theta=-65.207998 -> V=1.0, theta=0.0
% INFO    : Bus 40176	: V=1.0034844, theta=-65.175657 -> V=1.0, theta=0.0
% INFO    : Bus 40177	: V=1.0201998, theta=-68.125833 -> V=1.0, theta=0.0
% INFO    : Bus 40178	: V=1.0199531, theta=-68.15724 -> V=1.0, theta=0.0
% INFO    : Bus 40179	: V=1.0196383, theta=-67.96564 -> V=1.0, theta=0.0
% INFO    : Bus 40180	: V=0.9866012, theta=-65.678731 -> V=1.0, theta=0.0
% INFO    : Bus 40181	: V=1.0121755, theta=-67.500778 -> V=1.0, theta=0.0
% INFO    : Bus 40182	: V=1.0105715, theta=-67.492095 -> V=1.0, theta=0.0
% INFO    : Bus 40183	: V=1.0108968, theta=-67.469759 -> V=1.0, theta=0.0
% INFO    : Bus 40184	: V=1.0076203, theta=-67.750549 -> V=1.0, theta=0.0
% INFO    : Bus 40185	: V=1.0072592, theta=-67.786171 -> V=1.0, theta=0.0
% INFO    : Bus 40186	: V=1.0036149, theta=-63.385599 -> V=1.0, theta=0.0
% INFO    : Bus 40187	: V=1.0389724, theta=-66.676582 -> V=1.0, theta=0.0
% INFO    : Bus 40188	: V=1.0271013, theta=-67.630172 -> V=1.0, theta=0.0
% INFO    : Bus 40189	: V=1.0272796, theta=-67.606977 -> V=1.0, theta=0.0
% INFO    : Bus 40190	: V=1.0244172, theta=-67.864887 -> V=1.0, theta=0.0
% INFO    : Bus 40191	: V=1.0239948, theta=-66.69744 -> V=1.0, theta=0.0
% INFO    : Bus 40192	: V=1.0209219, theta=-67.120445 -> V=1.0, theta=0.0
% INFO    : Bus 40193	: V=1.020275, theta=-68.322687 -> V=1.0, theta=0.0
% INFO    : Bus 40194	: V=1.0023924, theta=-62.892418 -> V=1.0, theta=0.0
% INFO    : Bus 40195	: V=1.00225, theta=-62.904494 -> V=1.0, theta=0.0
% INFO    : Bus 40196	: V=1.0137828, theta=-67.808016 -> V=1.0, theta=0.0
% INFO    : Bus 40197	: V=1.0202621, theta=-68.021095 -> V=1.0, theta=0.0
% INFO    : Bus 40198	: V=0.9963083, theta=-66.164962 -> V=1.0, theta=0.0
% INFO    : Bus 40199	: V=1.0256664, theta=-67.866007 -> V=1.0, theta=0.0
% INFO    : Bus 40200	: V=1.0252249, theta=-67.895158 -> V=1.0, theta=0.0
% INFO    : Bus 40201	: V=1.0160297, theta=-68.249233 -> V=1.0, theta=0.0
% INFO    : Bus 40202	: V=0.9686477, theta=-71.603632 -> V=1.0, theta=0.0
% INFO    : Bus 40203	: V=1.0148176, theta=-68.327214 -> V=1.0, theta=0.0
% INFO    : Bus 40204	: V=1.0148176, theta=-68.327214 -> V=1.0, theta=0.0
% INFO    : Bus 40205	: V=1.0167115, theta=-68.216906 -> V=1.0, theta=0.0
% INFO    : Bus 40206	: V=1.0380857, theta=-67.467959 -> V=1.0, theta=0.0
% INFO    : Bus 40207	: V=1.021552, theta=-67.100895 -> V=1.0, theta=0.0
% INFO    : Bus 40208	: V=1.0209112, theta=-67.148058 -> V=1.0, theta=0.0
% INFO    : Bus 40209	: V=1.0221035, theta=-67.599337 -> V=1.0, theta=0.0
% INFO    : Bus 40210	: V=1.0228247, theta=-67.376748 -> V=1.0, theta=0.0
% INFO    : Bus 40211	: V=0.9956026, theta=-66.62435 -> V=1.0, theta=0.0
% INFO    : Bus 40212	: V=0.9954639, theta=-66.642802 -> V=1.0, theta=0.0
% INFO    : Bus 40213	: V=1.0290431, theta=-67.004696 -> V=1.0, theta=0.0
% INFO    : Bus 40214	: V=1.0077939, theta=-62.933873 -> V=1.0, theta=0.0
% INFO    : Bus 40215	: V=1.0294496, theta=-67.729529 -> V=1.0, theta=0.0
% INFO    : Bus 40216	: V=1.0340088, theta=-67.676932 -> V=1.0, theta=0.0
% INFO    : Bus 40217	: V=1.0279156, theta=-67.363993 -> V=1.0, theta=0.0
% INFO    : Bus 40218	: V=1.0300725, theta=-67.228492 -> V=1.0, theta=0.0
% INFO    : Bus 40219	: V=1.0297805, theta=-67.253385 -> V=1.0, theta=0.0
% INFO    : Bus 40220	: V=1.0303681, theta=-67.204582 -> V=1.0, theta=0.0
% INFO    : Bus 40221	: V=1.0211599, theta=-68.060964 -> V=1.0, theta=0.0
% INFO    : Bus 40222	: V=1.0258056, theta=-67.919112 -> V=1.0, theta=0.0
% INFO    : Bus 40223	: V=1.0195969, theta=-68.12131 -> V=1.0, theta=0.0
% INFO    : Bus 40224	: V=1.0329748, theta=-67.11354 -> V=1.0, theta=0.0
% INFO    : Bus 40225	: V=1.0179971, theta=-68.118482 -> V=1.0, theta=0.0
% INFO    : Bus 40226	: V=1.0143268, theta=-68.882495 -> V=1.0, theta=0.0
% INFO    : Bus 40227	: V=1.0126791, theta=-66.689663 -> V=1.0, theta=0.0
% INFO    : Bus 40228	: V=0.9941251, theta=-67.468368 -> V=1.0, theta=0.0
% INFO    : Bus 40229	: V=1.0138807, theta=-67.598376 -> V=1.0, theta=0.0
% INFO    : Bus 40230	: V=1.0192572, theta=-67.877361 -> V=1.0, theta=0.0
% INFO    : Bus 40231	: V=1.0193642, theta=-67.869348 -> V=1.0, theta=0.0
% INFO    : Bus 40232	: V=1.019143, theta=-67.885184 -> V=1.0, theta=0.0
% INFO    : Bus 40233	: V=1.0193441, theta=-67.998987 -> V=1.0, theta=0.0
% INFO    : Bus 40234	: V=1.0023, theta=-63.853333 -> V=1.0, theta=0.0
% INFO    : Bus 40235	: V=1.0017274, theta=-67.016746 -> V=1.0, theta=0.0
% INFO    : Bus 40236	: V=1.0019554, theta=-66.987912 -> V=1.0, theta=0.0
% INFO    : Bus 40237	: V=1.0015079, theta=-67.045718 -> V=1.0, theta=0.0
% INFO    : Bus 40238	: V=1.0226356, theta=-67.99096 -> V=1.0, theta=0.0
% INFO    : Bus 40239	: V=1.0223295, theta=-68.018516 -> V=1.0, theta=0.0
% INFO    : Bus 40240	: V=1.023384, theta=-68.054058 -> V=1.0, theta=0.0
% INFO    : Bus 40241	: V=1.0277304, theta=-67.833348 -> V=1.0, theta=0.0
% INFO    : Bus 40242	: V=1.0027264, theta=-67.62441 -> V=1.0, theta=0.0
% INFO    : Bus 40243	: V=1.0025255, theta=-67.646229 -> V=1.0, theta=0.0
% INFO    : Bus 40244	: V=1.0029383, theta=-67.600668 -> V=1.0, theta=0.0
% INFO    : Bus 40245	: V=1.0230554, theta=-67.93902 -> V=1.0, theta=0.0
% INFO    : Bus 40246	: V=1.0211949, theta=-68.106994 -> V=1.0, theta=0.0
% INFO    : Bus 40247	: V=1.0214678, theta=-68.069669 -> V=1.0, theta=0.0
% INFO    : Bus 40248	: V=1.017395, theta=-70.00432 -> V=1.0, theta=0.0
% INFO    : Bus 40249	: V=1.0173329, theta=-70.008532 -> V=1.0, theta=0.0
% INFO    : Bus 40250	: V=1.0313896, theta=-67.709338 -> V=1.0, theta=0.0
% INFO    : Bus 40251	: V=1.0285895, theta=-67.669545 -> V=1.0, theta=0.0
% INFO    : Bus 40252	: V=1.0280676, theta=-67.69833 -> V=1.0, theta=0.0
% INFO    : Bus 40253	: V=1.029108, theta=-67.638953 -> V=1.0, theta=0.0
% INFO    : Bus 40254	: V=0.996316, theta=-63.77158 -> V=1.0, theta=0.0
% INFO    : Bus 40255	: V=1.0309064, theta=-67.387359 -> V=1.0, theta=0.0
% INFO    : Bus 40256	: V=0.9960557, theta=-63.814728 -> V=1.0, theta=0.0
% INFO    : Bus 40257	: V=1.0283771, theta=-66.377062 -> V=1.0, theta=0.0
% INFO    : Bus 40258	: V=1.0281667, theta=-66.40084 -> V=1.0, theta=0.0
% INFO    : Bus 40259	: V=1.0118872, theta=-67.251754 -> V=1.0, theta=0.0
% INFO    : Bus 40260	: V=1.0079722, theta=-62.511607 -> V=1.0, theta=0.0
% INFO    : Bus 40261	: V=1.0059932, theta=-64.346224 -> V=1.0, theta=0.0
% INFO    : Bus 40262	: V=0.9998867, theta=-66.208133 -> V=1.0, theta=0.0
% INFO    : Bus 40263	: V=1.0062974, theta=-63.794418 -> V=1.0, theta=0.0
% INFO    : Bus 40264	: V=1.045714, theta=-48.152366 -> V=1.0, theta=0.0
% INFO    : Bus 40265	: V=1.0456406, theta=-48.156496 -> V=1.0, theta=0.0
% INFO    : Bus 40266	: V=1.0224049, theta=-68.047202 -> V=1.0, theta=0.0
% INFO    : Bus 40267	: V=1.009705, theta=-68.210251 -> V=1.0, theta=0.0
% INFO    : Bus 40268	: V=1.0094649, theta=-68.240162 -> V=1.0, theta=0.0
% INFO    : Bus 40269	: V=0.9957371, theta=-67.181801 -> V=1.0, theta=0.0
% INFO    : Bus 40270	: V=0.9960315, theta=-67.148454 -> V=1.0, theta=0.0
% INFO    : Bus 40271	: V=1.0260661, theta=-67.934324 -> V=1.0, theta=0.0
% INFO    : Bus 40272	: V=0.9935134, theta=-67.473407 -> V=1.0, theta=0.0
% INFO    : Bus 40273	: V=1.0173473, theta=-62.345835 -> V=1.0, theta=0.0
% INFO    : Bus 40274	: V=1.006857, theta=-64.687561 -> V=1.0, theta=0.0
% INFO    : Bus 40275	: V=1.015101, theta=-62.813082 -> V=1.0, theta=0.0
% INFO    : Bus 40276	: V=1.015101, theta=-62.813082 -> V=1.0, theta=0.0
% INFO    : Bus 40277	: V=1.0217203, theta=-68.095456 -> V=1.0, theta=0.0
% INFO    : Bus 40278	: V=1.0213773, theta=-68.127233 -> V=1.0, theta=0.0
% INFO    : Bus 40279	: V=1.0197198, theta=-67.749624 -> V=1.0, theta=0.0
% INFO    : Bus 40280	: V=1.0094835, theta=-68.438568 -> V=1.0, theta=0.0
% INFO    : Bus 40281	: V=1.0086393, theta=-68.487298 -> V=1.0, theta=0.0
% INFO    : Bus 40282	: V=1.01076, theta=-68.016312 -> V=1.0, theta=0.0
% INFO    : Bus 40283	: V=1.0105301, theta=-68.036957 -> V=1.0, theta=0.0
% INFO    : Bus 40284	: V=1.0214528, theta=-68.097809 -> V=1.0, theta=0.0
% INFO    : Bus 40285	: V=1.0213162, theta=-68.122056 -> V=1.0, theta=0.0
% INFO    : Bus 40286	: V=0.9937165, theta=-67.653548 -> V=1.0, theta=0.0
% INFO    : Bus 40287	: V=1.006775, theta=-65.224226 -> V=1.0, theta=0.0
% INFO    : Bus 40288	: V=1.0065767, theta=-65.255352 -> V=1.0, theta=0.0
% INFO    : Bus 40289	: V=0.9910505, theta=-65.812238 -> V=1.0, theta=0.0
% INFO    : Bus 40290	: V=1.0087387, theta=-68.374749 -> V=1.0, theta=0.0
% INFO    : Bus 40291	: V=1.0084857, theta=-68.408414 -> V=1.0, theta=0.0
% INFO    : Bus 40292	: V=1.0107052, theta=-68.273003 -> V=1.0, theta=0.0
% INFO    : Bus 40293	: V=1.0107052, theta=-68.273003 -> V=1.0, theta=0.0
% INFO    : Bus 40294	: V=1.0107052, theta=-68.273003 -> V=1.0, theta=0.0
% INFO    : Bus 40295	: V=1.0107052, theta=-68.273003 -> V=1.0, theta=0.0
% INFO    : Bus 40296	: V=1.010399, theta=-68.306663 -> V=1.0, theta=0.0
% INFO    : Bus 40297	: V=1.0109916, theta=-68.243535 -> V=1.0, theta=0.0
% INFO    : Bus 40298	: V=1.0075044, theta=-62.755829 -> V=1.0, theta=0.0
% INFO    : Bus 40299	: V=1.0401355, theta=-67.312225 -> V=1.0, theta=0.0
% INFO    : Bus 40300	: V=1.0027519, theta=-68.277372 -> V=1.0, theta=0.0
% INFO    : Bus 40301	: V=1.0017858, theta=-68.324547 -> V=1.0, theta=0.0
% INFO    : Bus 40302	: V=1.0125002, theta=-67.548332 -> V=1.0, theta=0.0
% INFO    : Bus 40303	: V=1.0100129, theta=-68.188662 -> V=1.0, theta=0.0
% INFO    : Bus 40304	: V=1.0027898, theta=-68.235673 -> V=1.0, theta=0.0
% INFO    : Bus 40305	: V=1.0162397, theta=-68.841311 -> V=1.0, theta=0.0
% INFO    : Bus 40306	: V=1.0161603, theta=-68.851407 -> V=1.0, theta=0.0
% INFO    : Bus 40307	: V=1.0120232, theta=-68.415607 -> V=1.0, theta=0.0
% INFO    : Bus 40308	: V=1.0222668, theta=-67.73187 -> V=1.0, theta=0.0
% INFO    : Bus 40309	: V=1.0216278, theta=-67.776672 -> V=1.0, theta=0.0
% INFO    : Bus 40310	: V=1.0188803, theta=-67.869046 -> V=1.0, theta=0.0
% INFO    : Bus 40311	: V=0.9985512, theta=-67.214117 -> V=1.0, theta=0.0
% INFO    : Bus 40312	: V=0.9981828, theta=-67.260309 -> V=1.0, theta=0.0
% INFO    : Bus 40313	: V=1.0133874, theta=-67.835546 -> V=1.0, theta=0.0
% INFO    : Bus 40314	: V=0.9994258, theta=-67.15919 -> V=1.0, theta=0.0
% INFO    : Bus 40315	: V=0.9989503, theta=-67.197198 -> V=1.0, theta=0.0
% INFO    : Bus 40316	: V=0.9998633, theta=-67.121304 -> V=1.0, theta=0.0
% INFO    : Bus 40317	: V=1.0010417, theta=-67.124631 -> V=1.0, theta=0.0
% INFO    : Bus 40318	: V=1.0014366, theta=-67.081749 -> V=1.0, theta=0.0
% INFO    : Bus 40319	: V=1.0006966, theta=-67.166734 -> V=1.0, theta=0.0
% INFO    : Bus 40320	: V=1.0067031, theta=-68.673342 -> V=1.0, theta=0.0
% INFO    : Bus 40321	: V=1.0095819, theta=-68.533791 -> V=1.0, theta=0.0
% INFO    : Bus 40322	: V=1.0145831, theta=-68.828502 -> V=1.0, theta=0.0
% INFO    : Bus 40323	: V=1.0150178, theta=-67.578231 -> V=1.0, theta=0.0
% INFO    : Bus 40324	: V=1.0152748, theta=-67.556401 -> V=1.0, theta=0.0
% INFO    : Bus 40325	: V=1.0072937, theta=-68.80874 -> V=1.0, theta=0.0
% INFO    : Bus 40326	: V=1.0071837, theta=-68.833417 -> V=1.0, theta=0.0
% INFO    : Bus 40327	: V=1.0141276, theta=-68.963135 -> V=1.0, theta=0.0
% INFO    : Bus 40328	: V=1.0140974, theta=-68.968678 -> V=1.0, theta=0.0
% INFO    : Bus 40329	: V=1.0122467, theta=-69.649128 -> V=1.0, theta=0.0
% INFO    : Bus 40330	: V=1.0120898, theta=-69.671718 -> V=1.0, theta=0.0
% INFO    : Bus 40331	: V=1.0124083, theta=-69.625846 -> V=1.0, theta=0.0
% INFO    : Bus 40332	: V=1.0091627, theta=-69.713081 -> V=1.0, theta=0.0
% INFO    : Bus 40333	: V=1.0090371, theta=-69.739341 -> V=1.0, theta=0.0
% INFO    : Bus 40334	: V=1.0018642, theta=-66.430982 -> V=1.0, theta=0.0
% INFO    : Bus 40335	: V=1.0122451, theta=-63.251459 -> V=1.0, theta=0.0
% INFO    : Bus 40336	: V=1.0101962, theta=-67.244762 -> V=1.0, theta=0.0
% INFO    : Bus 40337	: V=1.0118024, theta=-70.158459 -> V=1.0, theta=0.0
% INFO    : Bus 40338	: V=1.0118024, theta=-70.158459 -> V=1.0, theta=0.0
% INFO    : Bus 40339	: V=1.0119848, theta=-63.296689 -> V=1.0, theta=0.0
% INFO    : Bus 40340	: V=1.0064127, theta=-68.805559 -> V=1.0, theta=0.0
% INFO    : Bus 40341	: V=1.0063275, theta=-67.971351 -> V=1.0, theta=0.0
% INFO    : Bus 40342	: V=1.0122527, theta=-68.025717 -> V=1.0, theta=0.0
% INFO    : Bus 40343	: V=1.0017536, theta=-67.062551 -> V=1.0, theta=0.0
% INFO    : Bus 40344	: V=0.9951432, theta=-67.683824 -> V=1.0, theta=0.0
% INFO    : Bus 40345	: V=1.0139217, theta=-68.48345 -> V=1.0, theta=0.0
% INFO    : Bus 40346	: V=1.0085142, theta=-68.600132 -> V=1.0, theta=0.0
% INFO    : Bus 40347	: V=1.0083525, theta=-68.633575 -> V=1.0, theta=0.0
% INFO    : Bus 40348	: V=0.9995446, theta=-66.267343 -> V=1.0, theta=0.0
% INFO    : Bus 40349	: V=0.9993355, theta=-66.294111 -> V=1.0, theta=0.0
% INFO    : Bus 40350	: V=0.9997196, theta=-66.240586 -> V=1.0, theta=0.0
% INFO    : Bus 40351	: V=0.9995446, theta=-66.267343 -> V=1.0, theta=0.0
% INFO    : Bus 40352	: V=1.0044425, theta=-67.163433 -> V=1.0, theta=0.0
% INFO    : Bus 40353	: V=1.0041787, theta=-67.187324 -> V=1.0, theta=0.0
% INFO    : Bus 40354	: V=1.0004917, theta=-66.064817 -> V=1.0, theta=0.0
% INFO    : Bus 40355	: V=1.0003989, theta=-66.084397 -> V=1.0, theta=0.0
% INFO    : Bus 40356	: V=1.0059731, theta=-67.545692 -> V=1.0, theta=0.0
% INFO    : Bus 40357	: V=1.0055149, theta=-67.589029 -> V=1.0, theta=0.0
% INFO    : Bus 40358	: V=1.007568, theta=-68.065439 -> V=1.0, theta=0.0
% INFO    : Bus 40359	: V=1.0083876, theta=-68.227584 -> V=1.0, theta=0.0
% INFO    : Bus 40360	: V=1.0139883, theta=-67.45459 -> V=1.0, theta=0.0
% INFO    : Bus 40361	: V=1.013703, theta=-67.485225 -> V=1.0, theta=0.0
% INFO    : Bus 40362	: V=1.0108184, theta=-68.176203 -> V=1.0, theta=0.0
% INFO    : Bus 40363	: V=0.9975652, theta=-66.859769 -> V=1.0, theta=0.0
% INFO    : Bus 40364	: V=1.0041356, theta=-67.433787 -> V=1.0, theta=0.0
% INFO    : Bus 40365	: V=1.0038456, theta=-67.468516 -> V=1.0, theta=0.0
% INFO    : Bus 40366	: V=1.0044363, theta=-67.398969 -> V=1.0, theta=0.0
% INFO    : Bus 40367	: V=1.0052719, theta=-67.786456 -> V=1.0, theta=0.0
% INFO    : Bus 40368	: V=1.0217212, theta=-61.946602 -> V=1.0, theta=0.0
% INFO    : Bus 40369	: V=1.0013867, theta=-66.458576 -> V=1.0, theta=0.0
% INFO    : Bus 40370	: V=1.0027339, theta=-66.103345 -> V=1.0, theta=0.0
% INFO    : Bus 40371	: V=1.0027339, theta=-66.103345 -> V=1.0, theta=0.0
% INFO    : Bus 40372	: V=1.0062855, theta=-67.821328 -> V=1.0, theta=0.0
% INFO    : Bus 40373	: V=1.0061053, theta=-67.858003 -> V=1.0, theta=0.0
% INFO    : Bus 40374	: V=1.0046474, theta=-68.921093 -> V=1.0, theta=0.0
% INFO    : Bus 40375	: V=1.0043905, theta=-68.952853 -> V=1.0, theta=0.0
% INFO    : Bus 40376	: V=1.0049456, theta=-68.885046 -> V=1.0, theta=0.0
% INFO    : Bus 40377	: V=1.015844, theta=-63.915914 -> V=1.0, theta=0.0
% INFO    : Bus 40378	: V=1.0095799, theta=-67.993177 -> V=1.0, theta=0.0
% INFO    : Bus 40379	: V=1.0188548, theta=-67.310538 -> V=1.0, theta=0.0
% INFO    : Bus 40380	: V=1.0004488, theta=-69.506136 -> V=1.0, theta=0.0
% INFO    : Bus 40381	: V=1.0034681, theta=-68.479341 -> V=1.0, theta=0.0
% INFO    : Bus 40382	: V=1.0182956, theta=-62.433437 -> V=1.0, theta=0.0
% INFO    : Bus 40383	: V=1.021584, theta=-66.867349 -> V=1.0, theta=0.0
% INFO    : Bus 40384	: V=1.0105048, theta=-67.820898 -> V=1.0, theta=0.0
% INFO    : Bus 40385	: V=1.010322, theta=-67.851747 -> V=1.0, theta=0.0
% INFO    : Bus 40386	: V=0.9995799, theta=-65.808016 -> V=1.0, theta=0.0
% INFO    : Bus 40387	: V=0.9950779, theta=-67.152427 -> V=1.0, theta=0.0
% INFO    : Bus 40388	: V=0.9947315, theta=-67.182257 -> V=1.0, theta=0.0
% INFO    : Bus 40389	: V=0.997385, theta=-67.919906 -> V=1.0, theta=0.0
% INFO    : Bus 40390	: V=1.0092678, theta=-68.206853 -> V=1.0, theta=0.0
% INFO    : Bus 40391	: V=1.0032704, theta=-68.036656 -> V=1.0, theta=0.0
% INFO    : Bus 40392	: V=1.0015109, theta=-65.955243 -> V=1.0, theta=0.0
% INFO    : Bus 40393	: V=1.0112759, theta=-67.744553 -> V=1.0, theta=0.0
% INFO    : Bus 40394	: V=1.0110169, theta=-67.773017 -> V=1.0, theta=0.0
% INFO    : Bus 40395	: V=1.0114954, theta=-67.717778 -> V=1.0, theta=0.0
% INFO    : Bus 40396	: V=1.0112759, theta=-67.744553 -> V=1.0, theta=0.0
% INFO    : Bus 40397	: V=1.0207342, theta=-67.024428 -> V=1.0, theta=0.0
% INFO    : Bus 40398	: V=1.0068022, theta=-64.114509 -> V=1.0, theta=0.0
% INFO    : Bus 40399	: V=1.0063458, theta=-64.15549 -> V=1.0, theta=0.0
% INFO    : Bus 40400	: V=1.0108169, theta=-64.185174 -> V=1.0, theta=0.0
% INFO    : Bus 40401	: V=1.0105053, theta=-64.228623 -> V=1.0, theta=0.0
% INFO    : Bus 40402	: V=1.0111243, theta=-64.140557 -> V=1.0, theta=0.0
% INFO    : Bus 40403	: V=1.001711, theta=-69.065702 -> V=1.0, theta=0.0
% INFO    : Bus 40404	: V=1.0093193, theta=-68.338291 -> V=1.0, theta=0.0
% INFO    : Bus 40405	: V=1.0058896, theta=-67.937436 -> V=1.0, theta=0.0
% INFO    : Bus 40406	: V=0.9963056, theta=-66.969095 -> V=1.0, theta=0.0
% INFO    : Bus 40407	: V=1.0176119, theta=-68.075025 -> V=1.0, theta=0.0
% INFO    : Bus 40408	: V=1.0173729, theta=-68.104858 -> V=1.0, theta=0.0
% INFO    : Bus 40409	: V=1.0304027, theta=-67.649885 -> V=1.0, theta=0.0
% INFO    : Bus 40410	: V=1.0056673, theta=-67.77167 -> V=1.0, theta=0.0
% INFO    : Bus 40411	: V=0.9974015, theta=-66.811588 -> V=1.0, theta=0.0
% INFO    : Bus 40412	: V=0.9934708, theta=-67.85598 -> V=1.0, theta=0.0
% INFO    : Bus 40413	: V=1.0188943, theta=-68.06565 -> V=1.0, theta=0.0
% INFO    : Bus 40414	: V=1.0034102, theta=-68.194503 -> V=1.0, theta=0.0
% INFO    : Bus 40415	: V=1.0115567, theta=-68.256808 -> V=1.0, theta=0.0
% INFO    : Bus 40416	: V=1.0111743, theta=-68.293005 -> V=1.0, theta=0.0
% INFO    : Bus 40417	: V=1.0267206, theta=-67.516908 -> V=1.0, theta=0.0
% INFO    : Bus 40418	: V=1.0130518, theta=-67.590145 -> V=1.0, theta=0.0
% INFO    : Bus 40419	: V=1.0193385, theta=-68.213683 -> V=1.0, theta=0.0
% INFO    : Bus 40420	: V=1.0190113, theta=-68.240515 -> V=1.0, theta=0.0
% INFO    : Bus 40421	: V=1.0140037, theta=-64.479561 -> V=1.0, theta=0.0
% INFO    : Bus 40422	: V=1.0019587, theta=-65.672679 -> V=1.0, theta=0.0
% INFO    : Bus 40423	: V=1.0019135, theta=-65.681781 -> V=1.0, theta=0.0
% INFO    : Bus 40424	: V=1.0049259, theta=-62.051886 -> V=1.0, theta=0.0
% INFO    : Bus 40425	: V=1.0047828, theta=-62.061961 -> V=1.0, theta=0.0
% INFO    : Bus 40426	: V=0.9978892, theta=-61.192849 -> V=1.0, theta=0.0
% INFO    : Bus 40427	: V=0.9976955, theta=-61.229236 -> V=1.0, theta=0.0
% INFO    : Bus 40428	: V=1.0142282, theta=-58.070964 -> V=1.0, theta=0.0
% INFO    : Bus 40429	: V=1.0173547, theta=-59.126377 -> V=1.0, theta=0.0
% INFO    : Bus 40430	: V=1.0144419, theta=-68.219556 -> V=1.0, theta=0.0
% INFO    : Bus 40431	: V=1.0147307, theta=-68.187775 -> V=1.0, theta=0.0
% INFO    : Bus 40432	: V=1.0146342, theta=-68.095292 -> V=1.0, theta=0.0
% INFO    : Bus 40433	: V=1.0149363, theta=-68.063775 -> V=1.0, theta=0.0
% INFO    : Bus 40434	: V=0.99269, theta=-67.549344 -> V=1.0, theta=0.0
% INFO    : Bus 40435	: V=0.9910587, theta=-68.392949 -> V=1.0, theta=0.0
% INFO    : Bus 40436	: V=0.9913604, theta=-68.348883 -> V=1.0, theta=0.0
% INFO    : Bus 40437	: V=1.0162472, theta=-68.38315 -> V=1.0, theta=0.0
% INFO    : Bus 40438	: V=1.0158096, theta=-68.421594 -> V=1.0, theta=0.0
% INFO    : Bus 40439	: V=1.0183793, theta=-62.104186 -> V=1.0, theta=0.0
% INFO    : Bus 40440	: V=1.0398355, theta=-67.075407 -> V=1.0, theta=0.0
% INFO    : Bus 40441	: V=1.0181571, theta=-62.143812 -> V=1.0, theta=0.0
% INFO    : Bus 40442	: V=0.9867486, theta=-67.945823 -> V=1.0, theta=0.0
% INFO    : Bus 40443	: V=1.0120757, theta=-63.689681 -> V=1.0, theta=0.0
% INFO    : Bus 40444	: V=0.9831675, theta=-66.061732 -> V=1.0, theta=0.0
% INFO    : Bus 40445	: V=1.0125095, theta=-63.656121 -> V=1.0, theta=0.0
% INFO    : Bus 40446	: V=1.0125095, theta=-63.656121 -> V=1.0, theta=0.0
% INFO    : Bus 40447	: V=1.0234754, theta=-67.312923 -> V=1.0, theta=0.0
% INFO    : Bus 40448	: V=1.0216627, theta=-67.766858 -> V=1.0, theta=0.0
% INFO    : Bus 40449	: V=1.0243435, theta=-66.399982 -> V=1.0, theta=0.0
% INFO    : Bus 40450	: V=1.024551, theta=-66.370821 -> V=1.0, theta=0.0
% INFO    : Bus 40451	: V=1.0172272, theta=-67.349011 -> V=1.0, theta=0.0
% INFO    : Bus 40452	: V=1.0169576, theta=-67.37444 -> V=1.0, theta=0.0
% INFO    : Bus 40453	: V=1.0174504, theta=-67.325211 -> V=1.0, theta=0.0
% INFO    : Bus 40454	: V=1.0234105, theta=-66.703285 -> V=1.0, theta=0.0
% INFO    : Bus 40455	: V=1.0058042, theta=-68.35209 -> V=1.0, theta=0.0
% INFO    : Bus 40456	: V=1.0115323, theta=-65.045759 -> V=1.0, theta=0.0
% INFO    : Bus 40457	: V=1.0008544, theta=-66.434668 -> V=1.0, theta=0.0
% INFO    : Bus 40458	: V=1.0245319, theta=-67.998699 -> V=1.0, theta=0.0
% INFO    : Bus 40459	: V=1.0210524, theta=-63.350135 -> V=1.0, theta=0.0
% INFO    : Bus 40460	: V=1.0208674, theta=-63.374791 -> V=1.0, theta=0.0
% INFO    : Bus 40461	: V=1.0123036, theta=-68.750109 -> V=1.0, theta=0.0
% INFO    : Bus 40462	: V=1.0001045, theta=-68.046686 -> V=1.0, theta=0.0
% INFO    : Bus 40463	: V=1.0024998, theta=-65.812927 -> V=1.0, theta=0.0
% INFO    : Bus 40464	: V=1.0255365, theta=-65.99438 -> V=1.0, theta=0.0
% INFO    : Bus 40465	: V=1.0368207, theta=-51.0673 -> V=1.0, theta=0.0
% INFO    : Bus 40466	: V=1.0367931, theta=-51.070656 -> V=1.0, theta=0.0
% INFO    : Bus 40467	: V=1.0578925, theta=-44.52926 -> V=1.0, theta=0.0
% INFO    : Bus 40468	: V=1.0581418, theta=-44.536045 -> V=1.0, theta=0.0
% INFO    : Bus 40469	: V=1.0147645, theta=-66.844647 -> V=1.0, theta=0.0
% INFO    : Bus 40470	: V=1.0146356, theta=-66.870965 -> V=1.0, theta=0.0
% INFO    : Bus 40471	: V=0.9928052, theta=-61.972727 -> V=1.0, theta=0.0
% INFO    : Bus 40472	: V=0.9930529, theta=-61.938627 -> V=1.0, theta=0.0
% INFO    : Bus 40473	: V=0.9951753, theta=-61.889925 -> V=1.0, theta=0.0
% INFO    : Bus 40474	: V=1.0026824, theta=-70.314216 -> V=1.0, theta=0.0
% INFO    : Bus 40475	: V=1.0107564, theta=-68.137005 -> V=1.0, theta=0.0
% INFO    : Bus 40476	: V=1.000715, theta=-66.273191 -> V=1.0, theta=0.0
% INFO    : Bus 40477	: V=1.0008938, theta=-66.251266 -> V=1.0, theta=0.0
% INFO    : Bus 40478	: V=1.0007783, theta=-68.133611 -> V=1.0, theta=0.0
% INFO    : Bus 40479	: V=1.0054047, theta=-68.341306 -> V=1.0, theta=0.0
% INFO    : Bus 40480	: V=1.0002089, theta=-67.834952 -> V=1.0, theta=0.0
% INFO    : Bus 40481	: V=1.0000227, theta=-67.863842 -> V=1.0, theta=0.0
% INFO    : Bus 40482	: V=0.9999928, theta=-66.445404 -> V=1.0, theta=0.0
% INFO    : Bus 40483	: V=0.9999627, theta=-66.449304 -> V=1.0, theta=0.0
% INFO    : Bus 40484	: V=0.9989992, theta=-68.632752 -> V=1.0, theta=0.0
% INFO    : Bus 40485	: V=1.0016572, theta=-69.720285 -> V=1.0, theta=0.0
% INFO    : Bus 40486	: V=1.0039146, theta=-71.161731 -> V=1.0, theta=0.0
% INFO    : Bus 40487	: V=1.003864, theta=-71.166424 -> V=1.0, theta=0.0
% INFO    : Bus 40488	: V=1.0178272, theta=-70.356897 -> V=1.0, theta=0.0
% INFO    : Bus 40489	: V=1.0176823, theta=-70.369234 -> V=1.0, theta=0.0
% INFO    : Bus 40490	: V=1.0182902, theta=-67.099504 -> V=1.0, theta=0.0
% INFO    : Bus 40491	: V=1.0128351, theta=-68.32051 -> V=1.0, theta=0.0
% INFO    : Bus 40492	: V=1.0268154, theta=-52.738865 -> V=1.0, theta=0.0
% INFO    : Bus 40493	: V=1.0266724, theta=-52.757207 -> V=1.0, theta=0.0
% INFO    : Bus 40494	: V=0.9952077, theta=-68.919901 -> V=1.0, theta=0.0
% INFO    : Bus 40495	: V=0.9978135, theta=-69.983554 -> V=1.0, theta=0.0
% INFO    : Bus 40496	: V=1.0081855, theta=-70.534779 -> V=1.0, theta=0.0
% INFO    : Bus 40497	: V=1.0065718, theta=-69.234171 -> V=1.0, theta=0.0
% INFO    : Bus 40498	: V=1.007424, theta=-68.229253 -> V=1.0, theta=0.0
% INFO    : Bus 40499	: V=1.0544329, theta=-45.961562 -> V=1.0, theta=0.0
% INFO    : Bus 40500	: V=1.0123315, theta=-68.579608 -> V=1.0, theta=0.0
% INFO    : Bus 40501	: V=1.0121375, theta=-68.616235 -> V=1.0, theta=0.0
% INFO    : Bus 40502	: V=1.0126155, theta=-68.570353 -> V=1.0, theta=0.0
% INFO    : Bus 40503	: V=1.0054428, theta=-69.513981 -> V=1.0, theta=0.0
% INFO    : Bus 40504	: V=1.011901, theta=-67.70584 -> V=1.0, theta=0.0
% INFO    : Bus 40505	: V=1.0044348, theta=-71.190373 -> V=1.0, theta=0.0
% INFO    : Bus 40506	: V=1.013281, theta=-65.241297 -> V=1.0, theta=0.0
% INFO    : Bus 40507	: V=1.0229334, theta=-64.961129 -> V=1.0, theta=0.0
% INFO    : Bus 40508	: V=1.0204187, theta=-66.462883 -> V=1.0, theta=0.0
% INFO    : Bus 40509	: V=1.0223517, theta=-65.043728 -> V=1.0, theta=0.0
% INFO    : Bus 40510	: V=1.0156996, theta=-67.836871 -> V=1.0, theta=0.0
% INFO    : Bus 40511	: V=1.0118767, theta=-70.30989 -> V=1.0, theta=0.0
% INFO    : Bus 40512	: V=1.0118767, theta=-70.30989 -> V=1.0, theta=0.0
% INFO    : Bus 40513	: V=1.023898, theta=-64.851343 -> V=1.0, theta=0.0
% INFO    : Bus 40514	: V=1.0223517, theta=-65.043728 -> V=1.0, theta=0.0
% INFO    : Bus 40515	: V=1.0219599, theta=-65.090422 -> V=1.0, theta=0.0
% INFO    : Bus 40516	: V=1.0128254, theta=-68.46541 -> V=1.0, theta=0.0
% INFO    : Bus 40517	: V=1.0241683, theta=-64.511946 -> V=1.0, theta=0.0
% INFO    : Bus 40518	: V=1.0179598, theta=-67.683442 -> V=1.0, theta=0.0
% INFO    : Bus 40519	: V=1.0012212, theta=-70.341061 -> V=1.0, theta=0.0
% INFO    : Bus 40520	: V=1.0313751, theta=-71.17158 -> V=1.0, theta=0.0
% INFO    : Bus 40521	: V=1.0054088, theta=-70.708644 -> V=1.0, theta=0.0
% INFO    : Bus 40522	: V=1.0056907, theta=-70.684354 -> V=1.0, theta=0.0
% INFO    : Bus 40523	: V=1.0083723, theta=-69.056531 -> V=1.0, theta=0.0
% INFO    : Bus 40524	: V=1.0081663, theta=-69.084174 -> V=1.0, theta=0.0
% INFO    : Bus 40525	: V=1.0075009, theta=-68.714092 -> V=1.0, theta=0.0
% INFO    : Bus 40526	: V=1.0161935, theta=-68.682944 -> V=1.0, theta=0.0
% INFO    : Bus 40527	: V=1.0191536, theta=-68.567681 -> V=1.0, theta=0.0
% INFO    : Bus 40528	: V=1.0086075, theta=-68.830123 -> V=1.0, theta=0.0
% INFO    : Bus 40529	: V=1.0115117, theta=-68.52809 -> V=1.0, theta=0.0
% INFO    : Bus 40530	: V=1.0064608, theta=-68.491155 -> V=1.0, theta=0.0
% INFO    : Bus 40531	: V=1.0061847, theta=-68.527665 -> V=1.0, theta=0.0
% INFO    : Bus 40532	: V=1.0067432, theta=-68.452911 -> V=1.0, theta=0.0
% INFO    : Bus 40533	: V=1.0046644, theta=-58.453888 -> V=1.0, theta=0.0
% INFO    : Bus 40534	: V=1.0206886, theta=-68.904752 -> V=1.0, theta=0.0
% INFO    : Bus 40535	: V=1.0207443, theta=-68.475309 -> V=1.0, theta=0.0
% INFO    : Bus 40536	: V=1.0205898, theta=-68.536585 -> V=1.0, theta=0.0
% INFO    : Bus 40537	: V=1.0185884, theta=-68.590723 -> V=1.0, theta=0.0
% INFO    : Bus 40538	: V=1.0090413, theta=-71.070775 -> V=1.0, theta=0.0
% INFO    : Bus 40539	: V=1.008809, theta=-71.112034 -> V=1.0, theta=0.0
% INFO    : Bus 40540	: V=1.0059859, theta=-69.104078 -> V=1.0, theta=0.0
% INFO    : Bus 40541	: V=1.007727, theta=-69.106555 -> V=1.0, theta=0.0
% INFO    : Bus 40542	: V=1.0075761, theta=-69.129757 -> V=1.0, theta=0.0
% INFO    : Bus 40543	: V=1.0362523, theta=-68.223392 -> V=1.0, theta=0.0
% INFO    : Bus 40544	: V=1.0152884, theta=-68.788573 -> V=1.0, theta=0.0
% INFO    : Bus 40545	: V=1.0150178, theta=-68.623951 -> V=1.0, theta=0.0
% INFO    : Bus 40546	: V=1.0147493, theta=-68.654042 -> V=1.0, theta=0.0
% INFO    : Bus 40547	: V=1.0152422, theta=-68.59311 -> V=1.0, theta=0.0
% INFO    : Bus 40548	: V=1.0150178, theta=-68.623951 -> V=1.0, theta=0.0
% INFO    : Bus 40549	: V=1.0124068, theta=-67.931905 -> V=1.0, theta=0.0
% INFO    : Bus 40550	: V=1.0139456, theta=-68.42332 -> V=1.0, theta=0.0
% INFO    : Bus 40551	: V=1.0138038, theta=-68.454361 -> V=1.0, theta=0.0
% INFO    : Bus 40552	: V=1.0086035, theta=-69.090058 -> V=1.0, theta=0.0
% INFO    : Bus 40553	: V=1.015487, theta=-68.057613 -> V=1.0, theta=0.0
% INFO    : Bus 40554	: V=1.0235972, theta=-64.779036 -> V=1.0, theta=0.0
% INFO    : Bus 40555	: V=1.0068048, theta=-68.517927 -> V=1.0, theta=0.0
% INFO    : Bus 40556	: V=0.9815537, theta=-74.637873 -> V=1.0, theta=0.0
% INFO    : Bus 40557	: V=1.0039653, theta=-69.455809 -> V=1.0, theta=0.0
% INFO    : Bus 40558	: V=1.0230852, theta=-68.285898 -> V=1.0, theta=0.0
% INFO    : Bus 40559	: V=1.0129529, theta=-68.967633 -> V=1.0, theta=0.0
% INFO    : Bus 40560	: V=1.0133444, theta=-68.93987 -> V=1.0, theta=0.0
% INFO    : Bus 40561	: V=0.9991822, theta=-69.158477 -> V=1.0, theta=0.0
% INFO    : Bus 40562	: V=1.0225575, theta=-64.92775 -> V=1.0, theta=0.0
% INFO    : Bus 40563	: V=1.0270689, theta=-68.150477 -> V=1.0, theta=0.0
% INFO    : Bus 40564	: V=1.0024926, theta=-68.959796 -> V=1.0, theta=0.0
% INFO    : Bus 40565	: V=1.048916, theta=-47.47355 -> V=1.0, theta=0.0
% INFO    : Bus 40566	: V=1.0071226, theta=-70.031445 -> V=1.0, theta=0.0
% INFO    : Bus 40567	: V=1.0070366, theta=-70.03785 -> V=1.0, theta=0.0
% INFO    : Bus 40568	: V=1.0072127, theta=-70.024713 -> V=1.0, theta=0.0
% INFO    : Bus 40569	: V=1.0155209, theta=-69.911024 -> V=1.0, theta=0.0
% INFO    : Bus 40570	: V=1.0018211, theta=-68.614544 -> V=1.0, theta=0.0
% INFO    : Bus 40571	: V=1.010045, theta=-69.10723 -> V=1.0, theta=0.0
% INFO    : Bus 40572	: V=1.0189841, theta=-69.272785 -> V=1.0, theta=0.0
% INFO    : Bus 40573	: V=1.0192579, theta=-69.23738 -> V=1.0, theta=0.0
% INFO    : Bus 40574	: V=1.0186777, theta=-68.638505 -> V=1.0, theta=0.0
% INFO    : Bus 40575	: V=1.0053993, theta=-68.668997 -> V=1.0, theta=0.0
% INFO    : Bus 40576	: V=1.0181032, theta=-54.021687 -> V=1.0, theta=0.0
% INFO    : Bus 40577	: V=1.0180804, theta=-54.023892 -> V=1.0, theta=0.0
% INFO    : Bus 40578	: V=1.0181291, theta=-54.019573 -> V=1.0, theta=0.0
% INFO    : Bus 40579	: V=1.012109, theta=-69.734213 -> V=1.0, theta=0.0
% INFO    : Bus 40580	: V=1.02078, theta=-69.940825 -> V=1.0, theta=0.0
% INFO    : Bus 40581	: V=1.0231842, theta=-55.877699 -> V=1.0, theta=0.0
% INFO    : Bus 40582	: V=1.0233313, theta=-55.848856 -> V=1.0, theta=0.0
% INFO    : Bus 40583	: V=1.023023, theta=-55.905576 -> V=1.0, theta=0.0
% INFO    : Bus 40584	: V=1.0188556, theta=-70.298675 -> V=1.0, theta=0.0
% INFO    : Bus 40585	: V=1.0191933, theta=-70.260156 -> V=1.0, theta=0.0
% INFO    : Bus 40586	: V=1.018542, theta=-70.336888 -> V=1.0, theta=0.0
% INFO    : Bus 40587	: V=1.043512, theta=-48.976501 -> V=1.0, theta=0.0
% INFO    : Bus 40588	: V=1.0435448, theta=-48.973397 -> V=1.0, theta=0.0
% INFO    : Bus 40589	: V=1.043479, theta=-48.979701 -> V=1.0, theta=0.0
% INFO    : Bus 40590	: V=1.043512, theta=-48.976501 -> V=1.0, theta=0.0
% INFO    : Bus 40591	: V=1.0141811, theta=-70.903174 -> V=1.0, theta=0.0
% INFO    : Bus 40592	: V=1.0109069, theta=-55.07132 -> V=1.0, theta=0.0
% INFO    : Bus 40593	: V=1.0092587, theta=-54.50372 -> V=1.0, theta=0.0
% INFO    : Bus 40594	: V=1.021512, theta=-56.991303 -> V=1.0, theta=0.0
% INFO    : Bus 40595	: V=1.0214302, theta=-56.999327 -> V=1.0, theta=0.0
% INFO    : Bus 40596	: V=1.0215914, theta=-56.983313 -> V=1.0, theta=0.0
% INFO    : Bus 40597	: V=1.0111668, theta=-67.703386 -> V=1.0, theta=0.0
% INFO    : Bus 40598	: V=1.0070544, theta=-69.764326 -> V=1.0, theta=0.0
% INFO    : Bus 40599	: V=1.0323392, theta=-68.44407 -> V=1.0, theta=0.0
% INFO    : Bus 40600	: V=1.0221296, theta=-56.364584 -> V=1.0, theta=0.0
% INFO    : Bus 40601	: V=1.0221642, theta=-56.361779 -> V=1.0, theta=0.0
% INFO    : Bus 40602	: V=1.0157587, theta=-51.796546 -> V=1.0, theta=0.0
% INFO    : Bus 40603	: V=1.024129, theta=-69.285316 -> V=1.0, theta=0.0
% INFO    : Bus 40604	: V=1.0242201, theta=-69.274417 -> V=1.0, theta=0.0
% INFO    : Bus 40605	: V=1.0087985, theta=-67.461174 -> V=1.0, theta=0.0
% INFO    : Bus 40606	: V=1.0087194, theta=-67.466905 -> V=1.0, theta=0.0
% INFO    : Bus 40607	: V=1.0273202, theta=-54.745378 -> V=1.0, theta=0.0
% INFO    : Bus 40608	: V=1.027286, theta=-54.748074 -> V=1.0, theta=0.0
% INFO    : Bus 40609	: V=1.0273559, theta=-54.742964 -> V=1.0, theta=0.0
% INFO    : Bus 40610	: V=1.0057894, theta=-53.514957 -> V=1.0, theta=0.0
% INFO    : Bus 40611	: V=1.0017791, theta=-54.460411 -> V=1.0, theta=0.0
% INFO    : Bus 40612	: V=1.0054957, theta=-53.581827 -> V=1.0, theta=0.0
% INFO    : Bus 40613	: V=1.0054957, theta=-53.581827 -> V=1.0, theta=0.0
% INFO    : Bus 40614	: V=1.0070216, theta=-53.092946 -> V=1.0, theta=0.0
% INFO    : Bus 40615	: V=1.0277499, theta=-69.137301 -> V=1.0, theta=0.0
% INFO    : Bus 40616	: V=1.0242622, theta=-69.254785 -> V=1.0, theta=0.0
% INFO    : Bus 40617	: V=1.0085053, theta=-67.148761 -> V=1.0, theta=0.0
% INFO    : Bus 40618	: V=1.0084754, theta=-67.152079 -> V=1.0, theta=0.0
% INFO    : Bus 40619	: V=1.0085349, theta=-67.144955 -> V=1.0, theta=0.0
% INFO    : Bus 40620	: V=1.0308853, theta=-66.899738 -> V=1.0, theta=0.0
% INFO    : Bus 40621	: V=1.0308249, theta=-66.905901 -> V=1.0, theta=0.0
% INFO    : Bus 40622	: V=1.0365783, theta=-68.196335 -> V=1.0, theta=0.0
% INFO    : Bus 40623	: V=1.0101028, theta=-65.898081 -> V=1.0, theta=0.0
% INFO    : Bus 40624	: V=1.0461279, theta=-67.793228 -> V=1.0, theta=0.0
% INFO    : Bus 40625	: V=1.0461279, theta=-67.793228 -> V=1.0, theta=0.0
% INFO    : Bus 40626	: V=1.0461279, theta=-67.793228 -> V=1.0, theta=0.0
% INFO    : Bus 40627	: V=1.0461279, theta=-67.793228 -> V=1.0, theta=0.0
% INFO    : Bus 40628	: V=1.0089699, theta=-54.137157 -> V=1.0, theta=0.0
% INFO    : Bus 40629	: V=1.023533, theta=-54.816591 -> V=1.0, theta=0.0
% INFO    : Bus 40630	: V=1.0232277, theta=-55.16794 -> V=1.0, theta=0.0
% INFO    : Bus 40631	: V=1.014814, theta=-54.856522 -> V=1.0, theta=0.0
% INFO    : Bus 40632	: V=1.0159758, theta=-54.874026 -> V=1.0, theta=0.0
% INFO    : Bus 40633	: V=1.0148118, theta=-54.856851 -> V=1.0, theta=0.0
% INFO    : Bus 40634	: V=1.0240101, theta=-54.555325 -> V=1.0, theta=0.0
% INFO    : Bus 40635	: V=1.023986, theta=-54.558758 -> V=1.0, theta=0.0
% INFO    : Bus 40636	: V=1.0294101, theta=-66.104259 -> V=1.0, theta=0.0
% INFO    : Bus 40637	: V=1.0293771, theta=-66.107753 -> V=1.0, theta=0.0
% INFO    : Bus 40638	: V=1.0294455, theta=-66.10082 -> V=1.0, theta=0.0
% INFO    : Bus 40639	: V=1.0078877, theta=-60.693076 -> V=1.0, theta=0.0
% INFO    : Bus 40640	: V=1.0078856, theta=-66.805775 -> V=1.0, theta=0.0
% INFO    : Bus 40641	: V=1.0077873, theta=-66.812731 -> V=1.0, theta=0.0
% INFO    : Bus 40642	: V=0.9908069, theta=-63.897554 -> V=1.0, theta=0.0
% INFO    : Bus 40643	: V=1.0106482, theta=-67.37626 -> V=1.0, theta=0.0
% INFO    : Bus 40644	: V=1.0072306, theta=-60.195938 -> V=1.0, theta=0.0
% INFO    : Bus 40645	: V=1.0100536, theta=-51.585216 -> V=1.0, theta=0.0
% INFO    : Bus 40646	: V=1.010017, theta=-51.587915 -> V=1.0, theta=0.0
% INFO    : Bus 40647	: V=1.0293653, theta=-68.312411 -> V=1.0, theta=0.0
% INFO    : Bus 40648	: V=1.0108578, theta=-59.183066 -> V=1.0, theta=0.0
% INFO    : Bus 40649	: V=1.0109391, theta=-59.172224 -> V=1.0, theta=0.0
% INFO    : Bus 40650	: V=1.0203413, theta=-49.977129 -> V=1.0, theta=0.0
% INFO    : Bus 40651	: V=1.0203102, theta=-49.980104 -> V=1.0, theta=0.0
% INFO    : Bus 40652	: V=1.0137465, theta=-65.074229 -> V=1.0, theta=0.0
% INFO    : Bus 40653	: V=1.0138427, theta=-65.062456 -> V=1.0, theta=0.0
% INFO    : Bus 40654	: V=1.010721, theta=-52.327462 -> V=1.0, theta=0.0
% INFO    : Bus 40655	: V=1.0141609, theta=-47.576035 -> V=1.0, theta=0.0
% INFO    : Bus 40656	: V=1.0164701, theta=-49.024478 -> V=1.0, theta=0.0
% INFO    : Bus 40657	: V=1.0201369, theta=-56.163506 -> V=1.0, theta=0.0
% INFO    : Bus 40658	: V=1.0203101, theta=-57.314968 -> V=1.0, theta=0.0
% INFO    : Bus 40659	: V=1.0286979, theta=-65.705917 -> V=1.0, theta=0.0
% INFO    : Bus 40660	: V=1.0287594, theta=-65.699211 -> V=1.0, theta=0.0
% INFO    : Bus 40661	: V=1.0195105, theta=-50.531745 -> V=1.0, theta=0.0
% INFO    : Bus 40662	: V=1.0202643, theta=-50.454577 -> V=1.0, theta=0.0
% INFO    : Bus 40663	: V=1.0219019, theta=-54.269441 -> V=1.0, theta=0.0
% INFO    : Bus 40664	: V=1.0196423, theta=-61.831431 -> V=1.0, theta=0.0
% INFO    : Bus 40665	: V=1.0215683, theta=-62.496011 -> V=1.0, theta=0.0
% INFO    : Bus 40666	: V=1.0143202, theta=-64.316647 -> V=1.0, theta=0.0
% INFO    : Bus 40667	: V=1.015841, theta=-65.140279 -> V=1.0, theta=0.0
% INFO    : Bus 40668	: V=1.0197503, theta=-60.435604 -> V=1.0, theta=0.0
% INFO    : Bus 40669	: V=1.0204396, theta=-60.898098 -> V=1.0, theta=0.0
% INFO    : Bus 40670	: V=1.0206409, theta=-61.025189 -> V=1.0, theta=0.0
% INFO    : Bus 40671	: V=1.0206409, theta=-61.025189 -> V=1.0, theta=0.0
% INFO    : Bus 40672	: V=1.0276648, theta=-53.68006 -> V=1.0, theta=0.0
% INFO    : Bus 40673	: V=1.027641, theta=-53.684471 -> V=1.0, theta=0.0
% INFO    : Bus 40674	: V=1.0232512, theta=-49.766565 -> V=1.0, theta=0.0
% INFO    : Bus 40675	: V=1.0180467, theta=-56.786885 -> V=1.0, theta=0.0
% INFO    : Bus 40676	: V=1.0179962, theta=-56.79701 -> V=1.0, theta=0.0
% INFO    : Bus 40677	: V=1.0357409, theta=-51.504522 -> V=1.0, theta=0.0
% INFO    : Bus 40678	: V=1.0356565, theta=-51.511121 -> V=1.0, theta=0.0
% INFO    : Bus 40679	: V=1.0358274, theta=-51.497473 -> V=1.0, theta=0.0
% INFO    : Bus 40680	: V=1.0281226, theta=-47.451186 -> V=1.0, theta=0.0
% INFO    : Bus 40681	: V=1.0281544, theta=-47.447044 -> V=1.0, theta=0.0
% INFO    : Bus 40682	: V=1.0257286, theta=-47.929281 -> V=1.0, theta=0.0
% INFO    : Bus 40683	: V=1.0211039, theta=-54.266055 -> V=1.0, theta=0.0
% INFO    : Bus 40684	: V=1.0211452, theta=-54.26215 -> V=1.0, theta=0.0
% INFO    : Bus 40685	: V=1.0189776, theta=-54.458551 -> V=1.0, theta=0.0
% INFO    : Bus 40686	: V=1.0086474, theta=-54.772808 -> V=1.0, theta=0.0
% INFO    : Bus 40687	: V=1.0293487, theta=-46.943511 -> V=1.0, theta=0.0
% INFO    : Bus 40688	: V=1.0233239, theta=-61.673599 -> V=1.0, theta=0.0
% INFO    : Bus 40689	: V=1.0103334, theta=-50.819811 -> V=1.0, theta=0.0
% INFO    : Bus 40690	: V=1.0130552, theta=-51.198047 -> V=1.0, theta=0.0
% INFO    : Bus 40691	: V=1.0130252, theta=-51.202737 -> V=1.0, theta=0.0
% INFO    : Bus 40692	: V=1.0093516, theta=-53.688543 -> V=1.0, theta=0.0
% INFO    : Bus 40693	: V=1.0254399, theta=-62.689523 -> V=1.0, theta=0.0
% INFO    : Bus 40694	: V=1.0223011, theta=-64.814661 -> V=1.0, theta=0.0
% INFO    : Bus 40695	: V=0.9927307, theta=-61.529586 -> V=1.0, theta=0.0
% INFO    : Bus 40696	: V=1.0254399, theta=-62.689523 -> V=1.0, theta=0.0
% INFO    : Bus 40697	: V=0.9938165, theta=-62.088201 -> V=1.0, theta=0.0
% INFO    : Bus 40698	: V=1.022567, theta=-60.813549 -> V=1.0, theta=0.0
% INFO    : Bus 40699	: V=1.0232913, theta=-61.089001 -> V=1.0, theta=0.0
% INFO    : Bus 40700	: V=1.0226571, theta=-60.066227 -> V=1.0, theta=0.0
% INFO    : Bus 40701	: V=1.0226653, theta=-60.400451 -> V=1.0, theta=0.0
% INFO    : Bus 40702	: V=1.0226474, theta=-59.770734 -> V=1.0, theta=0.0
% INFO    : Bus 40703	: V=1.0473876, theta=-62.853901 -> V=1.0, theta=0.0
% INFO    : Bus 40704	: V=1.0162765, theta=-66.11856 -> V=1.0, theta=0.0
% INFO    : Bus 40705	: V=1.051627, theta=-66.696662 -> V=1.0, theta=0.0
% INFO    : Bus 40706	: V=1.0250121, theta=-65.869361 -> V=1.0, theta=0.0
% INFO    : Bus 40707	: V=1.03338, theta=-65.671121 -> V=1.0, theta=0.0
% INFO    : Bus 40708	: V=1.0213813, theta=-67.193073 -> V=1.0, theta=0.0
% INFO    : Bus 40709	: V=1.0258711, theta=-65.979436 -> V=1.0, theta=0.0
% INFO    : Bus 40710	: V=1.0258711, theta=-65.979436 -> V=1.0, theta=0.0
% INFO    : Bus 40711	: V=1.0275473, theta=-67.046849 -> V=1.0, theta=0.0
% INFO    : Bus 40712	: V=0.9955296, theta=-65.56396 -> V=1.0, theta=0.0
% INFO    : Bus 40713	: V=0.9951902, theta=-65.560826 -> V=1.0, theta=0.0
% INFO    : Bus 40714	: V=0.995625, theta=-65.580183 -> V=1.0, theta=0.0
% INFO    : Bus 40715	: V=1.0169819, theta=-62.506942 -> V=1.0, theta=0.0
% INFO    : Bus 40716	: V=1.0145327, theta=-62.936328 -> V=1.0, theta=0.0
% INFO    : Bus 40717	: V=1.0157397, theta=-62.723206 -> V=1.0, theta=0.0
% INFO    : Bus 40718	: V=1.0157397, theta=-62.723206 -> V=1.0, theta=0.0
% INFO    : Bus 40719	: V=1.0011733, theta=-68.016353 -> V=1.0, theta=0.0
% INFO    : Bus 40720	: V=1.0157456, theta=-58.719828 -> V=1.0, theta=0.0
% INFO    : Bus 40721	: V=1.0229726, theta=-55.773344 -> V=1.0, theta=0.0
% INFO    : Bus 40722	: V=1.0464688, theta=-65.431625 -> V=1.0, theta=0.0
% INFO    : Bus 40723	: V=1.0367932, theta=-64.664092 -> V=1.0, theta=0.0
% INFO    : Bus 40724	: V=1.0348104, theta=-66.932176 -> V=1.0, theta=0.0
% INFO    : Bus 40725	: V=1.0255342, theta=-69.868574 -> V=1.0, theta=0.0
% INFO    : Bus 40726	: V=1.035608, theta=-66.884376 -> V=1.0, theta=0.0
% INFO    : Bus 40727	: V=1.0188498, theta=-66.841056 -> V=1.0, theta=0.0
% INFO    : Bus 40728	: V=1.0188498, theta=-66.841056 -> V=1.0, theta=0.0
% INFO    : Bus 40729	: V=1.02753, theta=-60.261331 -> V=1.0, theta=0.0
% INFO    : Bus 40730	: V=1.0290747, theta=-61.220026 -> V=1.0, theta=0.0
% INFO    : Bus 40731	: V=1.030745, theta=-64.056315 -> V=1.0, theta=0.0
% INFO    : Bus 40732	: V=0.9922739, theta=-59.644021 -> V=1.0, theta=0.0
% INFO    : Bus 40733	: V=0.9922712, theta=-59.583302 -> V=1.0, theta=0.0
% INFO    : Bus 40734	: V=1.02753, theta=-60.261331 -> V=1.0, theta=0.0
% INFO    : Bus 40735	: V=0.9980395, theta=-59.691585 -> V=1.0, theta=0.0
% INFO    : Bus 40736	: V=0.9934834, theta=-58.964731 -> V=1.0, theta=0.0
% INFO    : Bus 40737	: V=1.0259522, theta=-62.179517 -> V=1.0, theta=0.0
% INFO    : Bus 40738	: V=1.005928, theta=-66.647521 -> V=1.0, theta=0.0
% INFO    : Bus 40739	: V=1.0259522, theta=-62.179517 -> V=1.0, theta=0.0
% INFO    : Bus 40740	: V=1.0116245, theta=-61.681581 -> V=1.0, theta=0.0
% INFO    : Bus 40741	: V=1.0259522, theta=-62.179517 -> V=1.0, theta=0.0
% INFO    : Bus 40742	: V=1.0094077, theta=-61.249173 -> V=1.0, theta=0.0
% INFO    : Bus 40743	: V=1.0121297, theta=-61.628223 -> V=1.0, theta=0.0
% INFO    : Bus 40744	: V=1.010177, theta=-61.165874 -> V=1.0, theta=0.0
% INFO    : Bus 40745	: V=1.0102066, theta=-61.840808 -> V=1.0, theta=0.0
% INFO    : Bus 40746	: V=1.025689, theta=-62.097687 -> V=1.0, theta=0.0
% INFO    : Bus 40747	: V=1.0340064, theta=-68.259338 -> V=1.0, theta=0.0
% INFO    : Bus 40748	: V=1.0339717, theta=-68.267646 -> V=1.0, theta=0.0
% INFO    : Bus 40749	: V=0.9938532, theta=-70.138051 -> V=1.0, theta=0.0
% INFO    : Bus 40750	: V=0.9938532, theta=-70.138051 -> V=1.0, theta=0.0
% INFO    : Bus 40751	: V=1.0470423, theta=-63.766679 -> V=1.0, theta=0.0
% INFO    : Bus 40752	: V=1.0374032, theta=-61.871819 -> V=1.0, theta=0.0
% INFO    : Bus 40753	: V=1.0599384, theta=-62.454607 -> V=1.0, theta=0.0
% INFO    : Bus 40754	: V=1.0264155, theta=-59.310218 -> V=1.0, theta=0.0
% INFO    : Bus 40755	: V=1.0264155, theta=-59.310218 -> V=1.0, theta=0.0
% INFO    : Bus 40756	: V=1.0198028, theta=-63.381176 -> V=1.0, theta=0.0
% INFO    : Bus 40757	: V=1.0470423, theta=-63.766679 -> V=1.0, theta=0.0
% INFO    : Bus 40758	: V=1.0185763, theta=-63.038024 -> V=1.0, theta=0.0
% INFO    : Bus 40759	: V=1.0479353, theta=-64.345818 -> V=1.0, theta=0.0
% INFO    : Bus 40760	: V=1.0224008, theta=-48.453362 -> V=1.0, theta=0.0
% INFO    : Bus 40761	: V=1.0372999, theta=-50.416671 -> V=1.0, theta=0.0
% INFO    : Bus 40762	: V=1.0369176, theta=-51.263722 -> V=1.0, theta=0.0
% INFO    : Bus 40763	: V=0.9982505, theta=-47.721189 -> V=1.0, theta=0.0
% INFO    : Bus 40764	: V=0.9987605, theta=-47.505135 -> V=1.0, theta=0.0
% INFO    : Bus 40765	: V=1.02, theta=-61.243397 -> V=1.0, theta=0.0
% INFO    : Bus 40766	: V=1.0281536, theta=-62.215516 -> V=1.0, theta=0.0
% INFO    : Bus 40767	: V=1.0296838, theta=-63.642102 -> V=1.0, theta=0.0
% INFO    : Bus 40768	: V=1.0247122, theta=-61.061135 -> V=1.0, theta=0.0
% INFO    : Bus 40769	: V=1.0238434, theta=-60.353799 -> V=1.0, theta=0.0
% INFO    : Bus 40770	: V=1.0232443, theta=-60.862059 -> V=1.0, theta=0.0
% INFO    : Bus 40771	: V=1.02, theta=-61.243397 -> V=1.0, theta=0.0
% INFO    : Bus 40772	: V=1.0239728, theta=-60.777235 -> V=1.0, theta=0.0
% INFO    : Bus 40773	: V=1.02, theta=-61.243397 -> V=1.0, theta=0.0
% INFO    : Bus 40774	: V=1.0120035, theta=-67.813367 -> V=1.0, theta=0.0
% INFO    : Bus 40775	: V=1.0153835, theta=-66.403256 -> V=1.0, theta=0.0
% INFO    : Bus 40776	: V=1.0153359, theta=-66.405945 -> V=1.0, theta=0.0
% INFO    : Bus 40777	: V=1.0334967, theta=-59.07053 -> V=1.0, theta=0.0
% INFO    : Bus 40778	: V=1.0325858, theta=-53.359842 -> V=1.0, theta=0.0
% INFO    : Bus 40779	: V=1.0336942, theta=-55.259937 -> V=1.0, theta=0.0
% INFO    : Bus 40780	: V=1.0341848, theta=-57.181601 -> V=1.0, theta=0.0
% INFO    : Bus 40781	: V=1.0332871, theta=-59.140493 -> V=1.0, theta=0.0
% INFO    : Bus 40782	: V=1.0319712, theta=-54.696702 -> V=1.0, theta=0.0
% INFO    : Bus 40783	: V=1.02, theta=-41.991641 -> V=1.0, theta=0.0
% INFO    : Bus 40784	: V=1.0584821, theta=-43.011527 -> V=1.0, theta=0.0
% INFO    : Bus 40785	: V=1.0605229, theta=-43.868867 -> V=1.0, theta=0.0
% INFO    : Bus 40786	: V=1.0024863, theta=-39.599951 -> V=1.0, theta=0.0
% INFO    : Bus 40787	: V=1.0010688, theta=-37.217208 -> V=1.0, theta=0.0
% INFO    : Bus 40788	: V=1.0026233, theta=-40.917755 -> V=1.0, theta=0.0
% INFO    : Bus 40789	: V=1.0538826, theta=-43.238737 -> V=1.0, theta=0.0
% INFO    : Bus 40790	: V=1.0159561, theta=-58.599072 -> V=1.0, theta=0.0
% INFO    : Bus 40791	: V=1.0159234, theta=-58.607127 -> V=1.0, theta=0.0
% INFO    : Bus 40792	: V=1.0159561, theta=-58.599072 -> V=1.0, theta=0.0
% INFO    : Bus 40793	: V=1.0348574, theta=-59.094818 -> V=1.0, theta=0.0
% INFO    : Bus 40794	: V=1.02704, theta=-57.768121 -> V=1.0, theta=0.0
% INFO    : Bus 40795	: V=1.0129266, theta=-62.324253 -> V=1.0, theta=0.0
% INFO    : Bus 40796	: V=1.012673, theta=-66.338556 -> V=1.0, theta=0.0
% INFO    : Bus 40797	: V=1.0266292, theta=-57.493265 -> V=1.0, theta=0.0
% INFO    : Bus 40798	: V=1.0266331, theta=-57.389124 -> V=1.0, theta=0.0
% INFO    : Bus 40799	: V=1.02704, theta=-57.768121 -> V=1.0, theta=0.0
% INFO    : Bus 40800	: V=1.02704, theta=-57.768121 -> V=1.0, theta=0.0
% INFO    : Bus 40801	: V=1.0267678, theta=-57.427544 -> V=1.0, theta=0.0
% INFO    : Bus 40802	: V=1.0265188, theta=-56.775451 -> V=1.0, theta=0.0
% INFO    : Bus 40803	: V=1.0264813, theta=-57.46465 -> V=1.0, theta=0.0
% INFO    : Bus 40804	: V=1.0265347, theta=-57.491724 -> V=1.0, theta=0.0
% INFO    : Bus 40805	: V=1.0233732, theta=-63.90912 -> V=1.0, theta=0.0
% INFO    : Bus 40806	: V=1.0173363, theta=-66.925248 -> V=1.0, theta=0.0
% INFO    : Bus 40807	: V=0.9964889, theta=-67.327981 -> V=1.0, theta=0.0
% INFO    : Bus 40808	: V=1.0430712, theta=-65.665223 -> V=1.0, theta=0.0
% INFO    : Bus 40809	: V=1.014789, theta=-62.879618 -> V=1.0, theta=0.0
% INFO    : Bus 40810	: V=1.0176895, theta=-66.795596 -> V=1.0, theta=0.0
% INFO    : Bus 40811	: V=1.0152556, theta=-64.23735 -> V=1.0, theta=0.0
% INFO    : Bus 40812	: V=1.0152556, theta=-64.23735 -> V=1.0, theta=0.0
% INFO    : Bus 40813	: V=0.999854, theta=-61.78614 -> V=1.0, theta=0.0
% INFO    : Bus 40814	: V=0.9982545, theta=-61.96304 -> V=1.0, theta=0.0
% INFO    : Bus 40815	: V=0.9963306, theta=-61.491244 -> V=1.0, theta=0.0
% INFO    : Bus 40816	: V=0.9953906, theta=-61.618179 -> V=1.0, theta=0.0
% INFO    : Bus 40817	: V=0.9975715, theta=-62.040761 -> V=1.0, theta=0.0
% INFO    : Bus 40818	: V=0.997159, theta=-61.391511 -> V=1.0, theta=0.0
% INFO    : Bus 40819	: V=1.02214, theta=-58.874856 -> V=1.0, theta=0.0
% INFO    : Bus 40820	: V=1.0231674, theta=-61.01928 -> V=1.0, theta=0.0
% INFO    : Bus 40821	: V=1.0239066, theta=-62.880657 -> V=1.0, theta=0.0
% INFO    : Bus 40822	: V=1.0232823, theta=-61.156766 -> V=1.0, theta=0.0
% INFO    : Bus 40823	: V=1.0232823, theta=-61.156766 -> V=1.0, theta=0.0
% INFO    : Bus 40824	: V=1.0233051, theta=-58.787565 -> V=1.0, theta=0.0
% INFO    : Bus 40825	: V=1.0234757, theta=-58.135035 -> V=1.0, theta=0.0
% INFO    : Bus 40826	: V=1.0233046, theta=-58.222878 -> V=1.0, theta=0.0
% INFO    : Bus 40827	: V=1.0231832, theta=-58.294577 -> V=1.0, theta=0.0
% INFO    : Bus 40828	: V=1.0232723, theta=-58.25951 -> V=1.0, theta=0.0
% INFO    : Bus 40829	: V=1.0235685, theta=-58.051883 -> V=1.0, theta=0.0
% INFO    : Bus 40830	: V=1.0264896, theta=-58.914088 -> V=1.0, theta=0.0
% INFO    : Bus 40831	: V=1.0232601, theta=-61.230028 -> V=1.0, theta=0.0
% INFO    : Bus 40832	: V=1.0439695, theta=-63.481414 -> V=1.0, theta=0.0
% INFO    : Bus 40833	: V=1.0449142, theta=-61.299491 -> V=1.0, theta=0.0
% INFO    : Bus 40834	: V=0.9963797, theta=-65.740298 -> V=1.0, theta=0.0
% INFO    : Bus 40835	: V=1.0359303, theta=-58.690216 -> V=1.0, theta=0.0
% INFO    : Bus 40836	: V=1.0359303, theta=-58.690216 -> V=1.0, theta=0.0
% INFO    : Bus 40837	: V=1.030327, theta=-55.599844 -> V=1.0, theta=0.0
% INFO    : Bus 40838	: V=1.0347481, theta=-53.986505 -> V=1.0, theta=0.0
% INFO    : Bus 40839	: V=1.0358702, theta=-58.949588 -> V=1.0, theta=0.0
% INFO    : Bus 40840	: V=1.0361854, theta=-55.437763 -> V=1.0, theta=0.0
% INFO    : Bus 40841	: V=1.0339665, theta=-60.124495 -> V=1.0, theta=0.0
% INFO    : Bus 40842	: V=1.0374451, theta=-61.56922 -> V=1.0, theta=0.0
% INFO    : Bus 40843	: V=1.0648015, theta=-50.83737 -> V=1.0, theta=0.0
% INFO    : Bus 40844	: V=1.0626328, theta=-51.225457 -> V=1.0, theta=0.0
% INFO    : Bus 40845	: V=1.043, theta=-49.407065 -> V=1.0, theta=0.0
% INFO    : Bus 40846	: V=1.0341546, theta=-56.579091 -> V=1.0, theta=0.0
% INFO    : Bus 40847	: V=1.0242259, theta=-60.027769 -> V=1.0, theta=0.0
% INFO    : Bus 40848	: V=1.0271847, theta=-59.863537 -> V=1.0, theta=0.0
% INFO    : Bus 40849	: V=1.0243508, theta=-58.915479 -> V=1.0, theta=0.0
% INFO    : Bus 40850	: V=1.0242259, theta=-60.027769 -> V=1.0, theta=0.0
% INFO    : Bus 40851	: V=1.025941, theta=-62.101914 -> V=1.0, theta=0.0
% INFO    : Bus 40852	: V=1.0309536, theta=-63.624626 -> V=1.0, theta=0.0
% INFO    : Bus 40853	: V=1.0259955, theta=-67.942136 -> V=1.0, theta=0.0
% INFO    : Bus 40854	: V=1.0339796, theta=-61.158382 -> V=1.0, theta=0.0
% INFO    : Bus 40855	: V=1.0320683, theta=-61.38607 -> V=1.0, theta=0.0
% INFO    : Bus 40856	: V=1.0311826, theta=-61.48973 -> V=1.0, theta=0.0
% INFO    : Bus 40857	: V=1.0299341, theta=-61.63481 -> V=1.0, theta=0.0
% INFO    : Bus 40858	: V=1.0275802, theta=-61.912555 -> V=1.0, theta=0.0
% INFO    : Bus 40859	: V=0.987178, theta=-63.333847 -> V=1.0, theta=0.0
% INFO    : Bus 40860	: V=1.0257003, theta=-64.346398 -> V=1.0, theta=0.0
% INFO    : Bus 40861	: V=1.0216269, theta=-70.48504 -> V=1.0, theta=0.0
% INFO    : Bus 40862	: V=1.0186946, theta=-66.805407 -> V=1.0, theta=0.0
% INFO    : Bus 40863	: V=1.0232279, theta=-61.408631 -> V=1.0, theta=0.0
% INFO    : Bus 40864	: V=1.0186317, theta=-66.810135 -> V=1.0, theta=0.0
% INFO    : Bus 40865	: V=1.0204577, theta=-67.710522 -> V=1.0, theta=0.0
% INFO    : Bus 40866	: V=1.0216971, theta=-61.09304 -> V=1.0, theta=0.0
% INFO    : Bus 40867	: V=1.0210984, theta=-63.058849 -> V=1.0, theta=0.0
% INFO    : Bus 40868	: V=1.0204609, theta=-60.40987 -> V=1.0, theta=0.0
% INFO    : Bus 40869	: V=1.0184208, theta=-59.678971 -> V=1.0, theta=0.0
% INFO    : Bus 40870	: V=1.018336, theta=-59.408737 -> V=1.0, theta=0.0
% INFO    : Bus 40871	: V=1.0146906, theta=-68.301895 -> V=1.0, theta=0.0
% INFO    : Bus 40872	: V=1.0035719, theta=-66.201508 -> V=1.0, theta=0.0
% INFO    : Bus 40873	: V=1.0042932, theta=-62.296938 -> V=1.0, theta=0.0
% INFO    : Bus 40874	: V=1.0035412, theta=-66.214521 -> V=1.0, theta=0.0
% INFO    : Bus 40875	: V=1.02018, theta=-47.460855 -> V=1.0, theta=0.0
% INFO    : Bus 40876	: V=1.0345612, theta=-50.707566 -> V=1.0, theta=0.0
% INFO    : Bus 40877	: V=1.0345447, theta=-51.484012 -> V=1.0, theta=0.0
% INFO    : Bus 40878	: V=1.0060285, theta=-45.101993 -> V=1.0, theta=0.0
% INFO    : Bus 40879	: V=1.02018, theta=-47.460855 -> V=1.0, theta=0.0
% INFO    : Bus 40880	: V=1.004869, theta=-46.37856 -> V=1.0, theta=0.0
% INFO    : Bus 40881	: V=1.005565, theta=-45.393182 -> V=1.0, theta=0.0
% INFO    : Bus 40882	: V=1.0204401, theta=-47.796182 -> V=1.0, theta=0.0
% INFO    : Bus 40883	: V=1.0170167, theta=-57.895381 -> V=1.0, theta=0.0
% INFO    : Bus 40884	: V=1.0102735, theta=-56.679112 -> V=1.0, theta=0.0
% INFO    : Bus 40885	: V=1.0064698, theta=-54.135055 -> V=1.0, theta=0.0
% INFO    : Bus 40886	: V=1.0067855, theta=-55.209814 -> V=1.0, theta=0.0
% INFO    : Bus 40887	: V=1.00079, theta=-51.42872 -> V=1.0, theta=0.0
% INFO    : Bus 40888	: V=1.0076026, theta=-55.618694 -> V=1.0, theta=0.0
% INFO    : Bus 40889	: V=1.0075149, theta=-55.362195 -> V=1.0, theta=0.0
% INFO    : Bus 40890	: V=1.02312, theta=-61.231573 -> V=1.0, theta=0.0
% INFO    : Bus 40891	: V=1.018721, theta=-63.066974 -> V=1.0, theta=0.0
% INFO    : Bus 40892	: V=1.0264803, theta=-60.549309 -> V=1.0, theta=0.0
% INFO    : Bus 40893	: V=1.0281522, theta=-60.198093 -> V=1.0, theta=0.0
% INFO    : Bus 40894	: V=1.0266903, theta=-60.505137 -> V=1.0, theta=0.0
% INFO    : Bus 40895	: V=1.0259719, theta=-60.655567 -> V=1.0, theta=0.0
% INFO    : Bus 40896	: V=1.0267827, theta=-60.495956 -> V=1.0, theta=0.0
% INFO    : Bus 40897	: V=1.0263576, theta=-60.574965 -> V=1.0, theta=0.0
% INFO    : Bus 40898	: V=1.02116, theta=-58.134621 -> V=1.0, theta=0.0
% INFO    : Bus 40899	: V=1.0247157, theta=-61.673995 -> V=1.0, theta=0.0
% INFO    : Bus 40900	: V=1.0067077, theta=-67.437279 -> V=1.0, theta=0.0
% INFO    : Bus 40901	: V=1.0013927, theta=-70.561014 -> V=1.0, theta=0.0
% INFO    : Bus 40902	: V=1.0013927, theta=-70.561014 -> V=1.0, theta=0.0
% INFO    : Bus 40903	: V=1.0374579, theta=-56.966544 -> V=1.0, theta=0.0
% INFO    : Bus 40904	: V=1.0355223, theta=-57.655326 -> V=1.0, theta=0.0
% INFO    : Bus 40905	: V=1.0369945, theta=-57.124451 -> V=1.0, theta=0.0
% INFO    : Bus 40906	: V=1.037139, theta=-57.068601 -> V=1.0, theta=0.0
% INFO    : Bus 40907	: V=1.0362141, theta=-57.404131 -> V=1.0, theta=0.0
% INFO    : Bus 40908	: V=1.0365425, theta=-57.729913 -> V=1.0, theta=0.0
% INFO    : Bus 40909	: V=1.0360172, theta=-57.394797 -> V=1.0, theta=0.0
% INFO    : Bus 40910	: V=1.034252, theta=-59.730876 -> V=1.0, theta=0.0
% INFO    : Bus 40911	: V=1.0346274, theta=-60.0771 -> V=1.0, theta=0.0
% INFO    : Bus 40912	: V=0.9731932, theta=-57.194485 -> V=1.0, theta=0.0
% INFO    : Bus 40913	: V=0.9795885, theta=-56.695678 -> V=1.0, theta=0.0
% INFO    : Bus 40914	: V=1.0360172, theta=-57.394797 -> V=1.0, theta=0.0
% INFO    : Bus 40915	: V=0.9797193, theta=-56.77487 -> V=1.0, theta=0.0
% INFO    : Bus 40916	: V=0.9795805, theta=-56.693488 -> V=1.0, theta=0.0
% INFO    : Bus 40917	: V=0.9795289, theta=-56.674173 -> V=1.0, theta=0.0
% INFO    : Bus 40918	: V=1.0274592, theta=-55.681616 -> V=1.0, theta=0.0
% INFO    : Bus 40919	: V=1.0264422, theta=-60.218562 -> V=1.0, theta=0.0
% INFO    : Bus 40920	: V=1.0222732, theta=-68.410884 -> V=1.0, theta=0.0
% INFO    : Bus 40921	: V=0.998439, theta=-65.734472 -> V=1.0, theta=0.0
% INFO    : Bus 40922	: V=1.0453004, theta=-43.457292 -> V=1.0, theta=0.0
% INFO    : Bus 40923	: V=1.0749769, theta=-43.695003 -> V=1.0, theta=0.0
% INFO    : Bus 40924	: V=1.0444657, theta=-42.529733 -> V=1.0, theta=0.0
% INFO    : Bus 40925	: V=1.0439538, theta=-41.930232 -> V=1.0, theta=0.0
% INFO    : Bus 40926	: V=1.0453004, theta=-43.457292 -> V=1.0, theta=0.0
% INFO    : Bus 40927	: V=1.0444379, theta=-42.577496 -> V=1.0, theta=0.0
% INFO    : Bus 40928	: V=1.0453004, theta=-43.457292 -> V=1.0, theta=0.0
% INFO    : Bus 40929	: V=1.0453004, theta=-43.457292 -> V=1.0, theta=0.0
% INFO    : Bus 40930	: V=1.0474505, theta=-43.656741 -> V=1.0, theta=0.0
% INFO    : Bus 40931	: V=1.02214, theta=-50.397639 -> V=1.0, theta=0.0
% INFO    : Bus 40932	: V=1.0388696, theta=-53.124027 -> V=1.0, theta=0.0
% INFO    : Bus 40933	: V=1.0346013, theta=-54.021796 -> V=1.0, theta=0.0
% INFO    : Bus 40934	: V=1.0079015, theta=-49.630047 -> V=1.0, theta=0.0
% INFO    : Bus 40935	: V=1.0049923, theta=-49.068783 -> V=1.0, theta=0.0
% INFO    : Bus 40936	: V=1.0047713, theta=-49.633832 -> V=1.0, theta=0.0
% INFO    : Bus 40937	: V=1.0092234, theta=-49.941674 -> V=1.0, theta=0.0
% INFO    : Bus 40938	: V=1.0268749, theta=-50.727895 -> V=1.0, theta=0.0
% INFO    : Bus 40939	: V=1.0252759, theta=-62.226796 -> V=1.0, theta=0.0
% INFO    : Bus 40940	: V=1.0197871, theta=-66.541304 -> V=1.0, theta=0.0
% INFO    : Bus 40941	: V=1.0226903, theta=-73.183955 -> V=1.0, theta=0.0
% INFO    : Bus 40942	: V=1.0226903, theta=-73.183955 -> V=1.0, theta=0.0
% INFO    : Bus 40943	: V=0.9853006, theta=-61.347726 -> V=1.0, theta=0.0
% INFO    : Bus 40944	: V=1.0252759, theta=-62.226796 -> V=1.0, theta=0.0
% INFO    : Bus 40945	: V=0.9932887, theta=-61.529118 -> V=1.0, theta=0.0
% INFO    : Bus 40946	: V=0.9924094, theta=-61.650869 -> V=1.0, theta=0.0
% INFO    : Bus 40947	: V=1.0403102, theta=-53.683325 -> V=1.0, theta=0.0
% INFO    : Bus 40948	: V=1.028272, theta=-54.80169 -> V=1.0, theta=0.0
% INFO    : Bus 40949	: V=1.0254859, theta=-65.209365 -> V=1.0, theta=0.0
% INFO    : Bus 40950	: V=1.0110333, theta=-70.502904 -> V=1.0, theta=0.0
% INFO    : Bus 40951	: V=1.0110333, theta=-70.502904 -> V=1.0, theta=0.0
% INFO    : Bus 40952	: V=1.0110333, theta=-70.502904 -> V=1.0, theta=0.0
% INFO    : Bus 40953	: V=1.0260814, theta=-61.839436 -> V=1.0, theta=0.0
% INFO    : Bus 40954	: V=1.0360773, theta=-63.647864 -> V=1.0, theta=0.0
% INFO    : Bus 40955	: V=1.0277202, theta=-61.577525 -> V=1.0, theta=0.0
% INFO    : Bus 40956	: V=1.03684, theta=-57.025459 -> V=1.0, theta=0.0
% INFO    : Bus 40957	: V=1.0265714, theta=-59.152545 -> V=1.0, theta=0.0
% INFO    : Bus 40958	: V=1.0173362, theta=-57.972897 -> V=1.0, theta=0.0
% INFO    : Bus 40959	: V=1.0050378, theta=-55.723774 -> V=1.0, theta=0.0
% INFO    : Bus 40960	: V=1.0025183, theta=-56.320535 -> V=1.0, theta=0.0
% INFO    : Bus 40961	: V=1.0040415, theta=-55.965092 -> V=1.0, theta=0.0
% INFO    : Bus 40962	: V=1.03684, theta=-57.025459 -> V=1.0, theta=0.0
% INFO    : Bus 40963	: V=1.0040346, theta=-55.958117 -> V=1.0, theta=0.0
% INFO    : Bus 40964	: V=1.03684, theta=-57.025459 -> V=1.0, theta=0.0
% INFO    : Bus 40965	: V=1.0246934, theta=-59.616554 -> V=1.0, theta=0.0
% INFO    : Bus 40966	: V=1.0196354, theta=-68.144998 -> V=1.0, theta=0.0
% INFO    : Bus 40967	: V=1.0294619, theta=-60.142953 -> V=1.0, theta=0.0
% INFO    : Bus 40968	: V=1.0353927, theta=-59.162126 -> V=1.0, theta=0.0
% INFO    : Bus 40969	: V=1.0262132, theta=-58.516588 -> V=1.0, theta=0.0
% INFO    : Bus 40970	: V=1.0260392, theta=-58.471866 -> V=1.0, theta=0.0
% INFO    : Bus 40971	: V=1.0261185, theta=-58.509295 -> V=1.0, theta=0.0
% INFO    : Bus 40972	: V=1.026675, theta=-58.725891 -> V=1.0, theta=0.0
% INFO    : Bus 40973	: V=1.0255526, theta=-58.220604 -> V=1.0, theta=0.0
% INFO    : Bus 40974	: V=1.0261637, theta=-58.502681 -> V=1.0, theta=0.0
% INFO    : Bus 40975	: V=1.0268365, theta=-60.136749 -> V=1.0, theta=0.0
% INFO    : Bus 40976	: V=1.027283, theta=-59.285239 -> V=1.0, theta=0.0
% INFO    : Bus 40977	: V=1.027171, theta=-59.558232 -> V=1.0, theta=0.0
% INFO    : Bus 40978	: V=1.0268002, theta=-60.22385 -> V=1.0, theta=0.0
% INFO    : Bus 40979	: V=1.0240999, theta=-56.584758 -> V=1.0, theta=0.0
% INFO    : Bus 40980	: V=1.0350212, theta=-56.164173 -> V=1.0, theta=0.0
% INFO    : Bus 40981	: V=1.0310998, theta=-58.425753 -> V=1.0, theta=0.0
% INFO    : Bus 40982	: V=1.0305924, theta=-58.812754 -> V=1.0, theta=0.0
% INFO    : Bus 40983	: V=1.0305924, theta=-58.812754 -> V=1.0, theta=0.0
% INFO    : Bus 40984	: V=1.0262938, theta=-55.883315 -> V=1.0, theta=0.0
% INFO    : Bus 40985	: V=1.0272628, theta=-56.052728 -> V=1.0, theta=0.0
% INFO    : Bus 40986	: V=1.026498, theta=-55.964763 -> V=1.0, theta=0.0
% INFO    : Bus 40987	: V=1.0262388, theta=-56.071539 -> V=1.0, theta=0.0
% INFO    : Bus 40988	: V=1.0240999, theta=-56.584758 -> V=1.0, theta=0.0
% INFO    : Bus 40989	: V=1.0240999, theta=-56.584758 -> V=1.0, theta=0.0
% INFO    : Bus 40990	: V=1.0216813, theta=-59.481969 -> V=1.0, theta=0.0
% INFO    : Bus 40991	: V=1.0322348, theta=-60.237952 -> V=1.0, theta=0.0
% INFO    : Bus 40992	: V=1.0337232, theta=-59.30745 -> V=1.0, theta=0.0
% INFO    : Bus 40993	: V=1.0322348, theta=-60.237952 -> V=1.0, theta=0.0
% INFO    : Bus 40994	: V=1.0396229, theta=-59.961299 -> V=1.0, theta=0.0
% INFO    : Bus 40995	: V=1.0322348, theta=-60.237952 -> V=1.0, theta=0.0
% INFO    : Bus 40996	: V=1.0334776, theta=-62.243739 -> V=1.0, theta=0.0
% INFO    : Bus 40997	: V=1.0135455, theta=-67.524402 -> V=1.0, theta=0.0
% INFO    : Bus 40998	: V=1.0324448, theta=-60.091524 -> V=1.0, theta=0.0
% INFO    : Bus 40999	: V=1.0358994, theta=-59.020825 -> V=1.0, theta=0.0
% INFO    : Bus 41000	: V=1.0408923, theta=-59.96402 -> V=1.0, theta=0.0
% INFO    : Bus 41001	: V=1.0324448, theta=-60.091524 -> V=1.0, theta=0.0
% INFO    : Bus 41002	: V=1.0324448, theta=-60.091524 -> V=1.0, theta=0.0
% INFO    : Bus 41003	: V=1.0315972, theta=-60.197601 -> V=1.0, theta=0.0
% INFO    : Bus 41004	: V=1.0318243, theta=-60.886083 -> V=1.0, theta=0.0
% INFO    : Bus 41005	: V=1.0388456, theta=-57.017158 -> V=1.0, theta=0.0
% INFO    : Bus 41006	: V=1.0240999, theta=-60.344687 -> V=1.0, theta=0.0
% INFO    : Bus 41007	: V=1.0290392, theta=-61.499845 -> V=1.0, theta=0.0
% INFO    : Bus 41008	: V=1.0517127, theta=-62.801457 -> V=1.0, theta=0.0
% INFO    : Bus 41009	: V=1.0271745, theta=-59.435157 -> V=1.0, theta=0.0
% INFO    : Bus 41010	: V=1.0269834, theta=-58.663991 -> V=1.0, theta=0.0
% INFO    : Bus 41011	: V=1.0268312, theta=-58.794544 -> V=1.0, theta=0.0
% INFO    : Bus 41012	: V=1.0256105, theta=-60.584587 -> V=1.0, theta=0.0
% INFO    : Bus 41013	: V=0.9971465, theta=-65.717142 -> V=1.0, theta=0.0
% INFO    : Bus 41014	: V=0.9971465, theta=-65.717142 -> V=1.0, theta=0.0
% INFO    : Bus 41015	: V=0.9971465, theta=-65.717142 -> V=1.0, theta=0.0
% INFO    : Bus 41016	: V=1.0148408, theta=-58.999515 -> V=1.0, theta=0.0
% INFO    : Bus 41017	: V=1.0421313, theta=-63.82985 -> V=1.0, theta=0.0
% INFO    : Bus 50000	: V=1.0282739, theta=-45.423308 -> V=1.0, theta=0.0
% INFO    : Bus 50001	: V=1.0173038, theta=-48.482951 -> V=1.0, theta=0.0
% INFO    : Bus 50002	: V=1.0215881, theta=-49.008654 -> V=1.0, theta=0.0
% INFO    : Bus 50003	: V=1.0207215, theta=-47.962386 -> V=1.0, theta=0.0
% INFO    : Bus 50004	: V=1.0202973, theta=-47.990494 -> V=1.0, theta=0.0
% INFO    : Bus 50005	: V=1.0238729, theta=-47.962182 -> V=1.0, theta=0.0
% INFO    : Bus 50006	: V=1.0296899, theta=-45.06148 -> V=1.0, theta=0.0
% INFO    : Bus 50007	: V=1.0296629, theta=-45.063952 -> V=1.0, theta=0.0
% INFO    : Bus 50008	: V=1.0265819, theta=-47.619217 -> V=1.0, theta=0.0
% INFO    : Bus 50009	: V=1.0262722, theta=-47.642515 -> V=1.0, theta=0.0
% INFO    : Bus 50010	: V=1.0253452, theta=-47.690516 -> V=1.0, theta=0.0
% INFO    : Bus 50011	: V=1.0232925, theta=-47.946319 -> V=1.0, theta=0.0
% INFO    : Bus 50012	: V=1.0229939, theta=-47.974403 -> V=1.0, theta=0.0
% INFO    : Bus 50013	: V=1.0235773, theta=-47.921063 -> V=1.0, theta=0.0
% INFO    : Bus 50014	: V=1.0294254, theta=-48.367706 -> V=1.0, theta=0.0
% INFO    : Bus 50015	: V=1.032134, theta=-47.334358 -> V=1.0, theta=0.0
% INFO    : Bus 50016	: V=1.0221862, theta=-46.467335 -> V=1.0, theta=0.0
% INFO    : Bus 50017	: V=1.0274864, theta=-48.081288 -> V=1.0, theta=0.0
% INFO    : Bus 50018	: V=1.0232277, theta=-44.289995 -> V=1.0, theta=0.0
% INFO    : Bus 50019	: V=1.0324533, theta=-39.433789 -> V=1.0, theta=0.0
% INFO    : Bus 50020	: V=1.0320084, theta=-41.35625 -> V=1.0, theta=0.0
% INFO    : Bus 50021	: V=1.0301702, theta=-47.845217 -> V=1.0, theta=0.0
% INFO    : Bus 50022	: V=1.021638, theta=-50.629889 -> V=1.0, theta=0.0
% INFO    : Bus 50023	: V=1.0460651, theta=-39.190756 -> V=1.0, theta=0.0
% INFO    : Bus 50024	: V=1.0459989, theta=-39.194438 -> V=1.0, theta=0.0
% INFO    : Bus 50025	: V=1.0305284, theta=-41.993843 -> V=1.0, theta=0.0
% INFO    : Bus 50026	: V=1.0305508, theta=-41.988731 -> V=1.0, theta=0.0
% INFO    : Bus 50027	: V=1.0220831, theta=-44.118585 -> V=1.0, theta=0.0
% INFO    : Bus 50028	: V=1.0227196, theta=-45.661379 -> V=1.0, theta=0.0
% INFO    : Bus 50029	: V=1.026117, theta=-47.482945 -> V=1.0, theta=0.0
% INFO    : Bus 50030	: V=1.0226689, theta=-45.663893 -> V=1.0, theta=0.0
% INFO    : Bus 50031	: V=1.0228025, theta=-45.638299 -> V=1.0, theta=0.0
% INFO    : Bus 50032	: V=1.0471795, theta=-39.769249 -> V=1.0, theta=0.0
% INFO    : Bus 50033	: V=1.0472181, theta=-39.763452 -> V=1.0, theta=0.0
% INFO    : Bus 50034	: V=1.0312609, theta=-34.931799 -> V=1.0, theta=0.0
% INFO    : Bus 50035	: V=1.0227028, theta=-41.736218 -> V=1.0, theta=0.0
% INFO    : Bus 50036	: V=1.0289384, theta=-42.132449 -> V=1.0, theta=0.0
% INFO    : Bus 50037	: V=1.0467242, theta=-42.59407 -> V=1.0, theta=0.0
% INFO    : Bus 50038	: V=1.0466898, theta=-42.59747 -> V=1.0, theta=0.0
% INFO    : Bus 50039	: V=1.0467606, theta=-42.589985 -> V=1.0, theta=0.0
% INFO    : Bus 50040	: V=1.0414529, theta=-36.087945 -> V=1.0, theta=0.0
% INFO    : Bus 50041	: V=1.0413916, theta=-36.092614 -> V=1.0, theta=0.0
% INFO    : Bus 50042	: V=1.0333413, theta=-36.115119 -> V=1.0, theta=0.0
% INFO    : Bus 50043	: V=1.0245067, theta=-41.210473 -> V=1.0, theta=0.0
% INFO    : Bus 50044	: V=1.0226729, theta=-41.774188 -> V=1.0, theta=0.0
% INFO    : Bus 50045	: V=1.0212908, theta=-42.222081 -> V=1.0, theta=0.0
% INFO    : Bus 50046	: V=1.0212908, theta=-42.222081 -> V=1.0, theta=0.0
% INFO    : Bus 50047	: V=1.0245534, theta=-41.204488 -> V=1.0, theta=0.0
% INFO    : Bus 50048	: V=1.0245067, theta=-41.210473 -> V=1.0, theta=0.0
% INFO    : Bus 50049	: V=1.0147205, theta=-44.656301 -> V=1.0, theta=0.0
% INFO    : Bus 50050	: V=1.017637, theta=-44.333716 -> V=1.0, theta=0.0
% INFO    : Bus 50051	: V=1.0174481, theta=-44.368092 -> V=1.0, theta=0.0
% INFO    : Bus 50052	: V=1.0500008, theta=-40.864656 -> V=1.0, theta=0.0
% INFO    : Bus 50053	: V=1.0300442, theta=-46.216409 -> V=1.0, theta=0.0
% INFO    : Bus 50054	: V=1.0133663, theta=-44.860673 -> V=1.0, theta=0.0
% INFO    : Bus 50055	: V=1.0157439, theta=-44.548396 -> V=1.0, theta=0.0
% INFO    : Bus 50056	: V=1.0146122, theta=-40.713638 -> V=1.0, theta=0.0
% INFO    : Bus 50057	: V=1.0423808, theta=-38.515438 -> V=1.0, theta=0.0
% INFO    : Bus 50058	: V=1.0195476, theta=-46.341261 -> V=1.0, theta=0.0
% INFO    : Bus 50059	: V=1.0189385, theta=-45.562943 -> V=1.0, theta=0.0
% INFO    : Bus 50060	: V=1.020369, theta=-44.469573 -> V=1.0, theta=0.0
% INFO    : Bus 50061	: V=1.0249202, theta=-45.610187 -> V=1.0, theta=0.0
% INFO    : Bus 50062	: V=1.0193566, theta=-46.358997 -> V=1.0, theta=0.0
% INFO    : Bus 50063	: V=1.038855, theta=-38.632735 -> V=1.0, theta=0.0
% INFO    : Bus 50064	: V=1.0388102, theta=-38.638787 -> V=1.0, theta=0.0
% INFO    : Bus 50065	: V=1.0210192, theta=-42.86773 -> V=1.0, theta=0.0
% INFO    : Bus 50066	: V=1.0188428, theta=-44.200447 -> V=1.0, theta=0.0
% INFO    : Bus 50067	: V=1.0175387, theta=-44.382462 -> V=1.0, theta=0.0
% INFO    : Bus 50068	: V=1.0205905, theta=-44.734813 -> V=1.0, theta=0.0
% INFO    : Bus 50069	: V=1.0202935, theta=-46.26763 -> V=1.0, theta=0.0
% INFO    : Bus 50070	: V=1.0228555, theta=-44.211715 -> V=1.0, theta=0.0
% INFO    : Bus 50071	: V=1.0197265, theta=-40.453432 -> V=1.0, theta=0.0
% INFO    : Bus 50072	: V=1.0196946, theta=-40.45829 -> V=1.0, theta=0.0
% INFO    : Bus 50073	: V=1.0197616, theta=-40.448845 -> V=1.0, theta=0.0
% INFO    : Bus 50074	: V=1.0167909, theta=-46.592285 -> V=1.0, theta=0.0
% INFO    : Bus 50075	: V=1.0161755, theta=-46.634816 -> V=1.0, theta=0.0
% INFO    : Bus 50076	: V=1.0199304, theta=-44.655181 -> V=1.0, theta=0.0
% INFO    : Bus 50077	: V=1.0178323, theta=-46.423568 -> V=1.0, theta=0.0
% INFO    : Bus 50078	: V=1.0132861, theta=-40.653561 -> V=1.0, theta=0.0
% INFO    : Bus 50079	: V=1.0218831, theta=-46.076663 -> V=1.0, theta=0.0
% INFO    : Bus 50080	: V=1.0217129, theta=-46.105434 -> V=1.0, theta=0.0
% INFO    : Bus 50081	: V=1.0220555, theta=-46.045852 -> V=1.0, theta=0.0
% INFO    : Bus 50082	: V=1.0221825, theta=-45.478385 -> V=1.0, theta=0.0
% INFO    : Bus 50083	: V=1.0220206, theta=-45.506483 -> V=1.0, theta=0.0
% INFO    : Bus 50084	: V=1.0223492, theta=-45.447401 -> V=1.0, theta=0.0
% INFO    : Bus 50085	: V=1.0147511, theta=-44.872089 -> V=1.0, theta=0.0
% INFO    : Bus 50086	: V=1.0149835, theta=-44.850681 -> V=1.0, theta=0.0
% INFO    : Bus 50087	: V=1.0144924, theta=-44.89325 -> V=1.0, theta=0.0
% INFO    : Bus 50088	: V=1.0176924, theta=-44.300952 -> V=1.0, theta=0.0
% INFO    : Bus 50089	: V=1.0155693, theta=-44.5883 -> V=1.0, theta=0.0
% INFO    : Bus 50090	: V=1.0152834, theta=-44.619872 -> V=1.0, theta=0.0
% INFO    : Bus 50091	: V=1.0158401, theta=-44.554855 -> V=1.0, theta=0.0
% INFO    : Bus 50092	: V=1.0109322, theta=-44.66534 -> V=1.0, theta=0.0
% INFO    : Bus 50093	: V=1.0183127, theta=-41.389513 -> V=1.0, theta=0.0
% INFO    : Bus 50094	: V=1.0182821, theta=-41.395172 -> V=1.0, theta=0.0
% INFO    : Bus 50095	: V=1.0148848, theta=-46.913511 -> V=1.0, theta=0.0
% INFO    : Bus 50096	: V=1.0142868, theta=-46.997517 -> V=1.0, theta=0.0
% INFO    : Bus 50097	: V=1.0145009, theta=-46.969199 -> V=1.0, theta=0.0
% INFO    : Bus 50098	: V=1.0244665, theta=-42.353424 -> V=1.0, theta=0.0
% INFO    : Bus 50099	: V=1.0203391, theta=-44.633195 -> V=1.0, theta=0.0
% INFO    : Bus 50100	: V=1.0153295, theta=-44.988881 -> V=1.0, theta=0.0
% INFO    : Bus 50101	: V=1.0148323, theta=-45.040236 -> V=1.0, theta=0.0
% INFO    : Bus 50102	: V=1.0199596, theta=-45.540891 -> V=1.0, theta=0.0
% INFO    : Bus 50103	: V=1.0100751, theta=-44.873325 -> V=1.0, theta=0.0
% INFO    : Bus 50104	: V=1.0107185, theta=-42.901928 -> V=1.0, theta=0.0
% INFO    : Bus 50105	: V=1.0207156, theta=-46.231023 -> V=1.0, theta=0.0
% INFO    : Bus 50106	: V=1.0206858, theta=-46.236352 -> V=1.0, theta=0.0
% INFO    : Bus 50107	: V=1.0207437, theta=-46.225917 -> V=1.0, theta=0.0
% INFO    : Bus 50108	: V=1.0164828, theta=-46.665171 -> V=1.0, theta=0.0
% INFO    : Bus 50109	: V=1.01624, theta=-46.697051 -> V=1.0, theta=0.0
% INFO    : Bus 50110	: V=1.0161059, theta=-46.728844 -> V=1.0, theta=0.0
% INFO    : Bus 50111	: V=1.0162958, theta=-46.697076 -> V=1.0, theta=0.0
% INFO    : Bus 50112	: V=1.0154288, theta=-44.44718 -> V=1.0, theta=0.0
% INFO    : Bus 50113	: V=1.0150127, theta=-44.486828 -> V=1.0, theta=0.0
% INFO    : Bus 50114	: V=1.0152618, theta=-43.648432 -> V=1.0, theta=0.0
% INFO    : Bus 50115	: V=1.0149963, theta=-43.689357 -> V=1.0, theta=0.0
% INFO    : Bus 50116	: V=1.02714, theta=-42.023543 -> V=1.0, theta=0.0
% INFO    : Bus 50117	: V=1.013725, theta=-44.437517 -> V=1.0, theta=0.0
% INFO    : Bus 50118	: V=1.0104781, theta=-45.087287 -> V=1.0, theta=0.0
% INFO    : Bus 50119	: V=1.0104781, theta=-45.087287 -> V=1.0, theta=0.0
% INFO    : Bus 50120	: V=1.0215257, theta=-45.098521 -> V=1.0, theta=0.0
% INFO    : Bus 50121	: V=1.0180368, theta=-41.53453 -> V=1.0, theta=0.0
% INFO    : Bus 50122	: V=1.0181495, theta=-41.513523 -> V=1.0, theta=0.0
% INFO    : Bus 50123	: V=1.0219186, theta=-46.090686 -> V=1.0, theta=0.0
% INFO    : Bus 50124	: V=1.0217441, theta=-46.116221 -> V=1.0, theta=0.0
% INFO    : Bus 50125	: V=1.0147101, theta=-46.926138 -> V=1.0, theta=0.0
% INFO    : Bus 50126	: V=1.0156604, theta=-45.065056 -> V=1.0, theta=0.0
% INFO    : Bus 50127	: V=1.0104176, theta=-44.88814 -> V=1.0, theta=0.0
% INFO    : Bus 50128	: V=1.0102399, theta=-44.916475 -> V=1.0, theta=0.0
% INFO    : Bus 50129	: V=1.0121847, theta=-44.620964 -> V=1.0, theta=0.0
% INFO    : Bus 50130	: V=1.012643, theta=-44.271196 -> V=1.0, theta=0.0
% INFO    : Bus 50131	: V=1.0203787, theta=-45.573908 -> V=1.0, theta=0.0
% INFO    : Bus 50132	: V=1.0201769, theta=-45.601217 -> V=1.0, theta=0.0
% INFO    : Bus 50133	: V=1.0205455, theta=-45.546547 -> V=1.0, theta=0.0
% INFO    : Bus 50134	: V=1.0195702, theta=-45.800185 -> V=1.0, theta=0.0
% INFO    : Bus 50135	: V=1.0160519, theta=-46.75739 -> V=1.0, theta=0.0
% INFO    : Bus 50136	: V=1.0153211, theta=-46.882607 -> V=1.0, theta=0.0
% INFO    : Bus 50137	: V=1.009802, theta=-44.879915 -> V=1.0, theta=0.0
% INFO    : Bus 50138	: V=1.0093281, theta=-44.916575 -> V=1.0, theta=0.0
% INFO    : Bus 50139	: V=1.0135921, theta=-45.182904 -> V=1.0, theta=0.0
% INFO    : Bus 50140	: V=1.0211885, theta=-40.910269 -> V=1.0, theta=0.0
% INFO    : Bus 50141	: V=1.0136471, theta=-44.600693 -> V=1.0, theta=0.0
% INFO    : Bus 50142	: V=1.0134322, theta=-44.628101 -> V=1.0, theta=0.0
% INFO    : Bus 50143	: V=1.0138337, theta=-44.571301 -> V=1.0, theta=0.0
% INFO    : Bus 50144	: V=1.0196912, theta=-43.097604 -> V=1.0, theta=0.0
% INFO    : Bus 50145	: V=1.0199657, theta=-43.067325 -> V=1.0, theta=0.0
% INFO    : Bus 50146	: V=1.0194342, theta=-43.127891 -> V=1.0, theta=0.0
% INFO    : Bus 50147	: V=1.0238052, theta=-45.528329 -> V=1.0, theta=0.0
% INFO    : Bus 50148	: V=1.0185802, theta=-46.256658 -> V=1.0, theta=0.0
% INFO    : Bus 50149	: V=1.0360343, theta=-37.886168 -> V=1.0, theta=0.0
% INFO    : Bus 50150	: V=1.035993, theta=-37.890145 -> V=1.0, theta=0.0
% INFO    : Bus 50151	: V=1.0105096, theta=-44.826109 -> V=1.0, theta=0.0
% INFO    : Bus 50152	: V=1.010192, theta=-44.854176 -> V=1.0, theta=0.0
% INFO    : Bus 50153	: V=1.0135944, theta=-44.626991 -> V=1.0, theta=0.0
% INFO    : Bus 50154	: V=1.0133902, theta=-44.658919 -> V=1.0, theta=0.0
% INFO    : Bus 50155	: V=1.0233264, theta=-45.889738 -> V=1.0, theta=0.0
% INFO    : Bus 50156	: V=1.0198962, theta=-43.360904 -> V=1.0, theta=0.0
% INFO    : Bus 50157	: V=1.0198962, theta=-43.360904 -> V=1.0, theta=0.0
% INFO    : Bus 50158	: V=1.0198962, theta=-43.360904 -> V=1.0, theta=0.0
% INFO    : Bus 50159	: V=1.0198962, theta=-43.360904 -> V=1.0, theta=0.0
% INFO    : Bus 50160	: V=1.0196907, theta=-43.384096 -> V=1.0, theta=0.0
% INFO    : Bus 50161	: V=1.0180186, theta=-46.152441 -> V=1.0, theta=0.0
% INFO    : Bus 50162	: V=1.0165109, theta=-46.878279 -> V=1.0, theta=0.0
% INFO    : Bus 50163	: V=1.0242916, theta=-43.748876 -> V=1.0, theta=0.0
% INFO    : Bus 50164	: V=1.0261484, theta=-45.515158 -> V=1.0, theta=0.0
% INFO    : Bus 50165	: V=1.0136481, theta=-44.851876 -> V=1.0, theta=0.0
% INFO    : Bus 50166	: V=1.0134747, theta=-44.626378 -> V=1.0, theta=0.0
% INFO    : Bus 50167	: V=1.0184248, theta=-45.088281 -> V=1.0, theta=0.0
% INFO    : Bus 50168	: V=1.0153888, theta=-44.65673 -> V=1.0, theta=0.0
% INFO    : Bus 50169	: V=1.0137893, theta=-44.308949 -> V=1.0, theta=0.0
% INFO    : Bus 50170	: V=1.0100512, theta=-44.894214 -> V=1.0, theta=0.0
% INFO    : Bus 50171	: V=1.0255895, theta=-45.597741 -> V=1.0, theta=0.0
% INFO    : Bus 50172	: V=1.0212424, theta=-45.398487 -> V=1.0, theta=0.0
% INFO    : Bus 50173	: V=1.0206375, theta=-40.388334 -> V=1.0, theta=0.0
% INFO    : Bus 50174	: V=1.0182308, theta=-44.061454 -> V=1.0, theta=0.0
% INFO    : Bus 50175	: V=1.0185324, theta=-44.021613 -> V=1.0, theta=0.0
% INFO    : Bus 50176	: V=1.0233385, theta=-41.159156 -> V=1.0, theta=0.0
% INFO    : Bus 50177	: V=1.0211787, theta=-43.26087 -> V=1.0, theta=0.0
% INFO    : Bus 50178	: V=1.018189, theta=-43.878956 -> V=1.0, theta=0.0
% INFO    : Bus 50179	: V=1.0183056, theta=-43.865759 -> V=1.0, theta=0.0
% INFO    : Bus 50180	: V=1.0194327, theta=-45.774218 -> V=1.0, theta=0.0
% INFO    : Bus 50181	: V=1.0227637, theta=-46.019198 -> V=1.0, theta=0.0
% INFO    : Bus 50182	: V=1.0270682, theta=-39.332231 -> V=1.0, theta=0.0
% INFO    : Bus 50183	: V=1.0269838, theta=-39.340172 -> V=1.0, theta=0.0
% INFO    : Bus 50184	: V=1.0160456, theta=-44.946673 -> V=1.0, theta=0.0
% INFO    : Bus 50185	: V=1.0135949, theta=-44.804348 -> V=1.0, theta=0.0
% INFO    : Bus 50186	: V=1.0153854, theta=-44.660673 -> V=1.0, theta=0.0
% INFO    : Bus 50187	: V=1.0144682, theta=-45.031342 -> V=1.0, theta=0.0
% INFO    : Bus 50188	: V=1.0142002, theta=-45.062267 -> V=1.0, theta=0.0
% INFO    : Bus 50189	: V=1.0182057, theta=-44.842216 -> V=1.0, theta=0.0
% INFO    : Bus 50190	: V=1.0137922, theta=-44.86831 -> V=1.0, theta=0.0
% INFO    : Bus 50191	: V=1.0134991, theta=-44.895157 -> V=1.0, theta=0.0
% INFO    : Bus 50192	: V=1.0140915, theta=-44.84304 -> V=1.0, theta=0.0
% INFO    : Bus 50193	: V=1.0225567, theta=-42.610566 -> V=1.0, theta=0.0
% INFO    : Bus 50194	: V=1.0225115, theta=-42.617104 -> V=1.0, theta=0.0
% INFO    : Bus 50195	: V=1.0226046, theta=-42.604806 -> V=1.0, theta=0.0
% INFO    : Bus 50196	: V=1.0189687, theta=-39.991917 -> V=1.0, theta=0.0
% INFO    : Bus 50197	: V=1.0189879, theta=-39.988437 -> V=1.0, theta=0.0
% INFO    : Bus 50198	: V=1.0251494, theta=-39.96719 -> V=1.0, theta=0.0
% INFO    : Bus 50199	: V=1.0250996, theta=-39.970442 -> V=1.0, theta=0.0
% INFO    : Bus 50200	: V=1.0131512, theta=-45.208488 -> V=1.0, theta=0.0
% INFO    : Bus 50201	: V=1.0189459, theta=-40.970022 -> V=1.0, theta=0.0
% INFO    : Bus 50202	: V=1.0185975, theta=-41.004787 -> V=1.0, theta=0.0
% INFO    : Bus 50203	: V=1.020219, theta=-48.192205 -> V=1.0, theta=0.0
% INFO    : Bus 50204	: V=1.0267847, theta=-34.531066 -> V=1.0, theta=0.0
% INFO    : Bus 50205	: V=1.0213998, theta=-39.648905 -> V=1.0, theta=0.0
% INFO    : Bus 50206	: V=1.0289565, theta=-35.51985 -> V=1.0, theta=0.0
% INFO    : Bus 50207	: V=1.0289565, theta=-35.51985 -> V=1.0, theta=0.0
% INFO    : Bus 50208	: V=1.0191091, theta=-41.312127 -> V=1.0, theta=0.0
% INFO    : Bus 50209	: V=1.0213004, theta=-42.268224 -> V=1.0, theta=0.0
% INFO    : Bus 50210	: V=1.0160442, theta=-44.470942 -> V=1.0, theta=0.0
% INFO    : Bus 50211	: V=1.0219569, theta=-42.032115 -> V=1.0, theta=0.0
% INFO    : Bus 50212	: V=1.0219569, theta=-42.032115 -> V=1.0, theta=0.0
% INFO    : Bus 50213	: V=1.0211054, theta=-42.303478 -> V=1.0, theta=0.0
% INFO    : Bus 50214	: V=1.0227655, theta=-42.051946 -> V=1.0, theta=0.0
% INFO    : Bus 50215	: V=1.0140243, theta=-44.572385 -> V=1.0, theta=0.0
% INFO    : Bus 50216	: V=1.0342552, theta=-36.896759 -> V=1.0, theta=0.0
% INFO    : Bus 50217	: V=1.0266304, theta=-40.666986 -> V=1.0, theta=0.0
% INFO    : Bus 50218	: V=1.0223248, theta=-39.99342 -> V=1.0, theta=0.0
% INFO    : Bus 50219	: V=1.0135107, theta=-44.824336 -> V=1.0, theta=0.0
% INFO    : Bus 50220	: V=1.022795, theta=-40.870343 -> V=1.0, theta=0.0
% INFO    : Bus 50221	: V=1.0282847, theta=-39.835004 -> V=1.0, theta=0.0
% INFO    : Bus 50222	: V=1.0273476, theta=-41.298948 -> V=1.0, theta=0.0
% INFO    : Bus 50223	: V=1.0074058, theta=-44.995093 -> V=1.0, theta=0.0
% INFO    : Bus 50224	: V=1.0303673, theta=-41.636083 -> V=1.0, theta=0.0
% INFO    : Bus 50225	: V=1.0335487, theta=-36.572223 -> V=1.0, theta=0.0
% INFO    : Bus 50226	: V=1.0183704, theta=-41.571802 -> V=1.0, theta=0.0
% INFO    : Bus 50227	: V=1.0183782, theta=-40.445889 -> V=1.0, theta=0.0
% INFO    : Bus 50228	: V=1.0163118, theta=-44.54957 -> V=1.0, theta=0.0
% INFO    : Bus 50229	: V=1.0202165, theta=-45.613351 -> V=1.0, theta=0.0
% INFO    : Bus 50230	: V=1.020406, theta=-45.580104 -> V=1.0, theta=0.0
% INFO    : Bus 50231	: V=1.0200108, theta=-45.645242 -> V=1.0, theta=0.0
% INFO    : Bus 50232	: V=1.0202165, theta=-45.613351 -> V=1.0, theta=0.0
% INFO    : Bus 50233	: V=1.0133976, theta=-42.881757 -> V=1.0, theta=0.0
% INFO    : Bus 50234	: V=1.0162166, theta=-42.894951 -> V=1.0, theta=0.0
% INFO    : Bus 50235	: V=1.0199048, theta=-43.343936 -> V=1.0, theta=0.0
% INFO    : Bus 50236	: V=1.0186192, theta=-41.821643 -> V=1.0, theta=0.0
% INFO    : Bus 50237	: V=1.0148801, theta=-44.462729 -> V=1.0, theta=0.0
% INFO    : Bus 50238	: V=1.0146005, theta=-44.495123 -> V=1.0, theta=0.0
% INFO    : Bus 50239	: V=1.0243186, theta=-42.318939 -> V=1.0, theta=0.0
% INFO    : Bus 50240	: V=1.0267723, theta=-44.32639 -> V=1.0, theta=0.0
% INFO    : Bus 50241	: V=1.0241046, theta=-42.348314 -> V=1.0, theta=0.0
% INFO    : Bus 50242	: V=1.0166482, theta=-42.639195 -> V=1.0, theta=0.0
% INFO    : Bus 50243	: V=1.0174057, theta=-42.843796 -> V=1.0, theta=0.0
% INFO    : Bus 50244	: V=1.0218017, theta=-44.648866 -> V=1.0, theta=0.0
% INFO    : Bus 50245	: V=1.0146165, theta=-44.746879 -> V=1.0, theta=0.0
% INFO    : Bus 50246	: V=1.0144606, theta=-44.770383 -> V=1.0, theta=0.0
% INFO    : Bus 50247	: V=1.0229276, theta=-45.065885 -> V=1.0, theta=0.0
% INFO    : Bus 50248	: V=1.034533, theta=-38.50303 -> V=1.0, theta=0.0
% INFO    : Bus 50249	: V=1.0148178, theta=-42.309693 -> V=1.0, theta=0.0
% INFO    : Bus 50250	: V=1.0146173, theta=-42.370395 -> V=1.0, theta=0.0
% INFO    : Bus 50251	: V=1.0187506, theta=-41.607775 -> V=1.0, theta=0.0
% INFO    : Bus 50252	: V=1.0184687, theta=-41.63433 -> V=1.0, theta=0.0
% INFO    : Bus 50253	: V=1.0159092, theta=-42.045479 -> V=1.0, theta=0.0
% INFO    : Bus 50254	: V=1.014766, theta=-44.38844 -> V=1.0, theta=0.0
% INFO    : Bus 50255	: V=1.0179326, theta=-44.128166 -> V=1.0, theta=0.0
% INFO    : Bus 50256	: V=1.0174929, theta=-44.16012 -> V=1.0, theta=0.0
% INFO    : Bus 50257	: V=1.0183817, theta=-44.095584 -> V=1.0, theta=0.0
% INFO    : Bus 50258	: V=1.0198358, theta=-46.504784 -> V=1.0, theta=0.0
% INFO    : Bus 50259	: V=1.0197688, theta=-46.520008 -> V=1.0, theta=0.0
% INFO    : Bus 50260	: V=1.0176229, theta=-42.856081 -> V=1.0, theta=0.0
% INFO    : Bus 50261	: V=1.0185528, theta=-44.138441 -> V=1.0, theta=0.0
% INFO    : Bus 50262	: V=1.0183224, theta=-44.1688 -> V=1.0, theta=0.0
% INFO    : Bus 50263	: V=1.0229154, theta=-41.457244 -> V=1.0, theta=0.0
% INFO    : Bus 50264	: V=1.0201197, theta=-44.005913 -> V=1.0, theta=0.0
% INFO    : Bus 50265	: V=1.0233733, theta=-40.922585 -> V=1.0, theta=0.0
% INFO    : Bus 50266	: V=1.0232771, theta=-40.935435 -> V=1.0, theta=0.0
% INFO    : Bus 50267	: V=1.0223733, theta=-40.954663 -> V=1.0, theta=0.0
% INFO    : Bus 50268	: V=1.0199238, theta=-40.517418 -> V=1.0, theta=0.0
% INFO    : Bus 50269	: V=1.0199012, theta=-40.521254 -> V=1.0, theta=0.0
% INFO    : Bus 50270	: V=1.0359012, theta=-38.1845 -> V=1.0, theta=0.0
% INFO    : Bus 50271	: V=1.0358755, theta=-38.188508 -> V=1.0, theta=0.0
% INFO    : Bus 50272	: V=1.0205645, theta=-42.149762 -> V=1.0, theta=0.0
% INFO    : Bus 50273	: V=1.018738, theta=-42.70147 -> V=1.0, theta=0.0
% INFO    : Bus 50274	: V=1.0190328, theta=-42.680692 -> V=1.0, theta=0.0
% INFO    : Bus 50275	: V=1.023977, theta=-42.184725 -> V=1.0, theta=0.0
% INFO    : Bus 50276	: V=1.0339204, theta=-36.941422 -> V=1.0, theta=0.0
% INFO    : Bus 50277	: V=1.0301173, theta=-38.492016 -> V=1.0, theta=0.0
% INFO    : Bus 50278	: V=1.0300846, theta=-38.497781 -> V=1.0, theta=0.0
% INFO    : Bus 50279	: V=1.0190799, theta=-41.77226 -> V=1.0, theta=0.0
% INFO    : Bus 50280	: V=1.0210667, theta=-42.817468 -> V=1.0, theta=0.0
% INFO    : Bus 50281	: V=1.021005, theta=-40.901907 -> V=1.0, theta=0.0
% INFO    : Bus 50282	: V=1.0225211, theta=-42.681894 -> V=1.0, theta=0.0
% INFO    : Bus 50283	: V=1.0205357, theta=-40.932613 -> V=1.0, theta=0.0
% INFO    : Bus 50284	: V=1.0225811, theta=-40.75777 -> V=1.0, theta=0.0
% INFO    : Bus 50285	: V=1.018883, theta=-42.855317 -> V=1.0, theta=0.0
% INFO    : Bus 50286	: V=1.0188138, theta=-42.866988 -> V=1.0, theta=0.0
% INFO    : Bus 50287	: V=1.0313655, theta=-36.15873 -> V=1.0, theta=0.0
% INFO    : Bus 50288	: V=1.0312794, theta=-36.171701 -> V=1.0, theta=0.0
% INFO    : Bus 50289	: V=1.0240794, theta=-44.861626 -> V=1.0, theta=0.0
% INFO    : Bus 50290	: V=1.0141244, theta=-44.272072 -> V=1.0, theta=0.0
% INFO    : Bus 50291	: V=1.0140534, theta=-44.280055 -> V=1.0, theta=0.0
% INFO    : Bus 50292	: V=1.0141913, theta=-44.264774 -> V=1.0, theta=0.0
% INFO    : Bus 50293	: V=1.0162539, theta=-44.315311 -> V=1.0, theta=0.0
% INFO    : Bus 50294	: V=1.019405, theta=-42.963257 -> V=1.0, theta=0.0
% INFO    : Bus 50295	: V=1.0211582, theta=-40.07493 -> V=1.0, theta=0.0
% INFO    : Bus 50296	: V=1.0272, theta=-40.025365 -> V=1.0, theta=0.0
% INFO    : Bus 50297	: V=1.034564, theta=-39.385481 -> V=1.0, theta=0.0
% INFO    : Bus 50298	: V=1.0326395, theta=-37.662232 -> V=1.0, theta=0.0
% INFO    : Bus 50299	: V=1.0140666, theta=-43.872993 -> V=1.0, theta=0.0
% INFO    : Bus 50300	: V=1.0277407, theta=-43.811767 -> V=1.0, theta=0.0
% INFO    : Bus 50301	: V=1.0301707, theta=-35.267454 -> V=1.0, theta=0.0
% INFO    : Bus 50302	: V=1.0171335, theta=-43.294617 -> V=1.0, theta=0.0
% INFO    : Bus 50303	: V=1.0302047, theta=-34.894976 -> V=1.0, theta=0.0
% INFO    : Bus 50304	: V=1.0368056, theta=-35.671391 -> V=1.0, theta=0.0
% INFO    : Bus 50305	: V=1.0367734, theta=-35.675275 -> V=1.0, theta=0.0
% INFO    : Bus 50306	: V=1.0368387, theta=-35.667027 -> V=1.0, theta=0.0
% INFO    : Bus 50307	: V=1.0368056, theta=-35.671391 -> V=1.0, theta=0.0
% INFO    : Bus 50308	: V=1.0298619, theta=-39.769467 -> V=1.0, theta=0.0
% INFO    : Bus 50309	: V=1.027615, theta=-34.150314 -> V=1.0, theta=0.0
% INFO    : Bus 50310	: V=1.0308895, theta=-38.204231 -> V=1.0, theta=0.0
% INFO    : Bus 50311	: V=1.0308244, theta=-38.209856 -> V=1.0, theta=0.0
% INFO    : Bus 50312	: V=1.0385273, theta=-35.25987 -> V=1.0, theta=0.0
% INFO    : Bus 50313	: V=1.0400353, theta=-34.934334 -> V=1.0, theta=0.0
% INFO    : Bus 50314	: V=1.0320642, theta=-38.814987 -> V=1.0, theta=0.0
% INFO    : Bus 50315	: V=1.0308302, theta=-36.851413 -> V=1.0, theta=0.0
% INFO    : Bus 50316	: V=1.0319585, theta=-38.83789 -> V=1.0, theta=0.0
% INFO    : Bus 50317	: V=1.0331716, theta=-39.852763 -> V=1.0, theta=0.0
% INFO    : Bus 50318	: V=1.0331223, theta=-39.857992 -> V=1.0, theta=0.0
% INFO    : Bus 50319	: V=1.0413225, theta=-34.926342 -> V=1.0, theta=0.0
% INFO    : Bus 50320	: V=1.0358526, theta=-36.9306 -> V=1.0, theta=0.0
% INFO    : Bus 50321	: V=1.0358814, theta=-36.927584 -> V=1.0, theta=0.0
% INFO    : Bus 50322	: V=1.0459071, theta=-35.873265 -> V=1.0, theta=0.0
% INFO    : Bus 50323	: V=1.0458947, theta=-35.874837 -> V=1.0, theta=0.0
% INFO    : Bus 50324	: V=1.0373288, theta=-35.784497 -> V=1.0, theta=0.0
% INFO    : Bus 50325	: V=1.0374681, theta=-36.772118 -> V=1.0, theta=0.0
% INFO    : Bus 50326	: V=1.0375935, theta=-36.800896 -> V=1.0, theta=0.0
% INFO    : Bus 50327	: V=1.0394503, theta=-35.266025 -> V=1.0, theta=0.0
% INFO    : Bus 50328	: V=1.0394022, theta=-35.268125 -> V=1.0, theta=0.0
% INFO    : Bus 50329	: V=1.0392046, theta=-35.216339 -> V=1.0, theta=0.0
% INFO    : Bus 50330	: V=1.0392245, theta=-35.214359 -> V=1.0, theta=0.0
% INFO    : Bus 50331	: V=1.020459, theta=-47.043076 -> V=1.0, theta=0.0
% INFO    : Bus 50332	: V=1.0246421, theta=-48.931177 -> V=1.0, theta=0.0
% INFO    : Bus 50333	: V=1.0204423, theta=-47.044984 -> V=1.0, theta=0.0
% INFO    : Bus 50334	: V=1.0299104, theta=-42.73714 -> V=1.0, theta=0.0
% INFO    : Bus 50335	: V=1.0327236, theta=-43.017512 -> V=1.0, theta=0.0
% INFO    : Bus 50336	: V=1.0298732, theta=-42.740519 -> V=1.0, theta=0.0
% INFO    : Bus 50337	: V=1.0388392, theta=-36.420963 -> V=1.0, theta=0.0
% INFO    : Bus 50338	: V=1.0401082, theta=-37.057524 -> V=1.0, theta=0.0
% INFO    : Bus 50339	: V=1.0407182, theta=-39.425979 -> V=1.0, theta=0.0
% INFO    : Bus 50340	: V=1.0361009, theta=-33.354661 -> V=1.0, theta=0.0
% INFO    : Bus 50341	: V=1.0393149, theta=-34.480286 -> V=1.0, theta=0.0
% INFO    : Bus 50342	: V=1.044687, theta=-36.120095 -> V=1.0, theta=0.0
% INFO    : Bus 50343	: V=1.0447924, theta=-36.093134 -> V=1.0, theta=0.0
% INFO    : Bus 50344	: V=1.039235, theta=-34.573658 -> V=1.0, theta=0.0
% INFO    : Bus 50345	: V=1.0240878, theta=-44.449195 -> V=1.0, theta=0.0
% INFO    : Bus 50346	: V=1.0248417, theta=-44.312914 -> V=1.0, theta=0.0
% INFO    : Bus 50347	: V=1.0238997, theta=-44.4834 -> V=1.0, theta=0.0
% INFO    : Bus 50348	: V=1.0238997, theta=-44.4834 -> V=1.0, theta=0.0
% INFO    : Bus 50349	: V=1.0241834, theta=-44.452077 -> V=1.0, theta=0.0
% INFO    : Bus 50350	: V=1.0240878, theta=-44.449195 -> V=1.0, theta=0.0
% INFO    : Bus 50351	: V=1.0240878, theta=-44.449195 -> V=1.0, theta=0.0
% INFO    : Bus 50352	: V=1.0201218, theta=-45.732819 -> V=1.0, theta=0.0
% INFO    : Bus 50353	: V=1.0274393, theta=-47.821929 -> V=1.0, theta=0.0
% INFO    : Bus 50354	: V=1.04251, theta=-33.249917 -> V=1.0, theta=0.0
% INFO    : Bus 50355	: V=1.0424992, theta=-33.250935 -> V=1.0, theta=0.0
% INFO    : Bus 50356	: V=1.02214, theta=-40.996247 -> V=1.0, theta=0.0
% INFO    : Bus 50357	: V=1.0178081, theta=-42.785567 -> V=1.0, theta=0.0
% INFO    : Bus 50358	: V=1.0163338, theta=-43.516356 -> V=1.0, theta=0.0
% INFO    : Bus 50359	: V=1.0163338, theta=-43.516356 -> V=1.0, theta=0.0
% INFO    : Bus 50360	: V=1.0284612, theta=-39.068022 -> V=1.0, theta=0.0
% INFO    : Bus 50361	: V=1.02214, theta=-40.996247 -> V=1.0, theta=0.0
% INFO    : Bus 50362	: V=1.027348, theta=-39.666145 -> V=1.0, theta=0.0
% INFO    : Bus 50363	: V=1.0263574, theta=-39.739589 -> V=1.0, theta=0.0
% INFO    : Bus 50364	: V=1.02214, theta=-40.996247 -> V=1.0, theta=0.0
% INFO    : Bus 50365	: V=1.0283296, theta=-39.133083 -> V=1.0, theta=0.0
% INFO    : Bus 50366	: V=1.0267873, theta=-40.499154 -> V=1.0, theta=0.0
% INFO    : Bus 50367	: V=1.0418766, theta=-34.385616 -> V=1.0, theta=0.0
% INFO    : Bus 50368	: V=1.0425132, theta=-34.829424 -> V=1.0, theta=0.0
% INFO    : Bus 50369	: V=1.0209989, theta=-45.437664 -> V=1.0, theta=0.0
% INFO    : Bus 50370	: V=1.02116, theta=-42.601332 -> V=1.0, theta=0.0
% INFO    : Bus 50371	: V=1.0168841, theta=-44.25448 -> V=1.0, theta=0.0
% INFO    : Bus 50372	: V=1.0128421, theta=-46.277212 -> V=1.0, theta=0.0
% INFO    : Bus 50373	: V=1.0128421, theta=-46.277212 -> V=1.0, theta=0.0
% INFO    : Bus 50374	: V=1.0053069, theta=-41.481538 -> V=1.0, theta=0.0
% INFO    : Bus 50375	: V=1.0046739, theta=-41.756322 -> V=1.0, theta=0.0
% INFO    : Bus 50376	: V=1.0071139, theta=-41.696194 -> V=1.0, theta=0.0
% INFO    : Bus 50377	: V=1.0227068, theta=-42.624501 -> V=1.0, theta=0.0
% INFO    : Bus 50378	: V=1.0217115, theta=-40.503783 -> V=1.0, theta=0.0
% INFO    : Bus 50379	: V=1.0211507, theta=-39.526366 -> V=1.0, theta=0.0
% INFO    : Bus 50380	: V=1.041, theta=-31.403363 -> V=1.0, theta=0.0
% INFO    : Bus 50381	: V=1.0433546, theta=-32.216173 -> V=1.0, theta=0.0
% INFO    : Bus 50382	: V=1.0437526, theta=-28.972807 -> V=1.0, theta=0.0
% INFO    : Bus 50383	: V=1.0282251, theta=-30.62806 -> V=1.0, theta=0.0
% INFO    : Bus 50384	: V=1.0345272, theta=-33.686656 -> V=1.0, theta=0.0
% INFO    : Bus 50385	: V=1.0159176, theta=-26.050446 -> V=1.0, theta=0.0
% INFO    : Bus 50386	: V=1.0191699, theta=-27.027664 -> V=1.0, theta=0.0
% INFO    : Bus 50387	: V=0.9880937, theta=-33.355595 -> V=1.0, theta=0.0
% INFO    : Bus 50388	: V=1.0284239, theta=-30.987345 -> V=1.0, theta=0.0
% INFO    : Bus 50389	: V=1.0480238, theta=-38.829489 -> V=1.0, theta=0.0
% INFO    : Bus 50390	: V=1.0484633, theta=-38.022748 -> V=1.0, theta=0.0
% INFO    : Bus 50391	: V=1.0484132, theta=-37.848704 -> V=1.0, theta=0.0
% INFO    : Bus 50392	: V=1.0468574, theta=-38.154817 -> V=1.0, theta=0.0
% INFO    : Bus 50393	: V=1.0030899, theta=-37.884255 -> V=1.0, theta=0.0
% INFO    : Bus 50394	: V=1.0468357, theta=-38.160737 -> V=1.0, theta=0.0
% INFO    : Bus 50395	: V=1.02018, theta=-32.62776 -> V=1.0, theta=0.0
% INFO    : Bus 50396	: V=1.0268026, theta=-33.772558 -> V=1.0, theta=0.0
% INFO    : Bus 50397	: V=1.0172138, theta=-31.161003 -> V=1.0, theta=0.0
% INFO    : Bus 50398	: V=1.0121742, theta=-29.158114 -> V=1.0, theta=0.0
% INFO    : Bus 50399	: V=1.013811, theta=-29.754118 -> V=1.0, theta=0.0
% INFO    : Bus 50400	: V=1.02802, theta=-37.805823 -> V=1.0, theta=0.0
% INFO    : Bus 50401	: V=1.029868, theta=-39.096555 -> V=1.0, theta=0.0
% INFO    : Bus 50402	: V=1.0117779, theta=-36.077022 -> V=1.0, theta=0.0
% INFO    : Bus 50403	: V=1.0113172, theta=-36.44829 -> V=1.0, theta=0.0
% INFO    : Bus 50404	: V=1.0110256, theta=-36.641683 -> V=1.0, theta=0.0
% INFO    : Bus 50405	: V=1.0265399, theta=-38.11477 -> V=1.0, theta=0.0
% INFO    : Bus 50406	: V=1.0274233, theta=-37.170668 -> V=1.0, theta=0.0
% INFO    : Bus 50407	: V=1.0317242, theta=-37.893181 -> V=1.0, theta=0.0
% INFO    : Bus 50408	: V=1.0333373, theta=-38.150588 -> V=1.0, theta=0.0
% INFO    : Bus 50409	: V=0.9952769, theta=-36.122124 -> V=1.0, theta=0.0
% INFO    : Bus 50410	: V=1.0312466, theta=-37.923764 -> V=1.0, theta=0.0
% INFO    : Bus 50411	: V=1.0251323, theta=-45.66704 -> V=1.0, theta=0.0
% INFO    : Bus 50412	: V=1.0450058, theta=-44.969101 -> V=1.0, theta=0.0
% INFO    : Bus 50413	: V=1.0700048, theta=-42.327615 -> V=1.0, theta=0.0
% INFO    : Bus 50414	: V=1.0343351, theta=-35.122166 -> V=1.0, theta=0.0
% INFO    : Bus 50415	: V=1.0347079, theta=-36.390699 -> V=1.0, theta=0.0
% INFO    : Bus 50416	: V=1.0345863, theta=-36.121538 -> V=1.0, theta=0.0
% INFO    : Bus 50417	: V=1.0345863, theta=-36.121538 -> V=1.0, theta=0.0
% INFO    : Bus 50418	: V=1.0323515, theta=-34.146033 -> V=1.0, theta=0.0
% INFO    : Bus 50419	: V=1.0322928, theta=-34.158733 -> V=1.0, theta=0.0
% INFO    : Bus 50420	: V=1.0395244, theta=-38.251207 -> V=1.0, theta=0.0
% INFO    : Bus 50421	: V=0.9912385, theta=-35.183058 -> V=1.0, theta=0.0
% INFO    : Bus 50422	: V=1.0391578, theta=-38.302286 -> V=1.0, theta=0.0
% INFO    : Bus 50423	: V=1.0395244, theta=-38.251207 -> V=1.0, theta=0.0
% INFO    : Bus 50424	: V=1.0241886, theta=-39.51256 -> V=1.0, theta=0.0
% INFO    : Bus 50425	: V=1.0202288, theta=-41.270061 -> V=1.0, theta=0.0
% INFO    : Bus 50426	: V=1.0145345, theta=-45.784511 -> V=1.0, theta=0.0
% INFO    : Bus 50427	: V=1.0145345, theta=-45.784511 -> V=1.0, theta=0.0
% INFO    : Bus 50428	: V=1.0239353, theta=-39.451037 -> V=1.0, theta=0.0
% INFO    : Bus 50429	: V=1.0398248, theta=-36.698039 -> V=1.0, theta=0.0
% INFO    : Bus 50430	: V=1.0341349, theta=-34.993487 -> V=1.0, theta=0.0
% INFO    : Bus 50431	: V=1.0352401, theta=-37.119387 -> V=1.0, theta=0.0
% INFO    : Bus 50432	: V=1.0331949, theta=-35.937486 -> V=1.0, theta=0.0
% INFO    : Bus 50433	: V=0.9879641, theta=-35.836923 -> V=1.0, theta=0.0
% INFO    : Bus 50434	: V=1.0398248, theta=-36.698039 -> V=1.0, theta=0.0
% INFO    : Bus 50435	: V=1.0398202, theta=-36.900964 -> V=1.0, theta=0.0
% INFO    : Bus 50436	: V=1.0346048, theta=-34.793938 -> V=1.0, theta=0.0
% INFO    : Bus 50437	: V=1.0139996, theta=-44.646595 -> V=1.0, theta=0.0
% INFO    : Bus 50438	: V=1.02116, theta=-42.968419 -> V=1.0, theta=0.0
% INFO    : Bus 50439	: V=1.0173169, theta=-44.262924 -> V=1.0, theta=0.0
% INFO    : Bus 50440	: V=1.0062185, theta=-41.958204 -> V=1.0, theta=0.0
% INFO    : Bus 50441	: V=1.0056009, theta=-42.135534 -> V=1.0, theta=0.0
% INFO    : Bus 50442	: V=1.0099057, theta=-42.06424 -> V=1.0, theta=0.0
% INFO    : Bus 50443	: V=1.0240999, theta=-43.282668 -> V=1.0, theta=0.0
% INFO    : Bus 50444	: V=1.0222914, theta=-45.172277 -> V=1.0, theta=0.0
% INFO    : Bus 50445	: V=1.023971, theta=-43.415167 -> V=1.0, theta=0.0
% INFO    : Bus 50446	: V=1.0288612, theta=-33.804483 -> V=1.0, theta=0.0
% INFO    : Bus 50447	: V=1.0383932, theta=-34.640891 -> V=1.0, theta=0.0
% INFO    : Bus 50448	: V=1.030704, theta=-30.404624 -> V=1.0, theta=0.0
% INFO    : Bus 50449	: V=1.0288612, theta=-33.804483 -> V=1.0, theta=0.0
% INFO    : Bus 50450	: V=1.0232926, theta=-42.657549 -> V=1.0, theta=0.0
% INFO    : Bus 50451	: V=1.0267123, theta=-42.699842 -> V=1.0, theta=0.0
% INFO    : Bus 50452	: V=1.0237603, theta=-42.658572 -> V=1.0, theta=0.0
% INFO    : Bus 50453	: V=1.0434214, theta=-43.865866 -> V=1.0, theta=0.0
% INFO    : Bus 50454	: V=1.0315805, theta=-46.761562 -> V=1.0, theta=0.0
% INFO    : Bus 50455	: V=1.0479296, theta=-42.920465 -> V=1.0, theta=0.0
% INFO    : Bus 50456	: V=1.0479296, theta=-42.920465 -> V=1.0, theta=0.0
% INFO    : Bus 50457	: V=1.042689, theta=-43.474 -> V=1.0, theta=0.0
% INFO    : Bus 50458	: V=1.0411595, theta=-34.050939 -> V=1.0, theta=0.0
% INFO    : Bus 50459	: V=1.0404243, theta=-34.098035 -> V=1.0, theta=0.0
% INFO    : Bus 50460	: V=1.0250013, theta=-33.320547 -> V=1.0, theta=0.0
% INFO    : Bus 53000	: V=1.0073293, theta=-67.776384 -> V=1.0, theta=0.0
% INFO    : Bus 53001	: V=1.0107223, theta=-61.033867 -> V=1.0, theta=0.0
% INFO    : Bus 53002	: V=1.0107011, theta=-61.037938 -> V=1.0, theta=0.0
% INFO    : Bus 53003	: V=1.0190028, theta=-69.252089 -> V=1.0, theta=0.0
% INFO    : Bus 53004	: V=1.0050328, theta=-65.412284 -> V=1.0, theta=0.0
% INFO    : Bus 53005	: V=1.0067951, theta=-61.943259 -> V=1.0, theta=0.0
% INFO    : Bus 53006	: V=1.0069117, theta=-61.933802 -> V=1.0, theta=0.0
% INFO    : Bus 53007	: V=1.0149104, theta=-59.044768 -> V=1.0, theta=0.0
% INFO    : Bus 53008	: V=1.0207376, theta=-65.365988 -> V=1.0, theta=0.0
% INFO    : Bus 53009	: V=1.0207508, theta=-65.362666 -> V=1.0, theta=0.0
% INFO    : Bus 53010	: V=1.0116241, theta=-70.573778 -> V=1.0, theta=0.0
% INFO    : Bus 53011	: V=1.0115752, theta=-70.577222 -> V=1.0, theta=0.0
% INFO    : Bus 53012	: V=1.0110733, theta=-70.874654 -> V=1.0, theta=0.0
% INFO    : Bus 53013	: V=1.0178816, theta=-66.382585 -> V=1.0, theta=0.0
% INFO    : Bus 53014	: V=1.0084341, theta=-61.446309 -> V=1.0, theta=0.0
% INFO    : Bus 53015	: V=1.008381, theta=-61.452179 -> V=1.0, theta=0.0
% INFO    : Bus 53016	: V=1.0161115, theta=-69.668024 -> V=1.0, theta=0.0
% INFO    : Bus 53017	: V=1.0161416, theta=-69.6655 -> V=1.0, theta=0.0
% INFO    : Bus 53018	: V=1.0160851, theta=-69.670552 -> V=1.0, theta=0.0
% INFO    : Bus 53019	: V=1.0133299, theta=-70.048294 -> V=1.0, theta=0.0
% INFO    : Bus 53020	: V=1.0065584, theta=-63.446963 -> V=1.0, theta=0.0
% INFO    : Bus 53021	: V=1.0201702, theta=-67.281457 -> V=1.0, theta=0.0
% INFO    : Bus 53022	: V=1.0013263, theta=-65.658293 -> V=1.0, theta=0.0
% INFO    : Bus 53023	: V=0.9986129, theta=-65.608724 -> V=1.0, theta=0.0
% INFO    : Bus 53024	: V=0.9945708, theta=-64.333005 -> V=1.0, theta=0.0
% INFO    : Bus 53025	: V=0.9944176, theta=-64.346199 -> V=1.0, theta=0.0
% INFO    : Bus 53026	: V=0.9935429, theta=-64.689916 -> V=1.0, theta=0.0
% INFO    : Bus 53027	: V=1.0171266, theta=-71.085742 -> V=1.0, theta=0.0
% INFO    : Bus 53028	: V=1.0158974, theta=-63.09984 -> V=1.0, theta=0.0
% INFO    : Bus 53029	: V=1.0064008, theta=-65.826562 -> V=1.0, theta=0.0
% INFO    : Bus 53030	: V=1.0209595, theta=-63.385503 -> V=1.0, theta=0.0
% INFO    : Bus 53031	: V=0.9990317, theta=-63.679904 -> V=1.0, theta=0.0
% INFO    : Bus 53032	: V=1.0015518, theta=-65.977139 -> V=1.0, theta=0.0
% INFO    : Bus 53033	: V=1.0189319, theta=-70.606793 -> V=1.0, theta=0.0
% INFO    : Bus 53034	: V=1.0188876, theta=-70.610957 -> V=1.0, theta=0.0
% INFO    : Bus 53035	: V=1.0151131, theta=-73.677099 -> V=1.0, theta=0.0
% INFO    : Bus 53036	: V=1.0269004, theta=-68.919755 -> V=1.0, theta=0.0
% INFO    : Bus 53037	: V=1.0265586, theta=-70.995352 -> V=1.0, theta=0.0
% INFO    : Bus 53038	: V=1.0267681, theta=-68.934676 -> V=1.0, theta=0.0
% INFO    : Bus 53039	: V=1.0238135, theta=-71.019771 -> V=1.0, theta=0.0
% INFO    : Bus 53040	: V=1.0222743, theta=-64.980244 -> V=1.0, theta=0.0
% INFO    : Bus 53041	: V=1.0032466, theta=-67.839893 -> V=1.0, theta=0.0
% INFO    : Bus 53042	: V=1.0240603, theta=-64.734882 -> V=1.0, theta=0.0
% INFO    : Bus 53043	: V=1.0240603, theta=-64.734882 -> V=1.0, theta=0.0
% INFO    : Bus 53044	: V=1.0187578, theta=-58.049724 -> V=1.0, theta=0.0
% INFO    : Bus 53045	: V=1.0053325, theta=-62.838404 -> V=1.0, theta=0.0
% INFO    : Bus 53046	: V=0.9990845, theta=-71.536108 -> V=1.0, theta=0.0
% INFO    : Bus 53047	: V=1.0003214, theta=-71.262337 -> V=1.0, theta=0.0
% INFO    : Bus 53048	: V=0.9972434, theta=-64.540375 -> V=1.0, theta=0.0
% INFO    : Bus 53049	: V=0.9970605, theta=-64.55857 -> V=1.0, theta=0.0
% INFO    : Bus 53050	: V=1.0062767, theta=-61.663169 -> V=1.0, theta=0.0
% INFO    : Bus 53051	: V=1.0063893, theta=-61.652979 -> V=1.0, theta=0.0
% INFO    : Bus 53052	: V=1.0078224, theta=-76.472266 -> V=1.0, theta=0.0
% INFO    : Bus 53053	: V=1.0077305, theta=-76.486727 -> V=1.0, theta=0.0
% INFO    : Bus 53054	: V=1.0340075, theta=-64.073817 -> V=1.0, theta=0.0
% INFO    : Bus 53055	: V=1.000926, theta=-63.655864 -> V=1.0, theta=0.0
% INFO    : Bus 53056	: V=1.0007319, theta=-63.672848 -> V=1.0, theta=0.0
% INFO    : Bus 53057	: V=1.0011137, theta=-63.639767 -> V=1.0, theta=0.0
% INFO    : Bus 53058	: V=1.0244214, theta=-59.631395 -> V=1.0, theta=0.0
% INFO    : Bus 53059	: V=1.0244534, theta=-59.627103 -> V=1.0, theta=0.0
% INFO    : Bus 53060	: V=1.0072634, theta=-61.211345 -> V=1.0, theta=0.0
% INFO    : Bus 53061	: V=1.0072008, theta=-61.219908 -> V=1.0, theta=0.0
% INFO    : Bus 53062	: V=1.0073256, theta=-61.203109 -> V=1.0, theta=0.0
% INFO    : Bus 53063	: V=1.0138484, theta=-61.547493 -> V=1.0, theta=0.0
% INFO    : Bus 53064	: V=1.0184893, theta=-60.595247 -> V=1.0, theta=0.0
% INFO    : Bus 53065	: V=1.0229622, theta=-60.225272 -> V=1.0, theta=0.0
% INFO    : Bus 53066	: V=1.0091429, theta=-60.62927 -> V=1.0, theta=0.0
% INFO    : Bus 53067	: V=1.0090033, theta=-60.653816 -> V=1.0, theta=0.0
% INFO    : Bus 53068	: V=1.007669, theta=-60.682414 -> V=1.0, theta=0.0
% INFO    : Bus 53069	: V=1.0074993, theta=-60.699615 -> V=1.0, theta=0.0
% INFO    : Bus 53070	: V=1.0078269, theta=-60.666279 -> V=1.0, theta=0.0
% INFO    : Bus 53071	: V=1.0028044, theta=-61.906895 -> V=1.0, theta=0.0
% INFO    : Bus 53072	: V=1.0038308, theta=-61.7183 -> V=1.0, theta=0.0
% INFO    : Bus 53073	: V=1.0064148, theta=-61.652197 -> V=1.0, theta=0.0
% INFO    : Bus 53074	: V=1.0062426, theta=-61.666901 -> V=1.0, theta=0.0
% INFO    : Bus 53075	: V=1.0041532, theta=-61.890463 -> V=1.0, theta=0.0
% INFO    : Bus 53076	: V=1.0079869, theta=-60.862807 -> V=1.0, theta=0.0
% INFO    : Bus 53077	: V=1.0078715, theta=-60.882372 -> V=1.0, theta=0.0
% INFO    : Bus 53078	: V=1.0080938, theta=-60.845258 -> V=1.0, theta=0.0
% INFO    : Bus 53079	: V=1.0225253, theta=-59.40807 -> V=1.0, theta=0.0
% INFO    : Bus 53080	: V=1.0227212, theta=-59.393701 -> V=1.0, theta=0.0
% INFO    : Bus 53081	: V=1.0090458, theta=-61.224413 -> V=1.0, theta=0.0
% INFO    : Bus 53082	: V=1.0051128, theta=-61.222138 -> V=1.0, theta=0.0
% INFO    : Bus 53083	: V=1.010431, theta=-60.620797 -> V=1.0, theta=0.0
% INFO    : Bus 53084	: V=1.0102745, theta=-60.636345 -> V=1.0, theta=0.0
% INFO    : Bus 53085	: V=1.0097746, theta=-60.510331 -> V=1.0, theta=0.0
% INFO    : Bus 53086	: V=1.0063098, theta=-61.221512 -> V=1.0, theta=0.0
% INFO    : Bus 53087	: V=1.0061931, theta=-61.238386 -> V=1.0, theta=0.0
% INFO    : Bus 53088	: V=1.0079568, theta=-61.113551 -> V=1.0, theta=0.0
% INFO    : Bus 53089	: V=1.0077832, theta=-61.125451 -> V=1.0, theta=0.0
% INFO    : Bus 53090	: V=1.0215275, theta=-60.416501 -> V=1.0, theta=0.0
% INFO    : Bus 53091	: V=1.0214488, theta=-60.423687 -> V=1.0, theta=0.0
% INFO    : Bus 53092	: V=1.0216104, theta=-60.408487 -> V=1.0, theta=0.0
% INFO    : Bus 53093	: V=1.0290284, theta=-75.093956 -> V=1.0, theta=0.0
% INFO    : Bus 53094	: V=1.0289357, theta=-75.104367 -> V=1.0, theta=0.0
% INFO    : Bus 53095	: V=1.0072065, theta=-60.8943 -> V=1.0, theta=0.0
% INFO    : Bus 53096	: V=1.0074447, theta=-60.869383 -> V=1.0, theta=0.0
% INFO    : Bus 53097	: V=1.0128459, theta=-60.132301 -> V=1.0, theta=0.0
% INFO    : Bus 53098	: V=1.0130698, theta=-60.109939 -> V=1.0, theta=0.0
% INFO    : Bus 53099	: V=1.0212218, theta=-75.573077 -> V=1.0, theta=0.0
% INFO    : Bus 53100	: V=1.0212039, theta=-75.574901 -> V=1.0, theta=0.0
% INFO    : Bus 53101	: V=1.0092241, theta=-60.733174 -> V=1.0, theta=0.0
% INFO    : Bus 53102	: V=1.009135, theta=-60.745367 -> V=1.0, theta=0.0
% INFO    : Bus 53103	: V=1.0081168, theta=-60.707787 -> V=1.0, theta=0.0
% INFO    : Bus 53104	: V=1.0079676, theta=-60.718244 -> V=1.0, theta=0.0
% INFO    : Bus 53105	: V=1.016153, theta=-60.134322 -> V=1.0, theta=0.0
% INFO    : Bus 53106	: V=1.0161911, theta=-60.127073 -> V=1.0, theta=0.0
% INFO    : Bus 53107	: V=1.0115073, theta=-60.408587 -> V=1.0, theta=0.0
% INFO    : Bus 53108	: V=1.0114219, theta=-60.422732 -> V=1.0, theta=0.0
% INFO    : Bus 53109	: V=1.0128574, theta=-60.164867 -> V=1.0, theta=0.0
% INFO    : Bus 53110	: V=1.0129284, theta=-60.152038 -> V=1.0, theta=0.0
% INFO    : Bus 53111	: V=1.0116066, theta=-60.409661 -> V=1.0, theta=0.0
% INFO    : Bus 53112	: V=1.0202869, theta=-74.0246 -> V=1.0, theta=0.0
% INFO    : Bus 53113	: V=1.0167223, theta=-74.22531 -> V=1.0, theta=0.0
% INFO    : Bus 53114	: V=1.0291422, theta=-60.508505 -> V=1.0, theta=0.0
% INFO    : Bus 53115	: V=1.0136575, theta=-60.491218 -> V=1.0, theta=0.0
% INFO    : Bus 53116	: V=1.0137868, theta=-60.471408 -> V=1.0, theta=0.0
% INFO    : Bus 53117	: V=1.0152576, theta=-75.311225 -> V=1.0, theta=0.0
% INFO    : Bus 53118	: V=1.0152315, theta=-75.314374 -> V=1.0, theta=0.0
% INFO    : Bus 53119	: V=1.0087891, theta=-60.50705 -> V=1.0, theta=0.0
% INFO    : Bus 53120	: V=1.0326883, theta=-75.543535 -> V=1.0, theta=0.0
% INFO    : Bus 53121	: V=1.0097216, theta=-60.463123 -> V=1.0, theta=0.0
% INFO    : Bus 53122	: V=1.0093065, theta=-60.48614 -> V=1.0, theta=0.0
% INFO    : Bus 53123	: V=1.0120396, theta=-60.314403 -> V=1.0, theta=0.0
% INFO    : Bus 53124	: V=1.0117283, theta=-60.336591 -> V=1.0, theta=0.0
% INFO    : Bus 53125	: V=1.0141574, theta=-60.271405 -> V=1.0, theta=0.0
% INFO    : Bus 53126	: V=1.0141316, theta=-60.275452 -> V=1.0, theta=0.0
% INFO    : Bus 53127	: V=1.0122165, theta=-60.439826 -> V=1.0, theta=0.0
% INFO    : Bus 53128	: V=1.0141514, theta=-60.020959 -> V=1.0, theta=0.0
% INFO    : Bus 53129	: V=1.0265669, theta=-60.859337 -> V=1.0, theta=0.0
% INFO    : Bus 53130	: V=1.0265264, theta=-60.862867 -> V=1.0, theta=0.0
% INFO    : Bus 53131	: V=1.021475, theta=-73.751545 -> V=1.0, theta=0.0
% INFO    : Bus 53132	: V=1.0125198, theta=-74.247295 -> V=1.0, theta=0.0
% INFO    : Bus 53133	: V=1.01392, theta=-60.00645 -> V=1.0, theta=0.0
% INFO    : Bus 53134	: V=1.013752, theta=-60.030137 -> V=1.0, theta=0.0
% INFO    : Bus 53135	: V=1.0226228, theta=-56.44607 -> V=1.0, theta=0.0
% INFO    : Bus 53136	: V=1.0193437, theta=-59.077944 -> V=1.0, theta=0.0
% INFO    : Bus 53137	: V=1.0182078, theta=-73.832445 -> V=1.0, theta=0.0
% INFO    : Bus 53138	: V=1.0206833, theta=-73.171776 -> V=1.0, theta=0.0
% INFO    : Bus 53139	: V=1.041564, theta=-61.543196 -> V=1.0, theta=0.0
% INFO    : Bus 53140	: V=1.016079, theta=-59.487437 -> V=1.0, theta=0.0
% INFO    : Bus 53141	: V=1.0159138, theta=-59.509785 -> V=1.0, theta=0.0
% INFO    : Bus 53142	: V=1.0270826, theta=-73.541357 -> V=1.0, theta=0.0
% INFO    : Bus 53143	: V=1.0126477, theta=-74.168335 -> V=1.0, theta=0.0
% INFO    : Bus 53144	: V=1.0161823, theta=-74.113458 -> V=1.0, theta=0.0
% INFO    : Bus 53145	: V=1.0160797, theta=-74.124631 -> V=1.0, theta=0.0
% INFO    : Bus 53146	: V=1.0162837, theta=-74.102776 -> V=1.0, theta=0.0
% INFO    : Bus 53147	: V=1.0351455, theta=-66.425364 -> V=1.0, theta=0.0
% INFO    : Bus 53148	: V=1.0067402, theta=-60.174832 -> V=1.0, theta=0.0
% INFO    : Bus 53149	: V=1.0235566, theta=-60.437555 -> V=1.0, theta=0.0
% INFO    : Bus 53150	: V=1.0063379, theta=-60.011587 -> V=1.0, theta=0.0
% INFO    : Bus 53151	: V=1.0237037, theta=-71.334084 -> V=1.0, theta=0.0
% INFO    : Bus 53152	: V=1.0239483, theta=-71.313824 -> V=1.0, theta=0.0
% INFO    : Bus 53153	: V=1.0293569, theta=-53.360768 -> V=1.0, theta=0.0
% INFO    : Bus 53154	: V=1.0277898, theta=-74.847883 -> V=1.0, theta=0.0
% INFO    : Bus 53155	: V=1.0278787, theta=-74.83211 -> V=1.0, theta=0.0
% INFO    : Bus 53156	: V=1.0140475, theta=-59.769895 -> V=1.0, theta=0.0
% INFO    : Bus 53157	: V=1.0138843, theta=-59.787726 -> V=1.0, theta=0.0
% INFO    : Bus 53158	: V=1.0139487, theta=-59.760637 -> V=1.0, theta=0.0
% INFO    : Bus 53159	: V=1.0113944, theta=-59.822052 -> V=1.0, theta=0.0
% INFO    : Bus 53160	: V=1.0313061, theta=-71.22864 -> V=1.0, theta=0.0
% INFO    : Bus 53161	: V=1.0312387, theta=-71.235096 -> V=1.0, theta=0.0
% INFO    : Bus 53162	: V=1.031382, theta=-71.220994 -> V=1.0, theta=0.0
% INFO    : Bus 53163	: V=1.0313061, theta=-71.22864 -> V=1.0, theta=0.0
% INFO    : Bus 53164	: V=1.0314297, theta=-70.685491 -> V=1.0, theta=0.0
% INFO    : Bus 53165	: V=1.0124429, theta=-59.030896 -> V=1.0, theta=0.0
% INFO    : Bus 53166	: V=1.0125014, theta=-59.026487 -> V=1.0, theta=0.0
% INFO    : Bus 53167	: V=1.0225133, theta=-59.254619 -> V=1.0, theta=0.0
% INFO    : Bus 53168	: V=1.0330993, theta=-70.501102 -> V=1.0, theta=0.0
% INFO    : Bus 53169	: V=1.0331139, theta=-70.498496 -> V=1.0, theta=0.0
% INFO    : Bus 53170	: V=1.0330812, theta=-70.503501 -> V=1.0, theta=0.0
% INFO    : Bus 53171	: V=1.0179294, theta=-57.369605 -> V=1.0, theta=0.0
% INFO    : Bus 53172	: V=1.0384224, theta=-69.227567 -> V=1.0, theta=0.0
% INFO    : Bus 53173	: V=1.0384433, theta=-69.224563 -> V=1.0, theta=0.0
% INFO    : Bus 53174	: V=1.022194, theta=-66.680267 -> V=1.0, theta=0.0
% INFO    : Bus 53175	: V=1.0169562, theta=-66.980347 -> V=1.0, theta=0.0
% INFO    : Bus 53176	: V=1.0256476, theta=-53.965194 -> V=1.0, theta=0.0
% INFO    : Bus 53177	: V=1.025564, theta=-53.970176 -> V=1.0, theta=0.0
% INFO    : Bus 53178	: V=1.0305814, theta=-47.24488 -> V=1.0, theta=0.0
% INFO    : Bus 53179	: V=1.0201556, theta=-55.870376 -> V=1.0, theta=0.0
% INFO    : Bus 53180	: V=1.008378, theta=-51.527308 -> V=1.0, theta=0.0
% INFO    : Bus 53181	: V=1.0082517, theta=-51.540087 -> V=1.0, theta=0.0
% INFO    : Bus 53182	: V=1.0216086, theta=-55.784177 -> V=1.0, theta=0.0
% INFO    : Bus 53183	: V=1.0324984, theta=-65.41467 -> V=1.0, theta=0.0
% INFO    : Bus 53184	: V=1.0325464, theta=-65.406721 -> V=1.0, theta=0.0
% INFO    : Bus 53185	: V=1.0324602, theta=-65.422128 -> V=1.0, theta=0.0
% INFO    : Bus 53186	: V=1.0176997, theta=-46.649305 -> V=1.0, theta=0.0
% INFO    : Bus 53187	: V=1.0129406, theta=-47.510562 -> V=1.0, theta=0.0
% INFO    : Bus 53188	: V=1.0128437, theta=-47.049374 -> V=1.0, theta=0.0
% INFO    : Bus 53189	: V=1.0235772, theta=-53.329091 -> V=1.0, theta=0.0
% INFO    : Bus 53190	: V=1.0235375, theta=-53.334184 -> V=1.0, theta=0.0
% INFO    : Bus 53191	: V=1.0315626, theta=-63.717812 -> V=1.0, theta=0.0
% INFO    : Bus 53192	: V=1.0316694, theta=-63.702425 -> V=1.0, theta=0.0
% INFO    : Bus 53193	: V=1.031456, theta=-63.731485 -> V=1.0, theta=0.0
% INFO    : Bus 53194	: V=1.0309353, theta=-45.195555 -> V=1.0, theta=0.0
% INFO    : Bus 53195	: V=1.0283041, theta=-54.49735 -> V=1.0, theta=0.0
% INFO    : Bus 53196	: V=1.028289, theta=-54.49965 -> V=1.0, theta=0.0
% INFO    : Bus 53197	: V=1.0283212, theta=-54.494849 -> V=1.0, theta=0.0
% INFO    : Bus 53198	: V=1.034109, theta=-44.844546 -> V=1.0, theta=0.0
% INFO    : Bus 53199	: V=1.0341496, theta=-44.83823 -> V=1.0, theta=0.0
% INFO    : Bus 53200	: V=1.0102207, theta=-54.711377 -> V=1.0, theta=0.0
% INFO    : Bus 53201	: V=1.0102583, theta=-54.707253 -> V=1.0, theta=0.0
% INFO    : Bus 53202	: V=1.0199661, theta=-49.294799 -> V=1.0, theta=0.0
% INFO    : Bus 53203	: V=1.0034685, theta=-55.276482 -> V=1.0, theta=0.0
% INFO    : Bus 53204	: V=1.024635, theta=-58.027236 -> V=1.0, theta=0.0
% INFO    : Bus 53205	: V=1.0246199, theta=-58.028699 -> V=1.0, theta=0.0
% INFO    : Bus 53206	: V=1.0128043, theta=-54.282597 -> V=1.0, theta=0.0
% INFO    : Bus 53207	: V=1.0127554, theta=-54.288223 -> V=1.0, theta=0.0
% INFO    : Bus 53208	: V=1.0128571, theta=-54.276772 -> V=1.0, theta=0.0
% INFO    : Bus 53209	: V=1.0293973, theta=-53.076722 -> V=1.0, theta=0.0
% INFO    : Bus 53210	: V=1.0080497, theta=-54.961925 -> V=1.0, theta=0.0
% INFO    : Bus 53211	: V=1.0306773, theta=-46.179473 -> V=1.0, theta=0.0
% INFO    : Bus 53212	: V=1.031886, theta=-41.747934 -> V=1.0, theta=0.0
% INFO    : Bus 53213	: V=1.0349388, theta=-42.344629 -> V=1.0, theta=0.0
% INFO    : Bus 53214	: V=1.03505, theta=-44.264756 -> V=1.0, theta=0.0
% INFO    : Bus 53215	: V=1.031886, theta=-41.747934 -> V=1.0, theta=0.0
% INFO    : Bus 53216	: V=0.9774982, theta=-41.294341 -> V=1.0, theta=0.0
% INFO    : Bus 53217	: V=0.9714105, theta=-40.902876 -> V=1.0, theta=0.0
% INFO    : Bus 53218	: V=0.9778099, theta=-41.417022 -> V=1.0, theta=0.0
% INFO    : Bus 53219	: V=1.0351885, theta=-42.34435 -> V=1.0, theta=0.0
% INFO    : Bus 53220	: V=1.0328816, theta=-41.8845 -> V=1.0, theta=0.0
% INFO    : Bus 53221	: V=1.0361279, theta=-45.851394 -> V=1.0, theta=0.0
% INFO    : Bus 53222	: V=1.0211918, theta=-39.279109 -> V=1.0, theta=0.0
% INFO    : Bus 53223	: V=1.0216433, theta=-43.524442 -> V=1.0, theta=0.0
% INFO    : Bus 53224	: V=1.0180424, theta=-41.642747 -> V=1.0, theta=0.0
% INFO    : Bus 53225	: V=1.0361049, theta=-45.884569 -> V=1.0, theta=0.0
% INFO    : Bus 53226	: V=1.0317325, theta=-70.279031 -> V=1.0, theta=0.0
% INFO    : Bus 53227	: V=1.0317325, theta=-70.279031 -> V=1.0, theta=0.0
% INFO    : Bus 53228	: V=1.0453005, theta=-48.246685 -> V=1.0, theta=0.0
% INFO    : Bus 53229	: V=1.0415871, theta=-49.770698 -> V=1.0, theta=0.0
% INFO    : Bus 53230	: V=1.0359918, theta=-51.949311 -> V=1.0, theta=0.0
% INFO    : Bus 53231	: V=1.0319675, theta=-53.893947 -> V=1.0, theta=0.0
% INFO    : Bus 53232	: V=1.0328704, theta=-53.620048 -> V=1.0, theta=0.0
% INFO    : Bus 53233	: V=1.0236293, theta=-47.059608 -> V=1.0, theta=0.0
% INFO    : Bus 53234	: V=1.0468799, theta=-48.080828 -> V=1.0, theta=0.0
% INFO    : Bus 53235	: V=1.0453005, theta=-48.246685 -> V=1.0, theta=0.0
% INFO    : Bus 53236	: V=1.0367523, theta=-63.171022 -> V=1.0, theta=0.0
% INFO    : Bus 53237	: V=1.0367403, theta=-63.179237 -> V=1.0, theta=0.0
% INFO    : Bus 53238	: V=1.0192147, theta=-67.271478 -> V=1.0, theta=0.0
% INFO    : Bus 53239	: V=1.0195505, theta=-71.133952 -> V=1.0, theta=0.0
% INFO    : Bus 53240	: V=1.0400462, theta=-74.989853 -> V=1.0, theta=0.0
% INFO    : Bus 53241	: V=1.0107835, theta=-66.132113 -> V=1.0, theta=0.0
% INFO    : Bus 53242	: V=1.0077934, theta=-66.477089 -> V=1.0, theta=0.0
% INFO    : Bus 53243	: V=1.00902, theta=-66.334586 -> V=1.0, theta=0.0
% INFO    : Bus 53244	: V=1.007755, theta=-66.470166 -> V=1.0, theta=0.0
% INFO    : Bus 53245	: V=1.0183238, theta=-71.182589 -> V=1.0, theta=0.0
% INFO    : Bus 53246	: V=1.04, theta=-59.998895 -> V=1.0, theta=0.0
% INFO    : Bus 53247	: V=1.0398701, theta=-60.050986 -> V=1.0, theta=0.0
% INFO    : Bus 53248	: V=1.0224601, theta=-60.443011 -> V=1.0, theta=0.0
% INFO    : Bus 53249	: V=1.0222256, theta=-60.460102 -> V=1.0, theta=0.0
% INFO    : Bus 53250	: V=1.02, theta=-64.714043 -> V=1.0, theta=0.0
% INFO    : Bus 53251	: V=1.0219108, theta=-65.698392 -> V=1.0, theta=0.0
% INFO    : Bus 53252	: V=1.022586, theta=-66.513066 -> V=1.0, theta=0.0
% INFO    : Bus 53253	: V=1.0352924, theta=-63.127733 -> V=1.0, theta=0.0
% INFO    : Bus 53254	: V=1.02, theta=-64.714043 -> V=1.0, theta=0.0
% INFO    : Bus 53255	: V=1.0374534, theta=-62.73395 -> V=1.0, theta=0.0
% INFO    : Bus 53256	: V=1.0219551, theta=-65.766433 -> V=1.0, theta=0.0
% INFO    : Bus 53257	: V=1.0418314, theta=-55.727035 -> V=1.0, theta=0.0
% INFO    : Bus 53258	: V=1.0271229, theta=-59.310467 -> V=1.0, theta=0.0
% INFO    : Bus 53259	: V=1.0183982, theta=-62.211411 -> V=1.0, theta=0.0
% INFO    : Bus 53260	: V=1.0183982, theta=-62.211411 -> V=1.0, theta=0.0
% INFO    : Bus 53261	: V=1.0814278, theta=-50.495623 -> V=1.0, theta=0.0
% INFO    : Bus 53262	: V=1.0299129, theta=-75.172935 -> V=1.0, theta=0.0
% INFO    : Bus 53263	: V=1.0117066, theta=-73.196946 -> V=1.0, theta=0.0
% INFO    : Bus 53264	: V=1.0112686, theta=-71.395059 -> V=1.0, theta=0.0
% INFO    : Bus 53265	: V=1.0298708, theta=-75.187989 -> V=1.0, theta=0.0
% INFO    : Bus 53266	: V=1.0196823, theta=-56.293338 -> V=1.0, theta=0.0
% INFO    : Bus 53267	: V=1.0121762, theta=-59.991503 -> V=1.0, theta=0.0
% INFO    : Bus 53268	: V=1.0065285, theta=-52.999943 -> V=1.0, theta=0.0
% INFO    : Bus 53269	: V=1.0100073, theta=-53.225288 -> V=1.0, theta=0.0
% INFO    : Bus 53270	: V=1.0213825, theta=-59.018565 -> V=1.0, theta=0.0
% INFO    : Bus 53271	: V=1.0283868, theta=-61.851293 -> V=1.0, theta=0.0
% INFO    : Bus 53272	: V=1.021017, theta=-59.024851 -> V=1.0, theta=0.0
% INFO    : Bus 53273	: V=1.0257003, theta=-53.755588 -> V=1.0, theta=0.0
% INFO    : Bus 53274	: V=1.0234745, theta=-56.276527 -> V=1.0, theta=0.0
% INFO    : Bus 53275	: V=1.0231015, theta=-57.600617 -> V=1.0, theta=0.0
% INFO    : Bus 53276	: V=1.0231015, theta=-57.600617 -> V=1.0, theta=0.0
% INFO    : Bus 53277	: V=1.0198833, theta=-51.636881 -> V=1.0, theta=0.0
% INFO    : Bus 53278	: V=1.03686, theta=-44.387698 -> V=1.0, theta=0.0
% INFO    : Bus 53279	: V=1.0361584, theta=-45.510654 -> V=1.0, theta=0.0
% INFO    : Bus 53280	: V=1.0364099, theta=-45.029905 -> V=1.0, theta=0.0
% INFO    : Bus 53281	: V=1.0364099, theta=-45.029905 -> V=1.0, theta=0.0
% INFO    : Bus 53282	: V=1.0308384, theta=-65.202851 -> V=1.0, theta=0.0
% INFO    : Bus 53283	: V=1.034275, theta=-64.952259 -> V=1.0, theta=0.0
% INFO    : Bus 53284	: V=1.0377804, theta=-64.476933 -> V=1.0, theta=0.0
% INFO    : Bus 53285	: V=1.0377804, theta=-64.476933 -> V=1.0, theta=0.0
% INFO    : Bus 53286	: V=1.0293705, theta=-65.35989 -> V=1.0, theta=0.0
% INFO    : Bus 53287	: V=1.0312766, theta=-65.251382 -> V=1.0, theta=0.0
% INFO    : Bus 53288	: V=1.0350247, theta=-63.165324 -> V=1.0, theta=0.0
% INFO    : Bus 53289	: V=1.0377597, theta=-60.072997 -> V=1.0, theta=0.0
% INFO    : Bus 53290	: V=1.02214, theta=-70.186623 -> V=1.0, theta=0.0
% INFO    : Bus 53291	: V=1.0327835, theta=-72.623447 -> V=1.0, theta=0.0
% INFO    : Bus 53292	: V=1.0153374, theta=-65.85104 -> V=1.0, theta=0.0
% INFO    : Bus 53293	: V=1.0158794, theta=-67.16011 -> V=1.0, theta=0.0
% INFO    : Bus 53294	: V=1.0366829, theta=-40.749541 -> V=1.0, theta=0.0
% INFO    : Bus 53295	: V=1.0375246, theta=-42.326178 -> V=1.0, theta=0.0
% INFO    : Bus 53296	: V=1.0347213, theta=-44.551683 -> V=1.0, theta=0.0
% INFO    : Bus 53297	: V=1.0257458, theta=-38.753126 -> V=1.0, theta=0.0
% INFO    : Bus 53298	: V=1.0232172, theta=-39.599583 -> V=1.0, theta=0.0
% INFO    : Bus 53299	: V=1.0373706, theta=-41.283997 -> V=1.0, theta=0.0
% INFO    : Bus 53300	: V=1.0290441, theta=-68.495111 -> V=1.0, theta=0.0
% INFO    : Bus 53301	: V=1.0331079, theta=-69.90247 -> V=1.0, theta=0.0
% INFO    : Bus 53302	: V=1.0289639, theta=-68.495218 -> V=1.0, theta=0.0
% INFO    : Bus 53303	: V=1.0143, theta=-46.804285 -> V=1.0, theta=0.0
% INFO    : Bus 53304	: V=1.0141138, theta=-46.862891 -> V=1.0, theta=0.0
% INFO    : Bus 53305	: V=1.0439422, theta=-51.807365 -> V=1.0, theta=0.0
% INFO    : Bus 53306	: V=1.0296986, theta=-54.907223 -> V=1.0, theta=0.0
% INFO    : Bus 53307	: V=1.024426, theta=-59.220173 -> V=1.0, theta=0.0
% INFO    : Bus 60000	: V=1.0307152, theta=-48.415888 -> V=1.0, theta=0.0
% INFO    : Bus 60001	: V=0.9921306, theta=-50.997379 -> V=1.0, theta=0.0
% INFO    : Bus 60002	: V=0.992334, theta=-50.972225 -> V=1.0, theta=0.0
% INFO    : Bus 60003	: V=0.9919323, theta=-51.022091 -> V=1.0, theta=0.0
% INFO    : Bus 60004	: V=0.9978217, theta=-49.753771 -> V=1.0, theta=0.0
% INFO    : Bus 60005	: V=1.0406935, theta=-45.889078 -> V=1.0, theta=0.0
% INFO    : Bus 60006	: V=1.0378145, theta=-46.613446 -> V=1.0, theta=0.0
% INFO    : Bus 60007	: V=1.0285258, theta=-49.363855 -> V=1.0, theta=0.0
% INFO    : Bus 60008	: V=1.0221732, theta=-51.901511 -> V=1.0, theta=0.0
% INFO    : Bus 60009	: V=1.0221732, theta=-51.901511 -> V=1.0, theta=0.0
% INFO    : Bus 60010	: V=1.0378459, theta=-46.609258 -> V=1.0, theta=0.0
% INFO    : Bus 60011	: V=1.0115798, theta=-48.658899 -> V=1.0, theta=0.0
% INFO    : Bus 60012	: V=1.0077488, theta=-49.156881 -> V=1.0, theta=0.0
% INFO    : Bus 60013	: V=1.0115626, theta=-48.660043 -> V=1.0, theta=0.0
% INFO    : Bus 60014	: V=1.0115626, theta=-48.660043 -> V=1.0, theta=0.0
% INFO    : Bus 60015	: V=0.990545, theta=-50.986855 -> V=1.0, theta=0.0
% INFO    : Bus 60016	: V=1.0145207, theta=-44.498533 -> V=1.0, theta=0.0
% INFO    : Bus 60017	: V=1.0069755, theta=-48.355179 -> V=1.0, theta=0.0
% INFO    : Bus 60018	: V=1.002228, theta=-49.289743 -> V=1.0, theta=0.0
% INFO    : Bus 60019	: V=1.0020981, theta=-49.306215 -> V=1.0, theta=0.0
% INFO    : Bus 60020	: V=0.9990915, theta=-50.343059 -> V=1.0, theta=0.0
% INFO    : Bus 60021	: V=1.000909, theta=-49.630084 -> V=1.0, theta=0.0
% INFO    : Bus 60022	: V=0.9999782, theta=-50.03562 -> V=1.0, theta=0.0
% INFO    : Bus 60023	: V=1.0152038, theta=-47.900495 -> V=1.0, theta=0.0
% INFO    : Bus 60024	: V=1.0151768, theta=-47.904079 -> V=1.0, theta=0.0
% INFO    : Bus 60025	: V=1.0152268, theta=-47.897325 -> V=1.0, theta=0.0
% INFO    : Bus 60026	: V=1.0001097, theta=-49.64003 -> V=1.0, theta=0.0
% INFO    : Bus 60027	: V=1.0050001, theta=-48.745064 -> V=1.0, theta=0.0
% INFO    : Bus 60028	: V=1.00517, theta=-48.726304 -> V=1.0, theta=0.0
% INFO    : Bus 60029	: V=1.030084, theta=-45.69803 -> V=1.0, theta=0.0
% INFO    : Bus 60030	: V=1.030008, theta=-45.704095 -> V=1.0, theta=0.0
% INFO    : Bus 60031	: V=0.9991658, theta=-49.635935 -> V=1.0, theta=0.0
% INFO    : Bus 60032	: V=1.0264069, theta=-49.746596 -> V=1.0, theta=0.0
% INFO    : Bus 60033	: V=0.9977233, theta=-48.979829 -> V=1.0, theta=0.0
% INFO    : Bus 60034	: V=0.9976547, theta=-48.987845 -> V=1.0, theta=0.0
% INFO    : Bus 60035	: V=1.0289984, theta=-48.530487 -> V=1.0, theta=0.0
% INFO    : Bus 60036	: V=0.9895027, theta=-50.076973 -> V=1.0, theta=0.0
% INFO    : Bus 60037	: V=0.9893009, theta=-50.09706 -> V=1.0, theta=0.0
% INFO    : Bus 60038	: V=0.9896831, theta=-50.053739 -> V=1.0, theta=0.0
% INFO    : Bus 60039	: V=0.9895027, theta=-50.076973 -> V=1.0, theta=0.0
% INFO    : Bus 60040	: V=1.0017562, theta=-50.688981 -> V=1.0, theta=0.0
% INFO    : Bus 60041	: V=1.0018018, theta=-50.681725 -> V=1.0, theta=0.0
% INFO    : Bus 60042	: V=1.0017146, theta=-50.695383 -> V=1.0, theta=0.0
% INFO    : Bus 60043	: V=1.0017562, theta=-50.688981 -> V=1.0, theta=0.0
% INFO    : Bus 60044	: V=1.0081382, theta=-46.993161 -> V=1.0, theta=0.0
% INFO    : Bus 60045	: V=1.0100913, theta=-46.894571 -> V=1.0, theta=0.0
% INFO    : Bus 60046	: V=1.0099988, theta=-46.90362 -> V=1.0, theta=0.0
% INFO    : Bus 60047	: V=0.9919794, theta=-50.03537 -> V=1.0, theta=0.0
% INFO    : Bus 60048	: V=0.9919419, theta=-50.037893 -> V=1.0, theta=0.0
% INFO    : Bus 60049	: V=0.9920336, theta=-50.030126 -> V=1.0, theta=0.0
% INFO    : Bus 60050	: V=1.0185654, theta=-46.916053 -> V=1.0, theta=0.0
% INFO    : Bus 60051	: V=1.0184782, theta=-46.93388 -> V=1.0, theta=0.0
% INFO    : Bus 60052	: V=0.9978228, theta=-49.594398 -> V=1.0, theta=0.0
% INFO    : Bus 60053	: V=1.0274723, theta=-50.23953 -> V=1.0, theta=0.0
% INFO    : Bus 60054	: V=0.9979516, theta=-50.391175 -> V=1.0, theta=0.0
% INFO    : Bus 60055	: V=1.0221851, theta=-50.704654 -> V=1.0, theta=0.0
% INFO    : Bus 60056	: V=1.0164234, theta=-44.741043 -> V=1.0, theta=0.0
% INFO    : Bus 60057	: V=1.0536865, theta=-47.038253 -> V=1.0, theta=0.0
% INFO    : Bus 60058	: V=1.0304285, theta=-50.678508 -> V=1.0, theta=0.0
% INFO    : Bus 60059	: V=1.0231687, theta=-43.186334 -> V=1.0, theta=0.0
% INFO    : Bus 60060	: V=1.0146694, theta=-46.257431 -> V=1.0, theta=0.0
% INFO    : Bus 60061	: V=1.0236191, theta=-43.124987 -> V=1.0, theta=0.0
% INFO    : Bus 60062	: V=0.9917359, theta=-48.712294 -> V=1.0, theta=0.0
% INFO    : Bus 60063	: V=1.0193198, theta=-43.789403 -> V=1.0, theta=0.0
% INFO    : Bus 60064	: V=1.0024541, theta=-48.484402 -> V=1.0, theta=0.0
% INFO    : Bus 60065	: V=1.0182565, theta=-40.358721 -> V=1.0, theta=0.0
% INFO    : Bus 60066	: V=1.018112, theta=-40.379378 -> V=1.0, theta=0.0
% INFO    : Bus 60067	: V=1.0194877, theta=-44.38878 -> V=1.0, theta=0.0
% INFO    : Bus 60068	: V=1.0193726, theta=-44.395772 -> V=1.0, theta=0.0
% INFO    : Bus 60069	: V=1.019604, theta=-44.381726 -> V=1.0, theta=0.0
% INFO    : Bus 60070	: V=1.0315706, theta=-51.250185 -> V=1.0, theta=0.0
% INFO    : Bus 60071	: V=1.0028913, theta=-48.193972 -> V=1.0, theta=0.0
% INFO    : Bus 60072	: V=1.0028282, theta=-48.199458 -> V=1.0, theta=0.0
% INFO    : Bus 60073	: V=1.0192468, theta=-44.458233 -> V=1.0, theta=0.0
% INFO    : Bus 60074	: V=1.0201582, theta=-51.546823 -> V=1.0, theta=0.0
% INFO    : Bus 60075	: V=1.0199937, theta=-51.557695 -> V=1.0, theta=0.0
% INFO    : Bus 60076	: V=1.0183875, theta=-44.701677 -> V=1.0, theta=0.0
% INFO    : Bus 60077	: V=1.0255865, theta=-40.689027 -> V=1.0, theta=0.0
% INFO    : Bus 60078	: V=1.0255498, theta=-40.69245 -> V=1.0, theta=0.0
% INFO    : Bus 60079	: V=1.0027719, theta=-47.518854 -> V=1.0, theta=0.0
% INFO    : Bus 60080	: V=1.0173444, theta=-44.830673 -> V=1.0, theta=0.0
% INFO    : Bus 60081	: V=1.0172647, theta=-44.843686 -> V=1.0, theta=0.0
% INFO    : Bus 60082	: V=1.0166305, theta=-52.17153 -> V=1.0, theta=0.0
% INFO    : Bus 60083	: V=1.0164672, theta=-52.191494 -> V=1.0, theta=0.0
% INFO    : Bus 60084	: V=0.9942553, theta=-45.930713 -> V=1.0, theta=0.0
% INFO    : Bus 60085	: V=1.0104812, theta=-47.429925 -> V=1.0, theta=0.0
% INFO    : Bus 60086	: V=1.0105459, theta=-47.42217 -> V=1.0, theta=0.0
% INFO    : Bus 60087	: V=1.0104222, theta=-47.436801 -> V=1.0, theta=0.0
% INFO    : Bus 60088	: V=1.0067351, theta=-48.056618 -> V=1.0, theta=0.0
% INFO    : Bus 60089	: V=1.0094355, theta=-48.849099 -> V=1.0, theta=0.0
% INFO    : Bus 60090	: V=1.0220569, theta=-44.377484 -> V=1.0, theta=0.0
% INFO    : Bus 60091	: V=1.0285998, theta=-46.058541 -> V=1.0, theta=0.0
% INFO    : Bus 60092	: V=1.0286529, theta=-46.053664 -> V=1.0, theta=0.0
% INFO    : Bus 60093	: V=1.0371801, theta=-47.287995 -> V=1.0, theta=0.0
% INFO    : Bus 60094	: V=1.0371052, theta=-47.299897 -> V=1.0, theta=0.0
% INFO    : Bus 60095	: V=1.0058693, theta=-48.91524 -> V=1.0, theta=0.0
% INFO    : Bus 60096	: V=0.9881036, theta=-44.469864 -> V=1.0, theta=0.0
% INFO    : Bus 60097	: V=1.0449171, theta=-47.027075 -> V=1.0, theta=0.0
% INFO    : Bus 60098	: V=1.0339547, theta=-47.552178 -> V=1.0, theta=0.0
% INFO    : Bus 60099	: V=1.0336527, theta=-47.566484 -> V=1.0, theta=0.0
% INFO    : Bus 60100	: V=1.0342493, theta=-47.538739 -> V=1.0, theta=0.0
% INFO    : Bus 60101	: V=1.025599, theta=-45.611118 -> V=1.0, theta=0.0
% INFO    : Bus 60102	: V=1.0195348, theta=-50.921961 -> V=1.0, theta=0.0
% INFO    : Bus 60103	: V=1.0159062, theta=-46.094486 -> V=1.0, theta=0.0
% INFO    : Bus 60104	: V=1.0227908, theta=-43.44037 -> V=1.0, theta=0.0
% INFO    : Bus 60105	: V=1.0223736, theta=-52.513595 -> V=1.0, theta=0.0
% INFO    : Bus 60106	: V=1.010206, theta=-45.373078 -> V=1.0, theta=0.0
% INFO    : Bus 60107	: V=1.0106661, theta=-45.367792 -> V=1.0, theta=0.0
% INFO    : Bus 60108	: V=1.010206, theta=-45.373078 -> V=1.0, theta=0.0
% INFO    : Bus 60109	: V=1.0378306, theta=-47.03298 -> V=1.0, theta=0.0
% INFO    : Bus 60110	: V=1.032579, theta=-47.060409 -> V=1.0, theta=0.0
% INFO    : Bus 60111	: V=1.019484, theta=-45.993865 -> V=1.0, theta=0.0
% INFO    : Bus 60112	: V=1.0194535, theta=-46.000396 -> V=1.0, theta=0.0
% INFO    : Bus 60113	: V=1.0171038, theta=-50.54057 -> V=1.0, theta=0.0
% INFO    : Bus 60114	: V=1.0170173, theta=-50.550966 -> V=1.0, theta=0.0
% INFO    : Bus 60115	: V=1.0171818, theta=-50.530087 -> V=1.0, theta=0.0
% INFO    : Bus 60116	: V=1.0175852, theta=-51.48922 -> V=1.0, theta=0.0
% INFO    : Bus 60117	: V=1.0207728, theta=-48.881474 -> V=1.0, theta=0.0
% INFO    : Bus 60118	: V=1.014891, theta=-49.750192 -> V=1.0, theta=0.0
% INFO    : Bus 60119	: V=1.0149773, theta=-49.734692 -> V=1.0, theta=0.0
% INFO    : Bus 60120	: V=1.0147901, theta=-49.765074 -> V=1.0, theta=0.0
% INFO    : Bus 60121	: V=1.0102744, theta=-46.37061 -> V=1.0, theta=0.0
% INFO    : Bus 60122	: V=1.0100988, theta=-46.384575 -> V=1.0, theta=0.0
% INFO    : Bus 60123	: V=1.0131465, theta=-46.32766 -> V=1.0, theta=0.0
% INFO    : Bus 60124	: V=1.0131828, theta=-46.321493 -> V=1.0, theta=0.0
% INFO    : Bus 60125	: V=1.0131465, theta=-46.32766 -> V=1.0, theta=0.0
% INFO    : Bus 60126	: V=1.0202854, theta=-51.313782 -> V=1.0, theta=0.0
% INFO    : Bus 60127	: V=1.0201514, theta=-51.321617 -> V=1.0, theta=0.0
% INFO    : Bus 60128	: V=1.0234108, theta=-46.939914 -> V=1.0, theta=0.0
% INFO    : Bus 60129	: V=1.0233183, theta=-46.954371 -> V=1.0, theta=0.0
% INFO    : Bus 60130	: V=1.0189818, theta=-51.494676 -> V=1.0, theta=0.0
% INFO    : Bus 60131	: V=1.0189818, theta=-51.494676 -> V=1.0, theta=0.0
% INFO    : Bus 60132	: V=1.0189818, theta=-51.494676 -> V=1.0, theta=0.0
% INFO    : Bus 60133	: V=1.0189818, theta=-51.494676 -> V=1.0, theta=0.0
% INFO    : Bus 60134	: V=1.0154609, theta=-49.989956 -> V=1.0, theta=0.0
% INFO    : Bus 60135	: V=1.0147538, theta=-53.004368 -> V=1.0, theta=0.0
% INFO    : Bus 60136	: V=1.0248431, theta=-50.902831 -> V=1.0, theta=0.0
% INFO    : Bus 60137	: V=1.0248167, theta=-50.906432 -> V=1.0, theta=0.0
% INFO    : Bus 60138	: V=1.0232098, theta=-50.257103 -> V=1.0, theta=0.0
% INFO    : Bus 60139	: V=1.0232406, theta=-50.251737 -> V=1.0, theta=0.0
% INFO    : Bus 60140	: V=1.0229816, theta=-49.584578 -> V=1.0, theta=0.0
% INFO    : Bus 60141	: V=1.0230212, theta=-49.580954 -> V=1.0, theta=0.0
% INFO    : Bus 60142	: V=1.0336016, theta=-49.657969 -> V=1.0, theta=0.0
% INFO    : Bus 60143	: V=1.0381289, theta=-48.537453 -> V=1.0, theta=0.0
% INFO    : Bus 60144	: V=1.0381028, theta=-48.540683 -> V=1.0, theta=0.0
% INFO    : Bus 60145	: V=1.0381589, theta=-48.534219 -> V=1.0, theta=0.0
% INFO    : Bus 60146	: V=1.0163706, theta=-51.744018 -> V=1.0, theta=0.0
% INFO    : Bus 60147	: V=1.0162562, theta=-51.751787 -> V=1.0, theta=0.0
% INFO    : Bus 60148	: V=1.0164742, theta=-51.736194 -> V=1.0, theta=0.0
% INFO    : Bus 60149	: V=1.0252463, theta=-52.968135 -> V=1.0, theta=0.0
% INFO    : Bus 60150	: V=1.02509, theta=-52.982811 -> V=1.0, theta=0.0
% INFO    : Bus 60151	: V=1.0170383, theta=-51.799275 -> V=1.0, theta=0.0
% INFO    : Bus 60152	: V=1.0213645, theta=-49.646903 -> V=1.0, theta=0.0
% INFO    : Bus 60153	: V=1.0212887, theta=-49.652215 -> V=1.0, theta=0.0
% INFO    : Bus 60154	: V=1.0214507, theta=-49.641194 -> V=1.0, theta=0.0
% INFO    : Bus 60155	: V=1.0146209, theta=-55.699612 -> V=1.0, theta=0.0
% INFO    : Bus 60156	: V=1.0244459, theta=-49.463235 -> V=1.0, theta=0.0
% INFO    : Bus 60157	: V=1.0242578, theta=-49.486695 -> V=1.0, theta=0.0
% INFO    : Bus 60158	: V=1.0353795, theta=-45.45982 -> V=1.0, theta=0.0
% INFO    : Bus 60159	: V=1.0290523, theta=-48.935014 -> V=1.0, theta=0.0
% INFO    : Bus 60160	: V=1.0158719, theta=-51.871571 -> V=1.0, theta=0.0
% INFO    : Bus 60161	: V=1.0157208, theta=-51.891234 -> V=1.0, theta=0.0
% INFO    : Bus 60162	: V=1.0164786, theta=-51.886191 -> V=1.0, theta=0.0
% INFO    : Bus 60163	: V=1.0447973, theta=-46.728581 -> V=1.0, theta=0.0
% INFO    : Bus 60164	: V=1.027749, theta=-50.250195 -> V=1.0, theta=0.0
% INFO    : Bus 60165	: V=1.025247, theta=-50.641678 -> V=1.0, theta=0.0
% INFO    : Bus 60166	: V=1.0118338, theta=-51.546968 -> V=1.0, theta=0.0
% INFO    : Bus 60167	: V=1.0263776, theta=-50.372827 -> V=1.0, theta=0.0
% INFO    : Bus 60168	: V=1.027864, theta=-50.242983 -> V=1.0, theta=0.0
% INFO    : Bus 60169	: V=1.027749, theta=-50.250195 -> V=1.0, theta=0.0
% INFO    : Bus 60170	: V=1.0321317, theta=-52.619068 -> V=1.0, theta=0.0
% INFO    : Bus 60171	: V=1.0320844, theta=-52.623631 -> V=1.0, theta=0.0
% INFO    : Bus 60172	: V=1.0288288, theta=-50.284612 -> V=1.0, theta=0.0
% INFO    : Bus 60173	: V=1.0114935, theta=-52.104769 -> V=1.0, theta=0.0
% INFO    : Bus 60174	: V=1.0112912, theta=-52.132835 -> V=1.0, theta=0.0
% INFO    : Bus 60175	: V=1.0173401, theta=-51.225263 -> V=1.0, theta=0.0
% INFO    : Bus 60176	: V=1.0174682, theta=-51.207027 -> V=1.0, theta=0.0
% INFO    : Bus 60177	: V=1.0166861, theta=-51.736095 -> V=1.0, theta=0.0
% INFO    : Bus 60178	: V=1.0181737, theta=-51.04131 -> V=1.0, theta=0.0
% INFO    : Bus 60179	: V=1.0181074, theta=-51.050536 -> V=1.0, theta=0.0
% INFO    : Bus 60180	: V=1.0218936, theta=-53.479613 -> V=1.0, theta=0.0
% INFO    : Bus 60181	: V=1.0218064, theta=-53.493269 -> V=1.0, theta=0.0
% INFO    : Bus 60182	: V=1.0153579, theta=-51.774423 -> V=1.0, theta=0.0
% INFO    : Bus 60183	: V=1.015081, theta=-51.797702 -> V=1.0, theta=0.0
% INFO    : Bus 60184	: V=0.9922839, theta=-48.721091 -> V=1.0, theta=0.0
% INFO    : Bus 60185	: V=1.0402109, theta=-52.062279 -> V=1.0, theta=0.0
% INFO    : Bus 60186	: V=1.0231255, theta=-52.731433 -> V=1.0, theta=0.0
% INFO    : Bus 60187	: V=1.0102244, theta=-52.890817 -> V=1.0, theta=0.0
% INFO    : Bus 60188	: V=1.0099888, theta=-52.913703 -> V=1.0, theta=0.0
% INFO    : Bus 60189	: V=1.0137771, theta=-52.259468 -> V=1.0, theta=0.0
% INFO    : Bus 60190	: V=1.0057658, theta=-52.207999 -> V=1.0, theta=0.0
% INFO    : Bus 60191	: V=1.0052224, theta=-52.236876 -> V=1.0, theta=0.0
% INFO    : Bus 60192	: V=1.0190998, theta=-52.853875 -> V=1.0, theta=0.0
% INFO    : Bus 60193	: V=1.0189182, theta=-52.878318 -> V=1.0, theta=0.0
% INFO    : Bus 60194	: V=1.0118602, theta=-51.567777 -> V=1.0, theta=0.0
% INFO    : Bus 60195	: V=1.0156123, theta=-52.251075 -> V=1.0, theta=0.0
% INFO    : Bus 60196	: V=1.036524, theta=-50.906716 -> V=1.0, theta=0.0
% INFO    : Bus 60197	: V=1.0364625, theta=-50.912224 -> V=1.0, theta=0.0
% INFO    : Bus 60198	: V=1.0365873, theta=-50.901504 -> V=1.0, theta=0.0
% INFO    : Bus 60199	: V=1.0551661, theta=-46.750779 -> V=1.0, theta=0.0
% INFO    : Bus 60200	: V=1.0083273, theta=-52.079241 -> V=1.0, theta=0.0
% INFO    : Bus 60201	: V=1.0263561, theta=-51.184689 -> V=1.0, theta=0.0
% INFO    : Bus 60202	: V=1.0386541, theta=-52.196083 -> V=1.0, theta=0.0
% INFO    : Bus 60203	: V=1.0125254, theta=-52.448079 -> V=1.0, theta=0.0
% INFO    : Bus 60204	: V=1.0210661, theta=-53.491673 -> V=1.0, theta=0.0
% INFO    : Bus 60205	: V=1.0212628, theta=-53.460651 -> V=1.0, theta=0.0
% INFO    : Bus 60206	: V=1.0208487, theta=-53.525793 -> V=1.0, theta=0.0
% INFO    : Bus 60207	: V=1.0271195, theta=-53.272008 -> V=1.0, theta=0.0
% INFO    : Bus 60208	: V=1.0269036, theta=-53.302838 -> V=1.0, theta=0.0
% INFO    : Bus 60209	: V=1.0273379, theta=-53.241072 -> V=1.0, theta=0.0
% INFO    : Bus 60210	: V=1.0190702, theta=-51.020047 -> V=1.0, theta=0.0
% INFO    : Bus 60211	: V=1.0189169, theta=-51.045237 -> V=1.0, theta=0.0
% INFO    : Bus 60212	: V=1.0192369, theta=-50.998498 -> V=1.0, theta=0.0
% INFO    : Bus 60213	: V=0.9891695, theta=-53.405514 -> V=1.0, theta=0.0
% INFO    : Bus 60214	: V=0.9891293, theta=-53.411881 -> V=1.0, theta=0.0
% INFO    : Bus 60215	: V=0.9892092, theta=-53.399325 -> V=1.0, theta=0.0
% INFO    : Bus 60216	: V=1.0317343, theta=-50.596661 -> V=1.0, theta=0.0
% INFO    : Bus 60217	: V=1.0227146, theta=-50.181151 -> V=1.0, theta=0.0
% INFO    : Bus 60218	: V=1.0213663, theta=-51.501784 -> V=1.0, theta=0.0
% INFO    : Bus 60219	: V=1.0229496, theta=-49.216779 -> V=1.0, theta=0.0
% INFO    : Bus 60220	: V=1.0227865, theta=-49.23211 -> V=1.0, theta=0.0
% INFO    : Bus 60221	: V=1.0184669, theta=-52.091076 -> V=1.0, theta=0.0
% INFO    : Bus 60222	: V=1.0182932, theta=-52.109139 -> V=1.0, theta=0.0
% INFO    : Bus 60223	: V=1.0151923, theta=-52.31835 -> V=1.0, theta=0.0
% INFO    : Bus 60224	: V=1.0154083, theta=-52.297879 -> V=1.0, theta=0.0
% INFO    : Bus 60225	: V=1.0149898, theta=-52.337636 -> V=1.0, theta=0.0
% INFO    : Bus 60226	: V=1.0000404, theta=-50.717282 -> V=1.0, theta=0.0
% INFO    : Bus 60227	: V=1.0002676, theta=-50.693211 -> V=1.0, theta=0.0
% INFO    : Bus 60228	: V=0.9993402, theta=-51.028603 -> V=1.0, theta=0.0
% INFO    : Bus 60229	: V=1.0202098, theta=-51.984484 -> V=1.0, theta=0.0
% INFO    : Bus 60230	: V=1.0150381, theta=-52.323405 -> V=1.0, theta=0.0
% INFO    : Bus 60231	: V=1.0148553, theta=-52.349603 -> V=1.0, theta=0.0
% INFO    : Bus 60232	: V=1.0138985, theta=-52.493292 -> V=1.0, theta=0.0
% INFO    : Bus 60233	: V=1.0155291, theta=-52.399104 -> V=1.0, theta=0.0
% INFO    : Bus 60234	: V=1.0153026, theta=-52.422345 -> V=1.0, theta=0.0
% INFO    : Bus 60235	: V=1.0157224, theta=-52.376557 -> V=1.0, theta=0.0
% INFO    : Bus 60236	: V=1.0159179, theta=-52.114432 -> V=1.0, theta=0.0
% INFO    : Bus 60237	: V=1.0157408, theta=-52.138907 -> V=1.0, theta=0.0
% INFO    : Bus 60238	: V=1.0412775, theta=-50.897933 -> V=1.0, theta=0.0
% INFO    : Bus 60239	: V=1.0300006, theta=-51.998936 -> V=1.0, theta=0.0
% INFO    : Bus 60240	: V=1.0299718, theta=-52.00331 -> V=1.0, theta=0.0
% INFO    : Bus 60241	: V=1.0300286, theta=-51.995066 -> V=1.0, theta=0.0
% INFO    : Bus 60242	: V=1.0131645, theta=-52.568011 -> V=1.0, theta=0.0
% INFO    : Bus 60243	: V=1.0129888, theta=-52.596927 -> V=1.0, theta=0.0
% INFO    : Bus 60244	: V=1.0133356, theta=-52.541558 -> V=1.0, theta=0.0
% INFO    : Bus 60245	: V=1.0131645, theta=-52.568011 -> V=1.0, theta=0.0
% INFO    : Bus 60246	: V=1.0190372, theta=-51.281354 -> V=1.0, theta=0.0
% INFO    : Bus 60247	: V=1.013248, theta=-53.189837 -> V=1.0, theta=0.0
% INFO    : Bus 60248	: V=1.0130214, theta=-53.219599 -> V=1.0, theta=0.0
% INFO    : Bus 60249	: V=1.012916, theta=-51.967648 -> V=1.0, theta=0.0
% INFO    : Bus 60250	: V=1.0035295, theta=-53.355046 -> V=1.0, theta=0.0
% INFO    : Bus 60251	: V=1.01644, theta=-52.331188 -> V=1.0, theta=0.0
% INFO    : Bus 60252	: V=1.016339, theta=-52.351338 -> V=1.0, theta=0.0
% INFO    : Bus 60253	: V=1.0165491, theta=-52.310707 -> V=1.0, theta=0.0
% INFO    : Bus 60254	: V=1.009707, theta=-51.747665 -> V=1.0, theta=0.0
% INFO    : Bus 60255	: V=1.0120961, theta=-52.645537 -> V=1.0, theta=0.0
% INFO    : Bus 60256	: V=1.0117951, theta=-52.666251 -> V=1.0, theta=0.0
% INFO    : Bus 60257	: V=1.015741, theta=-53.854064 -> V=1.0, theta=0.0
% INFO    : Bus 60258	: V=1.0072567, theta=-53.801524 -> V=1.0, theta=0.0
% INFO    : Bus 60259	: V=1.0097837, theta=-52.656244 -> V=1.0, theta=0.0
% INFO    : Bus 60260	: V=1.0152625, theta=-52.784487 -> V=1.0, theta=0.0
% INFO    : Bus 60261	: V=1.0260734, theta=-53.173836 -> V=1.0, theta=0.0
% INFO    : Bus 60262	: V=1.0261234, theta=-53.162284 -> V=1.0, theta=0.0
% INFO    : Bus 60263	: V=1.0260734, theta=-53.173836 -> V=1.0, theta=0.0
% INFO    : Bus 60264	: V=1.0096006, theta=-49.675825 -> V=1.0, theta=0.0
% INFO    : Bus 60265	: V=0.9962344, theta=-53.486355 -> V=1.0, theta=0.0
% INFO    : Bus 60266	: V=0.9869727, theta=-57.634393 -> V=1.0, theta=0.0
% INFO    : Bus 60267	: V=0.9869727, theta=-57.634393 -> V=1.0, theta=0.0
% INFO    : Bus 60268	: V=0.9955741, theta=-53.662197 -> V=1.0, theta=0.0
% INFO    : Bus 60269	: V=0.9953181, theta=-53.69106 -> V=1.0, theta=0.0
% INFO    : Bus 60270	: V=1.0218828, theta=-51.737517 -> V=1.0, theta=0.0
% INFO    : Bus 60271	: V=1.012113, theta=-51.489284 -> V=1.0, theta=0.0
% INFO    : Bus 60272	: V=1.0144033, theta=-53.528622 -> V=1.0, theta=0.0
% INFO    : Bus 60273	: V=1.0216082, theta=-53.550517 -> V=1.0, theta=0.0
% INFO    : Bus 60274	: V=1.0117518, theta=-48.349617 -> V=1.0, theta=0.0
% INFO    : Bus 60275	: V=1.0132277, theta=-52.367397 -> V=1.0, theta=0.0
% INFO    : Bus 60276	: V=1.0197037, theta=-56.374657 -> V=1.0, theta=0.0
% INFO    : Bus 60277	: V=1.0197037, theta=-56.374657 -> V=1.0, theta=0.0
% INFO    : Bus 60278	: V=1.011986, theta=-48.293006 -> V=1.0, theta=0.0
% INFO    : Bus 60279	: V=1.0178233, theta=-52.198883 -> V=1.0, theta=0.0
% INFO    : Bus 60280	: V=1.0176035, theta=-52.227741 -> V=1.0, theta=0.0
% INFO    : Bus 60281	: V=1.0096089, theta=-52.428854 -> V=1.0, theta=0.0
% INFO    : Bus 60282	: V=1.009355, theta=-52.453616 -> V=1.0, theta=0.0
% INFO    : Bus 60283	: V=1.0098719, theta=-52.401548 -> V=1.0, theta=0.0
% INFO    : Bus 60284	: V=0.9961215, theta=-53.949392 -> V=1.0, theta=0.0
% INFO    : Bus 60285	: V=0.9960042, theta=-53.966081 -> V=1.0, theta=0.0
% INFO    : Bus 60286	: V=1.0279221, theta=-51.224966 -> V=1.0, theta=0.0
% INFO    : Bus 60287	: V=1.0224685, theta=-45.72672 -> V=1.0, theta=0.0
% INFO    : Bus 60288	: V=1.0331653, theta=-50.891799 -> V=1.0, theta=0.0
% INFO    : Bus 60289	: V=1.0222384, theta=-45.758917 -> V=1.0, theta=0.0
% INFO    : Bus 60290	: V=1.0593895, theta=-46.619335 -> V=1.0, theta=0.0
% INFO    : Bus 60291	: V=1.0592269, theta=-46.630396 -> V=1.0, theta=0.0
% INFO    : Bus 60292	: V=1.0094525, theta=-52.797569 -> V=1.0, theta=0.0
% INFO    : Bus 60293	: V=1.0098829, theta=-53.060518 -> V=1.0, theta=0.0
% INFO    : Bus 60294	: V=1.0096969, theta=-53.087239 -> V=1.0, theta=0.0
% INFO    : Bus 60295	: V=1.0319824, theta=-52.074323 -> V=1.0, theta=0.0
% INFO    : Bus 60296	: V=1.0150105, theta=-52.410376 -> V=1.0, theta=0.0
% INFO    : Bus 60297	: V=1.0148653, theta=-52.435872 -> V=1.0, theta=0.0
% INFO    : Bus 60298	: V=1.0219321, theta=-51.733966 -> V=1.0, theta=0.0
% INFO    : Bus 60299	: V=1.0217679, theta=-51.756522 -> V=1.0, theta=0.0
% INFO    : Bus 60300	: V=1.0221112, theta=-51.712956 -> V=1.0, theta=0.0
% INFO    : Bus 60301	: V=1.0315495, theta=-45.832573 -> V=1.0, theta=0.0
% INFO    : Bus 60302	: V=1.0394121, theta=-46.009139 -> V=1.0, theta=0.0
% INFO    : Bus 60303	: V=1.0292384, theta=-50.059168 -> V=1.0, theta=0.0
% INFO    : Bus 60304	: V=1.0272552, theta=-51.250843 -> V=1.0, theta=0.0
% INFO    : Bus 60305	: V=1.0272552, theta=-51.250843 -> V=1.0, theta=0.0
% INFO    : Bus 60306	: V=1.0176088, theta=-51.272648 -> V=1.0, theta=0.0
% INFO    : Bus 60307	: V=1.010746, theta=-49.066049 -> V=1.0, theta=0.0
% INFO    : Bus 60308	: V=1.010539, theta=-52.263623 -> V=1.0, theta=0.0
% INFO    : Bus 60309	: V=1.0072404, theta=-52.66571 -> V=1.0, theta=0.0
% INFO    : Bus 60310	: V=1.0241524, theta=-48.425081 -> V=1.0, theta=0.0
% INFO    : Bus 60311	: V=1.0226335, theta=-50.864801 -> V=1.0, theta=0.0
% INFO    : Bus 60312	: V=1.0152144, theta=-51.427142 -> V=1.0, theta=0.0
% INFO    : Bus 60313	: V=1.0370278, theta=-49.128787 -> V=1.0, theta=0.0
% INFO    : Bus 60314	: V=1.0368666, theta=-49.153915 -> V=1.0, theta=0.0
% INFO    : Bus 60315	: V=1.0304512, theta=-49.915173 -> V=1.0, theta=0.0
% INFO    : Bus 60316	: V=1.0239249, theta=-52.609557 -> V=1.0, theta=0.0
% INFO    : Bus 60317	: V=1.024217, theta=-52.577069 -> V=1.0, theta=0.0
% INFO    : Bus 60318	: V=1.0236029, theta=-52.643388 -> V=1.0, theta=0.0
% INFO    : Bus 60319	: V=1.020079, theta=-52.998571 -> V=1.0, theta=0.0
% INFO    : Bus 60320	: V=1.014468, theta=-53.738152 -> V=1.0, theta=0.0
% INFO    : Bus 60321	: V=1.0142213, theta=-53.759825 -> V=1.0, theta=0.0
% INFO    : Bus 60322	: V=1.0147164, theta=-53.712627 -> V=1.0, theta=0.0
% INFO    : Bus 60323	: V=1.014468, theta=-53.738152 -> V=1.0, theta=0.0
% INFO    : Bus 60324	: V=1.0106203, theta=-52.37074 -> V=1.0, theta=0.0
% INFO    : Bus 60325	: V=1.0103218, theta=-52.394284 -> V=1.0, theta=0.0
% INFO    : Bus 60326	: V=1.0125837, theta=-52.503812 -> V=1.0, theta=0.0
% INFO    : Bus 60327	: V=1.0167145, theta=-53.298469 -> V=1.0, theta=0.0
% INFO    : Bus 60328	: V=1.0120066, theta=-53.243007 -> V=1.0, theta=0.0
% INFO    : Bus 60329	: V=1.0139441, theta=-53.898273 -> V=1.0, theta=0.0
% INFO    : Bus 60330	: V=1.0138982, theta=-52.374099 -> V=1.0, theta=0.0
% INFO    : Bus 60331	: V=1.0113937, theta=-52.281941 -> V=1.0, theta=0.0
% INFO    : Bus 60332	: V=1.0111393, theta=-52.309899 -> V=1.0, theta=0.0
% INFO    : Bus 60333	: V=0.9875362, theta=-53.973649 -> V=1.0, theta=0.0
% INFO    : Bus 60334	: V=0.9956199, theta=-54.064436 -> V=1.0, theta=0.0
% INFO    : Bus 60335	: V=0.9958716, theta=-54.044869 -> V=1.0, theta=0.0
% INFO    : Bus 60336	: V=1.0253331, theta=-51.718195 -> V=1.0, theta=0.0
% INFO    : Bus 60337	: V=1.0064103, theta=-48.32491 -> V=1.0, theta=0.0
% INFO    : Bus 60338	: V=1.0242533, theta=-51.491481 -> V=1.0, theta=0.0
% INFO    : Bus 60339	: V=1.00761, theta=-52.690792 -> V=1.0, theta=0.0
% INFO    : Bus 60340	: V=1.0073681, theta=-52.713963 -> V=1.0, theta=0.0
% INFO    : Bus 60341	: V=1.0138214, theta=-50.34455 -> V=1.0, theta=0.0
% INFO    : Bus 60342	: V=1.0131255, theta=-53.276633 -> V=1.0, theta=0.0
% INFO    : Bus 60343	: V=1.0135025, theta=-52.539191 -> V=1.0, theta=0.0
% INFO    : Bus 60344	: V=1.0140799, theta=-52.586602 -> V=1.0, theta=0.0
% INFO    : Bus 60345	: V=1.0139398, theta=-52.607856 -> V=1.0, theta=0.0
% INFO    : Bus 60346	: V=1.0141982, theta=-52.566278 -> V=1.0, theta=0.0
% INFO    : Bus 60347	: V=1.017194, theta=-52.226148 -> V=1.0, theta=0.0
% INFO    : Bus 60348	: V=1.0109633, theta=-52.380011 -> V=1.0, theta=0.0
% INFO    : Bus 60349	: V=1.0107843, theta=-52.407178 -> V=1.0, theta=0.0
% INFO    : Bus 60350	: V=1.0111385, theta=-52.350511 -> V=1.0, theta=0.0
% INFO    : Bus 60351	: V=1.0109633, theta=-52.380011 -> V=1.0, theta=0.0
% INFO    : Bus 60352	: V=1.0007399, theta=-53.858353 -> V=1.0, theta=0.0
% INFO    : Bus 60353	: V=1.0005947, theta=-53.889115 -> V=1.0, theta=0.0
% INFO    : Bus 60354	: V=1.0107134, theta=-49.119289 -> V=1.0, theta=0.0
% INFO    : Bus 60355	: V=1.0009329, theta=-52.900998 -> V=1.0, theta=0.0
% INFO    : Bus 60356	: V=1.0105192, theta=-49.153187 -> V=1.0, theta=0.0
% INFO    : Bus 60357	: V=1.0118774, theta=-53.699131 -> V=1.0, theta=0.0
% INFO    : Bus 60358	: V=1.0115466, theta=-53.73166 -> V=1.0, theta=0.0
% INFO    : Bus 60359	: V=1.012226, theta=-53.667414 -> V=1.0, theta=0.0
% INFO    : Bus 60360	: V=1.0021914, theta=-53.581487 -> V=1.0, theta=0.0
% INFO    : Bus 60361	: V=1.0023351, theta=-53.558095 -> V=1.0, theta=0.0
% INFO    : Bus 60362	: V=1.014858, theta=-53.878546 -> V=1.0, theta=0.0
% INFO    : Bus 60363	: V=1.0085492, theta=-52.80748 -> V=1.0, theta=0.0
% INFO    : Bus 60364	: V=1.0084047, theta=-52.832936 -> V=1.0, theta=0.0
% INFO    : Bus 60365	: V=0.9967928, theta=-54.048417 -> V=1.0, theta=0.0
% INFO    : Bus 60366	: V=0.9942306, theta=-53.246578 -> V=1.0, theta=0.0
% INFO    : Bus 60367	: V=0.9938908, theta=-53.276251 -> V=1.0, theta=0.0
% INFO    : Bus 60368	: V=0.9946085, theta=-53.218753 -> V=1.0, theta=0.0
% INFO    : Bus 60369	: V=1.007734, theta=-52.828348 -> V=1.0, theta=0.0
% INFO    : Bus 60370	: V=1.0098284, theta=-48.600651 -> V=1.0, theta=0.0
% INFO    : Bus 60371	: V=1.0204175, theta=-52.278057 -> V=1.0, theta=0.0
% INFO    : Bus 60372	: V=1.0116652, theta=-52.737239 -> V=1.0, theta=0.0
% INFO    : Bus 60373	: V=1.0242643, theta=-52.296436 -> V=1.0, theta=0.0
% INFO    : Bus 60374	: V=1.0103235, theta=-53.791299 -> V=1.0, theta=0.0
% INFO    : Bus 60375	: V=1.0105251, theta=-53.769379 -> V=1.0, theta=0.0
% INFO    : Bus 60376	: V=1.010121, theta=-53.814148 -> V=1.0, theta=0.0
% INFO    : Bus 60377	: V=1.0184214, theta=-53.595021 -> V=1.0, theta=0.0
% INFO    : Bus 60378	: V=1.0153567, theta=-52.232866 -> V=1.0, theta=0.0
% INFO    : Bus 60379	: V=1.0151242, theta=-52.256639 -> V=1.0, theta=0.0
% INFO    : Bus 60380	: V=1.0276779, theta=-52.356705 -> V=1.0, theta=0.0
% INFO    : Bus 60381	: V=1.0273586, theta=-52.376608 -> V=1.0, theta=0.0
% INFO    : Bus 60382	: V=1.0026631, theta=-54.221801 -> V=1.0, theta=0.0
% INFO    : Bus 60383	: V=1.0001298, theta=-53.029652 -> V=1.0, theta=0.0
% INFO    : Bus 60384	: V=0.9999113, theta=-53.063194 -> V=1.0, theta=0.0
% INFO    : Bus 60385	: V=1.0074644, theta=-48.010347 -> V=1.0, theta=0.0
% INFO    : Bus 60386	: V=1.0391674, theta=-51.525026 -> V=1.0, theta=0.0
% INFO    : Bus 60387	: V=1.0097482, theta=-47.875928 -> V=1.0, theta=0.0
% INFO    : Bus 60388	: V=1.0138889, theta=-52.64001 -> V=1.0, theta=0.0
% INFO    : Bus 60389	: V=1.0071518, theta=-51.723186 -> V=1.0, theta=0.0
% INFO    : Bus 60390	: V=1.011884, theta=-53.519177 -> V=1.0, theta=0.0
% INFO    : Bus 60391	: V=0.9996629, theta=-53.113142 -> V=1.0, theta=0.0
% INFO    : Bus 60392	: V=0.9960815, theta=-52.429209 -> V=1.0, theta=0.0
% INFO    : Bus 60393	: V=1.0118893, theta=-53.70256 -> V=1.0, theta=0.0
% INFO    : Bus 60394	: V=1.017433, theta=-52.515425 -> V=1.0, theta=0.0
% INFO    : Bus 60395	: V=1.0171833, theta=-52.550486 -> V=1.0, theta=0.0
% INFO    : Bus 60396	: V=0.9964078, theta=-53.615382 -> V=1.0, theta=0.0
% INFO    : Bus 60397	: V=0.9998686, theta=-53.257755 -> V=1.0, theta=0.0
% INFO    : Bus 60398	: V=1.0000327, theta=-53.231434 -> V=1.0, theta=0.0
% INFO    : Bus 60399	: V=1.0164729, theta=-52.266611 -> V=1.0, theta=0.0
% INFO    : Bus 60400	: V=1.0163143, theta=-52.28624 -> V=1.0, theta=0.0
% INFO    : Bus 60401	: V=1.0166214, theta=-52.24446 -> V=1.0, theta=0.0
% INFO    : Bus 60402	: V=1.0208098, theta=-50.845948 -> V=1.0, theta=0.0
% INFO    : Bus 60403	: V=1.0000884, theta=-53.727318 -> V=1.0, theta=0.0
% INFO    : Bus 60404	: V=1.0006068, theta=-53.68335 -> V=1.0, theta=0.0
% INFO    : Bus 60405	: V=1.0399827, theta=-50.828272 -> V=1.0, theta=0.0
% INFO    : Bus 60406	: V=1.0396952, theta=-50.85239 -> V=1.0, theta=0.0
% INFO    : Bus 60407	: V=0.9963463, theta=-52.393208 -> V=1.0, theta=0.0
% INFO    : Bus 60408	: V=1.0292387, theta=-48.985227 -> V=1.0, theta=0.0
% INFO    : Bus 60409	: V=1.0024789, theta=-53.676046 -> V=1.0, theta=0.0
% INFO    : Bus 60410	: V=1.0022728, theta=-53.703087 -> V=1.0, theta=0.0
% INFO    : Bus 60411	: V=0.982832, theta=-54.068522 -> V=1.0, theta=0.0
% INFO    : Bus 60412	: V=1.0193566, theta=-51.268821 -> V=1.0, theta=0.0
% INFO    : Bus 60413	: V=1.0196979, theta=-51.234899 -> V=1.0, theta=0.0
% INFO    : Bus 60414	: V=0.9834942, theta=-53.867966 -> V=1.0, theta=0.0
% INFO    : Bus 60415	: V=1.0102822, theta=-52.791304 -> V=1.0, theta=0.0
% INFO    : Bus 60416	: V=1.0101864, theta=-52.803076 -> V=1.0, theta=0.0
% INFO    : Bus 60417	: V=0.9953362, theta=-53.111768 -> V=1.0, theta=0.0
% INFO    : Bus 60418	: V=0.996901, theta=-53.694745 -> V=1.0, theta=0.0
% INFO    : Bus 60419	: V=1.0348514, theta=-51.866733 -> V=1.0, theta=0.0
% INFO    : Bus 60420	: V=1.0156531, theta=-52.621445 -> V=1.0, theta=0.0
% INFO    : Bus 60421	: V=1.0069153, theta=-53.27792 -> V=1.0, theta=0.0
% INFO    : Bus 60422	: V=1.009494, theta=-52.898924 -> V=1.0, theta=0.0
% INFO    : Bus 60423	: V=1.0159723, theta=-50.154361 -> V=1.0, theta=0.0
% INFO    : Bus 60424	: V=1.0313769, theta=-49.9586 -> V=1.0, theta=0.0
% INFO    : Bus 60425	: V=0.9957386, theta=-53.66787 -> V=1.0, theta=0.0
% INFO    : Bus 60426	: V=1.0004267, theta=-54.176418 -> V=1.0, theta=0.0
% INFO    : Bus 60427	: V=1.0211464, theta=-49.76666 -> V=1.0, theta=0.0
% INFO    : Bus 60428	: V=1.0209047, theta=-49.793899 -> V=1.0, theta=0.0
% INFO    : Bus 60429	: V=1.0214325, theta=-49.737824 -> V=1.0, theta=0.0
% INFO    : Bus 60430	: V=1.0105724, theta=-52.577221 -> V=1.0, theta=0.0
% INFO    : Bus 60431	: V=1.0095883, theta=-52.815515 -> V=1.0, theta=0.0
% INFO    : Bus 60432	: V=1.0389744, theta=-50.85308 -> V=1.0, theta=0.0
% INFO    : Bus 60433	: V=0.9942409, theta=-53.510107 -> V=1.0, theta=0.0
% INFO    : Bus 60434	: V=0.989147, theta=-53.316784 -> V=1.0, theta=0.0
% INFO    : Bus 60435	: V=0.9888514, theta=-53.337789 -> V=1.0, theta=0.0
% INFO    : Bus 60436	: V=0.9894251, theta=-53.293734 -> V=1.0, theta=0.0
% INFO    : Bus 60437	: V=0.989147, theta=-53.316784 -> V=1.0, theta=0.0
% INFO    : Bus 60438	: V=0.989147, theta=-53.316784 -> V=1.0, theta=0.0
% INFO    : Bus 60439	: V=1.03011, theta=-47.902724 -> V=1.0, theta=0.0
% INFO    : Bus 60440	: V=1.0175013, theta=-50.260175 -> V=1.0, theta=0.0
% INFO    : Bus 60441	: V=1.031801, theta=-49.930855 -> V=1.0, theta=0.0
% INFO    : Bus 60442	: V=1.031557, theta=-49.949985 -> V=1.0, theta=0.0
% INFO    : Bus 60443	: V=1.0278427, theta=-50.47533 -> V=1.0, theta=0.0
% INFO    : Bus 60444	: V=1.0209205, theta=-53.971554 -> V=1.0, theta=0.0
% INFO    : Bus 60445	: V=1.028578, theta=-50.191252 -> V=1.0, theta=0.0
% INFO    : Bus 60446	: V=1.028578, theta=-50.191252 -> V=1.0, theta=0.0
% INFO    : Bus 60447	: V=1.0279539, theta=-50.453848 -> V=1.0, theta=0.0
% INFO    : Bus 60448	: V=1.015362, theta=-50.23639 -> V=1.0, theta=0.0
% INFO    : Bus 60449	: V=1.0356018, theta=-50.948225 -> V=1.0, theta=0.0
% INFO    : Bus 60450	: V=1.017529, theta=-52.523342 -> V=1.0, theta=0.0
% INFO    : Bus 60451	: V=1.017677, theta=-52.494364 -> V=1.0, theta=0.0
% INFO    : Bus 60452	: V=1.0148852, theta=-52.532221 -> V=1.0, theta=0.0
% INFO    : Bus 60453	: V=1.0132585, theta=-50.111943 -> V=1.0, theta=0.0
% INFO    : Bus 60454	: V=1.0130495, theta=-50.13896 -> V=1.0, theta=0.0
% INFO    : Bus 60455	: V=0.9980269, theta=-53.438038 -> V=1.0, theta=0.0
% INFO    : Bus 60456	: V=0.9954875, theta=-53.654127 -> V=1.0, theta=0.0
% INFO    : Bus 60457	: V=1.0008943, theta=-53.343757 -> V=1.0, theta=0.0
% INFO    : Bus 60458	: V=0.9986933, theta=-53.492873 -> V=1.0, theta=0.0
% INFO    : Bus 60459	: V=1.0030057, theta=-51.672373 -> V=1.0, theta=0.0
% INFO    : Bus 60460	: V=0.9991792, theta=-51.814164 -> V=1.0, theta=0.0
% INFO    : Bus 60461	: V=0.9991792, theta=-51.814164 -> V=1.0, theta=0.0
% INFO    : Bus 60462	: V=0.9991792, theta=-51.814164 -> V=1.0, theta=0.0
% INFO    : Bus 60463	: V=0.9991792, theta=-51.814164 -> V=1.0, theta=0.0
% INFO    : Bus 60464	: V=1.032337, theta=-50.67366 -> V=1.0, theta=0.0
% INFO    : Bus 60465	: V=1.0268881, theta=-50.549693 -> V=1.0, theta=0.0
% INFO    : Bus 60466	: V=1.0271362, theta=-50.531335 -> V=1.0, theta=0.0
% INFO    : Bus 60467	: V=1.0287394, theta=-50.867938 -> V=1.0, theta=0.0
% INFO    : Bus 60468	: V=1.0411407, theta=-46.741972 -> V=1.0, theta=0.0
% INFO    : Bus 60469	: V=1.0297405, theta=-48.387232 -> V=1.0, theta=0.0
% INFO    : Bus 60470	: V=1.0112354, theta=-50.881986 -> V=1.0, theta=0.0
% INFO    : Bus 60471	: V=1.0178718, theta=-49.971042 -> V=1.0, theta=0.0
% INFO    : Bus 60472	: V=1.028932, theta=-51.433974 -> V=1.0, theta=0.0
% INFO    : Bus 60473	: V=1.0166794, theta=-52.164965 -> V=1.0, theta=0.0
% INFO    : Bus 60474	: V=1.0166794, theta=-52.164965 -> V=1.0, theta=0.0
% INFO    : Bus 60475	: V=1.0166794, theta=-52.164965 -> V=1.0, theta=0.0
% INFO    : Bus 60476	: V=1.0166794, theta=-52.164965 -> V=1.0, theta=0.0
% INFO    : Bus 60477	: V=1.0259757, theta=-51.136818 -> V=1.0, theta=0.0
% INFO    : Bus 60478	: V=1.0106763, theta=-52.823568 -> V=1.0, theta=0.0
% INFO    : Bus 60479	: V=1.0225273, theta=-52.268678 -> V=1.0, theta=0.0
% INFO    : Bus 60480	: V=1.0228377, theta=-52.237859 -> V=1.0, theta=0.0
% INFO    : Bus 60481	: V=1.0084486, theta=-51.373485 -> V=1.0, theta=0.0
% INFO    : Bus 60482	: V=1.023297, theta=-47.211109 -> V=1.0, theta=0.0
% INFO    : Bus 60483	: V=1.0186298, theta=-49.719109 -> V=1.0, theta=0.0
% INFO    : Bus 60484	: V=1.0092422, theta=-53.635982 -> V=1.0, theta=0.0
% INFO    : Bus 60485	: V=1.0094068, theta=-53.608022 -> V=1.0, theta=0.0
% INFO    : Bus 60486	: V=1.0113403, theta=-52.567227 -> V=1.0, theta=0.0
% INFO    : Bus 60487	: V=1.0091468, theta=-53.322573 -> V=1.0, theta=0.0
% INFO    : Bus 60488	: V=1.0072944, theta=-52.809968 -> V=1.0, theta=0.0
% INFO    : Bus 60489	: V=0.9972274, theta=-47.141448 -> V=1.0, theta=0.0
% INFO    : Bus 60490	: V=1.0463936, theta=-50.466813 -> V=1.0, theta=0.0
% INFO    : Bus 60491	: V=1.0367691, theta=-50.898508 -> V=1.0, theta=0.0
% INFO    : Bus 60492	: V=1.0363436, theta=-50.930815 -> V=1.0, theta=0.0
% INFO    : Bus 60493	: V=1.0371257, theta=-50.867406 -> V=1.0, theta=0.0
% INFO    : Bus 60494	: V=1.0111684, theta=-53.844846 -> V=1.0, theta=0.0
% INFO    : Bus 60495	: V=1.0150996, theta=-52.31331 -> V=1.0, theta=0.0
% INFO    : Bus 60496	: V=0.9964181, theta=-52.916596 -> V=1.0, theta=0.0
% INFO    : Bus 60497	: V=0.9961188, theta=-52.958992 -> V=1.0, theta=0.0
% INFO    : Bus 60498	: V=1.0168218, theta=-49.065889 -> V=1.0, theta=0.0
% INFO    : Bus 60499	: V=0.9968227, theta=-52.843826 -> V=1.0, theta=0.0
% INFO    : Bus 60500	: V=1.0208754, theta=-49.775351 -> V=1.0, theta=0.0
% INFO    : Bus 60501	: V=1.0225896, theta=-49.940408 -> V=1.0, theta=0.0
% INFO    : Bus 60502	: V=1.0213185, theta=-49.929094 -> V=1.0, theta=0.0
% INFO    : Bus 60503	: V=1.0210833, theta=-49.951466 -> V=1.0, theta=0.0
% INFO    : Bus 60504	: V=1.0206849, theta=-49.989452 -> V=1.0, theta=0.0
% INFO    : Bus 60505	: V=1.0402029, theta=-46.934665 -> V=1.0, theta=0.0
% INFO    : Bus 60506	: V=1.0396744, theta=-46.921908 -> V=1.0, theta=0.0
% INFO    : Bus 60507	: V=1.0270162, theta=-50.995797 -> V=1.0, theta=0.0
% INFO    : Bus 60508	: V=1.0286226, theta=-50.457091 -> V=1.0, theta=0.0
% INFO    : Bus 60509	: V=1.0289418, theta=-50.422256 -> V=1.0, theta=0.0
% INFO    : Bus 60510	: V=1.0186552, theta=-48.860437 -> V=1.0, theta=0.0
% INFO    : Bus 60511	: V=0.9969493, theta=-53.572596 -> V=1.0, theta=0.0
% INFO    : Bus 60512	: V=0.9466511, theta=-71.570066 -> V=1.0, theta=0.0
% INFO    : Bus 60513	: V=1.041488, theta=-49.457256 -> V=1.0, theta=0.0
% INFO    : Bus 60514	: V=1.0081397, theta=-53.328231 -> V=1.0, theta=0.0
% INFO    : Bus 60515	: V=1.0259984, theta=-51.066457 -> V=1.0, theta=0.0
% INFO    : Bus 60516	: V=1.0237424, theta=-49.908547 -> V=1.0, theta=0.0
% INFO    : Bus 60517	: V=1.0234575, theta=-49.930879 -> V=1.0, theta=0.0
% INFO    : Bus 60518	: V=1.0315134, theta=-53.748461 -> V=1.0, theta=0.0
% INFO    : Bus 60519	: V=1.0131501, theta=-52.172295 -> V=1.0, theta=0.0
% INFO    : Bus 60520	: V=1.0133069, theta=-52.155966 -> V=1.0, theta=0.0
% INFO    : Bus 60521	: V=1.0191766, theta=-49.48836 -> V=1.0, theta=0.0
% INFO    : Bus 60522	: V=1.0148987, theta=-50.138008 -> V=1.0, theta=0.0
% INFO    : Bus 60523	: V=1.0183831, theta=-49.825361 -> V=1.0, theta=0.0
% INFO    : Bus 60524	: V=1.0310415, theta=-50.496574 -> V=1.0, theta=0.0
% INFO    : Bus 60525	: V=1.0341213, theta=-50.85275 -> V=1.0, theta=0.0
% INFO    : Bus 60526	: V=1.0343078, theta=-50.835008 -> V=1.0, theta=0.0
% INFO    : Bus 60527	: V=1.0269542, theta=-50.932607 -> V=1.0, theta=0.0
% INFO    : Bus 60528	: V=1.0302749, theta=-48.012578 -> V=1.0, theta=0.0
% INFO    : Bus 60529	: V=1.0299984, theta=-48.031305 -> V=1.0, theta=0.0
% INFO    : Bus 60530	: V=1.0332433, theta=-47.418667 -> V=1.0, theta=0.0
% INFO    : Bus 60531	: V=1.0330575, theta=-47.436295 -> V=1.0, theta=0.0
% INFO    : Bus 60532	: V=1.0066422, theta=-52.955118 -> V=1.0, theta=0.0
% INFO    : Bus 60533	: V=1.0065933, theta=-52.961536 -> V=1.0, theta=0.0
% INFO    : Bus 60534	: V=1.0066918, theta=-52.948449 -> V=1.0, theta=0.0
% INFO    : Bus 60535	: V=1.0290189, theta=-50.759344 -> V=1.0, theta=0.0
% INFO    : Bus 60536	: V=1.0161876, theta=-50.348566 -> V=1.0, theta=0.0
% INFO    : Bus 60537	: V=1.0161844, theta=-52.484063 -> V=1.0, theta=0.0
% INFO    : Bus 60538	: V=0.9759288, theta=-58.284118 -> V=1.0, theta=0.0
% INFO    : Bus 60539	: V=1.0120891, theta=-52.99431 -> V=1.0, theta=0.0
% INFO    : Bus 60540	: V=1.0120891, theta=-52.99431 -> V=1.0, theta=0.0
% INFO    : Bus 60541	: V=1.0165714, theta=-52.455211 -> V=1.0, theta=0.0
% INFO    : Bus 60542	: V=1.0053161, theta=-53.651566 -> V=1.0, theta=0.0
% INFO    : Bus 60543	: V=1.0342325, theta=-50.938195 -> V=1.0, theta=0.0
% INFO    : Bus 60544	: V=1.0341, theta=-50.959518 -> V=1.0, theta=0.0
% INFO    : Bus 60545	: V=1.0308912, theta=-50.847348 -> V=1.0, theta=0.0
% INFO    : Bus 60546	: V=1.0144315, theta=-51.986723 -> V=1.0, theta=0.0
% INFO    : Bus 60547	: V=1.0146403, theta=-51.949991 -> V=1.0, theta=0.0
% INFO    : Bus 60548	: V=1.0298108, theta=-50.851088 -> V=1.0, theta=0.0
% INFO    : Bus 60549	: V=1.012737, theta=-53.212444 -> V=1.0, theta=0.0
% INFO    : Bus 60550	: V=1.0143437, theta=-49.706342 -> V=1.0, theta=0.0
% INFO    : Bus 60551	: V=1.0269969, theta=-48.021918 -> V=1.0, theta=0.0
% INFO    : Bus 60552	: V=1.0168761, theta=-50.065162 -> V=1.0, theta=0.0
% INFO    : Bus 60553	: V=1.0286879, theta=-45.113763 -> V=1.0, theta=0.0
% INFO    : Bus 60554	: V=1.0260006, theta=-47.180396 -> V=1.0, theta=0.0
% INFO    : Bus 60555	: V=1.0187639, theta=-49.941352 -> V=1.0, theta=0.0
% INFO    : Bus 60556	: V=1.0288914, theta=-45.068681 -> V=1.0, theta=0.0
% INFO    : Bus 60557	: V=1.0100302, theta=-52.159219 -> V=1.0, theta=0.0
% INFO    : Bus 60558	: V=1.0014832, theta=-53.628353 -> V=1.0, theta=0.0
% INFO    : Bus 60559	: V=1.0012674, theta=-53.652578 -> V=1.0, theta=0.0
% INFO    : Bus 60560	: V=1.0193944, theta=-49.854128 -> V=1.0, theta=0.0
% INFO    : Bus 60561	: V=1.0186372, theta=-49.422236 -> V=1.0, theta=0.0
% INFO    : Bus 60562	: V=1.0185252, theta=-49.434045 -> V=1.0, theta=0.0
% INFO    : Bus 60563	: V=1.0210577, theta=-50.160194 -> V=1.0, theta=0.0
% INFO    : Bus 60564	: V=1.0211283, theta=-50.149182 -> V=1.0, theta=0.0
% INFO    : Bus 60565	: V=1.0209827, theta=-50.17256 -> V=1.0, theta=0.0
% INFO    : Bus 60566	: V=1.0443804, theta=-46.198113 -> V=1.0, theta=0.0
% INFO    : Bus 60567	: V=1.04521, theta=-46.355973 -> V=1.0, theta=0.0
% INFO    : Bus 60568	: V=1.0125851, theta=-51.825646 -> V=1.0, theta=0.0
% INFO    : Bus 60569	: V=1.0216315, theta=-48.787185 -> V=1.0, theta=0.0
% INFO    : Bus 60570	: V=1.0216837, theta=-48.779885 -> V=1.0, theta=0.0
% INFO    : Bus 60571	: V=1.0215764, theta=-48.794654 -> V=1.0, theta=0.0
% INFO    : Bus 60572	: V=1.0216315, theta=-48.787185 -> V=1.0, theta=0.0
% INFO    : Bus 60573	: V=1.016008, theta=-49.551647 -> V=1.0, theta=0.0
% INFO    : Bus 60574	: V=1.0486262, theta=-45.717627 -> V=1.0, theta=0.0
% INFO    : Bus 60575	: V=1.0483929, theta=-45.737153 -> V=1.0, theta=0.0
% INFO    : Bus 60576	: V=1.0428861, theta=-46.455612 -> V=1.0, theta=0.0
% INFO    : Bus 60577	: V=1.0275672, theta=-57.243474 -> V=1.0, theta=0.0
% INFO    : Bus 60578	: V=1.0276722, theta=-57.223855 -> V=1.0, theta=0.0
% INFO    : Bus 60579	: V=1.0108363, theta=-51.129661 -> V=1.0, theta=0.0
% INFO    : Bus 60580	: V=1.0513922, theta=-45.74583 -> V=1.0, theta=0.0
% INFO    : Bus 60581	: V=1.0512625, theta=-45.76426 -> V=1.0, theta=0.0
% INFO    : Bus 60582	: V=1.0515134, theta=-45.728172 -> V=1.0, theta=0.0
% INFO    : Bus 60583	: V=1.024807, theta=-51.566662 -> V=1.0, theta=0.0
% INFO    : Bus 60584	: V=1.014304, theta=-51.267254 -> V=1.0, theta=0.0
% INFO    : Bus 60585	: V=1.0142594, theta=-51.272064 -> V=1.0, theta=0.0
% INFO    : Bus 60586	: V=1.0164185, theta=-50.672201 -> V=1.0, theta=0.0
% INFO    : Bus 60587	: V=1.0136022, theta=-52.450342 -> V=1.0, theta=0.0
% INFO    : Bus 60588	: V=1.0251326, theta=-51.271761 -> V=1.0, theta=0.0
% INFO    : Bus 60589	: V=1.0306474, theta=-50.385835 -> V=1.0, theta=0.0
% INFO    : Bus 60590	: V=1.0133206, theta=-51.906897 -> V=1.0, theta=0.0
% INFO    : Bus 60591	: V=1.0214955, theta=-51.677773 -> V=1.0, theta=0.0
% INFO    : Bus 60592	: V=1.0214683, theta=-51.680859 -> V=1.0, theta=0.0
% INFO    : Bus 60593	: V=1.0233287, theta=-50.20919 -> V=1.0, theta=0.0
% INFO    : Bus 60594	: V=1.0469729, theta=-48.379034 -> V=1.0, theta=0.0
% INFO    : Bus 60595	: V=1.0208442, theta=-48.725132 -> V=1.0, theta=0.0
% INFO    : Bus 60596	: V=1.013056, theta=-52.46633 -> V=1.0, theta=0.0
% INFO    : Bus 60597	: V=1.0341526, theta=-42.999882 -> V=1.0, theta=0.0
% INFO    : Bus 60598	: V=0.9910035, theta=-53.120089 -> V=1.0, theta=0.0
% INFO    : Bus 60599	: V=1.0084806, theta=-52.717892 -> V=1.0, theta=0.0
% INFO    : Bus 60600	: V=1.0370582, theta=-42.867384 -> V=1.0, theta=0.0
% INFO    : Bus 60601	: V=1.0370175, theta=-42.872272 -> V=1.0, theta=0.0
% INFO    : Bus 60602	: V=1.0318546, theta=-43.071238 -> V=1.0, theta=0.0
% INFO    : Bus 60603	: V=1.032019, theta=-43.061688 -> V=1.0, theta=0.0
% INFO    : Bus 60604	: V=0.9942669, theta=-52.552058 -> V=1.0, theta=0.0
% INFO    : Bus 60605	: V=1.0200249, theta=-41.35724 -> V=1.0, theta=0.0
% INFO    : Bus 60606	: V=1.0366474, theta=-42.226064 -> V=1.0, theta=0.0
% INFO    : Bus 60607	: V=1.0366148, theta=-42.229646 -> V=1.0, theta=0.0
% INFO    : Bus 60608	: V=0.9973992, theta=-50.864341 -> V=1.0, theta=0.0
% INFO    : Bus 60609	: V=0.9973144, theta=-50.872916 -> V=1.0, theta=0.0
% INFO    : Bus 60610	: V=1.0408989, theta=-41.681635 -> V=1.0, theta=0.0
% INFO    : Bus 60611	: V=1.0171222, theta=-39.672991 -> V=1.0, theta=0.0
% INFO    : Bus 60612	: V=1.0170979, theta=-39.676299 -> V=1.0, theta=0.0
% INFO    : Bus 60613	: V=1.0373352, theta=-41.212281 -> V=1.0, theta=0.0
% INFO    : Bus 60614	: V=1.0372508, theta=-41.221599 -> V=1.0, theta=0.0
% INFO    : Bus 60615	: V=1.0067496, theta=-47.750353 -> V=1.0, theta=0.0
% INFO    : Bus 60616	: V=1.0402888, theta=-40.094969 -> V=1.0, theta=0.0
% INFO    : Bus 60617	: V=1.0283272, theta=-40.18909 -> V=1.0, theta=0.0
% INFO    : Bus 60618	: V=1.0283489, theta=-40.186305 -> V=1.0, theta=0.0
% INFO    : Bus 60619	: V=1.0376836, theta=-40.458398 -> V=1.0, theta=0.0
% INFO    : Bus 60620	: V=1.0376277, theta=-40.462252 -> V=1.0, theta=0.0
% INFO    : Bus 60621	: V=1.0116644, theta=-41.328681 -> V=1.0, theta=0.0
% INFO    : Bus 60622	: V=1.018383, theta=-40.275472 -> V=1.0, theta=0.0
% INFO    : Bus 60623	: V=1.036272, theta=-41.31475 -> V=1.0, theta=0.0
% INFO    : Bus 60624	: V=1.0418971, theta=-39.431682 -> V=1.0, theta=0.0
% INFO    : Bus 60625	: V=1.0130134, theta=-46.740156 -> V=1.0, theta=0.0
% INFO    : Bus 60626	: V=1.0257769, theta=-39.616099 -> V=1.0, theta=0.0
% INFO    : Bus 60627	: V=1.0293022, theta=-39.495537 -> V=1.0, theta=0.0
% INFO    : Bus 60628	: V=1.0299383, theta=-40.124906 -> V=1.0, theta=0.0
% INFO    : Bus 60629	: V=1.0257769, theta=-39.616099 -> V=1.0, theta=0.0
% INFO    : Bus 60630	: V=1.029617, theta=-39.476685 -> V=1.0, theta=0.0
% INFO    : Bus 60631	: V=1.02802, theta=-38.643702 -> V=1.0, theta=0.0
% INFO    : Bus 60632	: V=1.0358707, theta=-38.926494 -> V=1.0, theta=0.0
% INFO    : Bus 60633	: V=1.0360994, theta=-38.85817 -> V=1.0, theta=0.0
% INFO    : Bus 60634	: V=1.0190447, theta=-40.26371 -> V=1.0, theta=0.0
% INFO    : Bus 60635	: V=1.0385562, theta=-44.422601 -> V=1.0, theta=0.0
% INFO    : Bus 60636	: V=1.032316, theta=-47.298449 -> V=1.0, theta=0.0
% INFO    : Bus 60637	: V=1.0321585, theta=-47.391586 -> V=1.0, theta=0.0
% INFO    : Bus 60638	: V=1.0321585, theta=-47.391586 -> V=1.0, theta=0.0
% INFO    : Bus 60639	: V=1.0381381, theta=-44.695229 -> V=1.0, theta=0.0
% INFO    : Bus 60640	: V=1.030322, theta=-39.994277 -> V=1.0, theta=0.0
% INFO    : Bus 60641	: V=1.0366719, theta=-40.811485 -> V=1.0, theta=0.0
% INFO    : Bus 60642	: V=1.025258, theta=-41.22815 -> V=1.0, theta=0.0
% INFO    : Bus 60643	: V=1.0349054, theta=-42.365246 -> V=1.0, theta=0.0
% INFO    : Bus 60644	: V=1.024496, theta=-41.256371 -> V=1.0, theta=0.0
% INFO    : Bus 60645	: V=1.024496, theta=-41.256371 -> V=1.0, theta=0.0
% INFO    : Bus 60646	: V=1.037521, theta=-38.884509 -> V=1.0, theta=0.0
% INFO    : Bus 60647	: V=1.0366612, theta=-40.812591 -> V=1.0, theta=0.0
% INFO    : Bus 60648	: V=1.0328542, theta=-41.022667 -> V=1.0, theta=0.0
% INFO    : Bus 60649	: V=1.0355978, theta=-41.82779 -> V=1.0, theta=0.0
% INFO    : Bus 60650	: V=1.0376727, theta=-43.183914 -> V=1.0, theta=0.0
% INFO    : Bus 60651	: V=1.0380286, theta=-40.15115 -> V=1.0, theta=0.0
% INFO    : Bus 60652	: V=1.037298, theta=-41.101952 -> V=1.0, theta=0.0
% INFO    : Bus 60653	: V=1.026116, theta=-39.058298 -> V=1.0, theta=0.0
% INFO    : Bus 60654	: V=1.0286949, theta=-39.713519 -> V=1.0, theta=0.0
% INFO    : Bus 60655	: V=1.0309917, theta=-40.183505 -> V=1.0, theta=0.0
% INFO    : Bus 60656	: V=1.0328503, theta=-37.579278 -> V=1.0, theta=0.0
% INFO    : Bus 60657	: V=1.0187393, theta=-38.589474 -> V=1.0, theta=0.0
% INFO    : Bus 60658	: V=1.0098076, theta=-42.023596 -> V=1.0, theta=0.0
% INFO    : Bus 60659	: V=1.0534921, theta=-44.936838 -> V=1.0, theta=0.0
% INFO    : Bus 60660	: V=1.0062299, theta=-44.096489 -> V=1.0, theta=0.0
% INFO    : Bus 60661	: V=1.0062299, theta=-44.096489 -> V=1.0, theta=0.0
% INFO    : Bus 60662	: V=1.0295495, theta=-35.091858 -> V=1.0, theta=0.0
% INFO    : Bus 60663	: V=1.0244253, theta=-36.868036 -> V=1.0, theta=0.0
% INFO    : Bus 60664	: V=1.029498, theta=-35.08055 -> V=1.0, theta=0.0
% INFO    : Bus 60665	: V=1.0404852, theta=-41.168135 -> V=1.0, theta=0.0
% INFO    : Bus 60666	: V=1.0369929, theta=-41.273749 -> V=1.0, theta=0.0
% INFO    : Bus 60667	: V=1.0389411, theta=-42.50335 -> V=1.0, theta=0.0
% INFO    : Bus 60668	: V=1.0197371, theta=-39.968469 -> V=1.0, theta=0.0
% INFO    : Bus 60669	: V=1.0391826, theta=-41.253993 -> V=1.0, theta=0.0
% INFO    : Bus 60670	: V=1.0260849, theta=-43.605556 -> V=1.0, theta=0.0
% INFO    : Bus 60671	: V=1.0278589, theta=-46.288831 -> V=1.0, theta=0.0
% INFO    : Bus 60672	: V=1.0400689, theta=-50.520858 -> V=1.0, theta=0.0
% INFO    : Bus 60673	: V=1.0264383, theta=-46.393211 -> V=1.0, theta=0.0
% INFO    : Bus 60674	: V=1.0196039, theta=-44.73143 -> V=1.0, theta=0.0
% INFO    : Bus 60675	: V=1.0204715, theta=-46.087457 -> V=1.0, theta=0.0
% INFO    : Bus 60676	: V=1.0198283, theta=-50.633953 -> V=1.0, theta=0.0
% INFO    : Bus 60677	: V=1.0087633, theta=-43.007177 -> V=1.0, theta=0.0
% INFO    : Bus 60678	: V=1.0056915, theta=-44.153097 -> V=1.0, theta=0.0
% INFO    : Bus 60679	: V=1.0508135, theta=-40.609968 -> V=1.0, theta=0.0
% INFO    : Bus 60680	: V=1.041667, theta=-41.224999 -> V=1.0, theta=0.0
% INFO    : Bus 60681	: V=1.0201089, theta=-41.412646 -> V=1.0, theta=0.0
% INFO    : Bus 60682	: V=1.02312, theta=-43.253234 -> V=1.0, theta=0.0
% INFO    : Bus 60683	: V=1.0218114, theta=-42.445523 -> V=1.0, theta=0.0
% INFO    : Bus 60684	: V=1.0266542, theta=-46.676147 -> V=1.0, theta=0.0
% INFO    : Bus 60685	: V=1.0317658, theta=-49.696399 -> V=1.0, theta=0.0
% INFO    : Bus 60686	: V=1.0132208, theta=-42.994588 -> V=1.0, theta=0.0
% INFO    : Bus 60687	: V=1.02312, theta=-43.253234 -> V=1.0, theta=0.0
% INFO    : Bus 60688	: V=1.0140166, theta=-42.644443 -> V=1.0, theta=0.0
% INFO    : Bus 60689	: V=1.02312, theta=-43.253234 -> V=1.0, theta=0.0
% INFO    : Bus 60690	: V=1.0147027, theta=-42.838092 -> V=1.0, theta=0.0
% INFO    : Bus 60691	: V=1.02312, theta=-43.253234 -> V=1.0, theta=0.0
% INFO    : Bus 60692	: V=0.9890718, theta=-41.459857 -> V=1.0, theta=0.0
% INFO    : Bus 60693	: V=1.0220149, theta=-42.251125 -> V=1.0, theta=0.0
% INFO    : Bus 60694	: V=1.0211777, theta=-45.943539 -> V=1.0, theta=0.0
% INFO    : Bus 60695	: V=1.02312, theta=-47.583488 -> V=1.0, theta=0.0
% INFO    : Bus 60696	: V=1.01626, theta=-45.543753 -> V=1.0, theta=0.0
% INFO    : Bus 60697	: V=1.011458, theta=-38.482808 -> V=1.0, theta=0.0
% INFO    : Bus 60698	: V=1.0150941, theta=-39.021172 -> V=1.0, theta=0.0
% INFO    : Bus 60699	: V=1.0153581, theta=-39.317165 -> V=1.0, theta=0.0
% INFO    : Bus 60700	: V=1.0164922, theta=-39.19753 -> V=1.0, theta=0.0
% INFO    : Bus 60701	: V=1.0202352, theta=-36.420526 -> V=1.0, theta=0.0
% INFO    : Bus 60702	: V=1.0160874, theta=-37.324189 -> V=1.0, theta=0.0
% INFO    : Bus 60703	: V=1.0112165, theta=-38.506497 -> V=1.0, theta=0.0
% INFO    : Bus 60704	: V=1.0283017, theta=-35.754854 -> V=1.0, theta=0.0
% INFO    : Bus 60705	: V=1.0247453, theta=-37.04015 -> V=1.0, theta=0.0
% INFO    : Bus 60706	: V=1.0267464, theta=-40.029197 -> V=1.0, theta=0.0
% INFO    : Bus 60707	: V=0.9977608, theta=-33.318787 -> V=1.0, theta=0.0
% INFO    : Bus 60708	: V=0.9995702, theta=-34.059096 -> V=1.0, theta=0.0
% INFO    : Bus 60709	: V=1.0256976, theta=-39.668213 -> V=1.0, theta=0.0
% INFO    : Bus 60710	: V=1.0294, theta=-40.578198 -> V=1.0, theta=0.0
% INFO    : Bus 60711	: V=1.032512, theta=-41.097715 -> V=1.0, theta=0.0
% INFO    : Bus 60712	: V=1.0120676, theta=-38.302467 -> V=1.0, theta=0.0
% INFO    : Bus 60713	: V=1.0319472, theta=-44.120188 -> V=1.0, theta=0.0
% INFO    : Bus 60714	: V=1.0252144, theta=-48.426231 -> V=1.0, theta=0.0
% INFO    : Bus 60715	: V=1.0269217, theta=-51.283175 -> V=1.0, theta=0.0
% INFO    : Bus 60716	: V=1.0346722, theta=-43.795959 -> V=1.0, theta=0.0
% INFO    : Bus 60717	: V=1.0388494, theta=-43.494887 -> V=1.0, theta=0.0
% INFO    : Bus 60718	: V=1.0320225, theta=-43.970336 -> V=1.0, theta=0.0
% INFO    : Bus 60719	: V=1.0360897, theta=-41.034009 -> V=1.0, theta=0.0
% INFO    : Bus 60720	: V=1.0384805, theta=-41.687765 -> V=1.0, theta=0.0
% INFO    : Bus 60721	: V=1.0268376, theta=-38.508616 -> V=1.0, theta=0.0
% INFO    : Bus 60722	: V=1.027599, theta=-50.230244 -> V=1.0, theta=0.0
% INFO    : Bus 60723	: V=1.027365, theta=-50.251669 -> V=1.0, theta=0.0
% INFO    : Bus 60724	: V=1.0241652, theta=-44.362988 -> V=1.0, theta=0.0
% INFO    : Bus 60725	: V=1.0158911, theta=-47.51691 -> V=1.0, theta=0.0
% INFO    : Bus 60726	: V=1.0122564, theta=-52.004728 -> V=1.0, theta=0.0
% INFO    : Bus 60727	: V=1.0250875, theta=-43.587749 -> V=1.0, theta=0.0
% INFO    : Bus 60728	: V=1.0258515, theta=-42.788698 -> V=1.0, theta=0.0
% INFO    : Bus 60729	: V=1.0210816, theta=-46.934727 -> V=1.0, theta=0.0
% INFO    : Bus 60730	: V=1.0307921, theta=-45.762609 -> V=1.0, theta=0.0
% INFO    : Bus 60731	: V=1.0428658, theta=-40.756738 -> V=1.0, theta=0.0
% INFO    : Bus 60732	: V=1.0408228, theta=-41.223012 -> V=1.0, theta=0.0
% INFO    : Bus 60733	: V=1.0428846, theta=-40.790543 -> V=1.0, theta=0.0
% INFO    : Bus 60734	: V=1.0403032, theta=-40.398064 -> V=1.0, theta=0.0
% INFO    : Bus 60735	: V=1.036886, theta=-40.460682 -> V=1.0, theta=0.0
% INFO    : Bus 60736	: V=1.0364696, theta=-41.925251 -> V=1.0, theta=0.0
% INFO    : Bus 60737	: V=1.0311502, theta=-45.156389 -> V=1.0, theta=0.0
% INFO    : Bus 60738	: V=1.02508, theta=-42.438062 -> V=1.0, theta=0.0
% INFO    : Bus 60739	: V=1.0271772, theta=-44.558762 -> V=1.0, theta=0.0
% INFO    : Bus 60740	: V=1.0249697, theta=-49.774672 -> V=1.0, theta=0.0
% INFO    : Bus 60741	: V=1.0247923, theta=-49.182374 -> V=1.0, theta=0.0
% INFO    : Bus 60742	: V=1.0247923, theta=-49.182374 -> V=1.0, theta=0.0
% INFO    : Bus 60743	: V=1.0251222, theta=-42.436198 -> V=1.0, theta=0.0
% INFO    : Bus 60744	: V=1.0276295, theta=-42.160962 -> V=1.0, theta=0.0
% INFO    : Bus 60745	: V=1.0251222, theta=-42.436198 -> V=1.0, theta=0.0
% INFO    : Bus 60746	: V=1.027776, theta=-41.167097 -> V=1.0, theta=0.0
% INFO    : Bus 60747	: V=1.0278154, theta=-41.479857 -> V=1.0, theta=0.0
% INFO    : Bus 60748	: V=1.049, theta=-40.340906 -> V=1.0, theta=0.0
% INFO    : Bus 60749	: V=1.0431077, theta=-40.926781 -> V=1.0, theta=0.0
% INFO    : Bus 60750	: V=1.0408718, theta=-41.706147 -> V=1.0, theta=0.0
% INFO    : Bus 60751	: V=1.033949, theta=-36.510653 -> V=1.0, theta=0.0
% INFO    : Bus 60752	: V=1.0245938, theta=-43.544397 -> V=1.0, theta=0.0
% INFO    : Bus 60753	: V=1.0260279, theta=-47.49582 -> V=1.0, theta=0.0
% INFO    : Bus 60754	: V=1.0151206, theta=-51.88624 -> V=1.0, theta=0.0
% INFO    : Bus 60755	: V=1.0100988, theta=-58.300132 -> V=1.0, theta=0.0
% INFO    : Bus 60756	: V=1.0100988, theta=-58.300132 -> V=1.0, theta=0.0
% INFO    : Bus 60757	: V=0.9998332, theta=-38.758483 -> V=1.0, theta=0.0
% INFO    : Bus 60758	: V=1.0021557, theta=-38.782038 -> V=1.0, theta=0.0
% INFO    : Bus 60759	: V=1.0125642, theta=-40.486307 -> V=1.0, theta=0.0
% INFO    : Bus 60760	: V=1.0054368, theta=-37.461785 -> V=1.0, theta=0.0
% INFO    : Bus 60761	: V=1.0016802, theta=-38.8312 -> V=1.0, theta=0.0
% INFO    : Bus 60762	: V=1.0310237, theta=-50.294412 -> V=1.0, theta=0.0
% INFO    : Bus 60763	: V=1.0310237, theta=-50.294412 -> V=1.0, theta=0.0
% INFO    : Bus 60764	: V=1.0310237, theta=-50.294412 -> V=1.0, theta=0.0
% INFO    : Bus 60765	: V=1.0167585, theta=-45.115651 -> V=1.0, theta=0.0
% INFO    : Bus 60766	: V=1.0397175, theta=-41.002504 -> V=1.0, theta=0.0
% INFO    : Bus 60767	: V=1.036646, theta=-42.045556 -> V=1.0, theta=0.0
% INFO    : Bus 60768	: V=1.0374069, theta=-44.053079 -> V=1.0, theta=0.0
% INFO    : Bus 60769	: V=1.0358674, theta=-42.331329 -> V=1.0, theta=0.0
% INFO    : Bus 60770	: V=1.0358674, theta=-42.331329 -> V=1.0, theta=0.0
% INFO    : Bus 60771	: V=1.0368623, theta=-41.942166 -> V=1.0, theta=0.0
% INFO    : Bus 60772	: V=1.036646, theta=-42.045556 -> V=1.0, theta=0.0
% INFO    : Bus 60773	: V=1.0186623, theta=-51.760369 -> V=1.0, theta=0.0
% INFO    : Bus 60774	: V=1.024683, theta=-47.684755 -> V=1.0, theta=0.0
% INFO    : Bus 60775	: V=1.0155462, theta=-43.27938 -> V=1.0, theta=0.0
% INFO    : Bus 60776	: V=1.0110285, theta=-41.876959 -> V=1.0, theta=0.0
% INFO    : Bus 60777	: V=1.0247489, theta=-47.868579 -> V=1.0, theta=0.0
% INFO    : Bus 60778	: V=1.0360312, theta=-40.993881 -> V=1.0, theta=0.0
% INFO    : Bus 60779	: V=1.0383888, theta=-41.946002 -> V=1.0, theta=0.0
% INFO    : Bus 60780	: V=1.0329429, theta=-36.055198 -> V=1.0, theta=0.0
% INFO    : Bus 60781	: V=1.0360543, theta=-41.088859 -> V=1.0, theta=0.0
% INFO    : Bus 60782	: V=1.0360312, theta=-40.993881 -> V=1.0, theta=0.0
% INFO    : Bus 60783	: V=1.0263823, theta=-45.354622 -> V=1.0, theta=0.0
% INFO    : Bus 60784	: V=1.0269749, theta=-49.421675 -> V=1.0, theta=0.0
% INFO    : Bus 60785	: V=1.0121019, theta=-39.577733 -> V=1.0, theta=0.0
% INFO    : Bus 60786	: V=1.0524286, theta=-42.754144 -> V=1.0, theta=0.0
% INFO    : Bus 60787	: V=1.0549259, theta=-45.371203 -> V=1.0, theta=0.0
% INFO    : Bus 60788	: V=1.0027589, theta=-39.2428 -> V=1.0, theta=0.0
% INFO    : Bus 60789	: V=1.0027589, theta=-39.2428 -> V=1.0, theta=0.0
% INFO    : Bus 60790	: V=1.0001252, theta=-39.528285 -> V=1.0, theta=0.0
% INFO    : Bus 60791	: V=1.0041608, theta=-39.331002 -> V=1.0, theta=0.0
% INFO    : Bus 60792	: V=1.0029504, theta=-38.527894 -> V=1.0, theta=0.0
% INFO    : Bus 60793	: V=1.0524286, theta=-42.754144 -> V=1.0, theta=0.0
% INFO    : Bus 60794	: V=1.005379, theta=-38.644814 -> V=1.0, theta=0.0
% INFO    : Bus 60795	: V=1.0071742, theta=-38.742542 -> V=1.0, theta=0.0
% INFO    : Bus 60796	: V=1.0512832, theta=-42.825881 -> V=1.0, theta=0.0
% INFO    : Bus 60797	: V=1.0372612, theta=-46.329578 -> V=1.0, theta=0.0
% INFO    : Bus 60798	: V=1.0470882, theta=-43.261091 -> V=1.0, theta=0.0
% INFO    : Bus 60799	: V=1.0461179, theta=-42.2767 -> V=1.0, theta=0.0
% INFO    : Bus 60800	: V=1.0372377, theta=-46.346837 -> V=1.0, theta=0.0
% INFO    : Bus 60801	: V=1.0105901, theta=-42.901452 -> V=1.0, theta=0.0
% INFO    : Bus 60802	: V=1.0217569, theta=-44.652621 -> V=1.0, theta=0.0
% INFO    : Bus 60803	: V=1.0232412, theta=-47.761911 -> V=1.0, theta=0.0
% INFO    : Bus 60804	: V=1.0113653, theta=-39.839728 -> V=1.0, theta=0.0
% INFO    : Bus 60805	: V=1.0196543, theta=-41.312692 -> V=1.0, theta=0.0
% INFO    : Bus 60806	: V=1.0138659, theta=-44.181322 -> V=1.0, theta=0.0
% INFO    : Bus 60807	: V=1.0190701, theta=-38.86904 -> V=1.0, theta=0.0
% INFO    : Bus 60808	: V=1.0113653, theta=-39.839728 -> V=1.0, theta=0.0
% INFO    : Bus 60809	: V=1.0191099, theta=-40.891214 -> V=1.0, theta=0.0
% INFO    : Bus 60810	: V=1.0094161, theta=-52.705114 -> V=1.0, theta=0.0
% INFO    : Bus 60811	: V=1.0008632, theta=-44.80306 -> V=1.0, theta=0.0
% INFO    : Bus 60812	: V=1.000614, theta=-44.816836 -> V=1.0, theta=0.0
% INFO    : Bus 60813	: V=1.0400141, theta=-41.812118 -> V=1.0, theta=0.0
% INFO    : Bus 60814	: V=1.0400141, theta=-41.812118 -> V=1.0, theta=0.0
% INFO    : Bus 60815	: V=1.0400141, theta=-41.812118 -> V=1.0, theta=0.0
% INFO    : Bus 60816	: V=1.0391261, theta=-38.765768 -> V=1.0, theta=0.0
% INFO    : Bus 60817	: V=1.0408754, theta=-39.411165 -> V=1.0, theta=0.0
% INFO    : Bus 60818	: V=1.0406555, theta=-39.332762 -> V=1.0, theta=0.0
% INFO    : Bus 60819	: V=1.0406555, theta=-39.332762 -> V=1.0, theta=0.0
% INFO    : Bus 60820	: V=1.0311297, theta=-36.181708 -> V=1.0, theta=0.0
% INFO    : Bus 60821	: V=1.0391493, theta=-38.799493 -> V=1.0, theta=0.0
% INFO    : Bus 60822	: V=1.0377216, theta=-38.912986 -> V=1.0, theta=0.0
% INFO    : Bus 60823	: V=1.0376877, theta=-38.937289 -> V=1.0, theta=0.0
% INFO    : Bus 60824	: V=1.0377216, theta=-38.912986 -> V=1.0, theta=0.0
% INFO    : Bus 60825	: V=1.0186388, theta=-50.649473 -> V=1.0, theta=0.0
% INFO    : Bus 60826	: V=1.0185335, theta=-50.702697 -> V=1.0, theta=0.0
% INFO    : Bus 60827	: V=1.0509318, theta=-40.642179 -> V=1.0, theta=0.0
% INFO    : Bus 60828	: V=1.0303707, theta=-42.8472 -> V=1.0, theta=0.0
% INFO    : Bus 60829	: V=1.0238115, theta=-44.839781 -> V=1.0, theta=0.0
% INFO    : Bus 60830	: V=1.02508, theta=-43.290174 -> V=1.0, theta=0.0
% INFO    : Bus 60831	: V=1.024727, theta=-46.934382 -> V=1.0, theta=0.0
% INFO    : Bus 60832	: V=1.0186122, theta=-51.105446 -> V=1.0, theta=0.0
% INFO    : Bus 60833	: V=1.0258665, theta=-41.677772 -> V=1.0, theta=0.0
% INFO    : Bus 60834	: V=1.0259624, theta=-41.311882 -> V=1.0, theta=0.0
% INFO    : Bus 60835	: V=1.0257531, theta=-42.929302 -> V=1.0, theta=0.0
% INFO    : Bus 60836	: V=1.017188, theta=-44.39379 -> V=1.0, theta=0.0
% INFO    : Bus 60837	: V=1.016016, theta=-49.183203 -> V=1.0, theta=0.0
% INFO    : Bus 60838	: V=1.0219456, theta=-52.858398 -> V=1.0, theta=0.0
% INFO    : Bus 60839	: V=1.017188, theta=-44.39379 -> V=1.0, theta=0.0
% INFO    : Bus 60840	: V=1.023444, theta=-44.303842 -> V=1.0, theta=0.0
% INFO    : Bus 60841	: V=1.0206204, theta=-44.026267 -> V=1.0, theta=0.0
% INFO    : Bus 60842	: V=1.0157349, theta=-49.066701 -> V=1.0, theta=0.0
% INFO    : Bus 60843	: V=1.021531, theta=-44.263694 -> V=1.0, theta=0.0
% INFO    : Bus 60844	: V=1.039, theta=-50.667345 -> V=1.0, theta=0.0
% INFO    : Bus 60845	: V=1.0385494, theta=-50.699136 -> V=1.0, theta=0.0
% INFO    : Bus 60846	: V=1.039, theta=-50.667345 -> V=1.0, theta=0.0
% INFO    : Bus 60847	: V=1.0263005, theta=-38.309556 -> V=1.0, theta=0.0
% INFO    : Bus 60848	: V=1.0271379, theta=-40.642176 -> V=1.0, theta=0.0
% INFO    : Bus 60849	: V=1.0222923, theta=-43.81782 -> V=1.0, theta=0.0
% INFO    : Bus 60850	: V=1.010298, theta=-48.480783 -> V=1.0, theta=0.0
% INFO    : Bus 60851	: V=1.0193004, theta=-51.685965 -> V=1.0, theta=0.0
% INFO    : Bus 60852	: V=1.0066931, theta=-41.182535 -> V=1.0, theta=0.0
% INFO    : Bus 60853	: V=1.0190468, theta=-46.137933 -> V=1.0, theta=0.0
% INFO    : Bus 60854	: V=1.0351238, theta=-49.501594 -> V=1.0, theta=0.0
% INFO    : Bus 60855	: V=1.0342082, theta=-49.816279 -> V=1.0, theta=0.0
% INFO    : Bus 60856	: V=1.0168714, theta=-46.054701 -> V=1.0, theta=0.0
% INFO    : Bus 60857	: V=1.0146789, theta=-47.595315 -> V=1.0, theta=0.0
% INFO    : Bus 60858	: V=1.02533, theta=-43.611559 -> V=1.0, theta=0.0
% INFO    : Bus 60859	: V=1.0206642, theta=-46.875538 -> V=1.0, theta=0.0
% INFO    : Bus 60860	: V=1.0221727, theta=-49.441204 -> V=1.0, theta=0.0
% INFO    : Bus 60861	: V=1.0364856, theta=-43.324008 -> V=1.0, theta=0.0
% INFO    : Bus 60862	: V=1.02533, theta=-43.611559 -> V=1.0, theta=0.0
% INFO    : Bus 60863	: V=1.0202826, theta=-46.92857 -> V=1.0, theta=0.0
% INFO    : Bus 60864	: V=1.0206642, theta=-46.875538 -> V=1.0, theta=0.0
% INFO    : Bus 60865	: V=1.03654, theta=-38.791273 -> V=1.0, theta=0.0
% INFO    : Bus 60866	: V=1.03654, theta=-38.791273 -> V=1.0, theta=0.0
% INFO    : Bus 60867	: V=1.0182199, theta=-34.063905 -> V=1.0, theta=0.0
% INFO    : Bus 60868	: V=1.0225539, theta=-35.943534 -> V=1.0, theta=0.0
% INFO    : Bus 60869	: V=1.0249551, theta=-38.621154 -> V=1.0, theta=0.0
% INFO    : Bus 60870	: V=1.023321, theta=-37.106635 -> V=1.0, theta=0.0
% INFO    : Bus 60871	: V=1.023321, theta=-37.106635 -> V=1.0, theta=0.0
% INFO    : Bus 60872	: V=0.9917034, theta=-31.808056 -> V=1.0, theta=0.0
% INFO    : Bus 60873	: V=0.987035, theta=-31.005349 -> V=1.0, theta=0.0
% INFO    : Bus 60874	: V=0.9919548, theta=-31.63669 -> V=1.0, theta=0.0
% INFO    : Bus 60875	: V=1.0393779, theta=-38.297634 -> V=1.0, theta=0.0
% INFO    : Bus 60876	: V=1.0142114, theta=-40.585476 -> V=1.0, theta=0.0
% INFO    : Bus 60877	: V=1.0401536, theta=-45.011138 -> V=1.0, theta=0.0
% INFO    : Bus 60878	: V=1.0248488, theta=-47.982472 -> V=1.0, theta=0.0
% INFO    : Bus 60879	: V=1.0232345, theta=-48.337204 -> V=1.0, theta=0.0
% INFO    : Bus 60880	: V=1.0232345, theta=-48.337204 -> V=1.0, theta=0.0
% INFO    : Bus 60881	: V=1.0142114, theta=-40.585476 -> V=1.0, theta=0.0
% INFO    : Bus 60882	: V=1.0305282, theta=-38.794346 -> V=1.0, theta=0.0
% INFO    : Bus 60883	: V=1.029189, theta=-40.279741 -> V=1.0, theta=0.0
% INFO    : Bus 60884	: V=1.0240999, theta=-40.787798 -> V=1.0, theta=0.0
% INFO    : Bus 60885	: V=1.0122889, theta=-38.274292 -> V=1.0, theta=0.0
% INFO    : Bus 60886	: V=1.0492025, theta=-41.532594 -> V=1.0, theta=0.0
% INFO    : Bus 60887	: V=1.0638793, theta=-43.656198 -> V=1.0, theta=0.0
% INFO    : Bus 60888	: V=1.0655499, theta=-46.277021 -> V=1.0, theta=0.0
% INFO    : Bus 60889	: V=1.0128048, theta=-38.394841 -> V=1.0, theta=0.0
% INFO    : Bus 60890	: V=1.0128048, theta=-38.394841 -> V=1.0, theta=0.0
% INFO    : Bus 60891	: V=1.0295186, theta=-38.389192 -> V=1.0, theta=0.0
% INFO    : Bus 60892	: V=1.0304095, theta=-39.882682 -> V=1.0, theta=0.0
% INFO    : Bus 60893	: V=1.027995, theta=-40.227274 -> V=1.0, theta=0.0
% INFO    : Bus 60894	: V=1.0312962, theta=-39.748118 -> V=1.0, theta=0.0
% INFO    : Bus 60895	: V=1.0289731, theta=-40.083153 -> V=1.0, theta=0.0
% INFO    : Bus 60896	: V=1.0320889, theta=-39.629827 -> V=1.0, theta=0.0
% INFO    : Bus 70000	: V=1.01249, theta=-41.096928 -> V=1.0, theta=0.0
% INFO    : Bus 70001	: V=1.0194798, theta=-43.717636 -> V=1.0, theta=0.0
% INFO    : Bus 70002	: V=1.0238106, theta=-43.910599 -> V=1.0, theta=0.0
% INFO    : Bus 70003	: V=1.023879, theta=-43.901857 -> V=1.0, theta=0.0
% INFO    : Bus 70004	: V=1.0202221, theta=-43.988268 -> V=1.0, theta=0.0
% INFO    : Bus 70005	: V=1.0201838, theta=-43.992151 -> V=1.0, theta=0.0
% INFO    : Bus 70006	: V=1.0144231, theta=-44.464873 -> V=1.0, theta=0.0
% INFO    : Bus 70007	: V=1.0429219, theta=-37.715141 -> V=1.0, theta=0.0
% INFO    : Bus 70008	: V=1.0297597, theta=-35.171751 -> V=1.0, theta=0.0
% INFO    : Bus 70009	: V=1.0407736, theta=-41.935257 -> V=1.0, theta=0.0
% INFO    : Bus 70010	: V=1.0313217, theta=-41.439396 -> V=1.0, theta=0.0
% INFO    : Bus 70011	: V=1.0228822, theta=-40.491059 -> V=1.0, theta=0.0
% INFO    : Bus 70012	: V=1.0228499, theta=-40.494528 -> V=1.0, theta=0.0
% INFO    : Bus 70013	: V=1.0205758, theta=-33.918668 -> V=1.0, theta=0.0
% INFO    : Bus 70014	: V=1.0203807, theta=-33.939096 -> V=1.0, theta=0.0
% INFO    : Bus 70015	: V=1.0002816, theta=-32.699525 -> V=1.0, theta=0.0
% INFO    : Bus 70016	: V=1.0000743, theta=-32.723338 -> V=1.0, theta=0.0
% INFO    : Bus 70017	: V=1.0042812, theta=-32.224393 -> V=1.0, theta=0.0
% INFO    : Bus 70018	: V=1.0026754, theta=-32.485537 -> V=1.0, theta=0.0
% INFO    : Bus 70019	: V=1.0024254, theta=-32.505989 -> V=1.0, theta=0.0
% INFO    : Bus 70020	: V=1.0029282, theta=-32.464175 -> V=1.0, theta=0.0
% INFO    : Bus 70021	: V=1.032461, theta=-40.364612 -> V=1.0, theta=0.0
% INFO    : Bus 70022	: V=1.0324376, theta=-40.36791 -> V=1.0, theta=0.0
% INFO    : Bus 70023	: V=1.0324847, theta=-40.361479 -> V=1.0, theta=0.0
% INFO    : Bus 70024	: V=1.0121531, theta=-23.720982 -> V=1.0, theta=0.0
% INFO    : Bus 70025	: V=1.0120184, theta=-23.74051 -> V=1.0, theta=0.0
% INFO    : Bus 70026	: V=1.0312989, theta=-42.260338 -> V=1.0, theta=0.0
% INFO    : Bus 70027	: V=1.0250266, theta=-35.459151 -> V=1.0, theta=0.0
% INFO    : Bus 70028	: V=1.0250346, theta=-35.495159 -> V=1.0, theta=0.0
% INFO    : Bus 70029	: V=1.024968, theta=-35.467381 -> V=1.0, theta=0.0
% INFO    : Bus 70030	: V=1.033873, theta=-42.426553 -> V=1.0, theta=0.0
% INFO    : Bus 70031	: V=1.0256733, theta=-19.565005 -> V=1.0, theta=0.0
% INFO    : Bus 70032	: V=1.0258916, theta=-19.561231 -> V=1.0, theta=0.0
% INFO    : Bus 70033	: V=1.0177426, theta=-31.085625 -> V=1.0, theta=0.0
% INFO    : Bus 70034	: V=1.0241834, theta=-26.244058 -> V=1.0, theta=0.0
% INFO    : Bus 70035	: V=1.0224066, theta=-22.540907 -> V=1.0, theta=0.0
% INFO    : Bus 70036	: V=1.0224361, theta=-22.536115 -> V=1.0, theta=0.0
% INFO    : Bus 70037	: V=0.9977787, theta=-24.264031 -> V=1.0, theta=0.0
% INFO    : Bus 70038	: V=1.0230892, theta=-15.901616 -> V=1.0, theta=0.0
% INFO    : Bus 70039	: V=1.0231148, theta=-15.897593 -> V=1.0, theta=0.0
% INFO    : Bus 70040	: V=1.0190264, theta=-18.281734 -> V=1.0, theta=0.0
% INFO    : Bus 70041	: V=1.0190017, theta=-18.285083 -> V=1.0, theta=0.0
% INFO    : Bus 70042	: V=1.0153267, theta=-27.36106 -> V=1.0, theta=0.0
% INFO    : Bus 70043	: V=1.0152839, theta=-27.366476 -> V=1.0, theta=0.0
% INFO    : Bus 70044	: V=1.0268621, theta=-19.81822 -> V=1.0, theta=0.0
% INFO    : Bus 70045	: V=1.0267404, theta=-19.837337 -> V=1.0, theta=0.0
% INFO    : Bus 70046	: V=1.016966, theta=-19.77667 -> V=1.0, theta=0.0
% INFO    : Bus 70047	: V=1.0136941, theta=-16.564297 -> V=1.0, theta=0.0
% INFO    : Bus 70048	: V=1.0135656, theta=-16.578327 -> V=1.0, theta=0.0
% INFO    : Bus 70049	: V=1.0149845, theta=-18.166768 -> V=1.0, theta=0.0
% INFO    : Bus 70050	: V=1.0147749, theta=-18.187247 -> V=1.0, theta=0.0
% INFO    : Bus 70051	: V=1.0152047, theta=-18.146129 -> V=1.0, theta=0.0
% INFO    : Bus 70052	: V=1.0161267, theta=-18.305608 -> V=1.0, theta=0.0
% INFO    : Bus 70053	: V=1.0236826, theta=-16.476147 -> V=1.0, theta=0.0
% INFO    : Bus 70054	: V=1.0051471, theta=-18.976172 -> V=1.0, theta=0.0
% INFO    : Bus 70055	: V=1.0246304, theta=-16.357206 -> V=1.0, theta=0.0
% INFO    : Bus 70056	: V=1.0246304, theta=-16.357206 -> V=1.0, theta=0.0
% INFO    : Bus 70057	: V=1.023981, theta=-16.453313 -> V=1.0, theta=0.0
% INFO    : Bus 70058	: V=1.0247634, theta=-16.335352 -> V=1.0, theta=0.0
% INFO    : Bus 70059	: V=1.0325152, theta=-15.604154 -> V=1.0, theta=0.0
% INFO    : Bus 70060	: V=1.0324392, theta=-15.609467 -> V=1.0, theta=0.0
% INFO    : Bus 70061	: V=1.013914, theta=-32.675263 -> V=1.0, theta=0.0
% INFO    : Bus 70062	: V=1.0237385, theta=-6.634221 -> V=1.0, theta=0.0
% INFO    : Bus 70063	: V=1.0235832, theta=-6.664703 -> V=1.0, theta=0.0
% INFO    : Bus 70064	: V=1.0238881, theta=-6.602404 -> V=1.0, theta=0.0
% INFO    : Bus 70065	: V=1.0266412, theta=-8.237042 -> V=1.0, theta=0.0
% INFO    : Bus 70066	: V=1.0340347, theta=-11.454333 -> V=1.0, theta=0.0
% INFO    : Bus 70067	: V=1.0097757, theta=-32.099694 -> V=1.0, theta=0.0
% INFO    : Bus 70068	: V=1.0312167, theta=-14.498476 -> V=1.0, theta=0.0
% INFO    : Bus 70069	: V=1.049683, theta=-31.997223 -> V=1.0, theta=0.0
% INFO    : Bus 70070	: V=1.049626, theta=-32.007148 -> V=1.0, theta=0.0
% INFO    : Bus 70071	: V=1.030789, theta=-40.478423 -> V=1.0, theta=0.0
% INFO    : Bus 70072	: V=1.0415127, theta=-44.083023 -> V=1.0, theta=0.0
% INFO    : Bus 70073	: V=1.0629653, theta=-48.922914 -> V=1.0, theta=0.0
% INFO    : Bus 70074	: V=1.0629653, theta=-48.922914 -> V=1.0, theta=0.0
% INFO    : Bus 70075	: V=1.0300886, theta=-40.571039 -> V=1.0, theta=0.0
% INFO    : Bus 70076	: V=1.0422913, theta=-43.968106 -> V=1.0, theta=0.0
% INFO    : Bus 70077	: V=1.0382158, theta=-6.010666 -> V=1.0, theta=0.0
% INFO    : Bus 70078	: V=1.0381563, theta=-37.964902 -> V=1.0, theta=0.0
% INFO    : Bus 70079	: V=1.0378136, theta=-37.987802 -> V=1.0, theta=0.0
% INFO    : Bus 70080	: V=1.0384914, theta=-37.946155 -> V=1.0, theta=0.0
% INFO    : Bus 70081	: V=1.0381555, theta=-37.964956 -> V=1.0, theta=0.0
% INFO    : Bus 70082	: V=1.0046046, theta=-37.377171 -> V=1.0, theta=0.0
% INFO    : Bus 70083	: V=1.0502236, theta=-32.099643 -> V=1.0, theta=0.0
% INFO    : Bus 70084	: V=1.0346766, theta=-40.241354 -> V=1.0, theta=0.0
% INFO    : Bus 70085	: V=1.0440432, theta=-43.671505 -> V=1.0, theta=0.0
% INFO    : Bus 70086	: V=1.0346914, theta=-40.218306 -> V=1.0, theta=0.0
% INFO    : Bus 70087	: V=1.0346766, theta=-40.241354 -> V=1.0, theta=0.0
% INFO    : Bus 70088	: V=1.043226, theta=-9.393813 -> V=1.0, theta=0.0
% INFO    : Bus 70089	: V=1.0432422, theta=-9.391324 -> V=1.0, theta=0.0
% INFO    : Bus 70090	: V=1.0425578, theta=-8.112406 -> V=1.0, theta=0.0
% INFO    : Bus 70091	: V=1.0425291, theta=-8.116873 -> V=1.0, theta=0.0
% INFO    : Bus 70092	: V=1.0129158, theta=-39.370136 -> V=1.0, theta=0.0
% INFO    : Bus 70093	: V=1.0410228, theta=-19.238906 -> V=1.0, theta=0.0
% INFO    : Bus 70094	: V=1.0386147, theta=-29.856279 -> V=1.0, theta=0.0
% INFO    : Bus 70095	: V=1.0394, theta=-17.420334 -> V=1.0, theta=0.0
% INFO    : Bus 70096	: V=1.0338096, theta=-15.815365 -> V=1.0, theta=0.0
% INFO    : Bus 70097	: V=1.0394, theta=-17.420334 -> V=1.0, theta=0.0
% INFO    : Bus 70098	: V=1.0418512, theta=-17.200717 -> V=1.0, theta=0.0
% INFO    : Bus 70099	: V=1.0394, theta=-17.420334 -> V=1.0, theta=0.0
% INFO    : Bus 70100	: V=1.0394, theta=-17.420334 -> V=1.0, theta=0.0
% INFO    : Bus 70101	: V=1.039243, theta=-17.554264 -> V=1.0, theta=0.0
% INFO    : Bus 70102	: V=1.0394, theta=-17.420334 -> V=1.0, theta=0.0
% INFO    : Bus 70103	: V=1.0347624, theta=-14.151673 -> V=1.0, theta=0.0
% INFO    : Bus 70104	: V=0.9739238, theta=-11.770587 -> V=1.0, theta=0.0
% INFO    : Bus 70105	: V=1.0363776, theta=-4.465039 -> V=1.0, theta=0.0
% INFO    : Bus 70106	: V=1.0364018, theta=-4.489106 -> V=1.0, theta=0.0
% INFO    : Bus 70107	: V=1.0369999, theta=-39.333838 -> V=1.0, theta=0.0
% INFO    : Bus 70108	: V=1.0369996, theta=-39.333873 -> V=1.0, theta=0.0
% INFO    : Bus 70109	: V=1.0367488, theta=-39.364841 -> V=1.0, theta=0.0
% INFO    : Bus 70110	: V=1.0363239, theta=-4.470291 -> V=1.0, theta=0.0
% INFO    : Bus 70111	: V=1.0380596, theta=-17.875076 -> V=1.0, theta=0.0
% INFO    : Bus 70112	: V=1.0350341, theta=-27.176389 -> V=1.0, theta=0.0
% INFO    : Bus 70113	: V=1.0304028, theta=-26.979832 -> V=1.0, theta=0.0
% INFO    : Bus 70114	: V=1.0427958, theta=-25.502397 -> V=1.0, theta=0.0
% INFO    : Bus 70115	: V=1.0307803, theta=-26.729662 -> V=1.0, theta=0.0
% INFO    : Bus 70116	: V=1.0346185, theta=-27.252039 -> V=1.0, theta=0.0
% INFO    : Bus 70117	: V=1.0240707, theta=-2.224399 -> V=1.0, theta=0.0
% INFO    : Bus 70118	: V=1.026527, theta=-4.188814 -> V=1.0, theta=0.0
% INFO    : Bus 70119	: V=1.028771, theta=-5.628014 -> V=1.0, theta=0.0
% INFO    : Bus 70120	: V=1.0290621, theta=-5.573761 -> V=1.0, theta=0.0
% INFO    : Bus 70121	: V=1.0137792, theta=-1.096975 -> V=1.0, theta=0.0
% INFO    : Bus 70122	: V=1.0288764, theta=-34.725188 -> V=1.0, theta=0.0
% INFO    : Bus 70123	: V=1.0496001, theta=-37.267721 -> V=1.0, theta=0.0
% INFO    : Bus 70124	: V=1.044645, theta=-37.666223 -> V=1.0, theta=0.0
% INFO    : Bus 70125	: V=1.0159509, theta=-33.721843 -> V=1.0, theta=0.0
% INFO    : Bus 70126	: V=1.0159604, theta=-33.560074 -> V=1.0, theta=0.0
% INFO    : Bus 70127	: V=1.015991, theta=-33.390119 -> V=1.0, theta=0.0
% INFO    : Bus 70128	: V=1.0200866, theta=-24.280377 -> V=1.0, theta=0.0
% INFO    : Bus 70129	: V=1.0200697, theta=-24.33489 -> V=1.0, theta=0.0
% INFO    : Bus 70130	: V=1.0334724, theta=-35.644569 -> V=1.0, theta=0.0
% INFO    : Bus 70131	: V=1.0504931, theta=-31.213215 -> V=1.0, theta=0.0
% INFO    : Bus 70132	: V=1.02606, theta=-2.417647 -> V=1.0, theta=0.0
% INFO    : Bus 70133	: V=1.0363987, theta=-4.467151 -> V=1.0, theta=0.0
% INFO    : Bus 70134	: V=0.9641463, theta=-1.358349 -> V=1.0, theta=0.0
% INFO    : Bus 70135	: V=1.0273842, theta=-36.628687 -> V=1.0, theta=0.0
% INFO    : Bus 70136	: V=1.0328711, theta=-40.808676 -> V=1.0, theta=0.0
% INFO    : Bus 70137	: V=1.0322504, theta=-41.291688 -> V=1.0, theta=0.0
% INFO    : Bus 70138	: V=1.0485738, theta=-43.554893 -> V=1.0, theta=0.0
% INFO    : Bus 70139	: V=1.0454462, theta=-45.410015 -> V=1.0, theta=0.0
% INFO    : Bus 70140	: V=1.0454462, theta=-45.410015 -> V=1.0, theta=0.0
% INFO    : Bus 70141	: V=1.0324322, theta=-36.514063 -> V=1.0, theta=0.0
% INFO    : Bus 70142	: V=1.032458, theta=-36.407869 -> V=1.0, theta=0.0
% INFO    : Bus 70143	: V=1.0274377, theta=-36.629365 -> V=1.0, theta=0.0
% INFO    : Bus 70144	: V=1.0349827, theta=-36.473695 -> V=1.0, theta=0.0
% INFO    : Bus 70145	: V=1.029785, theta=-21.459571 -> V=1.0, theta=0.0
% INFO    : Bus 70146	: V=1.0374861, theta=-18.255873 -> V=1.0, theta=0.0
% INFO    : Bus 70147	: V=1.0216172, theta=-33.169399 -> V=1.0, theta=0.0
% INFO    : Bus 70148	: V=1.0277199, theta=-15.529815 -> V=1.0, theta=0.0
% INFO    : Bus 70149	: V=1.0277199, theta=-15.529815 -> V=1.0, theta=0.0
% INFO    : Bus 70150	: V=1.0277199, theta=-15.529815 -> V=1.0, theta=0.0
% INFO    : Bus 70151	: V=1.01724, theta=-25.375039 -> V=1.0, theta=0.0
% INFO    : Bus 70152	: V=1.0187517, theta=-27.801623 -> V=1.0, theta=0.0
% INFO    : Bus 70153	: V=1.0128396, theta=-24.394771 -> V=1.0, theta=0.0
% INFO    : Bus 70154	: V=1.0101392, theta=-23.553468 -> V=1.0, theta=0.0
% INFO    : Bus 70155	: V=1.0106808, theta=-23.293496 -> V=1.0, theta=0.0
% INFO    : Bus 70156	: V=1.0130275, theta=-24.121168 -> V=1.0, theta=0.0
% INFO    : Bus 70157	: V=1.0173594, theta=-25.570465 -> V=1.0, theta=0.0
% INFO    : Bus 70158	: V=1.01724, theta=-25.375039 -> V=1.0, theta=0.0
% INFO    : Bus 70159	: V=1.0363912, theta=-13.665487 -> V=1.0, theta=0.0
% INFO    : Bus 70160	: V=1.0774115, theta=-7.269266 -> V=1.0, theta=0.0
% INFO    : Bus 70161	: V=1.029392, theta=-20.528105 -> V=1.0, theta=0.0
% INFO    : Bus 70162	: V=1.0372901, theta=-19.201837 -> V=1.0, theta=0.0
% INFO    : Bus 70163	: V=1.0372901, theta=-19.201837 -> V=1.0, theta=0.0
% INFO    : Bus 70164	: V=1.0498337, theta=-17.855759 -> V=1.0, theta=0.0
% INFO    : Bus 70165	: V=1.0657943, theta=-16.043005 -> V=1.0, theta=0.0
% INFO    : Bus 70166	: V=1.0295212, theta=-20.339306 -> V=1.0, theta=0.0
% INFO    : Bus 70167	: V=1.036416, theta=-4.501906 -> V=1.0, theta=0.0
% INFO    : Bus 70168	: V=1.0329657, theta=-36.019472 -> V=1.0, theta=0.0
% INFO    : Bus 70169	: V=1.0329657, theta=-36.019472 -> V=1.0, theta=0.0
% INFO    : Bus 70170	: V=1.05154, theta=-26.355919 -> V=1.0, theta=0.0
% INFO    : Bus 70171	: V=1.0520456, theta=-32.411468 -> V=1.0, theta=0.0
% INFO    : Bus 70172	: V=0.9881856, theta=-23.147801 -> V=1.0, theta=0.0
% INFO    : Bus 70173	: V=0.986017, theta=-24.761273 -> V=1.0, theta=0.0
% INFO    : Bus 70174	: V=0.9883207, theta=-24.822779 -> V=1.0, theta=0.0
% INFO    : Bus 70175	: V=1.0367109, theta=-4.552648 -> V=1.0, theta=0.0
% INFO    : Bus 70176	: V=1.0669748, theta=-3.422775 -> V=1.0, theta=0.0
% INFO    : Bus 70177	: V=1.0345, theta=-22.51198 -> V=1.0, theta=0.0
% INFO    : Bus 70178	: V=1.0341737, theta=-22.569577 -> V=1.0, theta=0.0
% INFO    : Bus 70179	: V=1.0338216, theta=-14.119048 -> V=1.0, theta=0.0
% INFO    : Bus 70180	: V=1.0451736, theta=-8.84966 -> V=1.0, theta=0.0
% INFO    : Bus 70181	: V=1.0338216, theta=-14.119048 -> V=1.0, theta=0.0
% INFO    : Bus 70182	: V=1.0317553, theta=-17.108708 -> V=1.0, theta=0.0
% INFO    : Bus 70183	: V=1.0366773, theta=-4.55099 -> V=1.0, theta=0.0
% INFO    : Bus 70184	: V=1.0366773, theta=-4.55099 -> V=1.0, theta=0.0
% INFO    : Bus 70185	: V=1.0366773, theta=-4.55099 -> V=1.0, theta=0.0
% INFO    : Bus 70186	: V=1.0366773, theta=-4.55099 -> V=1.0, theta=0.0
% INFO    : Bus 70187	: V=1.0311693, theta=-34.116436 -> V=1.0, theta=0.0
% INFO    : Bus 70188	: V=1.0354119, theta=-32.020276 -> V=1.0, theta=0.0
% INFO    : Bus 70189	: V=1.0340222, theta=-32.579229 -> V=1.0, theta=0.0
% INFO    : Bus 70190	: V=1.0311095, theta=-34.147126 -> V=1.0, theta=0.0
% INFO    : Bus 74000	: V=1.0275316, theta=-31.571355 -> V=1.0, theta=0.0
% INFO    : Bus 74001	: V=1.0205057, theta=-34.319287 -> V=1.0, theta=0.0
% INFO    : Bus 74002	: V=1.0141681, theta=-20.26094 -> V=1.0, theta=0.0
% INFO    : Bus 74003	: V=1.0104162, theta=-20.569065 -> V=1.0, theta=0.0
% INFO    : Bus 74004	: V=1.0177337, theta=-29.204621 -> V=1.0, theta=0.0
% INFO    : Bus 74005	: V=1.0176067, theta=-29.215507 -> V=1.0, theta=0.0
% INFO    : Bus 74006	: V=1.0062409, theta=-21.104979 -> V=1.0, theta=0.0
% INFO    : Bus 74007	: V=1.0061382, theta=-21.124903 -> V=1.0, theta=0.0
% INFO    : Bus 74008	: V=1.0138599, theta=-18.050433 -> V=1.0, theta=0.0
% INFO    : Bus 74009	: V=1.0136845, theta=-18.070738 -> V=1.0, theta=0.0
% INFO    : Bus 74010	: V=1.0164116, theta=-17.438974 -> V=1.0, theta=0.0
% INFO    : Bus 74011	: V=1.0166152, theta=-17.422676 -> V=1.0, theta=0.0
% INFO    : Bus 74012	: V=1.0087782, theta=-33.27759 -> V=1.0, theta=0.0
% INFO    : Bus 74013	: V=1.0281503, theta=-18.290661 -> V=1.0, theta=0.0
% INFO    : Bus 74014	: V=1.0251212, theta=-16.847523 -> V=1.0, theta=0.0
% INFO    : Bus 74015	: V=1.0249684, theta=-16.87527 -> V=1.0, theta=0.0
% INFO    : Bus 74016	: V=1.0163398, theta=-19.519865 -> V=1.0, theta=0.0
% INFO    : Bus 74017	: V=1.0202604, theta=-32.264592 -> V=1.0, theta=0.0
% INFO    : Bus 74018	: V=1.0137571, theta=-19.421742 -> V=1.0, theta=0.0
% INFO    : Bus 74019	: V=1.0178241, theta=-34.643117 -> V=1.0, theta=0.0
% INFO    : Bus 74020	: V=0.9999665, theta=-21.373031 -> V=1.0, theta=0.0
% INFO    : Bus 74021	: V=1.0000172, theta=-21.364934 -> V=1.0, theta=0.0
% INFO    : Bus 74022	: V=1.0208634, theta=-18.69853 -> V=1.0, theta=0.0
% INFO    : Bus 74023	: V=1.0208371, theta=-18.702858 -> V=1.0, theta=0.0
% INFO    : Bus 74024	: V=1.0045258, theta=-20.961317 -> V=1.0, theta=0.0
% INFO    : Bus 74025	: V=1.013894, theta=-20.67611 -> V=1.0, theta=0.0
% INFO    : Bus 74026	: V=1.0010506, theta=-34.55195 -> V=1.0, theta=0.0
% INFO    : Bus 74027	: V=1.0078338, theta=-17.931488 -> V=1.0, theta=0.0
% INFO    : Bus 74028	: V=1.0077423, theta=-17.939443 -> V=1.0, theta=0.0
% INFO    : Bus 74029	: V=1.0201337, theta=-32.368261 -> V=1.0, theta=0.0
% INFO    : Bus 74030	: V=1.0089202, theta=-19.992117 -> V=1.0, theta=0.0
% INFO    : Bus 74031	: V=1.0088617, theta=-20.000513 -> V=1.0, theta=0.0
% INFO    : Bus 74032	: V=1.0089117, theta=-19.993787 -> V=1.0, theta=0.0
% INFO    : Bus 74033	: V=1.0063071, theta=-20.749365 -> V=1.0, theta=0.0
% INFO    : Bus 74034	: V=1.0011224, theta=-34.435944 -> V=1.0, theta=0.0
% INFO    : Bus 74035	: V=1.0119947, theta=-34.280363 -> V=1.0, theta=0.0
% INFO    : Bus 74036	: V=1.0114419, theta=-19.862589 -> V=1.0, theta=0.0
% INFO    : Bus 74037	: V=1.0045054, theta=-21.754514 -> V=1.0, theta=0.0
% INFO    : Bus 74038	: V=1.0115948, theta=-19.801685 -> V=1.0, theta=0.0
% INFO    : Bus 74039	: V=1.0115948, theta=-19.801685 -> V=1.0, theta=0.0
% INFO    : Bus 74040	: V=1.0117101, theta=-19.832889 -> V=1.0, theta=0.0
% INFO    : Bus 74041	: V=1.0114419, theta=-19.862589 -> V=1.0, theta=0.0
% INFO    : Bus 74042	: V=1.0092414, theta=-34.411368 -> V=1.0, theta=0.0
% INFO    : Bus 74043	: V=1.0090517, theta=-34.430004 -> V=1.0, theta=0.0
% INFO    : Bus 74044	: V=1.0153067, theta=-33.90298 -> V=1.0, theta=0.0
% INFO    : Bus 74045	: V=1.015514, theta=-33.886854 -> V=1.0, theta=0.0
% INFO    : Bus 74046	: V=1.0177766, theta=-30.965892 -> V=1.0, theta=0.0
% INFO    : Bus 74047	: V=1.0177148, theta=-33.675183 -> V=1.0, theta=0.0
% INFO    : Bus 74048	: V=1.0175449, theta=-30.99345 -> V=1.0, theta=0.0
% INFO    : Bus 74049	: V=1.0151203, theta=-34.833673 -> V=1.0, theta=0.0
% INFO    : Bus 74050	: V=1.0160126, theta=-33.676604 -> V=1.0, theta=0.0
% INFO    : Bus 74051	: V=1.0158967, theta=-33.689038 -> V=1.0, theta=0.0
% INFO    : Bus 74052	: V=1.0367274, theta=-15.362285 -> V=1.0, theta=0.0
% INFO    : Bus 74053	: V=1.0366279, theta=-15.376613 -> V=1.0, theta=0.0
% INFO    : Bus 74054	: V=1.0217208, theta=-18.845105 -> V=1.0, theta=0.0
% INFO    : Bus 74055	: V=1.0216633, theta=-18.856753 -> V=1.0, theta=0.0
% INFO    : Bus 74056	: V=1.0158015, theta=-18.582461 -> V=1.0, theta=0.0
% INFO    : Bus 74057	: V=1.015691, theta=-18.591297 -> V=1.0, theta=0.0
% INFO    : Bus 74058	: V=1.0084132, theta=-34.236074 -> V=1.0, theta=0.0
% INFO    : Bus 74059	: V=1.0108058, theta=-34.43422 -> V=1.0, theta=0.0
% INFO    : Bus 74060	: V=1.0106771, theta=-34.455151 -> V=1.0, theta=0.0
% INFO    : Bus 74061	: V=1.0109337, theta=-34.414837 -> V=1.0, theta=0.0
% INFO    : Bus 74062	: V=1.0108058, theta=-34.43422 -> V=1.0, theta=0.0
% INFO    : Bus 74063	: V=1.0228267, theta=-17.105551 -> V=1.0, theta=0.0
% INFO    : Bus 74064	: V=1.0175185, theta=-33.437291 -> V=1.0, theta=0.0
% INFO    : Bus 74065	: V=1.0176694, theta=-33.418269 -> V=1.0, theta=0.0
% INFO    : Bus 74066	: V=1.0160481, theta=-34.01553 -> V=1.0, theta=0.0
% INFO    : Bus 74067	: V=1.0122338, theta=-34.859721 -> V=1.0, theta=0.0
% INFO    : Bus 74068	: V=1.0120188, theta=-34.893384 -> V=1.0, theta=0.0
% INFO    : Bus 74069	: V=1.0126977, theta=-34.802066 -> V=1.0, theta=0.0
% INFO    : Bus 74070	: V=1.0113707, theta=-34.730432 -> V=1.0, theta=0.0
% INFO    : Bus 74071	: V=1.0100093, theta=-34.767551 -> V=1.0, theta=0.0
% INFO    : Bus 74072	: V=1.0178874, theta=-30.734007 -> V=1.0, theta=0.0
% INFO    : Bus 74073	: V=1.0180236, theta=-33.82351 -> V=1.0, theta=0.0
% INFO    : Bus 74074	: V=1.0176499, theta=-30.765884 -> V=1.0, theta=0.0
% INFO    : Bus 74075	: V=1.0126393, theta=-34.778024 -> V=1.0, theta=0.0
% INFO    : Bus 74076	: V=1.0124906, theta=-34.795288 -> V=1.0, theta=0.0
% INFO    : Bus 74077	: V=1.0077299, theta=-34.55253 -> V=1.0, theta=0.0
% INFO    : Bus 74078	: V=1.0079823, theta=-34.535042 -> V=1.0, theta=0.0
% INFO    : Bus 74079	: V=1.0135835, theta=-35.360676 -> V=1.0, theta=0.0
% INFO    : Bus 74080	: V=1.0137904, theta=-35.326612 -> V=1.0, theta=0.0
% INFO    : Bus 74081	: V=1.0135835, theta=-35.360676 -> V=1.0, theta=0.0
% INFO    : Bus 74082	: V=1.013402, theta=-35.390777 -> V=1.0, theta=0.0
% INFO    : Bus 74083	: V=1.0197092, theta=-31.200877 -> V=1.0, theta=0.0
% INFO    : Bus 74084	: V=1.0136328, theta=-34.605521 -> V=1.0, theta=0.0
% INFO    : Bus 74085	: V=1.0112535, theta=-34.92553 -> V=1.0, theta=0.0
% INFO    : Bus 74086	: V=1.0109338, theta=-34.957549 -> V=1.0, theta=0.0
% INFO    : Bus 74087	: V=1.0139145, theta=-34.469378 -> V=1.0, theta=0.0
% INFO    : Bus 74088	: V=1.0124424, theta=-34.589844 -> V=1.0, theta=0.0
% INFO    : Bus 74089	: V=1.0124838, theta=-34.952388 -> V=1.0, theta=0.0
% INFO    : Bus 74090	: V=1.0122307, theta=-34.97703 -> V=1.0, theta=0.0
% INFO    : Bus 74091	: V=1.0125195, theta=-34.679217 -> V=1.0, theta=0.0
% INFO    : Bus 74092	: V=1.0123482, theta=-34.701393 -> V=1.0, theta=0.0
% INFO    : Bus 74093	: V=1.0127093, theta=-34.65665 -> V=1.0, theta=0.0
% INFO    : Bus 74094	: V=1.0069557, theta=-34.643898 -> V=1.0, theta=0.0
% INFO    : Bus 74095	: V=1.0020462, theta=-35.500749 -> V=1.0, theta=0.0
% INFO    : Bus 74096	: V=1.0018663, theta=-35.500601 -> V=1.0, theta=0.0
% INFO    : Bus 74097	: V=1.0077525, theta=-34.511571 -> V=1.0, theta=0.0
% INFO    : Bus 74098	: V=1.0072696, theta=-34.610046 -> V=1.0, theta=0.0
% INFO    : Bus 74099	: V=1.0069557, theta=-34.643898 -> V=1.0, theta=0.0
% INFO    : Bus 74100	: V=1.0069557, theta=-34.643898 -> V=1.0, theta=0.0
% INFO    : Bus 74101	: V=1.0069557, theta=-34.643898 -> V=1.0, theta=0.0
% INFO    : Bus 74102	: V=1.0116789, theta=-34.575095 -> V=1.0, theta=0.0
% INFO    : Bus 74103	: V=1.0097744, theta=-34.376882 -> V=1.0, theta=0.0
% INFO    : Bus 74104	: V=1.0395829, theta=-38.53359 -> V=1.0, theta=0.0
% INFO    : Bus 74105	: V=1.0088995, theta=-34.551196 -> V=1.0, theta=0.0
% INFO    : Bus 74106	: V=1.0394096, theta=-14.484517 -> V=1.0, theta=0.0
% INFO    : Bus 74107	: V=1.0156664, theta=-33.669646 -> V=1.0, theta=0.0
% INFO    : Bus 74108	: V=1.015601, theta=-33.676002 -> V=1.0, theta=0.0
% INFO    : Bus 74109	: V=1.0157431, theta=-33.662024 -> V=1.0, theta=0.0
% INFO    : Bus 74110	: V=1.0156664, theta=-33.669646 -> V=1.0, theta=0.0
% INFO    : Bus 74111	: V=1.0276921, theta=-16.47714 -> V=1.0, theta=0.0
% INFO    : Bus 74112	: V=1.0101621, theta=-34.216712 -> V=1.0, theta=0.0
% INFO    : Bus 74113	: V=1.0225776, theta=-23.906758 -> V=1.0, theta=0.0
% INFO    : Bus 74114	: V=1.0241345, theta=-27.26012 -> V=1.0, theta=0.0
% INFO    : Bus 74115	: V=1.0374151, theta=-15.90903 -> V=1.0, theta=0.0
% INFO    : Bus 74116	: V=1.0269268, theta=-26.869727 -> V=1.0, theta=0.0
% INFO    : Bus 74117	: V=1.0122436, theta=-34.109492 -> V=1.0, theta=0.0
% INFO    : Bus 74118	: V=1.0124492, theta=-34.090787 -> V=1.0, theta=0.0
% INFO    : Bus 74119	: V=1.0220048, theta=-32.492276 -> V=1.0, theta=0.0
% INFO    : Bus 74120	: V=1.0217275, theta=-32.519859 -> V=1.0, theta=0.0
% INFO    : Bus 74121	: V=1.0277417, theta=-27.250301 -> V=1.0, theta=0.0
% INFO    : Bus 74122	: V=1.0375602, theta=-24.832037 -> V=1.0, theta=0.0
% INFO    : Bus 74123	: V=1.0574124, theta=-32.890712 -> V=1.0, theta=0.0
% INFO    : Bus 74124	: V=1.041062, theta=-33.854774 -> V=1.0, theta=0.0
% INFO    : Bus 74125	: V=1.050469, theta=-34.667274 -> V=1.0, theta=0.0
% INFO    : Bus 74126	: V=1.0335593, theta=-35.273619 -> V=1.0, theta=0.0
% INFO    : Bus 74127	: V=1.0336705, theta=-35.266227 -> V=1.0, theta=0.0
% INFO    : Bus 74128	: V=1.048931, theta=-33.725017 -> V=1.0, theta=0.0
% INFO    : Bus 74129	: V=1.0220774, theta=-34.640045 -> V=1.0, theta=0.0
% INFO    : Bus 74130	: V=1.0080005, theta=-34.152947 -> V=1.0, theta=0.0
% INFO    : Bus 74131	: V=1.0187359, theta=-34.693969 -> V=1.0, theta=0.0
% INFO    : Bus 74132	: V=1.0454403, theta=-23.249415 -> V=1.0, theta=0.0
% INFO    : Bus 74133	: V=1.0395313, theta=-34.30191 -> V=1.0, theta=0.0
% INFO    : Bus 74134	: V=1.0398013, theta=-34.278933 -> V=1.0, theta=0.0
% INFO    : Bus 74135	: V=1.0473408, theta=-36.475231 -> V=1.0, theta=0.0
% INFO    : Bus 74136	: V=1.0473019, theta=-36.48017 -> V=1.0, theta=0.0
% INFO    : Bus 74137	: V=1.0225408, theta=-34.70654 -> V=1.0, theta=0.0
% INFO    : Bus 74138	: V=1.0449495, theta=-32.91651 -> V=1.0, theta=0.0
% INFO    : Bus 74139	: V=1.0424801, theta=-36.400919 -> V=1.0, theta=0.0
% INFO    : Bus 74140	: V=1.0460603, theta=-37.224091 -> V=1.0, theta=0.0
% INFO    : Bus 74141	: V=1.0460236, theta=-37.228897 -> V=1.0, theta=0.0
% INFO    : Bus 74142	: V=1.020641, theta=-36.059617 -> V=1.0, theta=0.0
% INFO    : Bus 74143	: V=1.0206019, theta=-36.063378 -> V=1.0, theta=0.0
% INFO    : Bus 74144	: V=1.0206855, theta=-36.05593 -> V=1.0, theta=0.0
% INFO    : Bus 74145	: V=1.020641, theta=-36.059617 -> V=1.0, theta=0.0
% INFO    : Bus 74146	: V=1.0435386, theta=-29.761802 -> V=1.0, theta=0.0
% INFO    : Bus 74147	: V=1.0179233, theta=-36.223072 -> V=1.0, theta=0.0
% INFO    : Bus 74148	: V=1.0178673, theta=-36.22954 -> V=1.0, theta=0.0
% INFO    : Bus 74149	: V=1.01798, theta=-36.217349 -> V=1.0, theta=0.0
% INFO    : Bus 74150	: V=1.0174948, theta=-35.984902 -> V=1.0, theta=0.0
% INFO    : Bus 74151	: V=1.0148992, theta=-36.186324 -> V=1.0, theta=0.0
% INFO    : Bus 74152	: V=1.0149461, theta=-36.18242 -> V=1.0, theta=0.0
% INFO    : Bus 74153	: V=1.0245652, theta=-37.407496 -> V=1.0, theta=0.0
% INFO    : Bus 74154	: V=1.0367867, theta=-38.052778 -> V=1.0, theta=0.0
% INFO    : Bus 74155	: V=1.0396192, theta=-41.059071 -> V=1.0, theta=0.0
% INFO    : Bus 74156	: V=1.0362, theta=-38.854152 -> V=1.0, theta=0.0
% INFO    : Bus 74157	: V=1.0361354, theta=-38.862313 -> V=1.0, theta=0.0
% INFO    : Bus 74158	: V=1.036563, theta=-39.017071 -> V=1.0, theta=0.0
% INFO    : Bus 74159	: V=1.0365002, theta=-39.021118 -> V=1.0, theta=0.0
% INFO    : Bus 74160	: V=1.0357824, theta=-39.708263 -> V=1.0, theta=0.0
% INFO    : Bus 74161	: V=1.0316647, theta=-42.902816 -> V=1.0, theta=0.0
% INFO    : Bus 74162	: V=1.0303111, theta=-42.879821 -> V=1.0, theta=0.0
% INFO    : Bus 74163	: V=1.0321475, theta=-40.538223 -> V=1.0, theta=0.0
% INFO    : Bus 74164	: V=1.0337065, theta=-41.767323 -> V=1.0, theta=0.0
% INFO    : Bus 74165	: V=1.0353505, theta=-41.232295 -> V=1.0, theta=0.0
% INFO    : Bus 74166	: V=1.0306029, theta=-39.988151 -> V=1.0, theta=0.0
% INFO    : Bus 74167	: V=0.9966754, theta=-37.515757 -> V=1.0, theta=0.0
% INFO    : Bus 74168	: V=1.0005319, theta=-37.914721 -> V=1.0, theta=0.0
% INFO    : Bus 74169	: V=1.0383756, theta=-41.375966 -> V=1.0, theta=0.0
% INFO    : Bus 74170	: V=1.020011, theta=-41.94785 -> V=1.0, theta=0.0
% INFO    : Bus 74171	: V=1.0301487, theta=-41.003674 -> V=1.0, theta=0.0
% INFO    : Bus 74172	: V=1.0314094, theta=-40.947872 -> V=1.0, theta=0.0
% INFO    : Bus 74173	: V=1.0267707, theta=-40.751062 -> V=1.0, theta=0.0
% INFO    : Bus 74174	: V=1.0211931, theta=-41.419183 -> V=1.0, theta=0.0
% INFO    : Bus 74175	: V=1.0209969, theta=-41.44414 -> V=1.0, theta=0.0
% INFO    : Bus 74176	: V=1.0256178, theta=-41.481996 -> V=1.0, theta=0.0
% INFO    : Bus 74177	: V=1.0319645, theta=-40.353768 -> V=1.0, theta=0.0
% INFO    : Bus 74178	: V=1.0391974, theta=-40.776471 -> V=1.0, theta=0.0
% INFO    : Bus 74179	: V=1.0162948, theta=-41.401052 -> V=1.0, theta=0.0
% INFO    : Bus 74180	: V=1.0160537, theta=-41.423671 -> V=1.0, theta=0.0
% INFO    : Bus 74181	: V=1.0192443, theta=-41.773956 -> V=1.0, theta=0.0
% INFO    : Bus 74182	: V=1.037107, theta=-40.27735 -> V=1.0, theta=0.0
% INFO    : Bus 74183	: V=1.0162203, theta=-41.643691 -> V=1.0, theta=0.0
% INFO    : Bus 74184	: V=1.0160079, theta=-41.656794 -> V=1.0, theta=0.0
% INFO    : Bus 74185	: V=1.0164099, theta=-41.631598 -> V=1.0, theta=0.0
% INFO    : Bus 74186	: V=1.0284568, theta=-39.735713 -> V=1.0, theta=0.0
% INFO    : Bus 74187	: V=1.0284412, theta=-41.603341 -> V=1.0, theta=0.0
% INFO    : Bus 74188	: V=1.0335927, theta=-40.224597 -> V=1.0, theta=0.0
% INFO    : Bus 74189	: V=1.0183186, theta=-39.452365 -> V=1.0, theta=0.0
% INFO    : Bus 74190	: V=1.0437462, theta=-40.687418 -> V=1.0, theta=0.0
% INFO    : Bus 74191	: V=1.0152279, theta=-42.593153 -> V=1.0, theta=0.0
% INFO    : Bus 74192	: V=1.0117799, theta=-38.056411 -> V=1.0, theta=0.0
% INFO    : Bus 74193	: V=1.0137323, theta=-39.05441 -> V=1.0, theta=0.0
% INFO    : Bus 74194	: V=1.0138888, theta=-39.128046 -> V=1.0, theta=0.0
% INFO    : Bus 74195	: V=1.0138888, theta=-39.128046 -> V=1.0, theta=0.0
% INFO    : Bus 74196	: V=1.0117799, theta=-38.056411 -> V=1.0, theta=0.0
% INFO    : Bus 74197	: V=0.9978957, theta=-36.584793 -> V=1.0, theta=0.0
% INFO    : Bus 74198	: V=1.0112807, theta=-38.063993 -> V=1.0, theta=0.0
% INFO    : Bus 74199	: V=1.0609762, theta=-32.061281 -> V=1.0, theta=0.0
% INFO    : Bus 74200	: V=1.0609578, theta=-32.03852 -> V=1.0, theta=0.0
% INFO    : Bus 74201	: V=1.0606337, theta=-31.596917 -> V=1.0, theta=0.0
% INFO    : Bus 74202	: V=1.0609578, theta=-32.03852 -> V=1.0, theta=0.0
% INFO    : Bus 74203	: V=1.0328829, theta=-30.334808 -> V=1.0, theta=0.0
% INFO    : Bus 74204	: V=1.0253402, theta=-26.471268 -> V=1.0, theta=0.0
% INFO    : Bus 74205	: V=1.0293984, theta=-28.238548 -> V=1.0, theta=0.0
% INFO    : Bus 74206	: V=1.0327967, theta=-30.447024 -> V=1.0, theta=0.0
% INFO    : Bus 74207	: V=1.02214, theta=-17.141237 -> V=1.0, theta=0.0
% INFO    : Bus 74208	: V=1.0153274, theta=-19.951977 -> V=1.0, theta=0.0
% INFO    : Bus 74209	: V=1.0121184, theta=-21.872089 -> V=1.0, theta=0.0
% INFO    : Bus 74210	: V=1.0121184, theta=-21.872089 -> V=1.0, theta=0.0
% INFO    : Bus 74211	: V=1.0525196, theta=-14.906098 -> V=1.0, theta=0.0
% INFO    : Bus 74212	: V=1.0523814, theta=-14.928423 -> V=1.0, theta=0.0
% INFO    : Bus 74213	: V=1.0281058, theta=-14.202282 -> V=1.0, theta=0.0
% INFO    : Bus 74214	: V=1.0274231, theta=-15.987952 -> V=1.0, theta=0.0
% INFO    : Bus 74215	: V=1.0274081, theta=-17.88902 -> V=1.0, theta=0.0
% INFO    : Bus 74216	: V=1.0279946, theta=-17.739547 -> V=1.0, theta=0.0
% INFO    : Bus 74217	: V=1.0283661, theta=-14.153596 -> V=1.0, theta=0.0
% INFO    : Bus 74218	: V=1.0236115, theta=-30.731193 -> V=1.0, theta=0.0
% INFO    : Bus 74219	: V=1.0152766, theta=-33.672506 -> V=1.0, theta=0.0
% INFO    : Bus 74220	: V=0.9863551, theta=-30.040489 -> V=1.0, theta=0.0
% INFO    : Bus 74221	: V=0.9863981, theta=-29.897594 -> V=1.0, theta=0.0
% INFO    : Bus 74222	: V=0.9830232, theta=-30.496974 -> V=1.0, theta=0.0
% INFO    : Bus 74223	: V=1.0201201, theta=-32.409035 -> V=1.0, theta=0.0
% INFO    : Bus 74224	: V=1.0251298, theta=-31.557517 -> V=1.0, theta=0.0
% INFO    : Bus 74225	: V=1.036, theta=-40.155382 -> V=1.0, theta=0.0
% INFO    : Bus 74226	: V=1.0626206, theta=-32.245994 -> V=1.0, theta=0.0
% INFO    : Bus 74227	: V=1.0626244, theta=-32.260209 -> V=1.0, theta=0.0
% INFO    : Bus 74228	: V=1.0207229, theta=-34.754246 -> V=1.0, theta=0.0
% INFO    : Bus 74229	: V=1.0566328, theta=-33.211784 -> V=1.0, theta=0.0
% INFO    : Bus 74230	: V=1.0050643, theta=-32.57096 -> V=1.0, theta=0.0
% INFO    : Bus 74231	: V=1.0030228, theta=-32.047012 -> V=1.0, theta=0.0
% INFO    : Bus 74232	: V=1.0068214, theta=-33.398265 -> V=1.0, theta=0.0
% INFO    : Bus 74233	: V=1.0566328, theta=-33.211784 -> V=1.0, theta=0.0
% INFO    : Bus 74234	: V=1.02508, theta=-12.861381 -> V=1.0, theta=0.0
% INFO    : Bus 74235	: V=1.0280203, theta=-14.970267 -> V=1.0, theta=0.0
% INFO    : Bus 74236	: V=1.029581, theta=-12.20061 -> V=1.0, theta=0.0
% INFO    : Bus 74237	: V=1.0293981, theta=-12.07443 -> V=1.0, theta=0.0
% INFO    : Bus 74238	: V=1.0282897, theta=-12.288252 -> V=1.0, theta=0.0
% INFO    : Bus 74239	: V=1.0289291, theta=-12.141889 -> V=1.0, theta=0.0
% INFO    : Bus 74240	: V=1.01626, theta=-19.432436 -> V=1.0, theta=0.0
% INFO    : Bus 74241	: V=1.0157113, theta=-19.52953 -> V=1.0, theta=0.0
% INFO    : Bus 74242	: V=1.01626, theta=-19.432436 -> V=1.0, theta=0.0
% INFO    : Bus 74243	: V=1.01626, theta=-19.432436 -> V=1.0, theta=0.0
% INFO    : Bus 74244	: V=1.0261487, theta=-37.436357 -> V=1.0, theta=0.0
% INFO    : Bus 74245	: V=1.0258935, theta=-36.989846 -> V=1.0, theta=0.0
% INFO    : Bus 74246	: V=1.0261219, theta=-37.394128 -> V=1.0, theta=0.0
% INFO    : Bus 74247	: V=1.0261219, theta=-37.394128 -> V=1.0, theta=0.0
% INFO    : Bus 74248	: V=1.0245691, theta=-36.279949 -> V=1.0, theta=0.0
% INFO    : Bus 74249	: V=1.0261367, theta=-37.442064 -> V=1.0, theta=0.0
% INFO    : Bus 74250	: V=1.0143, theta=-20.483021 -> V=1.0, theta=0.0
% INFO    : Bus 74251	: V=1.0226475, theta=-21.889273 -> V=1.0, theta=0.0
% INFO    : Bus 74252	: V=1.0143151, theta=-18.781137 -> V=1.0, theta=0.0
% INFO    : Bus 74253	: V=1.0143, theta=-20.483021 -> V=1.0, theta=0.0
% INFO    : Bus 74254	: V=1.0146501, theta=-19.016008 -> V=1.0, theta=0.0
% INFO    : Bus 74255	: V=1.014446, theta=-19.271211 -> V=1.0, theta=0.0
% INFO    : Bus 74256	: V=1.0143199, theta=-18.78597 -> V=1.0, theta=0.0
% INFO    : Bus 74257	: V=1.0098466, theta=-33.168599 -> V=1.0, theta=0.0
% INFO    : Bus 74258	: V=1.0654838, theta=-32.213866 -> V=1.0, theta=0.0
% INFO    : Bus 74259	: V=1.0108099, theta=-28.750508 -> V=1.0, theta=0.0
% INFO    : Bus 74260	: V=1.0098466, theta=-33.168599 -> V=1.0, theta=0.0
% INFO    : Bus 74261	: V=1.0627356, theta=-32.153568 -> V=1.0, theta=0.0
% INFO    : Bus 74262	: V=1.036615, theta=-39.144949 -> V=1.0, theta=0.0
% INFO    : Bus 74263	: V=1.036615, theta=-39.144949 -> V=1.0, theta=0.0
% INFO    : Bus 74264	: V=1.0405576, theta=-14.592606 -> V=1.0, theta=0.0
% INFO    : Bus 74265	: V=1.0359876, theta=-11.436955 -> V=1.0, theta=0.0
% INFO    : Bus 74266	: V=1.0399831, theta=-13.511091 -> V=1.0, theta=0.0
% INFO    : Bus 74267	: V=1.0405371, theta=-14.604481 -> V=1.0, theta=0.0
% INFO    : Bus 74268	: V=1.0301956, theta=-40.597789 -> V=1.0, theta=0.0
% INFO    : Bus 74269	: V=1.0301701, theta=-40.606277 -> V=1.0, theta=0.0
% INFO    : Bus 74270	: V=1.0489886, theta=-32.386394 -> V=1.0, theta=0.0
% INFO    : Bus 74271	: V=1.0333419, theta=-39.692476 -> V=1.0, theta=0.0
% INFO    : Bus 74272	: V=1.041, theta=-12.909404 -> V=1.0, theta=0.0
% INFO    : Bus 74273	: V=1.0404646, theta=-14.053201 -> V=1.0, theta=0.0
% INFO    : Bus 74274	: V=1.0370698, theta=-14.800629 -> V=1.0, theta=0.0
% INFO    : Bus 74275	: V=1.0405491, theta=-14.209524 -> V=1.0, theta=0.0
% INFO    : Bus 74276	: V=1.0518235, theta=-11.082618 -> V=1.0, theta=0.0
% INFO    : Bus 74277	: V=1.041, theta=-12.909404 -> V=1.0, theta=0.0
% INFO    : Bus 74278	: V=1.0504401, theta=-10.774492 -> V=1.0, theta=0.0
% INFO    : Bus 74279	: V=1.0367936, theta=-40.070001 -> V=1.0, theta=0.0
% INFO    : Bus 74280	: V=1.0062575, theta=-34.121718 -> V=1.0, theta=0.0
% INFO    : Bus 74281	: V=1.0501745, theta=-32.454981 -> V=1.0, theta=0.0
% INFO    : Bus 74282	: V=1.0501745, theta=-32.454981 -> V=1.0, theta=0.0
% INFO    : Bus 74283	: V=1.0501745, theta=-32.454981 -> V=1.0, theta=0.0
% INFO    : Bus 74284	: V=1.0360037, theta=-41.264584 -> V=1.0, theta=0.0
% INFO    : Bus 74285	: V=1.0359925, theta=-41.266824 -> V=1.0, theta=0.0
% INFO    : Bus 74286	: V=1.0359055, theta=-41.269067 -> V=1.0, theta=0.0
% INFO    : Bus 74287	: V=1.0634548, theta=-32.078297 -> V=1.0, theta=0.0
% INFO    : Bus 74288	: V=1.0635056, theta=-32.101744 -> V=1.0, theta=0.0
% INFO    : Bus 74289	: V=1.061832, theta=-31.278989 -> V=1.0, theta=0.0
% INFO    : Bus 74290	: V=1.0635056, theta=-32.101744 -> V=1.0, theta=0.0
% INFO    : Bus 74291	: V=1.0634548, theta=-32.078297 -> V=1.0, theta=0.0
% INFO    : Bus 74292	: V=1.0525916, theta=-28.868491 -> V=1.0, theta=0.0
% INFO    : Bus 74293	: V=1.0634565, theta=-32.089874 -> V=1.0, theta=0.0
% INFO    : Bus 74294	: V=1.0634548, theta=-32.078297 -> V=1.0, theta=0.0
% INFO    : Bus 74295	: V=1.0136996, theta=-32.502647 -> V=1.0, theta=0.0
% INFO    : Bus 74296	: V=1.0510146, theta=-32.243636 -> V=1.0, theta=0.0
% INFO    : Bus 74297	: V=1.0271329, theta=-32.224253 -> V=1.0, theta=0.0
% INFO    : Bus 74298	: V=1.0070427, theta=-30.674156 -> V=1.0, theta=0.0
% INFO    : Bus 74299	: V=1.0271004, theta=-32.233521 -> V=1.0, theta=0.0
% INFO    : Bus 74300	: V=1.0147098, theta=-19.576354 -> V=1.0, theta=0.0
% INFO    : Bus 74301	: V=0.9988555, theta=-16.772982 -> V=1.0, theta=0.0
% INFO    : Bus 74302	: V=0.9943941, theta=-19.058967 -> V=1.0, theta=0.0
% INFO    : Bus 74303	: V=1.0367083, theta=-38.652568 -> V=1.0, theta=0.0
% INFO    : Bus 74304	: V=1.0392184, theta=-38.121992 -> V=1.0, theta=0.0
% INFO    : Bus 74305	: V=1.0019527, theta=-35.510196 -> V=1.0, theta=0.0
% INFO    : Bus 74306	: V=1.0392348, theta=-38.137837 -> V=1.0, theta=0.0
% INFO    : Bus 74307	: V=1.038, theta=-33.600216 -> V=1.0, theta=0.0
% INFO    : Bus 74308	: V=1.0008421, theta=-38.206401 -> V=1.0, theta=0.0
% INFO    : Bus 74309	: V=1.040976, theta=-40.003165 -> V=1.0, theta=0.0
% INFO    : Bus 74310	: V=0.9992936, theta=-36.121283 -> V=1.0, theta=0.0
% INFO    : Bus 74311	: V=1.0294592, theta=-36.754249 -> V=1.0, theta=0.0
% INFO    : Bus 74312	: V=1.036702, theta=-38.309514 -> V=1.0, theta=0.0
% INFO    : Bus 74313	: V=1.0331137, theta=-36.312736 -> V=1.0, theta=0.0
% INFO    : Bus 74314	: V=1.0330713, theta=-36.507956 -> V=1.0, theta=0.0
% INFO    : Bus 74315	: V=1.0295229, theta=-36.75322 -> V=1.0, theta=0.0
% INFO    : Bus 74316	: V=1.0573293, theta=-36.728447 -> V=1.0, theta=0.0
% INFO    : Bus 74317	: V=1.0147522, theta=-36.65506 -> V=1.0, theta=0.0
% INFO    : Bus 74318	: V=1.0139439, theta=-37.89458 -> V=1.0, theta=0.0
% INFO    : Bus 74319	: V=1.028133, theta=-39.528568 -> V=1.0, theta=0.0
% INFO    : Bus 74320	: V=1.0136324, theta=-37.915315 -> V=1.0, theta=0.0
% INFO    : Bus 74321	: V=1.0264692, theta=-35.508668 -> V=1.0, theta=0.0
% INFO    : Bus 74322	: V=1.0467301, theta=-33.200406 -> V=1.0, theta=0.0
% INFO    : Bus 74323	: V=0.9927317, theta=-34.629084 -> V=1.0, theta=0.0
% INFO    : Bus 74324	: V=1.0030595, theta=-34.646704 -> V=1.0, theta=0.0
% INFO    : Bus 74325	: V=0.9951752, theta=-34.655021 -> V=1.0, theta=0.0
% INFO    : Bus 74326	: V=1.02312, theta=-28.500537 -> V=1.0, theta=0.0
% INFO    : Bus 74327	: V=1.0238135, theta=-31.53235 -> V=1.0, theta=0.0
% INFO    : Bus 74328	: V=1.033329, theta=-26.180183 -> V=1.0, theta=0.0
% INFO    : Bus 74329	: V=1.0331405, theta=-26.259593 -> V=1.0, theta=0.0
% INFO    : Bus 74330	: V=1.0225339, theta=-28.577481 -> V=1.0, theta=0.0
% INFO    : Bus 74331	: V=1.0578319, theta=-32.981507 -> V=1.0, theta=0.0
% INFO    : Bus 74332	: V=1.029, theta=-30.375921 -> V=1.0, theta=0.0
% INFO    : Bus 74333	: V=1.029, theta=-29.412111 -> V=1.0, theta=0.0
% INFO    : Bus 74334	: V=1.0626119, theta=-32.195916 -> V=1.0, theta=0.0
% INFO    : Bus 74335	: V=1.0192, theta=-35.864139 -> V=1.0, theta=0.0
% INFO    : Bus 74336	: V=1.0191829, theta=-35.876068 -> V=1.0, theta=0.0
% INFO    : Bus 77000	: V=1.0226023, theta=-10.895011 -> V=1.0, theta=0.0
% INFO    : Bus 77001	: V=1.0315268, theta=-7.217569 -> V=1.0, theta=0.0
% INFO    : Bus 77002	: V=1.0185203, theta=-17.090969 -> V=1.0, theta=0.0
% INFO    : Bus 77003	: V=1.0187288, theta=-17.059848 -> V=1.0, theta=0.0
% INFO    : Bus 77004	: V=1.0162552, theta=2.85755 -> V=1.0, theta=0.0
% INFO    : Bus 77005	: V=1.0286977, theta=-13.316076 -> V=1.0, theta=0.0
% INFO    : Bus 77006	: V=1.0286549, theta=-13.320105 -> V=1.0, theta=0.0
% INFO    : Bus 77007	: V=1.031362, theta=-15.354497 -> V=1.0, theta=0.0
% INFO    : Bus 77008	: V=1.0286325, theta=-14.302221 -> V=1.0, theta=0.0
% INFO    : Bus 77009	: V=1.0267186, theta=-4.162568 -> V=1.0, theta=0.0
% INFO    : Bus 77010	: V=1.0235523, theta=-16.905375 -> V=1.0, theta=0.0
% INFO    : Bus 77011	: V=1.0221148, theta=-17.623921 -> V=1.0, theta=0.0
% INFO    : Bus 77012	: V=1.0220747, theta=-17.62793 -> V=1.0, theta=0.0
% INFO    : Bus 77013	: V=1.0221602, theta=-17.619976 -> V=1.0, theta=0.0
% INFO    : Bus 77014	: V=1.0294396, theta=-18.067535 -> V=1.0, theta=0.0
% INFO    : Bus 77015	: V=1.0260353, theta=-17.28479 -> V=1.0, theta=0.0
% INFO    : Bus 77016	: V=1.0257507, theta=-17.304499 -> V=1.0, theta=0.0
% INFO    : Bus 77017	: V=1.0263802, theta=-17.263745 -> V=1.0, theta=0.0
% INFO    : Bus 77018	: V=1.0214733, theta=-17.978234 -> V=1.0, theta=0.0
% INFO    : Bus 77019	: V=1.0212412, theta=-17.994717 -> V=1.0, theta=0.0
% INFO    : Bus 77020	: V=1.0322832, theta=-17.673517 -> V=1.0, theta=0.0
% INFO    : Bus 77021	: V=1.0429592, theta=-18.909957 -> V=1.0, theta=0.0
% INFO    : Bus 77022	: V=1.0320852, theta=-17.995945 -> V=1.0, theta=0.0
% INFO    : Bus 77023	: V=1.0304167, theta=-18.284964 -> V=1.0, theta=0.0
% INFO    : Bus 77024	: V=1.0245554, theta=-18.340941 -> V=1.0, theta=0.0
% INFO    : Bus 77025	: V=1.0278033, theta=-13.458551 -> V=1.0, theta=0.0
% INFO    : Bus 77026	: V=1.0311786, theta=-18.34732 -> V=1.0, theta=0.0
% INFO    : Bus 77027	: V=1.0310455, theta=-18.36004 -> V=1.0, theta=0.0
% INFO    : Bus 77028	: V=1.0278041, theta=-10.856537 -> V=1.0, theta=0.0
% INFO    : Bus 77029	: V=1.0239666, theta=-22.09645 -> V=1.0, theta=0.0
% INFO    : Bus 77030	: V=1.034115, theta=-19.243801 -> V=1.0, theta=0.0
% INFO    : Bus 77031	: V=1.0283922, theta=-20.179971 -> V=1.0, theta=0.0
% INFO    : Bus 77032	: V=1.0359913, theta=-19.681028 -> V=1.0, theta=0.0
% INFO    : Bus 77033	: V=1.0294368, theta=-15.693669 -> V=1.0, theta=0.0
% INFO    : Bus 77034	: V=1.0373092, theta=-23.039439 -> V=1.0, theta=0.0
% INFO    : Bus 77035	: V=1.0374232, theta=-23.027418 -> V=1.0, theta=0.0
% INFO    : Bus 77036	: V=1.0141244, theta=-25.178786 -> V=1.0, theta=0.0
% INFO    : Bus 77037	: V=1.0140666, theta=-25.183716 -> V=1.0, theta=0.0
% INFO    : Bus 77038	: V=1.0141771, theta=-25.174242 -> V=1.0, theta=0.0
% INFO    : Bus 77039	: V=1.0336394, theta=-20.99087 -> V=1.0, theta=0.0
% INFO    : Bus 77040	: V=1.0272708, theta=-17.625467 -> V=1.0, theta=0.0
% INFO    : Bus 77041	: V=1.0271218, theta=-17.639577 -> V=1.0, theta=0.0
% INFO    : Bus 77042	: V=1.0339566, theta=-18.216866 -> V=1.0, theta=0.0
% INFO    : Bus 77043	: V=1.0293561, theta=-22.34176 -> V=1.0, theta=0.0
% INFO    : Bus 77044	: V=1.050384, theta=-22.188441 -> V=1.0, theta=0.0
% INFO    : Bus 77045	: V=1.0503518, theta=-22.192205 -> V=1.0, theta=0.0
% INFO    : Bus 77046	: V=1.0561501, theta=-25.437489 -> V=1.0, theta=0.0
% INFO    : Bus 77047	: V=1.0561364, theta=-25.438926 -> V=1.0, theta=0.0
% INFO    : Bus 77048	: V=1.0427402, theta=-25.373315 -> V=1.0, theta=0.0
% INFO    : Bus 77049	: V=1.040709, theta=-18.348553 -> V=1.0, theta=0.0
% INFO    : Bus 77050	: V=1.0339042, theta=-19.034451 -> V=1.0, theta=0.0
% INFO    : Bus 77051	: V=1.0541497, theta=-20.52074 -> V=1.0, theta=0.0
% INFO    : Bus 77052	: V=1.048611, theta=-23.695497 -> V=1.0, theta=0.0
% INFO    : Bus 77053	: V=1.0540533, theta=-20.538104 -> V=1.0, theta=0.0
% INFO    : Bus 77054	: V=1.0446277, theta=-24.155568 -> V=1.0, theta=0.0
% INFO    : Bus 77055	: V=1.0449444, theta=-24.140007 -> V=1.0, theta=0.0
% INFO    : Bus 77056	: V=1.0561335, theta=-14.257255 -> V=1.0, theta=0.0
% INFO    : Bus 77057	: V=1.0109011, theta=-20.327567 -> V=1.0, theta=0.0
% INFO    : Bus 77058	: V=1.040621, theta=-25.531959 -> V=1.0, theta=0.0
% INFO    : Bus 77059	: V=1.0404913, theta=-25.548559 -> V=1.0, theta=0.0
% INFO    : Bus 77060	: V=1.039984, theta=-25.946254 -> V=1.0, theta=0.0
% INFO    : Bus 77061	: V=1.0401637, theta=-25.931262 -> V=1.0, theta=0.0
% INFO    : Bus 77062	: V=1.039872, theta=-25.960249 -> V=1.0, theta=0.0
% INFO    : Bus 77063	: V=1.0284213, theta=-25.00346 -> V=1.0, theta=0.0
% INFO    : Bus 77064	: V=1.049389, theta=-25.713771 -> V=1.0, theta=0.0
% INFO    : Bus 77065	: V=1.0445961, theta=-28.477976 -> V=1.0, theta=0.0
% INFO    : Bus 77066	: V=1.0445716, theta=-28.480634 -> V=1.0, theta=0.0
% INFO    : Bus 77067	: V=1.0373615, theta=-18.439057 -> V=1.0, theta=0.0
% INFO    : Bus 77068	: V=1.0372193, theta=-18.453786 -> V=1.0, theta=0.0
% INFO    : Bus 77069	: V=1.0333161, theta=-19.141566 -> V=1.0, theta=0.0
% INFO    : Bus 77070	: V=1.0330281, theta=-18.594425 -> V=1.0, theta=0.0
% INFO    : Bus 77071	: V=1.0327966, theta=-18.610375 -> V=1.0, theta=0.0
% INFO    : Bus 77072	: V=1.0370529, theta=-18.442901 -> V=1.0, theta=0.0
% INFO    : Bus 77073	: V=1.0370529, theta=-18.442901 -> V=1.0, theta=0.0
% INFO    : Bus 77074	: V=1.0370529, theta=-18.442901 -> V=1.0, theta=0.0
% INFO    : Bus 77075	: V=1.0370529, theta=-18.442901 -> V=1.0, theta=0.0
% INFO    : Bus 77076	: V=1.0370548, theta=-18.442726 -> V=1.0, theta=0.0
% INFO    : Bus 77077	: V=1.0355322, theta=-18.64908 -> V=1.0, theta=0.0
% INFO    : Bus 77078	: V=1.0386522, theta=-25.348574 -> V=1.0, theta=0.0
% INFO    : Bus 77079	: V=1.0385689, theta=-25.353935 -> V=1.0, theta=0.0
% INFO    : Bus 77080	: V=1.0112101, theta=-21.682382 -> V=1.0, theta=0.0
% INFO    : Bus 77081	: V=1.0112586, theta=-21.677335 -> V=1.0, theta=0.0
% INFO    : Bus 77082	: V=1.0112101, theta=-21.682382 -> V=1.0, theta=0.0
% INFO    : Bus 77083	: V=1.0411346, theta=-25.090849 -> V=1.0, theta=0.0
% INFO    : Bus 77084	: V=1.0412336, theta=-18.11312 -> V=1.0, theta=0.0
% INFO    : Bus 77085	: V=1.0412063, theta=-18.115714 -> V=1.0, theta=0.0
% INFO    : Bus 77086	: V=1.0412606, theta=-18.11081 -> V=1.0, theta=0.0
% INFO    : Bus 77087	: V=1.0429221, theta=-27.122673 -> V=1.0, theta=0.0
% INFO    : Bus 77088	: V=1.0402673, theta=-27.631631 -> V=1.0, theta=0.0
% INFO    : Bus 77089	: V=1.04311, theta=-27.087336 -> V=1.0, theta=0.0
% INFO    : Bus 77090	: V=1.04311, theta=-27.087336 -> V=1.0, theta=0.0
% INFO    : Bus 77091	: V=1.0429658, theta=-27.117564 -> V=1.0, theta=0.0
% INFO    : Bus 77092	: V=1.0429221, theta=-27.122673 -> V=1.0, theta=0.0
% INFO    : Bus 77093	: V=1.0548026, theta=-14.193609 -> V=1.0, theta=0.0
% INFO    : Bus 77094	: V=1.0547729, theta=-14.197904 -> V=1.0, theta=0.0
% INFO    : Bus 77095	: V=1.0278307, theta=-19.301438 -> V=1.0, theta=0.0
% INFO    : Bus 77096	: V=1.0278795, theta=-19.298549 -> V=1.0, theta=0.0
% INFO    : Bus 77097	: V=1.0277776, theta=-19.304678 -> V=1.0, theta=0.0
% INFO    : Bus 77098	: V=1.0278307, theta=-19.301438 -> V=1.0, theta=0.0
% INFO    : Bus 77099	: V=1.0249134, theta=-22.504212 -> V=1.0, theta=0.0
% INFO    : Bus 77100	: V=1.0558229, theta=-14.897658 -> V=1.0, theta=0.0
% INFO    : Bus 77101	: V=1.0216262, theta=-22.847588 -> V=1.0, theta=0.0
% INFO    : Bus 77102	: V=1.0126258, theta=-22.84647 -> V=1.0, theta=0.0
% INFO    : Bus 77103	: V=1.0125653, theta=-22.855298 -> V=1.0, theta=0.0
% INFO    : Bus 77104	: V=1.0378061, theta=-26.480581 -> V=1.0, theta=0.0
% INFO    : Bus 77105	: V=1.0377787, theta=-26.48406 -> V=1.0, theta=0.0
% INFO    : Bus 77106	: V=1.0220527, theta=-23.443991 -> V=1.0, theta=0.0
% INFO    : Bus 77107	: V=1.0219928, theta=-23.448875 -> V=1.0, theta=0.0
% INFO    : Bus 77108	: V=1.0221032, theta=-23.439242 -> V=1.0, theta=0.0
% INFO    : Bus 77109	: V=1.0148265, theta=-23.500079 -> V=1.0, theta=0.0
% INFO    : Bus 77110	: V=1.0150093, theta=-23.466139 -> V=1.0, theta=0.0
% INFO    : Bus 77111	: V=1.0148673, theta=-23.481876 -> V=1.0, theta=0.0
% INFO    : Bus 77112	: V=1.0531158, theta=-15.88154 -> V=1.0, theta=0.0
% INFO    : Bus 77113	: V=1.0505397, theta=-16.779417 -> V=1.0, theta=0.0
% INFO    : Bus 77114	: V=1.0196409, theta=-22.869789 -> V=1.0, theta=0.0
% INFO    : Bus 77115	: V=1.0186561, theta=-22.86801 -> V=1.0, theta=0.0
% INFO    : Bus 77116	: V=1.0440544, theta=-13.888172 -> V=1.0, theta=0.0
% INFO    : Bus 77117	: V=1.0439966, theta=-13.892867 -> V=1.0, theta=0.0
% INFO    : Bus 77118	: V=1.0268516, theta=-20.136568 -> V=1.0, theta=0.0
% INFO    : Bus 77119	: V=1.0250049, theta=-22.019789 -> V=1.0, theta=0.0
% INFO    : Bus 77120	: V=1.0399515, theta=-29.214207 -> V=1.0, theta=0.0
% INFO    : Bus 77121	: V=1.0493143, theta=-15.417367 -> V=1.0, theta=0.0
% INFO    : Bus 77122	: V=1.0316054, theta=-22.281019 -> V=1.0, theta=0.0
% INFO    : Bus 77123	: V=1.0356312, theta=-22.909988 -> V=1.0, theta=0.0
% INFO    : Bus 77124	: V=1.035606, theta=-22.911547 -> V=1.0, theta=0.0
% INFO    : Bus 77125	: V=1.0405943, theta=-22.22883 -> V=1.0, theta=0.0
% INFO    : Bus 77126	: V=1.0528398, theta=-22.65199 -> V=1.0, theta=0.0
% INFO    : Bus 77127	: V=1.0378339, theta=-22.186712 -> V=1.0, theta=0.0
% INFO    : Bus 77128	: V=1.037945, theta=-22.176889 -> V=1.0, theta=0.0
% INFO    : Bus 77129	: V=1.0443206, theta=-23.062314 -> V=1.0, theta=0.0
% INFO    : Bus 77130	: V=1.0442005, theta=-23.085 -> V=1.0, theta=0.0
% INFO    : Bus 77131	: V=1.0444322, theta=-23.041107 -> V=1.0, theta=0.0
% INFO    : Bus 77132	: V=1.0443206, theta=-23.062314 -> V=1.0, theta=0.0
% INFO    : Bus 77133	: V=1.0084904, theta=-18.794585 -> V=1.0, theta=0.0
% INFO    : Bus 77134	: V=1.0572577, theta=-21.951896 -> V=1.0, theta=0.0
% INFO    : Bus 77135	: V=1.0278069, theta=-25.134636 -> V=1.0, theta=0.0
% INFO    : Bus 77136	: V=1.0277403, theta=-25.140903 -> V=1.0, theta=0.0
% INFO    : Bus 77137	: V=1.0294784, theta=-19.707097 -> V=1.0, theta=0.0
% INFO    : Bus 77138	: V=1.029454, theta=-19.711082 -> V=1.0, theta=0.0
% INFO    : Bus 77139	: V=1.0295801, theta=-19.704586 -> V=1.0, theta=0.0
% INFO    : Bus 77140	: V=1.0450966, theta=-22.639858 -> V=1.0, theta=0.0
% INFO    : Bus 77141	: V=1.0409936, theta=-23.098417 -> V=1.0, theta=0.0
% INFO    : Bus 77142	: V=1.0496759, theta=-22.773807 -> V=1.0, theta=0.0
% INFO    : Bus 77143	: V=1.0496192, theta=-22.779876 -> V=1.0, theta=0.0
% INFO    : Bus 77144	: V=1.0412335, theta=-23.273703 -> V=1.0, theta=0.0
% INFO    : Bus 77145	: V=1.0331548, theta=-20.881219 -> V=1.0, theta=0.0
% INFO    : Bus 77146	: V=1.0331998, theta=-20.878613 -> V=1.0, theta=0.0
% INFO    : Bus 77147	: V=1.0374223, theta=-22.013042 -> V=1.0, theta=0.0
% INFO    : Bus 77148	: V=1.0286998, theta=-18.319466 -> V=1.0, theta=0.0
% INFO    : Bus 77149	: V=1.0286126, theta=-18.330172 -> V=1.0, theta=0.0
% INFO    : Bus 77150	: V=1.0051059, theta=-18.557088 -> V=1.0, theta=0.0
% INFO    : Bus 77151	: V=1.0048531, theta=-18.57224 -> V=1.0, theta=0.0
% INFO    : Bus 77152	: V=1.0267268, theta=-16.640481 -> V=1.0, theta=0.0
% INFO    : Bus 77153	: V=1.0266003, theta=-16.650896 -> V=1.0, theta=0.0
% INFO    : Bus 77154	: V=1.0278924, theta=-16.707908 -> V=1.0, theta=0.0
% INFO    : Bus 77155	: V=1.0228655, theta=-24.332377 -> V=1.0, theta=0.0
% INFO    : Bus 77156	: V=1.0226713, theta=-24.348398 -> V=1.0, theta=0.0
% INFO    : Bus 77157	: V=1.0331393, theta=-19.608087 -> V=1.0, theta=0.0
% INFO    : Bus 77158	: V=1.0433895, theta=-23.827611 -> V=1.0, theta=0.0
% INFO    : Bus 77159	: V=1.043525, theta=-23.820309 -> V=1.0, theta=0.0
% INFO    : Bus 77160	: V=1.0395702, theta=-26.296573 -> V=1.0, theta=0.0
% INFO    : Bus 77161	: V=1.0365691, theta=-23.663207 -> V=1.0, theta=0.0
% INFO    : Bus 77162	: V=1.0365252, theta=-23.666629 -> V=1.0, theta=0.0
% INFO    : Bus 77163	: V=1.0366125, theta=-23.659791 -> V=1.0, theta=0.0
% INFO    : Bus 77164	: V=1.000845, theta=-19.234371 -> V=1.0, theta=0.0
% INFO    : Bus 77165	: V=1.0048351, theta=-19.055329 -> V=1.0, theta=0.0
% INFO    : Bus 77166	: V=1.0044238, theta=-19.083522 -> V=1.0, theta=0.0
% INFO    : Bus 77167	: V=1.0344632, theta=-20.62659 -> V=1.0, theta=0.0
% INFO    : Bus 77168	: V=1.0223298, theta=-17.32247 -> V=1.0, theta=0.0
% INFO    : Bus 77169	: V=1.0317407, theta=-16.541785 -> V=1.0, theta=0.0
% INFO    : Bus 77170	: V=1.0103189, theta=-14.582476 -> V=1.0, theta=0.0
% INFO    : Bus 77171	: V=1.0102826, theta=-14.588678 -> V=1.0, theta=0.0
% INFO    : Bus 77172	: V=1.0247892, theta=-12.617107 -> V=1.0, theta=0.0
% INFO    : Bus 77173	: V=1.0247268, theta=-12.623648 -> V=1.0, theta=0.0
% INFO    : Bus 77174	: V=1.0248502, theta=-12.609695 -> V=1.0, theta=0.0
% INFO    : Bus 77175	: V=1.0399516, theta=-21.794944 -> V=1.0, theta=0.0
% INFO    : Bus 77176	: V=1.0399311, theta=-21.797627 -> V=1.0, theta=0.0
% INFO    : Bus 77177	: V=1.0399729, theta=-21.792622 -> V=1.0, theta=0.0
% INFO    : Bus 77178	: V=1.0399516, theta=-21.794944 -> V=1.0, theta=0.0
% INFO    : Bus 77179	: V=1.0237994, theta=-15.260578 -> V=1.0, theta=0.0
% INFO    : Bus 77180	: V=1.0209976, theta=-12.989183 -> V=1.0, theta=0.0
% INFO    : Bus 77181	: V=1.02092, theta=-13.001494 -> V=1.0, theta=0.0
% INFO    : Bus 77182	: V=1.0416408, theta=-13.933912 -> V=1.0, theta=0.0
% INFO    : Bus 77183	: V=1.0416711, theta=-13.930791 -> V=1.0, theta=0.0
% INFO    : Bus 77184	: V=1.0253452, theta=-14.89279 -> V=1.0, theta=0.0
% INFO    : Bus 77185	: V=1.0330787, theta=-8.966572 -> V=1.0, theta=0.0
% INFO    : Bus 77186	: V=1.018047, theta=-11.099015 -> V=1.0, theta=0.0
% INFO    : Bus 77187	: V=0.9881154, theta=-7.41118 -> V=1.0, theta=0.0
% INFO    : Bus 77188	: V=0.9883643, theta=-7.860856 -> V=1.0, theta=0.0
% INFO    : Bus 77189	: V=0.9881295, theta=-7.435398 -> V=1.0, theta=0.0
% INFO    : Bus 77190	: V=0.9883454, theta=-7.438684 -> V=1.0, theta=0.0
% INFO    : Bus 77191	: V=0.9885809, theta=-7.534196 -> V=1.0, theta=0.0
% INFO    : Bus 77192	: V=1.0325322, theta=-9.135158 -> V=1.0, theta=0.0
% INFO    : Bus 77193	: V=1.02214, theta=-19.685256 -> V=1.0, theta=0.0
% INFO    : Bus 77194	: V=1.0291413, theta=-21.107295 -> V=1.0, theta=0.0
% INFO    : Bus 77195	: V=1.0226807, theta=-18.969181 -> V=1.0, theta=0.0
% INFO    : Bus 77196	: V=1.022901, theta=-18.583282 -> V=1.0, theta=0.0
% INFO    : Bus 77197	: V=1.02214, theta=-19.685256 -> V=1.0, theta=0.0
% INFO    : Bus 77198	: V=1.027246, theta=-9.31654 -> V=1.0, theta=0.0
% INFO    : Bus 77199	: V=1.027246, theta=-9.31654 -> V=1.0, theta=0.0
% INFO    : Bus 77200	: V=1.0352084, theta=-18.56943 -> V=1.0, theta=0.0
% INFO    : Bus 77201	: V=1.0351895, theta=-18.575544 -> V=1.0, theta=0.0
% INFO    : Bus 77202	: V=1.0207222, theta=-13.87794 -> V=1.0, theta=0.0
% INFO    : Bus 77203	: V=1.0501839, theta=-13.99095 -> V=1.0, theta=0.0
% INFO    : Bus 77204	: V=1.0207222, theta=-13.87794 -> V=1.0, theta=0.0
% INFO    : Bus 77205	: V=1.0207141, theta=-13.87902 -> V=1.0, theta=0.0
% INFO    : Bus 77206	: V=1.0167901, theta=-22.345514 -> V=1.0, theta=0.0
% INFO    : Bus 77207	: V=1.0375173, theta=-21.203756 -> V=1.0, theta=0.0
% INFO    : Bus 77208	: V=1.0172391, theta=-22.351863 -> V=1.0, theta=0.0
% INFO    : Bus 77209	: V=1.0361557, theta=-13.427143 -> V=1.0, theta=0.0
% INFO    : Bus 77210	: V=1.0348508, theta=-17.180615 -> V=1.0, theta=0.0
% INFO    : Bus 77211	: V=1.0357492, theta=-18.914721 -> V=1.0, theta=0.0
% INFO    : Bus 77212	: V=1.0357492, theta=-18.914721 -> V=1.0, theta=0.0
% INFO    : Bus 77213	: V=1.0018907, theta=-12.083751 -> V=1.0, theta=0.0
% INFO    : Bus 77214	: V=1.0318492, theta=-11.082598 -> V=1.0, theta=0.0
% INFO    : Bus 77215	: V=1.0352965, theta=-13.08425 -> V=1.0, theta=0.0
% INFO    : Bus 77216	: V=1.0318492, theta=-11.082598 -> V=1.0, theta=0.0
% INFO    : Bus 77217	: V=1.0450517, theta=-10.433091 -> V=1.0, theta=0.0
% INFO    : Bus 77218	: V=1.0468975, theta=-10.402518 -> V=1.0, theta=0.0
% INFO    : Bus 77219	: V=1.0452482, theta=-10.471993 -> V=1.0, theta=0.0
% INFO    : Bus 77220	: V=1.0325851, theta=-11.067919 -> V=1.0, theta=0.0
% INFO    : Bus 77221	: V=1.01724, theta=-14.241279 -> V=1.0, theta=0.0
% INFO    : Bus 77222	: V=1.0214742, theta=-16.796036 -> V=1.0, theta=0.0
% INFO    : Bus 77223	: V=1.0225436, theta=-12.847271 -> V=1.0, theta=0.0
% INFO    : Bus 77224	: V=1.0218945, theta=-12.905902 -> V=1.0, theta=0.0
% INFO    : Bus 77225	: V=1.0233403, theta=-12.139416 -> V=1.0, theta=0.0
% INFO    : Bus 77226	: V=1.01724, theta=-14.241279 -> V=1.0, theta=0.0
% INFO    : Bus 77227	: V=1.0190336, theta=-14.357629 -> V=1.0, theta=0.0
% INFO    : Bus 77228	: V=1.0429354, theta=-20.269703 -> V=1.0, theta=0.0
% INFO    : Bus 77229	: V=1.0267089, theta=-22.334021 -> V=1.0, theta=0.0
% INFO    : Bus 77230	: V=1.0435478, theta=-20.229211 -> V=1.0, theta=0.0
% INFO    : Bus 77231	: V=1.0448108, theta=-17.542717 -> V=1.0, theta=0.0
% INFO    : Bus 77232	: V=1.018024, theta=-13.345541 -> V=1.0, theta=0.0
% INFO    : Bus 77233	: V=1.0254806, theta=-15.605444 -> V=1.0, theta=0.0
% INFO    : Bus 77234	: V=1.03517, theta=-17.977272 -> V=1.0, theta=0.0
% INFO    : Bus 77235	: V=1.03517, theta=-17.977272 -> V=1.0, theta=0.0
% INFO    : Bus 77236	: V=1.0004626, theta=-12.266806 -> V=1.0, theta=0.0
% INFO    : Bus 77237	: V=1.0012849, theta=-12.357071 -> V=1.0, theta=0.0
% INFO    : Bus 77238	: V=1.0024901, theta=-12.039459 -> V=1.0, theta=0.0
% INFO    : Bus 77239	: V=1.02018, theta=7.477486 -> V=1.0, theta=0.0
% INFO    : Bus 77240	: V=1.0246381, theta=6.24438 -> V=1.0, theta=0.0
% INFO    : Bus 77241	: V=1.0270714, theta=5.625192 -> V=1.0, theta=0.0
% INFO    : Bus 77242	: V=1.0270714, theta=5.625192 -> V=1.0, theta=0.0
% INFO    : Bus 77243	: V=0.9855216, theta=8.942711 -> V=1.0, theta=0.0
% INFO    : Bus 77244	: V=0.9826349, theta=8.267987 -> V=1.0, theta=0.0
% INFO    : Bus 77245	: V=0.9829947, theta=7.89123 -> V=1.0, theta=0.0
% INFO    : Bus 77246	: V=1.02018, theta=7.477486 -> V=1.0, theta=0.0
% INFO    : Bus 77247	: V=1.0338006, theta=-17.354065 -> V=1.0, theta=0.0
% INFO    : Bus 77248	: V=1.023779, theta=-12.884812 -> V=1.0, theta=0.0
% INFO    : Bus 77249	: V=1.0455375, theta=-21.429296 -> V=1.0, theta=0.0
% INFO    : Bus 77250	: V=1.01416, theta=-16.722069 -> V=1.0, theta=0.0
% INFO    : Bus 77251	: V=1.0131763, theta=-17.781654 -> V=1.0, theta=0.0
% INFO    : Bus 77252	: V=1.0297208, theta=-13.495907 -> V=1.0, theta=0.0
% INFO    : Bus 77253	: V=1.025834, theta=-14.115531 -> V=1.0, theta=0.0
% INFO    : Bus 77254	: V=1.02018, theta=-7.256776 -> V=1.0, theta=0.0
% INFO    : Bus 77255	: V=1.0258278, theta=-8.360552 -> V=1.0, theta=0.0
% INFO    : Bus 77256	: V=1.0267491, theta=-8.532777 -> V=1.0, theta=0.0
% INFO    : Bus 77257	: V=1.0267491, theta=-8.532777 -> V=1.0, theta=0.0
% INFO    : Bus 77258	: V=0.9925613, theta=-6.13812 -> V=1.0, theta=0.0
% INFO    : Bus 77259	: V=0.9879932, theta=-1.754477 -> V=1.0, theta=0.0
% INFO    : Bus 77260	: V=0.9901792, theta=-5.07351 -> V=1.0, theta=0.0
% INFO    : Bus 77261	: V=0.990419, theta=-3.085145 -> V=1.0, theta=0.0
% INFO    : Bus 77262	: V=1.0187286, theta=18.401912 -> V=1.0, theta=0.0
% INFO    : Bus 77263	: V=1.0121116, theta=-21.142486 -> V=1.0, theta=0.0
% INFO    : Bus 77264	: V=1.0182199, theta=-22.068538 -> V=1.0, theta=0.0
% INFO    : Bus 77265	: V=1.0104207, theta=-20.876715 -> V=1.0, theta=0.0
% INFO    : Bus 77266	: V=1.0104207, theta=-20.876715 -> V=1.0, theta=0.0
% INFO    : Bus 77267	: V=1.0380169, theta=-18.135754 -> V=1.0, theta=0.0
% INFO    : Bus 77268	: V=1.0505347, theta=-17.680433 -> V=1.0, theta=0.0
% INFO    : Bus 77269	: V=1.0376156, theta=-18.141568 -> V=1.0, theta=0.0
% INFO    : Bus 77270	: V=1.0198666, theta=-19.219528 -> V=1.0, theta=0.0
% INFO    : Bus 77271	: V=1.0197906, theta=-19.239039 -> V=1.0, theta=0.0
% INFO    : Bus 77272	: V=1.0157066, theta=-12.460265 -> V=1.0, theta=0.0
% INFO    : Bus 77273	: V=1.0464929, theta=-12.929617 -> V=1.0, theta=0.0
% INFO    : Bus 77274	: V=1.0292397, theta=-11.028346 -> V=1.0, theta=0.0
% INFO    : Bus 77275	: V=1.0226372, theta=-11.760919 -> V=1.0, theta=0.0
% INFO    : Bus 77276	: V=1.0314244, theta=-10.995492 -> V=1.0, theta=0.0
% INFO    : Bus 77277	: V=1.0157066, theta=-12.460265 -> V=1.0, theta=0.0
% INFO    : Bus 77278	: V=1.0157066, theta=-12.460265 -> V=1.0, theta=0.0
% INFO    : Bus 77279	: V=1.0559988, theta=-13.953806 -> V=1.0, theta=0.0
% INFO    : Bus 77280	: V=1.0080657, theta=-11.120582 -> V=1.0, theta=0.0
% INFO    : Bus 77281	: V=1.055612, theta=-13.993077 -> V=1.0, theta=0.0
% INFO    : Bus 77282	: V=1.02116, theta=-11.008794 -> V=1.0, theta=0.0
% INFO    : Bus 77283	: V=1.0282097, theta=-13.293819 -> V=1.0, theta=0.0
% INFO    : Bus 77284	: V=1.0338513, theta=-14.809387 -> V=1.0, theta=0.0
% INFO    : Bus 77285	: V=1.0338513, theta=-14.809387 -> V=1.0, theta=0.0
% INFO    : Bus 77286	: V=1.0264706, theta=-9.151324 -> V=1.0, theta=0.0
% INFO    : Bus 77287	: V=1.02018, theta=-13.076847 -> V=1.0, theta=0.0
% INFO    : Bus 77288	: V=1.0280361, theta=-13.27506 -> V=1.0, theta=0.0
% INFO    : Bus 77289	: V=1.0080812, theta=-10.63445 -> V=1.0, theta=0.0
% INFO    : Bus 77290	: V=1.04, theta=-18.266216 -> V=1.0, theta=0.0
% INFO    : Bus 77291	: V=1.0385389, theta=-18.148182 -> V=1.0, theta=0.0
% INFO    : Bus 77292	: V=1.0384719, theta=-18.17213 -> V=1.0, theta=0.0
% INFO    : Bus 77293	: V=1.0385389, theta=-18.148182 -> V=1.0, theta=0.0
% INFO    : Bus 77294	: V=1.0392258, theta=-18.131572 -> V=1.0, theta=0.0
% INFO    : Bus 77295	: V=1.0391881, theta=-18.145515 -> V=1.0, theta=0.0
% INFO    : Bus 80000	: V=1.0268561, theta=-75.282253 -> V=1.0, theta=0.0
% INFO    : Bus 80001	: V=1.0272137, theta=-75.248625 -> V=1.0, theta=0.0
% INFO    : Bus 80002	: V=1.0268561, theta=-75.282253 -> V=1.0, theta=0.0
% INFO    : Bus 80003	: V=1.0245652, theta=-74.902955 -> V=1.0, theta=0.0
% INFO    : Bus 80004	: V=1.0299442, theta=-75.254336 -> V=1.0, theta=0.0
% INFO    : Bus 80005	: V=1.0300884, theta=-75.798939 -> V=1.0, theta=0.0
% INFO    : Bus 80006	: V=1.0098501, theta=-71.597161 -> V=1.0, theta=0.0
% INFO    : Bus 80007	: V=1.0433851, theta=-74.983937 -> V=1.0, theta=0.0
% INFO    : Bus 80008	: V=1.0329668, theta=-75.709206 -> V=1.0, theta=0.0
% INFO    : Bus 80009	: V=1.0327186, theta=-75.741921 -> V=1.0, theta=0.0
% INFO    : Bus 80010	: V=1.0366628, theta=-75.31421 -> V=1.0, theta=0.0
% INFO    : Bus 80011	: V=1.0363685, theta=-75.377481 -> V=1.0, theta=0.0
% INFO    : Bus 80012	: V=1.0342918, theta=-75.349942 -> V=1.0, theta=0.0
% INFO    : Bus 80013	: V=1.0343544, theta=-75.496572 -> V=1.0, theta=0.0
% INFO    : Bus 80014	: V=1.0162074, theta=-77.421237 -> V=1.0, theta=0.0
% INFO    : Bus 80015	: V=1.0160819, theta=-77.437177 -> V=1.0, theta=0.0
% INFO    : Bus 80016	: V=1.0163122, theta=-77.406448 -> V=1.0, theta=0.0
% INFO    : Bus 80017	: V=1.016424, theta=-76.336126 -> V=1.0, theta=0.0
% INFO    : Bus 80018	: V=1.0195551, theta=-76.016437 -> V=1.0, theta=0.0
% INFO    : Bus 80019	: V=1.0193657, theta=-76.040614 -> V=1.0, theta=0.0
% INFO    : Bus 80020	: V=1.0242379, theta=-76.722561 -> V=1.0, theta=0.0
% INFO    : Bus 80021	: V=1.027588, theta=-75.31016 -> V=1.0, theta=0.0
% INFO    : Bus 80022	: V=1.0238982, theta=-76.233222 -> V=1.0, theta=0.0
% INFO    : Bus 80023	: V=1.0237926, theta=-76.250212 -> V=1.0, theta=0.0
% INFO    : Bus 80024	: V=1.0158813, theta=-77.440583 -> V=1.0, theta=0.0
% INFO    : Bus 80025	: V=1.0365631, theta=-75.255341 -> V=1.0, theta=0.0
% INFO    : Bus 80026	: V=1.0154445, theta=-76.338225 -> V=1.0, theta=0.0
% INFO    : Bus 80027	: V=1.0151886, theta=-76.355912 -> V=1.0, theta=0.0
% INFO    : Bus 80028	: V=1.0140736, theta=-75.986936 -> V=1.0, theta=0.0
% INFO    : Bus 80029	: V=1.013828, theta=-76.026423 -> V=1.0, theta=0.0
% INFO    : Bus 80030	: V=1.0297887, theta=-76.219048 -> V=1.0, theta=0.0
% INFO    : Bus 80031	: V=1.0297419, theta=-76.224937 -> V=1.0, theta=0.0
% INFO    : Bus 80032	: V=1.0293899, theta=-76.03541 -> V=1.0, theta=0.0
% INFO    : Bus 80033	: V=1.0218404, theta=-77.356148 -> V=1.0, theta=0.0
% INFO    : Bus 80034	: V=1.0214555, theta=-77.383354 -> V=1.0, theta=0.0
% INFO    : Bus 80035	: V=1.028478, theta=-77.04054 -> V=1.0, theta=0.0
% INFO    : Bus 80036	: V=1.0198071, theta=-76.045958 -> V=1.0, theta=0.0
% INFO    : Bus 80037	: V=1.0166537, theta=-76.611064 -> V=1.0, theta=0.0
% INFO    : Bus 80038	: V=1.0352857, theta=-76.734983 -> V=1.0, theta=0.0
% INFO    : Bus 80039	: V=1.03514, theta=-76.757341 -> V=1.0, theta=0.0
% INFO    : Bus 80040	: V=1.0354388, theta=-76.711138 -> V=1.0, theta=0.0
% INFO    : Bus 80041	: V=1.0352857, theta=-76.734983 -> V=1.0, theta=0.0
% INFO    : Bus 80042	: V=1.0352857, theta=-76.734983 -> V=1.0, theta=0.0
% INFO    : Bus 80043	: V=1.0155587, theta=-77.304175 -> V=1.0, theta=0.0
% INFO    : Bus 80044	: V=1.02054, theta=-77.905805 -> V=1.0, theta=0.0
% INFO    : Bus 80045	: V=1.0058836, theta=-72.711616 -> V=1.0, theta=0.0
% INFO    : Bus 80046	: V=1.0444522, theta=-76.018618 -> V=1.0, theta=0.0
% INFO    : Bus 80047	: V=1.0233389, theta=-77.62202 -> V=1.0, theta=0.0
% INFO    : Bus 80048	: V=1.0182237, theta=-67.551606 -> V=1.0, theta=0.0
% INFO    : Bus 80049	: V=1.0216099, theta=-71.658881 -> V=1.0, theta=0.0
% INFO    : Bus 80050	: V=1.0233689, theta=-76.271868 -> V=1.0, theta=0.0
% INFO    : Bus 80051	: V=1.0243241, theta=-77.051926 -> V=1.0, theta=0.0
% INFO    : Bus 80052	: V=1.0243241, theta=-77.051926 -> V=1.0, theta=0.0
% INFO    : Bus 80053	: V=1.0200015, theta=-72.789115 -> V=1.0, theta=0.0
% INFO    : Bus 80054	: V=1.0152989, theta=-77.300909 -> V=1.0, theta=0.0
% INFO    : Bus 80055	: V=1.0070942, theta=-86.825289 -> V=1.0, theta=0.0
% INFO    : Bus 80056	: V=1.0345273, theta=-79.28081 -> V=1.0, theta=0.0
% INFO    : Bus 80057	: V=1.0201068, theta=-72.728503 -> V=1.0, theta=0.0
% INFO    : Bus 80058	: V=1.0164311, theta=-77.621553 -> V=1.0, theta=0.0
% INFO    : Bus 80059	: V=1.0161489, theta=-77.644008 -> V=1.0, theta=0.0
% INFO    : Bus 80060	: V=1.0167488, theta=-77.260899 -> V=1.0, theta=0.0
% INFO    : Bus 80061	: V=1.0165723, theta=-77.279048 -> V=1.0, theta=0.0
% INFO    : Bus 80062	: V=1.0169225, theta=-77.244543 -> V=1.0, theta=0.0
% INFO    : Bus 80063	: V=1.0167488, theta=-77.260899 -> V=1.0, theta=0.0
% INFO    : Bus 80064	: V=1.0167488, theta=-77.260899 -> V=1.0, theta=0.0
% INFO    : Bus 80065	: V=1.0084504, theta=-77.043808 -> V=1.0, theta=0.0
% INFO    : Bus 80066	: V=1.0082735, theta=-77.050455 -> V=1.0, theta=0.0
% INFO    : Bus 80067	: V=1.0109005, theta=-76.979771 -> V=1.0, theta=0.0
% INFO    : Bus 80068	: V=1.0160596, theta=-73.463028 -> V=1.0, theta=0.0
% INFO    : Bus 80069	: V=1.0119163, theta=-76.846205 -> V=1.0, theta=0.0
% INFO    : Bus 80070	: V=1.0157698, theta=-73.496036 -> V=1.0, theta=0.0
% INFO    : Bus 80071	: V=1.016593, theta=-73.38308 -> V=1.0, theta=0.0
% INFO    : Bus 80072	: V=1.0098884, theta=-77.37768 -> V=1.0, theta=0.0
% INFO    : Bus 80073	: V=1.0185255, theta=-77.78601 -> V=1.0, theta=0.0
% INFO    : Bus 80074	: V=0.9981317, theta=-77.568649 -> V=1.0, theta=0.0
% INFO    : Bus 80075	: V=0.9978847, theta=-77.606357 -> V=1.0, theta=0.0
% INFO    : Bus 80076	: V=1.0267857, theta=-73.002111 -> V=1.0, theta=0.0
% INFO    : Bus 80077	: V=0.9980853, theta=-77.270498 -> V=1.0, theta=0.0
% INFO    : Bus 80078	: V=0.950989, theta=-86.871352 -> V=1.0, theta=0.0
% INFO    : Bus 80079	: V=1.0003238, theta=-77.940403 -> V=1.0, theta=0.0
% INFO    : Bus 80080	: V=1.0265691, theta=-72.946951 -> V=1.0, theta=0.0
% INFO    : Bus 80081	: V=1.0177646, theta=-77.689164 -> V=1.0, theta=0.0
% INFO    : Bus 80082	: V=1.0178041, theta=-77.687026 -> V=1.0, theta=0.0
% INFO    : Bus 80083	: V=1.0242951, theta=-77.905561 -> V=1.0, theta=0.0
% INFO    : Bus 80084	: V=1.0242843, theta=-77.906419 -> V=1.0, theta=0.0
% INFO    : Bus 80085	: V=1.021232, theta=-76.886073 -> V=1.0, theta=0.0
% INFO    : Bus 80086	: V=1.02214, theta=-66.978906 -> V=1.0, theta=0.0
% INFO    : Bus 80087	: V=1.0150733, theta=-71.265227 -> V=1.0, theta=0.0
% INFO    : Bus 80088	: V=1.0182391, theta=-74.74499 -> V=1.0, theta=0.0
% INFO    : Bus 80089	: V=1.0170452, theta=-73.83368 -> V=1.0, theta=0.0
% INFO    : Bus 80090	: V=1.0170452, theta=-73.83368 -> V=1.0, theta=0.0
% INFO    : Bus 80091	: V=1.0257856, theta=-65.988171 -> V=1.0, theta=0.0
% INFO    : Bus 80092	: V=1.0244746, theta=-66.364134 -> V=1.0, theta=0.0
% INFO    : Bus 80093	: V=1.0241868, theta=-66.440426 -> V=1.0, theta=0.0
% INFO    : Bus 80094	: V=1.0254376, theta=-66.109456 -> V=1.0, theta=0.0
% INFO    : Bus 80095	: V=1.0252869, theta=-66.133676 -> V=1.0, theta=0.0
% INFO    : Bus 80096	: V=1.0249016, theta=-66.2375 -> V=1.0, theta=0.0
% INFO    : Bus 80097	: V=1.02214, theta=-66.978906 -> V=1.0, theta=0.0
% INFO    : Bus 80098	: V=1.025364, theta=-66.192405 -> V=1.0, theta=0.0
% INFO    : Bus 80099	: V=1.0276865, theta=-65.594145 -> V=1.0, theta=0.0
% INFO    : Bus 80100	: V=1.0183256, theta=-74.884219 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 10683	: Pg=0.0, Qg=0.0 -> Pg=105.64, Qg=26.68
% INFO    : Gen at bus 10683	: Vg=1.0464 -> Vg=1.0
% INFO    : Gen at bus 10684	: Pg=85.29, Qg=58.95 -> Pg=85.29, Qg=26.68
% INFO    : Gen at bus 10684	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 10685	: Pg=138.65, Qg=58.95 -> Pg=138.65, Qg=26.68
% INFO    : Gen at bus 10685	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 10686	: Pg=0.0, Qg=0.0 -> Pg=107.655, Qg=26.68
% INFO    : Gen at bus 10686	: Vg=1.0464 -> Vg=1.0
% INFO    : Gen at bus 10687	: Pg=120.63, Qg=58.95 -> Pg=120.63, Qg=26.68
% INFO    : Gen at bus 10687	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 10688	: Pg=109.93, Qg=58.95 -> Pg=109.93, Qg=26.68
% INFO    : Gen at bus 10688	: Vg=1.0208 -> Vg=1.0
% INFO    : Gen at bus 10689	: Pg=9.02, Qg=4.95 -> Pg=9.02, Qg=2.16
% INFO    : Gen at bus 10689	: Vg=1.0014 -> Vg=1.0
% INFO    : Gen at bus 10691	: Pg=59.72, Qg=21.07 -> Pg=59.72, Qg=3.415
% INFO    : Gen at bus 10691	: Vg=1.0063 -> Vg=1.0
% INFO    : Gen at bus 10694	: Pg=23.02, Qg=4.19 -> Pg=23.02, Qg=5.865
% INFO    : Gen at bus 10694	: Vg=1.0483 -> Vg=1.0
% INFO    : Gen at bus 10695	: Pg=25.55, Qg=4.19 -> Pg=25.55, Qg=5.865
% INFO    : Gen at bus 10695	: Vg=1.0484 -> Vg=1.0
% INFO    : Gen at bus 10699	: Pg=79.42, Qg=-14.5 -> Pg=79.42, Qg=3.475
% INFO    : Gen at bus 10699	: Vg=1.0019 -> Vg=1.0
% INFO    : Gen at bus 10703	: Pg=136.3, Qg=25.92 -> Pg=136.3, Qg=4.7
% INFO    : Gen at bus 10703	: Vg=1.0605 -> Vg=1.0
% INFO    : Gen at bus 10710	: Pg=171.16, Qg=-10.61 -> Pg=171.16, Qg=36.28
% INFO    : Gen at bus 10710	: Vg=1.0096 -> Vg=1.0
% INFO    : Gen at bus 10711	: Pg=189.67, Qg=-10.61 -> Pg=189.67, Qg=36.28
% INFO    : Gen at bus 10711	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 10712	: Pg=135.95, Qg=-10.61 -> Pg=135.95, Qg=36.28
% INFO    : Gen at bus 10712	: Vg=1.0097 -> Vg=1.0
% INFO    : Gen at bus 10713	: Pg=189.37, Qg=-10.61 -> Pg=189.37, Qg=36.28
% INFO    : Gen at bus 10713	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 10714	: Pg=0.0, Qg=0.0 -> Pg=129.665, Qg=36.28
% INFO    : Gen at bus 10714	: Vg=1.0296 -> Vg=1.0
% INFO    : Gen at bus 10715	: Pg=172.43, Qg=-10.61 -> Pg=172.43, Qg=36.28
% INFO    : Gen at bus 10715	: Vg=1.0166 -> Vg=1.0
% INFO    : Gen at bus 10722	: Pg=0.0, Qg=0.0 -> Pg=68.84, Qg=17.57
% INFO    : Gen at bus 10722	: Vg=1.0344 -> Vg=1.0
% INFO    : Gen at bus 10723	: Pg=82.25, Qg=40.28 -> Pg=82.25, Qg=17.57
% INFO    : Gen at bus 10723	: Vg=1.0007 -> Vg=1.0
% INFO    : Gen at bus 10724	: Pg=104.9, Qg=40.28 -> Pg=104.9, Qg=17.57
% INFO    : Gen at bus 10724	: Vg=1.0018 -> Vg=1.0
% INFO    : Gen at bus 10725	: Pg=71.29, Qg=40.28 -> Pg=71.29, Qg=17.57
% INFO    : Gen at bus 10725	: Vg=1.0026 -> Vg=1.0
% INFO    : Gen at bus 10726	: Pg=71.08, Qg=40.28 -> Pg=71.08, Qg=17.57
% INFO    : Gen at bus 10726	: Vg=1.0029 -> Vg=1.0
% INFO    : Gen at bus 10727	: Pg=0.0, Qg=0.0 -> Pg=66.575, Qg=17.57
% INFO    : Gen at bus 10727	: Vg=1.0344 -> Vg=1.0
% INFO    : Gen at bus 10728	: Pg=23.81, Qg=-1.37 -> Pg=23.81, Qg=4.68
% INFO    : Gen at bus 10728	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 10728	: Pg=0.0, Qg=0.0 -> Pg=17.465, Qg=4.68
% INFO    : Gen at bus 10728	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 10729	: Pg=0.0, Qg=0.0 -> Pg=16.99, Qg=4.68
% INFO    : Gen at bus 10729	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 10729	: Pg=20.46, Qg=-1.37 -> Pg=20.46, Qg=4.68
% INFO    : Gen at bus 10729	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 10731	: Pg=0.0, Qg=0.0 -> Pg=11.28, Qg=2.835
% INFO    : Gen at bus 10731	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10731	: Pg=0.0, Qg=0.0 -> Pg=11.89, Qg=2.835
% INFO    : Gen at bus 10731	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10731	: Pg=0.0, Qg=0.0 -> Pg=9.98, Qg=2.835
% INFO    : Gen at bus 10731	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10731	: Pg=9.83, Qg=-0.83 -> Pg=9.83, Qg=2.835
% INFO    : Gen at bus 10731	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10731	: Pg=0.0, Qg=0.0 -> Pg=10.54, Qg=2.835
% INFO    : Gen at bus 10731	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10737	: Pg=158.5, Qg=81.01 -> Pg=115.85, Qg=31.67
% INFO    : Gen at bus 10737	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 10738	: Pg=158.5, Qg=81.01 -> Pg=108.845, Qg=31.67
% INFO    : Gen at bus 10738	: Vg=1.0344 -> Vg=1.0
% INFO    : Gen at bus 10742	: Pg=80.0, Qg=-3.92 -> Pg=80.0, Qg=13.4
% INFO    : Gen at bus 10742	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 10743	: Pg=0.0, Qg=0.0 -> Pg=55.985, Qg=13.4
% INFO    : Gen at bus 10743	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 10744	: Pg=64.23, Qg=-3.92 -> Pg=64.23, Qg=13.4
% INFO    : Gen at bus 10744	: Vg=1.0262 -> Vg=1.0
% INFO    : Gen at bus 10746	: Pg=66.35, Qg=-12.96 -> Pg=66.35, Qg=3.105
% INFO    : Gen at bus 10746	: Vg=1.0205 -> Vg=1.0
% INFO    : Gen at bus 10750	: Pg=409.37, Qg=-20.06 -> Pg=409.37, Qg=68.57
% INFO    : Gen at bus 10750	: Vg=1.0419 -> Vg=1.0
% INFO    : Gen at bus 10751	: Pg=0.0, Qg=0.0 -> Pg=228.385, Qg=68.57
% INFO    : Gen at bus 10751	: Vg=1.0433 -> Vg=1.0
% INFO    : Gen at bus 10752	: Pg=293.05, Qg=-20.06 -> Pg=293.05, Qg=68.57
% INFO    : Gen at bus 10752	: Vg=1.0421 -> Vg=1.0
% INFO    : Gen at bus 10753	: Pg=0.0, Qg=0.0 -> Pg=229.495, Qg=68.57
% INFO    : Gen at bus 10753	: Vg=1.0433 -> Vg=1.0
% INFO    : Gen at bus 10754	: Pg=323.1, Qg=-20.06 -> Pg=323.1, Qg=68.57
% INFO    : Gen at bus 10754	: Vg=1.0417 -> Vg=1.0
% INFO    : Gen at bus 10755	: Pg=333.93, Qg=-20.06 -> Pg=333.93, Qg=68.57
% INFO    : Gen at bus 10755	: Vg=1.0413 -> Vg=1.0
% INFO    : Gen at bus 10757	: Pg=40.5, Qg=-1.98 -> Pg=40.5, Qg=6.785
% INFO    : Gen at bus 10757	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 10757	: Pg=40.5, Qg=-1.98 -> Pg=40.5, Qg=6.785
% INFO    : Gen at bus 10757	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 10757	: Pg=28.94, Qg=-1.98 -> Pg=28.94, Qg=6.785
% INFO    : Gen at bus 10757	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 10757	: Pg=0.0, Qg=0.0 -> Pg=25.04, Qg=6.785
% INFO    : Gen at bus 10757	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 10758	: Pg=0.0, Qg=0.0 -> Pg=37.51, Qg=9.315
% INFO    : Gen at bus 10758	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10758	: Pg=55.6, Qg=21.35 -> Pg=55.6, Qg=9.315
% INFO    : Gen at bus 10758	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10760	: Pg=0.0, Qg=0.0 -> Pg=37.28, Qg=0.0
% INFO    : Gen at bus 10760	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10768	: Pg=212.51, Qg=56.83 -> Pg=212.51, Qg=9.205
% INFO    : Gen at bus 10768	: Vg=1.0304 -> Vg=1.0
% INFO    : Gen at bus 10771	: Pg=51.82, Qg=19.9 -> Pg=51.82, Qg=8.68
% INFO    : Gen at bus 10771	: Vg=1.0384 -> Vg=1.0
% INFO    : Gen at bus 10772	: Pg=41.62, Qg=19.9 -> Pg=41.62, Qg=8.68
% INFO    : Gen at bus 10772	: Vg=1.0394 -> Vg=1.0
% INFO    : Gen at bus 10773	: Pg=0.0, Qg=0.0 -> Pg=36.35, Qg=8.68
% INFO    : Gen at bus 10773	: Vg=1.0317 -> Vg=1.0
% INFO    : Gen at bus 10774	: Pg=41.38, Qg=19.9 -> Pg=41.38, Qg=8.68
% INFO    : Gen at bus 10774	: Vg=1.0373 -> Vg=1.0
% INFO    : Gen at bus 10776	: Pg=0.0, Qg=0.0 -> Pg=15.885, Qg=0.0
% INFO    : Gen at bus 10776	: Vg=1.0318 -> Vg=1.0
% INFO    : Gen at bus 10776	: Pg=14.32, Qg=0.0 -> Pg=14.32, Qg=0.0
% INFO    : Gen at bus 10776	: Vg=1.0318 -> Vg=1.0
% INFO    : Gen at bus 10778	: Pg=8.03, Qg=-0.49 -> Pg=8.03, Qg=1.675
% INFO    : Gen at bus 10778	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10778	: Pg=14.8, Qg=-0.73 -> Pg=14.8, Qg=2.475
% INFO    : Gen at bus 10778	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10782	: Pg=13.43, Qg=0.0 -> Pg=13.43, Qg=0.0
% INFO    : Gen at bus 10782	: Vg=1.0162 -> Vg=1.0
% INFO    : Gen at bus 10782	: Pg=14.65, Qg=0.0 -> Pg=14.65, Qg=0.0
% INFO    : Gen at bus 10782	: Vg=1.0162 -> Vg=1.0
% INFO    : Gen at bus 10783	: Pg=13.24, Qg=0.0 -> Pg=13.24, Qg=0.0
% INFO    : Gen at bus 10783	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 10784	: Pg=17.21, Qg=0.0 -> Pg=17.21, Qg=0.0
% INFO    : Gen at bus 10784	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10784	: Pg=42.83, Qg=0.0 -> Pg=42.83, Qg=0.0
% INFO    : Gen at bus 10784	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10785	: Pg=39.4, Qg=0.0 -> Pg=39.4, Qg=0.0
% INFO    : Gen at bus 10785	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10785	: Pg=31.08, Qg=0.0 -> Pg=31.08, Qg=0.0
% INFO    : Gen at bus 10785	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10791	: Pg=58.2, Qg=22.43 -> Pg=58.2, Qg=3.635
% INFO    : Gen at bus 10791	: Vg=0.996 -> Vg=1.0
% INFO    : Gen at bus 10796	: Pg=0.0, Qg=0.0 -> Pg=24.56, Qg=8.3
% INFO    : Gen at bus 10796	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 10797	: Pg=41.53, Qg=10.61 -> Pg=25.265, Qg=8.3
% INFO    : Gen at bus 10797	: Vg=1.0445 -> Vg=1.0
% INFO    : Gen at bus 10797	: Pg=41.53, Qg=10.61 -> Pg=29.17, Qg=8.3
% INFO    : Gen at bus 10797	: Vg=1.0445 -> Vg=1.0
% INFO    : Gen at bus 10798	: Pg=41.53, Qg=-4.63 -> Pg=27.755, Qg=8.3
% INFO    : Gen at bus 10798	: Vg=1.0269 -> Vg=1.0
% INFO    : Gen at bus 10800	: Pg=82.34, Qg=-14.08 -> Pg=82.34, Qg=3.375
% INFO    : Gen at bus 10800	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10802	: Pg=10.22, Qg=4.61 -> Pg=10.22, Qg=2.01
% INFO    : Gen at bus 10802	: Vg=1.0443 -> Vg=1.0
% INFO    : Gen at bus 10803	: Pg=12.0, Qg=4.61 -> Pg=12.0, Qg=2.01
% INFO    : Gen at bus 10803	: Vg=1.0444 -> Vg=1.0
% INFO    : Gen at bus 10806	: Pg=34.74, Qg=-2.23 -> Pg=34.74, Qg=7.64
% INFO    : Gen at bus 10806	: Vg=1.0235 -> Vg=1.0
% INFO    : Gen at bus 10806	: Pg=42.97, Qg=-2.23 -> Pg=42.97, Qg=7.64
% INFO    : Gen at bus 10806	: Vg=1.0235 -> Vg=1.0
% INFO    : Gen at bus 10807	: Pg=0.0, Qg=0.0 -> Pg=33.305, Qg=7.64
% INFO    : Gen at bus 10807	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 10807	: Pg=30.26, Qg=-2.23 -> Pg=30.26, Qg=7.64
% INFO    : Gen at bus 10807	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 10811	: Pg=1195.12, Qg=296.98 -> Pg=834.565, Qg=171.6
% INFO    : Gen at bus 10811	: Vg=1.0653 -> Vg=1.0
% INFO    : Gen at bus 10813	: Pg=56.32, Qg=-3.28 -> Pg=56.32, Qg=11.225
% INFO    : Gen at bus 10813	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 10813	: Pg=0.0, Qg=0.0 -> Pg=48.685, Qg=11.225
% INFO    : Gen at bus 10813	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 10817	: Pg=50.7, Qg=0.0 -> Pg=50.7, Qg=0.0
% INFO    : Gen at bus 10817	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10818	: Pg=0.0, Qg=0.0 -> Pg=4.765, Qg=0.0
% INFO    : Gen at bus 10818	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10821	: Pg=0.0, Qg=0.0 -> Pg=107.525, Qg=5.22
% INFO    : Gen at bus 10821	: Vg=1.0423 -> Vg=1.0
% INFO    : Gen at bus 10829	: Pg=75.24, Qg=-6.62 -> Pg=75.24, Qg=22.61
% INFO    : Gen at bus 10829	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 10830	: Pg=135.0, Qg=-6.62 -> Pg=135.0, Qg=22.61
% INFO    : Gen at bus 10830	: Vg=1.0235 -> Vg=1.0
% INFO    : Gen at bus 10831	: Pg=106.15, Qg=-6.62 -> Pg=106.15, Qg=22.61
% INFO    : Gen at bus 10831	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 10832	: Pg=135.0, Qg=-6.62 -> Pg=135.0, Qg=22.61
% INFO    : Gen at bus 10832	: Vg=1.0236 -> Vg=1.0
% INFO    : Gen at bus 10833	: Pg=88.14, Qg=-6.62 -> Pg=88.14, Qg=22.61
% INFO    : Gen at bus 10833	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 10834	: Pg=75.59, Qg=-6.62 -> Pg=75.59, Qg=22.61
% INFO    : Gen at bus 10834	: Vg=1.0235 -> Vg=1.0
% INFO    : Gen at bus 10836	: Pg=88.54, Qg=-9.87 -> Pg=54.735, Qg=17.69
% INFO    : Gen at bus 10836	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 10836	: Pg=88.54, Qg=-9.87 -> Pg=51.91, Qg=17.69
% INFO    : Gen at bus 10836	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 10838	: Pg=45.58, Qg=0.0 -> Pg=45.58, Qg=0.0
% INFO    : Gen at bus 10838	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 10842	: Pg=10.5, Qg=4.92 -> Pg=10.5, Qg=2.145
% INFO    : Gen at bus 10842	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 10842	: Pg=8.22, Qg=4.92 -> Pg=8.22, Qg=2.145
% INFO    : Gen at bus 10842	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 10843	: Pg=11.05, Qg=-0.63 -> Pg=11.05, Qg=2.145
% INFO    : Gen at bus 10843	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 10843	: Pg=0.0, Qg=0.0 -> Pg=8.18, Qg=2.145
% INFO    : Gen at bus 10843	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 10843	: Pg=8.89, Qg=-0.63 -> Pg=8.89, Qg=2.145
% INFO    : Gen at bus 10843	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 10847	: Pg=100.5, Qg=-4.92 -> Pg=100.5, Qg=16.835
% INFO    : Gen at bus 10847	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 10848	: Pg=78.52, Qg=-4.92 -> Pg=78.52, Qg=16.835
% INFO    : Gen at bus 10848	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 10849	: Pg=83.39, Qg=-4.92 -> Pg=83.39, Qg=16.835
% INFO    : Gen at bus 10849	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 10850	: Pg=87.3, Qg=-4.92 -> Pg=87.3, Qg=16.835
% INFO    : Gen at bus 10850	: Vg=1.0365 -> Vg=1.0
% INFO    : Gen at bus 10851	: Pg=80.36, Qg=-4.92 -> Pg=80.36, Qg=16.835
% INFO    : Gen at bus 10851	: Vg=1.0368 -> Vg=1.0
% INFO    : Gen at bus 10852	: Pg=99.06, Qg=-4.92 -> Pg=99.06, Qg=16.835
% INFO    : Gen at bus 10852	: Vg=1.0368 -> Vg=1.0
% INFO    : Gen at bus 10853	: Pg=0.0, Qg=0.0 -> Pg=6.715, Qg=1.675
% INFO    : Gen at bus 10853	: Vg=1.0372 -> Vg=1.0
% INFO    : Gen at bus 10859	: Pg=0.0, Qg=0.0 -> Pg=543.575, Qg=125.54
% INFO    : Gen at bus 10859	: Vg=1.0395 -> Vg=1.0
% INFO    : Gen at bus 10860	: Pg=322.89, Qg=-89.05 -> Pg=521.045, Qg=125.54
% INFO    : Gen at bus 10860	: Vg=1.0341 -> Vg=1.0
% INFO    : Gen at bus 10864	: Pg=103.61, Qg=57.6 -> Pg=103.61, Qg=25.125
% INFO    : Gen at bus 10864	: Vg=1.0058 -> Vg=1.0
% INFO    : Gen at bus 10865	: Pg=110.96, Qg=57.6 -> Pg=110.96, Qg=25.125
% INFO    : Gen at bus 10865	: Vg=1.0062 -> Vg=1.0
% INFO    : Gen at bus 10867	: Pg=11.12, Qg=-0.74 -> Pg=11.12, Qg=2.51
% INFO    : Gen at bus 10867	: Vg=0.9782 -> Vg=1.0
% INFO    : Gen at bus 10867	: Pg=11.39, Qg=-0.74 -> Pg=11.39, Qg=2.51
% INFO    : Gen at bus 10867	: Vg=0.9782 -> Vg=1.0
% INFO    : Gen at bus 10869	: Pg=0.0, Qg=0.0 -> Pg=6.555, Qg=1.675
% INFO    : Gen at bus 10869	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 10869	: Pg=10.0, Qg=3.84 -> Pg=10.0, Qg=1.675
% INFO    : Gen at bus 10869	: Vg=1.0067 -> Vg=1.0
% INFO    : Gen at bus 10872	: Pg=61.55, Qg=31.46 -> Pg=44.945, Qg=12.3
% INFO    : Gen at bus 10872	: Vg=1.0229 -> Vg=1.0
% INFO    : Gen at bus 10873	: Pg=21.91, Qg=-1.45 -> Pg=21.91, Qg=4.96
% INFO    : Gen at bus 10873	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10873	: Pg=0.0, Qg=0.0 -> Pg=17.095, Qg=4.96
% INFO    : Gen at bus 10873	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10879	: Pg=70.43, Qg=-6.62 -> Pg=70.43, Qg=22.61
% INFO    : Gen at bus 10879	: Vg=1.0364 -> Vg=1.0
% INFO    : Gen at bus 10880	: Pg=109.22, Qg=-6.62 -> Pg=109.22, Qg=22.61
% INFO    : Gen at bus 10880	: Vg=1.0366 -> Vg=1.0
% INFO    : Gen at bus 10881	: Pg=73.16, Qg=-6.62 -> Pg=73.16, Qg=22.61
% INFO    : Gen at bus 10881	: Vg=1.0364 -> Vg=1.0
% INFO    : Gen at bus 10882	: Pg=0.0, Qg=0.0 -> Pg=80.925, Qg=22.61
% INFO    : Gen at bus 10882	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 10883	: Pg=0.0, Qg=0.0 -> Pg=96.27, Qg=22.61
% INFO    : Gen at bus 10883	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 10884	: Pg=118.13, Qg=-6.62 -> Pg=118.13, Qg=22.61
% INFO    : Gen at bus 10884	: Vg=1.0364 -> Vg=1.0
% INFO    : Gen at bus 10889	: Pg=87.44, Qg=42.4 -> Pg=65.715, Qg=17.47
% INFO    : Gen at bus 10889	: Vg=1.0386 -> Vg=1.0
% INFO    : Gen at bus 10890	: Pg=0.0, Qg=0.0 -> Pg=26.4, Qg=7.505
% INFO    : Gen at bus 10890	: Vg=1.0327 -> Vg=1.0
% INFO    : Gen at bus 10895	: Pg=93.62, Qg=-10.43 -> Pg=66.475, Qg=18.71
% INFO    : Gen at bus 10895	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 10896	: Pg=93.62, Qg=-10.43 -> Pg=52.805, Qg=18.71
% INFO    : Gen at bus 10896	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 10897	: Pg=93.62, Qg=-10.43 -> Pg=61.335, Qg=18.71
% INFO    : Gen at bus 10897	: Vg=1.0249 -> Vg=1.0
% INFO    : Gen at bus 10898	: Pg=93.62, Qg=-10.43 -> Pg=66.86, Qg=18.71
% INFO    : Gen at bus 10898	: Vg=1.0248 -> Vg=1.0
% INFO    : Gen at bus 10901	: Pg=36.21, Qg=-2.25 -> Pg=36.21, Qg=7.705
% INFO    : Gen at bus 10901	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 10902	: Pg=0.0, Qg=0.0 -> Pg=28.065, Qg=7.705
% INFO    : Gen at bus 10902	: Vg=1.0396 -> Vg=1.0
% INFO    : Gen at bus 10904	: Pg=37.13, Qg=-3.49 -> Pg=37.13, Qg=1.725
% INFO    : Gen at bus 10904	: Vg=1.0489 -> Vg=1.0
% INFO    : Gen at bus 10908	: Pg=115.41, Qg=-8.37 -> Pg=115.41, Qg=28.62
% INFO    : Gen at bus 10908	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 10909	: Pg=0.0, Qg=0.0 -> Pg=104.05, Qg=28.62
% INFO    : Gen at bus 10909	: Vg=1.0438 -> Vg=1.0
% INFO    : Gen at bus 10910	: Pg=99.62, Qg=-8.37 -> Pg=99.62, Qg=28.62
% INFO    : Gen at bus 10910	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 10911	: Pg=0.0, Qg=0.0 -> Pg=111.375, Qg=28.62
% INFO    : Gen at bus 10911	: Vg=1.0438 -> Vg=1.0
% INFO    : Gen at bus 10912	: Pg=116.3, Qg=-8.37 -> Pg=116.3, Qg=28.62
% INFO    : Gen at bus 10912	: Vg=1.0304 -> Vg=1.0
% INFO    : Gen at bus 10913	: Pg=0.0, Qg=0.0 -> Pg=94.215, Qg=28.62
% INFO    : Gen at bus 10913	: Vg=1.0438 -> Vg=1.0
% INFO    : Gen at bus 10914	: Pg=7.23, Qg=-0.46 -> Pg=7.23, Qg=1.575
% INFO    : Gen at bus 10914	: Vg=1.0308 -> Vg=1.0
% INFO    : Gen at bus 10919	: Pg=112.5, Qg=-5.51 -> Pg=112.5, Qg=18.845
% INFO    : Gen at bus 10919	: Vg=1.032 -> Vg=1.0
% INFO    : Gen at bus 10920	: Pg=0.0, Qg=0.0 -> Pg=80.83, Qg=18.845
% INFO    : Gen at bus 10920	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 10921	: Pg=93.79, Qg=-5.51 -> Pg=93.79, Qg=18.845
% INFO    : Gen at bus 10921	: Vg=1.0323 -> Vg=1.0
% INFO    : Gen at bus 10922	: Pg=0.0, Qg=0.0 -> Pg=77.5, Qg=18.845
% INFO    : Gen at bus 10922	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 10923	: Pg=84.26, Qg=43.06 -> Pg=52.245, Qg=16.835
% INFO    : Gen at bus 10923	: Vg=1.044 -> Vg=1.0
% INFO    : Gen at bus 10923	: Pg=84.26, Qg=43.06 -> Pg=59.8, Qg=16.835
% INFO    : Gen at bus 10923	: Vg=1.044 -> Vg=1.0
% INFO    : Gen at bus 10925	: Pg=16.8, Qg=-0.82 -> Pg=16.8, Qg=2.815
% INFO    : Gen at bus 10925	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 10925	: Pg=6.52, Qg=-0.37 -> Pg=6.52, Qg=1.255
% INFO    : Gen at bus 10925	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 10930	: Pg=87.57, Qg=58.32 -> Pg=158.415, Qg=46.3
% INFO    : Gen at bus 10930	: Vg=1.062 -> Vg=1.0
% INFO    : Gen at bus 10931	: Pg=231.72, Qg=58.32 -> Pg=135.32, Qg=46.3
% INFO    : Gen at bus 10931	: Vg=1.0518 -> Vg=1.0
% INFO    : Gen at bus 10932	: Pg=231.72, Qg=58.32 -> Pg=161.72, Qg=46.3
% INFO    : Gen at bus 10932	: Vg=1.059 -> Vg=1.0
% INFO    : Gen at bus 10933	: Pg=50.0, Qg=-7.2 -> Pg=50.0, Qg=1.725
% INFO    : Gen at bus 10933	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 10934	: Pg=36.0, Qg=-1.76 -> Pg=36.0, Qg=6.03
% INFO    : Gen at bus 10934	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10934	: Pg=36.0, Qg=-1.76 -> Pg=36.0, Qg=6.03
% INFO    : Gen at bus 10934	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 10938	: Pg=14.84, Qg=0.0 -> Pg=14.84, Qg=0.0
% INFO    : Gen at bus 10938	: Vg=1.0374 -> Vg=1.0
% INFO    : Gen at bus 10939	: Pg=7.5, Qg=0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 10939	: Vg=1.0362 -> Vg=1.0
% INFO    : Gen at bus 10940	: Pg=7.5, Qg=0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 10940	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 10944	: Pg=123.26, Qg=-6.62 -> Pg=123.26, Qg=22.61
% INFO    : Gen at bus 10944	: Vg=1.0381 -> Vg=1.0
% INFO    : Gen at bus 10945	: Pg=118.78, Qg=-6.62 -> Pg=118.78, Qg=22.61
% INFO    : Gen at bus 10945	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 10946	: Pg=135.0, Qg=-6.62 -> Pg=135.0, Qg=22.61
% INFO    : Gen at bus 10946	: Vg=1.0383 -> Vg=1.0
% INFO    : Gen at bus 10947	: Pg=109.12, Qg=-6.62 -> Pg=109.12, Qg=22.61
% INFO    : Gen at bus 10947	: Vg=1.0382 -> Vg=1.0
% INFO    : Gen at bus 10948	: Pg=0.0, Qg=0.0 -> Pg=89.95, Qg=22.61
% INFO    : Gen at bus 10948	: Vg=1.0387 -> Vg=1.0
% INFO    : Gen at bus 10949	: Pg=90.42, Qg=-6.62 -> Pg=90.42, Qg=22.61
% INFO    : Gen at bus 10949	: Vg=1.0382 -> Vg=1.0
% INFO    : Gen at bus 10951	: Pg=0.0, Qg=0.0 -> Pg=12.05, Qg=3.24
% INFO    : Gen at bus 10951	: Vg=1.0312 -> Vg=1.0
% INFO    : Gen at bus 10951	: Pg=0.0, Qg=0.0 -> Pg=13.865, Qg=3.24
% INFO    : Gen at bus 10951	: Vg=1.0312 -> Vg=1.0
% INFO    : Gen at bus 10955	: Pg=32.11, Qg=-1.67 -> Pg=32.11, Qg=5.695
% INFO    : Gen at bus 10955	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 10955	: Pg=17.04, Qg=-1.67 -> Pg=17.04, Qg=5.695
% INFO    : Gen at bus 10955	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 10956	: Pg=0.0, Qg=0.0 -> Pg=19.355, Qg=5.695
% INFO    : Gen at bus 10956	: Vg=1.0209 -> Vg=1.0
% INFO    : Gen at bus 10956	: Pg=0.0, Qg=0.0 -> Pg=25.415, Qg=5.695
% INFO    : Gen at bus 10956	: Vg=1.0209 -> Vg=1.0
% INFO    : Gen at bus 10959	: Pg=221.29, Qg=55.85 -> Pg=221.29, Qg=9.045
% INFO    : Gen at bus 10959	: Vg=1.0088 -> Vg=1.0
% INFO    : Gen at bus 10965	: Pg=0.0, Qg=0.0 -> Pg=245.83, Qg=11.825
% INFO    : Gen at bus 10965	: Vg=1.0351 -> Vg=1.0
% INFO    : Gen at bus 10966	: Pg=0.0, Qg=0.0 -> Pg=4.875, Qg=1.155
% INFO    : Gen at bus 10966	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 10966	: Pg=5.28, Qg=-0.34 -> Pg=5.28, Qg=1.155
% INFO    : Gen at bus 10966	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 10966	: Pg=20.12, Qg=-1.35 -> Pg=20.12, Qg=4.605
% INFO    : Gen at bus 10966	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 10969	: Pg=0.0, Qg=0.0 -> Pg=18.465, Qg=5.17
% INFO    : Gen at bus 10969	: Vg=1.0284 -> Vg=1.0
% INFO    : Gen at bus 10972	: Pg=13.16, Qg=-0.86 -> Pg=13.16, Qg=2.93
% INFO    : Gen at bus 10972	: Vg=1.0105 -> Vg=1.0
% INFO    : Gen at bus 10972	: Pg=17.5, Qg=-0.86 -> Pg=17.5, Qg=2.93
% INFO    : Gen at bus 10972	: Vg=1.0105 -> Vg=1.0
% INFO    : Gen at bus 10973	: Pg=0.0, Qg=0.0 -> Pg=12.96, Qg=2.93
% INFO    : Gen at bus 10973	: Vg=1.0123 -> Vg=1.0
% INFO    : Gen at bus 10973	: Pg=17.5, Qg=-0.86 -> Pg=17.5, Qg=2.93
% INFO    : Gen at bus 10973	: Vg=1.0123 -> Vg=1.0
% INFO    : Gen at bus 10978	: Pg=95.9, Qg=12.94 -> Pg=95.9, Qg=3.31
% INFO    : Gen at bus 10978	: Vg=1.0423 -> Vg=1.0
% INFO    : Gen at bus 10981	: Pg=97.59, Qg=20.38 -> Pg=97.59, Qg=4.7
% INFO    : Gen at bus 10981	: Vg=1.0485 -> Vg=1.0
% INFO    : Gen at bus 10982	: Pg=92.02, Qg=20.38 -> Pg=92.02, Qg=4.7
% INFO    : Gen at bus 10982	: Vg=1.0469 -> Vg=1.0
% INFO    : Gen at bus 10985	: Pg=199.0, Qg=-28.66 -> Pg=199.0, Qg=6.865
% INFO    : Gen at bus 10985	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 10989	: Pg=215.79, Qg=-24.05 -> Pg=140.28, Qg=43.115
% INFO    : Gen at bus 10989	: Vg=1.0371 -> Vg=1.0
% INFO    : Gen at bus 10990	: Pg=215.79, Qg=-24.05 -> Pg=136.815, Qg=43.115
% INFO    : Gen at bus 10990	: Vg=1.0373 -> Vg=1.0
% INFO    : Gen at bus 10991	: Pg=215.79, Qg=-24.05 -> Pg=119.68, Qg=43.115
% INFO    : Gen at bus 10991	: Vg=1.0377 -> Vg=1.0
% INFO    : Gen at bus 10993	: Pg=0.0, Qg=0.0 -> Pg=15.145, Qg=3.455
% INFO    : Gen at bus 10993	: Vg=1.0435 -> Vg=1.0
% INFO    : Gen at bus 10993	: Pg=0.0, Qg=0.0 -> Pg=14.155, Qg=3.455
% INFO    : Gen at bus 10993	: Vg=1.0435 -> Vg=1.0
% INFO    : Gen at bus 10994	: Pg=0.0, Qg=0.0 -> Pg=12.39, Qg=3.455
% INFO    : Gen at bus 10994	: Vg=1.0435 -> Vg=1.0
% INFO    : Gen at bus 10995	: Pg=20.62, Qg=-1.01 -> Pg=20.62, Qg=3.455
% INFO    : Gen at bus 10995	: Vg=1.0416 -> Vg=1.0
% INFO    : Gen at bus 10998	: Pg=16.51, Qg=-1.22 -> Pg=16.51, Qg=4.19
% INFO    : Gen at bus 10998	: Vg=1.0258 -> Vg=1.0
% INFO    : Gen at bus 10998	: Pg=25.0, Qg=-1.22 -> Pg=25.0, Qg=4.19
% INFO    : Gen at bus 10998	: Vg=1.0258 -> Vg=1.0
% INFO    : Gen at bus 11005	: Pg=141.57, Qg=72.35 -> Pg=93.475, Qg=28.285
% INFO    : Gen at bus 11005	: Vg=1.0257 -> Vg=1.0
% INFO    : Gen at bus 11006	: Pg=141.57, Qg=72.35 -> Pg=79.055, Qg=28.285
% INFO    : Gen at bus 11006	: Vg=1.0271 -> Vg=1.0
% INFO    : Gen at bus 11008	: Pg=21.6, Qg=-1.06 -> Pg=21.6, Qg=3.615
% INFO    : Gen at bus 11008	: Vg=0.9755 -> Vg=1.0
% INFO    : Gen at bus 11009	: Pg=16.3, Qg=-1.06 -> Pg=16.3, Qg=3.615
% INFO    : Gen at bus 11009	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 11009	: Pg=5.97, Qg=-0.63 -> Pg=5.97, Qg=2.145
% INFO    : Gen at bus 11009	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 11014	: Pg=812.69, Qg=322.47 -> Pg=812.69, Qg=181.32
% INFO    : Gen at bus 11014	: Vg=1.0694 -> Vg=1.0
% INFO    : Gen at bus 11015	: Pg=0.0, Qg=0.0 -> Pg=680.16, Qg=181.32
% INFO    : Gen at bus 11015	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 11016	: Pg=1082.5, Qg=322.47 -> Pg=1082.5, Qg=181.32
% INFO    : Gen at bus 11016	: Vg=1.0633 -> Vg=1.0
% INFO    : Gen at bus 11017	: Pg=0.0, Qg=0.0 -> Pg=648.375, Qg=181.32
% INFO    : Gen at bus 11017	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 11018	: Pg=885.08, Qg=322.47 -> Pg=885.08, Qg=181.32
% INFO    : Gen at bus 11018	: Vg=1.0618 -> Vg=1.0
% INFO    : Gen at bus 11019	: Pg=754.61, Qg=322.47 -> Pg=754.61, Qg=181.32
% INFO    : Gen at bus 11019	: Vg=1.0615 -> Vg=1.0
% INFO    : Gen at bus 11020	: Pg=52.33, Qg=20.1 -> Pg=52.33, Qg=8.77
% INFO    : Gen at bus 11020	: Vg=1.0431 -> Vg=1.0
% INFO    : Gen at bus 11021	: Pg=26.5, Qg=20.1 -> Pg=26.5, Qg=8.77
% INFO    : Gen at bus 11021	: Vg=1.0436 -> Vg=1.0
% INFO    : Gen at bus 11022	: Pg=0.0, Qg=0.0 -> Pg=30.27, Qg=8.77
% INFO    : Gen at bus 11022	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 11023	: Pg=40.81, Qg=20.1 -> Pg=40.81, Qg=8.77
% INFO    : Gen at bus 11023	: Vg=1.0431 -> Vg=1.0
% INFO    : Gen at bus 11024	: Pg=0.0, Qg=0.0 -> Pg=37.81, Qg=8.77
% INFO    : Gen at bus 11024	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 11025	: Pg=40.92, Qg=20.1 -> Pg=40.92, Qg=8.77
% INFO    : Gen at bus 11025	: Vg=1.0431 -> Vg=1.0
% INFO    : Gen at bus 11031	: Pg=94.78, Qg=-10.56 -> Pg=55.65, Qg=18.94
% INFO    : Gen at bus 11031	: Vg=1.0422 -> Vg=1.0
% INFO    : Gen at bus 11032	: Pg=94.78, Qg=-10.56 -> Pg=58.985, Qg=18.94
% INFO    : Gen at bus 11032	: Vg=1.0411 -> Vg=1.0
% INFO    : Gen at bus 11033	: Pg=94.78, Qg=-10.56 -> Pg=58.305, Qg=18.94
% INFO    : Gen at bus 11033	: Vg=1.0411 -> Vg=1.0
% INFO    : Gen at bus 11035	: Pg=14.85, Qg=0.0 -> Pg=14.85, Qg=0.0
% INFO    : Gen at bus 11035	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 11035	: Pg=7.71, Qg=0.0 -> Pg=7.71, Qg=0.0
% INFO    : Gen at bus 11035	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 11035	: Pg=0.0, Qg=0.0 -> Pg=10.195, Qg=0.0
% INFO    : Gen at bus 11035	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 11035	: Pg=0.0, Qg=0.0 -> Pg=10.88, Qg=0.0
% INFO    : Gen at bus 11035	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 11037	: Pg=9.69, Qg=-0.59 -> Pg=9.69, Qg=2.01
% INFO    : Gen at bus 11037	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 11037	: Pg=37.76, Qg=-2.57 -> Pg=37.76, Qg=8.775
% INFO    : Gen at bus 11037	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 11037	: Pg=0.0, Qg=0.0 -> Pg=29.325, Qg=8.775
% INFO    : Gen at bus 11037	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 11041	: Pg=0.0, Qg=0.0 -> Pg=125.16, Qg=29.03
% INFO    : Gen at bus 11041	: Vg=1.0358 -> Vg=1.0
% INFO    : Gen at bus 11042	: Pg=0.0, Qg=0.0 -> Pg=126.245, Qg=29.03
% INFO    : Gen at bus 11042	: Vg=1.0358 -> Vg=1.0
% INFO    : Gen at bus 11043	: Pg=0.0, Qg=0.0 -> Pg=127.075, Qg=29.03
% INFO    : Gen at bus 11043	: Vg=1.0358 -> Vg=1.0
% INFO    : Gen at bus 11044	: Pg=0.0, Qg=0.0 -> Pg=108.155, Qg=29.03
% INFO    : Gen at bus 11044	: Vg=1.0358 -> Vg=1.0
% INFO    : Gen at bus 11045	: Pg=131.96, Qg=-8.49 -> Pg=131.96, Qg=29.03
% INFO    : Gen at bus 11045	: Vg=1.0352 -> Vg=1.0
% INFO    : Gen at bus 11046	: Pg=129.26, Qg=-8.49 -> Pg=129.26, Qg=29.03
% INFO    : Gen at bus 11046	: Vg=1.0351 -> Vg=1.0
% INFO    : Gen at bus 11047	: Pg=22.81, Qg=-0.23 -> Pg=22.81, Qg=4.49
% INFO    : Gen at bus 11047	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 11050	: Pg=246.99, Qg=126.23 -> Pg=181.895, Qg=49.35
% INFO    : Gen at bus 11050	: Vg=1.0399 -> Vg=1.0
% INFO    : Gen at bus 11052	: Pg=44.37, Qg=-11.28 -> Pg=44.37, Qg=2.7
% INFO    : Gen at bus 11052	: Vg=1.0142 -> Vg=1.0
% INFO    : Gen at bus 11053	: Pg=51.88, Qg=-11.28 -> Pg=51.88, Qg=2.7
% INFO    : Gen at bus 11053	: Vg=1.0131 -> Vg=1.0
% INFO    : Gen at bus 11054	: Pg=6.59, Qg=3.07 -> Pg=6.59, Qg=1.34
% INFO    : Gen at bus 11054	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 11054	: Pg=5.96, Qg=3.07 -> Pg=5.96, Qg=1.34
% INFO    : Gen at bus 11054	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 11054	: Pg=6.19, Qg=3.07 -> Pg=6.19, Qg=1.34
% INFO    : Gen at bus 11054	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 11054	: Pg=0.0, Qg=0.0 -> Pg=4.46, Qg=1.34
% INFO    : Gen at bus 11054	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 11060	: Pg=105.3, Qg=22.43 -> Pg=105.3, Qg=3.635
% INFO    : Gen at bus 11060	: Vg=1.0428 -> Vg=1.0
% INFO    : Gen at bus 11061	: Pg=105.3, Qg=22.43 -> Pg=105.3, Qg=3.635
% INFO    : Gen at bus 11061	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 11062	: Pg=0.0, Qg=0.0 -> Pg=7.395, Qg=2.265
% INFO    : Gen at bus 11062	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 11062	: Pg=0.0, Qg=0.0 -> Pg=6.81, Qg=2.265
% INFO    : Gen at bus 11062	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 11062	: Pg=0.0, Qg=0.0 -> Pg=6.57, Qg=2.265
% INFO    : Gen at bus 11062	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 11062	: Pg=11.35, Qg=-1.27 -> Pg=7.08, Qg=2.265
% INFO    : Gen at bus 11062	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 11065	: Pg=130.66, Qg=37.68 -> Pg=130.66, Qg=6.105
% INFO    : Gen at bus 11065	: Vg=1.0681 -> Vg=1.0
% INFO    : Gen at bus 11069	: Pg=204.0, Qg=23.23 -> Pg=204.0, Qg=7.035
% INFO    : Gen at bus 11069	: Vg=1.0482 -> Vg=1.0
% INFO    : Gen at bus 11072	: Pg=158.85, Qg=-17.7 -> Pg=96.825, Qg=31.745
% INFO    : Gen at bus 11072	: Vg=1.0249 -> Vg=1.0
% INFO    : Gen at bus 11073	: Pg=158.85, Qg=-17.7 -> Pg=93.905, Qg=31.745
% INFO    : Gen at bus 11073	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 11077	: Pg=100.99, Qg=-6.32 -> Pg=100.99, Qg=21.61
% INFO    : Gen at bus 11077	: Vg=1.0428 -> Vg=1.0
% INFO    : Gen at bus 11078	: Pg=0.0, Qg=0.0 -> Pg=76.435, Qg=21.61
% INFO    : Gen at bus 11078	: Vg=1.0432 -> Vg=1.0
% INFO    : Gen at bus 11079	: Pg=84.92, Qg=-6.32 -> Pg=84.92, Qg=21.61
% INFO    : Gen at bus 11079	: Vg=1.0427 -> Vg=1.0
% INFO    : Gen at bus 11080	: Pg=106.47, Qg=-6.32 -> Pg=106.47, Qg=21.61
% INFO    : Gen at bus 11080	: Vg=1.0427 -> Vg=1.0
% INFO    : Gen at bus 11081	: Pg=0.0, Qg=0.0 -> Pg=77.205, Qg=21.61
% INFO    : Gen at bus 11081	: Vg=1.0432 -> Vg=1.0
% INFO    : Gen at bus 11082	: Pg=98.22, Qg=-6.32 -> Pg=98.22, Qg=21.61
% INFO    : Gen at bus 11082	: Vg=1.0427 -> Vg=1.0
% INFO    : Gen at bus 13454	: Pg=38.1, Qg=3.6 -> Pg=38.1, Qg=6.38
% INFO    : Gen at bus 13454	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 13454	: Pg=38.1, Qg=3.6 -> Pg=38.1, Qg=6.38
% INFO    : Gen at bus 13454	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 13454	: Pg=26.18, Qg=3.6 -> Pg=26.18, Qg=6.38
% INFO    : Gen at bus 13454	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 13458	: Pg=98.7, Qg=-14.21 -> Pg=98.7, Qg=3.405
% INFO    : Gen at bus 13458	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13460	: Pg=13.81, Qg=3.65 -> Pg=13.81, Qg=2.88
% INFO    : Gen at bus 13460	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13460	: Pg=31.36, Qg=3.65 -> Pg=31.36, Qg=8.265
% INFO    : Gen at bus 13460	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13460	: Pg=49.35, Qg=3.65 -> Pg=49.35, Qg=8.265
% INFO    : Gen at bus 13460	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13462	: Pg=34.33, Qg=-3.83 -> Pg=19.7, Qg=6.855
% INFO    : Gen at bus 13462	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13462	: Pg=0.0, Qg=0.0 -> Pg=20.52, Qg=6.855
% INFO    : Gen at bus 13462	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13462	: Pg=0.0, Qg=0.0 -> Pg=22.865, Qg=6.855
% INFO    : Gen at bus 13462	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13462	: Pg=34.33, Qg=-3.83 -> Pg=22.795, Qg=6.855
% INFO    : Gen at bus 13462	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13462	: Pg=34.33, Qg=-3.83 -> Pg=20.09, Qg=6.855
% INFO    : Gen at bus 13462	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13462	: Pg=34.33, Qg=-3.83 -> Pg=20.9, Qg=6.855
% INFO    : Gen at bus 13462	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13466	: Pg=86.5, Qg=-17.68 -> Pg=86.5, Qg=4.24
% INFO    : Gen at bus 13466	: Vg=1.0376 -> Vg=1.0
% INFO    : Gen at bus 13468	: Pg=100.5, Qg=-14.47 -> Pg=100.5, Qg=3.47
% INFO    : Gen at bus 13468	: Vg=1.0068 -> Vg=1.0
% INFO    : Gen at bus 13475	: Pg=165.08, Qg=-8.09 -> Pg=165.08, Qg=27.65
% INFO    : Gen at bus 13475	: Vg=1.0297 -> Vg=1.0
% INFO    : Gen at bus 13476	: Pg=139.14, Qg=-8.09 -> Pg=139.14, Qg=27.65
% INFO    : Gen at bus 13476	: Vg=1.0297 -> Vg=1.0
% INFO    : Gen at bus 13477	: Pg=165.08, Qg=-8.09 -> Pg=165.08, Qg=27.65
% INFO    : Gen at bus 13477	: Vg=1.0298 -> Vg=1.0
% INFO    : Gen at bus 13478	: Pg=0.0, Qg=0.0 -> Pg=91.995, Qg=27.65
% INFO    : Gen at bus 13478	: Vg=1.0301 -> Vg=1.0
% INFO    : Gen at bus 13479	: Pg=131.28, Qg=-8.09 -> Pg=131.28, Qg=27.65
% INFO    : Gen at bus 13479	: Vg=1.0294 -> Vg=1.0
% INFO    : Gen at bus 13480	: Pg=96.69, Qg=-8.09 -> Pg=96.69, Qg=27.65
% INFO    : Gen at bus 13480	: Vg=1.0299 -> Vg=1.0
% INFO    : Gen at bus 13483	: Pg=0.0, Qg=0.0 -> Pg=69.42, Qg=3.475
% INFO    : Gen at bus 13483	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 13486	: Pg=148.75, Qg=-21.42 -> Pg=148.75, Qg=5.13
% INFO    : Gen at bus 13486	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 13487	: Pg=148.75, Qg=-21.42 -> Pg=148.75, Qg=5.13
% INFO    : Gen at bus 13487	: Vg=1.0338 -> Vg=1.0
% INFO    : Gen at bus 13488	: Pg=0.0, Qg=0.0 -> Pg=34.82, Qg=8.375
% INFO    : Gen at bus 13488	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 13488	: Pg=37.31, Qg=19.2 -> Pg=37.31, Qg=8.375
% INFO    : Gen at bus 13488	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 13489	: Pg=0.0, Qg=0.0 -> Pg=12.29, Qg=3.015
% INFO    : Gen at bus 13489	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13492	: Pg=27.65, Qg=0.0 -> Pg=27.65, Qg=0.0
% INFO    : Gen at bus 13492	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13493	: Pg=16.25, Qg=0.0 -> Pg=16.25, Qg=0.0
% INFO    : Gen at bus 13493	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 13494	: Pg=0.0, Qg=0.0 -> Pg=19.955, Qg=0.0
% INFO    : Gen at bus 13494	: Vg=1.0199 -> Vg=1.0
% INFO    : Gen at bus 13499	: Pg=229.4, Qg=-17.64 -> Pg=229.4, Qg=60.3
% INFO    : Gen at bus 13499	: Vg=0.9963 -> Vg=1.0
% INFO    : Gen at bus 13500	: Pg=0.0, Qg=0.0 -> Pg=209.125, Qg=60.3
% INFO    : Gen at bus 13500	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 13501	: Pg=290.08, Qg=-17.64 -> Pg=290.08, Qg=60.3
% INFO    : Gen at bus 13501	: Vg=1.0035 -> Vg=1.0
% INFO    : Gen at bus 13502	: Pg=304.83, Qg=-17.64 -> Pg=304.83, Qg=60.3
% INFO    : Gen at bus 13502	: Vg=0.9968 -> Vg=1.0
% INFO    : Gen at bus 13503	: Pg=231.15, Qg=-17.64 -> Pg=231.15, Qg=60.3
% INFO    : Gen at bus 13503	: Vg=1.0031 -> Vg=1.0
% INFO    : Gen at bus 13504	: Pg=316.7, Qg=-17.64 -> Pg=316.7, Qg=60.3
% INFO    : Gen at bus 13504	: Vg=1.0038 -> Vg=1.0
% INFO    : Gen at bus 13509	: Pg=228.87, Qg=-25.51 -> Pg=168.175, Qg=45.73
% INFO    : Gen at bus 13509	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 13510	: Pg=228.87, Qg=-25.51 -> Pg=170.16, Qg=45.73
% INFO    : Gen at bus 13510	: Vg=1.0297 -> Vg=1.0
% INFO    : Gen at bus 13511	: Pg=228.87, Qg=-25.51 -> Pg=171.59, Qg=45.73
% INFO    : Gen at bus 13511	: Vg=1.0302 -> Vg=1.0
% INFO    : Gen at bus 13512	: Pg=29.35, Qg=0.0 -> Pg=29.35, Qg=0.0
% INFO    : Gen at bus 13512	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13513	: Pg=10.46, Qg=-0.74 -> Pg=10.46, Qg=2.51
% INFO    : Gen at bus 13513	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 13513	: Pg=8.65, Qg=-0.74 -> Pg=8.65, Qg=2.51
% INFO    : Gen at bus 13513	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 13515	: Pg=21.57, Qg=-3.59 -> Pg=21.57, Qg=0.855
% INFO    : Gen at bus 13515	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 13515	: Pg=22.57, Qg=-3.59 -> Pg=22.57, Qg=0.855
% INFO    : Gen at bus 13515	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 13518	: Pg=119.83, Qg=-21.59 -> Pg=119.83, Qg=5.17
% INFO    : Gen at bus 13518	: Vg=1.0363 -> Vg=1.0
% INFO    : Gen at bus 13519	: Pg=132.39, Qg=-21.59 -> Pg=132.39, Qg=5.17
% INFO    : Gen at bus 13519	: Vg=1.0362 -> Vg=1.0
% INFO    : Gen at bus 13520	: Pg=149.9, Qg=-21.59 -> Pg=149.9, Qg=5.17
% INFO    : Gen at bus 13520	: Vg=1.0335 -> Vg=1.0
% INFO    : Gen at bus 13521	: Pg=7.46, Qg=-1.3 -> Pg=7.46, Qg=0.31
% INFO    : Gen at bus 13521	: Vg=1.0386 -> Vg=1.0
% INFO    : Gen at bus 13522	: Pg=29.28, Qg=-3.26 -> Pg=18.055, Qg=5.85
% INFO    : Gen at bus 13522	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13522	: Pg=0.0, Qg=0.0 -> Pg=20.545, Qg=5.85
% INFO    : Gen at bus 13522	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13522	: Pg=29.28, Qg=-3.26 -> Pg=17.125, Qg=5.85
% INFO    : Gen at bus 13522	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13522	: Pg=0.0, Qg=0.0 -> Pg=18.485, Qg=5.85
% INFO    : Gen at bus 13522	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13526	: Pg=124.17, Qg=-6.08 -> Pg=124.17, Qg=20.8
% INFO    : Gen at bus 13526	: Vg=1.0559 -> Vg=1.0
% INFO    : Gen at bus 13527	: Pg=68.07, Qg=-6.08 -> Pg=68.07, Qg=20.8
% INFO    : Gen at bus 13527	: Vg=1.0557 -> Vg=1.0
% INFO    : Gen at bus 13528	: Pg=0.0, Qg=0.0 -> Pg=84.575, Qg=20.8
% INFO    : Gen at bus 13528	: Vg=1.0562 -> Vg=1.0
% INFO    : Gen at bus 13530	: Pg=60.82, Qg=-15.55 -> Pg=60.82, Qg=3.725
% INFO    : Gen at bus 13530	: Vg=1.0262 -> Vg=1.0
% INFO    : Gen at bus 13533	: Pg=9.9, Qg=-0.64 -> Pg=9.9, Qg=2.175
% INFO    : Gen at bus 13533	: Vg=1.0279 -> Vg=1.0
% INFO    : Gen at bus 13534	: Pg=13.0, Qg=-0.64 -> Pg=13.0, Qg=2.175
% INFO    : Gen at bus 13534	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 13539	: Pg=154.67, Qg=-17.24 -> Pg=115.495, Qg=30.905
% INFO    : Gen at bus 13539	: Vg=1.0081 -> Vg=1.0
% INFO    : Gen at bus 13540	: Pg=154.67, Qg=-17.24 -> Pg=111.725, Qg=30.905
% INFO    : Gen at bus 13540	: Vg=1.0123 -> Vg=1.0
% INFO    : Gen at bus 13541	: Pg=154.67, Qg=-17.24 -> Pg=114.44, Qg=30.905
% INFO    : Gen at bus 13541	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 13542	: Pg=154.67, Qg=-17.24 -> Pg=86.73, Qg=30.905
% INFO    : Gen at bus 13542	: Vg=1.0111 -> Vg=1.0
% INFO    : Gen at bus 13543	: Pg=39.78, Qg=-2.33 -> Pg=39.78, Qg=7.955
% INFO    : Gen at bus 13543	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 13543	: Pg=0.0, Qg=0.0 -> Pg=33.67, Qg=7.955
% INFO    : Gen at bus 13543	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 13544	: Pg=0.0, Qg=0.0 -> Pg=33.48, Qg=7.955
% INFO    : Gen at bus 13544	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13544	: Pg=40.73, Qg=18.24 -> Pg=40.73, Qg=7.955
% INFO    : Gen at bus 13544	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13548	: Pg=0.0, Qg=0.0 -> Pg=5.225, Qg=0.0
% INFO    : Gen at bus 13548	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13548	: Pg=6.29, Qg=0.0 -> Pg=6.29, Qg=0.0
% INFO    : Gen at bus 13548	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13549	: Pg=7.5, Qg=0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 13549	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13549	: Pg=5.78, Qg=0.0 -> Pg=5.78, Qg=0.0
% INFO    : Gen at bus 13549	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13549	: Pg=0.0, Qg=0.0 -> Pg=5.245, Qg=0.0
% INFO    : Gen at bus 13549	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13549	: Pg=7.18, Qg=0.0 -> Pg=7.18, Qg=0.0
% INFO    : Gen at bus 13549	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13549	: Pg=5.17, Qg=0.0 -> Pg=5.17, Qg=0.0
% INFO    : Gen at bus 13549	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13551	: Pg=132.61, Qg=-14.78 -> Pg=94.71, Qg=26.495
% INFO    : Gen at bus 13551	: Vg=1.0342 -> Vg=1.0
% INFO    : Gen at bus 13552	: Pg=132.61, Qg=-14.78 -> Pg=77.565, Qg=26.495
% INFO    : Gen at bus 13552	: Vg=1.0318 -> Vg=1.0
% INFO    : Gen at bus 13559	: Pg=0.0, Qg=0.0 -> Pg=114.62, Qg=33.265
% INFO    : Gen at bus 13559	: Vg=1.0477 -> Vg=1.0
% INFO    : Gen at bus 13560	: Pg=166.49, Qg=-18.56 -> Pg=99.12, Qg=33.265
% INFO    : Gen at bus 13560	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 13561	: Pg=166.49, Qg=-18.56 -> Pg=104.165, Qg=33.265
% INFO    : Gen at bus 13561	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 13563	: Pg=12.97, Qg=0.0 -> Pg=12.97, Qg=0.0
% INFO    : Gen at bus 13563	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13563	: Pg=0.0, Qg=0.0 -> Pg=11.865, Qg=0.0
% INFO    : Gen at bus 13563	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13563	: Pg=0.0, Qg=0.0 -> Pg=14.28, Qg=0.0
% INFO    : Gen at bus 13563	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13566	: Pg=11.73, Qg=0.0 -> Pg=11.73, Qg=0.0
% INFO    : Gen at bus 13566	: Vg=1.0006 -> Vg=1.0
% INFO    : Gen at bus 13567	: Pg=12.59, Qg=0.0 -> Pg=12.59, Qg=0.0
% INFO    : Gen at bus 13567	: Vg=1.0006 -> Vg=1.0
% INFO    : Gen at bus 13570	: Pg=69.48, Qg=10.92 -> Pg=69.48, Qg=3.345
% INFO    : Gen at bus 13570	: Vg=1.0566 -> Vg=1.0
% INFO    : Gen at bus 13572	: Pg=0.0, Qg=0.0 -> Pg=12.04, Qg=0.0
% INFO    : Gen at bus 13572	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13572	: Pg=18.65, Qg=0.0 -> Pg=18.65, Qg=0.0
% INFO    : Gen at bus 13572	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13573	: Pg=18.44, Qg=5.32 -> Pg=18.44, Qg=0.86
% INFO    : Gen at bus 13573	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13574	: Pg=0.0, Qg=0.0 -> Pg=5.465, Qg=0.34
% INFO    : Gen at bus 13574	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13574	: Pg=72.0, Qg=-10.37 -> Pg=72.0, Qg=2.485
% INFO    : Gen at bus 13574	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13577	: Pg=23.33, Qg=7.26 -> Pg=23.33, Qg=4.27
% INFO    : Gen at bus 13577	: Vg=1.0554 -> Vg=1.0
% INFO    : Gen at bus 13578	: Pg=24.18, Qg=3.63 -> Pg=24.18, Qg=4.27
% INFO    : Gen at bus 13578	: Vg=1.0482 -> Vg=1.0
% INFO    : Gen at bus 13578	: Pg=8.08, Qg=3.63 -> Pg=8.08, Qg=2.01
% INFO    : Gen at bus 13578	: Vg=1.0482 -> Vg=1.0
% INFO    : Gen at bus 13583	: Pg=0.0, Qg=0.0 -> Pg=25.655, Qg=6.7
% INFO    : Gen at bus 13583	: Vg=1.0446 -> Vg=1.0
% INFO    : Gen at bus 13583	: Pg=23.97, Qg=-1.96 -> Pg=23.97, Qg=6.7
% INFO    : Gen at bus 13583	: Vg=1.0446 -> Vg=1.0
% INFO    : Gen at bus 13584	: Pg=33.81, Qg=-1.96 -> Pg=33.81, Qg=6.7
% INFO    : Gen at bus 13584	: Vg=1.0445 -> Vg=1.0
% INFO    : Gen at bus 13585	: Pg=14.06, Qg=-0.74 -> Pg=14.06, Qg=2.51
% INFO    : Gen at bus 13585	: Vg=1.0447 -> Vg=1.0
% INFO    : Gen at bus 13586	: Pg=6.0, Qg=-0.39 -> Pg=6.0, Qg=1.34
% INFO    : Gen at bus 13586	: Vg=1.0397 -> Vg=1.0
% INFO    : Gen at bus 13586	: Pg=5.7, Qg=-0.39 -> Pg=5.7, Qg=1.33
% INFO    : Gen at bus 13586	: Vg=1.0397 -> Vg=1.0
% INFO    : Gen at bus 13587	: Pg=6.96, Qg=-0.39 -> Pg=6.96, Qg=1.33
% INFO    : Gen at bus 13587	: Vg=1.0447 -> Vg=1.0
% INFO    : Gen at bus 13590	: Pg=103.0, Qg=-14.83 -> Pg=103.0, Qg=3.555
% INFO    : Gen at bus 13590	: Vg=1.0279 -> Vg=1.0
% INFO    : Gen at bus 13593	: Pg=14.62, Qg=-1.0 -> Pg=14.62, Qg=3.415
% INFO    : Gen at bus 13593	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 13593	: Pg=0.0, Qg=0.0 -> Pg=13.515, Qg=3.415
% INFO    : Gen at bus 13593	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 13597	: Pg=0.0, Qg=0.0 -> Pg=91.685, Qg=21.86
% INFO    : Gen at bus 13597	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13598	: Pg=88.03, Qg=50.11 -> Pg=88.03, Qg=21.86
% INFO    : Gen at bus 13598	: Vg=1.0256 -> Vg=1.0
% INFO    : Gen at bus 13599	: Pg=115.67, Qg=50.11 -> Pg=115.67, Qg=21.86
% INFO    : Gen at bus 13599	: Vg=1.025 -> Vg=1.0
% INFO    : Gen at bus 13600	: Pg=9.2, Qg=4.22 -> Pg=9.2, Qg=1.84
% INFO    : Gen at bus 13600	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 13600	: Pg=14.66, Qg=6.91 -> Pg=14.66, Qg=3.015
% INFO    : Gen at bus 13600	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 13602	: Pg=12.17, Qg=5.76 -> Pg=12.17, Qg=2.51
% INFO    : Gen at bus 13602	: Vg=1.0477 -> Vg=1.0
% INFO    : Gen at bus 13603	: Pg=0.0, Qg=0.0 -> Pg=19.235, Qg=4.355
% INFO    : Gen at bus 13603	: Vg=1.0406 -> Vg=1.0
% INFO    : Gen at bus 13606	: Pg=65.41, Qg=-14.24 -> Pg=65.41, Qg=3.415
% INFO    : Gen at bus 13606	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 13612	: Pg=0.0, Qg=0.0 -> Pg=10.23, Qg=2.68
% INFO    : Gen at bus 13612	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 13612	: Pg=16.0, Qg=-0.78 -> Pg=16.0, Qg=2.68
% INFO    : Gen at bus 13612	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 13613	: Pg=5.26, Qg=-0.35 -> Pg=5.26, Qg=1.205
% INFO    : Gen at bus 13613	: Vg=1.0237 -> Vg=1.0
% INFO    : Gen at bus 13614	: Pg=0.0, Qg=0.0 -> Pg=5.995, Qg=0.34
% INFO    : Gen at bus 13614	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13614	: Pg=0.0, Qg=0.0 -> Pg=6.835, Qg=0.34
% INFO    : Gen at bus 13614	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13614	: Pg=0.0, Qg=0.0 -> Pg=6.87, Qg=0.345
% INFO    : Gen at bus 13614	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13614	: Pg=7.52, Qg=-1.44 -> Pg=7.52, Qg=0.345
% INFO    : Gen at bus 13614	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13618	: Pg=171.49, Qg=-28.94 -> Pg=171.49, Qg=6.935
% INFO    : Gen at bus 13618	: Vg=1.0341 -> Vg=1.0
% INFO    : Gen at bus 13625	: Pg=0.0, Qg=0.0 -> Pg=196.725, Qg=50.8
% INFO    : Gen at bus 13625	: Vg=1.0363 -> Vg=1.0
% INFO    : Gen at bus 13626	: Pg=246.09, Qg=-14.86 -> Pg=246.09, Qg=50.8
% INFO    : Gen at bus 13626	: Vg=1.0358 -> Vg=1.0
% INFO    : Gen at bus 13627	: Pg=230.23, Qg=-14.86 -> Pg=230.23, Qg=50.8
% INFO    : Gen at bus 13627	: Vg=1.0355 -> Vg=1.0
% INFO    : Gen at bus 13628	: Pg=0.0, Qg=0.0 -> Pg=208.865, Qg=50.8
% INFO    : Gen at bus 13628	: Vg=1.0363 -> Vg=1.0
% INFO    : Gen at bus 13629	: Pg=303.28, Qg=-14.86 -> Pg=303.28, Qg=50.8
% INFO    : Gen at bus 13629	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 13630	: Pg=0.0, Qg=0.0 -> Pg=190.025, Qg=50.8
% INFO    : Gen at bus 13630	: Vg=1.0363 -> Vg=1.0
% INFO    : Gen at bus 13632	: Pg=0.0, Qg=0.0 -> Pg=9.37, Qg=0.0
% INFO    : Gen at bus 13632	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13632	: Pg=10.53, Qg=0.0 -> Pg=10.53, Qg=0.0
% INFO    : Gen at bus 13632	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13632	: Pg=9.8, Qg=0.0 -> Pg=9.8, Qg=0.0
% INFO    : Gen at bus 13632	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13633	: Pg=32.0, Qg=-1.57 -> Pg=32.0, Qg=5.36
% INFO    : Gen at bus 13633	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 13634	: Pg=94.34, Qg=-14.21 -> Pg=94.34, Qg=3.405
% INFO    : Gen at bus 13634	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 13641	: Pg=49.23, Qg=-9.07 -> Pg=49.23, Qg=2.175
% INFO    : Gen at bus 13641	: Vg=1.0084 -> Vg=1.0
% INFO    : Gen at bus 13642	: Pg=34.87, Qg=-5.9 -> Pg=34.87, Qg=1.415
% INFO    : Gen at bus 13642	: Vg=1.0093 -> Vg=1.0
% INFO    : Gen at bus 13645	: Pg=97.3, Qg=-10.84 -> Pg=56.86, Qg=19.445
% INFO    : Gen at bus 13645	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13645	: Pg=0.0, Qg=0.0 -> Pg=67.095, Qg=19.445
% INFO    : Gen at bus 13645	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13645	: Pg=97.3, Qg=-10.84 -> Pg=67.65, Qg=19.445
% INFO    : Gen at bus 13645	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13645	: Pg=97.3, Qg=-10.84 -> Pg=58.995, Qg=19.445
% INFO    : Gen at bus 13645	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13645	: Pg=97.3, Qg=-10.84 -> Pg=65.845, Qg=19.445
% INFO    : Gen at bus 13645	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13645	: Pg=97.3, Qg=-10.84 -> Pg=58.665, Qg=19.445
% INFO    : Gen at bus 13645	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13646	: Pg=10.86, Qg=-1.21 -> Pg=6.685, Qg=2.17
% INFO    : Gen at bus 13646	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 13646	: Pg=13.05, Qg=-1.45 -> Pg=8.465, Qg=2.61
% INFO    : Gen at bus 13646	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 13646	: Pg=24.4, Qg=-2.72 -> Pg=14.495, Qg=4.875
% INFO    : Gen at bus 13646	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 13650	: Pg=33.31, Qg=-1.96 -> Pg=33.31, Qg=6.7
% INFO    : Gen at bus 13650	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 13650	: Pg=40.0, Qg=-1.96 -> Pg=40.0, Qg=6.7
% INFO    : Gen at bus 13650	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 13652	: Pg=5.95, Qg=-0.49 -> Pg=5.95, Qg=1.675
% INFO    : Gen at bus 13652	: Vg=1.0164 -> Vg=1.0
% INFO    : Gen at bus 13653	: Pg=6.99, Qg=-0.49 -> Pg=6.99, Qg=1.675
% INFO    : Gen at bus 13653	: Vg=1.0164 -> Vg=1.0
% INFO    : Gen at bus 13655	: Pg=24.5, Qg=-1.2 -> Pg=24.5, Qg=4.105
% INFO    : Gen at bus 13655	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 13655	: Pg=19.26, Qg=-1.2 -> Pg=19.26, Qg=4.105
% INFO    : Gen at bus 13655	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 13658	: Pg=10.22, Qg=-0.7 -> Pg=10.22, Qg=2.375
% INFO    : Gen at bus 13658	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 13658	: Pg=0.0, Qg=0.0 -> Pg=10.58, Qg=2.375
% INFO    : Gen at bus 13658	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 13659	: Pg=13.4, Qg=-0.7 -> Pg=13.4, Qg=2.375
% INFO    : Gen at bus 13659	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 13659	: Pg=7.6, Qg=-0.54 -> Pg=7.6, Qg=1.84
% INFO    : Gen at bus 13659	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 13661	: Pg=56.64, Qg=-10.8 -> Pg=56.64, Qg=2.585
% INFO    : Gen at bus 13661	: Vg=0.9828 -> Vg=1.0
% INFO    : Gen at bus 13662	: Pg=15.0, Qg=-3.53 -> Pg=15.0, Qg=0.845
% INFO    : Gen at bus 13662	: Vg=0.9886 -> Vg=1.0
% INFO    : Gen at bus 13663	: Pg=0.0, Qg=0.0 -> Pg=12.23, Qg=3.285
% INFO    : Gen at bus 13663	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 13663	: Pg=29.33, Qg=-1.79 -> Pg=29.33, Qg=6.13
% INFO    : Gen at bus 13663	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 13663	: Pg=0.0, Qg=0.0 -> Pg=25.68, Qg=6.13
% INFO    : Gen at bus 13663	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 13663	: Pg=28.42, Qg=-1.79 -> Pg=28.42, Qg=6.13
% INFO    : Gen at bus 13663	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 13665	: Pg=13.79, Qg=-1.16 -> Pg=13.79, Qg=3.97
% INFO    : Gen at bus 13665	: Vg=1.0419 -> Vg=1.0
% INFO    : Gen at bus 13665	: Pg=0.0, Qg=0.0 -> Pg=8.43, Qg=1.975
% INFO    : Gen at bus 13665	: Vg=1.0419 -> Vg=1.0
% INFO    : Gen at bus 13669	: Pg=0.0, Qg=0.0 -> Pg=137.28, Qg=32.44
% INFO    : Gen at bus 13669	: Vg=1.032 -> Vg=1.0
% INFO    : Gen at bus 13670	: Pg=193.67, Qg=-9.49 -> Pg=193.67, Qg=32.44
% INFO    : Gen at bus 13670	: Vg=1.0316 -> Vg=1.0
% INFO    : Gen at bus 13671	: Pg=126.43, Qg=-9.49 -> Pg=126.43, Qg=32.44
% INFO    : Gen at bus 13671	: Vg=1.0314 -> Vg=1.0
% INFO    : Gen at bus 13672	: Pg=0.0, Qg=0.0 -> Pg=125.545, Qg=32.44
% INFO    : Gen at bus 13672	: Vg=1.032 -> Vg=1.0
% INFO    : Gen at bus 13673	: Pg=0.0, Qg=0.0 -> Pg=138.84, Qg=32.44
% INFO    : Gen at bus 13673	: Vg=1.032 -> Vg=1.0
% INFO    : Gen at bus 13674	: Pg=193.67, Qg=-9.49 -> Pg=193.67, Qg=32.44
% INFO    : Gen at bus 13674	: Vg=1.0311 -> Vg=1.0
% INFO    : Gen at bus 13677	: Pg=0.0, Qg=0.0 -> Pg=89.355, Qg=28.555
% INFO    : Gen at bus 13677	: Vg=1.0371 -> Vg=1.0
% INFO    : Gen at bus 13678	: Pg=142.92, Qg=-15.93 -> Pg=104.365, Qg=28.555
% INFO    : Gen at bus 13678	: Vg=1.0406 -> Vg=1.0
% INFO    : Gen at bus 13680	: Pg=38.5, Qg=-1.89 -> Pg=38.5, Qg=6.445
% INFO    : Gen at bus 13680	: Vg=0.9834 -> Vg=1.0
% INFO    : Gen at bus 13684	: Pg=267.92, Qg=53.19 -> Pg=267.92, Qg=10.005
% INFO    : Gen at bus 13684	: Vg=1.0191 -> Vg=1.0
% INFO    : Gen at bus 13685	: Pg=191.32, Qg=53.19 -> Pg=191.32, Qg=10.005
% INFO    : Gen at bus 13685	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 13686	: Pg=0.0, Qg=0.0 -> Pg=197.955, Qg=9.145
% INFO    : Gen at bus 13686	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 13687	: Pg=6.41, Qg=0.0 -> Pg=6.41, Qg=0.0
% INFO    : Gen at bus 13687	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13687	: Pg=8.91, Qg=0.0 -> Pg=8.91, Qg=0.0
% INFO    : Gen at bus 13687	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13687	: Pg=9.58, Qg=0.0 -> Pg=9.58, Qg=0.0
% INFO    : Gen at bus 13687	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13687	: Pg=8.82, Qg=0.0 -> Pg=8.82, Qg=0.0
% INFO    : Gen at bus 13687	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 13693	: Pg=240.52, Qg=72.85 -> Pg=170.575, Qg=48.055
% INFO    : Gen at bus 13693	: Vg=1.0513 -> Vg=1.0
% INFO    : Gen at bus 13694	: Pg=240.52, Qg=72.85 -> Pg=137.46, Qg=48.055
% INFO    : Gen at bus 13694	: Vg=1.0518 -> Vg=1.0
% INFO    : Gen at bus 13698	: Pg=639.59, Qg=299.27 -> Pg=415.205, Qg=110.46
% INFO    : Gen at bus 13698	: Vg=1.0549 -> Vg=1.0
% INFO    : Gen at bus 20283	: Pg=60.36, Qg=8.58 -> Pg=60.36, Qg=12.41
% INFO    : Gen at bus 20283	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20284	: Pg=12.34, Qg=-0.75 -> Pg=12.34, Qg=2.565
% INFO    : Gen at bus 20284	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20288	: Pg=76.69, Qg=39.19 -> Pg=50.45, Qg=15.32
% INFO    : Gen at bus 20288	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 20293	: Pg=42.41, Qg=21.56 -> Pg=42.41, Qg=3.495
% INFO    : Gen at bus 20293	: Vg=1.0082 -> Vg=1.0
% INFO    : Gen at bus 20295	: Pg=85.3, Qg=45.27 -> Pg=85.3, Qg=19.745
% INFO    : Gen at bus 20295	: Vg=0.9977 -> Vg=1.0
% INFO    : Gen at bus 20299	: Pg=236.5, Qg=50.69 -> Pg=147.12, Qg=47.255
% INFO    : Gen at bus 20299	: Vg=1.0306 -> Vg=1.0
% INFO    : Gen at bus 20300	: Pg=236.51, Qg=50.69 -> Pg=144.25, Qg=47.255
% INFO    : Gen at bus 20300	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 20301	: Pg=236.51, Qg=50.69 -> Pg=161.75, Qg=47.255
% INFO    : Gen at bus 20301	: Vg=1.0293 -> Vg=1.0
% INFO    : Gen at bus 20302	: Pg=28.48, Qg=14.56 -> Pg=16.5, Qg=5.695
% INFO    : Gen at bus 20302	: Vg=1.0279 -> Vg=1.0
% INFO    : Gen at bus 20304	: Pg=0.0, Qg=0.0 -> Pg=33.01, Qg=0.0
% INFO    : Gen at bus 20304	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20304	: Pg=0.0, Qg=0.0 -> Pg=39.715, Qg=0.0
% INFO    : Gen at bus 20304	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20306	: Pg=44.08, Qg=0.0 -> Pg=44.08, Qg=0.0
% INFO    : Gen at bus 20306	: Vg=1.0213 -> Vg=1.0
% INFO    : Gen at bus 20307	: Pg=8.82, Qg=0.0 -> Pg=8.82, Qg=0.0
% INFO    : Gen at bus 20307	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 20307	: Pg=10.64, Qg=0.0 -> Pg=10.64, Qg=0.0
% INFO    : Gen at bus 20307	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 20313	: Pg=0.0, Qg=0.0 -> Pg=97.575, Qg=22.275
% INFO    : Gen at bus 20313	: Vg=1.0292 -> Vg=1.0
% INFO    : Gen at bus 20314	: Pg=119.27, Qg=51.07 -> Pg=119.27, Qg=22.275
% INFO    : Gen at bus 20314	: Vg=1.0199 -> Vg=1.0
% INFO    : Gen at bus 20315	: Pg=5.48, Qg=-0.34 -> Pg=5.48, Qg=1.175
% INFO    : Gen at bus 20315	: Vg=0.9646 -> Vg=1.0
% INFO    : Gen at bus 20319	: Pg=51.54, Qg=-4.13 -> Pg=51.54, Qg=14.12
% INFO    : Gen at bus 20319	: Vg=1.0374 -> Vg=1.0
% INFO    : Gen at bus 20320	: Pg=73.19, Qg=-4.13 -> Pg=73.19, Qg=14.12
% INFO    : Gen at bus 20320	: Vg=1.0374 -> Vg=1.0
% INFO    : Gen at bus 20323	: Pg=14.67, Qg=-1.31 -> Pg=14.67, Qg=4.47
% INFO    : Gen at bus 20323	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20323	: Pg=0.0, Qg=0.0 -> Pg=19.035, Qg=4.47
% INFO    : Gen at bus 20323	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20323	: Pg=19.2, Qg=-1.31 -> Pg=19.2, Qg=4.47
% INFO    : Gen at bus 20323	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20328	: Pg=62.65, Qg=24.06 -> Pg=62.65, Qg=10.495
% INFO    : Gen at bus 20328	: Vg=0.9896 -> Vg=1.0
% INFO    : Gen at bus 20329	: Pg=62.65, Qg=24.06 -> Pg=62.65, Qg=10.495
% INFO    : Gen at bus 20329	: Vg=0.9902 -> Vg=1.0
% INFO    : Gen at bus 20330	: Pg=0.0, Qg=0.0 -> Pg=10.355, Qg=2.43
% INFO    : Gen at bus 20330	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20330	: Pg=10.11, Qg=-0.9 -> Pg=10.11, Qg=3.085
% INFO    : Gen at bus 20330	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20330	: Pg=23.1, Qg=-1.81 -> Pg=23.1, Qg=6.18
% INFO    : Gen at bus 20330	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20330	: Pg=35.59, Qg=-1.81 -> Pg=35.59, Qg=6.18
% INFO    : Gen at bus 20330	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20332	: Pg=32.87, Qg=-3.66 -> Pg=24.32, Qg=6.57
% INFO    : Gen at bus 20332	: Vg=1.0105 -> Vg=1.0
% INFO    : Gen at bus 20332	: Pg=32.87, Qg=-3.66 -> Pg=19.86, Qg=6.57
% INFO    : Gen at bus 20332	: Vg=1.0105 -> Vg=1.0
% INFO    : Gen at bus 20335	: Pg=78.1, Qg=30.3 -> Pg=78.1, Qg=13.215
% INFO    : Gen at bus 20335	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20335	: Pg=61.12, Qg=30.3 -> Pg=61.12, Qg=13.215
% INFO    : Gen at bus 20335	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20336	: Pg=10.0, Qg=-0.49 -> Pg=10.0, Qg=1.675
% INFO    : Gen at bus 20336	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20336	: Pg=10.0, Qg=-0.49 -> Pg=10.0, Qg=1.675
% INFO    : Gen at bus 20336	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20339	: Pg=54.44, Qg=-6.07 -> Pg=30.7, Qg=10.88
% INFO    : Gen at bus 20339	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20339	: Pg=54.45, Qg=-6.07 -> Pg=40.335, Qg=10.88
% INFO    : Gen at bus 20339	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20339	: Pg=54.44, Qg=-6.07 -> Pg=33.485, Qg=10.88
% INFO    : Gen at bus 20339	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20344	: Pg=13.6, Qg=5.22 -> Pg=13.6, Qg=2.275
% INFO    : Gen at bus 20344	: Vg=1.0249 -> Vg=1.0
% INFO    : Gen at bus 20344	: Pg=9.62, Qg=4.88 -> Pg=9.62, Qg=2.13
% INFO    : Gen at bus 20344	: Vg=1.0249 -> Vg=1.0
% INFO    : Gen at bus 20345	: Pg=0.0, Qg=0.0 -> Pg=5.5, Qg=1.375
% INFO    : Gen at bus 20345	: Vg=1.0165 -> Vg=1.0
% INFO    : Gen at bus 20345	: Pg=0.0, Qg=0.0 -> Pg=4.665, Qg=1.375
% INFO    : Gen at bus 20345	: Vg=1.0165 -> Vg=1.0
% INFO    : Gen at bus 20347	: Pg=32.69, Qg=6.86 -> Pg=32.69, Qg=6.465
% INFO    : Gen at bus 20347	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20349	: Pg=15.81, Qg=0.0 -> Pg=15.81, Qg=0.0
% INFO    : Gen at bus 20349	: Vg=0.9875 -> Vg=1.0
% INFO    : Gen at bus 20349	: Pg=14.03, Qg=0.0 -> Pg=14.03, Qg=0.0
% INFO    : Gen at bus 20349	: Vg=0.9875 -> Vg=1.0
% INFO    : Gen at bus 20350	: Pg=18.3, Qg=0.0 -> Pg=18.3, Qg=0.0
% INFO    : Gen at bus 20350	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 20351	: Pg=64.43, Qg=26.88 -> Pg=64.43, Qg=11.725
% INFO    : Gen at bus 20351	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20351	: Pg=0.0, Qg=0.0 -> Pg=48.14, Qg=11.725
% INFO    : Gen at bus 20351	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20353	: Pg=39.89, Qg=-2.53 -> Pg=39.89, Qg=8.66
% INFO    : Gen at bus 20353	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20353	: Pg=39.98, Qg=-2.53 -> Pg=39.98, Qg=8.66
% INFO    : Gen at bus 20353	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20355	: Pg=35.6, Qg=18.2 -> Pg=22.295, Qg=7.115
% INFO    : Gen at bus 20355	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 20355	: Pg=53.78, Qg=27.49 -> Pg=33.02, Qg=10.75
% INFO    : Gen at bus 20355	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 20356	: Pg=35.6, Qg=18.2 -> Pg=24.18, Qg=7.115
% INFO    : Gen at bus 20356	: Vg=1.039 -> Vg=1.0
% INFO    : Gen at bus 20357	: Pg=15.22, Qg=-1.08 -> Pg=15.22, Qg=3.685
% INFO    : Gen at bus 20357	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20357	: Pg=32.46, Qg=-1.62 -> Pg=32.46, Qg=5.525
% INFO    : Gen at bus 20357	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20357	: Pg=24.92, Qg=-1.62 -> Pg=24.92, Qg=5.525
% INFO    : Gen at bus 20357	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20359	: Pg=0.0, Qg=0.0 -> Pg=23.775, Qg=0.0
% INFO    : Gen at bus 20359	: Vg=1.0434 -> Vg=1.0
% INFO    : Gen at bus 20363	: Pg=0.0, Qg=0.0 -> Pg=85.15, Qg=5.175
% INFO    : Gen at bus 20363	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 20367	: Pg=44.41, Qg=21.08 -> Pg=44.41, Qg=9.195
% INFO    : Gen at bus 20367	: Vg=1.0118 -> Vg=1.0
% INFO    : Gen at bus 20368	: Pg=42.08, Qg=21.08 -> Pg=42.08, Qg=9.195
% INFO    : Gen at bus 20368	: Vg=1.0125 -> Vg=1.0
% INFO    : Gen at bus 20369	: Pg=9.29, Qg=4.65 -> Pg=9.29, Qg=2.03
% INFO    : Gen at bus 20369	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 20369	: Pg=8.5, Qg=3.26 -> Pg=8.5, Qg=1.42
% INFO    : Gen at bus 20369	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 20370	: Pg=4.98, Qg=0.84 -> Pg=4.98, Qg=1.275
% INFO    : Gen at bus 20370	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 20371	: Pg=3.98, Qg=-0.33 -> Pg=3.98, Qg=1.14
% INFO    : Gen at bus 20371	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 20371	: Pg=0.0, Qg=0.0 -> Pg=4.755, Qg=1.12
% INFO    : Gen at bus 20371	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 20372	: Pg=6.31, Qg=2.76 -> Pg=6.31, Qg=1.205
% INFO    : Gen at bus 20372	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 20372	: Pg=8.33, Qg=3.92 -> Pg=8.33, Qg=1.71
% INFO    : Gen at bus 20372	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 20372	: Pg=35.98, Qg=17.93 -> Pg=35.98, Qg=7.82
% INFO    : Gen at bus 20372	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 20376	: Pg=0.0, Qg=0.0 -> Pg=33.19, Qg=9.875
% INFO    : Gen at bus 20376	: Vg=1.0073 -> Vg=1.0
% INFO    : Gen at bus 20377	: Pg=58.95, Qg=22.64 -> Pg=58.95, Qg=9.875
% INFO    : Gen at bus 20377	: Vg=1.0131 -> Vg=1.0
% INFO    : Gen at bus 20379	: Pg=62.28, Qg=-3.5 -> Pg=62.28, Qg=11.96
% INFO    : Gen at bus 20379	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20379	: Pg=53.56, Qg=-3.5 -> Pg=53.56, Qg=11.96
% INFO    : Gen at bus 20379	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20383	: Pg=59.0, Qg=-2.89 -> Pg=59.0, Qg=9.885
% INFO    : Gen at bus 20383	: Vg=1.0408 -> Vg=1.0
% INFO    : Gen at bus 20384	: Pg=4.8, Qg=-0.59 -> Pg=4.8, Qg=2.03
% INFO    : Gen at bus 20384	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 20385	: Pg=19.64, Qg=9.45 -> Pg=19.64, Qg=4.12
% INFO    : Gen at bus 20385	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20385	: Pg=20.11, Qg=9.45 -> Pg=20.11, Qg=4.12
% INFO    : Gen at bus 20385	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20385	: Pg=0.0, Qg=0.0 -> Pg=18.03, Qg=4.12
% INFO    : Gen at bus 20385	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20390	: Pg=70.36, Qg=-5.83 -> Pg=70.36, Qg=19.935
% INFO    : Gen at bus 20390	: Vg=1.0279 -> Vg=1.0
% INFO    : Gen at bus 20391	: Pg=88.31, Qg=-5.83 -> Pg=88.31, Qg=19.935
% INFO    : Gen at bus 20391	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 20392	: Pg=74.94, Qg=-5.83 -> Pg=74.94, Qg=19.935
% INFO    : Gen at bus 20392	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 20393	: Pg=119.0, Qg=-5.83 -> Pg=119.0, Qg=19.935
% INFO    : Gen at bus 20393	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 20394	: Pg=0.0, Qg=0.0 -> Pg=68.35, Qg=19.935
% INFO    : Gen at bus 20394	: Vg=1.0348 -> Vg=1.0
% INFO    : Gen at bus 20395	: Pg=0.0, Qg=0.0 -> Pg=81.9, Qg=19.935
% INFO    : Gen at bus 20395	: Vg=1.0348 -> Vg=1.0
% INFO    : Gen at bus 20396	: Pg=48.83, Qg=25.42 -> Pg=48.83, Qg=11.09
% INFO    : Gen at bus 20396	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 20396	: Pg=50.61, Qg=25.42 -> Pg=50.61, Qg=11.09
% INFO    : Gen at bus 20396	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 20396	: Pg=66.2, Qg=25.42 -> Pg=66.2, Qg=11.09
% INFO    : Gen at bus 20396	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 20397	: Pg=4.62, Qg=-0.33 -> Pg=4.62, Qg=1.12
% INFO    : Gen at bus 20397	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20397	: Pg=5.31, Qg=-0.33 -> Pg=5.31, Qg=1.12
% INFO    : Gen at bus 20397	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20401	: Pg=0.0, Qg=0.0 -> Pg=12.1, Qg=0.0
% INFO    : Gen at bus 20401	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20401	: Pg=0.0, Qg=0.0 -> Pg=18.095, Qg=0.0
% INFO    : Gen at bus 20401	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20406	: Pg=8.79, Qg=-0.49 -> Pg=8.79, Qg=1.675
% INFO    : Gen at bus 20406	: Vg=1.0198 -> Vg=1.0
% INFO    : Gen at bus 20407	: Pg=21.65, Qg=-1.25 -> Pg=21.65, Qg=4.27
% INFO    : Gen at bus 20407	: Vg=1.0191 -> Vg=1.0
% INFO    : Gen at bus 20410	: Pg=0.0, Qg=0.0 -> Pg=29.73, Qg=8.895
% INFO    : Gen at bus 20410	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20412	: Pg=5.78, Qg=2.53 -> Pg=5.78, Qg=1.105
% INFO    : Gen at bus 20412	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 20413	: Pg=7.0, Qg=2.69 -> Pg=7.0, Qg=1.175
% INFO    : Gen at bus 20413	: Vg=1.0368 -> Vg=1.0
% INFO    : Gen at bus 20415	: Pg=6.84, Qg=3.84 -> Pg=6.84, Qg=1.675
% INFO    : Gen at bus 20415	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 20416	: Pg=10.0, Qg=3.19 -> Pg=10.0, Qg=1.675
% INFO    : Gen at bus 20416	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20416	: Pg=11.32, Qg=3.19 -> Pg=11.32, Qg=2.26
% INFO    : Gen at bus 20416	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20416	: Pg=10.66, Qg=3.19 -> Pg=10.66, Qg=2.26
% INFO    : Gen at bus 20416	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20416	: Pg=14.08, Qg=3.19 -> Pg=14.08, Qg=3.015
% INFO    : Gen at bus 20416	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=47.45, Qg=-2.84 -> Pg=47.45, Qg=9.725
% INFO    : Gen at bus 20418	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20418	: Pg=58.05, Qg=-2.84 -> Pg=58.05, Qg=9.725
% INFO    : Gen at bus 20418	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20428	: Pg=0.0, Qg=0.0 -> Pg=155.19, Qg=42.19
% INFO    : Gen at bus 20428	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 20429	: Pg=211.14, Qg=-23.53 -> Pg=126.1, Qg=42.19
% INFO    : Gen at bus 20429	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 20430	: Pg=211.14, Qg=-23.53 -> Pg=151.58, Qg=42.19
% INFO    : Gen at bus 20430	: Vg=1.0196 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=8.83, Qg=0.0 -> Pg=8.83, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=9.05, Qg=0.0 -> Pg=9.05, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=10.83, Qg=0.0 -> Pg=10.83, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=13.8, Qg=0.0 -> Pg=13.8, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=16.13, Qg=0.0 -> Pg=16.13, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20432	: Pg=0.0, Qg=0.0 -> Pg=12.575, Qg=0.0
% INFO    : Gen at bus 20432	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=0.0, Qg=0.0 -> Pg=16.085, Qg=4.57
% INFO    : Gen at bus 20435	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 20435	: Pg=12.95, Qg=8.45 -> Pg=12.95, Qg=3.685
% INFO    : Gen at bus 20435	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 20439	: Pg=95.83, Qg=-5.73 -> Pg=95.83, Qg=19.6
% INFO    : Gen at bus 20439	: Vg=0.9943 -> Vg=1.0
% INFO    : Gen at bus 20440	: Pg=0.0, Qg=0.0 -> Pg=83.78, Qg=19.6
% INFO    : Gen at bus 20440	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 20441	: Pg=0.0, Qg=0.0 -> Pg=78.525, Qg=19.6
% INFO    : Gen at bus 20441	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 20442	: Pg=97.7, Qg=-4.79 -> Pg=97.7, Qg=16.365
% INFO    : Gen at bus 20442	: Vg=0.9945 -> Vg=1.0
% INFO    : Gen at bus 20443	: Pg=97.7, Qg=-4.79 -> Pg=97.7, Qg=16.365
% INFO    : Gen at bus 20443	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 20444	: Pg=0.0, Qg=0.0 -> Pg=66.535, Qg=16.365
% INFO    : Gen at bus 20444	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 20445	: Pg=7.62, Qg=-0.49 -> Pg=7.62, Qg=1.675
% INFO    : Gen at bus 20445	: Vg=1.0361 -> Vg=1.0
% INFO    : Gen at bus 20447	: Pg=55.0, Qg=0.0 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 20447	: Vg=1.0073 -> Vg=1.0
% INFO    : Gen at bus 20448	: Pg=41.98, Qg=0.0 -> Pg=41.98, Qg=0.0
% INFO    : Gen at bus 20448	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=9.07, Qg=0.0 -> Pg=9.07, Qg=0.0
% INFO    : Gen at bus 20449	: Vg=1.0075 -> Vg=1.0
% INFO    : Gen at bus 20449	: Pg=0.0, Qg=0.0 -> Pg=8.07, Qg=0.0
% INFO    : Gen at bus 20449	: Vg=1.0075 -> Vg=1.0
% INFO    : Gen at bus 20450	: Pg=0.0, Qg=0.0 -> Pg=11.65, Qg=0.0
% INFO    : Gen at bus 20450	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20450	: Pg=0.0, Qg=0.0 -> Pg=10.605, Qg=0.0
% INFO    : Gen at bus 20450	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20453	: Pg=49.3, Qg=25.2 -> Pg=33.605, Qg=9.855
% INFO    : Gen at bus 20453	: Vg=1.0415 -> Vg=1.0
% INFO    : Gen at bus 20454	: Pg=53.93, Qg=-3.88 -> Pg=53.93, Qg=13.265
% INFO    : Gen at bus 20454	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 20456	: Pg=46.81, Qg=23.92 -> Pg=28.2, Qg=9.35
% INFO    : Gen at bus 20456	: Vg=1.0754 -> Vg=1.0
% INFO    : Gen at bus 20460	: Pg=47.11, Qg=24.08 -> Pg=33.645, Qg=9.415
% INFO    : Gen at bus 20460	: Vg=1.0544 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=32.58, Qg=3.83 -> Pg=32.58, Qg=6.535
% INFO    : Gen at bus 20462	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=26.81, Qg=3.83 -> Pg=26.81, Qg=6.535
% INFO    : Gen at bus 20462	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 20462	: Pg=0.0, Qg=0.0 -> Pg=28.82, Qg=6.535
% INFO    : Gen at bus 20462	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=51.08, Qg=0.0 -> Pg=51.08, Qg=0.0
% INFO    : Gen at bus 20463	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20463	: Pg=65.43, Qg=0.0 -> Pg=65.43, Qg=0.0
% INFO    : Gen at bus 20463	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20468	: Pg=175.95, Qg=-19.61 -> Pg=124.285, Qg=35.155
% INFO    : Gen at bus 20468	: Vg=0.9951 -> Vg=1.0
% INFO    : Gen at bus 20469	: Pg=175.95, Qg=-19.61 -> Pg=118.825, Qg=35.155
% INFO    : Gen at bus 20469	: Vg=0.9948 -> Vg=1.0
% INFO    : Gen at bus 20470	: Pg=175.95, Qg=-19.61 -> Pg=115.14, Qg=35.155
% INFO    : Gen at bus 20470	: Vg=0.9884 -> Vg=1.0
% INFO    : Gen at bus 20471	: Pg=48.8, Qg=-5.44 -> Pg=29.52, Qg=9.75
% INFO    : Gen at bus 20471	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20472	: Pg=40.0, Qg=8.68 -> Pg=40.0, Qg=6.7
% INFO    : Gen at bus 20472	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20474	: Pg=78.0, Qg=0.0 -> Pg=78.0, Qg=0.0
% INFO    : Gen at bus 20474	: Vg=1.0366 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=0.0, Qg=0.0 -> Pg=5.605, Qg=0.0
% INFO    : Gen at bus 20475	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=8.41, Qg=0.0 -> Pg=8.41, Qg=0.0
% INFO    : Gen at bus 20475	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=0.0, Qg=0.0 -> Pg=8.645, Qg=0.0
% INFO    : Gen at bus 20475	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=14.58, Qg=0.0 -> Pg=14.58, Qg=0.0
% INFO    : Gen at bus 20475	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20475	: Pg=31.0, Qg=0.0 -> Pg=31.0, Qg=0.0
% INFO    : Gen at bus 20475	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20478	: Pg=0.0, Qg=0.0 -> Pg=67.33, Qg=15.075
% INFO    : Gen at bus 20478	: Vg=1.0171 -> Vg=1.0
% INFO    : Gen at bus 20479	: Pg=53.69, Qg=-4.41 -> Pg=53.69, Qg=15.075
% INFO    : Gen at bus 20479	: Vg=1.0157 -> Vg=1.0
% INFO    : Gen at bus 20482	: Pg=61.31, Qg=29.64 -> Pg=61.31, Qg=12.93
% INFO    : Gen at bus 20482	: Vg=0.9827 -> Vg=1.0
% INFO    : Gen at bus 20483	: Pg=69.11, Qg=29.64 -> Pg=69.11, Qg=12.93
% INFO    : Gen at bus 20483	: Vg=0.9809 -> Vg=1.0
% INFO    : Gen at bus 20487	: Pg=0.0, Qg=0.0 -> Pg=157.455, Qg=0.0
% INFO    : Gen at bus 20487	: Vg=1.0315 -> Vg=1.0
% INFO    : Gen at bus 20488	: Pg=182.08, Qg=0.0 -> Pg=182.08, Qg=0.0
% INFO    : Gen at bus 20488	: Vg=1.0252 -> Vg=1.0
% INFO    : Gen at bus 20489	: Pg=0.0, Qg=0.0 -> Pg=134.015, Qg=0.0
% INFO    : Gen at bus 20489	: Vg=1.0315 -> Vg=1.0
% INFO    : Gen at bus 20490	: Pg=212.17, Qg=0.0 -> Pg=212.17, Qg=0.0
% INFO    : Gen at bus 20490	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 20491	: Pg=127.29, Qg=0.0 -> Pg=127.29, Qg=0.0
% INFO    : Gen at bus 20491	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 20492	: Pg=212.17, Qg=0.0 -> Pg=212.17, Qg=0.0
% INFO    : Gen at bus 20492	: Vg=1.0252 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=39.6, Qg=15.21 -> Pg=39.6, Qg=6.635
% INFO    : Gen at bus 20494	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20494	: Pg=36.69, Qg=15.21 -> Pg=36.69, Qg=6.635
% INFO    : Gen at bus 20494	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20496	: Pg=7.48, Qg=0.0 -> Pg=7.48, Qg=0.0
% INFO    : Gen at bus 20496	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20496	: Pg=9.15, Qg=0.0 -> Pg=9.15, Qg=0.0
% INFO    : Gen at bus 20496	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20496	: Pg=13.75, Qg=0.0 -> Pg=13.75, Qg=0.0
% INFO    : Gen at bus 20496	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20496	: Pg=8.06, Qg=0.0 -> Pg=8.06, Qg=0.0
% INFO    : Gen at bus 20496	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20499	: Pg=24.5, Qg=0.8 -> Pg=14.73, Qg=4.895
% INFO    : Gen at bus 20499	: Vg=0.9818 -> Vg=1.0
% INFO    : Gen at bus 20500	: Pg=0.0, Qg=0.0 -> Pg=13.595, Qg=4.895
% INFO    : Gen at bus 20500	: Vg=0.9803 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=36.29, Qg=18.54 -> Pg=24.05, Qg=7.25
% INFO    : Gen at bus 20502	: Vg=1.0352 -> Vg=1.0
% INFO    : Gen at bus 20502	: Pg=36.28, Qg=18.54 -> Pg=22.63, Qg=7.25
% INFO    : Gen at bus 20502	: Vg=1.0352 -> Vg=1.0
% INFO    : Gen at bus 20503	: Pg=0.0, Qg=0.0 -> Pg=25.825, Qg=7.25
% INFO    : Gen at bus 20503	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 20503	: Pg=24.5, Qg=12.52 -> Pg=16.99, Qg=4.895
% INFO    : Gen at bus 20503	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 20505	: Pg=7.1, Qg=-0.59 -> Pg=7.1, Qg=2.03
% INFO    : Gen at bus 20505	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 20506	: Pg=40.29, Qg=-2.16 -> Pg=40.29, Qg=7.37
% INFO    : Gen at bus 20506	: Vg=1.0191 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=0.0, Qg=0.0 -> Pg=27.64, Qg=8.76
% INFO    : Gen at bus 20509	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=49.6, Qg=-5.53 -> Pg=30.375, Qg=9.91
% INFO    : Gen at bus 20509	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=49.6, Qg=-5.53 -> Pg=30.285, Qg=9.91
% INFO    : Gen at bus 20509	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 20509	: Pg=0.0, Qg=0.0 -> Pg=33.83, Qg=9.91
% INFO    : Gen at bus 20509	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 20515	: Pg=20.11, Qg=0.0 -> Pg=20.11, Qg=0.0
% INFO    : Gen at bus 20515	: Vg=1.0042 -> Vg=1.0
% INFO    : Gen at bus 20516	: Pg=16.77, Qg=0.0 -> Pg=16.77, Qg=0.0
% INFO    : Gen at bus 20516	: Vg=1.0041 -> Vg=1.0
% INFO    : Gen at bus 20516	: Pg=8.39, Qg=0.0 -> Pg=8.39, Qg=0.0
% INFO    : Gen at bus 20516	: Vg=1.0041 -> Vg=1.0
% INFO    : Gen at bus 20517	: Pg=6.64, Qg=0.0 -> Pg=6.64, Qg=0.0
% INFO    : Gen at bus 20517	: Vg=1.0033 -> Vg=1.0
% INFO    : Gen at bus 20519	: Pg=0.0, Qg=0.0 -> Pg=16.29, Qg=4.605
% INFO    : Gen at bus 20519	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20519	: Pg=27.5, Qg=-1.35 -> Pg=27.5, Qg=4.605
% INFO    : Gen at bus 20519	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20519	: Pg=20.41, Qg=-1.35 -> Pg=20.41, Qg=4.605
% INFO    : Gen at bus 20519	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20519	: Pg=0.0, Qg=0.0 -> Pg=22.76, Qg=5.46
% INFO    : Gen at bus 20519	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 20521	: Pg=0.0, Qg=0.0 -> Pg=23.85, Qg=7.02
% INFO    : Gen at bus 20521	: Vg=1.0284 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=86.6, Qg=17.52 -> Pg=55.56, Qg=17.305
% INFO    : Gen at bus 20523	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 20523	: Pg=86.6, Qg=17.52 -> Pg=62.345, Qg=17.305
% INFO    : Gen at bus 20523	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 20525	: Pg=28.11, Qg=13.29 -> Pg=28.11, Qg=5.795
% INFO    : Gen at bus 20525	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 20526	: Pg=8.56, Qg=3.84 -> Pg=8.56, Qg=1.675
% INFO    : Gen at bus 20526	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 20526	: Pg=7.2, Qg=3.84 -> Pg=7.2, Qg=1.675
% INFO    : Gen at bus 20526	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 20526	: Pg=0.0, Qg=0.0 -> Pg=18.44, Qg=5.005
% INFO    : Gen at bus 20526	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 20526	: Pg=21.01, Qg=13.29 -> Pg=21.01, Qg=5.795
% INFO    : Gen at bus 20526	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=0.0, Qg=0.0 -> Pg=4.395, Qg=1.54
% INFO    : Gen at bus 20528	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=0.0, Qg=0.0 -> Pg=5.37, Qg=1.54
% INFO    : Gen at bus 20528	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=7.7, Qg=3.94 -> Pg=5.65, Qg=1.54
% INFO    : Gen at bus 20528	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=0.0, Qg=0.0 -> Pg=4.31, Qg=1.54
% INFO    : Gen at bus 20528	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=7.7, Qg=3.94 -> Pg=4.975, Qg=1.54
% INFO    : Gen at bus 20528	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20528	: Pg=7.7, Qg=3.94 -> Pg=5.34, Qg=1.54
% INFO    : Gen at bus 20528	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20530	: Pg=27.72, Qg=14.17 -> Pg=17.405, Qg=5.54
% INFO    : Gen at bus 20530	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20530	: Pg=0.0, Qg=0.0 -> Pg=17.82, Qg=5.54
% INFO    : Gen at bus 20530	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 20531	: Pg=27.72, Qg=-3.09 -> Pg=19.005, Qg=5.54
% INFO    : Gen at bus 20531	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20531	: Pg=27.72, Qg=-3.09 -> Pg=16.885, Qg=5.54
% INFO    : Gen at bus 20531	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20531	: Pg=27.72, Qg=-3.09 -> Pg=19.825, Qg=5.54
% INFO    : Gen at bus 20531	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20531	: Pg=27.72, Qg=-3.09 -> Pg=20.695, Qg=5.54
% INFO    : Gen at bus 20531	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20534	: Pg=10.34, Qg=-0.6 -> Pg=10.34, Qg=2.06
% INFO    : Gen at bus 20534	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20534	: Pg=0.0, Qg=0.0 -> Pg=8.495, Qg=2.06
% INFO    : Gen at bus 20534	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20534	: Pg=12.3, Qg=-0.6 -> Pg=12.3, Qg=2.06
% INFO    : Gen at bus 20534	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20534	: Pg=0.0, Qg=0.0 -> Pg=9.0, Qg=2.06
% INFO    : Gen at bus 20534	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=23.08, Qg=-1.73 -> Pg=23.08, Qg=5.93
% INFO    : Gen at bus 20536	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 20536	: Pg=15.96, Qg=-1.73 -> Pg=15.96, Qg=5.93
% INFO    : Gen at bus 20536	: Vg=1.0343 -> Vg=1.0
% INFO    : Gen at bus 20537	: Pg=27.4, Qg=-1.73 -> Pg=27.4, Qg=5.93
% INFO    : Gen at bus 20537	: Vg=1.033 -> Vg=1.0
% INFO    : Gen at bus 20538	: Pg=35.4, Qg=-1.73 -> Pg=35.4, Qg=5.93
% INFO    : Gen at bus 20538	: Vg=1.0351 -> Vg=1.0
% INFO    : Gen at bus 20540	: Pg=61.74, Qg=31.03 -> Pg=61.74, Qg=13.535
% INFO    : Gen at bus 20540	: Vg=1.0718 -> Vg=1.0
% INFO    : Gen at bus 20541	: Pg=60.2, Qg=31.03 -> Pg=60.2, Qg=13.535
% INFO    : Gen at bus 20541	: Vg=1.078 -> Vg=1.0
% INFO    : Gen at bus 20544	: Pg=124.18, Qg=-7.72 -> Pg=124.18, Qg=26.38
% INFO    : Gen at bus 20544	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 20545	: Pg=0.0, Qg=0.0 -> Pg=100.1, Qg=26.38
% INFO    : Gen at bus 20545	: Vg=1.0327 -> Vg=1.0
% INFO    : Gen at bus 21596	: Pg=206.16, Qg=60.92 -> Pg=116.55, Qg=41.19
% INFO    : Gen at bus 21596	: Vg=0.9997 -> Vg=1.0
% INFO    : Gen at bus 21597	: Pg=206.16, Qg=60.92 -> Pg=120.58, Qg=41.19
% INFO    : Gen at bus 21597	: Vg=0.9994 -> Vg=1.0
% INFO    : Gen at bus 21598	: Pg=206.16, Qg=60.92 -> Pg=145.435, Qg=41.19
% INFO    : Gen at bus 21598	: Vg=0.9995 -> Vg=1.0
% INFO    : Gen at bus 21599	: Pg=206.16, Qg=60.92 -> Pg=114.92, Qg=41.19
% INFO    : Gen at bus 21599	: Vg=0.9947 -> Vg=1.0
% INFO    : Gen at bus 21602	: Pg=57.05, Qg=12.15 -> Pg=57.05, Qg=1.965
% INFO    : Gen at bus 21602	: Vg=1.0377 -> Vg=1.0
% INFO    : Gen at bus 21603	: Pg=36.47, Qg=12.15 -> Pg=36.47, Qg=1.965
% INFO    : Gen at bus 21603	: Vg=1.0396 -> Vg=1.0
% INFO    : Gen at bus 21604	: Pg=38.97, Qg=12.15 -> Pg=38.97, Qg=1.965
% INFO    : Gen at bus 21604	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 21605	: Pg=36.12, Qg=12.15 -> Pg=36.12, Qg=1.965
% INFO    : Gen at bus 21605	: Vg=1.0371 -> Vg=1.0
% INFO    : Gen at bus 21611	: Pg=234.92, Qg=24.58 -> Pg=130.865, Qg=46.94
% INFO    : Gen at bus 21611	: Vg=0.9821 -> Vg=1.0
% INFO    : Gen at bus 21612	: Pg=234.92, Qg=24.58 -> Pg=166.605, Qg=46.94
% INFO    : Gen at bus 21612	: Vg=0.9674 -> Vg=1.0
% INFO    : Gen at bus 21613	: Pg=234.92, Qg=24.58 -> Pg=134.26, Qg=46.94
% INFO    : Gen at bus 21613	: Vg=0.9719 -> Vg=1.0
% INFO    : Gen at bus 21614	: Pg=0.0, Qg=0.0 -> Pg=146.88, Qg=46.94
% INFO    : Gen at bus 21614	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 21617	: Pg=283.17, Qg=70.82 -> Pg=283.17, Qg=11.47
% INFO    : Gen at bus 21617	: Vg=0.9965 -> Vg=1.0
% INFO    : Gen at bus 21618	: Pg=16.22, Qg=5.11 -> Pg=16.22, Qg=0.825
% INFO    : Gen at bus 21618	: Vg=0.9881 -> Vg=1.0
% INFO    : Gen at bus 21619	: Pg=18.0, Qg=3.83 -> Pg=18.0, Qg=0.62
% INFO    : Gen at bus 21619	: Vg=0.9928 -> Vg=1.0
% INFO    : Gen at bus 21619	: Pg=0.0, Qg=0.0 -> Pg=10.235, Qg=0.62
% INFO    : Gen at bus 21619	: Vg=0.9928 -> Vg=1.0
% INFO    : Gen at bus 21620	: Pg=10.9, Qg=2.32 -> Pg=10.9, Qg=0.375
% INFO    : Gen at bus 21620	: Vg=0.994 -> Vg=1.0
% INFO    : Gen at bus 21620	: Pg=10.5, Qg=2.24 -> Pg=10.5, Qg=0.365
% INFO    : Gen at bus 21620	: Vg=0.994 -> Vg=1.0
% INFO    : Gen at bus 21623	: Pg=205.73, Qg=-4.42 -> Pg=120.24, Qg=41.105
% INFO    : Gen at bus 21623	: Vg=1.017 -> Vg=1.0
% INFO    : Gen at bus 21624	: Pg=205.73, Qg=-4.42 -> Pg=138.875, Qg=41.105
% INFO    : Gen at bus 21624	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 21625	: Pg=205.73, Qg=-4.42 -> Pg=139.835, Qg=41.105
% INFO    : Gen at bus 21625	: Vg=1.0181 -> Vg=1.0
% INFO    : Gen at bus 21627	: Pg=51.12, Qg=26.13 -> Pg=29.865, Qg=10.215
% INFO    : Gen at bus 21627	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 21627	: Pg=51.12, Qg=26.13 -> Pg=35.215, Qg=10.215
% INFO    : Gen at bus 21627	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 21627	: Pg=51.12, Qg=26.13 -> Pg=30.795, Qg=10.215
% INFO    : Gen at bus 21627	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 21628	: Pg=13.45, Qg=6.87 -> Pg=8.145, Qg=2.685
% INFO    : Gen at bus 21628	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 21628	: Pg=0.0, Qg=0.0 -> Pg=8.05, Qg=2.685
% INFO    : Gen at bus 21628	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 21631	: Pg=55.08, Qg=25.77 -> Pg=32.54, Qg=9.51
% INFO    : Gen at bus 21631	: Vg=1.0328 -> Vg=1.0
% INFO    : Gen at bus 21636	: Pg=26.29, Qg=13.44 -> Pg=15.31, Qg=5.255
% INFO    : Gen at bus 21636	: Vg=0.9692 -> Vg=1.0
% INFO    : Gen at bus 21637	: Pg=26.29, Qg=13.44 -> Pg=18.55, Qg=5.255
% INFO    : Gen at bus 21637	: Vg=1.0011 -> Vg=1.0
% INFO    : Gen at bus 21639	: Pg=64.74, Qg=22.63 -> Pg=44.845, Qg=12.94
% INFO    : Gen at bus 21639	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 21639	: Pg=0.0, Qg=0.0 -> Pg=47.355, Qg=12.94
% INFO    : Gen at bus 21639	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 21646	: Pg=253.45, Qg=238.2 -> Pg=329.61, Qg=93.13
% INFO    : Gen at bus 21646	: Vg=1.0458 -> Vg=1.0
% INFO    : Gen at bus 21647	: Pg=466.07, Qg=238.2 -> Pg=270.99, Qg=93.13
% INFO    : Gen at bus 21647	: Vg=1.0463 -> Vg=1.0
% INFO    : Gen at bus 21648	: Pg=0.0, Qg=0.0 -> Pg=335.485, Qg=93.13
% INFO    : Gen at bus 21648	: Vg=1.025 -> Vg=1.0
% INFO    : Gen at bus 21651	: Pg=225.18, Qg=63.23 -> Pg=154.61, Qg=44.99
% INFO    : Gen at bus 21651	: Vg=1.0162 -> Vg=1.0
% INFO    : Gen at bus 21652	: Pg=225.18, Qg=63.23 -> Pg=144.955, Qg=44.99
% INFO    : Gen at bus 21652	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 21653	: Pg=225.18, Qg=63.23 -> Pg=167.36, Qg=44.99
% INFO    : Gen at bus 21653	: Vg=1.0165 -> Vg=1.0
% INFO    : Gen at bus 21654	: Pg=0.0, Qg=0.0 -> Pg=15.885, Qg=0.0
% INFO    : Gen at bus 21654	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 21654	: Pg=0.0, Qg=0.0 -> Pg=17.87, Qg=0.0
% INFO    : Gen at bus 21654	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 21656	: Pg=46.81, Qg=23.92 -> Pg=33.895, Qg=9.35
% INFO    : Gen at bus 21656	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 21656	: Pg=46.81, Qg=23.92 -> Pg=26.96, Qg=9.35
% INFO    : Gen at bus 21656	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 21656	: Pg=46.81, Qg=23.92 -> Pg=31.9, Qg=9.35
% INFO    : Gen at bus 21656	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 21662	: Pg=0.0, Qg=0.0 -> Pg=36.35, Qg=9.93
% INFO    : Gen at bus 21662	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 21662	: Pg=49.7, Qg=25.4 -> Pg=31.145, Qg=9.93
% INFO    : Gen at bus 21662	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 21663	: Pg=49.7, Qg=25.4 -> Pg=33.895, Qg=9.93
% INFO    : Gen at bus 21663	: Vg=1.0281 -> Vg=1.0
% INFO    : Gen at bus 21663	: Pg=49.7, Qg=25.4 -> Pg=36.375, Qg=9.93
% INFO    : Gen at bus 21663	: Vg=1.0281 -> Vg=1.0
% INFO    : Gen at bus 21668	: Pg=74.2, Qg=34.72 -> Pg=47.885, Qg=12.815
% INFO    : Gen at bus 21668	: Vg=1.0338 -> Vg=1.0
% INFO    : Gen at bus 21669	: Pg=74.2, Qg=34.72 -> Pg=48.59, Qg=12.815
% INFO    : Gen at bus 21669	: Vg=1.0313 -> Vg=1.0
% INFO    : Gen at bus 21670	: Pg=0.0, Qg=0.0 -> Pg=44.44, Qg=12.815
% INFO    : Gen at bus 21670	: Vg=1.0076 -> Vg=1.0
% INFO    : Gen at bus 21673	: Pg=60.25, Qg=4.07 -> Pg=43.435, Qg=12.035
% INFO    : Gen at bus 21673	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 21675	: Pg=46.81, Qg=23.92 -> Pg=33.145, Qg=9.35
% INFO    : Gen at bus 21675	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 21676	: Pg=32.64, Qg=7.84 -> Pg=32.64, Qg=1.27
% INFO    : Gen at bus 21676	: Vg=1.042 -> Vg=1.0
% INFO    : Gen at bus 21676	: Pg=81.0, Qg=17.25 -> Pg=81.0, Qg=2.795
% INFO    : Gen at bus 21676	: Vg=1.042 -> Vg=1.0
% INFO    : Gen at bus 21676	: Pg=71.8, Qg=17.25 -> Pg=71.8, Qg=2.795
% INFO    : Gen at bus 21676	: Vg=1.042 -> Vg=1.0
% INFO    : Gen at bus 21681	: Pg=110.83, Qg=31.95 -> Pg=110.83, Qg=5.175
% INFO    : Gen at bus 21681	: Vg=1.0123 -> Vg=1.0
% INFO    : Gen at bus 21689	: Pg=210.81, Qg=107.74 -> Pg=117.025, Qg=42.12
% INFO    : Gen at bus 21689	: Vg=1.0434 -> Vg=1.0
% INFO    : Gen at bus 21690	: Pg=210.81, Qg=107.74 -> Pg=146.15, Qg=42.12
% INFO    : Gen at bus 21690	: Vg=1.0444 -> Vg=1.0
% INFO    : Gen at bus 21691	: Pg=210.81, Qg=107.74 -> Pg=153.575, Qg=42.12
% INFO    : Gen at bus 21691	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 21693	: Pg=0.0, Qg=0.0 -> Pg=75.975, Qg=3.535
% INFO    : Gen at bus 21693	: Vg=1.0206 -> Vg=1.0
% INFO    : Gen at bus 21694	: Pg=46.81, Qg=23.92 -> Pg=34.52, Qg=9.35
% INFO    : Gen at bus 21694	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 21694	: Pg=50.79, Qg=25.96 -> Pg=36.78, Qg=10.15
% INFO    : Gen at bus 21694	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 21699	: Pg=37.68, Qg=2.57 -> Pg=25.19, Qg=7.53
% INFO    : Gen at bus 21699	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 21699	: Pg=37.68, Qg=2.57 -> Pg=23.235, Qg=7.53
% INFO    : Gen at bus 21699	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 21699	: Pg=37.68, Qg=2.57 -> Pg=23.175, Qg=7.53
% INFO    : Gen at bus 21699	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 21702	: Pg=111.58, Qg=1.94 -> Pg=64.04, Qg=22.29
% INFO    : Gen at bus 21702	: Vg=1.0169 -> Vg=1.0
% INFO    : Gen at bus 21703	: Pg=111.58, Qg=1.94 -> Pg=66.62, Qg=22.29
% INFO    : Gen at bus 21703	: Vg=1.0168 -> Vg=1.0
% INFO    : Gen at bus 21704	: Pg=111.57, Qg=1.94 -> Pg=67.34, Qg=22.29
% INFO    : Gen at bus 21704	: Vg=1.0169 -> Vg=1.0
% INFO    : Gen at bus 21706	: Pg=0.0, Qg=0.0 -> Pg=8.095, Qg=2.835
% INFO    : Gen at bus 21706	: Vg=1.0046 -> Vg=1.0
% INFO    : Gen at bus 21707	: Pg=0.0, Qg=0.0 -> Pg=9.805, Qg=2.835
% INFO    : Gen at bus 21707	: Vg=1.0046 -> Vg=1.0
% INFO    : Gen at bus 21709	: Pg=27.29, Qg=13.95 -> Pg=18.87, Qg=5.455
% INFO    : Gen at bus 21709	: Vg=1.0243 -> Vg=1.0
% INFO    : Gen at bus 21710	: Pg=27.29, Qg=13.95 -> Pg=18.145, Qg=5.455
% INFO    : Gen at bus 21710	: Vg=1.0243 -> Vg=1.0
% INFO    : Gen at bus 21716	: Pg=0.0, Qg=0.0 -> Pg=9.585, Qg=0.56
% INFO    : Gen at bus 21716	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 21716	: Pg=52.68, Qg=13.95 -> Pg=52.68, Qg=2.7
% INFO    : Gen at bus 21716	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 21718	: Pg=33.2, Qg=16.97 -> Pg=22.68, Qg=6.635
% INFO    : Gen at bus 21718	: Vg=1.0399 -> Vg=1.0
% INFO    : Gen at bus 21718	: Pg=33.19, Qg=16.97 -> Pg=21.47, Qg=6.635
% INFO    : Gen at bus 21718	: Vg=1.0399 -> Vg=1.0
% INFO    : Gen at bus 21719	: Pg=33.19, Qg=16.97 -> Pg=21.075, Qg=6.635
% INFO    : Gen at bus 21719	: Vg=1.0428 -> Vg=1.0
% INFO    : Gen at bus 21720	: Pg=8.9, Qg=4.16 -> Pg=5.3, Qg=1.535
% INFO    : Gen at bus 21720	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21720	: Pg=8.9, Qg=4.16 -> Pg=6.06, Qg=1.535
% INFO    : Gen at bus 21720	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21720	: Pg=0.0, Qg=0.0 -> Pg=5.64, Qg=1.535
% INFO    : Gen at bus 21720	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21720	: Pg=0.0, Qg=0.0 -> Pg=5.2, Qg=1.535
% INFO    : Gen at bus 21720	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21720	: Pg=8.9, Qg=4.16 -> Pg=5.625, Qg=1.535
% INFO    : Gen at bus 21720	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21720	: Pg=8.9, Qg=4.16 -> Pg=5.06, Qg=1.535
% INFO    : Gen at bus 21720	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21726	: Pg=246.39, Qg=78.59 -> Pg=148.375, Qg=49.235
% INFO    : Gen at bus 21726	: Vg=0.9899 -> Vg=1.0
% INFO    : Gen at bus 21730	: Pg=217.44, Qg=111.13 -> Pg=154.955, Qg=43.45
% INFO    : Gen at bus 21730	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 21731	: Pg=217.45, Qg=111.13 -> Pg=162.32, Qg=43.45
% INFO    : Gen at bus 21731	: Vg=1.0308 -> Vg=1.0
% INFO    : Gen at bus 21732	: Pg=217.45, Qg=111.13 -> Pg=136.72, Qg=43.45
% INFO    : Gen at bus 21732	: Vg=1.0237 -> Vg=1.0
% INFO    : Gen at bus 21735	: Pg=60.97, Qg=31.16 -> Pg=41.765, Qg=12.18
% INFO    : Gen at bus 21735	: Vg=0.9831 -> Vg=1.0
% INFO    : Gen at bus 21736	: Pg=0.0, Qg=0.0 -> Pg=34.44, Qg=12.18
% INFO    : Gen at bus 21736	: Vg=0.9975 -> Vg=1.0
% INFO    : Gen at bus 21737	: Pg=60.97, Qg=31.16 -> Pg=41.215, Qg=12.18
% INFO    : Gen at bus 21737	: Vg=0.9831 -> Vg=1.0
% INFO    : Gen at bus 21738	: Pg=0.0, Qg=0.0 -> Pg=39.385, Qg=12.18
% INFO    : Gen at bus 21738	: Vg=0.9975 -> Vg=1.0
% INFO    : Gen at bus 21739	: Pg=60.97, Qg=31.16 -> Pg=36.215, Qg=12.18
% INFO    : Gen at bus 21739	: Vg=0.9826 -> Vg=1.0
% INFO    : Gen at bus 21740	: Pg=0.0, Qg=0.0 -> Pg=10.105, Qg=3.18
% INFO    : Gen at bus 21740	: Vg=0.9975 -> Vg=1.0
% INFO    : Gen at bus 21740	: Pg=0.0, Qg=0.0 -> Pg=10.99, Qg=3.18
% INFO    : Gen at bus 21740	: Vg=0.9975 -> Vg=1.0
% INFO    : Gen at bus 21742	: Pg=68.89, Qg=16.66 -> Pg=68.89, Qg=2.7
% INFO    : Gen at bus 21742	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 21743	: Pg=38.0, Qg=-5.47 -> Pg=38.0, Qg=1.31
% INFO    : Gen at bus 21743	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 21744	: Pg=44.82, Qg=14.17 -> Pg=24.94, Qg=8.955
% INFO    : Gen at bus 21744	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 21748	: Pg=44.82, Qg=14.17 -> Pg=31.76, Qg=8.955
% INFO    : Gen at bus 21748	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 21749	: Pg=44.82, Qg=14.17 -> Pg=33.16, Qg=8.955
% INFO    : Gen at bus 21749	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 21753	: Pg=62.35, Qg=31.86 -> Pg=37.38, Qg=12.455
% INFO    : Gen at bus 21753	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 21753	: Pg=62.35, Qg=31.86 -> Pg=42.815, Qg=12.455
% INFO    : Gen at bus 21753	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 21754	: Pg=30.28, Qg=15.47 -> Pg=21.675, Qg=6.05
% INFO    : Gen at bus 21754	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 21756	: Pg=0.0, Qg=0.0 -> Pg=12.2, Qg=3.64
% INFO    : Gen at bus 21756	: Vg=1.0129 -> Vg=1.0
% INFO    : Gen at bus 21756	: Pg=0.0, Qg=0.0 -> Pg=12.105, Qg=3.64
% INFO    : Gen at bus 21756	: Vg=1.0129 -> Vg=1.0
% INFO    : Gen at bus 21757	: Pg=18.23, Qg=9.31 -> Pg=10.69, Qg=3.64
% INFO    : Gen at bus 21757	: Vg=1.0227 -> Vg=1.0
% INFO    : Gen at bus 21758	: Pg=32.17, Qg=16.44 -> Pg=20.585, Qg=6.425
% INFO    : Gen at bus 21758	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21758	: Pg=32.17, Qg=16.44 -> Pg=19.295, Qg=6.425
% INFO    : Gen at bus 21758	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 21760	: Pg=70.01, Qg=-14.59 -> Pg=70.01, Qg=3.495
% INFO    : Gen at bus 21760	: Vg=0.973 -> Vg=1.0
% INFO    : Gen at bus 23267	: Pg=48.8, Qg=24.94 -> Pg=30.665, Qg=9.75
% INFO    : Gen at bus 23267	: Vg=1.0457 -> Vg=1.0
% INFO    : Gen at bus 23268	: Pg=48.8, Qg=24.94 -> Pg=30.085, Qg=9.75
% INFO    : Gen at bus 23268	: Vg=1.0457 -> Vg=1.0
% INFO    : Gen at bus 23270	: Pg=27.29, Qg=-3.04 -> Pg=20.12, Qg=5.455
% INFO    : Gen at bus 23270	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23270	: Pg=49.8, Qg=-5.55 -> Pg=28.055, Qg=9.95
% INFO    : Gen at bus 23270	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23272	: Pg=6.4, Qg=-0.49 -> Pg=6.4, Qg=1.675
% INFO    : Gen at bus 23272	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23272	: Pg=13.54, Qg=-0.79 -> Pg=13.54, Qg=2.715
% INFO    : Gen at bus 23272	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23272	: Pg=57.7, Qg=-3.53 -> Pg=57.7, Qg=12.06
% INFO    : Gen at bus 23272	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23277	: Pg=0.0, Qg=0.0 -> Pg=25.055, Qg=5.725
% INFO    : Gen at bus 23277	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23278	: Pg=0.0, Qg=0.0 -> Pg=4.965, Qg=1.315
% INFO    : Gen at bus 23278	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 23278	: Pg=7.04, Qg=-0.39 -> Pg=7.04, Qg=1.315
% INFO    : Gen at bus 23278	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 23278	: Pg=7.87, Qg=-0.39 -> Pg=7.87, Qg=1.315
% INFO    : Gen at bus 23278	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 23278	: Pg=0.0, Qg=0.0 -> Pg=20.975, Qg=5.725
% INFO    : Gen at bus 23278	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 23278	: Pg=0.0, Qg=0.0 -> Pg=23.545, Qg=5.725
% INFO    : Gen at bus 23278	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 23281	: Pg=42.09, Qg=19.2 -> Pg=42.09, Qg=8.375
% INFO    : Gen at bus 23281	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 23281	: Pg=0.0, Qg=0.0 -> Pg=32.47, Qg=8.375
% INFO    : Gen at bus 23281	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 23282	: Pg=20.0, Qg=0.0 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 23282	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23282	: Pg=12.92, Qg=0.0 -> Pg=12.92, Qg=0.0
% INFO    : Gen at bus 23282	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23282	: Pg=0.0, Qg=0.0 -> Pg=13.98, Qg=0.0
% INFO    : Gen at bus 23282	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23282	: Pg=17.33, Qg=0.0 -> Pg=17.33, Qg=0.0
% INFO    : Gen at bus 23282	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23287	: Pg=107.56, Qg=0.12 -> Pg=79.605, Qg=21.49
% INFO    : Gen at bus 23287	: Vg=1.0222 -> Vg=1.0
% INFO    : Gen at bus 23288	: Pg=107.56, Qg=0.12 -> Pg=65.08, Qg=21.49
% INFO    : Gen at bus 23288	: Vg=1.0222 -> Vg=1.0
% INFO    : Gen at bus 23289	: Pg=107.56, Qg=0.12 -> Pg=62.47, Qg=21.49
% INFO    : Gen at bus 23289	: Vg=1.0222 -> Vg=1.0
% INFO    : Gen at bus 23290	: Pg=107.56, Qg=0.12 -> Pg=66.6, Qg=21.49
% INFO    : Gen at bus 23290	: Vg=1.0222 -> Vg=1.0
% INFO    : Gen at bus 23293	: Pg=113.37, Qg=-6.84 -> Pg=113.37, Qg=23.365
% INFO    : Gen at bus 23293	: Vg=0.969 -> Vg=1.0
% INFO    : Gen at bus 23294	: Pg=0.0, Qg=0.0 -> Pg=6.675, Qg=1.895
% INFO    : Gen at bus 23294	: Vg=1.0336 -> Vg=1.0
% INFO    : Gen at bus 23295	: Pg=11.3, Qg=4.34 -> Pg=11.3, Qg=1.895
% INFO    : Gen at bus 23295	: Vg=1.0269 -> Vg=1.0
% INFO    : Gen at bus 23295	: Pg=7.94, Qg=3.92 -> Pg=7.94, Qg=1.71
% INFO    : Gen at bus 23295	: Vg=1.0269 -> Vg=1.0
% INFO    : Gen at bus 23296	: Pg=5.07, Qg=-0.5 -> Pg=5.07, Qg=1.71
% INFO    : Gen at bus 23296	: Vg=0.989 -> Vg=1.0
% INFO    : Gen at bus 23297	: Pg=10.2, Qg=-0.5 -> Pg=10.2, Qg=1.71
% INFO    : Gen at bus 23297	: Vg=0.9891 -> Vg=1.0
% INFO    : Gen at bus 23298	: Pg=28.11, Qg=0.0 -> Pg=28.11, Qg=0.0
% INFO    : Gen at bus 23298	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23298	: Pg=27.55, Qg=0.0 -> Pg=27.55, Qg=0.0
% INFO    : Gen at bus 23298	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23298	: Pg=22.76, Qg=0.0 -> Pg=22.76, Qg=0.0
% INFO    : Gen at bus 23298	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23302	: Pg=47.51, Qg=0.0 -> Pg=47.51, Qg=0.0
% INFO    : Gen at bus 23302	: Vg=1.0388 -> Vg=1.0
% INFO    : Gen at bus 23303	: Pg=20.2, Qg=0.0 -> Pg=20.2, Qg=0.0
% INFO    : Gen at bus 23303	: Vg=1.0387 -> Vg=1.0
% INFO    : Gen at bus 23303	: Pg=14.2, Qg=0.0 -> Pg=14.2, Qg=0.0
% INFO    : Gen at bus 23303	: Vg=1.0387 -> Vg=1.0
% INFO    : Gen at bus 23304	: Pg=20.0, Qg=0.0 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 23304	: Vg=0.9993 -> Vg=1.0
% INFO    : Gen at bus 23305	: Pg=0.0, Qg=0.0 -> Pg=11.5, Qg=0.0
% INFO    : Gen at bus 23305	: Vg=1.0386 -> Vg=1.0
% INFO    : Gen at bus 23306	: Pg=36.36, Qg=8.11 -> Pg=36.36, Qg=8.375
% INFO    : Gen at bus 23306	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 23306	: Pg=33.66, Qg=8.11 -> Pg=33.66, Qg=8.375
% INFO    : Gen at bus 23306	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 23307	: Pg=15.37, Qg=-0.98 -> Pg=15.37, Qg=3.37
% INFO    : Gen at bus 23307	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23307	: Pg=0.0, Qg=0.0 -> Pg=27.58, Qg=8.14
% INFO    : Gen at bus 23307	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23309	: Pg=55.64, Qg=-6.2 -> Pg=30.92, Qg=11.12
% INFO    : Gen at bus 23309	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23309	: Pg=55.65, Qg=-6.2 -> Pg=35.835, Qg=11.12
% INFO    : Gen at bus 23309	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23309	: Pg=55.65, Qg=-6.2 -> Pg=38.27, Qg=11.12
% INFO    : Gen at bus 23309	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23309	: Pg=55.64, Qg=-6.2 -> Pg=41.79, Qg=11.12
% INFO    : Gen at bus 23309	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23311	: Pg=33.82, Qg=-1.71 -> Pg=33.82, Qg=5.84
% INFO    : Gen at bus 23311	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23311	: Pg=34.88, Qg=-1.71 -> Pg=34.88, Qg=5.84
% INFO    : Gen at bus 23311	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23311	: Pg=0.0, Qg=0.0 -> Pg=21.275, Qg=5.84
% INFO    : Gen at bus 23311	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23311	: Pg=24.68, Qg=-1.71 -> Pg=24.68, Qg=5.84
% INFO    : Gen at bus 23311	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23311	: Pg=0.0, Qg=0.0 -> Pg=20.875, Qg=5.84
% INFO    : Gen at bus 23311	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23313	: Pg=11.37, Qg=0.0 -> Pg=11.37, Qg=0.0
% INFO    : Gen at bus 23313	: Vg=1.0406 -> Vg=1.0
% INFO    : Gen at bus 23313	: Pg=14.51, Qg=0.0 -> Pg=14.51, Qg=0.0
% INFO    : Gen at bus 23313	: Vg=1.0406 -> Vg=1.0
% INFO    : Gen at bus 23315	: Pg=38.04, Qg=13.28 -> Pg=27.2, Qg=7.6
% INFO    : Gen at bus 23315	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23318	: Pg=27.29, Qg=13.95 -> Pg=17.365, Qg=5.455
% INFO    : Gen at bus 23318	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23318	: Pg=27.29, Qg=13.95 -> Pg=17.4, Qg=5.455
% INFO    : Gen at bus 23318	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23319	: Pg=67.5, Qg=25.92 -> Pg=67.5, Qg=11.305
% INFO    : Gen at bus 23319	: Vg=1.044 -> Vg=1.0
% INFO    : Gen at bus 23319	: Pg=0.0, Qg=0.0 -> Pg=41.965, Qg=11.305
% INFO    : Gen at bus 23319	: Vg=1.044 -> Vg=1.0
% INFO    : Gen at bus 23321	: Pg=10.8, Qg=-0.53 -> Pg=10.8, Qg=1.81
% INFO    : Gen at bus 23321	: Vg=1.0449 -> Vg=1.0
% INFO    : Gen at bus 23322	: Pg=18.22, Qg=-1.08 -> Pg=18.22, Qg=3.7
% INFO    : Gen at bus 23322	: Vg=1.0444 -> Vg=1.0
% INFO    : Gen at bus 23324	: Pg=20.0, Qg=-1.08 -> Pg=20.0, Qg=3.7
% INFO    : Gen at bus 23324	: Vg=1.0437 -> Vg=1.0
% INFO    : Gen at bus 23325	: Pg=13.96, Qg=-1.08 -> Pg=13.96, Qg=3.7
% INFO    : Gen at bus 23325	: Vg=1.0416 -> Vg=1.0
% INFO    : Gen at bus 23326	: Pg=22.08, Qg=-1.08 -> Pg=22.08, Qg=3.7
% INFO    : Gen at bus 23326	: Vg=1.0432 -> Vg=1.0
% INFO    : Gen at bus 23329	: Pg=66.33, Qg=6.52 -> Pg=39.855, Qg=13.255
% INFO    : Gen at bus 23329	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23329	: Pg=66.33, Qg=6.52 -> Pg=37.715, Qg=13.255
% INFO    : Gen at bus 23329	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23333	: Pg=0.0, Qg=0.0 -> Pg=16.995, Qg=0.0
% INFO    : Gen at bus 23333	: Vg=1.0449 -> Vg=1.0
% INFO    : Gen at bus 23333	: Pg=24.87, Qg=0.0 -> Pg=24.87, Qg=0.0
% INFO    : Gen at bus 23333	: Vg=1.0449 -> Vg=1.0
% INFO    : Gen at bus 23334	: Pg=0.0, Qg=0.0 -> Pg=22.685, Qg=0.0
% INFO    : Gen at bus 23334	: Vg=1.0448 -> Vg=1.0
% INFO    : Gen at bus 23337	: Pg=27.45, Qg=-1.84 -> Pg=27.45, Qg=6.28
% INFO    : Gen at bus 23337	: Vg=1.0376 -> Vg=1.0
% INFO    : Gen at bus 23338	: Pg=0.0, Qg=0.0 -> Pg=50.285, Qg=13.135
% INFO    : Gen at bus 23338	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23338	: Pg=60.59, Qg=30.11 -> Pg=60.59, Qg=13.135
% INFO    : Gen at bus 23338	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23340	: Pg=0.0, Qg=0.0 -> Pg=35.03, Qg=12.035
% INFO    : Gen at bus 23340	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 23340	: Pg=60.25, Qg=-6.72 -> Pg=41.1, Qg=12.035
% INFO    : Gen at bus 23340	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 23345	: Pg=0.0, Qg=0.0 -> Pg=9.355, Qg=2.485
% INFO    : Gen at bus 23345	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23346	: Pg=18.03, Qg=9.21 -> Pg=10.685, Qg=3.6
% INFO    : Gen at bus 23346	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23346	: Pg=18.03, Qg=9.21 -> Pg=10.135, Qg=3.6
% INFO    : Gen at bus 23346	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23346	: Pg=48.8, Qg=24.94 -> Pg=34.64, Qg=9.75
% INFO    : Gen at bus 23346	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23347	: Pg=0.0, Qg=0.0 -> Pg=8.045, Qg=1.895
% INFO    : Gen at bus 23347	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23347	: Pg=38.5, Qg=-1.89 -> Pg=38.5, Qg=6.445
% INFO    : Gen at bus 23347	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23347	: Pg=27.83, Qg=-1.89 -> Pg=27.83, Qg=6.445
% INFO    : Gen at bus 23347	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23347	: Pg=31.94, Qg=-1.89 -> Pg=31.94, Qg=6.445
% INFO    : Gen at bus 23347	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23348	: Pg=70.91, Qg=13.16 -> Pg=44.88, Qg=12.245
% INFO    : Gen at bus 23348	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 23348	: Pg=70.91, Qg=13.16 -> Pg=42.48, Qg=12.245
% INFO    : Gen at bus 23348	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 23351	: Pg=24.8, Qg=12.67 -> Pg=18.28, Qg=4.955
% INFO    : Gen at bus 23351	: Vg=0.9975 -> Vg=1.0
% INFO    : Gen at bus 23351	: Pg=24.8, Qg=12.67 -> Pg=17.67, Qg=4.955
% INFO    : Gen at bus 23351	: Vg=0.9975 -> Vg=1.0
% INFO    : Gen at bus 23352	: Pg=23.9, Qg=12.22 -> Pg=13.825, Qg=4.78
% INFO    : Gen at bus 23352	: Vg=0.9958 -> Vg=1.0
% INFO    : Gen at bus 23353	: Pg=0.0, Qg=0.0 -> Pg=20.87, Qg=6.28
% INFO    : Gen at bus 23353	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23353	: Pg=33.78, Qg=-1.84 -> Pg=33.78, Qg=6.28
% INFO    : Gen at bus 23353	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23354	: Pg=0.0, Qg=0.0 -> Pg=42.875, Qg=11.84
% INFO    : Gen at bus 23354	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23354	: Pg=70.67, Qg=27.14 -> Pg=70.67, Qg=11.84
% INFO    : Gen at bus 23354	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23354	: Pg=0.0, Qg=0.0 -> Pg=42.155, Qg=11.84
% INFO    : Gen at bus 23354	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23354	: Pg=0.0, Qg=0.0 -> Pg=41.335, Qg=11.84
% INFO    : Gen at bus 23354	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23354	: Pg=0.0, Qg=0.0 -> Pg=41.785, Qg=11.84
% INFO    : Gen at bus 23354	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23354	: Pg=0.0, Qg=0.0 -> Pg=45.25, Qg=11.84
% INFO    : Gen at bus 23354	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 23360	: Pg=16.74, Qg=0.0 -> Pg=16.74, Qg=0.0
% INFO    : Gen at bus 23360	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 23361	: Pg=12.92, Qg=0.0 -> Pg=12.92, Qg=0.0
% INFO    : Gen at bus 23361	: Vg=1.0243 -> Vg=1.0
% INFO    : Gen at bus 23363	: Pg=28.55, Qg=14.4 -> Pg=28.55, Qg=6.28
% INFO    : Gen at bus 23363	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23366	: Pg=0.0, Qg=0.0 -> Pg=12.92, Qg=0.0
% INFO    : Gen at bus 23366	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23366	: Pg=17.74, Qg=0.0 -> Pg=17.74, Qg=0.0
% INFO    : Gen at bus 23366	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23367	: Pg=0.0, Qg=0.0 -> Pg=7.37, Qg=0.0
% INFO    : Gen at bus 23367	: Vg=1.0256 -> Vg=1.0
% INFO    : Gen at bus 23368	: Pg=15.05, Qg=0.0 -> Pg=15.05, Qg=0.0
% INFO    : Gen at bus 23368	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 23370	: Pg=0.0, Qg=0.0 -> Pg=10.16, Qg=2.275
% INFO    : Gen at bus 23370	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23370	: Pg=0.0, Qg=0.0 -> Pg=16.465, Qg=4.37
% INFO    : Gen at bus 23370	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23370	: Pg=0.0, Qg=0.0 -> Pg=15.445, Qg=4.37
% INFO    : Gen at bus 23370	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23372	: Pg=49.45, Qg=-2.69 -> Pg=49.45, Qg=9.215
% INFO    : Gen at bus 23372	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23372	: Pg=43.41, Qg=-2.69 -> Pg=43.41, Qg=9.215
% INFO    : Gen at bus 23372	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23377	: Pg=338.32, Qg=-36.04 -> Pg=515.015, Qg=139.7
% INFO    : Gen at bus 23377	: Vg=1.0215 -> Vg=1.0
% INFO    : Gen at bus 23378	: Pg=0.0, Qg=0.0 -> Pg=498.08, Qg=139.7
% INFO    : Gen at bus 23378	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 23379	: Pg=232.05, Qg=-25.86 -> Pg=163.915, Qg=46.37
% INFO    : Gen at bus 23379	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 23380	: Pg=232.05, Qg=-25.86 -> Pg=156.71, Qg=46.37
% INFO    : Gen at bus 23380	: Vg=1.022 -> Vg=1.0
% INFO    : Gen at bus 23381	: Pg=232.05, Qg=-25.86 -> Pg=151.85, Qg=46.37
% INFO    : Gen at bus 23381	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 23382	: Pg=211.44, Qg=-25.86 -> Pg=170.565, Qg=46.37
% INFO    : Gen at bus 23382	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 23383	: Pg=232.05, Qg=-25.86 -> Pg=138.595, Qg=46.37
% INFO    : Gen at bus 23383	: Vg=1.0213 -> Vg=1.0
% INFO    : Gen at bus 23384	: Pg=232.05, Qg=-25.86 -> Pg=166.595, Qg=46.37
% INFO    : Gen at bus 23384	: Vg=1.0205 -> Vg=1.0
% INFO    : Gen at bus 23385	: Pg=21.97, Qg=0.0 -> Pg=21.97, Qg=0.0
% INFO    : Gen at bus 23385	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23385	: Pg=30.0, Qg=0.0 -> Pg=30.0, Qg=0.0
% INFO    : Gen at bus 23385	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23385	: Pg=26.4, Qg=0.0 -> Pg=26.4, Qg=0.0
% INFO    : Gen at bus 23385	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23386	: Pg=49.7, Qg=-5.54 -> Pg=30.67, Qg=9.93
% INFO    : Gen at bus 23386	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 23389	: Pg=0.0, Qg=0.0 -> Pg=38.56, Qg=0.0
% INFO    : Gen at bus 23389	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23390	: Pg=0.0, Qg=0.0 -> Pg=4.94, Qg=0.0
% INFO    : Gen at bus 23390	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23390	: Pg=14.03, Qg=0.0 -> Pg=14.03, Qg=0.0
% INFO    : Gen at bus 23390	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23390	: Pg=25.0, Qg=0.0 -> Pg=25.0, Qg=0.0
% INFO    : Gen at bus 23390	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23390	: Pg=7.56, Qg=0.0 -> Pg=7.56, Qg=0.0
% INFO    : Gen at bus 23390	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23393	: Pg=32.64, Qg=14.4 -> Pg=32.64, Qg=6.28
% INFO    : Gen at bus 23393	: Vg=1.0214 -> Vg=1.0
% INFO    : Gen at bus 23396	: Pg=0.0, Qg=0.0 -> Pg=35.36, Qg=0.0
% INFO    : Gen at bus 23396	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 23399	: Pg=27.42, Qg=1.27 -> Pg=17.385, Qg=5.475
% INFO    : Gen at bus 23399	: Vg=1.0248 -> Vg=1.0
% INFO    : Gen at bus 23400	: Pg=27.42, Qg=1.27 -> Pg=18.03, Qg=5.475
% INFO    : Gen at bus 23400	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 23401	: Pg=27.42, Qg=1.27 -> Pg=18.51, Qg=5.475
% INFO    : Gen at bus 23401	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 23403	: Pg=45.81, Qg=23.41 -> Pg=26.295, Qg=9.15
% INFO    : Gen at bus 23403	: Vg=1.0049 -> Vg=1.0
% INFO    : Gen at bus 23405	: Pg=47.11, Qg=-5.25 -> Pg=34.46, Qg=9.415
% INFO    : Gen at bus 23405	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23406	: Pg=60.25, Qg=30.79 -> Pg=44.445, Qg=12.035
% INFO    : Gen at bus 23406	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23406	: Pg=60.25, Qg=30.79 -> Pg=36.505, Qg=12.035
% INFO    : Gen at bus 23406	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23411	: Pg=150.67, Qg=76.72 -> Pg=150.67, Qg=33.465
% INFO    : Gen at bus 23411	: Vg=1.0473 -> Vg=1.0
% INFO    : Gen at bus 23417	: Pg=291.98, Qg=42.4 -> Pg=291.98, Qg=58.79
% INFO    : Gen at bus 23417	: Vg=1.0349 -> Vg=1.0
% INFO    : Gen at bus 23418	: Pg=351.0, Qg=42.4 -> Pg=351.0, Qg=58.79
% INFO    : Gen at bus 23418	: Vg=1.0359 -> Vg=1.0
% INFO    : Gen at bus 23419	: Pg=346.13, Qg=42.4 -> Pg=346.13, Qg=58.79
% INFO    : Gen at bus 23419	: Vg=1.0337 -> Vg=1.0
% INFO    : Gen at bus 23421	: Pg=49.3, Qg=25.2 -> Pg=32.97, Qg=9.855
% INFO    : Gen at bus 23421	: Vg=1.0365 -> Vg=1.0
% INFO    : Gen at bus 23422	: Pg=38.24, Qg=4.01 -> Pg=27.11, Qg=7.645
% INFO    : Gen at bus 23422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23423	: Pg=81.9, Qg=31.45 -> Pg=81.9, Qg=13.72
% INFO    : Gen at bus 23423	: Vg=1.0385 -> Vg=1.0
% INFO    : Gen at bus 23425	: Pg=45.91, Qg=-5.12 -> Pg=32.815, Qg=9.17
% INFO    : Gen at bus 23425	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23426	: Pg=45.91, Qg=23.46 -> Pg=29.635, Qg=9.17
% INFO    : Gen at bus 23426	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 23434	: Pg=184.25, Qg=-9.82 -> Pg=121.715, Qg=36.815
% INFO    : Gen at bus 23434	: Vg=1.0239 -> Vg=1.0
% INFO    : Gen at bus 23435	: Pg=103.48, Qg=-9.82 -> Pg=58.01, Qg=20.68
% INFO    : Gen at bus 23435	: Vg=1.0236 -> Vg=1.0
% INFO    : Gen at bus 23436	: Pg=0.0, Qg=0.0 -> Pg=37.825, Qg=9.215
% INFO    : Gen at bus 23436	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23436	: Pg=51.3, Qg=-2.69 -> Pg=51.3, Qg=9.215
% INFO    : Gen at bus 23436	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23436	: Pg=33.47, Qg=-2.69 -> Pg=33.47, Qg=9.215
% INFO    : Gen at bus 23436	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23438	: Pg=8.02, Qg=0.0 -> Pg=8.02, Qg=0.0
% INFO    : Gen at bus 23438	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23438	: Pg=14.77, Qg=0.0 -> Pg=14.77, Qg=0.0
% INFO    : Gen at bus 23438	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23438	: Pg=12.75, Qg=0.0 -> Pg=12.75, Qg=0.0
% INFO    : Gen at bus 23438	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23438	: Pg=14.1, Qg=0.0 -> Pg=14.1, Qg=0.0
% INFO    : Gen at bus 23438	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23438	: Pg=12.58, Qg=0.0 -> Pg=12.58, Qg=0.0
% INFO    : Gen at bus 23438	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23441	: Pg=0.0, Qg=0.0 -> Pg=8.53, Qg=0.0
% INFO    : Gen at bus 23441	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23441	: Pg=8.83, Qg=0.0 -> Pg=8.83, Qg=0.0
% INFO    : Gen at bus 23441	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23441	: Pg=0.0, Qg=0.0 -> Pg=19.735, Qg=0.0
% INFO    : Gen at bus 23441	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23445	: Pg=99.79, Qg=51.0 -> Pg=59.03, Qg=19.94
% INFO    : Gen at bus 23445	: Vg=0.995 -> Vg=1.0
% INFO    : Gen at bus 23446	: Pg=99.79, Qg=51.0 -> Pg=71.27, Qg=19.94
% INFO    : Gen at bus 23446	: Vg=0.992 -> Vg=1.0
% INFO    : Gen at bus 23447	: Pg=99.79, Qg=51.0 -> Pg=58.37, Qg=19.94
% INFO    : Gen at bus 23447	: Vg=0.9897 -> Vg=1.0
% INFO    : Gen at bus 23449	: Pg=60.25, Qg=30.79 -> Pg=40.895, Qg=12.035
% INFO    : Gen at bus 23449	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 23453	: Pg=91.83, Qg=-7.35 -> Pg=91.83, Qg=25.125
% INFO    : Gen at bus 23453	: Vg=1.0228 -> Vg=1.0
% INFO    : Gen at bus 23454	: Pg=132.32, Qg=-7.35 -> Pg=132.32, Qg=25.125
% INFO    : Gen at bus 23454	: Vg=1.0227 -> Vg=1.0
% INFO    : Gen at bus 23455	: Pg=5.79, Qg=-0.4 -> Pg=5.79, Qg=1.35
% INFO    : Gen at bus 23455	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 23456	: Pg=5.85, Qg=-0.4 -> Pg=5.85, Qg=1.35
% INFO    : Gen at bus 23456	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 23456	: Pg=5.83, Qg=-0.4 -> Pg=5.83, Qg=1.35
% INFO    : Gen at bus 23456	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 23459	: Pg=14.45, Qg=-0.81 -> Pg=14.45, Qg=2.78
% INFO    : Gen at bus 23459	: Vg=1.0189 -> Vg=1.0
% INFO    : Gen at bus 23460	: Pg=0.0, Qg=0.0 -> Pg=9.5, Qg=2.78
% INFO    : Gen at bus 23460	: Vg=1.0199 -> Vg=1.0
% INFO    : Gen at bus 23462	: Pg=11.65, Qg=-0.81 -> Pg=11.65, Qg=2.78
% INFO    : Gen at bus 23462	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 23463	: Pg=11.03, Qg=-0.81 -> Pg=11.03, Qg=2.78
% INFO    : Gen at bus 23463	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 23469	: Pg=0.0, Qg=0.0 -> Pg=6.08, Qg=1.51
% INFO    : Gen at bus 23469	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23469	: Pg=0.0, Qg=0.0 -> Pg=65.08, Qg=15.83
% INFO    : Gen at bus 23469	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23471	: Pg=38.74, Qg=-4.32 -> Pg=23.615, Qg=7.74
% INFO    : Gen at bus 23471	: Vg=1.0362 -> Vg=1.0
% INFO    : Gen at bus 23477	: Pg=50.2, Qg=25.65 -> Pg=27.96, Qg=25.65
% INFO    : Gen at bus 23477	: Vg=1.0025 -> Vg=1.0
% INFO    : Gen at bus 23478	: Pg=48.9, Qg=14.38 -> Pg=29.985, Qg=9.77
% INFO    : Gen at bus 23478	: Vg=0.9935 -> Vg=1.0
% INFO    : Gen at bus 23478	: Pg=48.9, Qg=14.38 -> Pg=27.945, Qg=9.77
% INFO    : Gen at bus 23478	: Vg=0.9935 -> Vg=1.0
% INFO    : Gen at bus 23479	: Pg=8.37, Qg=4.28 -> Pg=6.25, Qg=1.675
% INFO    : Gen at bus 23479	: Vg=0.9997 -> Vg=1.0
% INFO    : Gen at bus 23479	: Pg=0.0, Qg=0.0 -> Pg=5.42, Qg=1.675
% INFO    : Gen at bus 23479	: Vg=0.9997 -> Vg=1.0
% INFO    : Gen at bus 23480	: Pg=0.0, Qg=0.0 -> Pg=5.8, Qg=1.675
% INFO    : Gen at bus 23480	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 23480	: Pg=0.0, Qg=0.0 -> Pg=6.02, Qg=1.675
% INFO    : Gen at bus 23480	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 23481	: Pg=0.0, Qg=0.0 -> Pg=5.05, Qg=1.675
% INFO    : Gen at bus 23481	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 23481	: Pg=0.0, Qg=0.0 -> Pg=5.645, Qg=1.675
% INFO    : Gen at bus 23481	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 23484	: Pg=31.0, Qg=-1.52 -> Pg=31.0, Qg=5.19
% INFO    : Gen at bus 23484	: Vg=1.0338 -> Vg=1.0
% INFO    : Gen at bus 23485	: Pg=40.94, Qg=-2.38 -> Pg=40.94, Qg=8.14
% INFO    : Gen at bus 23485	: Vg=1.0337 -> Vg=1.0
% INFO    : Gen at bus 23487	: Pg=33.45, Qg=-2.38 -> Pg=33.45, Qg=8.14
% INFO    : Gen at bus 23487	: Vg=1.0315 -> Vg=1.0
% INFO    : Gen at bus 23490	: Pg=12.81, Qg=0.45 -> Pg=12.81, Qg=3.515
% INFO    : Gen at bus 23490	: Vg=0.9772 -> Vg=1.0
% INFO    : Gen at bus 23491	: Pg=21.0, Qg=0.45 -> Pg=21.0, Qg=3.515
% INFO    : Gen at bus 23491	: Vg=0.9773 -> Vg=1.0
% INFO    : Gen at bus 23493	: Pg=95.0, Qg=36.48 -> Pg=95.0, Qg=15.915
% INFO    : Gen at bus 23493	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23493	: Pg=95.0, Qg=36.48 -> Pg=95.0, Qg=15.915
% INFO    : Gen at bus 23493	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 23495	: Pg=0.0, Qg=0.0 -> Pg=5.03, Qg=1.645
% INFO    : Gen at bus 23495	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23495	: Pg=0.0, Qg=0.0 -> Pg=5.41, Qg=1.645
% INFO    : Gen at bus 23495	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23495	: Pg=8.23, Qg=4.21 -> Pg=5.945, Qg=1.645
% INFO    : Gen at bus 23495	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23495	: Pg=0.0, Qg=0.0 -> Pg=5.03, Qg=1.645
% INFO    : Gen at bus 23495	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23495	: Pg=0.0, Qg=0.0 -> Pg=5.16, Qg=1.645
% INFO    : Gen at bus 23495	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23495	: Pg=0.0, Qg=0.0 -> Pg=4.95, Qg=1.645
% INFO    : Gen at bus 23495	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 23499	: Pg=69.62, Qg=-7.76 -> Pg=48.035, Qg=13.91
% INFO    : Gen at bus 23499	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23499	: Pg=69.62, Qg=-7.76 -> Pg=48.69, Qg=13.91
% INFO    : Gen at bus 23499	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 23501	: Pg=27.85, Qg=-2.09 -> Pg=27.85, Qg=7.155
% INFO    : Gen at bus 23501	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 23501	: Pg=36.51, Qg=-2.09 -> Pg=36.51, Qg=7.155
% INFO    : Gen at bus 23501	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 23502	: Pg=0.0, Qg=0.0 -> Pg=31.545, Qg=7.155
% INFO    : Gen at bus 23502	: Vg=1.0298 -> Vg=1.0
% INFO    : Gen at bus 23503	: Pg=27.91, Qg=-2.09 -> Pg=27.91, Qg=7.155
% INFO    : Gen at bus 23503	: Vg=1.0292 -> Vg=1.0
% INFO    : Gen at bus 23510	: Pg=228.54, Qg=16.42 -> Pg=157.48, Qg=45.665
% INFO    : Gen at bus 23510	: Vg=1.0274 -> Vg=1.0
% INFO    : Gen at bus 23511	: Pg=228.53, Qg=16.42 -> Pg=157.265, Qg=45.665
% INFO    : Gen at bus 23511	: Vg=1.0278 -> Vg=1.0
% INFO    : Gen at bus 23512	: Pg=116.53, Qg=16.42 -> Pg=171.32, Qg=45.665
% INFO    : Gen at bus 23512	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 23513	: Pg=0.0, Qg=0.0 -> Pg=5.41, Qg=1.495
% INFO    : Gen at bus 23513	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 25829	: Pg=0.0, Qg=0.0 -> Pg=477.79, Qg=160.39
% INFO    : Gen at bus 25829	: Vg=1.0256 -> Vg=1.0
% INFO    : Gen at bus 25830	: Pg=802.73, Qg=410.25 -> Pg=563.23, Qg=160.39
% INFO    : Gen at bus 25830	: Vg=1.0436 -> Vg=1.0
% INFO    : Gen at bus 25831	: Pg=28.88, Qg=14.76 -> Pg=16.43, Qg=5.77
% INFO    : Gen at bus 25831	: Vg=1.0269 -> Vg=1.0
% INFO    : Gen at bus 25834	: Pg=136.12, Qg=40.26 -> Pg=136.12, Qg=6.52
% INFO    : Gen at bus 25834	: Vg=1.0426 -> Vg=1.0
% INFO    : Gen at bus 25835	: Pg=60.0, Qg=-8.64 -> Pg=60.0, Qg=2.07
% INFO    : Gen at bus 25835	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25837	: Pg=0.0, Qg=0.0 -> Pg=16.505, Qg=5.55
% INFO    : Gen at bus 25837	: Vg=1.0327 -> Vg=1.0
% INFO    : Gen at bus 25837	: Pg=27.79, Qg=14.2 -> Pg=18.46, Qg=5.55
% INFO    : Gen at bus 25837	: Vg=1.0327 -> Vg=1.0
% INFO    : Gen at bus 25839	: Pg=0.0, Qg=0.0 -> Pg=38.105, Qg=0.0
% INFO    : Gen at bus 25839	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25840	: Pg=34.21, Qg=17.48 -> Pg=21.705, Qg=6.835
% INFO    : Gen at bus 25840	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 25840	: Pg=34.21, Qg=17.48 -> Pg=21.03, Qg=6.835
% INFO    : Gen at bus 25840	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 25843	: Pg=49.96, Qg=0.0 -> Pg=49.96, Qg=0.0
% INFO    : Gen at bus 25843	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25844	: Pg=40.07, Qg=0.0 -> Pg=40.07, Qg=0.0
% INFO    : Gen at bus 25844	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25844	: Pg=0.0, Qg=0.0 -> Pg=35.475, Qg=0.0
% INFO    : Gen at bus 25844	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25845	: Pg=0.0, Qg=0.0 -> Pg=36.115, Qg=0.0
% INFO    : Gen at bus 25845	: Vg=1.0359 -> Vg=1.0
% INFO    : Gen at bus 25846	: Pg=39.48, Qg=0.0 -> Pg=39.48, Qg=0.0
% INFO    : Gen at bus 25846	: Vg=1.0361 -> Vg=1.0
% INFO    : Gen at bus 25852	: Pg=103.16, Qg=32.31 -> Pg=103.16, Qg=5.235
% INFO    : Gen at bus 25852	: Vg=1.0039 -> Vg=1.0
% INFO    : Gen at bus 25854	: Pg=31.9, Qg=0.0 -> Pg=31.9, Qg=0.0
% INFO    : Gen at bus 25854	: Vg=1.0368 -> Vg=1.0
% INFO    : Gen at bus 25855	: Pg=0.0, Qg=0.0 -> Pg=23.095, Qg=0.0
% INFO    : Gen at bus 25855	: Vg=1.0364 -> Vg=1.0
% INFO    : Gen at bus 25857	: Pg=57.17, Qg=-6.37 -> Pg=40.3, Qg=11.425
% INFO    : Gen at bus 25857	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 25863	: Pg=0.0, Qg=0.0 -> Pg=89.055, Qg=4.66
% INFO    : Gen at bus 25863	: Vg=1.0357 -> Vg=1.0
% INFO    : Gen at bus 25867	: Pg=111.8, Qg=31.95 -> Pg=111.8, Qg=5.175
% INFO    : Gen at bus 25867	: Vg=1.0083 -> Vg=1.0
% INFO    : Gen at bus 25868	: Pg=119.0, Qg=31.95 -> Pg=119.0, Qg=5.175
% INFO    : Gen at bus 25868	: Vg=1.0084 -> Vg=1.0
% INFO    : Gen at bus 25869	: Pg=25.25, Qg=0.0 -> Pg=25.25, Qg=0.0
% INFO    : Gen at bus 25869	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25871	: Pg=20.64, Qg=0.0 -> Pg=20.64, Qg=0.0
% INFO    : Gen at bus 25871	: Vg=1.0332 -> Vg=1.0
% INFO    : Gen at bus 25872	: Pg=26.08, Qg=0.0 -> Pg=26.08, Qg=0.0
% INFO    : Gen at bus 25872	: Vg=1.0332 -> Vg=1.0
% INFO    : Gen at bus 25874	: Pg=0.0, Qg=0.0 -> Pg=39.935, Qg=13.435
% INFO    : Gen at bus 25874	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25874	: Pg=67.23, Qg=-7.49 -> Pg=48.59, Qg=13.435
% INFO    : Gen at bus 25874	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25874	: Pg=67.23, Qg=-7.49 -> Pg=49.78, Qg=13.435
% INFO    : Gen at bus 25874	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25874	: Pg=67.23, Qg=-7.49 -> Pg=41.79, Qg=13.435
% INFO    : Gen at bus 25874	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25874	: Pg=67.23, Qg=-7.49 -> Pg=49.34, Qg=13.435
% INFO    : Gen at bus 25874	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25874	: Pg=67.23, Qg=-7.49 -> Pg=40.925, Qg=13.435
% INFO    : Gen at bus 25874	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25875	: Pg=0.0, Qg=0.0 -> Pg=8.155, Qg=2.39
% INFO    : Gen at bus 25875	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25876	: Pg=99.59, Qg=50.9 -> Pg=69.065, Qg=19.9
% INFO    : Gen at bus 25876	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25876	: Pg=99.59, Qg=50.9 -> Pg=61.21, Qg=19.9
% INFO    : Gen at bus 25876	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25876	: Pg=99.59, Qg=50.9 -> Pg=59.46, Qg=19.9
% INFO    : Gen at bus 25876	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25876	: Pg=99.59, Qg=50.9 -> Pg=70.755, Qg=19.9
% INFO    : Gen at bus 25876	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25876	: Pg=99.59, Qg=50.9 -> Pg=65.72, Qg=19.9
% INFO    : Gen at bus 25876	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25881	: Pg=57.76, Qg=-6.44 -> Pg=41.825, Qg=11.54
% INFO    : Gen at bus 25881	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 25887	: Pg=0.0, Qg=0.0 -> Pg=155.07, Qg=0.0
% INFO    : Gen at bus 25887	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 25889	: Pg=74.7, Qg=38.17 -> Pg=47.275, Qg=14.92
% INFO    : Gen at bus 25889	: Vg=1.0066 -> Vg=1.0
% INFO    : Gen at bus 25890	: Pg=30.83, Qg=0.0 -> Pg=30.83, Qg=0.0
% INFO    : Gen at bus 25890	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25892	: Pg=49.6, Qg=-5.53 -> Pg=30.075, Qg=9.91
% INFO    : Gen at bus 25892	: Vg=1.0381 -> Vg=1.0
% INFO    : Gen at bus 25896	: Pg=0.0, Qg=0.0 -> Pg=70.32, Qg=0.0
% INFO    : Gen at bus 25896	: Vg=1.0341 -> Vg=1.0
% INFO    : Gen at bus 25899	: Pg=15.56, Qg=4.26 -> Pg=15.56, Qg=0.76
% INFO    : Gen at bus 25899	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25899	: Pg=58.87, Qg=4.26 -> Pg=58.87, Qg=2.655
% INFO    : Gen at bus 25899	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25900	: Pg=0.0, Qg=0.0 -> Pg=14.335, Qg=0.0
% INFO    : Gen at bus 25900	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25900	: Pg=15.99, Qg=0.0 -> Pg=15.99, Qg=0.0
% INFO    : Gen at bus 25900	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25904	: Pg=155.17, Qg=36.64 -> Pg=113.41, Qg=31.005
% INFO    : Gen at bus 25904	: Vg=0.9983 -> Vg=1.0
% INFO    : Gen at bus 25905	: Pg=155.17, Qg=36.64 -> Pg=106.555, Qg=31.005
% INFO    : Gen at bus 25905	: Vg=0.9984 -> Vg=1.0
% INFO    : Gen at bus 25906	: Pg=155.17, Qg=36.64 -> Pg=110.99, Qg=31.005
% INFO    : Gen at bus 25906	: Vg=0.9973 -> Vg=1.0
% INFO    : Gen at bus 25907	: Pg=155.17, Qg=36.64 -> Pg=86.92, Qg=31.005
% INFO    : Gen at bus 25907	: Vg=0.9984 -> Vg=1.0
% INFO    : Gen at bus 25908	: Pg=155.17, Qg=36.64 -> Pg=114.62, Qg=31.005
% INFO    : Gen at bus 25908	: Vg=0.9973 -> Vg=1.0
% INFO    : Gen at bus 25911	: Pg=0.0, Qg=0.0 -> Pg=27.49, Qg=6.57
% INFO    : Gen at bus 25911	: Vg=1.0336 -> Vg=1.0
% INFO    : Gen at bus 25914	: Pg=23.21, Qg=7.31 -> Pg=12.995, Qg=4.635
% INFO    : Gen at bus 25914	: Vg=1.0607 -> Vg=1.0
% INFO    : Gen at bus 25914	: Pg=23.21, Qg=7.31 -> Pg=14.995, Qg=4.635
% INFO    : Gen at bus 25914	: Vg=1.0607 -> Vg=1.0
% INFO    : Gen at bus 25915	: Pg=10.22, Qg=-1.14 -> Pg=7.55, Qg=2.045
% INFO    : Gen at bus 25915	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 25915	: Pg=10.23, Qg=-1.14 -> Pg=7.17, Qg=2.045
% INFO    : Gen at bus 25915	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 25915	: Pg=0.0, Qg=0.0 -> Pg=6.92, Qg=2.045
% INFO    : Gen at bus 25915	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 25915	: Pg=24.3, Qg=-2.71 -> Pg=15.195, Qg=4.855
% INFO    : Gen at bus 25915	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 25915	: Pg=24.3, Qg=-2.71 -> Pg=15.485, Qg=4.855
% INFO    : Gen at bus 25915	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 25916	: Pg=60.25, Qg=30.79 -> Pg=34.935, Qg=12.035
% INFO    : Gen at bus 25916	: Vg=1.0405 -> Vg=1.0
% INFO    : Gen at bus 25917	: Pg=23.84, Qg=6.18 -> Pg=23.84, Qg=1.0
% INFO    : Gen at bus 25917	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 25917	: Pg=0.0, Qg=0.0 -> Pg=26.385, Qg=1.615
% INFO    : Gen at bus 25917	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 25918	: Pg=7.56, Qg=0.0 -> Pg=7.56, Qg=0.0
% INFO    : Gen at bus 25918	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25918	: Pg=0.0, Qg=0.0 -> Pg=8.87, Qg=0.0
% INFO    : Gen at bus 25918	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25918	: Pg=0.0, Qg=0.0 -> Pg=13.45, Qg=0.0
% INFO    : Gen at bus 25918	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25918	: Pg=14.31, Qg=0.0 -> Pg=14.31, Qg=0.0
% INFO    : Gen at bus 25918	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25923	: Pg=133.8, Qg=49.95 -> Pg=91.735, Qg=26.735
% INFO    : Gen at bus 25923	: Vg=1.0405 -> Vg=1.0
% INFO    : Gen at bus 25924	: Pg=133.8, Qg=49.95 -> Pg=83.88, Qg=26.735
% INFO    : Gen at bus 25924	: Vg=1.0382 -> Vg=1.0
% INFO    : Gen at bus 25925	: Pg=133.8, Qg=49.95 -> Pg=96.615, Qg=26.735
% INFO    : Gen at bus 25925	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25926	: Pg=133.8, Qg=49.95 -> Pg=98.9, Qg=26.735
% INFO    : Gen at bus 25926	: Vg=1.0352 -> Vg=1.0
% INFO    : Gen at bus 25927	: Pg=35.46, Qg=-3.95 -> Pg=23.605, Qg=7.085
% INFO    : Gen at bus 25927	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 25932	: Pg=49.6, Qg=25.35 -> Pg=29.92, Qg=9.91
% INFO    : Gen at bus 25932	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 25932	: Pg=0.0, Qg=0.0 -> Pg=11.045, Qg=3.055
% INFO    : Gen at bus 25932	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 25933	: Pg=0.0, Qg=0.0 -> Pg=9.65, Qg=3.055
% INFO    : Gen at bus 25933	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 25933	: Pg=0.0, Qg=0.0 -> Pg=4.79, Qg=1.335
% INFO    : Gen at bus 25933	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 25934	: Pg=40.06, Qg=0.0 -> Pg=40.06, Qg=0.0
% INFO    : Gen at bus 25934	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25934	: Pg=0.0, Qg=0.0 -> Pg=28.735, Qg=0.0
% INFO    : Gen at bus 25934	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25934	: Pg=47.1, Qg=0.0 -> Pg=47.1, Qg=0.0
% INFO    : Gen at bus 25934	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25935	: Pg=47.1, Qg=0.0 -> Pg=47.1, Qg=0.0
% INFO    : Gen at bus 25935	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25935	: Pg=28.23, Qg=0.0 -> Pg=28.23, Qg=0.0
% INFO    : Gen at bus 25935	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25938	: Pg=340.61, Qg=-37.96 -> Pg=227.875, Qg=68.06
% INFO    : Gen at bus 25938	: Vg=1.0186 -> Vg=1.0
% INFO    : Gen at bus 25940	: Pg=36.05, Qg=0.0 -> Pg=36.05, Qg=0.0
% INFO    : Gen at bus 25940	: Vg=1.004 -> Vg=1.0
% INFO    : Gen at bus 25940	: Pg=10.64, Qg=0.0 -> Pg=10.64, Qg=0.0
% INFO    : Gen at bus 25940	: Vg=1.004 -> Vg=1.0
% INFO    : Gen at bus 25941	: Pg=0.0, Qg=0.0 -> Pg=5.1, Qg=0.0
% INFO    : Gen at bus 25941	: Vg=1.0344 -> Vg=1.0
% INFO    : Gen at bus 25943	: Pg=48.3, Qg=22.21 -> Pg=32.925, Qg=9.655
% INFO    : Gen at bus 25943	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 25944	: Pg=12.29, Qg=-0.85 -> Pg=12.29, Qg=2.9
% INFO    : Gen at bus 25944	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 25944	: Pg=17.33, Qg=-0.85 -> Pg=17.33, Qg=2.9
% INFO    : Gen at bus 25944	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 25944	: Pg=13.8, Qg=-0.85 -> Pg=13.8, Qg=2.9
% INFO    : Gen at bus 25944	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 25944	: Pg=0.0, Qg=0.0 -> Pg=10.25, Qg=2.9
% INFO    : Gen at bus 25944	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 25947	: Pg=5.97, Qg=-1.24 -> Pg=5.97, Qg=0.3
% INFO    : Gen at bus 25947	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 25948	: Pg=8.62, Qg=-1.24 -> Pg=8.62, Qg=0.3
% INFO    : Gen at bus 25948	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 25950	: Pg=30.0, Qg=-4.32 -> Pg=30.0, Qg=1.035
% INFO    : Gen at bus 25950	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 25950	: Pg=27.18, Qg=-4.32 -> Pg=27.18, Qg=1.035
% INFO    : Gen at bus 25950	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 25951	: Pg=24.36, Qg=-4.18 -> Pg=24.36, Qg=1.0
% INFO    : Gen at bus 25951	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 25951	: Pg=22.85, Qg=-4.13 -> Pg=22.85, Qg=0.99
% INFO    : Gen at bus 25951	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 25952	: Pg=0.0, Qg=0.0 -> Pg=14.32, Qg=0.86
% INFO    : Gen at bus 25952	: Vg=1.0275 -> Vg=1.0
% INFO    : Gen at bus 25953	: Pg=20.34, Qg=-3.38 -> Pg=20.34, Qg=0.815
% INFO    : Gen at bus 25953	: Vg=1.0076 -> Vg=1.0
% INFO    : Gen at bus 25954	: Pg=20.43, Qg=-3.24 -> Pg=20.43, Qg=0.775
% INFO    : Gen at bus 25954	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 25954	: Pg=6.92, Qg=-1.24 -> Pg=6.92, Qg=0.3
% INFO    : Gen at bus 25954	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 25955	: Pg=0.0, Qg=0.0 -> Pg=6.385, Qg=0.3
% INFO    : Gen at bus 25955	: Vg=1.0275 -> Vg=1.0
% INFO    : Gen at bus 25957	: Pg=7.4, Qg=-1.07 -> Pg=7.4, Qg=0.255
% INFO    : Gen at bus 25957	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 25957	: Pg=5.83, Qg=-1.58 -> Pg=5.83, Qg=0.375
% INFO    : Gen at bus 25957	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 25957	: Pg=9.43, Qg=-1.58 -> Pg=9.43, Qg=0.375
% INFO    : Gen at bus 25957	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 25957	: Pg=0.0, Qg=0.0 -> Pg=8.25, Qg=0.485
% INFO    : Gen at bus 25957	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 25957	: Pg=0.0, Qg=0.0 -> Pg=11.455, Qg=0.635
% INFO    : Gen at bus 25957	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 25957	: Pg=0.0, Qg=0.0 -> Pg=13.345, Qg=0.735
% INFO    : Gen at bus 25957	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 25960	: Pg=24.8, Qg=12.67 -> Pg=18.625, Qg=4.955
% INFO    : Gen at bus 25960	: Vg=1.0634 -> Vg=1.0
% INFO    : Gen at bus 25961	: Pg=24.8, Qg=12.67 -> Pg=17.565, Qg=4.955
% INFO    : Gen at bus 25961	: Vg=1.0507 -> Vg=1.0
% INFO    : Gen at bus 25963	: Pg=24.8, Qg=-2.76 -> Pg=15.115, Qg=4.955
% INFO    : Gen at bus 25963	: Vg=0.9974 -> Vg=1.0
% INFO    : Gen at bus 25964	: Pg=24.8, Qg=-2.76 -> Pg=15.825, Qg=4.955
% INFO    : Gen at bus 25964	: Vg=0.9974 -> Vg=1.0
% INFO    : Gen at bus 25968	: Pg=109.85, Qg=19.83 -> Pg=109.85, Qg=4.14
% INFO    : Gen at bus 25968	: Vg=0.9968 -> Vg=1.0
% INFO    : Gen at bus 25969	: Pg=0.0, Qg=0.0 -> Pg=10.165, Qg=0.555
% INFO    : Gen at bus 25969	: Vg=0.9951 -> Vg=1.0
% INFO    : Gen at bus 25969	: Pg=5.27, Qg=1.6 -> Pg=5.27, Qg=0.26
% INFO    : Gen at bus 25969	: Vg=0.9951 -> Vg=1.0
% INFO    : Gen at bus 25970	: Pg=4.64, Qg=1.47 -> Pg=4.64, Qg=0.24
% INFO    : Gen at bus 25970	: Vg=0.9968 -> Vg=1.0
% INFO    : Gen at bus 25972	: Pg=62.74, Qg=-6.99 -> Pg=46.42, Qg=12.54
% INFO    : Gen at bus 25972	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25972	: Pg=62.74, Qg=-6.99 -> Pg=44.335, Qg=12.54
% INFO    : Gen at bus 25972	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25972	: Pg=62.74, Qg=-6.99 -> Pg=39.59, Qg=12.54
% INFO    : Gen at bus 25972	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25972	: Pg=62.74, Qg=-6.99 -> Pg=40.57, Qg=12.54
% INFO    : Gen at bus 25972	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 25975	: Pg=132.0, Qg=-19.01 -> Pg=132.0, Qg=4.555
% INFO    : Gen at bus 25975	: Vg=1.0151 -> Vg=1.0
% INFO    : Gen at bus 25977	: Pg=15.0, Qg=3.2 -> Pg=15.0, Qg=0.52
% INFO    : Gen at bus 25977	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25977	: Pg=27.1, Qg=5.77 -> Pg=27.1, Qg=0.935
% INFO    : Gen at bus 25977	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25978	: Pg=0.0, Qg=0.0 -> Pg=22.175, Qg=0.0
% INFO    : Gen at bus 25978	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25980	: Pg=24.8, Qg=-2.76 -> Pg=14.24, Qg=4.955
% INFO    : Gen at bus 25980	: Vg=1.0274 -> Vg=1.0
% INFO    : Gen at bus 25980	: Pg=24.8, Qg=-2.76 -> Pg=16.06, Qg=4.955
% INFO    : Gen at bus 25980	: Vg=1.0274 -> Vg=1.0
% INFO    : Gen at bus 25982	: Pg=24.55, Qg=12.55 -> Pg=18.03, Qg=4.905
% INFO    : Gen at bus 25982	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 25982	: Pg=24.55, Qg=12.55 -> Pg=15.105, Qg=4.905
% INFO    : Gen at bus 25982	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 25984	: Pg=44.47, Qg=-4.96 -> Pg=32.76, Qg=8.885
% INFO    : Gen at bus 25984	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25984	: Pg=44.47, Qg=-4.96 -> Pg=29.38, Qg=8.885
% INFO    : Gen at bus 25984	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 25985	: Pg=44.47, Qg=-4.96 -> Pg=26.805, Qg=8.885
% INFO    : Gen at bus 25985	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25985	: Pg=44.47, Qg=-4.96 -> Pg=30.17, Qg=8.885
% INFO    : Gen at bus 25985	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=60.25, Qg=-6.72 -> Pg=37.855, Qg=12.035
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=60.25, Qg=-6.72 -> Pg=33.53, Qg=12.035
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=60.25, Qg=-6.72 -> Pg=42.54, Qg=12.035
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=60.25, Qg=-6.72 -> Pg=39.28, Qg=12.035
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=60.25, Qg=-6.72 -> Pg=38.1, Qg=12.035
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=81.53, Qg=-9.09 -> Pg=59.63, Qg=16.29
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=81.54, Qg=-9.09 -> Pg=48.89, Qg=16.29
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25987	: Pg=81.53, Qg=-9.09 -> Pg=55.815, Qg=16.29
% INFO    : Gen at bus 25987	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 25991	: Pg=5.56, Qg=0.0 -> Pg=5.56, Qg=0.0
% INFO    : Gen at bus 25991	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25991	: Pg=0.0, Qg=0.0 -> Pg=12.52, Qg=0.0
% INFO    : Gen at bus 25991	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25991	: Pg=15.72, Qg=0.0 -> Pg=15.72, Qg=0.0
% INFO    : Gen at bus 25991	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25991	: Pg=12.76, Qg=0.0 -> Pg=12.76, Qg=0.0
% INFO    : Gen at bus 25991	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25995	: Pg=129.41, Qg=-21.6 -> Pg=129.41, Qg=5.175
% INFO    : Gen at bus 25995	: Vg=0.9616 -> Vg=1.0
% INFO    : Gen at bus 25996	: Pg=0.0, Qg=0.0 -> Pg=40.055, Qg=2.055
% INFO    : Gen at bus 25996	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25998	: Pg=45.81, Qg=23.41 -> Pg=29.155, Qg=9.15
% INFO    : Gen at bus 25998	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 25999	: Pg=0.0, Qg=0.0 -> Pg=6.84, Qg=2.39
% INFO    : Gen at bus 25999	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25999	: Pg=52.71, Qg=-5.88 -> Pg=33.04, Qg=10.53
% INFO    : Gen at bus 25999	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25999	: Pg=52.72, Qg=-5.88 -> Pg=39.18, Qg=10.53
% INFO    : Gen at bus 25999	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 25999	: Pg=52.72, Qg=-5.88 -> Pg=38.27, Qg=10.53
% INFO    : Gen at bus 25999	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26000	: Pg=12.35, Qg=-1.38 -> Pg=7.505, Qg=2.465
% INFO    : Gen at bus 26000	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26000	: Pg=22.01, Qg=-2.45 -> Pg=13.46, Qg=4.4
% INFO    : Gen at bus 26000	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26004	: Pg=135.75, Qg=-21.6 -> Pg=135.75, Qg=5.175
% INFO    : Gen at bus 26004	: Vg=1.0115 -> Vg=1.0
% INFO    : Gen at bus 26006	: Pg=0.0, Qg=0.0 -> Pg=8.695, Qg=3.09
% INFO    : Gen at bus 26006	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 26006	: Pg=15.49, Qg=-1.73 -> Pg=9.46, Qg=3.09
% INFO    : Gen at bus 26006	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 26006	: Pg=48.3, Qg=-5.38 -> Pg=34.045, Qg=9.655
% INFO    : Gen at bus 26006	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 26009	: Pg=0.0, Qg=0.0 -> Pg=10.31, Qg=3.58
% INFO    : Gen at bus 26009	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 26009	: Pg=17.93, Qg=9.16 -> Pg=11.21, Qg=3.58
% INFO    : Gen at bus 26009	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 26012	: Pg=90.81, Qg=35.78 -> Pg=90.81, Qg=5.795
% INFO    : Gen at bus 26012	: Vg=1.0091 -> Vg=1.0
% INFO    : Gen at bus 26013	: Pg=0.0, Qg=0.0 -> Pg=32.755, Qg=9.15
% INFO    : Gen at bus 26013	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26017	: Pg=327.76, Qg=167.51 -> Pg=206.33, Qg=65.49
% INFO    : Gen at bus 26017	: Vg=1.0389 -> Vg=1.0
% INFO    : Gen at bus 26018	: Pg=327.76, Qg=167.51 -> Pg=246.02, Qg=65.49
% INFO    : Gen at bus 26018	: Vg=1.0414 -> Vg=1.0
% INFO    : Gen at bus 26019	: Pg=327.76, Qg=167.51 -> Pg=220.855, Qg=65.49
% INFO    : Gen at bus 26019	: Vg=1.0403 -> Vg=1.0
% INFO    : Gen at bus 26020	: Pg=327.76, Qg=167.51 -> Pg=212.385, Qg=65.49
% INFO    : Gen at bus 26020	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 26023	: Pg=0.0, Qg=0.0 -> Pg=6.19, Qg=2.11
% INFO    : Gen at bus 26023	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 26023	: Pg=45.81, Qg=-5.11 -> Pg=28.03, Qg=9.15
% INFO    : Gen at bus 26023	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 26026	: Pg=14.28, Qg=-1.59 -> Pg=9.925, Qg=2.855
% INFO    : Gen at bus 26026	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26026	: Pg=0.0, Qg=0.0 -> Pg=9.705, Qg=2.855
% INFO    : Gen at bus 26026	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26026	: Pg=0.0, Qg=0.0 -> Pg=10.165, Qg=2.855
% INFO    : Gen at bus 26026	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26029	: Pg=0.0, Qg=0.0 -> Pg=21.96, Qg=5.975
% INFO    : Gen at bus 26029	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 26029	: Pg=29.9, Qg=-3.33 -> Pg=17.83, Qg=5.975
% INFO    : Gen at bus 26029	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 26029	: Pg=29.9, Qg=-3.33 -> Pg=17.2, Qg=5.975
% INFO    : Gen at bus 26029	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 26029	: Pg=29.89, Qg=-3.33 -> Pg=19.78, Qg=5.975
% INFO    : Gen at bus 26029	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 26030	: Pg=29.89, Qg=-3.33 -> Pg=21.43, Qg=5.975
% INFO    : Gen at bus 26030	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 26031	: Pg=29.89, Qg=-3.33 -> Pg=19.68, Qg=5.975
% INFO    : Gen at bus 26031	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 26034	: Pg=45.81, Qg=23.41 -> Pg=31.825, Qg=9.15
% INFO    : Gen at bus 26034	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 26038	: Pg=217.11, Qg=89.51 -> Pg=135.935, Qg=43.38
% INFO    : Gen at bus 26038	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 26039	: Pg=217.11, Qg=89.51 -> Pg=161.92, Qg=43.38
% INFO    : Gen at bus 26039	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 26040	: Pg=137.44, Qg=70.24 -> Pg=89.05, Qg=27.46
% INFO    : Gen at bus 26040	: Vg=1.0291 -> Vg=1.0
% INFO    : Gen at bus 26042	: Pg=58.26, Qg=-3.35 -> Pg=42.485, Qg=11.645
% INFO    : Gen at bus 26042	: Vg=1.0194 -> Vg=1.0
% INFO    : Gen at bus 26043	: Pg=0.0, Qg=0.0 -> Pg=5.64, Qg=1.99
% INFO    : Gen at bus 26043	: Vg=1.0227 -> Vg=1.0
% INFO    : Gen at bus 26044	: Pg=54.63, Qg=26.44 -> Pg=31.715, Qg=10.915
% INFO    : Gen at bus 26044	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 26044	: Pg=54.63, Qg=26.44 -> Pg=33.155, Qg=10.915
% INFO    : Gen at bus 26044	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 26047	: Pg=108.59, Qg=7.19 -> Pg=108.59, Qg=5.175
% INFO    : Gen at bus 26047	: Vg=1.0407 -> Vg=1.0
% INFO    : Gen at bus 26051	: Pg=0.0, Qg=0.0 -> Pg=118.645, Qg=40.16
% INFO    : Gen at bus 26051	: Vg=1.0292 -> Vg=1.0
% INFO    : Gen at bus 26052	: Pg=200.98, Qg=102.72 -> Pg=119.33, Qg=40.16
% INFO    : Gen at bus 26052	: Vg=0.9905 -> Vg=1.0
% INFO    : Gen at bus 26053	: Pg=200.98, Qg=102.72 -> Pg=120.515, Qg=40.16
% INFO    : Gen at bus 26053	: Vg=0.9897 -> Vg=1.0
% INFO    : Gen at bus 26056	: Pg=45.81, Qg=-5.11 -> Pg=28.995, Qg=9.15
% INFO    : Gen at bus 26056	: Vg=0.9976 -> Vg=1.0
% INFO    : Gen at bus 26061	: Pg=209.15, Qg=106.89 -> Pg=120.59, Qg=41.79
% INFO    : Gen at bus 26061	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 26062	: Pg=0.0, Qg=0.0 -> Pg=116.535, Qg=41.79
% INFO    : Gen at bus 26062	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26063	: Pg=209.15, Qg=106.89 -> Pg=149.28, Qg=41.79
% INFO    : Gen at bus 26063	: Vg=1.0149 -> Vg=1.0
% INFO    : Gen at bus 26064	: Pg=60.25, Qg=30.79 -> Pg=43.465, Qg=12.035
% INFO    : Gen at bus 26064	: Vg=1.0167 -> Vg=1.0
% INFO    : Gen at bus 26066	: Pg=0.0, Qg=0.0 -> Pg=5.35, Qg=1.91
% INFO    : Gen at bus 26066	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 26067	: Pg=0.0, Qg=0.0 -> Pg=7.15, Qg=1.91
% INFO    : Gen at bus 26067	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 26069	: Pg=9.56, Qg=-1.07 -> Pg=5.67, Qg=1.91
% INFO    : Gen at bus 26069	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 26069	: Pg=0.0, Qg=0.0 -> Pg=6.46, Qg=1.91
% INFO    : Gen at bus 26069	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 26073	: Pg=38.54, Qg=-4.3 -> Pg=21.93, Qg=7.7
% INFO    : Gen at bus 26073	: Vg=1.0171 -> Vg=1.0
% INFO    : Gen at bus 26074	: Pg=8.76, Qg=4.48 -> Pg=5.81, Qg=1.75
% INFO    : Gen at bus 26074	: Vg=1.0296 -> Vg=1.0
% INFO    : Gen at bus 26074	: Pg=0.0, Qg=0.0 -> Pg=5.005, Qg=1.75
% INFO    : Gen at bus 26074	: Vg=1.0296 -> Vg=1.0
% INFO    : Gen at bus 26076	: Pg=14.91, Qg=-1.66 -> Pg=11.15, Qg=2.98
% INFO    : Gen at bus 26076	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 26076	: Pg=14.91, Qg=-1.66 -> Pg=10.665, Qg=2.98
% INFO    : Gen at bus 26076	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 26077	: Pg=14.91, Qg=-1.66 -> Pg=11.025, Qg=2.98
% INFO    : Gen at bus 26077	: Vg=0.9856 -> Vg=1.0
% INFO    : Gen at bus 26078	: Pg=0.0, Qg=0.0 -> Pg=10.825, Qg=2.98
% INFO    : Gen at bus 26078	: Vg=0.9862 -> Vg=1.0
% INFO    : Gen at bus 26080	: Pg=15.44, Qg=7.89 -> Pg=10.1, Qg=3.085
% INFO    : Gen at bus 26080	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 26080	: Pg=0.0, Qg=0.0 -> Pg=10.305, Qg=3.085
% INFO    : Gen at bus 26080	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 26080	: Pg=27.55, Qg=14.08 -> Pg=17.15, Qg=5.505
% INFO    : Gen at bus 26080	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 26080	: Pg=27.55, Qg=14.08 -> Pg=16.54, Qg=5.505
% INFO    : Gen at bus 26080	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 26080	: Pg=27.55, Qg=14.08 -> Pg=19.44, Qg=5.505
% INFO    : Gen at bus 26080	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 26085	: Pg=0.0, Qg=0.0 -> Pg=25.185, Qg=6.215
% INFO    : Gen at bus 26085	: Vg=1.0255 -> Vg=1.0
% INFO    : Gen at bus 26085	: Pg=0.0, Qg=0.0 -> Pg=23.87, Qg=6.215
% INFO    : Gen at bus 26085	: Vg=1.0255 -> Vg=1.0
% INFO    : Gen at bus 26086	: Pg=14.26, Qg=7.53 -> Pg=14.26, Qg=3.285
% INFO    : Gen at bus 26086	: Vg=1.0281 -> Vg=1.0
% INFO    : Gen at bus 26089	: Pg=120.31, Qg=-23.33 -> Pg=120.31, Qg=5.59
% INFO    : Gen at bus 26089	: Vg=0.9801 -> Vg=1.0
% INFO    : Gen at bus 26091	: Pg=0.0, Qg=0.0 -> Pg=16.405, Qg=0.0
% INFO    : Gen at bus 26091	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26091	: Pg=24.88, Qg=0.0 -> Pg=24.88, Qg=0.0
% INFO    : Gen at bus 26091	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26093	: Pg=22.08, Qg=0.0 -> Pg=22.08, Qg=0.0
% INFO    : Gen at bus 26093	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 26093	: Pg=8.15, Qg=0.0 -> Pg=8.15, Qg=0.0
% INFO    : Gen at bus 26093	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 26097	: Pg=319.03, Qg=151.46 -> Pg=188.66, Qg=63.745
% INFO    : Gen at bus 26097	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 26098	: Pg=319.03, Qg=151.46 -> Pg=189.52, Qg=63.745
% INFO    : Gen at bus 26098	: Vg=1.0195 -> Vg=1.0
% INFO    : Gen at bus 26099	: Pg=319.03, Qg=151.46 -> Pg=224.085, Qg=63.745
% INFO    : Gen at bus 26099	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 26100	: Pg=319.03, Qg=151.46 -> Pg=230.315, Qg=63.745
% INFO    : Gen at bus 26100	: Vg=1.0217 -> Vg=1.0
% INFO    : Gen at bus 26101	: Pg=319.03, Qg=151.46 -> Pg=193.965, Qg=63.745
% INFO    : Gen at bus 26101	: Vg=1.0243 -> Vg=1.0
% INFO    : Gen at bus 26102	: Pg=0.0, Qg=0.0 -> Pg=218.195, Qg=63.745
% INFO    : Gen at bus 26102	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 26105	: Pg=44.82, Qg=-4.99 -> Pg=29.7, Qg=8.955
% INFO    : Gen at bus 26105	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 26105	: Pg=44.82, Qg=-4.99 -> Pg=27.985, Qg=8.955
% INFO    : Gen at bus 26105	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 26106	: Pg=0.0, Qg=0.0 -> Pg=10.48, Qg=2.815
% INFO    : Gen at bus 26106	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 26107	: Pg=0.0, Qg=0.0 -> Pg=8.78, Qg=2.815
% INFO    : Gen at bus 26107	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 26110	: Pg=48.0, Qg=-5.35 -> Pg=29.035, Qg=9.59
% INFO    : Gen at bus 26110	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 26116	: Pg=168.0, Qg=35.78 -> Pg=168.0, Qg=5.795
% INFO    : Gen at bus 26116	: Vg=1.0452 -> Vg=1.0
% INFO    : Gen at bus 26117	: Pg=81.91, Qg=21.73 -> Pg=81.91, Qg=3.52
% INFO    : Gen at bus 26117	: Vg=1.0404 -> Vg=1.0
% INFO    : Gen at bus 26120	: Pg=0.0, Qg=0.0 -> Pg=56.36, Qg=3.105
% INFO    : Gen at bus 26120	: Vg=1.0306 -> Vg=1.0
% INFO    : Gen at bus 26121	: Pg=8.45, Qg=-1.63 -> Pg=8.45, Qg=0.395
% INFO    : Gen at bus 26121	: Vg=1.0009 -> Vg=1.0
% INFO    : Gen at bus 26122	: Pg=9.76, Qg=-1.63 -> Pg=9.76, Qg=0.395
% INFO    : Gen at bus 26122	: Vg=1.0027 -> Vg=1.0
% INFO    : Gen at bus 26122	: Pg=8.7, Qg=-1.25 -> Pg=8.7, Qg=0.3
% INFO    : Gen at bus 26122	: Vg=1.0027 -> Vg=1.0
% INFO    : Gen at bus 26128	: Pg=0.0, Qg=0.0 -> Pg=123.795, Qg=38.565
% INFO    : Gen at bus 26128	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 26129	: Pg=193.01, Qg=98.64 -> Pg=118.36, Qg=38.565
% INFO    : Gen at bus 26129	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 26133	: Pg=1156.78, Qg=53.95 -> Pg=663.665, Qg=166.095
% INFO    : Gen at bus 26133	: Vg=1.025 -> Vg=1.0
% INFO    : Gen at bus 26134	: Pg=1156.78, Qg=53.95 -> Pg=645.875, Qg=166.095
% INFO    : Gen at bus 26134	: Vg=1.0249 -> Vg=1.0
% INFO    : Gen at bus 26138	: Pg=0.0, Qg=0.0 -> Pg=7.43, Qg=2.665
% INFO    : Gen at bus 26138	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 26139	: Pg=0.0, Qg=0.0 -> Pg=9.83, Qg=2.665
% INFO    : Gen at bus 26139	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 26141	: Pg=22.41, Qg=11.45 -> Pg=14.04, Qg=4.475
% INFO    : Gen at bus 26141	: Vg=1.0412 -> Vg=1.0
% INFO    : Gen at bus 26145	: Pg=0.0, Qg=0.0 -> Pg=68.96, Qg=0.0
% INFO    : Gen at bus 26145	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 26146	: Pg=117.18, Qg=0.0 -> Pg=117.18, Qg=0.0
% INFO    : Gen at bus 26146	: Vg=1.0286 -> Vg=1.0
% INFO    : Gen at bus 26147	: Pg=114.33, Qg=0.0 -> Pg=114.33, Qg=0.0
% INFO    : Gen at bus 26147	: Vg=1.0286 -> Vg=1.0
% INFO    : Gen at bus 26148	: Pg=95.92, Qg=0.0 -> Pg=95.92, Qg=0.0
% INFO    : Gen at bus 26148	: Vg=1.0286 -> Vg=1.0
% INFO    : Gen at bus 26149	: Pg=0.0, Qg=0.0 -> Pg=76.525, Qg=0.0
% INFO    : Gen at bus 26149	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 26150	: Pg=66.0, Qg=0.0 -> Pg=66.0, Qg=0.0
% INFO    : Gen at bus 26150	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26157	: Pg=131.94, Qg=0.0 -> Pg=131.94, Qg=0.0
% INFO    : Gen at bus 26157	: Vg=0.9986 -> Vg=1.0
% INFO    : Gen at bus 26158	: Pg=114.12, Qg=0.0 -> Pg=114.12, Qg=0.0
% INFO    : Gen at bus 26158	: Vg=0.9986 -> Vg=1.0
% INFO    : Gen at bus 26159	: Pg=0.0, Qg=0.0 -> Pg=132.86, Qg=0.0
% INFO    : Gen at bus 26159	: Vg=1.0297 -> Vg=1.0
% INFO    : Gen at bus 26163	: Pg=597.56, Qg=-66.6 -> Pg=397.005, Qg=119.4
% INFO    : Gen at bus 26163	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 26164	: Pg=303.87, Qg=-33.87 -> Pg=194.055, Qg=60.715
% INFO    : Gen at bus 26164	: Vg=1.0205 -> Vg=1.0
% INFO    : Gen at bus 26165	: Pg=298.78, Qg=-33.3 -> Pg=184.305, Qg=59.7
% INFO    : Gen at bus 26165	: Vg=1.0204 -> Vg=1.0
% INFO    : Gen at bus 26166	: Pg=298.78, Qg=-33.3 -> Pg=214.62, Qg=59.7
% INFO    : Gen at bus 26166	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 26167	: Pg=77.68, Qg=-8.66 -> Pg=51.96, Qg=15.52
% INFO    : Gen at bus 26167	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26167	: Pg=77.68, Qg=-8.66 -> Pg=52.89, Qg=15.52
% INFO    : Gen at bus 26167	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26167	: Pg=77.68, Qg=-8.66 -> Pg=54.995, Qg=15.52
% INFO    : Gen at bus 26167	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26173	: Pg=0.0, Qg=0.0 -> Pg=144.41, Qg=45.77
% INFO    : Gen at bus 26173	: Vg=1.0213 -> Vg=1.0
% INFO    : Gen at bus 26174	: Pg=229.07, Qg=-25.53 -> Pg=127.165, Qg=45.77
% INFO    : Gen at bus 26174	: Vg=1.0023 -> Vg=1.0
% INFO    : Gen at bus 26175	: Pg=0.0, Qg=0.0 -> Pg=155.935, Qg=41.78
% INFO    : Gen at bus 26175	: Vg=1.0213 -> Vg=1.0
% INFO    : Gen at bus 26176	: Pg=209.12, Qg=-23.31 -> Pg=123.45, Qg=41.78
% INFO    : Gen at bus 26176	: Vg=1.0034 -> Vg=1.0
% INFO    : Gen at bus 26177	: Pg=209.11, Qg=-23.31 -> Pg=130.88, Qg=41.78
% INFO    : Gen at bus 26177	: Vg=0.999 -> Vg=1.0
% INFO    : Gen at bus 26178	: Pg=107.76, Qg=-12.01 -> Pg=61.07, Qg=21.53
% INFO    : Gen at bus 26178	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 26179	: Pg=107.76, Qg=-12.01 -> Pg=75.84, Qg=21.53
% INFO    : Gen at bus 26179	: Vg=1.0002 -> Vg=1.0
% INFO    : Gen at bus 26180	: Pg=107.76, Qg=-12.01 -> Pg=79.02, Qg=21.53
% INFO    : Gen at bus 26180	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 26181	: Pg=107.76, Qg=-12.01 -> Pg=69.275, Qg=21.53
% INFO    : Gen at bus 26181	: Vg=1.0001 -> Vg=1.0
% INFO    : Gen at bus 26182	: Pg=107.76, Qg=-12.01 -> Pg=69.78, Qg=21.53
% INFO    : Gen at bus 26182	: Vg=1.0048 -> Vg=1.0
% INFO    : Gen at bus 26183	: Pg=107.76, Qg=-12.01 -> Pg=65.215, Qg=21.53
% INFO    : Gen at bus 26183	: Vg=0.9993 -> Vg=1.0
% INFO    : Gen at bus 26185	: Pg=38.94, Qg=19.9 -> Pg=28.665, Qg=7.78
% INFO    : Gen at bus 26185	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26190	: Pg=35.65, Qg=-3.97 -> Pg=26.025, Qg=7.125
% INFO    : Gen at bus 26190	: Vg=1.0115 -> Vg=1.0
% INFO    : Gen at bus 26190	: Pg=35.65, Qg=-3.97 -> Pg=24.025, Qg=7.125
% INFO    : Gen at bus 26190	: Vg=1.0115 -> Vg=1.0
% INFO    : Gen at bus 26191	: Pg=35.65, Qg=-3.97 -> Pg=23.09, Qg=7.125
% INFO    : Gen at bus 26191	: Vg=1.0152 -> Vg=1.0
% INFO    : Gen at bus 26197	: Pg=178.6, Qg=57.96 -> Pg=178.6, Qg=45.39
% INFO    : Gen at bus 26197	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 26198	: Pg=196.9, Qg=57.96 -> Pg=196.9, Qg=45.39
% INFO    : Gen at bus 26198	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 26199	: Pg=180.95, Qg=57.96 -> Pg=180.95, Qg=45.39
% INFO    : Gen at bus 26199	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 26200	: Pg=237.95, Qg=57.96 -> Pg=237.95, Qg=45.39
% INFO    : Gen at bus 26200	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 26201	: Pg=257.84, Qg=57.96 -> Pg=257.84, Qg=45.39
% INFO    : Gen at bus 26201	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 26202	: Pg=194.09, Qg=57.96 -> Pg=194.09, Qg=45.39
% INFO    : Gen at bus 26202	: Vg=1.0278 -> Vg=1.0
% INFO    : Gen at bus 26203	: Pg=0.0, Qg=0.0 -> Pg=37.65, Qg=9.38
% INFO    : Gen at bus 26203	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 26205	: Pg=0.0, Qg=0.0 -> Pg=13.29, Qg=3.36
% INFO    : Gen at bus 26205	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26206	: Pg=4.32, Qg=-0.32 -> Pg=4.32, Qg=1.105
% INFO    : Gen at bus 26206	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26206	: Pg=7.0, Qg=-0.34 -> Pg=7.0, Qg=1.175
% INFO    : Gen at bus 26206	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26206	: Pg=0.0, Qg=0.0 -> Pg=4.48, Qg=1.175
% INFO    : Gen at bus 26206	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26206	: Pg=7.48, Qg=-0.47 -> Pg=7.48, Qg=1.59
% INFO    : Gen at bus 26206	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26206	: Pg=15.29, Qg=-0.98 -> Pg=15.29, Qg=3.36
% INFO    : Gen at bus 26206	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26208	: Pg=21.31, Qg=10.89 -> Pg=15.555, Qg=4.255
% INFO    : Gen at bus 26208	: Vg=1.0267 -> Vg=1.0
% INFO    : Gen at bus 26208	: Pg=21.31, Qg=10.89 -> Pg=15.7, Qg=4.255
% INFO    : Gen at bus 26208	: Vg=1.0267 -> Vg=1.0
% INFO    : Gen at bus 26210	: Pg=83.11, Qg=-14.69 -> Pg=83.11, Qg=3.52
% INFO    : Gen at bus 26210	: Vg=0.9747 -> Vg=1.0
% INFO    : Gen at bus 26215	: Pg=273.29, Qg=-30.46 -> Pg=199.285, Qg=54.605
% INFO    : Gen at bus 26215	: Vg=1.0091 -> Vg=1.0
% INFO    : Gen at bus 26216	: Pg=273.29, Qg=-30.46 -> Pg=175.165, Qg=54.605
% INFO    : Gen at bus 26216	: Vg=1.0082 -> Vg=1.0
% INFO    : Gen at bus 26217	: Pg=273.29, Qg=-30.46 -> Pg=173.05, Qg=54.605
% INFO    : Gen at bus 26217	: Vg=1.0073 -> Vg=1.0
% INFO    : Gen at bus 26219	: Pg=45.81, Qg=-2.25 -> Pg=28.62, Qg=9.15
% INFO    : Gen at bus 26219	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 26222	: Pg=7.39, Qg=3.26 -> Pg=7.39, Qg=1.42
% INFO    : Gen at bus 26222	: Vg=1.0275 -> Vg=1.0
% INFO    : Gen at bus 26223	: Pg=0.0, Qg=0.0 -> Pg=7.215, Qg=1.655
% INFO    : Gen at bus 26223	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 26225	: Pg=10.59, Qg=5.38 -> Pg=10.59, Qg=2.345
% INFO    : Gen at bus 26225	: Vg=1.0713 -> Vg=1.0
% INFO    : Gen at bus 26226	: Pg=6.93, Qg=5.38 -> Pg=6.93, Qg=2.345
% INFO    : Gen at bus 26226	: Vg=1.0306 -> Vg=1.0
% INFO    : Gen at bus 26226	: Pg=14.0, Qg=5.38 -> Pg=14.0, Qg=2.345
% INFO    : Gen at bus 26226	: Vg=1.0306 -> Vg=1.0
% INFO    : Gen at bus 26227	: Pg=7.88, Qg=4.22 -> Pg=7.88, Qg=1.84
% INFO    : Gen at bus 26227	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 26227	: Pg=7.8, Qg=3.88 -> Pg=7.8, Qg=1.695
% INFO    : Gen at bus 26227	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 26229	: Pg=31.27, Qg=15.98 -> Pg=22.44, Qg=6.245
% INFO    : Gen at bus 26229	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26230	: Pg=31.27, Qg=-3.49 -> Pg=19.51, Qg=6.245
% INFO    : Gen at bus 26230	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26230	: Pg=31.27, Qg=-3.49 -> Pg=22.745, Qg=6.245
% INFO    : Gen at bus 26230	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 26234	: Pg=110.94, Qg=-19.87 -> Pg=110.94, Qg=4.76
% INFO    : Gen at bus 26234	: Vg=1.0281 -> Vg=1.0
% INFO    : Gen at bus 26236	: Pg=32.51, Qg=0.0 -> Pg=32.51, Qg=0.0
% INFO    : Gen at bus 26236	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26236	: Pg=44.25, Qg=0.0 -> Pg=44.25, Qg=0.0
% INFO    : Gen at bus 26236	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26236	: Pg=35.46, Qg=0.0 -> Pg=35.46, Qg=0.0
% INFO    : Gen at bus 26236	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26236	: Pg=28.33, Qg=0.0 -> Pg=28.33, Qg=0.0
% INFO    : Gen at bus 26236	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26237	: Pg=0.0, Qg=0.0 -> Pg=37.85, Qg=11.425
% INFO    : Gen at bus 26237	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=30.0, Qg=-3.34 -> Pg=19.03, Qg=5.995
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=30.0, Qg=-3.34 -> Pg=17.6, Qg=5.995
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=30.01, Qg=-3.34 -> Pg=18.7, Qg=5.995
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=30.01, Qg=-3.34 -> Pg=19.47, Qg=5.995
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=40.83, Qg=-4.55 -> Pg=25.58, Qg=8.16
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=40.83, Qg=-4.55 -> Pg=27.64, Qg=8.16
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 26238	: Pg=40.83, Qg=-4.55 -> Pg=24.92, Qg=8.16
% INFO    : Gen at bus 26238	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 28720	: Pg=103.47, Qg=0.0 -> Pg=103.47, Qg=0.0
% INFO    : Gen at bus 28720	: Vg=1.0329 -> Vg=1.0
% INFO    : Gen at bus 28721	: Pg=0.0, Qg=0.0 -> Pg=79.565, Qg=0.0
% INFO    : Gen at bus 28721	: Vg=1.0328 -> Vg=1.0
% INFO    : Gen at bus 28722	: Pg=16.45, Qg=0.0 -> Pg=16.45, Qg=0.0
% INFO    : Gen at bus 28722	: Vg=1.0328 -> Vg=1.0
% INFO    : Gen at bus 28723	: Pg=10.0, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 28723	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 28725	: Pg=58.66, Qg=29.98 -> Pg=39.635, Qg=11.72
% INFO    : Gen at bus 28725	: Vg=1.0131 -> Vg=1.0
% INFO    : Gen at bus 28727	: Pg=39.87, Qg=10.54 -> Pg=39.87, Qg=1.705
% INFO    : Gen at bus 28727	: Vg=1.0476 -> Vg=1.0
% INFO    : Gen at bus 28729	: Pg=60.25, Qg=30.79 -> Pg=42.94, Qg=12.035
% INFO    : Gen at bus 28729	: Vg=1.0601 -> Vg=1.0
% INFO    : Gen at bus 28732	: Pg=7.16, Qg=0.0 -> Pg=7.16, Qg=0.0
% INFO    : Gen at bus 28732	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 28733	: Pg=10.6, Qg=0.0 -> Pg=10.6, Qg=0.0
% INFO    : Gen at bus 28733	: Vg=1.0242 -> Vg=1.0
% INFO    : Gen at bus 28735	: Pg=0.0, Qg=0.0 -> Pg=15.82, Qg=0.0
% INFO    : Gen at bus 28735	: Vg=1.0238 -> Vg=1.0
% INFO    : Gen at bus 28736	: Pg=12.85, Qg=0.0 -> Pg=12.85, Qg=0.0
% INFO    : Gen at bus 28736	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 28736	: Pg=0.0, Qg=0.0 -> Pg=9.915, Qg=0.0
% INFO    : Gen at bus 28736	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 28740	: Pg=52.28, Qg=0.0 -> Pg=52.28, Qg=0.0
% INFO    : Gen at bus 28740	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28741	: Pg=0.0, Qg=0.0 -> Pg=35.035, Qg=0.0
% INFO    : Gen at bus 28741	: Vg=1.0524 -> Vg=1.0
% INFO    : Gen at bus 28742	: Pg=44.47, Qg=0.0 -> Pg=44.47, Qg=0.0
% INFO    : Gen at bus 28742	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28743	: Pg=38.89, Qg=0.0 -> Pg=38.89, Qg=0.0
% INFO    : Gen at bus 28743	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28744	: Pg=25.36, Qg=0.0 -> Pg=25.36, Qg=0.0
% INFO    : Gen at bus 28744	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 28744	: Pg=38.36, Qg=0.0 -> Pg=38.36, Qg=0.0
% INFO    : Gen at bus 28744	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 28746	: Pg=26.15, Qg=0.0 -> Pg=26.15, Qg=0.0
% INFO    : Gen at bus 28746	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28746	: Pg=0.0, Qg=0.0 -> Pg=25.895, Qg=0.0
% INFO    : Gen at bus 28746	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28747	: Pg=31.57, Qg=0.0 -> Pg=31.57, Qg=0.0
% INFO    : Gen at bus 28747	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 28747	: Pg=35.98, Qg=0.0 -> Pg=35.98, Qg=0.0
% INFO    : Gen at bus 28747	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 28748	: Pg=0.0, Qg=0.0 -> Pg=22.995, Qg=0.0
% INFO    : Gen at bus 28748	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28748	: Pg=28.27, Qg=0.0 -> Pg=28.27, Qg=0.0
% INFO    : Gen at bus 28748	: Vg=1.0459 -> Vg=1.0
% INFO    : Gen at bus 28751	: Pg=23.52, Qg=0.0 -> Pg=23.52, Qg=0.0
% INFO    : Gen at bus 28751	: Vg=0.9929 -> Vg=1.0
% INFO    : Gen at bus 28751	: Pg=25.12, Qg=0.0 -> Pg=25.12, Qg=0.0
% INFO    : Gen at bus 28751	: Vg=0.9929 -> Vg=1.0
% INFO    : Gen at bus 28752	: Pg=21.58, Qg=0.0 -> Pg=21.58, Qg=0.0
% INFO    : Gen at bus 28752	: Vg=0.9929 -> Vg=1.0
% INFO    : Gen at bus 28753	: Pg=29.13, Qg=0.0 -> Pg=29.13, Qg=0.0
% INFO    : Gen at bus 28753	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 28753	: Pg=20.69, Qg=0.0 -> Pg=20.69, Qg=0.0
% INFO    : Gen at bus 28753	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 28754	: Pg=22.2, Qg=0.0 -> Pg=22.2, Qg=0.0
% INFO    : Gen at bus 28754	: Vg=0.9929 -> Vg=1.0
% INFO    : Gen at bus 28755	: Pg=6.66, Qg=0.0 -> Pg=6.66, Qg=0.0
% INFO    : Gen at bus 28755	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28755	: Pg=15.36, Qg=0.0 -> Pg=15.36, Qg=0.0
% INFO    : Gen at bus 28755	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28755	: Pg=13.52, Qg=0.0 -> Pg=13.52, Qg=0.0
% INFO    : Gen at bus 28755	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28755	: Pg=0.0, Qg=0.0 -> Pg=11.27, Qg=0.0
% INFO    : Gen at bus 28755	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28757	: Pg=40.21, Qg=10.65 -> Pg=40.21, Qg=1.725
% INFO    : Gen at bus 28757	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 28761	: Pg=0.0, Qg=0.0 -> Pg=91.62, Qg=0.0
% INFO    : Gen at bus 28761	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 28765	: Pg=132.79, Qg=67.87 -> Pg=81.37, Qg=26.535
% INFO    : Gen at bus 28765	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 28766	: Pg=132.79, Qg=67.87 -> Pg=75.305, Qg=26.535
% INFO    : Gen at bus 28766	: Vg=1.0306 -> Vg=1.0
% INFO    : Gen at bus 28767	: Pg=0.0, Qg=0.0 -> Pg=92.31, Qg=26.535
% INFO    : Gen at bus 28767	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 28768	: Pg=132.79, Qg=67.87 -> Pg=96.72, Qg=26.535
% INFO    : Gen at bus 28768	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 28769	: Pg=132.79, Qg=67.87 -> Pg=86.63, Qg=26.535
% INFO    : Gen at bus 28769	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 28770	: Pg=132.79, Qg=67.87 -> Pg=75.83, Qg=26.535
% INFO    : Gen at bus 28770	: Vg=1.0315 -> Vg=1.0
% INFO    : Gen at bus 28771	: Pg=7.17, Qg=3.66 -> Pg=4.755, Qg=1.43
% INFO    : Gen at bus 28771	: Vg=1.0252 -> Vg=1.0
% INFO    : Gen at bus 28778	: Pg=52.78, Qg=26.98 -> Pg=31.885, Qg=10.55
% INFO    : Gen at bus 28778	: Vg=0.9968 -> Vg=1.0
% INFO    : Gen at bus 28779	: Pg=52.78, Qg=26.98 -> Pg=32.965, Qg=10.55
% INFO    : Gen at bus 28779	: Vg=0.9973 -> Vg=1.0
% INFO    : Gen at bus 28784	: Pg=172.1, Qg=-19.18 -> Pg=95.28, Qg=34.39
% INFO    : Gen at bus 28784	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 28785	: Pg=172.1, Qg=-19.18 -> Pg=100.755, Qg=34.39
% INFO    : Gen at bus 28785	: Vg=1.0267 -> Vg=1.0
% INFO    : Gen at bus 28786	: Pg=172.1, Qg=-19.18 -> Pg=115.715, Qg=34.39
% INFO    : Gen at bus 28786	: Vg=1.0274 -> Vg=1.0
% INFO    : Gen at bus 28787	: Pg=172.1, Qg=-19.18 -> Pg=123.135, Qg=34.39
% INFO    : Gen at bus 28787	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 28788	: Pg=172.1, Qg=-19.18 -> Pg=95.295, Qg=34.39
% INFO    : Gen at bus 28788	: Vg=1.0275 -> Vg=1.0
% INFO    : Gen at bus 28789	: Pg=172.1, Qg=-19.18 -> Pg=105.965, Qg=34.39
% INFO    : Gen at bus 28789	: Vg=1.0271 -> Vg=1.0
% INFO    : Gen at bus 28791	: Pg=25.6, Qg=13.08 -> Pg=16.355, Qg=5.115
% INFO    : Gen at bus 28791	: Vg=1.0347 -> Vg=1.0
% INFO    : Gen at bus 28792	: Pg=25.6, Qg=13.08 -> Pg=16.435, Qg=5.115
% INFO    : Gen at bus 28792	: Vg=1.0347 -> Vg=1.0
% INFO    : Gen at bus 28797	: Pg=331.65, Qg=169.5 -> Pg=238.145, Qg=66.27
% INFO    : Gen at bus 28797	: Vg=0.9867 -> Vg=1.0
% INFO    : Gen at bus 28798	: Pg=331.65, Qg=169.5 -> Pg=184.61, Qg=66.27
% INFO    : Gen at bus 28798	: Vg=0.9917 -> Vg=1.0
% INFO    : Gen at bus 28799	: Pg=0.0, Qg=0.0 -> Pg=4.86, Qg=1.455
% INFO    : Gen at bus 28799	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 28799	: Pg=49.6, Qg=25.35 -> Pg=31.2, Qg=9.91
% INFO    : Gen at bus 28799	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 28800	: Pg=23.4, Qg=11.96 -> Pg=17.115, Qg=4.675
% INFO    : Gen at bus 28800	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28804	: Pg=15.42, Qg=0.0 -> Pg=15.42, Qg=0.0
% INFO    : Gen at bus 28804	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28804	: Pg=0.0, Qg=0.0 -> Pg=13.965, Qg=0.0
% INFO    : Gen at bus 28804	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28804	: Pg=0.0, Qg=0.0 -> Pg=12.4, Qg=0.0
% INFO    : Gen at bus 28804	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28805	: Pg=48.5, Qg=-5.41 -> Pg=36.03, Qg=9.69
% INFO    : Gen at bus 28805	: Vg=1.0133 -> Vg=1.0
% INFO    : Gen at bus 28811	: Pg=58.76, Qg=30.03 -> Pg=41.355, Qg=11.74
% INFO    : Gen at bus 28811	: Vg=1.0174 -> Vg=1.0
% INFO    : Gen at bus 28812	: Pg=58.76, Qg=30.03 -> Pg=43.09, Qg=11.74
% INFO    : Gen at bus 28812	: Vg=1.0178 -> Vg=1.0
% INFO    : Gen at bus 28815	: Pg=20.75, Qg=-2.54 -> Pg=13.25, Qg=3.585
% INFO    : Gen at bus 28815	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 28815	: Pg=20.75, Qg=-2.54 -> Pg=11.76, Qg=3.585
% INFO    : Gen at bus 28815	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 28815	: Pg=20.75, Qg=-2.54 -> Pg=14.645, Qg=3.585
% INFO    : Gen at bus 28815	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 28816	: Pg=0.0, Qg=0.0 -> Pg=10.0, Qg=2.58
% INFO    : Gen at bus 28816	: Vg=1.0482 -> Vg=1.0
% INFO    : Gen at bus 28817	: Pg=0.0, Qg=0.0 -> Pg=9.92, Qg=2.58
% INFO    : Gen at bus 28817	: Vg=1.0482 -> Vg=1.0
% INFO    : Gen at bus 28820	: Pg=19.92, Qg=10.18 -> Pg=11.77, Qg=3.98
% INFO    : Gen at bus 28820	: Vg=1.0635 -> Vg=1.0
% INFO    : Gen at bus 28821	: Pg=9.46, Qg=4.84 -> Pg=6.995, Qg=1.895
% INFO    : Gen at bus 28821	: Vg=1.0677 -> Vg=1.0
% INFO    : Gen at bus 28821	: Pg=9.46, Qg=4.84 -> Pg=5.845, Qg=1.895
% INFO    : Gen at bus 28821	: Vg=1.0677 -> Vg=1.0
% INFO    : Gen at bus 28823	: Pg=24.07, Qg=0.0 -> Pg=24.07, Qg=0.0
% INFO    : Gen at bus 28823	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28824	: Pg=35.75, Qg=9.58 -> Pg=35.75, Qg=1.55
% INFO    : Gen at bus 28824	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 28828	: Pg=53.9, Qg=0.0 -> Pg=53.9, Qg=0.0
% INFO    : Gen at bus 28828	: Vg=0.994 -> Vg=1.0
% INFO    : Gen at bus 28829	: Pg=7.86, Qg=0.0 -> Pg=7.86, Qg=0.0
% INFO    : Gen at bus 28829	: Vg=1.0211 -> Vg=1.0
% INFO    : Gen at bus 28829	: Pg=5.01, Qg=0.0 -> Pg=5.01, Qg=0.0
% INFO    : Gen at bus 28829	: Vg=1.0211 -> Vg=1.0
% INFO    : Gen at bus 28830	: Pg=6.67, Qg=0.0 -> Pg=6.67, Qg=0.0
% INFO    : Gen at bus 28830	: Vg=0.9938 -> Vg=1.0
% INFO    : Gen at bus 28830	: Pg=6.67, Qg=0.0 -> Pg=6.67, Qg=0.0
% INFO    : Gen at bus 28830	: Vg=0.9938 -> Vg=1.0
% INFO    : Gen at bus 28831	: Pg=60.25, Qg=30.79 -> Pg=43.315, Qg=12.035
% INFO    : Gen at bus 28831	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28833	: Pg=55.5, Qg=0.0 -> Pg=55.5, Qg=0.0
% INFO    : Gen at bus 28833	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28834	: Pg=0.0, Qg=0.0 -> Pg=19.47, Qg=0.0
% INFO    : Gen at bus 28834	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28835	: Pg=0.0, Qg=0.0 -> Pg=5.895, Qg=1.77
% INFO    : Gen at bus 28835	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 28835	: Pg=24.8, Qg=12.67 -> Pg=17.92, Qg=4.955
% INFO    : Gen at bus 28835	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 28835	: Pg=24.8, Qg=12.67 -> Pg=14.185, Qg=4.955
% INFO    : Gen at bus 28835	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 28837	: Pg=0.0, Qg=0.0 -> Pg=6.875, Qg=2.19
% INFO    : Gen at bus 28837	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 28837	: Pg=10.96, Qg=5.6 -> Pg=6.68, Qg=2.19
% INFO    : Gen at bus 28837	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 28838	: Pg=10.96, Qg=5.6 -> Pg=7.6, Qg=2.19
% INFO    : Gen at bus 28838	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 28839	: Pg=62.02, Qg=0.0 -> Pg=62.02, Qg=0.0
% INFO    : Gen at bus 28839	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28844	: Pg=185.57, Qg=-20.68 -> Pg=107.34, Qg=37.08
% INFO    : Gen at bus 28844	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 28845	: Pg=185.58, Qg=-20.68 -> Pg=138.385, Qg=37.08
% INFO    : Gen at bus 28845	: Vg=1.0222 -> Vg=1.0
% INFO    : Gen at bus 28846	: Pg=185.58, Qg=-20.68 -> Pg=128.365, Qg=37.08
% INFO    : Gen at bus 28846	: Vg=1.023 -> Vg=1.0
% INFO    : Gen at bus 28850	: Pg=212.13, Qg=-23.64 -> Pg=128.185, Qg=42.39
% INFO    : Gen at bus 28850	: Vg=1.0235 -> Vg=1.0
% INFO    : Gen at bus 28851	: Pg=212.13, Qg=-23.64 -> Pg=146.205, Qg=42.39
% INFO    : Gen at bus 28851	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 28852	: Pg=212.13, Qg=-23.64 -> Pg=153.325, Qg=42.39
% INFO    : Gen at bus 28852	: Vg=1.023 -> Vg=1.0
% INFO    : Gen at bus 28853	: Pg=0.0, Qg=0.0 -> Pg=154.2, Qg=42.39
% INFO    : Gen at bus 28853	: Vg=1.025 -> Vg=1.0
% INFO    : Gen at bus 28854	: Pg=19.92, Qg=-2.22 -> Pg=11.57, Qg=3.98
% INFO    : Gen at bus 28854	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 28855	: Pg=17.93, Qg=9.16 -> Pg=10.005, Qg=3.58
% INFO    : Gen at bus 28855	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28856	: Pg=49.7, Qg=25.4 -> Pg=27.47, Qg=9.93
% INFO    : Gen at bus 28856	: Vg=1.0365 -> Vg=1.0
% INFO    : Gen at bus 28858	: Pg=6.15, Qg=0.0 -> Pg=6.15, Qg=0.0
% INFO    : Gen at bus 28858	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28858	: Pg=31.53, Qg=0.0 -> Pg=31.53, Qg=0.0
% INFO    : Gen at bus 28858	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28859	: Pg=0.0, Qg=0.0 -> Pg=5.015, Qg=0.275
% INFO    : Gen at bus 28859	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28859	: Pg=0.0, Qg=0.0 -> Pg=11.55, Qg=0.69
% INFO    : Gen at bus 28859	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28859	: Pg=0.0, Qg=0.0 -> Pg=32.375, Qg=1.69
% INFO    : Gen at bus 28859	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28862	: Pg=6.33, Qg=3.03 -> Pg=6.33, Qg=1.32
% INFO    : Gen at bus 28862	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 28863	: Pg=18.72, Qg=9.18 -> Pg=18.72, Qg=4.005
% INFO    : Gen at bus 28863	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 28865	: Pg=54.93, Qg=26.52 -> Pg=54.93, Qg=11.57
% INFO    : Gen at bus 28865	: Vg=1.0222 -> Vg=1.0
% INFO    : Gen at bus 28866	: Pg=0.0, Qg=0.0 -> Pg=40.335, Qg=11.57
% INFO    : Gen at bus 28866	: Vg=1.0129 -> Vg=1.0
% INFO    : Gen at bus 28867	: Pg=48.47, Qg=26.52 -> Pg=48.47, Qg=11.57
% INFO    : Gen at bus 28867	: Vg=1.0171 -> Vg=1.0
% INFO    : Gen at bus 28868	: Pg=47.61, Qg=26.52 -> Pg=47.61, Qg=11.57
% INFO    : Gen at bus 28868	: Vg=1.0203 -> Vg=1.0
% INFO    : Gen at bus 28869	: Pg=69.0, Qg=0.0 -> Pg=69.0, Qg=0.0
% INFO    : Gen at bus 28869	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28871	: Pg=24.4, Qg=12.47 -> Pg=14.515, Qg=4.875
% INFO    : Gen at bus 28871	: Vg=1.0125 -> Vg=1.0
% INFO    : Gen at bus 28872	: Pg=24.4, Qg=12.47 -> Pg=17.215, Qg=4.875
% INFO    : Gen at bus 28872	: Vg=1.0125 -> Vg=1.0
% INFO    : Gen at bus 28874	: Pg=49.0, Qg=25.04 -> Pg=30.545, Qg=9.79
% INFO    : Gen at bus 28874	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28877	: Pg=45.83, Qg=0.0 -> Pg=45.83, Qg=0.0
% INFO    : Gen at bus 28877	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28877	: Pg=43.32, Qg=0.0 -> Pg=43.32, Qg=0.0
% INFO    : Gen at bus 28877	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28877	: Pg=48.14, Qg=0.0 -> Pg=48.14, Qg=0.0
% INFO    : Gen at bus 28877	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28885	: Pg=196.2, Qg=-21.87 -> Pg=128.415, Qg=39.2
% INFO    : Gen at bus 28885	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 28886	: Pg=196.2, Qg=-21.87 -> Pg=134.145, Qg=39.2
% INFO    : Gen at bus 28886	: Vg=1.0374 -> Vg=1.0
% INFO    : Gen at bus 28887	: Pg=196.2, Qg=-21.87 -> Pg=135.71, Qg=39.2
% INFO    : Gen at bus 28887	: Vg=1.0364 -> Vg=1.0
% INFO    : Gen at bus 28890	: Pg=133.0, Qg=0.0 -> Pg=133.0, Qg=0.0
% INFO    : Gen at bus 28890	: Vg=1.0301 -> Vg=1.0
% INFO    : Gen at bus 28893	: Pg=14.49, Qg=0.0 -> Pg=14.49, Qg=0.0
% INFO    : Gen at bus 28893	: Vg=1.0304 -> Vg=1.0
% INFO    : Gen at bus 28893	: Pg=12.7, Qg=0.0 -> Pg=12.7, Qg=0.0
% INFO    : Gen at bus 28893	: Vg=1.0304 -> Vg=1.0
% INFO    : Gen at bus 28896	: Pg=10.9, Qg=4.19 -> Pg=10.9, Qg=1.83
% INFO    : Gen at bus 28896	: Vg=1.0332 -> Vg=1.0
% INFO    : Gen at bus 28897	: Pg=0.0, Qg=0.0 -> Pg=6.415, Qg=1.83
% INFO    : Gen at bus 28897	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 28898	: Pg=10.9, Qg=4.19 -> Pg=10.9, Qg=1.83
% INFO    : Gen at bus 28898	: Vg=1.0223 -> Vg=1.0
% INFO    : Gen at bus 28901	: Pg=48.8, Qg=-5.44 -> Pg=34.46, Qg=9.75
% INFO    : Gen at bus 28901	: Vg=1.017 -> Vg=1.0
% INFO    : Gen at bus 28902	: Pg=0.0, Qg=0.0 -> Pg=34.32, Qg=0.0
% INFO    : Gen at bus 28902	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28906	: Pg=265.4, Qg=-38.22 -> Pg=265.4, Qg=9.155
% INFO    : Gen at bus 28906	: Vg=0.9945 -> Vg=1.0
% INFO    : Gen at bus 28907	: Pg=12.75, Qg=6.52 -> Pg=7.955, Qg=2.55
% INFO    : Gen at bus 28907	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28908	: Pg=0.0, Qg=0.0 -> Pg=7.51, Qg=2.55
% INFO    : Gen at bus 28908	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 28908	: Pg=0.0, Qg=0.0 -> Pg=12.47, Qg=4.01
% INFO    : Gen at bus 28908	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 28908	: Pg=20.07, Qg=-2.24 -> Pg=11.205, Qg=4.01
% INFO    : Gen at bus 28908	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 28913	: Pg=0.0, Qg=0.0 -> Pg=106.785, Qg=0.0
% INFO    : Gen at bus 28913	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 28915	: Pg=7.81, Qg=-0.48 -> Pg=7.81, Qg=1.64
% INFO    : Gen at bus 28915	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 28915	: Pg=9.8, Qg=-0.48 -> Pg=9.8, Qg=1.64
% INFO    : Gen at bus 28915	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 28915	: Pg=0.0, Qg=0.0 -> Pg=10.855, Qg=2.765
% INFO    : Gen at bus 28915	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 28915	: Pg=7.8, Qg=-0.81 -> Pg=7.8, Qg=2.765
% INFO    : Gen at bus 28915	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 28918	: Pg=25.4, Qg=-3.66 -> Pg=25.4, Qg=0.875
% INFO    : Gen at bus 28918	: Vg=0.9916 -> Vg=1.0
% INFO    : Gen at bus 28918	: Pg=0.0, Qg=0.0 -> Pg=12.485, Qg=0.655
% INFO    : Gen at bus 28918	: Vg=0.9916 -> Vg=1.0
% INFO    : Gen at bus 28919	: Pg=55.12, Qg=-6.14 -> Pg=34.675, Qg=11.015
% INFO    : Gen at bus 28919	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28919	: Pg=55.12, Qg=-6.14 -> Pg=34.335, Qg=11.015
% INFO    : Gen at bus 28919	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28919	: Pg=55.12, Qg=-6.14 -> Pg=36.54, Qg=11.015
% INFO    : Gen at bus 28919	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28919	: Pg=55.12, Qg=-6.14 -> Pg=38.125, Qg=11.015
% INFO    : Gen at bus 28919	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28919	: Pg=55.12, Qg=-6.14 -> Pg=37.2, Qg=11.015
% INFO    : Gen at bus 28919	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28919	: Pg=81.27, Qg=-9.06 -> Pg=51.205, Qg=16.235
% INFO    : Gen at bus 28919	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28926	: Pg=0.0, Qg=0.0 -> Pg=37.405, Qg=9.93
% INFO    : Gen at bus 28926	: Vg=0.9955 -> Vg=1.0
% INFO    : Gen at bus 28926	: Pg=49.7, Qg=-5.54 -> Pg=36.955, Qg=9.93
% INFO    : Gen at bus 28926	: Vg=0.9955 -> Vg=1.0
% INFO    : Gen at bus 28927	: Pg=49.7, Qg=25.4 -> Pg=30.46, Qg=9.93
% INFO    : Gen at bus 28927	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 28928	: Pg=9.3, Qg=4.75 -> Pg=5.7, Qg=1.855
% INFO    : Gen at bus 28928	: Vg=1.0179 -> Vg=1.0
% INFO    : Gen at bus 28928	: Pg=18.3, Qg=6.02 -> Pg=10.565, Qg=3.655
% INFO    : Gen at bus 28928	: Vg=1.0179 -> Vg=1.0
% INFO    : Gen at bus 28928	: Pg=18.3, Qg=6.02 -> Pg=12.035, Qg=3.655
% INFO    : Gen at bus 28928	: Vg=1.0179 -> Vg=1.0
% INFO    : Gen at bus 28928	: Pg=18.29, Qg=6.02 -> Pg=10.625, Qg=3.655
% INFO    : Gen at bus 28928	: Vg=1.0179 -> Vg=1.0
% INFO    : Gen at bus 28929	: Pg=9.3, Qg=4.75 -> Pg=6.49, Qg=1.855
% INFO    : Gen at bus 28929	: Vg=0.9869 -> Vg=1.0
% INFO    : Gen at bus 28930	: Pg=9.3, Qg=4.75 -> Pg=5.615, Qg=1.855
% INFO    : Gen at bus 28930	: Vg=0.9869 -> Vg=1.0
% INFO    : Gen at bus 28934	: Pg=33.86, Qg=17.31 -> Pg=22.445, Qg=6.77
% INFO    : Gen at bus 28934	: Vg=1.0433 -> Vg=1.0
% INFO    : Gen at bus 28935	: Pg=49.74, Qg=0.0 -> Pg=49.74, Qg=0.0
% INFO    : Gen at bus 28935	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28935	: Pg=66.63, Qg=0.0 -> Pg=66.63, Qg=0.0
% INFO    : Gen at bus 28935	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28935	: Pg=0.0, Qg=0.0 -> Pg=43.725, Qg=0.0
% INFO    : Gen at bus 28935	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 28938	: Pg=0.0, Qg=0.0 -> Pg=8.38, Qg=2.23
% INFO    : Gen at bus 28938	: Vg=1.0127 -> Vg=1.0
% INFO    : Gen at bus 28939	: Pg=11.15, Qg=5.7 -> Pg=7.79, Qg=2.23
% INFO    : Gen at bus 28939	: Vg=1.0201 -> Vg=1.0
% INFO    : Gen at bus 28941	: Pg=0.0, Qg=0.0 -> Pg=7.12, Qg=2.23
% INFO    : Gen at bus 28941	: Vg=1.0119 -> Vg=1.0
% INFO    : Gen at bus 28942	: Pg=11.15, Qg=5.7 -> Pg=6.32, Qg=2.23
% INFO    : Gen at bus 28942	: Vg=1.0583 -> Vg=1.0
% INFO    : Gen at bus 28946	: Pg=49.6, Qg=25.35 -> Pg=30.155, Qg=9.91
% INFO    : Gen at bus 28946	: Vg=1.0603 -> Vg=1.0
% INFO    : Gen at bus 28948	: Pg=0.0, Qg=0.0 -> Pg=11.97, Qg=0.0
% INFO    : Gen at bus 28948	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28948	: Pg=17.7, Qg=0.0 -> Pg=17.7, Qg=0.0
% INFO    : Gen at bus 28948	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28951	: Pg=74.5, Qg=0.0 -> Pg=74.5, Qg=0.0
% INFO    : Gen at bus 28951	: Vg=1.0059 -> Vg=1.0
% INFO    : Gen at bus 28952	: Pg=0.0, Qg=0.0 -> Pg=80.66, Qg=0.0
% INFO    : Gen at bus 28952	: Vg=1.0435 -> Vg=1.0
% INFO    : Gen at bus 28953	: Pg=0.0, Qg=0.0 -> Pg=12.415, Qg=0.0
% INFO    : Gen at bus 28953	: Vg=1.0379 -> Vg=1.0
% INFO    : Gen at bus 28957	: Pg=0.0, Qg=0.0 -> Pg=5.97, Qg=1.99
% INFO    : Gen at bus 28957	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28957	: Pg=0.0, Qg=0.0 -> Pg=6.815, Qg=1.99
% INFO    : Gen at bus 28957	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28957	: Pg=0.0, Qg=0.0 -> Pg=5.855, Qg=1.99
% INFO    : Gen at bus 28957	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28957	: Pg=0.0, Qg=0.0 -> Pg=6.63, Qg=1.99
% INFO    : Gen at bus 28957	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28961	: Pg=15.24, Qg=0.0 -> Pg=15.24, Qg=0.0
% INFO    : Gen at bus 28961	: Vg=1.0049 -> Vg=1.0
% INFO    : Gen at bus 28962	: Pg=14.84, Qg=0.0 -> Pg=14.84, Qg=0.0
% INFO    : Gen at bus 28962	: Vg=1.001 -> Vg=1.0
% INFO    : Gen at bus 28963	: Pg=10.1, Qg=0.0 -> Pg=10.1, Qg=0.0
% INFO    : Gen at bus 28963	: Vg=1.0013 -> Vg=1.0
% INFO    : Gen at bus 28963	: Pg=6.93, Qg=0.0 -> Pg=6.93, Qg=0.0
% INFO    : Gen at bus 28963	: Vg=1.0013 -> Vg=1.0
% INFO    : Gen at bus 28969	: Pg=10.9, Qg=0.0 -> Pg=10.9, Qg=0.0
% INFO    : Gen at bus 28969	: Vg=1.0189 -> Vg=1.0
% INFO    : Gen at bus 28970	: Pg=8.75, Qg=0.0 -> Pg=8.75, Qg=0.0
% INFO    : Gen at bus 28970	: Vg=1.0189 -> Vg=1.0
% INFO    : Gen at bus 28972	: Pg=12.68, Qg=0.0 -> Pg=12.68, Qg=0.0
% INFO    : Gen at bus 28972	: Vg=1.0095 -> Vg=1.0
% INFO    : Gen at bus 28972	: Pg=13.33, Qg=0.0 -> Pg=13.33, Qg=0.0
% INFO    : Gen at bus 28972	: Vg=1.0095 -> Vg=1.0
% INFO    : Gen at bus 28973	: Pg=13.33, Qg=0.0 -> Pg=13.33, Qg=0.0
% INFO    : Gen at bus 28973	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 28973	: Pg=12.3, Qg=0.0 -> Pg=12.3, Qg=0.0
% INFO    : Gen at bus 28973	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 28974	: Pg=0.0, Qg=0.0 -> Pg=7.565, Qg=0.0
% INFO    : Gen at bus 28974	: Vg=1.0188 -> Vg=1.0
% INFO    : Gen at bus 28975	: Pg=10.35, Qg=0.0 -> Pg=10.35, Qg=0.0
% INFO    : Gen at bus 28975	: Vg=1.0189 -> Vg=1.0
% INFO    : Gen at bus 28978	: Pg=71.71, Qg=36.65 -> Pg=47.335, Qg=14.33
% INFO    : Gen at bus 28978	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28978	: Pg=0.0, Qg=0.0 -> Pg=46.71, Qg=14.33
% INFO    : Gen at bus 28978	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28980	: Pg=14.13, Qg=8.06 -> Pg=14.13, Qg=3.515
% INFO    : Gen at bus 28980	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28980	: Pg=16.88, Qg=8.06 -> Pg=16.88, Qg=3.515
% INFO    : Gen at bus 28980	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 28982	: Pg=0.0, Qg=0.0 -> Pg=26.0, Qg=0.0
% INFO    : Gen at bus 28982	: Vg=1.0347 -> Vg=1.0
% INFO    : Gen at bus 28984	: Pg=49.6, Qg=25.35 -> Pg=37.23, Qg=9.91
% INFO    : Gen at bus 28984	: Vg=1.0059 -> Vg=1.0
% INFO    : Gen at bus 28987	: Pg=33.7, Qg=0.0 -> Pg=33.7, Qg=0.0
% INFO    : Gen at bus 28987	: Vg=1.0338 -> Vg=1.0
% INFO    : Gen at bus 28991	: Pg=28.74, Qg=-1.47 -> Pg=28.74, Qg=5.025
% INFO    : Gen at bus 28991	: Vg=1.0413 -> Vg=1.0
% INFO    : Gen at bus 28991	: Pg=23.98, Qg=-1.47 -> Pg=23.98, Qg=5.025
% INFO    : Gen at bus 28991	: Vg=1.0413 -> Vg=1.0
% INFO    : Gen at bus 28992	: Pg=24.48, Qg=-1.47 -> Pg=24.48, Qg=5.025
% INFO    : Gen at bus 28992	: Vg=1.0409 -> Vg=1.0
% INFO    : Gen at bus 28992	: Pg=30.0, Qg=-1.47 -> Pg=30.0, Qg=5.025
% INFO    : Gen at bus 28992	: Vg=1.0409 -> Vg=1.0
% INFO    : Gen at bus 28994	: Pg=23.01, Qg=11.76 -> Pg=16.835, Qg=4.6
% INFO    : Gen at bus 28994	: Vg=1.0477 -> Vg=1.0
% INFO    : Gen at bus 28994	: Pg=23.01, Qg=11.76 -> Pg=12.96, Qg=4.6
% INFO    : Gen at bus 28994	: Vg=1.0477 -> Vg=1.0
% INFO    : Gen at bus 28995	: Pg=23.01, Qg=11.76 -> Pg=14.335, Qg=4.6
% INFO    : Gen at bus 28995	: Vg=1.0442 -> Vg=1.0
% INFO    : Gen at bus 28995	: Pg=23.01, Qg=11.76 -> Pg=16.195, Qg=4.6
% INFO    : Gen at bus 28995	: Vg=1.0442 -> Vg=1.0
% INFO    : Gen at bus 29000	: Pg=48.8, Qg=24.51 -> Pg=34.67, Qg=9.75
% INFO    : Gen at bus 29000	: Vg=1.0179 -> Vg=1.0
% INFO    : Gen at bus 29001	: Pg=48.8, Qg=12.26 -> Pg=34.08, Qg=9.75
% INFO    : Gen at bus 29001	: Vg=1.0132 -> Vg=1.0
% INFO    : Gen at bus 29001	: Pg=48.8, Qg=12.26 -> Pg=32.03, Qg=9.75
% INFO    : Gen at bus 29001	: Vg=1.0132 -> Vg=1.0
% INFO    : Gen at bus 29002	: Pg=48.8, Qg=24.51 -> Pg=36.115, Qg=9.75
% INFO    : Gen at bus 29002	: Vg=1.0131 -> Vg=1.0
% INFO    : Gen at bus 29004	: Pg=49.7, Qg=-5.54 -> Pg=35.215, Qg=9.93
% INFO    : Gen at bus 29004	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 29006	: Pg=11.15, Qg=5.7 -> Pg=6.495, Qg=2.23
% INFO    : Gen at bus 29006	: Vg=1.0395 -> Vg=1.0
% INFO    : Gen at bus 29006	: Pg=11.15, Qg=5.7 -> Pg=7.665, Qg=2.23
% INFO    : Gen at bus 29006	: Vg=1.0395 -> Vg=1.0
% INFO    : Gen at bus 29007	: Pg=11.15, Qg=5.7 -> Pg=6.62, Qg=2.23
% INFO    : Gen at bus 29007	: Vg=1.0441 -> Vg=1.0
% INFO    : Gen at bus 29007	: Pg=11.15, Qg=5.7 -> Pg=6.865, Qg=2.23
% INFO    : Gen at bus 29007	: Vg=1.0441 -> Vg=1.0
% INFO    : Gen at bus 29010	: Pg=0.0, Qg=0.0 -> Pg=37.445, Qg=12.035
% INFO    : Gen at bus 29010	: Vg=1.0338 -> Vg=1.0
% INFO    : Gen at bus 29011	: Pg=60.25, Qg=30.79 -> Pg=42.34, Qg=12.035
% INFO    : Gen at bus 29011	: Vg=1.0437 -> Vg=1.0
% INFO    : Gen at bus 29013	: Pg=0.0, Qg=0.0 -> Pg=27.435, Qg=9.35
% INFO    : Gen at bus 29013	: Vg=1.0084 -> Vg=1.0
% INFO    : Gen at bus 29018	: Pg=228.57, Qg=49.76 -> Pg=152.16, Qg=45.675
% INFO    : Gen at bus 29018	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 29019	: Pg=228.57, Qg=49.76 -> Pg=165.75, Qg=45.675
% INFO    : Gen at bus 29019	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 29020	: Pg=228.57, Qg=49.76 -> Pg=134.62, Qg=45.675
% INFO    : Gen at bus 29020	: Vg=1.0247 -> Vg=1.0
% INFO    : Gen at bus 29022	: Pg=108.98, Qg=0.0 -> Pg=108.98, Qg=0.0
% INFO    : Gen at bus 29022	: Vg=1.0217 -> Vg=1.0
% INFO    : Gen at bus 29027	: Pg=195.52, Qg=53.0 -> Pg=133.355, Qg=39.07
% INFO    : Gen at bus 29027	: Vg=1.0302 -> Vg=1.0
% INFO    : Gen at bus 29028	: Pg=195.52, Qg=53.0 -> Pg=109.4, Qg=39.07
% INFO    : Gen at bus 29028	: Vg=1.0281 -> Vg=1.0
% INFO    : Gen at bus 29029	: Pg=195.52, Qg=53.0 -> Pg=131.62, Qg=39.07
% INFO    : Gen at bus 29029	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 29030	: Pg=195.52, Qg=53.0 -> Pg=117.09, Qg=39.07
% INFO    : Gen at bus 29030	: Vg=1.0294 -> Vg=1.0
% INFO    : Gen at bus 29031	: Pg=195.52, Qg=53.0 -> Pg=128.715, Qg=39.07
% INFO    : Gen at bus 29031	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 29032	: Pg=17.93, Qg=9.16 -> Pg=11.875, Qg=3.58
% INFO    : Gen at bus 29032	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 29033	: Pg=10.07, Qg=-1.81 -> Pg=10.07, Qg=0.43
% INFO    : Gen at bus 29033	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 29033	: Pg=16.0, Qg=-2.3 -> Pg=16.0, Qg=0.555
% INFO    : Gen at bus 29033	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 29034	: Pg=7.3, Qg=-1.05 -> Pg=7.3, Qg=0.25
% INFO    : Gen at bus 29034	: Vg=1.0298 -> Vg=1.0
% INFO    : Gen at bus 29035	: Pg=10.54, Qg=-1.81 -> Pg=10.54, Qg=0.43
% INFO    : Gen at bus 29035	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 29038	: Pg=16.66, Qg=-3.23 -> Pg=16.66, Qg=0.77
% INFO    : Gen at bus 29038	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 29038	: Pg=34.09, Qg=-6.25 -> Pg=34.09, Qg=1.495
% INFO    : Gen at bus 29038	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 29042	: Pg=0.0, Qg=0.0 -> Pg=146.065, Qg=43.38
% INFO    : Gen at bus 29042	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 29043	: Pg=217.11, Qg=110.96 -> Pg=122.4, Qg=43.38
% INFO    : Gen at bus 29043	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 29044	: Pg=7.41, Qg=3.79 -> Pg=4.37, Qg=1.48
% INFO    : Gen at bus 29044	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29044	: Pg=0.0, Qg=0.0 -> Pg=4.62, Qg=1.48
% INFO    : Gen at bus 29044	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29044	: Pg=7.41, Qg=3.79 -> Pg=4.72, Qg=1.48
% INFO    : Gen at bus 29044	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29044	: Pg=7.41, Qg=3.79 -> Pg=4.405, Qg=1.48
% INFO    : Gen at bus 29044	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29044	: Pg=0.0, Qg=0.0 -> Pg=4.54, Qg=1.48
% INFO    : Gen at bus 29044	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29046	: Pg=0.0, Qg=0.0 -> Pg=6.83, Qg=0.32
% INFO    : Gen at bus 29046	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 29046	: Pg=5.63, Qg=-1.35 -> Pg=5.63, Qg=0.32
% INFO    : Gen at bus 29046	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 29047	: Pg=22.41, Qg=-4.8 -> Pg=22.41, Qg=1.145
% INFO    : Gen at bus 29047	: Vg=1.0385 -> Vg=1.0
% INFO    : Gen at bus 29047	: Pg=19.32, Qg=-4.8 -> Pg=19.32, Qg=1.145
% INFO    : Gen at bus 29047	: Vg=1.0385 -> Vg=1.0
% INFO    : Gen at bus 29048	: Pg=0.0, Qg=0.0 -> Pg=6.98, Qg=0.405
% INFO    : Gen at bus 29048	: Vg=1.0337 -> Vg=1.0
% INFO    : Gen at bus 29048	: Pg=0.0, Qg=0.0 -> Pg=7.375, Qg=0.405
% INFO    : Gen at bus 29048	: Vg=1.0337 -> Vg=1.0
% INFO    : Gen at bus 29051	: Pg=39.25, Qg=0.0 -> Pg=39.25, Qg=0.0
% INFO    : Gen at bus 29051	: Vg=1.0348 -> Vg=1.0
% INFO    : Gen at bus 29052	: Pg=0.0, Qg=0.0 -> Pg=13.49, Qg=0.0
% INFO    : Gen at bus 29052	: Vg=1.0341 -> Vg=1.0
% INFO    : Gen at bus 29054	: Pg=16.2, Qg=0.0 -> Pg=16.2, Qg=0.0
% INFO    : Gen at bus 29054	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29056	: Pg=5.17, Qg=0.0 -> Pg=5.17, Qg=0.0
% INFO    : Gen at bus 29056	: Vg=1.0006 -> Vg=1.0
% INFO    : Gen at bus 29057	: Pg=10.43, Qg=0.0 -> Pg=10.43, Qg=0.0
% INFO    : Gen at bus 29057	: Vg=1.0008 -> Vg=1.0
% INFO    : Gen at bus 29059	: Pg=49.7, Qg=-5.54 -> Pg=29.64, Qg=9.93
% INFO    : Gen at bus 29059	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 29059	: Pg=49.7, Qg=-5.54 -> Pg=31.53, Qg=9.93
% INFO    : Gen at bus 29059	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 29060	: Pg=43.82, Qg=22.4 -> Pg=25.405, Qg=8.76
% INFO    : Gen at bus 29060	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 29062	: Pg=23.31, Qg=-5.72 -> Pg=23.31, Qg=1.37
% INFO    : Gen at bus 29062	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 29063	: Pg=0.0, Qg=0.0 -> Pg=9.505, Qg=0.565
% INFO    : Gen at bus 29063	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 29064	: Pg=21.56, Qg=-4.31 -> Pg=21.56, Qg=1.03
% INFO    : Gen at bus 29064	: Vg=1.0248 -> Vg=1.0
% INFO    : Gen at bus 29070	: Pg=46.37, Qg=13.1 -> Pg=46.37, Qg=2.12
% INFO    : Gen at bus 29070	: Vg=1.0457 -> Vg=1.0
% INFO    : Gen at bus 29071	: Pg=31.0, Qg=6.6 -> Pg=31.0, Qg=1.07
% INFO    : Gen at bus 29071	: Vg=1.0494 -> Vg=1.0
% INFO    : Gen at bus 29073	: Pg=82.75, Qg=0.0 -> Pg=82.75, Qg=0.0
% INFO    : Gen at bus 29073	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 29075	: Pg=49.8, Qg=25.45 -> Pg=28.895, Qg=9.95
% INFO    : Gen at bus 29075	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 29075	: Pg=49.8, Qg=25.45 -> Pg=34.03, Qg=9.95
% INFO    : Gen at bus 29075	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 29075	: Pg=49.8, Qg=25.45 -> Pg=34.345, Qg=9.95
% INFO    : Gen at bus 29075	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 29075	: Pg=49.8, Qg=25.45 -> Pg=29.74, Qg=9.95
% INFO    : Gen at bus 29075	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 29076	: Pg=0.0, Qg=0.0 -> Pg=7.825, Qg=2.085
% INFO    : Gen at bus 29076	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29076	: Pg=0.0, Qg=0.0 -> Pg=6.105, Qg=2.085
% INFO    : Gen at bus 29076	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 29083	: Pg=407.84, Qg=208.44 -> Pg=265.13, Qg=81.495
% INFO    : Gen at bus 29083	: Vg=1.0329 -> Vg=1.0
% INFO    : Gen at bus 29084	: Pg=0.0, Qg=0.0 -> Pg=258.58, Qg=81.495
% INFO    : Gen at bus 29084	: Vg=1.0142 -> Vg=1.0
% INFO    : Gen at bus 30269	: Pg=7.69, Qg=0.0 -> Pg=7.69, Qg=0.0
% INFO    : Gen at bus 30269	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 30269	: Pg=8.84, Qg=0.0 -> Pg=8.84, Qg=0.0
% INFO    : Gen at bus 30269	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 30272	: Pg=0.0, Qg=0.0 -> Pg=13.74, Qg=0.0
% INFO    : Gen at bus 30272	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30272	: Pg=0.0, Qg=0.0 -> Pg=14.0, Qg=0.0
% INFO    : Gen at bus 30272	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30272	: Pg=14.62, Qg=0.0 -> Pg=14.62, Qg=0.0
% INFO    : Gen at bus 30272	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30274	: Pg=11.49, Qg=0.0 -> Pg=11.49, Qg=0.0
% INFO    : Gen at bus 30274	: Vg=0.9912 -> Vg=1.0
% INFO    : Gen at bus 30277	: Pg=10.0, Qg=0.0 -> Pg=10.0, Qg=0.0
% INFO    : Gen at bus 30277	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30279	: Pg=0.0, Qg=0.0 -> Pg=6.69, Qg=0.0
% INFO    : Gen at bus 30279	: Vg=1.0135 -> Vg=1.0
% INFO    : Gen at bus 30280	: Pg=7.91, Qg=0.0 -> Pg=7.91, Qg=0.0
% INFO    : Gen at bus 30280	: Vg=1.0139 -> Vg=1.0
% INFO    : Gen at bus 30281	: Pg=0.0, Qg=0.0 -> Pg=14.105, Qg=3.9
% INFO    : Gen at bus 30281	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 30281	: Pg=0.0, Qg=0.0 -> Pg=12.25, Qg=3.9
% INFO    : Gen at bus 30281	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 30281	: Pg=19.52, Qg=-2.18 -> Pg=11.905, Qg=3.9
% INFO    : Gen at bus 30281	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 30281	: Pg=0.0, Qg=0.0 -> Pg=13.49, Qg=3.9
% INFO    : Gen at bus 30281	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 30281	: Pg=0.0, Qg=0.0 -> Pg=13.12, Qg=3.9
% INFO    : Gen at bus 30281	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 30281	: Pg=0.0, Qg=0.0 -> Pg=11.905, Qg=3.9
% INFO    : Gen at bus 30281	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 30285	: Pg=0.0, Qg=0.0 -> Pg=11.63, Qg=0.0
% INFO    : Gen at bus 30285	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30287	: Pg=6.84, Qg=0.0 -> Pg=6.84, Qg=0.0
% INFO    : Gen at bus 30287	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30287	: Pg=8.08, Qg=0.0 -> Pg=8.08, Qg=0.0
% INFO    : Gen at bus 30287	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30287	: Pg=7.15, Qg=0.0 -> Pg=7.15, Qg=0.0
% INFO    : Gen at bus 30287	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30287	: Pg=8.22, Qg=0.0 -> Pg=8.22, Qg=0.0
% INFO    : Gen at bus 30287	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30291	: Pg=9.88, Qg=0.0 -> Pg=9.88, Qg=0.0
% INFO    : Gen at bus 30291	: Vg=0.9991 -> Vg=1.0
% INFO    : Gen at bus 30291	: Pg=8.42, Qg=0.0 -> Pg=8.42, Qg=0.0
% INFO    : Gen at bus 30291	: Vg=0.9991 -> Vg=1.0
% INFO    : Gen at bus 30293	: Pg=26.49, Qg=0.0 -> Pg=26.49, Qg=0.0
% INFO    : Gen at bus 30293	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30297	: Pg=0.0, Qg=0.0 -> Pg=111.275, Qg=37.05
% INFO    : Gen at bus 30297	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 30298	: Pg=71.19, Qg=34.43 -> Pg=112.605, Qg=37.05
% INFO    : Gen at bus 30298	: Vg=1.0044 -> Vg=1.0
% INFO    : Gen at bus 30299	: Pg=122.6, Qg=34.43 -> Pg=103.3, Qg=37.05
% INFO    : Gen at bus 30299	: Vg=1.0019 -> Vg=1.0
% INFO    : Gen at bus 30300	: Pg=92.87, Qg=34.43 -> Pg=51.49, Qg=18.555
% INFO    : Gen at bus 30300	: Vg=1.0097 -> Vg=1.0
% INFO    : Gen at bus 30301	: Pg=92.87, Qg=34.43 -> Pg=67.52, Qg=18.555
% INFO    : Gen at bus 30301	: Vg=1.0098 -> Vg=1.0
% INFO    : Gen at bus 30306	: Pg=55.62, Qg=61.7 -> Pg=147.035, Qg=41.625
% INFO    : Gen at bus 30306	: Vg=1.0325 -> Vg=1.0
% INFO    : Gen at bus 30307	: Pg=60.5, Qg=0.0 -> Pg=60.5, Qg=0.0
% INFO    : Gen at bus 30307	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30309	: Pg=9.46, Qg=0.0 -> Pg=9.46, Qg=0.0
% INFO    : Gen at bus 30309	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30309	: Pg=13.0, Qg=0.0 -> Pg=13.0, Qg=0.0
% INFO    : Gen at bus 30309	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30310	: Pg=15.0, Qg=0.0 -> Pg=15.0, Qg=0.0
% INFO    : Gen at bus 30310	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30310	: Pg=9.55, Qg=0.0 -> Pg=9.55, Qg=0.0
% INFO    : Gen at bus 30310	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30316	: Pg=282.35, Qg=71.94 -> Pg=198.925, Qg=48.76
% INFO    : Gen at bus 30316	: Vg=0.9828 -> Vg=1.0
% INFO    : Gen at bus 30317	: Pg=120.83, Qg=71.94 -> Pg=200.09, Qg=48.76
% INFO    : Gen at bus 30317	: Vg=0.9845 -> Vg=1.0
% INFO    : Gen at bus 30319	: Pg=8.34, Qg=0.0 -> Pg=8.34, Qg=0.0
% INFO    : Gen at bus 30319	: Vg=1.0113 -> Vg=1.0
% INFO    : Gen at bus 30320	: Pg=0.0, Qg=0.0 -> Pg=7.075, Qg=0.0
% INFO    : Gen at bus 30320	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 30323	: Pg=42.23, Qg=-4.71 -> Pg=25.295, Qg=8.435
% INFO    : Gen at bus 30323	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 30323	: Pg=42.23, Qg=-4.71 -> Pg=29.92, Qg=8.435
% INFO    : Gen at bus 30323	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 30323	: Pg=42.23, Qg=-4.71 -> Pg=24.095, Qg=8.435
% INFO    : Gen at bus 30323	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 30326	: Pg=8.01, Qg=0.0 -> Pg=8.01, Qg=0.0
% INFO    : Gen at bus 30326	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30326	: Pg=7.09, Qg=0.0 -> Pg=7.09, Qg=0.0
% INFO    : Gen at bus 30326	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30327	: Pg=5.89, Qg=0.0 -> Pg=5.89, Qg=0.0
% INFO    : Gen at bus 30327	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30327	: Pg=8.57, Qg=0.0 -> Pg=8.57, Qg=0.0
% INFO    : Gen at bus 30327	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30327	: Pg=7.27, Qg=0.0 -> Pg=7.27, Qg=0.0
% INFO    : Gen at bus 30327	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30332	: Pg=0.0, Qg=0.0 -> Pg=14.31, Qg=4.79
% INFO    : Gen at bus 30332	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 30332	: Pg=0.0, Qg=0.0 -> Pg=13.71, Qg=4.79
% INFO    : Gen at bus 30332	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 30332	: Pg=0.0, Qg=0.0 -> Pg=14.685, Qg=4.79
% INFO    : Gen at bus 30332	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 30332	: Pg=23.98, Qg=-2.67 -> Pg=13.63, Qg=4.79
% INFO    : Gen at bus 30332	: Vg=1.0158 -> Vg=1.0
% INFO    : Gen at bus 30335	: Pg=17.83, Qg=0.0 -> Pg=17.83, Qg=0.0
% INFO    : Gen at bus 30335	: Vg=1.0218 -> Vg=1.0
% INFO    : Gen at bus 30335	: Pg=11.8, Qg=0.0 -> Pg=11.8, Qg=0.0
% INFO    : Gen at bus 30335	: Vg=1.0218 -> Vg=1.0
% INFO    : Gen at bus 30336	: Pg=8.86, Qg=0.0 -> Pg=8.86, Qg=0.0
% INFO    : Gen at bus 30336	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 30336	: Pg=0.0, Qg=0.0 -> Pg=8.46, Qg=0.0
% INFO    : Gen at bus 30336	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 30337	: Pg=8.38, Qg=0.0 -> Pg=8.38, Qg=0.0
% INFO    : Gen at bus 30337	: Vg=1.021 -> Vg=1.0
% INFO    : Gen at bus 30342	: Pg=25.45, Qg=10.32 -> Pg=100.75, Qg=35.555
% INFO    : Gen at bus 30342	: Vg=1.0335 -> Vg=1.0
% INFO    : Gen at bus 30343	: Pg=177.94, Qg=10.32 -> Pg=123.99, Qg=35.555
% INFO    : Gen at bus 30343	: Vg=1.0317 -> Vg=1.0
% INFO    : Gen at bus 30344	: Pg=62.66, Qg=10.32 -> Pg=119.355, Qg=35.555
% INFO    : Gen at bus 30344	: Vg=1.0317 -> Vg=1.0
% INFO    : Gen at bus 30347	: Pg=293.6, Qg=137.38 -> Pg=213.425, Qg=50.705
% INFO    : Gen at bus 30347	: Vg=1.0645 -> Vg=1.0
% INFO    : Gen at bus 30349	: Pg=23.98, Qg=12.25 -> Pg=13.355, Qg=4.79
% INFO    : Gen at bus 30349	: Vg=1.0447 -> Vg=1.0
% INFO    : Gen at bus 30349	: Pg=23.98, Qg=12.25 -> Pg=17.55, Qg=4.79
% INFO    : Gen at bus 30349	: Vg=1.0447 -> Vg=1.0
% INFO    : Gen at bus 30350	: Pg=0.0, Qg=0.0 -> Pg=13.7, Qg=4.79
% INFO    : Gen at bus 30350	: Vg=1.0336 -> Vg=1.0
% INFO    : Gen at bus 30350	: Pg=23.98, Qg=12.25 -> Pg=15.89, Qg=4.79
% INFO    : Gen at bus 30350	: Vg=1.0336 -> Vg=1.0
% INFO    : Gen at bus 30351	: Pg=30.66, Qg=0.0 -> Pg=30.66, Qg=0.0
% INFO    : Gen at bus 30351	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30352	: Pg=27.74, Qg=0.0 -> Pg=27.74, Qg=0.0
% INFO    : Gen at bus 30352	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30352	: Pg=0.0, Qg=0.0 -> Pg=25.705, Qg=0.0
% INFO    : Gen at bus 30352	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30352	: Pg=18.82, Qg=0.0 -> Pg=18.82, Qg=0.0
% INFO    : Gen at bus 30352	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30352	: Pg=35.0, Qg=0.0 -> Pg=35.0, Qg=0.0
% INFO    : Gen at bus 30352	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30352	: Pg=0.0, Qg=0.0 -> Pg=23.95, Qg=0.0
% INFO    : Gen at bus 30352	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30357	: Pg=0.0, Qg=0.0 -> Pg=8.515, Qg=0.0
% INFO    : Gen at bus 30357	: Vg=1.0329 -> Vg=1.0
% INFO    : Gen at bus 30358	: Pg=11.46, Qg=0.0 -> Pg=11.46, Qg=0.0
% INFO    : Gen at bus 30358	: Vg=1.033 -> Vg=1.0
% INFO    : Gen at bus 30363	: Pg=0.0, Qg=0.0 -> Pg=10.58, Qg=0.0
% INFO    : Gen at bus 30363	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30364	: Pg=14.2, Qg=0.0 -> Pg=14.2, Qg=0.0
% INFO    : Gen at bus 30364	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 30365	: Pg=9.0, Qg=0.0 -> Pg=9.0, Qg=0.0
% INFO    : Gen at bus 30365	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 30368	: Pg=0.0, Qg=0.0 -> Pg=48.765, Qg=0.0
% INFO    : Gen at bus 30368	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30372	: Pg=0.0, Qg=0.0 -> Pg=137.125, Qg=48.61
% INFO    : Gen at bus 30372	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 30373	: Pg=0.0, Qg=0.0 -> Pg=140.285, Qg=48.61
% INFO    : Gen at bus 30373	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 30374	: Pg=243.28, Qg=80.48 -> Pg=166.365, Qg=48.61
% INFO    : Gen at bus 30374	: Vg=1.0248 -> Vg=1.0
% INFO    : Gen at bus 30375	: Pg=92.04, Qg=80.48 -> Pg=166.365, Qg=48.61
% INFO    : Gen at bus 30375	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 30376	: Pg=243.27, Qg=80.48 -> Pg=155.555, Qg=48.61
% INFO    : Gen at bus 30376	: Vg=1.0217 -> Vg=1.0
% INFO    : Gen at bus 30377	: Pg=78.7, Qg=80.48 -> Pg=159.695, Qg=48.61
% INFO    : Gen at bus 30377	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 30379	: Pg=27.34, Qg=37.67 -> Pg=50.125, Qg=14.73
% INFO    : Gen at bus 30379	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30379	: Pg=32.67, Qg=37.67 -> Pg=47.49, Qg=14.73
% INFO    : Gen at bus 30379	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30379	: Pg=73.7, Qg=37.67 -> Pg=46.435, Qg=14.73
% INFO    : Gen at bus 30379	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30381	: Pg=0.0, Qg=0.0 -> Pg=14.665, Qg=0.0
% INFO    : Gen at bus 30381	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30386	: Pg=150.0, Qg=31.95 -> Pg=150.0, Qg=5.175
% INFO    : Gen at bus 30386	: Vg=0.9936 -> Vg=1.0
% INFO    : Gen at bus 30390	: Pg=148.02, Qg=-16.5 -> Pg=81.83, Qg=29.575
% INFO    : Gen at bus 30390	: Vg=1.0356 -> Vg=1.0
% INFO    : Gen at bus 30391	: Pg=77.52, Qg=-16.5 -> Pg=87.555, Qg=29.575
% INFO    : Gen at bus 30391	: Vg=1.0359 -> Vg=1.0
% INFO    : Gen at bus 30392	: Pg=148.02, Qg=-16.5 -> Pg=105.71, Qg=29.575
% INFO    : Gen at bus 30392	: Vg=1.0355 -> Vg=1.0
% INFO    : Gen at bus 30393	: Pg=148.02, Qg=-16.5 -> Pg=86.575, Qg=29.575
% INFO    : Gen at bus 30393	: Vg=1.0363 -> Vg=1.0
% INFO    : Gen at bus 30394	: Pg=148.02, Qg=-16.5 -> Pg=89.165, Qg=29.575
% INFO    : Gen at bus 30394	: Vg=1.0355 -> Vg=1.0
% INFO    : Gen at bus 30395	: Pg=26.95, Qg=-13.3 -> Pg=72.495, Qg=23.84
% INFO    : Gen at bus 30395	: Vg=1.0359 -> Vg=1.0
% INFO    : Gen at bus 30396	: Pg=84.65, Qg=-9.44 -> Pg=62.585, Qg=16.91
% INFO    : Gen at bus 30396	: Vg=1.0359 -> Vg=1.0
% INFO    : Gen at bus 30397	: Pg=0.0, Qg=0.0 -> Pg=47.365, Qg=16.91
% INFO    : Gen at bus 30397	: Vg=1.0369 -> Vg=1.0
% INFO    : Gen at bus 30398	: Pg=10.05, Qg=0.0 -> Pg=10.05, Qg=0.0
% INFO    : Gen at bus 30398	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30398	: Pg=7.46, Qg=0.0 -> Pg=7.46, Qg=0.0
% INFO    : Gen at bus 30398	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30404	: Pg=132.26, Qg=30.44 -> Pg=97.225, Qg=26.43
% INFO    : Gen at bus 30404	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 30405	: Pg=64.33, Qg=30.44 -> Pg=97.59, Qg=26.43
% INFO    : Gen at bus 30405	: Vg=1.0297 -> Vg=1.0
% INFO    : Gen at bus 30406	: Pg=132.26, Qg=30.44 -> Pg=91.77, Qg=26.43
% INFO    : Gen at bus 30406	: Vg=1.0269 -> Vg=1.0
% INFO    : Gen at bus 30407	: Pg=132.26, Qg=30.44 -> Pg=95.315, Qg=26.43
% INFO    : Gen at bus 30407	: Vg=1.0294 -> Vg=1.0
% INFO    : Gen at bus 30408	: Pg=50.74, Qg=30.44 -> Pg=90.795, Qg=26.43
% INFO    : Gen at bus 30408	: Vg=1.0282 -> Vg=1.0
% INFO    : Gen at bus 30409	: Pg=16.69, Qg=30.44 -> Pg=73.77, Qg=26.43
% INFO    : Gen at bus 30409	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 30410	: Pg=96.07, Qg=30.44 -> Pg=56.46, Qg=19.195
% INFO    : Gen at bus 30410	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 30411	: Pg=96.07, Qg=30.44 -> Pg=59.635, Qg=19.195
% INFO    : Gen at bus 30411	: Vg=1.0298 -> Vg=1.0
% INFO    : Gen at bus 30412	: Pg=96.07, Qg=30.44 -> Pg=70.84, Qg=19.195
% INFO    : Gen at bus 30412	: Vg=1.0293 -> Vg=1.0
% INFO    : Gen at bus 30413	: Pg=33.22, Qg=30.44 -> Pg=64.14, Qg=19.195
% INFO    : Gen at bus 30413	: Vg=1.0289 -> Vg=1.0
% INFO    : Gen at bus 30414	: Pg=39.7, Qg=30.44 -> Pg=67.38, Qg=19.195
% INFO    : Gen at bus 30414	: Vg=1.0289 -> Vg=1.0
% INFO    : Gen at bus 30415	: Pg=96.07, Qg=30.44 -> Pg=55.17, Qg=19.195
% INFO    : Gen at bus 30415	: Vg=1.0307 -> Vg=1.0
% INFO    : Gen at bus 30421	: Pg=0.0, Qg=0.0 -> Pg=148.705, Qg=44.095
% INFO    : Gen at bus 30421	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 30422	: Pg=77.55, Qg=112.78 -> Pg=147.935, Qg=44.095
% INFO    : Gen at bus 30422	: Vg=0.9893 -> Vg=1.0
% INFO    : Gen at bus 30423	: Pg=74.04, Qg=112.78 -> Pg=127.335, Qg=44.095
% INFO    : Gen at bus 30423	: Vg=0.9858 -> Vg=1.0
% INFO    : Gen at bus 30425	: Pg=16.89, Qg=0.0 -> Pg=16.89, Qg=0.0
% INFO    : Gen at bus 30425	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30426	: Pg=13.06, Qg=0.0 -> Pg=13.06, Qg=0.0
% INFO    : Gen at bus 30426	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30426	: Pg=12.86, Qg=0.0 -> Pg=12.86, Qg=0.0
% INFO    : Gen at bus 30426	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30426	: Pg=0.0, Qg=0.0 -> Pg=9.11, Qg=0.0
% INFO    : Gen at bus 30426	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30427	: Pg=17.88, Qg=0.0 -> Pg=17.88, Qg=0.0
% INFO    : Gen at bus 30427	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30428	: Pg=41.91, Qg=-5.34 -> Pg=35.48, Qg=12.54
% INFO    : Gen at bus 30428	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30428	: Pg=62.74, Qg=-5.34 -> Pg=41.795, Qg=12.54
% INFO    : Gen at bus 30428	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30428	: Pg=22.9, Qg=-5.34 -> Pg=42.49, Qg=12.54
% INFO    : Gen at bus 30428	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30428	: Pg=62.74, Qg=-5.34 -> Pg=37.49, Qg=12.54
% INFO    : Gen at bus 30428	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30429	: Pg=8.86, Qg=24.12 -> Pg=33.9, Qg=11.905
% INFO    : Gen at bus 30429	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30429	: Pg=42.72, Qg=24.12 -> Pg=37.35, Qg=11.905
% INFO    : Gen at bus 30429	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30429	: Pg=59.57, Qg=24.12 -> Pg=40.085, Qg=11.905
% INFO    : Gen at bus 30429	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30429	: Pg=21.23, Qg=24.12 -> Pg=40.085, Qg=11.905
% INFO    : Gen at bus 30429	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30429	: Pg=25.95, Qg=24.12 -> Pg=42.445, Qg=11.905
% INFO    : Gen at bus 30429	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30429	: Pg=59.57, Qg=24.12 -> Pg=44.385, Qg=11.905
% INFO    : Gen at bus 30429	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30434	: Pg=0.0, Qg=0.0 -> Pg=22.235, Qg=0.0
% INFO    : Gen at bus 30434	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30434	: Pg=21.81, Qg=0.0 -> Pg=21.81, Qg=0.0
% INFO    : Gen at bus 30434	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30434	: Pg=21.02, Qg=0.0 -> Pg=21.02, Qg=0.0
% INFO    : Gen at bus 30434	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 30435	: Pg=6.54, Qg=0.0 -> Pg=6.54, Qg=0.0
% INFO    : Gen at bus 30435	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30441	: Pg=199.39, Qg=101.9 -> Pg=118.235, Qg=39.84
% INFO    : Gen at bus 30441	: Vg=1.0039 -> Vg=1.0
% INFO    : Gen at bus 30442	: Pg=58.57, Qg=101.9 -> Pg=127.92, Qg=39.84
% INFO    : Gen at bus 30442	: Vg=1.0073 -> Vg=1.0
% INFO    : Gen at bus 30443	: Pg=199.39, Qg=101.9 -> Pg=113.65, Qg=39.84
% INFO    : Gen at bus 30443	: Vg=1.0041 -> Vg=1.0
% INFO    : Gen at bus 30445	: Pg=0.0, Qg=0.0 -> Pg=6.22, Qg=0.0
% INFO    : Gen at bus 30445	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30445	: Pg=7.93, Qg=0.0 -> Pg=7.93, Qg=0.0
% INFO    : Gen at bus 30445	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 30446	: Pg=9.1, Qg=0.0 -> Pg=9.1, Qg=0.0
% INFO    : Gen at bus 30446	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 30447	: Pg=6.05, Qg=0.0 -> Pg=6.05, Qg=0.0
% INFO    : Gen at bus 30447	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 30451	: Pg=0.0, Qg=0.0 -> Pg=115.565, Qg=29.015
% INFO    : Gen at bus 30451	: Vg=1.0348 -> Vg=1.0
% INFO    : Gen at bus 30452	: Pg=173.23, Qg=66.52 -> Pg=173.23, Qg=29.015
% INFO    : Gen at bus 30452	: Vg=1.0583 -> Vg=1.0
% INFO    : Gen at bus 30453	: Pg=173.23, Qg=66.52 -> Pg=173.23, Qg=29.015
% INFO    : Gen at bus 30453	: Vg=1.0539 -> Vg=1.0
% INFO    : Gen at bus 30454	: Pg=137.19, Qg=66.52 -> Pg=137.19, Qg=29.015
% INFO    : Gen at bus 30454	: Vg=1.0582 -> Vg=1.0
% INFO    : Gen at bus 30455	: Pg=115.71, Qg=66.52 -> Pg=115.71, Qg=29.015
% INFO    : Gen at bus 30455	: Vg=1.0564 -> Vg=1.0
% INFO    : Gen at bus 30456	: Pg=173.23, Qg=66.52 -> Pg=173.23, Qg=29.015
% INFO    : Gen at bus 30456	: Vg=1.063 -> Vg=1.0
% INFO    : Gen at bus 30460	: Pg=114.53, Qg=58.53 -> Pg=79.205, Qg=22.885
% INFO    : Gen at bus 30460	: Vg=0.9639 -> Vg=1.0
% INFO    : Gen at bus 30461	: Pg=114.53, Qg=58.53 -> Pg=69.805, Qg=22.885
% INFO    : Gen at bus 30461	: Vg=0.9691 -> Vg=1.0
% INFO    : Gen at bus 40695	: Pg=61.25, Qg=31.3 -> Pg=45.44, Qg=12.235
% INFO    : Gen at bus 40695	: Vg=0.9927 -> Vg=1.0
% INFO    : Gen at bus 40696	: Pg=0.0, Qg=0.0 -> Pg=36.91, Qg=12.235
% INFO    : Gen at bus 40696	: Vg=1.0254 -> Vg=1.0
% INFO    : Gen at bus 40697	: Pg=61.25, Qg=31.3 -> Pg=41.24, Qg=12.235
% INFO    : Gen at bus 40697	: Vg=0.9938 -> Vg=1.0
% INFO    : Gen at bus 40700	: Pg=95.91, Qg=0.0 -> Pg=95.91, Qg=0.0
% INFO    : Gen at bus 40700	: Vg=1.0227 -> Vg=1.0
% INFO    : Gen at bus 40701	: Pg=90.97, Qg=0.0 -> Pg=90.97, Qg=0.0
% INFO    : Gen at bus 40701	: Vg=1.0227 -> Vg=1.0
% INFO    : Gen at bus 40702	: Pg=115.9, Qg=0.0 -> Pg=115.9, Qg=0.0
% INFO    : Gen at bus 40702	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 40703	: Pg=16.0, Qg=-6.72 -> Pg=37.805, Qg=12.035
% INFO    : Gen at bus 40703	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 40703	: Pg=60.25, Qg=-6.72 -> Pg=38.76, Qg=12.035
% INFO    : Gen at bus 40703	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 40706	: Pg=0.0, Qg=0.0 -> Pg=17.02, Qg=5.37
% INFO    : Gen at bus 40706	: Vg=1.025 -> Vg=1.0
% INFO    : Gen at bus 40706	: Pg=26.89, Qg=13.74 -> Pg=16.11, Qg=5.37
% INFO    : Gen at bus 40706	: Vg=1.025 -> Vg=1.0
% INFO    : Gen at bus 40707	: Pg=26.89, Qg=13.74 -> Pg=19.225, Qg=5.37
% INFO    : Gen at bus 40707	: Vg=1.0334 -> Vg=1.0
% INFO    : Gen at bus 40707	: Pg=26.89, Qg=13.74 -> Pg=15.34, Qg=5.37
% INFO    : Gen at bus 40707	: Vg=1.0334 -> Vg=1.0
% INFO    : Gen at bus 40708	: Pg=7.47, Qg=-0.83 -> Pg=5.03, Qg=1.495
% INFO    : Gen at bus 40708	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40708	: Pg=0.0, Qg=0.0 -> Pg=4.26, Qg=1.495
% INFO    : Gen at bus 40708	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40709	: Pg=7.47, Qg=-0.83 -> Pg=4.735, Qg=1.495
% INFO    : Gen at bus 40709	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 40710	: Pg=7.47, Qg=-0.83 -> Pg=4.315, Qg=1.495
% INFO    : Gen at bus 40710	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 40712	: Pg=23.96, Qg=13.82 -> Pg=23.96, Qg=6.03
% INFO    : Gen at bus 40712	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 40715	: Pg=63.42, Qg=21.13 -> Pg=63.42, Qg=3.425
% INFO    : Gen at bus 40715	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40719	: Pg=10.0, Qg=3.84 -> Pg=10.0, Qg=1.675
% INFO    : Gen at bus 40719	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40719	: Pg=8.16, Qg=3.84 -> Pg=8.16, Qg=1.675
% INFO    : Gen at bus 40719	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40719	: Pg=0.0, Qg=0.0 -> Pg=5.555, Qg=1.675
% INFO    : Gen at bus 40719	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40719	: Pg=0.0, Qg=0.0 -> Pg=7.035, Qg=1.675
% INFO    : Gen at bus 40719	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40721	: Pg=9.99, Qg=0.0 -> Pg=9.99, Qg=0.0
% INFO    : Gen at bus 40721	: Vg=1.023 -> Vg=1.0
% INFO    : Gen at bus 40722	: Pg=47.92, Qg=-5.34 -> Pg=35.255, Qg=9.575
% INFO    : Gen at bus 40722	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40722	: Pg=86.35, Qg=-9.62 -> Pg=62.35, Qg=17.255
% INFO    : Gen at bus 40722	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40723	: Pg=0.0, Qg=0.0 -> Pg=32.26, Qg=9.575
% INFO    : Gen at bus 40723	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40723	: Pg=47.92, Qg=-5.34 -> Pg=32.245, Qg=9.575
% INFO    : Gen at bus 40723	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40723	: Pg=0.0, Qg=0.0 -> Pg=27.775, Qg=9.575
% INFO    : Gen at bus 40723	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40723	: Pg=47.92, Qg=-5.34 -> Pg=27.265, Qg=9.575
% INFO    : Gen at bus 40723	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40723	: Pg=0.0, Qg=0.0 -> Pg=30.885, Qg=9.72
% INFO    : Gen at bus 40723	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40723	: Pg=48.65, Qg=-5.42 -> Pg=26.9, Qg=9.72
% INFO    : Gen at bus 40723	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40728	: Pg=0.0, Qg=0.0 -> Pg=16.95, Qg=4.49
% INFO    : Gen at bus 40728	: Vg=1.0188 -> Vg=1.0
% INFO    : Gen at bus 40732	: Pg=41.0, Qg=6.86 -> Pg=41.0, Qg=8.535
% INFO    : Gen at bus 40732	: Vg=0.9923 -> Vg=1.0
% INFO    : Gen at bus 40733	: Pg=45.25, Qg=6.86 -> Pg=45.25, Qg=8.535
% INFO    : Gen at bus 40733	: Vg=0.9923 -> Vg=1.0
% INFO    : Gen at bus 40734	: Pg=0.0, Qg=0.0 -> Pg=32.335, Qg=8.535
% INFO    : Gen at bus 40734	: Vg=1.0275 -> Vg=1.0
% INFO    : Gen at bus 40735	: Pg=44.51, Qg=6.86 -> Pg=44.51, Qg=8.535
% INFO    : Gen at bus 40735	: Vg=0.998 -> Vg=1.0
% INFO    : Gen at bus 40736	: Pg=50.96, Qg=6.86 -> Pg=50.96, Qg=8.535
% INFO    : Gen at bus 40736	: Vg=0.9935 -> Vg=1.0
% INFO    : Gen at bus 40739	: Pg=0.0, Qg=0.0 -> Pg=91.67, Qg=29.05
% INFO    : Gen at bus 40739	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 40740	: Pg=145.41, Qg=74.31 -> Pg=80.72, Qg=29.05
% INFO    : Gen at bus 40740	: Vg=1.0116 -> Vg=1.0
% INFO    : Gen at bus 40741	: Pg=0.0, Qg=0.0 -> Pg=43.0, Qg=11.52
% INFO    : Gen at bus 40741	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 40742	: Pg=57.66, Qg=29.47 -> Pg=34.04, Qg=11.52
% INFO    : Gen at bus 40742	: Vg=1.0094 -> Vg=1.0
% INFO    : Gen at bus 40743	: Pg=57.66, Qg=29.47 -> Pg=36.09, Qg=11.52
% INFO    : Gen at bus 40743	: Vg=1.0121 -> Vg=1.0
% INFO    : Gen at bus 40744	: Pg=53.78, Qg=27.49 -> Pg=30.48, Qg=10.75
% INFO    : Gen at bus 40744	: Vg=1.0102 -> Vg=1.0
% INFO    : Gen at bus 40745	: Pg=53.78, Qg=27.49 -> Pg=37.85, Qg=10.75
% INFO    : Gen at bus 40745	: Vg=1.0102 -> Vg=1.0
% INFO    : Gen at bus 40747	: Pg=13.6, Qg=0.0 -> Pg=13.6, Qg=0.0
% INFO    : Gen at bus 40747	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40750	: Pg=0.0, Qg=0.0 -> Pg=10.59, Qg=0.0
% INFO    : Gen at bus 40750	: Vg=0.9939 -> Vg=1.0
% INFO    : Gen at bus 40756	: Pg=102.1, Qg=-26.2 -> Pg=167.32, Qg=46.96
% INFO    : Gen at bus 40756	: Vg=1.0198 -> Vg=1.0
% INFO    : Gen at bus 40757	: Pg=0.0, Qg=0.0 -> Pg=153.19, Qg=46.96
% INFO    : Gen at bus 40757	: Vg=1.047 -> Vg=1.0
% INFO    : Gen at bus 40758	: Pg=112.59, Qg=-26.2 -> Pg=172.565, Qg=46.96
% INFO    : Gen at bus 40758	: Vg=1.0186 -> Vg=1.0
% INFO    : Gen at bus 40763	: Pg=191.96, Qg=191.48 -> Pg=298.42, Qg=70.675
% INFO    : Gen at bus 40763	: Vg=0.9983 -> Vg=1.0
% INFO    : Gen at bus 40764	: Pg=238.61, Qg=191.48 -> Pg=262.305, Qg=70.675
% INFO    : Gen at bus 40764	: Vg=0.9988 -> Vg=1.0
% INFO    : Gen at bus 40768	: Pg=34.42, Qg=48.72 -> Pg=117.715, Qg=35.085
% INFO    : Gen at bus 40768	: Vg=1.0247 -> Vg=1.0
% INFO    : Gen at bus 40769	: Pg=203.17, Qg=48.72 -> Pg=124.99, Qg=35.085
% INFO    : Gen at bus 40769	: Vg=1.0238 -> Vg=1.0
% INFO    : Gen at bus 40770	: Pg=81.27, Qg=38.03 -> Pg=57.39, Qg=14.035
% INFO    : Gen at bus 40770	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 40771	: Pg=0.0, Qg=0.0 -> Pg=24.09, Qg=7.355
% INFO    : Gen at bus 40771	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40772	: Pg=42.6, Qg=19.93 -> Pg=29.89, Qg=7.355
% INFO    : Gen at bus 40772	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 40772	: Pg=42.6, Qg=19.93 -> Pg=31.455, Qg=7.355
% INFO    : Gen at bus 40772	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 40773	: Pg=0.0, Qg=0.0 -> Pg=24.965, Qg=7.355
% INFO    : Gen at bus 40773	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 40774	: Pg=15.35, Qg=0.0 -> Pg=15.35, Qg=0.0
% INFO    : Gen at bus 40774	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40775	: Pg=8.86, Qg=3.53 -> Pg=8.86, Qg=1.54
% INFO    : Gen at bus 40775	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40775	: Pg=0.0, Qg=0.0 -> Pg=31.38, Qg=9.095
% INFO    : Gen at bus 40775	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40778	: Pg=21.12, Qg=0.0 -> Pg=21.12, Qg=0.0
% INFO    : Gen at bus 40778	: Vg=1.0326 -> Vg=1.0
% INFO    : Gen at bus 40778	: Pg=18.7, Qg=0.0 -> Pg=18.7, Qg=0.0
% INFO    : Gen at bus 40778	: Vg=1.0326 -> Vg=1.0
% INFO    : Gen at bus 40779	: Pg=25.8, Qg=0.0 -> Pg=25.8, Qg=0.0
% INFO    : Gen at bus 40779	: Vg=1.0337 -> Vg=1.0
% INFO    : Gen at bus 40779	: Pg=25.02, Qg=0.0 -> Pg=25.02, Qg=0.0
% INFO    : Gen at bus 40779	: Vg=1.0337 -> Vg=1.0
% INFO    : Gen at bus 40780	: Pg=20.34, Qg=0.0 -> Pg=20.34, Qg=0.0
% INFO    : Gen at bus 40780	: Vg=1.0342 -> Vg=1.0
% INFO    : Gen at bus 40782	: Pg=55.28, Qg=13.42 -> Pg=55.28, Qg=2.175
% INFO    : Gen at bus 40782	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40786	: Pg=558.91, Qg=21.71 -> Pg=483.145, Qg=138.13
% INFO    : Gen at bus 40786	: Vg=1.0025 -> Vg=1.0
% INFO    : Gen at bus 40787	: Pg=799.84, Qg=21.71 -> Pg=571.125, Qg=138.13
% INFO    : Gen at bus 40787	: Vg=1.0011 -> Vg=1.0
% INFO    : Gen at bus 40788	: Pg=308.1, Qg=21.71 -> Pg=549.715, Qg=138.13
% INFO    : Gen at bus 40788	: Vg=1.0026 -> Vg=1.0
% INFO    : Gen at bus 40790	: Pg=12.48, Qg=0.0 -> Pg=12.48, Qg=0.0
% INFO    : Gen at bus 40790	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40793	: Pg=22.35, Qg=0.0 -> Pg=22.35, Qg=0.0
% INFO    : Gen at bus 40793	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40793	: Pg=19.0, Qg=0.0 -> Pg=19.0, Qg=0.0
% INFO    : Gen at bus 40793	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40793	: Pg=0.0, Qg=0.0 -> Pg=15.795, Qg=0.0
% INFO    : Gen at bus 40793	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40793	: Pg=19.12, Qg=0.0 -> Pg=19.12, Qg=0.0
% INFO    : Gen at bus 40793	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40793	: Pg=14.42, Qg=0.0 -> Pg=14.42, Qg=0.0
% INFO    : Gen at bus 40793	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40793	: Pg=0.0, Qg=0.0 -> Pg=19.2, Qg=0.0
% INFO    : Gen at bus 40793	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40797	: Pg=63.12, Qg=-5.92 -> Pg=121.98, Qg=36.525
% INFO    : Gen at bus 40797	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 40798	: Pg=86.75, Qg=-5.92 -> Pg=133.795, Qg=36.525
% INFO    : Gen at bus 40798	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 40799	: Pg=0.0, Qg=0.0 -> Pg=127.205, Qg=36.525
% INFO    : Gen at bus 40799	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 40800	: Pg=0.0, Qg=0.0 -> Pg=126.225, Qg=36.525
% INFO    : Gen at bus 40800	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 40801	: Pg=107.62, Qg=-5.92 -> Pg=134.405, Qg=36.525
% INFO    : Gen at bus 40801	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 40802	: Pg=182.79, Qg=-5.92 -> Pg=122.975, Qg=36.525
% INFO    : Gen at bus 40802	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 40803	: Pg=52.88, Qg=-5.89 -> Pg=32.635, Qg=10.57
% INFO    : Gen at bus 40803	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 40804	: Pg=52.88, Qg=-5.89 -> Pg=29.33, Qg=10.57
% INFO    : Gen at bus 40804	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 40806	: Pg=26.84, Qg=-2.99 -> Pg=16.905, Qg=5.365
% INFO    : Gen at bus 40806	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 40806	: Pg=0.0, Qg=0.0 -> Pg=16.525, Qg=5.365
% INFO    : Gen at bus 40806	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 40806	: Pg=26.84, Qg=-2.99 -> Pg=18.93, Qg=5.365
% INFO    : Gen at bus 40806	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 40806	: Pg=0.0, Qg=0.0 -> Pg=16.47, Qg=5.365
% INFO    : Gen at bus 40806	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 40808	: Pg=15.31, Qg=0.0 -> Pg=15.31, Qg=0.0
% INFO    : Gen at bus 40808	: Vg=1.0431 -> Vg=1.0
% INFO    : Gen at bus 40813	: Pg=129.6, Qg=66.24 -> Pg=94.535, Qg=25.9
% INFO    : Gen at bus 40813	: Vg=0.9999 -> Vg=1.0
% INFO    : Gen at bus 40814	: Pg=129.6, Qg=66.24 -> Pg=80.775, Qg=25.9
% INFO    : Gen at bus 40814	: Vg=0.9983 -> Vg=1.0
% INFO    : Gen at bus 40815	: Pg=129.6, Qg=66.24 -> Pg=84.82, Qg=25.9
% INFO    : Gen at bus 40815	: Vg=0.9963 -> Vg=1.0
% INFO    : Gen at bus 40816	: Pg=74.0, Qg=37.82 -> Pg=49.955, Qg=14.785
% INFO    : Gen at bus 40816	: Vg=0.9954 -> Vg=1.0
% INFO    : Gen at bus 40817	: Pg=74.0, Qg=37.82 -> Pg=42.455, Qg=14.785
% INFO    : Gen at bus 40817	: Vg=0.9976 -> Vg=1.0
% INFO    : Gen at bus 40818	: Pg=74.0, Qg=37.82 -> Pg=44.79, Qg=14.785
% INFO    : Gen at bus 40818	: Vg=0.9972 -> Vg=1.0
% INFO    : Gen at bus 40824	: Pg=15.6, Qg=11.32 -> Pg=67.415, Qg=24.08
% INFO    : Gen at bus 40824	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 40825	: Pg=120.51, Qg=11.32 -> Pg=87.35, Qg=24.08
% INFO    : Gen at bus 40825	: Vg=1.0235 -> Vg=1.0
% INFO    : Gen at bus 40826	: Pg=120.51, Qg=11.32 -> Pg=71.205, Qg=24.08
% INFO    : Gen at bus 40826	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 40827	: Pg=120.51, Qg=11.32 -> Pg=84.235, Qg=24.08
% INFO    : Gen at bus 40827	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 40828	: Pg=120.51, Qg=11.32 -> Pg=73.31, Qg=24.08
% INFO    : Gen at bus 40828	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 40829	: Pg=120.51, Qg=11.32 -> Pg=71.84, Qg=24.08
% INFO    : Gen at bus 40829	: Vg=1.0236 -> Vg=1.0
% INFO    : Gen at bus 40833	: Pg=5.43, Qg=0.0 -> Pg=5.43, Qg=0.0
% INFO    : Gen at bus 40833	: Vg=1.0449 -> Vg=1.0
% INFO    : Gen at bus 40834	: Pg=10.31, Qg=0.0 -> Pg=10.31, Qg=0.0
% INFO    : Gen at bus 40834	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40836	: Pg=0.0, Qg=0.0 -> Pg=165.89, Qg=45.875
% INFO    : Gen at bus 40836	: Vg=1.0359 -> Vg=1.0
% INFO    : Gen at bus 40837	: Pg=200.03, Qg=-21.87 -> Pg=145.835, Qg=45.875
% INFO    : Gen at bus 40837	: Vg=1.0303 -> Vg=1.0
% INFO    : Gen at bus 40838	: Pg=229.6, Qg=-21.87 -> Pg=148.365, Qg=45.875
% INFO    : Gen at bus 40838	: Vg=1.0347 -> Vg=1.0
% INFO    : Gen at bus 40843	: Pg=1397.5, Qg=516.38 -> Pg=854.15, Qg=200.66
% INFO    : Gen at bus 40843	: Vg=1.0648 -> Vg=1.0
% INFO    : Gen at bus 40844	: Pg=1397.5, Qg=516.38 -> Pg=849.41, Qg=200.66
% INFO    : Gen at bus 40844	: Vg=1.0626 -> Vg=1.0
% INFO    : Gen at bus 40845	: Pg=1397.32, Qg=143.68 -> Pg=924.69, Qg=200.66
% INFO    : Gen at bus 40845	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 40849	: Pg=119.09, Qg=0.0 -> Pg=119.09, Qg=0.0
% INFO    : Gen at bus 40849	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 40850	: Pg=0.0, Qg=0.0 -> Pg=87.775, Qg=0.0
% INFO    : Gen at bus 40850	: Vg=1.0242 -> Vg=1.0
% INFO    : Gen at bus 40854	: Pg=172.6, Qg=80.76 -> Pg=122.995, Qg=29.81
% INFO    : Gen at bus 40854	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 40855	: Pg=109.95, Qg=51.45 -> Pg=82.08, Qg=18.99
% INFO    : Gen at bus 40855	: Vg=1.0321 -> Vg=1.0
% INFO    : Gen at bus 40856	: Pg=109.95, Qg=51.45 -> Pg=69.135, Qg=18.99
% INFO    : Gen at bus 40856	: Vg=1.0312 -> Vg=1.0
% INFO    : Gen at bus 40857	: Pg=109.95, Qg=51.45 -> Pg=64.965, Qg=18.99
% INFO    : Gen at bus 40857	: Vg=1.0299 -> Vg=1.0
% INFO    : Gen at bus 40858	: Pg=26.89, Qg=12.58 -> Pg=15.66, Qg=4.645
% INFO    : Gen at bus 40858	: Vg=1.0276 -> Vg=1.0
% INFO    : Gen at bus 40859	: Pg=26.89, Qg=-3.29 -> Pg=18.97, Qg=4.645
% INFO    : Gen at bus 40859	: Vg=0.9872 -> Vg=1.0
% INFO    : Gen at bus 40861	: Pg=0.0, Qg=0.0 -> Pg=22.23, Qg=6.23
% INFO    : Gen at bus 40861	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40861	: Pg=31.17, Qg=15.93 -> Pg=17.83, Qg=6.23
% INFO    : Gen at bus 40861	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40863	: Pg=9.16, Qg=4.68 -> Pg=6.16, Qg=1.83
% INFO    : Gen at bus 40863	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 40865	: Pg=84.65, Qg=43.26 -> Pg=50.56, Qg=16.91
% INFO    : Gen at bus 40865	: Vg=1.0425 -> Vg=1.0
% INFO    : Gen at bus 40868	: Pg=214.49, Qg=-23.91 -> Pg=135.82, Qg=42.855
% INFO    : Gen at bus 40868	: Vg=1.0205 -> Vg=1.0
% INFO    : Gen at bus 40869	: Pg=181.41, Qg=-23.91 -> Pg=122.58, Qg=42.855
% INFO    : Gen at bus 40869	: Vg=1.0184 -> Vg=1.0
% INFO    : Gen at bus 40870	: Pg=214.49, Qg=-23.91 -> Pg=146.68, Qg=42.855
% INFO    : Gen at bus 40870	: Vg=1.0183 -> Vg=1.0
% INFO    : Gen at bus 40871	: Pg=8.96, Qg=4.58 -> Pg=6.25, Qg=1.79
% INFO    : Gen at bus 40871	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40873	: Pg=20.0, Qg=0.0 -> Pg=20.0, Qg=0.0
% INFO    : Gen at bus 40873	: Vg=1.0043 -> Vg=1.0
% INFO    : Gen at bus 40878	: Pg=439.66, Qg=52.57 -> Pg=276.97, Qg=75.93
% INFO    : Gen at bus 40878	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 40879	: Pg=0.0, Qg=0.0 -> Pg=295.785, Qg=75.93
% INFO    : Gen at bus 40879	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 40880	: Pg=293.05, Qg=52.57 -> Pg=247.86, Qg=75.93
% INFO    : Gen at bus 40880	: Vg=1.0049 -> Vg=1.0
% INFO    : Gen at bus 40881	: Pg=439.66, Qg=52.57 -> Pg=254.75, Qg=75.93
% INFO    : Gen at bus 40881	: Vg=1.0056 -> Vg=1.0
% INFO    : Gen at bus 40884	: Pg=66.56, Qg=-22.9 -> Pg=134.935, Qg=41.06
% INFO    : Gen at bus 40884	: Vg=1.0103 -> Vg=1.0
% INFO    : Gen at bus 40885	: Pg=135.15, Qg=-22.9 -> Pg=144.49, Qg=41.06
% INFO    : Gen at bus 40885	: Vg=1.0065 -> Vg=1.0
% INFO    : Gen at bus 40886	: Pg=102.22, Qg=-22.9 -> Pg=117.05, Qg=41.06
% INFO    : Gen at bus 40886	: Vg=1.0068 -> Vg=1.0
% INFO    : Gen at bus 40887	: Pg=185.44, Qg=-22.9 -> Pg=146.535, Qg=41.06
% INFO    : Gen at bus 40887	: Vg=1.0008 -> Vg=1.0
% INFO    : Gen at bus 40888	: Pg=91.97, Qg=-22.9 -> Pg=147.64, Qg=41.06
% INFO    : Gen at bus 40888	: Vg=1.0076 -> Vg=1.0
% INFO    : Gen at bus 40889	: Pg=99.64, Qg=-22.9 -> Pg=151.475, Qg=41.06
% INFO    : Gen at bus 40889	: Vg=1.0075 -> Vg=1.0
% INFO    : Gen at bus 40892	: Pg=100.42, Qg=26.84 -> Pg=72.535, Qg=20.065
% INFO    : Gen at bus 40892	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 40893	: Pg=100.42, Qg=26.84 -> Pg=61.925, Qg=20.065
% INFO    : Gen at bus 40893	: Vg=1.0282 -> Vg=1.0
% INFO    : Gen at bus 40894	: Pg=100.42, Qg=26.84 -> Pg=68.93, Qg=20.065
% INFO    : Gen at bus 40894	: Vg=1.0267 -> Vg=1.0
% INFO    : Gen at bus 40895	: Pg=100.42, Qg=26.84 -> Pg=57.485, Qg=20.065
% INFO    : Gen at bus 40895	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 40896	: Pg=100.42, Qg=26.84 -> Pg=68.03, Qg=20.065
% INFO    : Gen at bus 40896	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 40897	: Pg=100.42, Qg=26.84 -> Pg=66.63, Qg=20.065
% INFO    : Gen at bus 40897	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 40903	: Pg=220.1, Qg=34.14 -> Pg=122.63, Qg=43.98
% INFO    : Gen at bus 40903	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 40904	: Pg=220.1, Qg=34.14 -> Pg=150.73, Qg=43.98
% INFO    : Gen at bus 40904	: Vg=1.0355 -> Vg=1.0
% INFO    : Gen at bus 40905	: Pg=220.1, Qg=34.14 -> Pg=147.54, Qg=43.98
% INFO    : Gen at bus 40905	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 40906	: Pg=220.1, Qg=34.14 -> Pg=144.21, Qg=43.98
% INFO    : Gen at bus 40906	: Vg=1.0371 -> Vg=1.0
% INFO    : Gen at bus 40907	: Pg=220.1, Qg=34.14 -> Pg=126.265, Qg=43.98
% INFO    : Gen at bus 40907	: Vg=1.0362 -> Vg=1.0
% INFO    : Gen at bus 40908	: Pg=104.6, Qg=34.14 -> Pg=161.18, Qg=43.98
% INFO    : Gen at bus 40908	: Vg=1.0365 -> Vg=1.0
% INFO    : Gen at bus 40912	: Pg=43.12, Qg=-24.51 -> Pg=130.365, Qg=43.95
% INFO    : Gen at bus 40912	: Vg=0.9732 -> Vg=1.0
% INFO    : Gen at bus 40913	: Pg=219.95, Qg=-24.51 -> Pg=123.645, Qg=43.95
% INFO    : Gen at bus 40913	: Vg=0.9796 -> Vg=1.0
% INFO    : Gen at bus 40914	: Pg=0.0, Qg=0.0 -> Pg=156.135, Qg=43.95
% INFO    : Gen at bus 40914	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 40915	: Pg=219.95, Qg=-24.51 -> Pg=141.2, Qg=43.95
% INFO    : Gen at bus 40915	: Vg=0.9797 -> Vg=1.0
% INFO    : Gen at bus 40916	: Pg=219.95, Qg=-24.51 -> Pg=145.795, Qg=43.95
% INFO    : Gen at bus 40916	: Vg=0.9796 -> Vg=1.0
% INFO    : Gen at bus 40917	: Pg=219.95, Qg=-24.51 -> Pg=161.945, Qg=43.95
% INFO    : Gen at bus 40917	: Vg=0.9795 -> Vg=1.0
% INFO    : Gen at bus 40918	: Pg=0.0, Qg=0.0 -> Pg=19.18, Qg=0.0
% INFO    : Gen at bus 40918	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40919	: Pg=9.4, Qg=0.0 -> Pg=9.4, Qg=0.0
% INFO    : Gen at bus 40919	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40921	: Pg=6.67, Qg=0.0 -> Pg=6.67, Qg=0.0
% INFO    : Gen at bus 40921	: Vg=0.9984 -> Vg=1.0
% INFO    : Gen at bus 40924	: Pg=178.48, Qg=-10.71 -> Pg=178.48, Qg=36.63
% INFO    : Gen at bus 40924	: Vg=1.0445 -> Vg=1.0
% INFO    : Gen at bus 40925	: Pg=218.67, Qg=-10.71 -> Pg=218.67, Qg=36.63
% INFO    : Gen at bus 40925	: Vg=1.044 -> Vg=1.0
% INFO    : Gen at bus 40926	: Pg=0.0, Qg=0.0 -> Pg=131.56, Qg=36.63
% INFO    : Gen at bus 40926	: Vg=1.0453 -> Vg=1.0
% INFO    : Gen at bus 40927	: Pg=179.81, Qg=-10.71 -> Pg=179.81, Qg=36.63
% INFO    : Gen at bus 40927	: Vg=1.0444 -> Vg=1.0
% INFO    : Gen at bus 40928	: Pg=0.0, Qg=0.0 -> Pg=142.315, Qg=36.63
% INFO    : Gen at bus 40928	: Vg=1.0453 -> Vg=1.0
% INFO    : Gen at bus 40929	: Pg=0.0, Qg=0.0 -> Pg=147.145, Qg=36.63
% INFO    : Gen at bus 40929	: Vg=1.0453 -> Vg=1.0
% INFO    : Gen at bus 40934	: Pg=281.05, Qg=94.06 -> Pg=161.61, Qg=48.54
% INFO    : Gen at bus 40934	: Vg=1.0079 -> Vg=1.0
% INFO    : Gen at bus 40935	: Pg=281.05, Qg=94.06 -> Pg=211.33, Qg=48.54
% INFO    : Gen at bus 40935	: Vg=1.005 -> Vg=1.0
% INFO    : Gen at bus 40936	: Pg=168.44, Qg=94.06 -> Pg=183.95, Qg=48.54
% INFO    : Gen at bus 40936	: Vg=1.0048 -> Vg=1.0
% INFO    : Gen at bus 40937	: Pg=130.04, Qg=94.06 -> Pg=204.05, Qg=48.54
% INFO    : Gen at bus 40937	: Vg=1.0092 -> Vg=1.0
% INFO    : Gen at bus 40943	: Pg=113.14, Qg=21.8 -> Pg=78.025, Qg=22.605
% INFO    : Gen at bus 40943	: Vg=0.9853 -> Vg=1.0
% INFO    : Gen at bus 40944	: Pg=0.0, Qg=0.0 -> Pg=82.755, Qg=22.605
% INFO    : Gen at bus 40944	: Vg=1.0253 -> Vg=1.0
% INFO    : Gen at bus 40945	: Pg=52.88, Qg=21.8 -> Pg=30.405, Qg=10.57
% INFO    : Gen at bus 40945	: Vg=0.9933 -> Vg=1.0
% INFO    : Gen at bus 40946	: Pg=52.88, Qg=21.8 -> Pg=36.07, Qg=10.57
% INFO    : Gen at bus 40946	: Vg=0.9924 -> Vg=1.0
% INFO    : Gen at bus 40947	: Pg=49.23, Qg=-9.37 -> Pg=49.23, Qg=2.25
% INFO    : Gen at bus 40947	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40949	: Pg=10.36, Qg=4.99 -> Pg=10.36, Qg=2.175
% INFO    : Gen at bus 40949	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 40950	: Pg=0.0, Qg=0.0 -> Pg=11.77, Qg=0.0
% INFO    : Gen at bus 40950	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40950	: Pg=0.0, Qg=0.0 -> Pg=12.575, Qg=0.0
% INFO    : Gen at bus 40950	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 40953	: Pg=0.0, Qg=0.0 -> Pg=63.17, Qg=16.715
% INFO    : Gen at bus 40953	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40954	: Pg=7.96, Qg=3.8 -> Pg=7.96, Qg=1.655
% INFO    : Gen at bus 40954	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 40954	: Pg=6.36, Qg=3.8 -> Pg=6.36, Qg=1.655
% INFO    : Gen at bus 40954	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 40954	: Pg=0.0, Qg=0.0 -> Pg=5.925, Qg=1.655
% INFO    : Gen at bus 40954	: Vg=1.053 -> Vg=1.0
% INFO    : Gen at bus 40959	: Pg=205.49, Qg=50.99 -> Pg=135.28, Qg=41.06
% INFO    : Gen at bus 40959	: Vg=1.005 -> Vg=1.0
% INFO    : Gen at bus 40960	: Pg=205.49, Qg=50.99 -> Pg=140.2, Qg=41.06
% INFO    : Gen at bus 40960	: Vg=1.0025 -> Vg=1.0
% INFO    : Gen at bus 40961	: Pg=205.49, Qg=50.99 -> Pg=128.05, Qg=41.06
% INFO    : Gen at bus 40961	: Vg=1.004 -> Vg=1.0
% INFO    : Gen at bus 40962	: Pg=0.0, Qg=0.0 -> Pg=147.08, Qg=41.06
% INFO    : Gen at bus 40962	: Vg=1.0368 -> Vg=1.0
% INFO    : Gen at bus 40963	: Pg=205.49, Qg=50.99 -> Pg=126.7, Qg=41.06
% INFO    : Gen at bus 40963	: Vg=1.004 -> Vg=1.0
% INFO    : Gen at bus 40964	: Pg=0.0, Qg=0.0 -> Pg=151.4, Qg=41.06
% INFO    : Gen at bus 40964	: Vg=1.0368 -> Vg=1.0
% INFO    : Gen at bus 40966	: Pg=7.63, Qg=0.0 -> Pg=7.63, Qg=0.0
% INFO    : Gen at bus 40966	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40969	: Pg=189.28, Qg=-21.1 -> Pg=140.365, Qg=37.82
% INFO    : Gen at bus 40969	: Vg=1.0262 -> Vg=1.0
% INFO    : Gen at bus 40970	: Pg=189.28, Qg=-21.1 -> Pg=125.69, Qg=37.82
% INFO    : Gen at bus 40970	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 40971	: Pg=189.28, Qg=-21.1 -> Pg=127.69, Qg=37.82
% INFO    : Gen at bus 40971	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 40972	: Pg=189.28, Qg=-21.1 -> Pg=134.275, Qg=37.82
% INFO    : Gen at bus 40972	: Vg=1.0267 -> Vg=1.0
% INFO    : Gen at bus 40973	: Pg=189.28, Qg=-21.1 -> Pg=107.215, Qg=37.82
% INFO    : Gen at bus 40973	: Vg=1.0256 -> Vg=1.0
% INFO    : Gen at bus 40974	: Pg=189.28, Qg=-21.1 -> Pg=128.46, Qg=37.82
% INFO    : Gen at bus 40974	: Vg=1.0262 -> Vg=1.0
% INFO    : Gen at bus 40976	: Pg=11.0, Qg=0.0 -> Pg=11.0, Qg=0.0
% INFO    : Gen at bus 40976	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 40977	: Pg=7.8, Qg=0.0 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 40977	: Vg=1.0272 -> Vg=1.0
% INFO    : Gen at bus 40984	: Pg=173.23, Qg=29.4 -> Pg=173.23, Qg=29.015
% INFO    : Gen at bus 40984	: Vg=1.0263 -> Vg=1.0
% INFO    : Gen at bus 40985	: Pg=90.55, Qg=29.4 -> Pg=90.55, Qg=29.015
% INFO    : Gen at bus 40985	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 40986	: Pg=142.76, Qg=29.4 -> Pg=142.76, Qg=29.015
% INFO    : Gen at bus 40986	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 40987	: Pg=131.55, Qg=29.4 -> Pg=131.55, Qg=29.015
% INFO    : Gen at bus 40987	: Vg=1.0262 -> Vg=1.0
% INFO    : Gen at bus 40988	: Pg=0.0, Qg=0.0 -> Pg=100.525, Qg=29.015
% INFO    : Gen at bus 40988	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 40989	: Pg=0.0, Qg=0.0 -> Pg=111.445, Qg=29.015
% INFO    : Gen at bus 40989	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 40990	: Pg=0.0, Qg=0.0 -> Pg=19.56, Qg=0.0
% INFO    : Gen at bus 40990	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40993	: Pg=0.0, Qg=0.0 -> Pg=132.44, Qg=47.295
% INFO    : Gen at bus 40993	: Vg=1.0322 -> Vg=1.0
% INFO    : Gen at bus 40994	: Pg=84.5, Qg=120.97 -> Pg=159.345, Qg=47.295
% INFO    : Gen at bus 40994	: Vg=1.0396 -> Vg=1.0
% INFO    : Gen at bus 40995	: Pg=0.0, Qg=0.0 -> Pg=141.75, Qg=47.295
% INFO    : Gen at bus 40995	: Vg=1.0322 -> Vg=1.0
% INFO    : Gen at bus 40996	: Pg=9.97, Qg=0.0 -> Pg=9.97, Qg=0.0
% INFO    : Gen at bus 40996	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 40997	: Pg=15.61, Qg=0.0 -> Pg=15.61, Qg=0.0
% INFO    : Gen at bus 40997	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 41000	: Pg=33.95, Qg=117.34 -> Pg=130.55, Qg=45.875
% INFO    : Gen at bus 41000	: Vg=1.0409 -> Vg=1.0
% INFO    : Gen at bus 41001	: Pg=0.0, Qg=0.0 -> Pg=139.19, Qg=45.875
% INFO    : Gen at bus 41001	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 41002	: Pg=0.0, Qg=0.0 -> Pg=172.495, Qg=45.875
% INFO    : Gen at bus 41002	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 41005	: Pg=11.6, Qg=0.0 -> Pg=11.6, Qg=0.0
% INFO    : Gen at bus 41005	: Vg=1.0388 -> Vg=1.0
% INFO    : Gen at bus 41009	: Pg=116.48, Qg=21.08 -> Pg=130.755, Qg=43.41
% INFO    : Gen at bus 41009	: Vg=1.0272 -> Vg=1.0
% INFO    : Gen at bus 41010	: Pg=217.25, Qg=21.08 -> Pg=144.055, Qg=43.41
% INFO    : Gen at bus 41010	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 41011	: Pg=217.25, Qg=21.08 -> Pg=161.055, Qg=43.41
% INFO    : Gen at bus 41011	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 41014	: Pg=0.0, Qg=0.0 -> Pg=11.715, Qg=0.0
% INFO    : Gen at bus 41014	: Vg=0.9971 -> Vg=1.0
% INFO    : Gen at bus 41016	: Pg=11.82, Qg=0.0 -> Pg=11.82, Qg=0.0
% INFO    : Gen at bus 41016	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 41017	: Pg=7.28, Qg=-1.44 -> Pg=7.28, Qg=0.345
% INFO    : Gen at bus 41017	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 50360	: Pg=229.9, Qg=42.75 -> Pg=139.995, Qg=45.935
% INFO    : Gen at bus 50360	: Vg=1.0285 -> Vg=1.0
% INFO    : Gen at bus 50361	: Pg=0.0, Qg=0.0 -> Pg=157.465, Qg=45.935
% INFO    : Gen at bus 50361	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 50362	: Pg=196.76, Qg=42.75 -> Pg=137.2, Qg=45.935
% INFO    : Gen at bus 50362	: Vg=1.0273 -> Vg=1.0
% INFO    : Gen at bus 50363	: Pg=229.9, Qg=42.75 -> Pg=145.24, Qg=45.935
% INFO    : Gen at bus 50363	: Vg=1.0264 -> Vg=1.0
% INFO    : Gen at bus 50364	: Pg=0.0, Qg=0.0 -> Pg=150.08, Qg=45.935
% INFO    : Gen at bus 50364	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 50365	: Pg=229.9, Qg=42.75 -> Pg=145.985, Qg=45.935
% INFO    : Gen at bus 50365	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 50366	: Pg=7.47, Qg=3.82 -> Pg=5.385, Qg=1.495
% INFO    : Gen at bus 50366	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 50367	: Pg=57.86, Qg=27.07 -> Pg=32.22, Qg=9.99
% INFO    : Gen at bus 50367	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 50369	: Pg=0.0, Qg=0.0 -> Pg=4.98, Qg=1.475
% INFO    : Gen at bus 50369	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 50369	: Pg=0.0, Qg=0.0 -> Pg=8.345, Qg=2.485
% INFO    : Gen at bus 50369	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 50369	: Pg=12.45, Qg=-1.39 -> Pg=9.025, Qg=2.485
% INFO    : Gen at bus 50369	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 50374	: Pg=43.22, Qg=6.35 -> Pg=25.63, Qg=8.635
% INFO    : Gen at bus 50374	: Vg=1.0053 -> Vg=1.0
% INFO    : Gen at bus 50374	: Pg=43.22, Qg=6.35 -> Pg=26.37, Qg=8.635
% INFO    : Gen at bus 50374	: Vg=1.0053 -> Vg=1.0
% INFO    : Gen at bus 50375	: Pg=43.22, Qg=6.35 -> Pg=27.475, Qg=8.635
% INFO    : Gen at bus 50375	: Vg=1.0047 -> Vg=1.0
% INFO    : Gen at bus 50375	: Pg=43.22, Qg=6.35 -> Pg=30.63, Qg=8.635
% INFO    : Gen at bus 50375	: Vg=1.0047 -> Vg=1.0
% INFO    : Gen at bus 50376	: Pg=43.22, Qg=12.71 -> Pg=28.505, Qg=8.635
% INFO    : Gen at bus 50376	: Vg=1.0071 -> Vg=1.0
% INFO    : Gen at bus 50379	: Pg=11.93, Qg=-0.74 -> Pg=11.93, Qg=2.51
% INFO    : Gen at bus 50379	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 50379	: Pg=15.0, Qg=-0.74 -> Pg=15.0, Qg=2.51
% INFO    : Gen at bus 50379	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 50382	: Pg=495.45, Qg=35.11 -> Pg=345.55, Qg=85.915
% INFO    : Gen at bus 50382	: Vg=1.0438 -> Vg=1.0
% INFO    : Gen at bus 50385	: Pg=816.67, Qg=-100.04 -> Pg=467.135, Qg=141.04
% INFO    : Gen at bus 50385	: Vg=1.0159 -> Vg=1.0
% INFO    : Gen at bus 50386	: Pg=816.67, Qg=-100.04 -> Pg=460.33, Qg=141.04
% INFO    : Gen at bus 50386	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 50387	: Pg=0.0, Qg=0.0 -> Pg=5.0, Qg=1.205
% INFO    : Gen at bus 50387	: Vg=0.9881 -> Vg=1.0
% INFO    : Gen at bus 50387	: Pg=6.97, Qg=3.26 -> Pg=5.07, Qg=1.205
% INFO    : Gen at bus 50387	: Vg=0.9881 -> Vg=1.0
% INFO    : Gen at bus 50390	: Pg=16.05, Qg=0.0 -> Pg=16.05, Qg=0.0
% INFO    : Gen at bus 50390	: Vg=1.0485 -> Vg=1.0
% INFO    : Gen at bus 50390	: Pg=17.46, Qg=0.0 -> Pg=17.46, Qg=0.0
% INFO    : Gen at bus 50390	: Vg=1.0485 -> Vg=1.0
% INFO    : Gen at bus 50391	: Pg=9.49, Qg=0.0 -> Pg=9.49, Qg=0.0
% INFO    : Gen at bus 50391	: Vg=1.0484 -> Vg=1.0
% INFO    : Gen at bus 50393	: Pg=0.0, Qg=0.0 -> Pg=7.565, Qg=0.0
% INFO    : Gen at bus 50393	: Vg=1.0031 -> Vg=1.0
% INFO    : Gen at bus 50393	: Pg=10.08, Qg=0.0 -> Pg=10.08, Qg=0.0
% INFO    : Gen at bus 50393	: Vg=1.0031 -> Vg=1.0
% INFO    : Gen at bus 50397	: Pg=523.59, Qg=-59.59 -> Pg=297.4, Qg=90.425
% INFO    : Gen at bus 50397	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 50398	: Pg=523.6, Qg=-59.59 -> Pg=348.595, Qg=90.425
% INFO    : Gen at bus 50398	: Vg=1.0122 -> Vg=1.0
% INFO    : Gen at bus 50399	: Pg=523.6, Qg=-59.59 -> Pg=290.775, Qg=90.425
% INFO    : Gen at bus 50399	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 50402	: Pg=215.45, Qg=19.3 -> Pg=157.22, Qg=43.05
% INFO    : Gen at bus 50402	: Vg=1.0118 -> Vg=1.0
% INFO    : Gen at bus 50403	: Pg=215.45, Qg=19.3 -> Pg=151.42, Qg=43.05
% INFO    : Gen at bus 50403	: Vg=1.0113 -> Vg=1.0
% INFO    : Gen at bus 50404	: Pg=215.45, Qg=19.3 -> Pg=119.905, Qg=43.05
% INFO    : Gen at bus 50404	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 50409	: Pg=160.85, Qg=43.35 -> Pg=160.85, Qg=7.025
% INFO    : Gen at bus 50409	: Vg=0.9953 -> Vg=1.0
% INFO    : Gen at bus 50412	: Pg=0.0, Qg=0.0 -> Pg=5.785, Qg=2.02
% INFO    : Gen at bus 50412	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 50412	: Pg=10.09, Qg=5.16 -> Pg=7.03, Qg=2.02
% INFO    : Gen at bus 50412	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 50413	: Pg=10.09, Qg=5.16 -> Pg=6.83, Qg=2.02
% INFO    : Gen at bus 50413	: Vg=1.07 -> Vg=1.0
% INFO    : Gen at bus 50418	: Pg=103.88, Qg=-12.72 -> Pg=71.31, Qg=17.94
% INFO    : Gen at bus 50418	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 50419	: Pg=103.88, Qg=-12.72 -> Pg=57.94, Qg=17.94
% INFO    : Gen at bus 50419	: Vg=1.0323 -> Vg=1.0
% INFO    : Gen at bus 50421	: Pg=91.74, Qg=21.73 -> Pg=91.74, Qg=3.52
% INFO    : Gen at bus 50421	: Vg=0.9912 -> Vg=1.0
% INFO    : Gen at bus 50424	: Pg=69.72, Qg=35.63 -> Pg=42.265, Qg=13.93
% INFO    : Gen at bus 50424	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 50424	: Pg=69.72, Qg=35.63 -> Pg=49.27, Qg=13.93
% INFO    : Gen at bus 50424	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 50433	: Pg=127.66, Qg=-20.74 -> Pg=127.66, Qg=4.965
% INFO    : Gen at bus 50433	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 50434	: Pg=0.0, Qg=0.0 -> Pg=12.075, Qg=0.655
% INFO    : Gen at bus 50434	: Vg=1.0398 -> Vg=1.0
% INFO    : Gen at bus 50437	: Pg=0.0, Qg=0.0 -> Pg=10.205, Qg=2.79
% INFO    : Gen at bus 50437	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 50437	: Pg=0.0, Qg=0.0 -> Pg=8.63, Qg=2.79
% INFO    : Gen at bus 50437	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 50437	: Pg=13.94, Qg=7.13 -> Pg=9.545, Qg=2.79
% INFO    : Gen at bus 50437	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=45.32, Qg=9.7 -> Pg=26.255, Qg=7.825
% INFO    : Gen at bus 50440	: Vg=1.0062 -> Vg=1.0
% INFO    : Gen at bus 50440	: Pg=45.32, Qg=9.7 -> Pg=25.83, Qg=7.825
% INFO    : Gen at bus 50440	: Vg=1.0062 -> Vg=1.0
% INFO    : Gen at bus 50441	: Pg=45.32, Qg=9.7 -> Pg=27.28, Qg=7.825
% INFO    : Gen at bus 50441	: Vg=1.0056 -> Vg=1.0
% INFO    : Gen at bus 50441	: Pg=45.32, Qg=9.7 -> Pg=26.135, Qg=7.825
% INFO    : Gen at bus 50441	: Vg=1.0056 -> Vg=1.0
% INFO    : Gen at bus 50442	: Pg=31.67, Qg=14.82 -> Pg=21.9, Qg=5.47
% INFO    : Gen at bus 50442	: Vg=1.0099 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=70.71, Qg=3.82 -> Pg=40.48, Qg=14.13
% INFO    : Gen at bus 50443	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=70.71, Qg=3.82 -> Pg=39.205, Qg=14.13
% INFO    : Gen at bus 50443	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=70.71, Qg=3.82 -> Pg=42.7, Qg=14.13
% INFO    : Gen at bus 50443	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=92.66, Qg=3.82 -> Pg=66.445, Qg=18.51
% INFO    : Gen at bus 50443	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=92.65, Qg=3.82 -> Pg=64.225, Qg=18.51
% INFO    : Gen at bus 50443	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 50443	: Pg=92.65, Qg=3.82 -> Pg=58.77, Qg=18.51
% INFO    : Gen at bus 50443	: Vg=1.0241 -> Vg=1.0
% INFO    : Gen at bus 50448	: Pg=516.54, Qg=241.69 -> Pg=382.18, Qg=89.205
% INFO    : Gen at bus 50448	: Vg=1.0307 -> Vg=1.0
% INFO    : Gen at bus 50449	: Pg=0.0, Qg=0.0 -> Pg=327.725, Qg=89.205
% INFO    : Gen at bus 50449	: Vg=1.0289 -> Vg=1.0
% INFO    : Gen at bus 50451	: Pg=15.93, Qg=8.14 -> Pg=11.69, Qg=3.18
% INFO    : Gen at bus 50451	: Vg=1.0415 -> Vg=1.0
% INFO    : Gen at bus 50451	: Pg=15.93, Qg=8.14 -> Pg=9.835, Qg=3.18
% INFO    : Gen at bus 50451	: Vg=1.0415 -> Vg=1.0
% INFO    : Gen at bus 50451	: Pg=15.93, Qg=8.14 -> Pg=11.01, Qg=3.18
% INFO    : Gen at bus 50451	: Vg=1.0415 -> Vg=1.0
% INFO    : Gen at bus 50457	: Pg=0.0, Qg=0.0 -> Pg=27.24, Qg=7.96
% INFO    : Gen at bus 50457	: Vg=1.0427 -> Vg=1.0
% INFO    : Gen at bus 50457	: Pg=39.84, Qg=-4.44 -> Pg=22.99, Qg=7.96
% INFO    : Gen at bus 50457	: Vg=1.0427 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=30.16, Qg=-2.48 -> Pg=30.16, Qg=-2.48
% INFO    : Gen at bus 50458	: Vg=1.0412 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=39.06, Qg=-2.48 -> Pg=39.06, Qg=-2.48
% INFO    : Gen at bus 50458	: Vg=1.0412 -> Vg=1.0
% INFO    : Gen at bus 50458	: Pg=43.01, Qg=-2.48 -> Pg=43.01, Qg=-2.48
% INFO    : Gen at bus 50458	: Vg=1.0412 -> Vg=1.0
% INFO    : Gen at bus 53215	: Pg=0.0, Qg=0.0 -> Pg=287.21, Qg=79.465
% INFO    : Gen at bus 53215	: Vg=1.0319 -> Vg=1.0
% INFO    : Gen at bus 53216	: Pg=81.26, Qg=-56.36 -> Pg=268.245, Qg=79.465
% INFO    : Gen at bus 53216	: Vg=0.9775 -> Vg=1.0
% INFO    : Gen at bus 53217	: Pg=144.41, Qg=-56.36 -> Pg=299.82, Qg=79.465
% INFO    : Gen at bus 53217	: Vg=0.9714 -> Vg=1.0
% INFO    : Gen at bus 53218	: Pg=63.07, Qg=-56.36 -> Pg=259.15, Qg=79.465
% INFO    : Gen at bus 53218	: Vg=0.9778 -> Vg=1.0
% INFO    : Gen at bus 53222	: Pg=15.0, Qg=-0.74 -> Pg=15.0, Qg=2.51
% INFO    : Gen at bus 53222	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 53222	: Pg=13.03, Qg=-0.74 -> Pg=13.03, Qg=2.51
% INFO    : Gen at bus 53222	: Vg=1.0212 -> Vg=1.0
% INFO    : Gen at bus 53223	: Pg=8.14, Qg=-0.46 -> Pg=8.14, Qg=1.555
% INFO    : Gen at bus 53223	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 53223	: Pg=7.44, Qg=-0.46 -> Pg=7.44, Qg=1.555
% INFO    : Gen at bus 53223	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 53224	: Pg=4.59, Qg=-0.46 -> Pg=4.59, Qg=1.555
% INFO    : Gen at bus 53224	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 53224	: Pg=6.42, Qg=-0.39 -> Pg=6.42, Qg=1.34
% INFO    : Gen at bus 53224	: Vg=1.018 -> Vg=1.0
% INFO    : Gen at bus 53226	: Pg=0.0, Qg=0.0 -> Pg=35.915, Qg=1.74
% INFO    : Gen at bus 53226	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53233	: Pg=255.96, Qg=119.76 -> Pg=155.125, Qg=44.205
% INFO    : Gen at bus 53233	: Vg=1.0236 -> Vg=1.0
% INFO    : Gen at bus 53236	: Pg=7.54, Qg=-0.92 -> Pg=4.995, Qg=1.305
% INFO    : Gen at bus 53236	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53236	: Pg=7.54, Qg=-0.92 -> Pg=5.24, Qg=1.305
% INFO    : Gen at bus 53236	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53236	: Pg=0.0, Qg=0.0 -> Pg=5.45, Qg=1.305
% INFO    : Gen at bus 53236	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53236	: Pg=0.0, Qg=0.0 -> Pg=4.94, Qg=1.305
% INFO    : Gen at bus 53236	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53236	: Pg=0.0, Qg=0.0 -> Pg=4.865, Qg=1.305
% INFO    : Gen at bus 53236	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53236	: Pg=0.0, Qg=0.0 -> Pg=4.38, Qg=1.305
% INFO    : Gen at bus 53236	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53241	: Pg=105.57, Qg=53.95 -> Pg=63.055, Qg=21.09
% INFO    : Gen at bus 53241	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 53242	: Pg=88.47, Qg=45.22 -> Pg=58.79, Qg=17.68
% INFO    : Gen at bus 53242	: Vg=1.0078 -> Vg=1.0
% INFO    : Gen at bus 53243	: Pg=88.47, Qg=45.22 -> Pg=50.25, Qg=17.68
% INFO    : Gen at bus 53243	: Vg=1.009 -> Vg=1.0
% INFO    : Gen at bus 53244	: Pg=88.47, Qg=45.22 -> Pg=58.9, Qg=17.68
% INFO    : Gen at bus 53244	: Vg=1.0078 -> Vg=1.0
% INFO    : Gen at bus 53246	: Pg=43.82, Qg=-3.07 -> Pg=29.315, Qg=8.76
% INFO    : Gen at bus 53246	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53246	: Pg=43.82, Qg=-3.07 -> Pg=24.87, Qg=8.76
% INFO    : Gen at bus 53246	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53248	: Pg=0.0, Qg=0.0 -> Pg=9.65, Qg=2.985
% INFO    : Gen at bus 53248	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 53248	: Pg=14.94, Qg=7.64 -> Pg=9.645, Qg=2.985
% INFO    : Gen at bus 53248	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 53248	: Pg=14.94, Qg=7.64 -> Pg=9.735, Qg=2.985
% INFO    : Gen at bus 53248	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 53253	: Pg=215.79, Qg=67.79 -> Pg=135.43, Qg=43.115
% INFO    : Gen at bus 53253	: Vg=1.0353 -> Vg=1.0
% INFO    : Gen at bus 53254	: Pg=0.0, Qg=0.0 -> Pg=158.305, Qg=43.115
% INFO    : Gen at bus 53254	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 53255	: Pg=215.79, Qg=67.79 -> Pg=161.62, Qg=43.115
% INFO    : Gen at bus 53255	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 53261	: Pg=158.85, Qg=68.95 -> Pg=116.89, Qg=31.745
% INFO    : Gen at bus 53261	: Vg=1.0814 -> Vg=1.0
% INFO    : Gen at bus 53263	: Pg=0.0, Qg=0.0 -> Pg=11.155, Qg=0.0
% INFO    : Gen at bus 53263	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 53263	: Pg=12.0, Qg=0.0 -> Pg=12.0, Qg=0.0
% INFO    : Gen at bus 53263	: Vg=1.0117 -> Vg=1.0
% INFO    : Gen at bus 53264	: Pg=7.55, Qg=0.0 -> Pg=7.55, Qg=0.0
% INFO    : Gen at bus 53264	: Vg=1.0113 -> Vg=1.0
% INFO    : Gen at bus 53264	: Pg=7.5, Qg=0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 53264	: Vg=1.0113 -> Vg=1.0
% INFO    : Gen at bus 53268	: Pg=149.39, Qg=-16.65 -> Pg=103.88, Qg=29.85
% INFO    : Gen at bus 53268	: Vg=1.0065 -> Vg=1.0
% INFO    : Gen at bus 53269	: Pg=6.82, Qg=3.49 -> Pg=5.1, Qg=1.365
% INFO    : Gen at bus 53269	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 53269	: Pg=6.82, Qg=3.49 -> Pg=4.935, Qg=1.365
% INFO    : Gen at bus 53269	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 53270	: Pg=100.0, Qg=21.3 -> Pg=100.0, Qg=3.45
% INFO    : Gen at bus 53270	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 53277	: Pg=92.38, Qg=-14.75 -> Pg=92.38, Qg=3.53
% INFO    : Gen at bus 53277	: Vg=1.0199 -> Vg=1.0
% INFO    : Gen at bus 53279	: Pg=30.28, Qg=-3.37 -> Pg=18.505, Qg=6.05
% INFO    : Gen at bus 53279	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53279	: Pg=30.28, Qg=-3.37 -> Pg=21.155, Qg=6.05
% INFO    : Gen at bus 53279	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53279	: Pg=30.28, Qg=-3.37 -> Pg=17.225, Qg=6.05
% INFO    : Gen at bus 53279	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53279	: Pg=0.0, Qg=0.0 -> Pg=22.295, Qg=6.05
% INFO    : Gen at bus 53279	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53284	: Pg=26.89, Qg=13.74 -> Pg=17.14, Qg=5.37
% INFO    : Gen at bus 53284	: Vg=1.0378 -> Vg=1.0
% INFO    : Gen at bus 53285	: Pg=26.89, Qg=13.74 -> Pg=17.39, Qg=5.37
% INFO    : Gen at bus 53285	: Vg=1.0378 -> Vg=1.0
% INFO    : Gen at bus 53288	: Pg=0.0, Qg=0.0 -> Pg=32.91, Qg=9.255
% INFO    : Gen at bus 53288	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53289	: Pg=46.31, Qg=-5.16 -> Pg=27.275, Qg=9.255
% INFO    : Gen at bus 53289	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 53289	: Pg=46.31, Qg=-5.16 -> Pg=34.725, Qg=9.255
% INFO    : Gen at bus 53289	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 53289	: Pg=46.31, Qg=-5.16 -> Pg=27.625, Qg=9.255
% INFO    : Gen at bus 53289	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 53292	: Pg=142.92, Qg=0.91 -> Pg=107.51, Qg=28.555
% INFO    : Gen at bus 53292	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 53293	: Pg=142.92, Qg=0.91 -> Pg=86.07, Qg=28.555
% INFO    : Gen at bus 53293	: Vg=1.0159 -> Vg=1.0
% INFO    : Gen at bus 53297	: Pg=814.78, Qg=-99.81 -> Pg=512.18, Qg=140.71
% INFO    : Gen at bus 53297	: Vg=1.0257 -> Vg=1.0
% INFO    : Gen at bus 53298	: Pg=288.48, Qg=-99.81 -> Pg=547.295, Qg=140.71
% INFO    : Gen at bus 53298	: Vg=1.0232 -> Vg=1.0
% INFO    : Gen at bus 53300	: Pg=43.36, Qg=0.0 -> Pg=43.36, Qg=0.0
% INFO    : Gen at bus 53300	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53301	: Pg=4.59, Qg=0.0 -> Pg=4.59, Qg=0.0
% INFO    : Gen at bus 53301	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53301	: Pg=23.18, Qg=0.0 -> Pg=23.18, Qg=0.0
% INFO    : Gen at bus 53301	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 53303	: Pg=8.17, Qg=-0.91 -> Pg=6.015, Qg=1.63
% INFO    : Gen at bus 53303	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 53303	: Pg=8.17, Qg=-0.91 -> Pg=5.57, Qg=1.63
% INFO    : Gen at bus 53303	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 53303	: Pg=8.17, Qg=-0.91 -> Pg=5.085, Qg=1.63
% INFO    : Gen at bus 53303	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 53303	: Pg=33.36, Qg=-2.1 -> Pg=20.055, Qg=6.665
% INFO    : Gen at bus 53303	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 53303	: Pg=33.36, Qg=-2.1 -> Pg=18.92, Qg=6.665
% INFO    : Gen at bus 53303	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 53305	: Pg=51.12, Qg=-5.7 -> Pg=29.62, Qg=10.215
% INFO    : Gen at bus 53305	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53305	: Pg=51.12, Qg=-5.7 -> Pg=32.58, Qg=10.215
% INFO    : Gen at bus 53305	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 53305	: Pg=51.12, Qg=-5.7 -> Pg=36.88, Qg=10.215
% INFO    : Gen at bus 53305	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60629	: Pg=0.0, Qg=0.0 -> Pg=125.25, Qg=6.935
% INFO    : Gen at bus 60629	: Vg=1.0258 -> Vg=1.0
% INFO    : Gen at bus 60631	: Pg=71.04, Qg=-11.11 -> Pg=71.04, Qg=3.005
% INFO    : Gen at bus 60631	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 60631	: Pg=63.78, Qg=-11.11 -> Pg=63.78, Qg=3.005
% INFO    : Gen at bus 60631	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 60635	: Pg=37.85, Qg=-4.22 -> Pg=25.165, Qg=7.56
% INFO    : Gen at bus 60635	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60635	: Pg=37.85, Qg=-4.22 -> Pg=23.68, Qg=7.56
% INFO    : Gen at bus 60635	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60635	: Pg=5.5, Qg=-4.22 -> Pg=21.47, Qg=7.56
% INFO    : Gen at bus 60635	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60635	: Pg=37.85, Qg=-4.22 -> Pg=25.915, Qg=7.56
% INFO    : Gen at bus 60635	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60635	: Pg=6.52, Qg=-4.22 -> Pg=21.98, Qg=7.56
% INFO    : Gen at bus 60635	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60635	: Pg=25.94, Qg=-4.22 -> Pg=22.225, Qg=7.56
% INFO    : Gen at bus 60635	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60646	: Pg=180.88, Qg=64.01 -> Pg=180.88, Qg=10.37
% INFO    : Gen at bus 60646	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 60651	: Pg=167.95, Qg=53.68 -> Pg=167.95, Qg=8.695
% INFO    : Gen at bus 60651	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 60656	: Pg=167.96, Qg=42.49 -> Pg=167.96, Qg=6.88
% INFO    : Gen at bus 60656	: Vg=1.0329 -> Vg=1.0
% INFO    : Gen at bus 60662	: Pg=542.89, Qg=101.42 -> Pg=390.01, Qg=93.76
% INFO    : Gen at bus 60662	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 60663	: Pg=542.89, Qg=101.42 -> Pg=344.21, Qg=93.76
% INFO    : Gen at bus 60663	: Vg=1.0244 -> Vg=1.0
% INFO    : Gen at bus 60664	: Pg=542.89, Qg=101.42 -> Pg=389.33, Qg=93.76
% INFO    : Gen at bus 60664	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 60668	: Pg=200.0, Qg=42.6 -> Pg=200.0, Qg=6.9
% INFO    : Gen at bus 60668	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 60670	: Pg=65.88, Qg=33.67 -> Pg=44.375, Qg=13.165
% INFO    : Gen at bus 60670	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 60670	: Pg=65.88, Qg=33.67 -> Pg=45.695, Qg=13.165
% INFO    : Gen at bus 60670	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 60670	: Pg=65.88, Qg=33.67 -> Pg=39.155, Qg=13.165
% INFO    : Gen at bus 60670	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 60670	: Pg=65.88, Qg=33.67 -> Pg=41.895, Qg=13.165
% INFO    : Gen at bus 60670	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 60670	: Pg=65.88, Qg=33.67 -> Pg=36.47, Qg=13.165
% INFO    : Gen at bus 60670	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 60670	: Pg=65.88, Qg=33.67 -> Pg=36.98, Qg=13.165
% INFO    : Gen at bus 60670	: Vg=1.0266 -> Vg=1.0
% INFO    : Gen at bus 60677	: Pg=190.92, Qg=89.33 -> Pg=111.245, Qg=32.97
% INFO    : Gen at bus 60677	: Vg=1.0088 -> Vg=1.0
% INFO    : Gen at bus 60678	: Pg=59.06, Qg=27.63 -> Pg=42.045, Qg=10.2
% INFO    : Gen at bus 60678	: Vg=1.0057 -> Vg=1.0
% INFO    : Gen at bus 60679	: Pg=64.44, Qg=-7.89 -> Pg=41.895, Qg=11.13
% INFO    : Gen at bus 60679	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60679	: Pg=64.44, Qg=-7.89 -> Pg=46.4, Qg=11.13
% INFO    : Gen at bus 60679	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60686	: Pg=57.03, Qg=32.79 -> Pg=135.41, Qg=43.18
% INFO    : Gen at bus 60686	: Vg=1.0132 -> Vg=1.0
% INFO    : Gen at bus 60687	: Pg=0.0, Qg=0.0 -> Pg=158.355, Qg=43.18
% INFO    : Gen at bus 60687	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 60688	: Pg=102.52, Qg=32.79 -> Pg=158.155, Qg=43.18
% INFO    : Gen at bus 60688	: Vg=1.014 -> Vg=1.0
% INFO    : Gen at bus 60689	: Pg=0.0, Qg=0.0 -> Pg=158.61, Qg=43.18
% INFO    : Gen at bus 60689	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 60690	: Pg=58.5, Qg=32.79 -> Pg=98.375, Qg=27.92
% INFO    : Gen at bus 60690	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 60691	: Pg=0.0, Qg=0.0 -> Pg=97.015, Qg=27.92
% INFO    : Gen at bus 60691	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 60692	: Pg=36.85, Qg=-4.11 -> Pg=27.405, Qg=7.36
% INFO    : Gen at bus 60692	: Vg=0.9891 -> Vg=1.0
% INFO    : Gen at bus 60695	: Pg=11.03, Qg=4.64 -> Pg=18.62, Qg=5.295
% INFO    : Gen at bus 60695	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 60695	: Pg=26.49, Qg=4.64 -> Pg=16.235, Qg=5.295
% INFO    : Gen at bus 60695	: Vg=1.0231 -> Vg=1.0
% INFO    : Gen at bus 60696	: Pg=21.66, Qg=8.95 -> Pg=14.69, Qg=3.745
% INFO    : Gen at bus 60696	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 60696	: Pg=21.66, Qg=8.95 -> Pg=16.005, Qg=3.745
% INFO    : Gen at bus 60696	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 60701	: Pg=69.05, Qg=15.97 -> Pg=69.05, Qg=2.585
% INFO    : Gen at bus 60701	: Vg=1.0202 -> Vg=1.0
% INFO    : Gen at bus 60702	: Pg=29.0, Qg=6.18 -> Pg=29.0, Qg=1.0
% INFO    : Gen at bus 60702	: Vg=1.0161 -> Vg=1.0
% INFO    : Gen at bus 60707	: Pg=231.75, Qg=-28.39 -> Pg=138.385, Qg=40.025
% INFO    : Gen at bus 60707	: Vg=0.9978 -> Vg=1.0
% INFO    : Gen at bus 60708	: Pg=231.75, Qg=-28.39 -> Pg=141.965, Qg=40.025
% INFO    : Gen at bus 60708	: Vg=0.9996 -> Vg=1.0
% INFO    : Gen at bus 60712	: Pg=250.8, Qg=53.42 -> Pg=250.8, Qg=8.65
% INFO    : Gen at bus 60712	: Vg=1.0121 -> Vg=1.0
% INFO    : Gen at bus 60716	: Pg=66.37, Qg=101.24 -> Pg=131.175, Qg=39.58
% INFO    : Gen at bus 60716	: Vg=1.0347 -> Vg=1.0
% INFO    : Gen at bus 60717	: Pg=87.06, Qg=101.24 -> Pg=141.525, Qg=39.58
% INFO    : Gen at bus 60717	: Vg=1.0388 -> Vg=1.0
% INFO    : Gen at bus 60721	: Pg=139.82, Qg=-28.89 -> Pg=139.82, Qg=6.92
% INFO    : Gen at bus 60721	: Vg=1.0268 -> Vg=1.0
% INFO    : Gen at bus 60722	: Pg=38.2, Qg=14.67 -> Pg=38.2, Qg=6.4
% INFO    : Gen at bus 60722	: Vg=1.039 -> Vg=1.0
% INFO    : Gen at bus 60727	: Pg=274.53, Qg=16.53 -> Pg=159.87, Qg=47.41
% INFO    : Gen at bus 60727	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60728	: Pg=274.53, Qg=16.53 -> Pg=193.1, Qg=47.41
% INFO    : Gen at bus 60728	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 60729	: Pg=11.62, Qg=5.44 -> Pg=8.62, Qg=2.01
% INFO    : Gen at bus 60729	: Vg=1.0211 -> Vg=1.0
% INFO    : Gen at bus 60730	: Pg=11.62, Qg=5.44 -> Pg=6.785, Qg=2.01
% INFO    : Gen at bus 60730	: Vg=1.0308 -> Vg=1.0
% INFO    : Gen at bus 60730	: Pg=11.62, Qg=5.44 -> Pg=6.815, Qg=2.01
% INFO    : Gen at bus 60730	: Vg=1.0308 -> Vg=1.0
% INFO    : Gen at bus 60731	: Pg=23.7, Qg=-2.64 -> Pg=16.395, Qg=4.735
% INFO    : Gen at bus 60731	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60731	: Pg=45.38, Qg=-5.06 -> Pg=25.97, Qg=9.065
% INFO    : Gen at bus 60731	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60732	: Pg=19.48, Qg=-5.06 -> Pg=32.19, Qg=9.065
% INFO    : Gen at bus 60732	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60732	: Pg=10.88, Qg=-5.06 -> Pg=27.89, Qg=9.065
% INFO    : Gen at bus 60732	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60732	: Pg=45.38, Qg=-5.06 -> Pg=27.205, Qg=9.065
% INFO    : Gen at bus 60732	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60732	: Pg=0.0, Qg=0.0 -> Pg=26.08, Qg=9.065
% INFO    : Gen at bus 60732	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60732	: Pg=45.38, Qg=-5.06 -> Pg=33.775, Qg=9.065
% INFO    : Gen at bus 60732	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60734	: Pg=28.33, Qg=-3.47 -> Pg=16.905, Qg=4.895
% INFO    : Gen at bus 60734	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60735	: Pg=28.33, Qg=-3.47 -> Pg=16.0, Qg=4.895
% INFO    : Gen at bus 60735	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60735	: Pg=28.33, Qg=-3.47 -> Pg=18.45, Qg=4.895
% INFO    : Gen at bus 60735	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60735	: Pg=28.33, Qg=-3.47 -> Pg=19.915, Qg=4.895
% INFO    : Gen at bus 60735	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60743	: Pg=0.0, Qg=0.0 -> Pg=5.56, Qg=1.31
% INFO    : Gen at bus 60743	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 60744	: Pg=21.54, Qg=10.6 -> Pg=21.54, Qg=4.625
% INFO    : Gen at bus 60744	: Vg=1.0276 -> Vg=1.0
% INFO    : Gen at bus 60746	: Pg=124.58, Qg=14.47 -> Pg=124.58, Qg=25.125
% INFO    : Gen at bus 60746	: Vg=1.0278 -> Vg=1.0
% INFO    : Gen at bus 60747	: Pg=94.45, Qg=14.47 -> Pg=94.45, Qg=25.125
% INFO    : Gen at bus 60747	: Vg=1.0278 -> Vg=1.0
% INFO    : Gen at bus 60751	: Pg=550.06, Qg=95.96 -> Pg=315.545, Qg=94.995
% INFO    : Gen at bus 60751	: Vg=1.0339 -> Vg=1.0
% INFO    : Gen at bus 60752	: Pg=76.79, Qg=39.24 -> Pg=46.785, Qg=15.34
% INFO    : Gen at bus 60752	: Vg=1.0475 -> Vg=1.0
% INFO    : Gen at bus 60752	: Pg=76.79, Qg=39.24 -> Pg=44.94, Qg=15.34
% INFO    : Gen at bus 60752	: Vg=1.0475 -> Vg=1.0
% INFO    : Gen at bus 60760	: Pg=142.31, Qg=34.51 -> Pg=142.31, Qg=5.59
% INFO    : Gen at bus 60760	: Vg=1.0054 -> Vg=1.0
% INFO    : Gen at bus 60763	: Pg=0.0, Qg=0.0 -> Pg=14.255, Qg=3.95
% INFO    : Gen at bus 60763	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 60763	: Pg=0.0, Qg=0.0 -> Pg=13.5, Qg=3.95
% INFO    : Gen at bus 60763	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 60764	: Pg=0.0, Qg=0.0 -> Pg=11.14, Qg=3.95
% INFO    : Gen at bus 60764	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 60765	: Pg=9.9, Qg=3.8 -> Pg=9.9, Qg=1.655
% INFO    : Gen at bus 60765	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 60765	: Pg=17.84, Qg=10.75 -> Pg=17.84, Qg=4.69
% INFO    : Gen at bus 60765	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 60766	: Pg=25.1, Qg=-8.56 -> Pg=50.535, Qg=15.34
% INFO    : Gen at bus 60766	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60766	: Pg=14.22, Qg=-8.56 -> Pg=45.095, Qg=15.34
% INFO    : Gen at bus 60766	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60773	: Pg=18.92, Qg=9.67 -> Pg=13.77, Qg=3.78
% INFO    : Gen at bus 60773	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60773	: Pg=18.92, Qg=9.67 -> Pg=11.61, Qg=3.78
% INFO    : Gen at bus 60773	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60773	: Pg=18.92, Qg=9.67 -> Pg=13.555, Qg=3.78
% INFO    : Gen at bus 60773	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60773	: Pg=18.92, Qg=9.67 -> Pg=14.2, Qg=3.78
% INFO    : Gen at bus 60773	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60773	: Pg=0.0, Qg=0.0 -> Pg=10.855, Qg=3.78
% INFO    : Gen at bus 60773	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60773	: Pg=0.0, Qg=0.0 -> Pg=13.895, Qg=3.78
% INFO    : Gen at bus 60773	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60775	: Pg=206.16, Qg=-25.25 -> Pg=136.665, Qg=35.605
% INFO    : Gen at bus 60775	: Vg=1.0155 -> Vg=1.0
% INFO    : Gen at bus 60776	: Pg=37.65, Qg=-4.61 -> Pg=27.49, Qg=6.5
% INFO    : Gen at bus 60776	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 60776	: Pg=37.65, Qg=-4.61 -> Pg=26.795, Qg=6.5
% INFO    : Gen at bus 60776	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 60780	: Pg=175.68, Qg=-28.8 -> Pg=175.68, Qg=6.9
% INFO    : Gen at bus 60780	: Vg=1.0329 -> Vg=1.0
% INFO    : Gen at bus 60783	: Pg=30.75, Qg=-2.11 -> Pg=30.75, Qg=7.2
% INFO    : Gen at bus 60783	: Vg=1.0153 -> Vg=1.0
% INFO    : Gen at bus 60784	: Pg=6.5, Qg=3.26 -> Pg=6.5, Qg=1.42
% INFO    : Gen at bus 60784	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 60784	: Pg=29.14, Qg=16.51 -> Pg=29.14, Qg=7.2
% INFO    : Gen at bus 60784	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 60788	: Pg=33.2, Qg=16.97 -> Pg=24.94, Qg=6.635
% INFO    : Gen at bus 60788	: Vg=1.0028 -> Vg=1.0
% INFO    : Gen at bus 60789	: Pg=33.2, Qg=16.97 -> Pg=21.37, Qg=6.635
% INFO    : Gen at bus 60789	: Vg=1.0028 -> Vg=1.0
% INFO    : Gen at bus 60791	: Pg=21.19, Qg=50.9 -> Pg=59.865, Qg=19.9
% INFO    : Gen at bus 60791	: Vg=1.0042 -> Vg=1.0
% INFO    : Gen at bus 60792	: Pg=99.59, Qg=50.9 -> Pg=68.41, Qg=19.9
% INFO    : Gen at bus 60792	: Vg=1.003 -> Vg=1.0
% INFO    : Gen at bus 60793	: Pg=0.0, Qg=0.0 -> Pg=24.455, Qg=6.635
% INFO    : Gen at bus 60793	: Vg=1.0524 -> Vg=1.0
% INFO    : Gen at bus 60794	: Pg=33.2, Qg=16.97 -> Pg=22.375, Qg=6.635
% INFO    : Gen at bus 60794	: Vg=1.0054 -> Vg=1.0
% INFO    : Gen at bus 60794	: Pg=13.55, Qg=16.97 -> Pg=23.195, Qg=6.635
% INFO    : Gen at bus 60794	: Vg=1.0054 -> Vg=1.0
% INFO    : Gen at bus 60795	: Pg=33.19, Qg=16.97 -> Pg=20.785, Qg=6.635
% INFO    : Gen at bus 60795	: Vg=1.0072 -> Vg=1.0
% INFO    : Gen at bus 60798	: Pg=9.34, Qg=-0.64 -> Pg=9.34, Qg=2.175
% INFO    : Gen at bus 60798	: Vg=1.0471 -> Vg=1.0
% INFO    : Gen at bus 60798	: Pg=8.99, Qg=-0.64 -> Pg=8.99, Qg=2.175
% INFO    : Gen at bus 60798	: Vg=1.0471 -> Vg=1.0
% INFO    : Gen at bus 60799	: Pg=6.32, Qg=-0.35 -> Pg=6.32, Qg=1.205
% INFO    : Gen at bus 60799	: Vg=1.0461 -> Vg=1.0
% INFO    : Gen at bus 60799	: Pg=6.05, Qg=-0.35 -> Pg=6.05, Qg=1.205
% INFO    : Gen at bus 60799	: Vg=1.0461 -> Vg=1.0
% INFO    : Gen at bus 60801	: Pg=8.81, Qg=0.0 -> Pg=8.81, Qg=0.0
% INFO    : Gen at bus 60801	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60802	: Pg=7.74, Qg=0.0 -> Pg=7.74, Qg=0.0
% INFO    : Gen at bus 60802	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60802	: Pg=21.83, Qg=0.0 -> Pg=21.83, Qg=0.0
% INFO    : Gen at bus 60802	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60802	: Pg=0.0, Qg=0.0 -> Pg=25.785, Qg=0.0
% INFO    : Gen at bus 60802	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60803	: Pg=7.54, Qg=0.0 -> Pg=7.54, Qg=0.0
% INFO    : Gen at bus 60803	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60807	: Pg=75.19, Qg=33.25 -> Pg=75.19, Qg=14.505
% INFO    : Gen at bus 60807	: Vg=1.0191 -> Vg=1.0
% INFO    : Gen at bus 60808	: Pg=0.0, Qg=0.0 -> Pg=55.88, Qg=14.505
% INFO    : Gen at bus 60808	: Vg=1.0114 -> Vg=1.0
% INFO    : Gen at bus 60809	: Pg=6.31, Qg=-0.56 -> Pg=6.31, Qg=1.91
% INFO    : Gen at bus 60809	: Vg=1.0191 -> Vg=1.0
% INFO    : Gen at bus 60810	: Pg=74.7, Qg=38.17 -> Pg=44.785, Qg=14.92
% INFO    : Gen at bus 60810	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60811	: Pg=26.08, Qg=16.59 -> Pg=26.08, Qg=7.235
% INFO    : Gen at bus 60811	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 60811	: Pg=0.0, Qg=0.0 -> Pg=24.175, Qg=7.235
% INFO    : Gen at bus 60811	: Vg=1.043 -> Vg=1.0
% INFO    : Gen at bus 60814	: Pg=0.0, Qg=0.0 -> Pg=89.48, Qg=29.85
% INFO    : Gen at bus 60814	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60815	: Pg=0.0, Qg=0.0 -> Pg=97.905, Qg=29.85
% INFO    : Gen at bus 60815	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60820	: Pg=41.04, Qg=-6.55 -> Pg=41.04, Qg=1.57
% INFO    : Gen at bus 60820	: Vg=1.0311 -> Vg=1.0
% INFO    : Gen at bus 60820	: Pg=35.21, Qg=-6.55 -> Pg=35.21, Qg=1.57
% INFO    : Gen at bus 60820	: Vg=1.0311 -> Vg=1.0
% INFO    : Gen at bus 60822	: Pg=39.82, Qg=-7.34 -> Pg=39.82, Qg=1.76
% INFO    : Gen at bus 60822	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60825	: Pg=0.0, Qg=0.0 -> Pg=7.43, Qg=2.19
% INFO    : Gen at bus 60825	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 60825	: Pg=10.96, Qg=-1.22 -> Pg=7.46, Qg=2.19
% INFO    : Gen at bus 60825	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 60825	: Pg=10.96, Qg=-1.22 -> Pg=7.065, Qg=2.19
% INFO    : Gen at bus 60825	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 60825	: Pg=0.0, Qg=0.0 -> Pg=53.085, Qg=14.15
% INFO    : Gen at bus 60825	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 60825	: Pg=70.81, Qg=-7.89 -> Pg=42.245, Qg=14.15
% INFO    : Gen at bus 60825	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 60827	: Pg=0.0, Qg=0.0 -> Pg=62.775, Qg=16.75
% INFO    : Gen at bus 60827	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60827	: Pg=78.85, Qg=-4.9 -> Pg=78.85, Qg=16.75
% INFO    : Gen at bus 60827	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60833	: Pg=227.44, Qg=6.27 -> Pg=161.74, Qg=45.445
% INFO    : Gen at bus 60833	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 60834	: Pg=227.44, Qg=6.27 -> Pg=158.87, Qg=45.445
% INFO    : Gen at bus 60834	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 60835	: Pg=65.64, Qg=6.27 -> Pg=145.33, Qg=45.445
% INFO    : Gen at bus 60835	: Vg=1.0258 -> Vg=1.0
% INFO    : Gen at bus 60839	: Pg=0.0, Qg=0.0 -> Pg=43.33, Qg=12.87
% INFO    : Gen at bus 60839	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 60840	: Pg=8.9, Qg=32.92 -> Pg=36.31, Qg=12.87
% INFO    : Gen at bus 60840	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 60841	: Pg=64.41, Qg=32.92 -> Pg=37.32, Qg=12.87
% INFO    : Gen at bus 60841	: Vg=1.0206 -> Vg=1.0
% INFO    : Gen at bus 60844	: Pg=50.2, Qg=13.95 -> Pg=36.18, Qg=10.03
% INFO    : Gen at bus 60844	: Vg=1.039 -> Vg=1.0
% INFO    : Gen at bus 60844	: Pg=7.36, Qg=13.95 -> Pg=28.51, Qg=10.03
% INFO    : Gen at bus 60844	: Vg=1.039 -> Vg=1.0
% INFO    : Gen at bus 60847	: Pg=0.0, Qg=0.0 -> Pg=15.615, Qg=4.18
% INFO    : Gen at bus 60847	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60847	: Pg=0.0, Qg=0.0 -> Pg=12.76, Qg=4.18
% INFO    : Gen at bus 60847	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60847	: Pg=20.91, Qg=-2.33 -> Pg=12.975, Qg=4.18
% INFO    : Gen at bus 60847	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60848	: Pg=20.91, Qg=10.69 -> Pg=11.71, Qg=4.18
% INFO    : Gen at bus 60848	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60848	: Pg=26.49, Qg=13.54 -> Pg=18.735, Qg=5.295
% INFO    : Gen at bus 60848	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 60850	: Pg=19.52, Qg=9.98 -> Pg=10.93, Qg=3.9
% INFO    : Gen at bus 60850	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60850	: Pg=19.52, Qg=9.98 -> Pg=12.52, Qg=3.9
% INFO    : Gen at bus 60850	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60850	: Pg=0.0, Qg=0.0 -> Pg=14.415, Qg=3.9
% INFO    : Gen at bus 60850	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60851	: Pg=0.0, Qg=0.0 -> Pg=14.325, Qg=3.9
% INFO    : Gen at bus 60851	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 60851	: Pg=0.0, Qg=0.0 -> Pg=12.445, Qg=3.9
% INFO    : Gen at bus 60851	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 60851	: Pg=19.52, Qg=9.98 -> Pg=14.555, Qg=3.9
% INFO    : Gen at bus 60851	: Vg=1.0197 -> Vg=1.0
% INFO    : Gen at bus 60852	: Pg=85.32, Qg=39.92 -> Pg=58.595, Qg=14.735
% INFO    : Gen at bus 60852	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 60852	: Pg=85.32, Qg=39.92 -> Pg=58.135, Qg=14.735
% INFO    : Gen at bus 60852	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 60852	: Pg=85.32, Qg=39.92 -> Pg=51.62, Qg=14.735
% INFO    : Gen at bus 60852	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 60856	: Pg=9.63, Qg=5.76 -> Pg=9.63, Qg=2.51
% INFO    : Gen at bus 60856	: Vg=1.0169 -> Vg=1.0
% INFO    : Gen at bus 60856	: Pg=10.87, Qg=5.76 -> Pg=10.87, Qg=2.51
% INFO    : Gen at bus 60856	: Vg=1.0169 -> Vg=1.0
% INFO    : Gen at bus 60857	: Pg=13.52, Qg=5.76 -> Pg=13.52, Qg=2.51
% INFO    : Gen at bus 60857	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 60857	: Pg=0.0, Qg=0.0 -> Pg=5.195, Qg=1.355
% INFO    : Gen at bus 60857	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 60861	: Pg=48.16, Qg=100.27 -> Pg=121.14, Qg=39.2
% INFO    : Gen at bus 60861	: Vg=1.0365 -> Vg=1.0
% INFO    : Gen at bus 60862	: Pg=0.0, Qg=0.0 -> Pg=144.105, Qg=39.2
% INFO    : Gen at bus 60862	: Vg=1.0253 -> Vg=1.0
% INFO    : Gen at bus 60865	: Pg=0.0, Qg=0.0 -> Pg=42.25, Qg=2.07
% INFO    : Gen at bus 60865	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60872	: Pg=473.94, Qg=55.38 -> Pg=268.455, Qg=81.845
% INFO    : Gen at bus 60872	: Vg=0.9917 -> Vg=1.0
% INFO    : Gen at bus 60873	: Pg=473.94, Qg=55.38 -> Pg=321.65, Qg=81.845
% INFO    : Gen at bus 60873	: Vg=0.987 -> Vg=1.0
% INFO    : Gen at bus 60874	: Pg=473.93, Qg=55.38 -> Pg=354.27, Qg=81.845
% INFO    : Gen at bus 60874	: Vg=0.992 -> Vg=1.0
% INFO    : Gen at bus 60875	: Pg=20.86, Qg=-4.28 -> Pg=20.86, Qg=1.025
% INFO    : Gen at bus 60875	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60875	: Pg=22.13, Qg=-4.51 -> Pg=22.13, Qg=1.08
% INFO    : Gen at bus 60875	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60875	: Pg=22.36, Qg=-4.51 -> Pg=22.36, Qg=1.08
% INFO    : Gen at bus 60875	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 60881	: Pg=0.0, Qg=0.0 -> Pg=111.815, Qg=35.885
% INFO    : Gen at bus 60881	: Vg=1.0142 -> Vg=1.0
% INFO    : Gen at bus 60882	: Pg=179.6, Qg=91.79 -> Pg=109.47, Qg=35.885
% INFO    : Gen at bus 60882	: Vg=1.0305 -> Vg=1.0
% INFO    : Gen at bus 60883	: Pg=34.65, Qg=91.79 -> Pg=106.17, Qg=35.885
% INFO    : Gen at bus 60883	: Vg=1.0292 -> Vg=1.0
% INFO    : Gen at bus 60891	: Pg=292.41, Qg=38.28 -> Pg=190.58, Qg=50.5
% INFO    : Gen at bus 60891	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 60892	: Pg=100.95, Qg=38.28 -> Pg=74.115, Qg=17.43
% INFO    : Gen at bus 60892	: Vg=1.0304 -> Vg=1.0
% INFO    : Gen at bus 60893	: Pg=100.95, Qg=38.28 -> Pg=56.245, Qg=17.43
% INFO    : Gen at bus 60893	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 60894	: Pg=100.95, Qg=38.28 -> Pg=69.13, Qg=17.43
% INFO    : Gen at bus 60894	: Vg=1.0313 -> Vg=1.0
% INFO    : Gen at bus 60895	: Pg=100.95, Qg=38.28 -> Pg=67.67, Qg=17.43
% INFO    : Gen at bus 60895	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 60896	: Pg=100.95, Qg=38.28 -> Pg=66.14, Qg=17.43
% INFO    : Gen at bus 60896	: Vg=1.0321 -> Vg=1.0
% INFO    : Gen at bus 70097	: Pg=0.0, Qg=0.0 -> Pg=167.445, Qg=39.655
% INFO    : Gen at bus 70097	: Vg=1.0394 -> Vg=1.0
% INFO    : Gen at bus 70098	: Pg=27.14, Qg=16.11 -> Pg=127.155, Qg=39.655
% INFO    : Gen at bus 70098	: Vg=1.0419 -> Vg=1.0
% INFO    : Gen at bus 70099	: Pg=0.0, Qg=0.0 -> Pg=172.885, Qg=39.655
% INFO    : Gen at bus 70099	: Vg=1.0394 -> Vg=1.0
% INFO    : Gen at bus 70100	: Pg=0.0, Qg=0.0 -> Pg=131.665, Qg=39.655
% INFO    : Gen at bus 70100	: Vg=1.0394 -> Vg=1.0
% INFO    : Gen at bus 70104	: Pg=185.19, Qg=-1.23 -> Pg=185.19, Qg=6.9
% INFO    : Gen at bus 70104	: Vg=0.9739 -> Vg=1.0
% INFO    : Gen at bus 70105	: Pg=37.25, Qg=-10.74 -> Pg=61.98, Qg=15.135
% INFO    : Gen at bus 70105	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 70107	: Pg=23.13, Qg=5.48 -> Pg=23.13, Qg=1.015
% INFO    : Gen at bus 70107	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 70107	: Pg=30.77, Qg=5.48 -> Pg=30.77, Qg=1.45
% INFO    : Gen at bus 70107	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 70110	: Pg=7.04, Qg=-4.88 -> Pg=23.225, Qg=6.88
% INFO    : Gen at bus 70110	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 70110	: Pg=17.13, Qg=-9.76 -> Pg=47.98, Qg=13.76
% INFO    : Gen at bus 70110	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 70111	: Pg=29.77, Qg=-1.64 -> Pg=29.77, Qg=5.595
% INFO    : Gen at bus 70111	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 70111	: Pg=33.4, Qg=-1.64 -> Pg=33.4, Qg=5.595
% INFO    : Gen at bus 70111	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 70114	: Pg=86.23, Qg=22.0 -> Pg=86.23, Qg=3.56
% INFO    : Gen at bus 70114	: Vg=1.0428 -> Vg=1.0
% INFO    : Gen at bus 70115	: Pg=24.86, Qg=6.33 -> Pg=24.86, Qg=1.025
% INFO    : Gen at bus 70115	: Vg=1.0308 -> Vg=1.0
% INFO    : Gen at bus 70121	: Pg=113.47, Qg=-59.01 -> Pg=295.04, Qg=83.195
% INFO    : Gen at bus 70121	: Vg=1.0138 -> Vg=1.0
% INFO    : Gen at bus 70125	: Pg=90.53, Qg=-33.83 -> Pg=181.9, Qg=47.705
% INFO    : Gen at bus 70125	: Vg=1.016 -> Vg=1.0
% INFO    : Gen at bus 70126	: Pg=104.66, Qg=-33.83 -> Pg=188.965, Qg=47.705
% INFO    : Gen at bus 70126	: Vg=1.016 -> Vg=1.0
% INFO    : Gen at bus 70127	: Pg=121.1, Qg=-33.83 -> Pg=197.185, Qg=47.705
% INFO    : Gen at bus 70127	: Vg=1.016 -> Vg=1.0
% INFO    : Gen at bus 70128	: Pg=11.5, Qg=-1.66 -> Pg=11.5, Qg=0.395
% INFO    : Gen at bus 70128	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 70128	: Pg=10.92, Qg=-2.42 -> Pg=10.92, Qg=0.58
% INFO    : Gen at bus 70128	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 70128	: Pg=0.0, Qg=0.0 -> Pg=17.32, Qg=0.855
% INFO    : Gen at bus 70128	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 70128	: Pg=28.33, Qg=-5.96 -> Pg=28.33, Qg=1.43
% INFO    : Gen at bus 70128	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 70128	: Pg=32.04, Qg=-7.2 -> Pg=32.04, Qg=1.725
% INFO    : Gen at bus 70128	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 70131	: Pg=48.17, Qg=10.41 -> Pg=48.17, Qg=2.105
% INFO    : Gen at bus 70131	: Vg=1.0505 -> Vg=1.0
% INFO    : Gen at bus 70134	: Pg=96.09, Qg=21.22 -> Pg=246.245, Qg=69.195
% INFO    : Gen at bus 70134	: Vg=0.9641 -> Vg=1.0
% INFO    : Gen at bus 70141	: Pg=7.35, Qg=16.97 -> Pg=20.095, Qg=6.635
% INFO    : Gen at bus 70141	: Vg=1.0324 -> Vg=1.0
% INFO    : Gen at bus 70142	: Pg=13.87, Qg=16.97 -> Pg=23.355, Qg=6.635
% INFO    : Gen at bus 70142	: Vg=1.0325 -> Vg=1.0
% INFO    : Gen at bus 70144	: Pg=7.5, Qg=20.36 -> Pg=23.46, Qg=7.96
% INFO    : Gen at bus 70144	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 70144	: Pg=6.81, Qg=16.97 -> Pg=19.825, Qg=6.635
% INFO    : Gen at bus 70144	: Vg=1.035 -> Vg=1.0
% INFO    : Gen at bus 70146	: Pg=75.68, Qg=-16.68 -> Pg=75.68, Qg=3.995
% INFO    : Gen at bus 70146	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=0.0, Qg=0.0 -> Pg=4.48, Qg=1.175
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=1.71, Qg=-0.83 -> Pg=4.22, Qg=1.175
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=2.61, Qg=-0.83 -> Pg=4.67, Qg=1.175
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=1.53, Qg=-0.83 -> Pg=4.13, Qg=1.175
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=1.02, Qg=-0.83 -> Pg=3.875, Qg=1.175
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=0.0, Qg=0.0 -> Pg=4.645, Qg=1.175
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=0.0, Qg=0.0 -> Pg=10.645, Qg=2.58
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70147	: Pg=0.0, Qg=0.0 -> Pg=10.595, Qg=2.58
% INFO    : Gen at bus 70147	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 70149	: Pg=0.0, Qg=0.0 -> Pg=71.29, Qg=3.415
% INFO    : Gen at bus 70149	: Vg=1.0277 -> Vg=1.0
% INFO    : Gen at bus 70150	: Pg=0.0, Qg=0.0 -> Pg=11.75, Qg=0.585
% INFO    : Gen at bus 70150	: Vg=1.0277 -> Vg=1.0
% INFO    : Gen at bus 70153	: Pg=153.29, Qg=-40.17 -> Pg=377.415, Qg=105.0
% INFO    : Gen at bus 70153	: Vg=1.0128 -> Vg=1.0
% INFO    : Gen at bus 70154	: Pg=184.75, Qg=-40.17 -> Pg=393.14, Qg=105.0
% INFO    : Gen at bus 70154	: Vg=1.0101 -> Vg=1.0
% INFO    : Gen at bus 70155	: Pg=224.65, Qg=-40.17 -> Pg=413.095, Qg=105.0
% INFO    : Gen at bus 70155	: Vg=1.0107 -> Vg=1.0
% INFO    : Gen at bus 70156	: Pg=202.37, Qg=-40.17 -> Pg=401.955, Qg=105.0
% INFO    : Gen at bus 70156	: Vg=1.013 -> Vg=1.0
% INFO    : Gen at bus 70160	: Pg=87.22, Qg=22.0 -> Pg=87.22, Qg=3.56
% INFO    : Gen at bus 70160	: Vg=1.0774 -> Vg=1.0
% INFO    : Gen at bus 70163	: Pg=0.0, Qg=0.0 -> Pg=12.4, Qg=3.47
% INFO    : Gen at bus 70163	: Vg=1.0373 -> Vg=1.0
% INFO    : Gen at bus 70164	: Pg=16.26, Qg=7.95 -> Pg=16.26, Qg=3.47
% INFO    : Gen at bus 70164	: Vg=1.0498 -> Vg=1.0
% INFO    : Gen at bus 70164	: Pg=0.0, Qg=0.0 -> Pg=11.53, Qg=3.185
% INFO    : Gen at bus 70164	: Vg=1.0498 -> Vg=1.0
% INFO    : Gen at bus 70165	: Pg=13.57, Qg=7.3 -> Pg=13.57, Qg=3.185
% INFO    : Gen at bus 70165	: Vg=1.0658 -> Vg=1.0
% INFO    : Gen at bus 70165	: Pg=9.06, Qg=3.84 -> Pg=9.06, Qg=1.675
% INFO    : Gen at bus 70165	: Vg=1.0658 -> Vg=1.0
% INFO    : Gen at bus 70166	: Pg=0.0, Qg=0.0 -> Pg=5.15, Qg=1.255
% INFO    : Gen at bus 70166	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 70166	: Pg=6.66, Qg=0.15 -> Pg=6.66, Qg=1.255
% INFO    : Gen at bus 70166	: Vg=1.0295 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=2.97, Qg=-0.83 -> Pg=5.18, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=12.28, Qg=-4.44 -> Pg=25.85, Qg=7.96
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=3.36, Qg=-0.83 -> Pg=5.375, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=3.73, Qg=-0.83 -> Pg=5.56, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=1.96, Qg=-0.83 -> Pg=4.675, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=1.39, Qg=-0.83 -> Pg=4.39, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=2.46, Qg=-0.83 -> Pg=4.925, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=1.74, Qg=-0.83 -> Pg=4.565, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=0.94, Qg=-0.83 -> Pg=4.165, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70167	: Pg=3.28, Qg=-0.83 -> Pg=5.335, Qg=1.495
% INFO    : Gen at bus 70167	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 70168	: Pg=0.0, Qg=0.0 -> Pg=54.41, Qg=2.76
% INFO    : Gen at bus 70168	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 70172	: Pg=199.22, Qg=39.12 -> Pg=380.43, Qg=98.04
% INFO    : Gen at bus 70172	: Vg=0.9882 -> Vg=1.0
% INFO    : Gen at bus 70173	: Pg=137.24, Qg=39.12 -> Pg=349.445, Qg=98.04
% INFO    : Gen at bus 70173	: Vg=0.986 -> Vg=1.0
% INFO    : Gen at bus 70174	: Pg=102.92, Qg=39.12 -> Pg=332.28, Qg=98.04
% INFO    : Gen at bus 70174	: Vg=0.9883 -> Vg=1.0
% INFO    : Gen at bus 70176	: Pg=38.6, Qg=54.15 -> Pg=76.55, Qg=19.985
% INFO    : Gen at bus 70176	: Vg=1.067 -> Vg=1.0
% INFO    : Gen at bus 70177	: Pg=42.55, Qg=3.92 -> Pg=42.55, Qg=2.13
% INFO    : Gen at bus 70177	: Vg=1.0345 -> Vg=1.0
% INFO    : Gen at bus 70177	: Pg=55.22, Qg=3.92 -> Pg=55.22, Qg=2.13
% INFO    : Gen at bus 70177	: Vg=1.0345 -> Vg=1.0
% INFO    : Gen at bus 70180	: Pg=72.0, Qg=-10.37 -> Pg=72.0, Qg=2.485
% INFO    : Gen at bus 70180	: Vg=1.0452 -> Vg=1.0
% INFO    : Gen at bus 70181	: Pg=0.0, Qg=0.0 -> Pg=45.235, Qg=2.485
% INFO    : Gen at bus 70181	: Vg=1.0338 -> Vg=1.0
% INFO    : Gen at bus 70182	: Pg=7.28, Qg=-0.59 -> Pg=7.28, Qg=2.01
% INFO    : Gen at bus 70182	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 70182	: Pg=10.86, Qg=-0.59 -> Pg=10.86, Qg=2.01
% INFO    : Gen at bus 70182	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 70182	: Pg=9.26, Qg=-0.59 -> Pg=9.26, Qg=2.01
% INFO    : Gen at bus 70182	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 70182	: Pg=12.64, Qg=-0.84 -> Pg=12.64, Qg=2.88
% INFO    : Gen at bus 70182	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 70182	: Pg=11.08, Qg=-0.84 -> Pg=11.08, Qg=2.88
% INFO    : Gen at bus 70182	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 70182	: Pg=11.79, Qg=-0.84 -> Pg=11.79, Qg=2.88
% INFO    : Gen at bus 70182	: Vg=1.0177 -> Vg=1.0
% INFO    : Gen at bus 70184	: Pg=0.0, Qg=0.0 -> Pg=64.345, Qg=16.34
% INFO    : Gen at bus 70184	: Vg=1.0367 -> Vg=1.0
% INFO    : Gen at bus 70188	: Pg=15.71, Qg=-1.14 -> Pg=25.59, Qg=7.16
% INFO    : Gen at bus 70188	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 70188	: Pg=16.19, Qg=-1.14 -> Pg=25.83, Qg=7.16
% INFO    : Gen at bus 70188	: Vg=1.0354 -> Vg=1.0
% INFO    : Gen at bus 70189	: Pg=14.39, Qg=-2.28 -> Pg=24.93, Qg=7.16
% INFO    : Gen at bus 70189	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 74196	: Pg=0.0, Qg=0.0 -> Pg=26.315, Qg=7.385
% INFO    : Gen at bus 74196	: Vg=1.0118 -> Vg=1.0
% INFO    : Gen at bus 74196	: Pg=0.0, Qg=0.0 -> Pg=29.24, Qg=7.385
% INFO    : Gen at bus 74196	: Vg=1.0118 -> Vg=1.0
% INFO    : Gen at bus 74197	: Pg=44.1, Qg=16.93 -> Pg=44.1, Qg=7.385
% INFO    : Gen at bus 74197	: Vg=0.9979 -> Vg=1.0
% INFO    : Gen at bus 74197	: Pg=37.11, Qg=16.93 -> Pg=37.11, Qg=7.385
% INFO    : Gen at bus 74197	: Vg=0.9979 -> Vg=1.0
% INFO    : Gen at bus 74199	: Pg=15.0, Qg=-0.74 -> Pg=15.0, Qg=2.51
% INFO    : Gen at bus 74199	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74199	: Pg=8.04, Qg=-0.74 -> Pg=8.04, Qg=2.51
% INFO    : Gen at bus 74199	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74199	: Pg=12.94, Qg=-0.74 -> Pg=12.94, Qg=2.51
% INFO    : Gen at bus 74199	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74199	: Pg=12.99, Qg=-0.74 -> Pg=12.99, Qg=2.51
% INFO    : Gen at bus 74199	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74200	: Pg=0.0, Qg=0.0 -> Pg=6.045, Qg=1.39
% INFO    : Gen at bus 74200	: Vg=1.061 -> Vg=1.0
% INFO    : Gen at bus 74201	: Pg=10.18, Qg=-0.66 -> Pg=10.18, Qg=2.26
% INFO    : Gen at bus 74201	: Vg=1.0606 -> Vg=1.0
% INFO    : Gen at bus 74204	: Pg=172.1, Qg=-19.18 -> Pg=118.01, Qg=34.39
% INFO    : Gen at bus 74204	: Vg=1.0253 -> Vg=1.0
% INFO    : Gen at bus 74205	: Pg=0.0, Qg=0.0 -> Pg=6.965, Qg=2.07
% INFO    : Gen at bus 74205	: Vg=1.0294 -> Vg=1.0
% INFO    : Gen at bus 74205	: Pg=10.36, Qg=-1.15 -> Pg=6.42, Qg=2.07
% INFO    : Gen at bus 74205	: Vg=1.0294 -> Vg=1.0
% INFO    : Gen at bus 74211	: Pg=150.14, Qg=40.4 -> Pg=89.675, Qg=30.0
% INFO    : Gen at bus 74211	: Vg=1.0525 -> Vg=1.0
% INFO    : Gen at bus 74212	: Pg=150.14, Qg=40.4 -> Pg=99.765, Qg=30.0
% INFO    : Gen at bus 74212	: Vg=1.0524 -> Vg=1.0
% INFO    : Gen at bus 74213	: Pg=38.28, Qg=0.0 -> Pg=38.28, Qg=0.0
% INFO    : Gen at bus 74213	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74214	: Pg=9.35, Qg=0.0 -> Pg=9.35, Qg=0.0
% INFO    : Gen at bus 74214	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74214	: Pg=7.46, Qg=0.0 -> Pg=7.46, Qg=0.0
% INFO    : Gen at bus 74214	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74214	: Pg=33.93, Qg=0.0 -> Pg=33.93, Qg=0.0
% INFO    : Gen at bus 74214	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74220	: Pg=28.36, Qg=12.95 -> Pg=28.36, Qg=5.65
% INFO    : Gen at bus 74220	: Vg=0.9864 -> Vg=1.0
% INFO    : Gen at bus 74220	: Pg=27.57, Qg=12.95 -> Pg=27.57, Qg=5.65
% INFO    : Gen at bus 74220	: Vg=0.9864 -> Vg=1.0
% INFO    : Gen at bus 74221	: Pg=33.73, Qg=12.95 -> Pg=33.73, Qg=5.65
% INFO    : Gen at bus 74221	: Vg=0.9864 -> Vg=1.0
% INFO    : Gen at bus 74221	: Pg=0.0, Qg=0.0 -> Pg=4.745, Qg=1.255
% INFO    : Gen at bus 74221	: Vg=0.9864 -> Vg=1.0
% INFO    : Gen at bus 74222	: Pg=5.26, Qg=2.88 -> Pg=5.26, Qg=1.255
% INFO    : Gen at bus 74222	: Vg=0.983 -> Vg=1.0
% INFO    : Gen at bus 74223	: Pg=0.0, Qg=0.0 -> Pg=57.02, Qg=17.97
% INFO    : Gen at bus 74223	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74223	: Pg=89.93, Qg=-10.02 -> Pg=62.02, Qg=17.97
% INFO    : Gen at bus 74223	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74223	: Pg=89.93, Qg=-10.02 -> Pg=55.975, Qg=17.97
% INFO    : Gen at bus 74223	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74225	: Pg=50.07, Qg=-2.04 -> Pg=50.07, Qg=2.225
% INFO    : Gen at bus 74225	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 74226	: Pg=16.8, Qg=-2.42 -> Pg=16.8, Qg=0.58
% INFO    : Gen at bus 74226	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74226	: Pg=6.55, Qg=-2.72 -> Pg=6.55, Qg=0.655
% INFO    : Gen at bus 74226	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74228	: Pg=5.65, Qg=2.69 -> Pg=5.65, Qg=1.175
% INFO    : Gen at bus 74228	: Vg=1.042 -> Vg=1.0
% INFO    : Gen at bus 74228	: Pg=8.06, Qg=4.8 -> Pg=8.06, Qg=2.095
% INFO    : Gen at bus 74228	: Vg=1.042 -> Vg=1.0
% INFO    : Gen at bus 74228	: Pg=12.36, Qg=4.8 -> Pg=12.36, Qg=2.095
% INFO    : Gen at bus 74228	: Vg=1.042 -> Vg=1.0
% INFO    : Gen at bus 74230	: Pg=9.89, Qg=-1.51 -> Pg=9.89, Qg=0.365
% INFO    : Gen at bus 74230	: Vg=1.0051 -> Vg=1.0
% INFO    : Gen at bus 74231	: Pg=16.1, Qg=-3.02 -> Pg=16.1, Qg=0.725
% INFO    : Gen at bus 74231	: Vg=1.003 -> Vg=1.0
% INFO    : Gen at bus 74233	: Pg=0.0, Qg=0.0 -> Pg=14.015, Qg=0.725
% INFO    : Gen at bus 74233	: Vg=1.0566 -> Vg=1.0
% INFO    : Gen at bus 74236	: Pg=36.59, Qg=13.47 -> Pg=36.59, Qg=11.105
% INFO    : Gen at bus 74236	: Vg=1.0296 -> Vg=1.0
% INFO    : Gen at bus 74237	: Pg=45.59, Qg=13.47 -> Pg=45.59, Qg=11.105
% INFO    : Gen at bus 74237	: Vg=1.0294 -> Vg=1.0
% INFO    : Gen at bus 74238	: Pg=44.9, Qg=13.47 -> Pg=44.9, Qg=11.105
% INFO    : Gen at bus 74238	: Vg=1.0283 -> Vg=1.0
% INFO    : Gen at bus 74239	: Pg=47.54, Qg=13.47 -> Pg=47.54, Qg=11.105
% INFO    : Gen at bus 74239	: Vg=1.0289 -> Vg=1.0
% INFO    : Gen at bus 74240	: Pg=82.86, Qg=7.24 -> Pg=53.835, Qg=16.555
% INFO    : Gen at bus 74240	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 74240	: Pg=82.86, Qg=7.24 -> Pg=53.36, Qg=16.555
% INFO    : Gen at bus 74240	: Vg=1.0163 -> Vg=1.0
% INFO    : Gen at bus 74245	: Pg=5.43, Qg=-0.34 -> Pg=5.43, Qg=1.16
% INFO    : Gen at bus 74245	: Vg=1.0259 -> Vg=1.0
% INFO    : Gen at bus 74246	: Pg=0.0, Qg=0.0 -> Pg=3.885, Qg=1.16
% INFO    : Gen at bus 74246	: Vg=1.0261 -> Vg=1.0
% INFO    : Gen at bus 74248	: Pg=3.4, Qg=-0.34 -> Pg=3.4, Qg=1.16
% INFO    : Gen at bus 74248	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 74248	: Pg=0.0, Qg=0.0 -> Pg=4.495, Qg=1.16
% INFO    : Gen at bus 74248	: Vg=1.0246 -> Vg=1.0
% INFO    : Gen at bus 74252	: Pg=89.21, Qg=-0.07 -> Pg=89.21, Qg=19.61
% INFO    : Gen at bus 74252	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 74253	: Pg=0.0, Qg=0.0 -> Pg=84.005, Qg=19.61
% INFO    : Gen at bus 74253	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 74254	: Pg=83.06, Qg=-0.07 -> Pg=83.06, Qg=19.61
% INFO    : Gen at bus 74254	: Vg=1.0147 -> Vg=1.0
% INFO    : Gen at bus 74255	: Pg=80.11, Qg=-0.07 -> Pg=80.11, Qg=19.61
% INFO    : Gen at bus 74255	: Vg=1.0144 -> Vg=1.0
% INFO    : Gen at bus 74256	: Pg=105.82, Qg=-0.07 -> Pg=105.82, Qg=19.61
% INFO    : Gen at bus 74256	: Vg=1.0143 -> Vg=1.0
% INFO    : Gen at bus 74259	: Pg=22.5, Qg=-3.24 -> Pg=22.5, Qg=0.775
% INFO    : Gen at bus 74259	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 74259	: Pg=16.46, Qg=-3.02 -> Pg=16.46, Qg=0.725
% INFO    : Gen at bus 74259	: Vg=1.0108 -> Vg=1.0
% INFO    : Gen at bus 74260	: Pg=0.0, Qg=0.0 -> Pg=6.475, Qg=0.365
% INFO    : Gen at bus 74260	: Vg=1.0098 -> Vg=1.0
% INFO    : Gen at bus 74261	: Pg=25.0, Qg=-1.22 -> Pg=25.0, Qg=4.19
% INFO    : Gen at bus 74261	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74261	: Pg=20.31, Qg=-1.22 -> Pg=20.31, Qg=4.19
% INFO    : Gen at bus 74261	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74261	: Pg=0.0, Qg=0.0 -> Pg=16.155, Qg=4.19
% INFO    : Gen at bus 74261	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74263	: Pg=0.0, Qg=0.0 -> Pg=43.945, Qg=2.735
% INFO    : Gen at bus 74263	: Vg=1.0366 -> Vg=1.0
% INFO    : Gen at bus 74265	: Pg=7.49, Qg=-0.62 -> Pg=7.49, Qg=2.13
% INFO    : Gen at bus 74265	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 74266	: Pg=12.7, Qg=-0.62 -> Pg=12.7, Qg=2.13
% INFO    : Gen at bus 74266	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74266	: Pg=0.0, Qg=0.0 -> Pg=9.44, Qg=2.13
% INFO    : Gen at bus 74266	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74268	: Pg=5.03, Qg=-0.39 -> Pg=5.03, Qg=1.34
% INFO    : Gen at bus 74268	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 74268	: Pg=0.0, Qg=0.0 -> Pg=4.595, Qg=1.34
% INFO    : Gen at bus 74268	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 74268	: Pg=8.0, Qg=-0.39 -> Pg=8.0, Qg=1.34
% INFO    : Gen at bus 74268	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 74268	: Pg=0.0, Qg=0.0 -> Pg=13.14, Qg=3.92
% INFO    : Gen at bus 74268	: Vg=1.0216 -> Vg=1.0
% INFO    : Gen at bus 74270	: Pg=18.07, Qg=-3.23 -> Pg=18.07, Qg=0.77
% INFO    : Gen at bus 74270	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74270	: Pg=16.56, Qg=-3.31 -> Pg=16.56, Qg=0.795
% INFO    : Gen at bus 74270	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74270	: Pg=23.0, Qg=-3.31 -> Pg=23.0, Qg=0.795
% INFO    : Gen at bus 74270	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74271	: Pg=48.32, Qg=-8.29 -> Pg=48.32, Qg=1.99
% INFO    : Gen at bus 74271	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 74276	: Pg=90.64, Qg=29.03 -> Pg=90.64, Qg=22.335
% INFO    : Gen at bus 74276	: Vg=1.0518 -> Vg=1.0
% INFO    : Gen at bus 74277	: Pg=0.0, Qg=0.0 -> Pg=85.23, Qg=22.335
% INFO    : Gen at bus 74277	: Vg=1.041 -> Vg=1.0
% INFO    : Gen at bus 74278	: Pg=117.94, Qg=29.03 -> Pg=117.94, Qg=22.335
% INFO    : Gen at bus 74278	: Vg=1.0504 -> Vg=1.0
% INFO    : Gen at bus 74280	: Pg=100.14, Qg=25.5 -> Pg=100.14, Qg=4.13
% INFO    : Gen at bus 74280	: Vg=1.0063 -> Vg=1.0
% INFO    : Gen at bus 74282	: Pg=0.0, Qg=0.0 -> Pg=13.91, Qg=0.795
% INFO    : Gen at bus 74282	: Vg=1.0502 -> Vg=1.0
% INFO    : Gen at bus 74283	: Pg=0.0, Qg=0.0 -> Pg=13.95, Qg=0.795
% INFO    : Gen at bus 74283	: Vg=1.0502 -> Vg=1.0
% INFO    : Gen at bus 74284	: Pg=6.33, Qg=3.84 -> Pg=6.33, Qg=1.675
% INFO    : Gen at bus 74284	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74284	: Pg=6.27, Qg=3.84 -> Pg=6.27, Qg=1.675
% INFO    : Gen at bus 74284	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74284	: Pg=0.0, Qg=0.0 -> Pg=6.87, Qg=1.675
% INFO    : Gen at bus 74284	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74288	: Pg=0.0, Qg=0.0 -> Pg=7.52, Qg=0.365
% INFO    : Gen at bus 74288	: Vg=1.0635 -> Vg=1.0
% INFO    : Gen at bus 74289	: Pg=10.5, Qg=-1.51 -> Pg=10.5, Qg=0.365
% INFO    : Gen at bus 74289	: Vg=1.0618 -> Vg=1.0
% INFO    : Gen at bus 74291	: Pg=0.0, Qg=0.0 -> Pg=9.36, Qg=0.47
% INFO    : Gen at bus 74291	: Vg=1.0635 -> Vg=1.0
% INFO    : Gen at bus 74292	: Pg=9.23, Qg=-1.73 -> Pg=9.23, Qg=0.415
% INFO    : Gen at bus 74292	: Vg=1.0526 -> Vg=1.0
% INFO    : Gen at bus 74295	: Pg=17.56, Qg=4.47 -> Pg=17.56, Qg=0.725
% INFO    : Gen at bus 74295	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74296	: Pg=14.85, Qg=-3.02 -> Pg=14.85, Qg=0.725
% INFO    : Gen at bus 74296	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74296	: Pg=15.01, Qg=-3.31 -> Pg=15.01, Qg=0.795
% INFO    : Gen at bus 74296	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74296	: Pg=0.0, Qg=0.0 -> Pg=16.42, Qg=0.795
% INFO    : Gen at bus 74296	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74298	: Pg=0.0, Qg=0.0 -> Pg=12.64, Qg=3.35
% INFO    : Gen at bus 74298	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 74298	: Pg=16.3, Qg=-0.98 -> Pg=16.3, Qg=3.35
% INFO    : Gen at bus 74298	: Vg=1.007 -> Vg=1.0
% INFO    : Gen at bus 74301	: Pg=9.94, Qg=5.38 -> Pg=9.94, Qg=2.345
% INFO    : Gen at bus 74301	: Vg=0.9989 -> Vg=1.0
% INFO    : Gen at bus 74302	: Pg=11.55, Qg=5.38 -> Pg=11.55, Qg=2.345
% INFO    : Gen at bus 74302	: Vg=0.9944 -> Vg=1.0
% INFO    : Gen at bus 74302	: Pg=0.0, Qg=0.0 -> Pg=8.855, Qg=2.345
% INFO    : Gen at bus 74302	: Vg=0.9944 -> Vg=1.0
% INFO    : Gen at bus 74303	: Pg=18.18, Qg=-3.24 -> Pg=18.18, Qg=0.775
% INFO    : Gen at bus 74303	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74303	: Pg=17.29, Qg=-3.24 -> Pg=17.29, Qg=0.775
% INFO    : Gen at bus 74303	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74305	: Pg=14.89, Qg=0.0 -> Pg=14.89, Qg=0.0
% INFO    : Gen at bus 74305	: Vg=1.002 -> Vg=1.0
% INFO    : Gen at bus 74305	: Pg=11.56, Qg=0.0 -> Pg=11.56, Qg=0.0
% INFO    : Gen at bus 74305	: Vg=1.002 -> Vg=1.0
% INFO    : Gen at bus 74307	: Pg=25.47, Qg=7.27 -> Pg=25.47, Qg=4.625
% INFO    : Gen at bus 74307	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 74307	: Pg=0.0, Qg=0.0 -> Pg=19.015, Qg=4.625
% INFO    : Gen at bus 74307	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 74307	: Pg=24.9, Qg=7.27 -> Pg=24.9, Qg=4.625
% INFO    : Gen at bus 74307	: Vg=1.038 -> Vg=1.0
% INFO    : Gen at bus 74310	: Pg=88.0, Qg=26.52 -> Pg=88.0, Qg=4.295
% INFO    : Gen at bus 74310	: Vg=0.9993 -> Vg=1.0
% INFO    : Gen at bus 74313	: Pg=27.14, Qg=11.83 -> Pg=27.14, Qg=5.16
% INFO    : Gen at bus 74313	: Vg=1.0331 -> Vg=1.0
% INFO    : Gen at bus 74314	: Pg=15.21, Qg=11.83 -> Pg=15.21, Qg=5.16
% INFO    : Gen at bus 74314	: Vg=1.0331 -> Vg=1.0
% INFO    : Gen at bus 74316	: Pg=17.14, Qg=11.83 -> Pg=17.14, Qg=5.16
% INFO    : Gen at bus 74316	: Vg=1.0573 -> Vg=1.0
% INFO    : Gen at bus 74317	: Pg=6.64, Qg=4.22 -> Pg=6.64, Qg=1.84
% INFO    : Gen at bus 74317	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74317	: Pg=0.0, Qg=0.0 -> Pg=7.71, Qg=1.84
% INFO    : Gen at bus 74317	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74318	: Pg=5.41, Qg=2.78 -> Pg=5.41, Qg=1.21
% INFO    : Gen at bus 74318	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 74318	: Pg=0.0, Qg=0.0 -> Pg=8.065, Qg=1.84
% INFO    : Gen at bus 74318	: Vg=1.046 -> Vg=1.0
% INFO    : Gen at bus 74319	: Pg=0.0, Qg=0.0 -> Pg=5.28, Qg=1.21
% INFO    : Gen at bus 74319	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 74322	: Pg=21.04, Qg=10.12 -> Pg=21.04, Qg=4.415
% INFO    : Gen at bus 74322	: Vg=1.0467 -> Vg=1.0
% INFO    : Gen at bus 74322	: Pg=22.05, Qg=10.12 -> Pg=22.05, Qg=4.415
% INFO    : Gen at bus 74322	: Vg=1.0467 -> Vg=1.0
% INFO    : Gen at bus 74324	: Pg=0.0, Qg=0.0 -> Pg=12.885, Qg=3.325
% INFO    : Gen at bus 74324	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 74324	: Pg=18.29, Qg=7.62 -> Pg=18.29, Qg=3.325
% INFO    : Gen at bus 74324	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 74324	: Pg=19.83, Qg=7.62 -> Pg=19.83, Qg=3.325
% INFO    : Gen at bus 74324	: Vg=1.0187 -> Vg=1.0
% INFO    : Gen at bus 74328	: Pg=158.6, Qg=40.14 -> Pg=99.54, Qg=31.69
% INFO    : Gen at bus 74328	: Vg=1.0333 -> Vg=1.0
% INFO    : Gen at bus 74329	: Pg=158.6, Qg=40.14 -> Pg=116.35, Qg=31.69
% INFO    : Gen at bus 74329	: Vg=1.0331 -> Vg=1.0
% INFO    : Gen at bus 74332	: Pg=5.73, Qg=1.95 -> Pg=5.73, Qg=1.51
% INFO    : Gen at bus 74332	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 74332	: Pg=6.36, Qg=1.95 -> Pg=6.36, Qg=1.51
% INFO    : Gen at bus 74332	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 74333	: Pg=6.8, Qg=0.78 -> Pg=6.8, Qg=1.385
% INFO    : Gen at bus 74333	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 74333	: Pg=4.14, Qg=0.78 -> Pg=4.14, Qg=1.385
% INFO    : Gen at bus 74333	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 74334	: Pg=26.93, Qg=-5.76 -> Pg=26.93, Qg=1.38
% INFO    : Gen at bus 74334	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74335	: Pg=0.0, Qg=0.0 -> Pg=8.155, Qg=0.415
% INFO    : Gen at bus 74335	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74335	: Pg=8.69, Qg=-1.86 -> Pg=8.69, Qg=0.47
% INFO    : Gen at bus 74335	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 74335	: Pg=11.06, Qg=-1.86 -> Pg=11.06, Qg=0.67
% INFO    : Gen at bus 74335	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77187	: Pg=82.0, Qg=-5.14 -> Pg=82.0, Qg=17.59
% INFO    : Gen at bus 77187	: Vg=0.9881 -> Vg=1.0
% INFO    : Gen at bus 77188	: Pg=65.45, Qg=-5.14 -> Pg=65.45, Qg=17.59
% INFO    : Gen at bus 77188	: Vg=0.9884 -> Vg=1.0
% INFO    : Gen at bus 77189	: Pg=77.22, Qg=-5.14 -> Pg=77.22, Qg=17.59
% INFO    : Gen at bus 77189	: Vg=0.9881 -> Vg=1.0
% INFO    : Gen at bus 77190	: Pg=89.78, Qg=-5.14 -> Pg=89.78, Qg=17.59
% INFO    : Gen at bus 77190	: Vg=0.9883 -> Vg=1.0
% INFO    : Gen at bus 77191	: Pg=90.22, Qg=-5.14 -> Pg=90.22, Qg=17.59
% INFO    : Gen at bus 77191	: Vg=0.9886 -> Vg=1.0
% INFO    : Gen at bus 77195	: Pg=67.42, Qg=2.01 -> Pg=47.27, Qg=13.475
% INFO    : Gen at bus 77195	: Vg=1.0227 -> Vg=1.0
% INFO    : Gen at bus 77196	: Pg=67.42, Qg=2.01 -> Pg=46.885, Qg=13.475
% INFO    : Gen at bus 77196	: Vg=1.0229 -> Vg=1.0
% INFO    : Gen at bus 77197	: Pg=0.0, Qg=0.0 -> Pg=45.855, Qg=13.475
% INFO    : Gen at bus 77197	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 77199	: Pg=0.0, Qg=0.0 -> Pg=27.555, Qg=7.93
% INFO    : Gen at bus 77199	: Vg=1.0272 -> Vg=1.0
% INFO    : Gen at bus 77200	: Pg=4.35, Qg=-0.39 -> Pg=4.35, Qg=1.34
% INFO    : Gen at bus 77200	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77200	: Pg=0.0, Qg=0.0 -> Pg=4.915, Qg=1.34
% INFO    : Gen at bus 77200	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77200	: Pg=5.32, Qg=-0.39 -> Pg=5.32, Qg=1.34
% INFO    : Gen at bus 77200	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77204	: Pg=0.0, Qg=0.0 -> Pg=78.05, Qg=3.67
% INFO    : Gen at bus 77204	: Vg=1.0207 -> Vg=1.0
% INFO    : Gen at bus 77207	: Pg=5.79, Qg=2.07 -> Pg=5.79, Qg=0.335
% INFO    : Gen at bus 77207	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 77207	: Pg=0.0, Qg=0.0 -> Pg=5.32, Qg=0.33
% INFO    : Gen at bus 77207	: Vg=1.0375 -> Vg=1.0
% INFO    : Gen at bus 77213	: Pg=172.1, Qg=-21.08 -> Pg=104.855, Qg=29.72
% INFO    : Gen at bus 77213	: Vg=1.0019 -> Vg=1.0
% INFO    : Gen at bus 77216	: Pg=0.0, Qg=0.0 -> Pg=42.68, Qg=10.47
% INFO    : Gen at bus 77216	: Vg=1.0318 -> Vg=1.0
% INFO    : Gen at bus 77217	: Pg=43.2, Qg=24.0 -> Pg=43.2, Qg=10.47
% INFO    : Gen at bus 77217	: Vg=1.0451 -> Vg=1.0
% INFO    : Gen at bus 77218	: Pg=35.53, Qg=24.0 -> Pg=35.53, Qg=10.47
% INFO    : Gen at bus 77218	: Vg=1.0469 -> Vg=1.0
% INFO    : Gen at bus 77219	: Pg=40.32, Qg=24.0 -> Pg=40.32, Qg=10.47
% INFO    : Gen at bus 77219	: Vg=1.0452 -> Vg=1.0
% INFO    : Gen at bus 77223	: Pg=83.19, Qg=17.46 -> Pg=83.19, Qg=17.925
% INFO    : Gen at bus 77223	: Vg=1.0225 -> Vg=1.0
% INFO    : Gen at bus 77224	: Pg=90.98, Qg=17.46 -> Pg=90.98, Qg=17.925
% INFO    : Gen at bus 77224	: Vg=1.0219 -> Vg=1.0
% INFO    : Gen at bus 77225	: Pg=107.0, Qg=17.46 -> Pg=107.0, Qg=17.925
% INFO    : Gen at bus 77225	: Vg=1.0233 -> Vg=1.0
% INFO    : Gen at bus 77226	: Pg=0.0, Qg=0.0 -> Pg=77.82, Qg=17.925
% INFO    : Gen at bus 77226	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 77228	: Pg=8.42, Qg=-0.48 -> Pg=8.42, Qg=1.62
% INFO    : Gen at bus 77228	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 77229	: Pg=12.97, Qg=-0.81 -> Pg=12.97, Qg=2.78
% INFO    : Gen at bus 77229	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 77229	: Pg=0.0, Qg=0.0 -> Pg=12.38, Qg=2.78
% INFO    : Gen at bus 77229	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 77229	: Pg=9.01, Qg=-0.81 -> Pg=9.01, Qg=2.78
% INFO    : Gen at bus 77229	: Vg=1.0251 -> Vg=1.0
% INFO    : Gen at bus 77231	: Pg=0.0, Qg=0.0 -> Pg=5.015, Qg=0.31
% INFO    : Gen at bus 77231	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77231	: Pg=7.23, Qg=-1.44 -> Pg=7.23, Qg=0.345
% INFO    : Gen at bus 77231	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77236	: Pg=57.44, Qg=21.78 -> Pg=57.44, Qg=11.59
% INFO    : Gen at bus 77236	: Vg=1.0005 -> Vg=1.0
% INFO    : Gen at bus 77237	: Pg=47.12, Qg=21.78 -> Pg=47.12, Qg=11.59
% INFO    : Gen at bus 77237	: Vg=1.0013 -> Vg=1.0
% INFO    : Gen at bus 77238	: Pg=54.18, Qg=21.78 -> Pg=54.18, Qg=11.59
% INFO    : Gen at bus 77238	: Vg=1.0025 -> Vg=1.0
% INFO    : Gen at bus 77243	: Pg=29.2, Qg=10.67 -> Pg=29.2, Qg=6.205
% INFO    : Gen at bus 77243	: Vg=0.9855 -> Vg=1.0
% INFO    : Gen at bus 77243	: Pg=37.06, Qg=10.67 -> Pg=37.06, Qg=6.205
% INFO    : Gen at bus 77243	: Vg=0.9855 -> Vg=1.0
% INFO    : Gen at bus 77244	: Pg=28.91, Qg=10.67 -> Pg=28.91, Qg=6.205
% INFO    : Gen at bus 77244	: Vg=0.9826 -> Vg=1.0
% INFO    : Gen at bus 77244	: Pg=27.91, Qg=10.67 -> Pg=27.91, Qg=6.205
% INFO    : Gen at bus 77244	: Vg=0.9826 -> Vg=1.0
% INFO    : Gen at bus 77245	: Pg=18.64, Qg=14.23 -> Pg=18.64, Qg=6.205
% INFO    : Gen at bus 77245	: Vg=0.983 -> Vg=1.0
% INFO    : Gen at bus 77248	: Pg=67.72, Qg=-8.3 -> Pg=41.13, Qg=11.695
% INFO    : Gen at bus 77248	: Vg=1.0238 -> Vg=1.0
% INFO    : Gen at bus 77250	: Pg=7.0, Qg=-1.44 -> Pg=7.0, Qg=0.345
% INFO    : Gen at bus 77250	: Vg=1.0142 -> Vg=1.0
% INFO    : Gen at bus 77251	: Pg=7.22, Qg=-1.44 -> Pg=7.22, Qg=0.345
% INFO    : Gen at bus 77251	: Vg=1.0132 -> Vg=1.0
% INFO    : Gen at bus 77252	: Pg=10.66, Qg=5.57 -> Pg=10.66, Qg=2.43
% INFO    : Gen at bus 77252	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 77253	: Pg=14.52, Qg=-0.71 -> Pg=14.52, Qg=2.43
% INFO    : Gen at bus 77253	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77253	: Pg=12.39, Qg=-0.71 -> Pg=12.39, Qg=2.43
% INFO    : Gen at bus 77253	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77253	: Pg=8.81, Qg=-0.71 -> Pg=8.81, Qg=2.43
% INFO    : Gen at bus 77253	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77253	: Pg=10.57, Qg=-0.71 -> Pg=10.57, Qg=2.43
% INFO    : Gen at bus 77253	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77253	: Pg=10.56, Qg=-0.71 -> Pg=10.56, Qg=2.43
% INFO    : Gen at bus 77253	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77258	: Pg=176.66, Qg=-26.01 -> Pg=368.17, Qg=97.695
% INFO    : Gen at bus 77258	: Vg=0.9926 -> Vg=1.0
% INFO    : Gen at bus 77259	: Pg=565.69, Qg=-26.01 -> Pg=419.055, Qg=97.695
% INFO    : Gen at bus 77259	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 77260	: Pg=198.93, Qg=-26.01 -> Pg=332.125, Qg=97.695
% INFO    : Gen at bus 77260	: Vg=0.9902 -> Vg=1.0
% INFO    : Gen at bus 77261	: Pg=565.69, Qg=-26.01 -> Pg=337.36, Qg=97.695
% INFO    : Gen at bus 77261	: Vg=0.9904 -> Vg=1.0
% INFO    : Gen at bus 77264	: Pg=9.11, Qg=-0.66 -> Pg=5.785, Qg=1.82
% INFO    : Gen at bus 77264	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 77264	: Pg=9.11, Qg=-0.66 -> Pg=5.88, Qg=1.82
% INFO    : Gen at bus 77264	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 77264	: Pg=9.11, Qg=-0.66 -> Pg=5.965, Qg=1.82
% INFO    : Gen at bus 77264	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 77264	: Pg=0.0, Qg=0.0 -> Pg=5.46, Qg=1.82
% INFO    : Gen at bus 77264	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 77264	: Pg=2.92, Qg=-0.66 -> Pg=5.97, Qg=1.82
% INFO    : Gen at bus 77264	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 77264	: Pg=9.11, Qg=-0.66 -> Pg=5.71, Qg=1.82
% INFO    : Gen at bus 77264	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 77267	: Pg=57.69, Qg=-2.89 -> Pg=57.69, Qg=9.885
% INFO    : Gen at bus 77267	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77268	: Pg=22.98, Qg=-1.48 -> Pg=22.98, Qg=5.06
% INFO    : Gen at bus 77268	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 77269	: Pg=21.98, Qg=-1.48 -> Pg=21.98, Qg=5.06
% INFO    : Gen at bus 77269	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77270	: Pg=9.27, Qg=-0.47 -> Pg=9.27, Qg=1.61
% INFO    : Gen at bus 77270	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 77270	: Pg=6.63, Qg=-0.47 -> Pg=6.63, Qg=1.61
% INFO    : Gen at bus 77270	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 77270	: Pg=9.6, Qg=-0.47 -> Pg=9.6, Qg=1.61
% INFO    : Gen at bus 77270	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 77270	: Pg=7.33, Qg=-0.47 -> Pg=7.33, Qg=1.61
% INFO    : Gen at bus 77270	: Vg=1.0172 -> Vg=1.0
% INFO    : Gen at bus 77274	: Pg=78.26, Qg=40.89 -> Pg=78.26, Qg=17.835
% INFO    : Gen at bus 77274	: Vg=1.0292 -> Vg=1.0
% INFO    : Gen at bus 77275	: Pg=75.25, Qg=40.89 -> Pg=75.25, Qg=17.835
% INFO    : Gen at bus 77275	: Vg=1.0226 -> Vg=1.0
% INFO    : Gen at bus 77276	: Pg=68.38, Qg=40.89 -> Pg=68.38, Qg=17.835
% INFO    : Gen at bus 77276	: Vg=1.0314 -> Vg=1.0
% INFO    : Gen at bus 77277	: Pg=0.0, Qg=0.0 -> Pg=70.01, Qg=17.835
% INFO    : Gen at bus 77277	: Vg=1.0157 -> Vg=1.0
% INFO    : Gen at bus 77278	: Pg=0.0, Qg=0.0 -> Pg=77.795, Qg=17.835
% INFO    : Gen at bus 77278	: Vg=1.0157 -> Vg=1.0
% INFO    : Gen at bus 77280	: Pg=78.36, Qg=22.05 -> Pg=78.36, Qg=3.575
% INFO    : Gen at bus 77280	: Vg=1.0081 -> Vg=1.0
% INFO    : Gen at bus 77286	: Pg=115.23, Qg=-3.94 -> Pg=76.11, Qg=19.9
% INFO    : Gen at bus 77286	: Vg=1.0265 -> Vg=1.0
% INFO    : Gen at bus 77289	: Pg=180.65, Qg=-23.61 -> Pg=180.65, Qg=6.52
% INFO    : Gen at bus 77289	: Vg=1.0081 -> Vg=1.0
% INFO    : Gen at bus 77290	: Pg=7.31, Qg=16.58 -> Pg=24.6, Qg=8.475
% INFO    : Gen at bus 77290	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 77291	: Pg=5.48, Qg=-0.41 -> Pg=5.48, Qg=1.41
% INFO    : Gen at bus 77291	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77291	: Pg=8.4, Qg=-0.41 -> Pg=8.4, Qg=1.41
% INFO    : Gen at bus 77291	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77291	: Pg=8.4, Qg=-0.41 -> Pg=8.4, Qg=1.41
% INFO    : Gen at bus 77291	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77291	: Pg=0.0, Qg=0.0 -> Pg=5.54, Qg=1.41
% INFO    : Gen at bus 77291	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77291	: Pg=6.76, Qg=-0.41 -> Pg=6.76, Qg=1.41
% INFO    : Gen at bus 77291	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77291	: Pg=8.2, Qg=-0.41 -> Pg=8.2, Qg=1.41
% INFO    : Gen at bus 77291	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77294	: Pg=0.0, Qg=0.0 -> Pg=4.265, Qg=1.255
% INFO    : Gen at bus 77294	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77294	: Pg=0.0, Qg=0.0 -> Pg=15.27, Qg=4.525
% INFO    : Gen at bus 77294	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 77294	: Pg=22.54, Qg=-1.32 -> Pg=22.54, Qg=4.525
% INFO    : Gen at bus 77294	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 80085	: Pg=0.0, Qg=0.0 -> Pg=55.75, Qg=16.015
% INFO    : Gen at bus 80085	: Vg=1.0192 -> Vg=1.0
% INFO    : Gen at bus 80091	: Pg=104.24, Qg=21.02 -> Pg=70.425, Qg=20.83
% INFO    : Gen at bus 80091	: Vg=1.0258 -> Vg=1.0
% INFO    : Gen at bus 80092	: Pg=104.24, Qg=21.02 -> Pg=71.535, Qg=20.83
% INFO    : Gen at bus 80092	: Vg=1.0245 -> Vg=1.0
% INFO    : Gen at bus 80093	: Pg=104.24, Qg=21.02 -> Pg=65.545, Qg=20.83
% INFO    : Gen at bus 80093	: Vg=1.0242 -> Vg=1.0
% INFO    : Gen at bus 80094	: Pg=104.24, Qg=21.02 -> Pg=58.895, Qg=20.83
% INFO    : Gen at bus 80094	: Vg=1.0254 -> Vg=1.0
% INFO    : Gen at bus 80095	: Pg=104.24, Qg=21.02 -> Pg=78.375, Qg=20.83
% INFO    : Gen at bus 80095	: Vg=1.0253 -> Vg=1.0
% INFO    : Gen at bus 80096	: Pg=104.24, Qg=21.02 -> Pg=64.215, Qg=20.83
% INFO    : Gen at bus 80096	: Vg=1.0249 -> Vg=1.0
% INFO    : Gen at bus 80097	: Pg=0.0, Qg=0.0 -> Pg=67.99, Qg=18.91
% INFO    : Gen at bus 80097	: Vg=1.0221 -> Vg=1.0
% INFO    : Gen at bus 80098	: Pg=94.61, Qg=21.02 -> Pg=68.18, Qg=18.91
% INFO    : Gen at bus 80098	: Vg=1.0254 -> Vg=1.0
% INFO    : Gen at bus 80099	: Pg=94.61, Qg=21.02 -> Pg=67.41, Qg=18.91
% INFO    : Gen at bus 80099	: Vg=1.0277 -> Vg=1.0
% INFO    : Gen at bus 80100	: Pg=6.67, Qg=0.0 -> Pg=6.67, Qg=0.0
% INFO    : Gen at bus 80100	: Vg=1.04 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
