%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v19.01     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                       04 - January - 2019                        %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is an entirely synthetic 2000 bus case, geographically situated
%   in the US state of Texas. The case is designed with a 500, 230, 161
%   and 115 kV transmission network to serve a load that roughly mimics
%   the actual population of its geographic footprint. The synthetic
%   transmission system was designed by algorithms described in [1] to be
%   statistically similar to actual transmission system models but without
%   modeling any actual lines.
%
%   When publishing results based on this data, please cite:
%
%   [1] A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye, T.J. Overbye,
%       "Grid Structural Characteristics as Validation Criteria for
%       Synthetic Networks," IEEE Transactions on Power Systems,
%       vol. 32, no. 4, pp. 3258-3265, July 2017.
%       DOI: 10.1109/TPWRS.2016.2616385
%
%   This is a synthetic power system model that does not represent the
%   actual grid. It was developed as part of the US ARPA-E GRID DATA
%   research project and contains no CEII.
%
%   One-line diagrams and other data formats available at:
%       https://electricgrids.engr.tamu.edu
%
%   February 3, 2018
%
%   Created from ACTIVSg2000.pwb, saved by
%   PowerWorld Simulator, version 20, build date January 28, 2018,
%   then by MATPOWER 6.
%
%   Copyright (c) 2017-2018 by A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye,
%   and T.J. Overbye
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case2000_tamu
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1001	 1	 20.78	 5.89	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1002	 1	 15.41	 4.37	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1003	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1004	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 9	    1.10000	    0.90000;
	1005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1006	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1007	 1	 7.01	 1.99	 0.0	 -0.82	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1008	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1009	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1010	 1	 0.0	 0.0	 0.0	 -3.07	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1011	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 9	    1.10000	    0.90000;
	1012	 1	 2.99	 0.85	 0.0	 9.5	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1013	 1	 29.23	 8.28	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1014	 1	 2.22	 0.63	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1015	 1	 7.51	 2.13	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1016	 1	 2.89	 0.82	 0.0	 30.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1017	 1	 18.34	 5.2	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1018	 1	 0.07	 0.02	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1019	 1	 61.78	 17.5	 0.0	 142.98	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1020	 1	 0.0	 0.0	 0.0	 67.23	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1021	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1024	 1	 63.04	 17.86	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1026	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1027	 1	 101.21	 28.68	 0.0	 75.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1028	 1	 10.01	 2.84	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1029	 1	 83.18	 23.57	 0.0	 40.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1030	 1	 24.63	 6.98	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1031	 1	 9.25	 2.62	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1032	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1033	 2	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 230.0	 9	    1.10000	    0.90000;
	1034	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1035	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1036	 1	 13.6	 3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1037	 1	 102.24	 28.97	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1038	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1039	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 9	    1.10000	    0.90000;
	1040	 1	 44.36	 12.57	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1042	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1043	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1044	 1	 14.68	 4.16	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1045	 1	 98.56	 27.93	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1046	 1	 11.08	 3.14	 0.0	 12.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1048	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1049	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1050	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1051	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1052	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1053	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 230.0	 9	    1.10000	    0.90000;
	1054	 1	 14.99	 4.25	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1055	 1	 3.98	 1.13	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1056	 1	 0.0	 0.0	 0.0	 59.97	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1057	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1058	 1	 13.46	 3.81	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1059	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 9	    1.10000	    0.90000;
	1060	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 22.0	 9	    1.10000	    0.90000;
	1061	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1062	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1063	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1064	 1	 123.76	 35.07	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1065	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1066	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1067	 1	 101.55	 28.77	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1068	 1	 59.4	 16.83	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1070	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 9	    1.10000	    0.90000;
	1071	 1	 91.46	 25.91	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1072	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1073	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1074	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1075	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1076	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1077	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1078	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1079	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 500.0	 9	    1.10000	    0.90000;
	1080	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 9	    1.10000	    0.90000;
	1081	 2	 0.0	 0.0	 0.0	 56.9	 1	    1.00000	    0.00000	 230.0	 9	    1.10000	    0.90000;
	1082	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1083	 1	 39.95	 11.32	 0.0	 26.15	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1084	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1085	 1	 21.3	 6.03	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1086	 1	 39.67	 11.24	 0.0	 30.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1087	 1	 0.91	 0.26	 0.0	 8.66	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1088	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1089	 1	 40.6	 11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1090	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 115.0	 9	    1.10000	    0.90000;
	1091	 1	 11.62	 3.29	 0.0	 0.0	 1	    1.00000	    0.00000	 161.0	 9	    1.10000	    0.90000;
	2001	 1	 48.36	 13.7	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2002	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 11	    1.10000	    0.90000;
	2003	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2004	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2005	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2006	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2007	 1	 9.54	 2.7	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2008	 1	 8.06	 2.28	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2009	 1	 39.14	 11.09	 0.0	 113.65	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2010	 1	 56.81	 16.09	 0.0	 22.39	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2011	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 10	    1.10000	    0.90000;
	2012	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2013	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 10	    1.10000	    0.90000;
	2014	 1	 25.43	 7.2	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2015	 1	 4.69	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2016	 1	 69.27	 19.63	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2017	 1	 0.0	 0.0	 0.0	 -200.0	 2	    1.00000	    0.00000	 500.0	 10	    1.10000	    0.90000;
	2018	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2019	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2020	 1	 47.97	 13.59	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2021	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 11	    1.10000	    0.90000;
	2022	 1	 11.56	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2023	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2024	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2025	 1	 39.62	 11.23	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2026	 1	 18.57	 5.26	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2027	 1	 3.55	 1.01	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2028	 1	 14.24	 4.03	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2029	 1	 3.2	 0.91	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2030	 1	 47.15	 13.36	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2031	 1	 5.77	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2032	 1	 3.35	 0.95	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2033	 1	 13.57	 3.85	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2034	 1	 5.34	 1.51	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2035	 1	 4.68	 1.33	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2036	 1	 41.59	 11.78	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2037	 1	 3.5	 0.99	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2038	 1	 2.6	 0.74	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2039	 1	 5.56	 1.58	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2040	 1	 15.9	 4.51	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2041	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2042	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 10	    1.10000	    0.90000;
	2043	 1	 4.24	 1.2	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2044	 1	 27.4	 7.76	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2045	 1	 22.61	 6.4	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2046	 1	 22.13	 6.27	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2047	 1	 14.96	 4.24	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2048	 1	 6.42	 1.82	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2049	 1	 11.57	 3.28	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2050	 1	 3.66	 1.04	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2051	 1	 17.85	 5.06	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2052	 1	 24.84	 7.04	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2053	 1	 29.13	 8.25	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2054	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 11	    1.10000	    0.90000;
	2055	 1	 49.62	 14.06	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2056	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 11	    1.10000	    0.90000;
	2057	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 11	    1.10000	    0.90000;
	2058	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2059	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 10	    1.10000	    0.90000;
	2060	 1	 3.8	 1.08	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2061	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2062	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 10	    1.10000	    0.90000;
	2063	 1	 65.62	 18.59	 0.0	 40.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2064	 1	 10.05	 2.85	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2065	 1	 78.36	 22.2	 0.0	 94.98	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2066	 1	 7.11	 2.02	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2067	 1	 53.97	 15.29	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2068	 1	 5.76	 1.63	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2069	 1	 21.92	 6.21	 0.0	 110.69	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2070	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2071	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 11	    1.10000	    0.90000;
	2072	 1	 9.71	 2.75	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2073	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2074	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 115.0	 10	    1.10000	    0.90000;
	2075	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 115.0	 10	    1.10000	    0.90000;
	2076	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 10	    1.10000	    0.90000;
	2077	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2078	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2079	 1	 4.48	 1.27	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2080	 1	 16.93	 4.8	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2081	 1	 4.46	 1.26	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2082	 1	 59.03	 16.73	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2083	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 11	    1.10000	    0.90000;
	2084	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 11	    1.10000	    0.90000;
	2085	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 11	    1.10000	    0.90000;
	2086	 1	 2.19	 0.62	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2087	 1	 7.9	 2.24	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2088	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2089	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 24.0	 11	    1.10000	    0.90000;
	2090	 1	 2.42	 0.69	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2091	 1	 17.05	 4.83	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2092	 1	 24.11	 6.83	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2093	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2094	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 10	    1.10000	    0.90000;
	2095	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 10	    1.10000	    0.90000;
	2096	 1	 0.0	 0.0	 0.0	 -122.33	 2	    1.00000	    0.00000	 500.0	 10	    1.10000	    0.90000;
	2097	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 230.0	 10	    1.10000	    0.90000;
	2098	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2099	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 10	    1.10000	    0.90000;
	2100	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 18.0	 10	    1.10000	    0.90000;
	2101	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 11	    1.10000	    0.90000;
	2102	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2103	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 11	    1.10000	    0.90000;
	2104	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 11	    1.10000	    0.90000;
	2105	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 20.0	 11	    1.10000	    0.90000;
	2106	 1	 14.4	 4.08	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2107	 1	 74.15	 21.01	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2108	 1	 2.14	 0.61	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2109	 1	 33.81	 9.58	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2110	 1	 8.59	 2.43	 0.0	 40.13	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2111	 1	 13.95	 3.95	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2112	 1	 4.54	 1.29	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2113	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 500.0	 11	    1.10000	    0.90000;
	2114	 1	 70.78	 20.05	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2115	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2116	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2117	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2118	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2119	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2120	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 13.8	 11	    1.10000	    0.90000;
	2121	 1	 2.33	 0.66	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2122	 1	 6.72	 1.9	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2123	 2	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2124	 1	 21.29	 6.03	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2125	 1	 4.06	 1.15	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2126	 1	 14.24	 4.03	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2127	 2	 0.0	 0.0	 0.0	 -155.97	 2	    1.00000	    0.00000	 500.0	 10	    1.10000	    0.90000;
	2128	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2129	 1	 6.63	 1.88	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	2130	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 10	    1.10000	    0.90000;
	2131	 1	 0.0	 0.0	 0.0	 0.0	 2	    1.00000	    0.00000	 115.0	 10	    1.10000	    0.90000;
	2132	 1	 11.94	 3.38	 0.0	 10.0	 2	    1.00000	    0.00000	 115.0	 10	    1.10000	    0.90000;
	2133	 1	 5.68	 1.61	 0.0	 0.0	 2	    1.00000	    0.00000	 161.0	 11	    1.10000	    0.90000;
	3001	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 28	    1.10000	    0.90000;
	3002	 1	 112.86	 31.98	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3003	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3004	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3005	 1	 7.34	 2.08	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3006	 1	 7.35	 2.08	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3007	 1	 14.96	 4.24	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3008	 1	 19.81	 5.61	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3009	 1	 12.54	 3.55	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3010	 1	 4.67	 1.32	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3011	 1	 27.14	 7.69	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3012	 1	 0.56	 0.16	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3013	 1	 64.56	 18.29	 0.0	 65.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3014	 1	 22.0	 6.23	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3015	 1	 5.36	 1.52	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3016	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3017	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3018	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3019	 1	 0.0	 0.0	 0.0	 27.84	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3020	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3021	 1	 1.94	 0.55	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3022	 1	 24.59	 6.97	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3023	 1	 10.41	 2.95	 0.0	 46.37	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3024	 1	 10.13	 2.87	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3025	 1	 13.67	 3.87	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3026	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3027	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3028	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3029	 1	 4.87	 1.38	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3030	 1	 129.72	 36.75	 0.0	 80.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3031	 1	 14.73	 4.17	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3032	 1	 72.86	 20.64	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3033	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3034	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 22.0	 27	    1.10000	    0.90000;
	3035	 1	 3.47	 0.98	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3036	 1	 5.8	 1.64	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3037	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3038	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3039	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3040	 1	 14.61	 4.14	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3041	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3042	 1	 8.75	 2.48	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3043	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3044	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3045	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3046	 1	 0.0	 0.0	 0.0	 200.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3047	 1	 0.0	 0.0	 0.0	 99.71	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3048	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 500.0	 27	    1.10000	    0.90000;
	3049	 1	 10.58	 3.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3050	 1	 0.0	 0.0	 0.0	 65.0	 3	    1.00000	    0.00000	 230.0	 28	    1.10000	    0.90000;
	3051	 1	 145.29	 41.17	 0.0	 20.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3052	 1	 8.08	 2.29	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3053	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3054	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3055	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3056	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3057	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3058	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3059	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3060	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3061	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3062	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3063	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3064	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3065	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3066	 1	 22.03	 6.24	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3067	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3068	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 27	    1.10000	    0.90000;
	3069	 1	 3.81	 1.08	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3070	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3071	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 24.0	 27	    1.10000	    0.90000;
	3072	 1	 5.98	 1.7	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3073	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3074	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 28	    1.10000	    0.90000;
	3075	 1	 12.18	 3.45	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3076	 1	 10.79	 3.06	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3077	 1	 68.66	 19.45	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3078	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3079	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 161.0	 27	    1.10000	    0.90000;
	3080	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3081	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 20.0	 27	    1.10000	    0.90000;
	3082	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3083	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3084	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3085	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3086	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 27	    1.10000	    0.90000;
	3087	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 27	    1.10000	    0.90000;
	3088	 1	 0.0	 0.0	 0.0	 34.55	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3089	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 161.0	 27	    1.10000	    0.90000;
	3090	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 161.0	 27	    1.10000	    0.90000;
	3091	 1	 0.0	 0.0	 0.0	 81.81	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3092	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3093	 1	 5.05	 1.43	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3094	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3095	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3096	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3097	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3098	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3099	 1	 12.08	 3.42	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3100	 1	 8.53	 2.42	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3101	 1	 9.43	 2.67	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3102	 1	 75.26	 21.32	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3103	 1	 39.32	 11.14	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3104	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3105	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 28	    1.10000	    0.90000;
	3106	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.2	 28	    1.10000	    0.90000;
	3107	 1	 14.87	 4.21	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3108	 1	 23.52	 6.66	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3109	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3110	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3111	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3112	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3113	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3114	 1	 98.31	 27.85	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3115	 1	 9.58	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3116	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3117	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3118	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 27	    1.10000	    0.90000;
	3119	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3120	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 13.8	 28	    1.10000	    0.90000;
	3121	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3122	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 18.0	 27	    1.10000	    0.90000;
	3123	 1	 66.07	 18.72	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3124	 1	 64.54	 18.29	 0.0	 44.23	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3125	 1	 91.26	 25.86	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3126	 1	 9.96	 2.82	 0.0	 37.42	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3127	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3128	 1	 2.82	 0.8	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3129	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3130	 1	 92.15	 26.11	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3131	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3132	 1	 9.56	 2.71	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3133	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 230.0	 27	    1.10000	    0.90000;
	3134	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 161.0	 27	    1.10000	    0.90000;
	3135	 1	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 161.0	 27	    1.10000	    0.90000;
	3136	 1	 46.96	 13.3	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3137	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3138	 1	 10.95	 3.1	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3139	 1	 14.92	 4.23	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3140	 1	 0.22	 0.06	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3141	 2	 0.0	 0.0	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3142	 1	 7.07	 2.0	 0.0	 30.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3143	 1	 5.75	 1.63	 0.0	 17.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3144	 1	 5.56	 1.57	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3145	 1	 2.94	 0.83	 0.0	 0.0	 3	    1.00000	    0.00000	 115.0	 27	    1.10000	    0.90000;
	3146	 1	 12.04	 3.41	 0.0	 15.0	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	3147	 1	 34.76	 9.85	 0.0	 29.16	 3	    1.00000	    0.00000	 115.0	 28	    1.10000	    0.90000;
	4002	 1	 1.01	 0.29	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4003	 1	 127.29	 36.07	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4004	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4005	 1	 164.14	 46.51	 0.0	 70.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4006	 1	 2.75	 0.78	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4007	 1	 183.66	 52.04	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4008	 1	 32.49	 9.21	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4009	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4010	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 21	    1.10000	    0.90000;
	4011	 1	 16.05	 4.55	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4012	 1	 13.74	 3.89	 0.0	 50.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4013	 1	 92.35	 26.17	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4014	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4015	 1	 159.81	 45.28	 0.0	 65.14	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4016	 1	 6.25	 1.77	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4017	 1	 89.56	 25.38	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4018	 1	 7.14	 2.02	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4019	 1	 135.83	 38.48	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4020	 1	 117.81	 33.38	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4021	 1	 31.97	 9.06	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4022	 1	 5.56	 1.58	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4023	 1	 5.06	 1.43	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4024	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4025	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4026	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 20	    1.10000	    0.90000;
	4027	 1	 65.12	 18.45	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4028	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4029	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4030	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4031	 1	 2.75	 0.78	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4032	 1	 91.39	 25.89	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4033	 1	 126.25	 35.77	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4034	 1	 37.64	 10.66	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4035	 1	 79.16	 22.43	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4036	 1	 35.07	 9.94	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4037	 1	 28.72	 8.14	 0.0	 65.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4038	 1	 83.3	 23.6	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4039	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 19	    1.10000	    0.90000;
	4040	 1	 225.66	 63.94	 0.0	 342.33	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4041	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 19	    1.10000	    0.90000;
	4042	 1	 215.18	 60.97	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4043	 1	 2.47	 0.7	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4044	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4045	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4046	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4047	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4048	 1	 13.1	 3.71	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4049	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4050	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4051	 1	 89.39	 25.33	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4052	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 21	    1.10000	    0.90000;
	4053	 1	 0.11	 0.03	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4054	 1	 5.6	 1.59	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4055	 1	 17.78	 5.04	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4056	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4057	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4058	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4059	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4060	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4061	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4062	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4063	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4064	 1	 8.82	 2.5	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4065	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 21	    1.10000	    0.90000;
	4066	 1	 191.53	 54.27	 0.0	 145.13	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4067	 1	 159.46	 45.18	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4068	 1	 27.99	 7.93	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4069	 1	 4.24	 1.2	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4070	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 19	    1.10000	    0.90000;
	4071	 1	 281.45	 79.75	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4072	 1	 51.71	 14.65	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4073	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 19	    1.10000	    0.90000;
	4074	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4075	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 19	    1.10000	    0.90000;
	4076	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 19	    1.10000	    0.90000;
	4077	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 24.0	 19	    1.10000	    0.90000;
	4078	 1	 84.07	 23.82	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4079	 1	 171.21	 48.51	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4080	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4081	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4082	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4083	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4084	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4085	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4086	 1	 19.87	 5.63	 0.0	 95.16	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4087	 1	 2.08	 0.59	 0.0	 120.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4088	 1	 212.52	 60.21	 0.0	 278.42	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4089	 1	 8.6	 2.44	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4090	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4091	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4092	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4093	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4094	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4095	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4096	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4097	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4098	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 19	    1.10000	    0.90000;
	4099	 1	 15.17	 4.3	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4100	 1	 50.6	 14.34	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4101	 1	 128.14	 36.31	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4102	 1	 24.17	 6.85	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4103	 1	 189.88	 53.8	 0.0	 120.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4104	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4105	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 21	    1.10000	    0.90000;
	4106	 1	 37.55	 10.64	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4107	 1	 118.36	 33.54	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4108	 1	 28.34	 8.03	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4109	 1	 110.86	 31.41	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4110	 1	 57.35	 16.25	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4111	 1	 104.08	 29.49	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4112	 1	 5.59	 1.58	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4113	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4114	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4115	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 20	    1.10000	    0.90000;
	4116	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 20	    1.10000	    0.90000;
	4117	 1	 18.89	 5.35	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4118	 1	 13.88	 3.93	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4119	 1	 55.57	 15.75	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4120	 1	 46.52	 13.18	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4121	 1	 4.11	 1.16	 0.0	 50.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4122	 1	 146.11	 41.4	 0.0	 150.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4123	 1	 90.5	 25.64	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4124	 1	 24.38	 6.91	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4125	 1	 4.5	 1.28	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4126	 1	 127.38	 36.09	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4127	 1	 87.29	 24.73	 0.0	 70.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4128	 1	 123.51	 35.0	 0.0	 70.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4129	 1	 18.51	 5.25	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4130	 1	 9.48	 2.69	 0.0	 20.9	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4131	 1	 0.0	 0.0	 0.0	 59.58	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4132	 1	 33.09	 9.38	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4133	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4134	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4135	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4136	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4137	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4138	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4139	 1	 10.62	 3.01	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4140	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4141	 1	 0.0	 0.0	 0.0	 60.3	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4142	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4143	 1	 14.36	 4.07	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4144	 1	 16.36	 4.63	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4145	 1	 49.86	 14.13	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4146	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4147	 1	 193.64	 54.87	 0.0	 92.09	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4148	 1	 14.64	 4.15	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4149	 1	 61.36	 17.38	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4150	 1	 12.53	 3.55	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4151	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4152	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4153	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 18.0	 21	    1.10000	    0.90000;
	4154	 1	 26.32	 7.46	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4155	 1	 19.45	 5.51	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4156	 1	 108.01	 30.6	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4157	 1	 104.67	 29.66	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4158	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4159	 1	 36.18	 10.25	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4160	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4161	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4162	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4163	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4164	 1	 2.03	 0.57	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4165	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4166	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 21	    1.10000	    0.90000;
	4167	 1	 5.31	 1.5	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4168	 1	 8.87	 2.51	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4169	 1	 27.68	 7.84	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4170	 1	 35.86	 10.16	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4171	 1	 167.63	 47.5	 0.0	 100.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4172	 1	 42.31	 11.99	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4173	 1	 12.05	 3.42	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4174	 1	 19.16	 5.43	 0.0	 85.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4175	 1	 3.16	 0.89	 0.0	 13.02	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4176	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4177	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 13.8	 20	    1.10000	    0.90000;
	4178	 1	 17.46	 4.95	 0.0	 43.6	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4179	 1	 19.92	 5.64	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4180	 1	 10.76	 3.05	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4181	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 21	    1.10000	    0.90000;
	4182	 1	 22.68	 6.43	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 21	    1.10000	    0.90000;
	4183	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 19	    1.10000	    0.90000;
	4184	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4185	 1	 37.84	 10.72	 0.0	 20.63	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4186	 1	 37.06	 10.5	 0.0	 53.8	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4187	 1	 15.06	 4.27	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4188	 1	 2.97	 0.84	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4189	 1	 29.89	 8.47	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4190	 1	 132.46	 37.53	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	4191	 1	 46.43	 13.16	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4192	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 19	    1.10000	    0.90000;
	4193	 1	 178.22	 50.5	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4194	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 19	    1.10000	    0.90000;
	4195	 2	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 500.0	 20	    1.10000	    0.90000;
	4196	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 230.0	 20	    1.10000	    0.90000;
	4197	 1	 0.0	 0.0	 0.0	 0.0	 4	    1.00000	    0.00000	 115.0	 20	    1.10000	    0.90000;
	5003	 1	 113.64	 32.2	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5004	 1	 11.69	 3.31	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5005	 1	 8.95	 2.53	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5006	 1	 100.19	 28.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5007	 1	 72.05	 20.42	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5008	 1	 7.6	 2.15	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5009	 1	 62.68	 17.76	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5010	 1	 133.87	 37.93	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5011	 1	 7.64	 2.17	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5012	 1	 81.32	 23.04	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5013	 1	 19.34	 5.48	 0.0	 36.26	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5014	 1	 46.76	 13.25	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5015	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5016	 1	 181.16	 51.33	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5017	 1	 13.85	 3.93	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5018	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5019	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5020	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5021	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5022	 1	 140.24	 39.73	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5023	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5024	 1	 50.92	 14.43	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5025	 1	 74.46	 21.1	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5026	 1	 71.11	 20.15	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5027	 1	 74.13	 21.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5028	 1	 9.35	 2.65	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5029	 1	 12.77	 3.62	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5030	 1	 79.61	 22.55	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5031	 1	 42.36	 12.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5032	 1	 47.16	 13.36	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5033	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5034	 1	 55.35	 15.68	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5035	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5036	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5037	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5038	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5039	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5040	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5041	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5042	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 16	    1.10000	    0.90000;
	5043	 1	 68.1	 19.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5044	 1	 17.5	 4.96	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5045	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 18	    1.10000	    0.90000;
	5046	 1	 77.11	 21.85	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5047	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5048	 1	 184.54	 52.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5049	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5050	 1	 64.6	 18.3	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5051	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 22.0	 16	    1.10000	    0.90000;
	5052	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 16	    1.10000	    0.90000;
	5053	 1	 152.78	 43.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5054	 1	 21.17	 6.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5055	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5056	 1	 40.4	 11.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5057	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5058	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5059	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5060	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 14	    1.10000	    0.90000;
	5061	 1	 0.0	 0.0	 0.0	 33.47	 5	    1.00000	    0.00000	 115.0	 14	    1.10000	    0.90000;
	5062	 1	 43.74	 12.39	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 14	    1.10000	    0.90000;
	5063	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5064	 1	 77.07	 21.84	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5065	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5066	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5067	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5068	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5069	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5070	 1	 74.65	 21.15	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5071	 1	 74.11	 21.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5072	 1	 72.34	 20.5	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5073	 1	 8.83	 2.5	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5074	 1	 31.78	 9.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5075	 1	 3.96	 1.12	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5076	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5077	 1	 18.49	 5.24	 0.0	 75.91	 5	    1.00000	    0.00000	 115.0	 16	    1.10000	    0.90000;
	5078	 1	 66.42	 18.82	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5079	 1	 38.19	 10.82	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5080	 1	 37.61	 10.66	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5081	 1	 89.83	 25.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5082	 1	 102.22	 28.96	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5083	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5084	 1	 224.2	 63.52	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5085	 1	 51.3	 14.54	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5086	 1	 92.04	 26.08	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5087	 1	 4.13	 1.17	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5088	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5089	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 18	    1.10000	    0.90000;
	5090	 1	 108.74	 30.81	 0.0	 175.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5091	 1	 5.33	 1.51	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5092	 1	 17.62	 4.99	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5093	 1	 47.98	 13.6	 0.0	 215.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5094	 1	 2.66	 0.75	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5095	 1	 32.24	 9.14	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5096	 1	 61.74	 17.49	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5097	 1	 82.57	 23.4	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5098	 1	 156.22	 44.26	 0.0	 250.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5099	 1	 67.63	 19.16	 0.0	 162.79	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5100	 1	 22.45	 6.36	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5101	 1	 22.63	 6.41	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5102	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5103	 1	 234.49	 66.44	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5104	 1	 79.02	 22.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5105	 1	 105.27	 29.83	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5106	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5107	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5108	 1	 40.12	 11.37	 0.0	 437.23	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5109	 1	 53.98	 15.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5110	 1	 3.44	 0.97	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5111	 1	 37.24	 10.55	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5112	 1	 14.25	 4.04	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5113	 1	 21.58	 6.11	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5114	 1	 56.95	 16.13	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5115	 1	 17.73	 5.02	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5116	 1	 141.56	 40.11	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5117	 1	 128.28	 36.35	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5118	 1	 8.65	 2.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5119	 1	 4.4	 1.25	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5120	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 15	    1.10000	    0.90000;
	5121	 1	 76.66	 21.72	 0.0	 30.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5122	 1	 65.0	 18.42	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5123	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5124	 1	 26.69	 7.56	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 13	    1.10000	    0.90000;
	5125	 1	 67.92	 19.24	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5126	 1	 173.21	 49.08	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5127	 1	 3.89	 1.1	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5128	 1	 90.51	 25.65	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5129	 1	 14.89	 4.22	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5130	 1	 99.79	 28.27	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5131	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5132	 1	 102.52	 29.05	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5133	 1	 12.16	 3.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5134	 1	 26.98	 7.64	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5135	 1	 27.59	 7.82	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5136	 1	 11.94	 3.38	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5137	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5138	 1	 105.04	 29.76	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5139	 1	 86.38	 24.47	 0.0	 270.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5140	 1	 8.65	 2.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5141	 1	 45.38	 12.86	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5142	 1	 15.53	 4.4	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5143	 1	 87.45	 24.78	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5144	 1	 73.43	 20.8	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5145	 1	 117.86	 33.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5146	 1	 90.75	 25.71	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5147	 1	 108.12	 30.63	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5148	 1	 83.41	 23.63	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5149	 1	 91.45	 25.91	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5150	 1	 4.11	 1.17	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5151	 1	 5.33	 1.51	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5152	 1	 60.98	 17.28	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5153	 1	 15.98	 4.53	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5154	 1	 15.58	 4.41	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5155	 1	 3.71	 1.05	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5156	 1	 6.22	 1.76	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5157	 1	 146.63	 41.55	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5158	 1	 168.19	 47.66	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5159	 1	 14.54	 4.12	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5160	 1	 59.35	 16.81	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5161	 1	 199.65	 56.57	 0.0	 210.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5162	 1	 6.69	 1.9	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5163	 1	 15.15	 4.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5164	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5165	 1	 55.53	 15.73	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5166	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5167	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5168	 1	 125.67	 35.61	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5169	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5170	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 15	    1.10000	    0.90000;
	5171	 1	 1.06	 0.3	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5172	 1	 74.24	 21.03	 0.0	 200.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5173	 1	 136.36	 38.63	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5174	 1	 4.32	 1.22	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5175	 1	 118.67	 33.62	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5176	 1	 7.3	 2.07	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5177	 1	 91.38	 25.89	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5178	 1	 83.96	 23.79	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5179	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 14	    1.10000	    0.90000;
	5180	 1	 88.36	 25.04	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5181	 1	 178.22	 50.5	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5182	 1	 3.82	 1.08	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5183	 1	 139.09	 39.41	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5184	 1	 80.23	 22.73	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5185	 1	 25.72	 7.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5186	 1	 24.98	 7.08	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5187	 1	 15.41	 4.37	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5188	 1	 64.82	 18.37	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5189	 1	 78.84	 22.34	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5190	 1	 3.38	 0.96	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5191	 1	 7.58	 2.15	 0.0	 60.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5192	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5193	 1	 134.77	 38.19	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5194	 1	 59.01	 16.72	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5195	 1	 55.26	 15.66	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5196	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5197	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5198	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 12	    1.10000	    0.90000;
	5199	 1	 24.33	 6.89	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5200	 1	 66.35	 18.8	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5201	 1	 4.81	 1.36	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5202	 1	 8.64	 2.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5203	 1	 147.01	 41.65	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5204	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5205	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5206	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5207	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5208	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5209	 1	 3.59	 1.02	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5210	 1	 39.64	 11.23	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5211	 1	 6.91	 1.96	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5212	 1	 33.89	 9.6	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5213	 1	 92.1	 26.09	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5214	 1	 102.1	 28.93	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5215	 1	 19.98	 5.66	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5216	 1	 66.58	 18.86	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5217	 1	 100.33	 28.43	 0.0	 438.77	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5218	 1	 39.29	 11.13	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5219	 1	 13.35	 3.78	 0.0	 30.53	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5220	 1	 40.49	 11.47	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5221	 1	 91.29	 25.87	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5222	 1	 33.14	 9.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5223	 1	 34.79	 9.86	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5224	 1	 154.87	 43.88	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5225	 1	 13.06	 3.7	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5226	 1	 5.49	 1.56	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5227	 1	 70.88	 20.08	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5228	 1	 81.2	 23.01	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5229	 1	 43.94	 12.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5230	 1	 66.37	 18.81	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5231	 1	 14.93	 4.23	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5232	 1	 49.97	 14.16	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5233	 1	 98.77	 27.99	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5234	 1	 142.66	 40.42	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5235	 1	 20.37	 5.77	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5236	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5237	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5238	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 12	    1.10000	    0.90000;
	5239	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 18	    1.10000	    0.90000;
	5240	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5241	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 18	    1.10000	    0.90000;
	5242	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 18	    1.10000	    0.90000;
	5243	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 18	    1.10000	    0.90000;
	5244	 1	 65.13	 18.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5245	 1	 138.96	 39.37	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5246	 1	 21.21	 6.01	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5247	 1	 3.26	 0.92	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5248	 1	 101.02	 28.62	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5249	 1	 114.68	 32.49	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5250	 1	 165.09	 46.77	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5251	 1	 123.12	 34.88	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5252	 1	 80.8	 22.89	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5253	 1	 126.68	 35.89	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5254	 1	 82.94	 23.5	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5255	 1	 9.43	 2.67	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5256	 1	 1.3	 0.37	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5257	 1	 9.9	 2.8	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5258	 1	 100.19	 28.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5259	 1	 9.21	 2.61	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5260	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 18	    1.10000	    0.90000;
	5261	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5262	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 18	    1.10000	    0.90000;
	5263	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 18	    1.10000	    0.90000;
	5264	 1	 12.13	 3.44	 0.0	 67.86	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5265	 1	 103.94	 29.45	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5266	 1	 136.12	 38.57	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5267	 1	 39.32	 11.14	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5268	 1	 32.23	 9.13	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5269	 1	 86.96	 24.64	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5270	 1	 22.41	 6.35	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5271	 1	 10.01	 2.83	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5272	 1	 18.83	 5.33	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5273	 1	 116.0	 32.87	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5274	 1	 11.87	 3.36	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5275	 1	 4.75	 1.35	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5276	 1	 10.54	 2.99	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5277	 1	 104.8	 29.69	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5278	 1	 50.69	 14.36	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5279	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5280	 1	 94.63	 26.81	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5281	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 13	    1.10000	    0.90000;
	5282	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 13	    1.10000	    0.90000;
	5283	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 13	    1.10000	    0.90000;
	5284	 1	 44.65	 12.65	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5285	 1	 10.15	 2.88	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5286	 1	 30.18	 8.55	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5287	 1	 186.78	 52.92	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5288	 1	 13.61	 3.86	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5289	 1	 69.76	 19.77	 0.0	 250.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5290	 1	 30.34	 8.6	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5291	 1	 144.17	 40.85	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5292	 1	 62.05	 17.58	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5293	 1	 62.97	 17.84	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5294	 1	 111.16	 31.49	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5295	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5296	 1	 102.32	 28.99	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5297	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5298	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5299	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5300	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5301	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5302	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5303	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 16	    1.10000	    0.90000;
	5304	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5305	 1	 189.42	 53.67	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5306	 1	 40.81	 11.56	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5307	 1	 143.56	 40.67	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5308	 1	 15.35	 4.35	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5309	 1	 98.85	 28.01	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5310	 1	 69.99	 19.83	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5311	 1	 40.96	 11.61	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5312	 1	 81.81	 23.18	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5313	 1	 16.12	 4.57	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5314	 1	 11.99	 3.4	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5315	 1	 31.74	 8.99	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5316	 1	 176.19	 49.92	 0.0	 433.99	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5317	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 18	    1.10000	    0.90000;
	5318	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5319	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 18	    1.10000	    0.90000;
	5320	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 18	    1.10000	    0.90000;
	5321	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.2	 18	    1.10000	    0.90000;
	5322	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5323	 1	 219.44	 62.17	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5324	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5325	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5326	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5327	 1	 4.01	 1.14	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5328	 1	 13.64	 3.86	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5329	 1	 148.25	 42.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5330	 1	 64.78	 18.35	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5331	 1	 26.36	 7.47	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5332	 1	 85.12	 24.12	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5333	 1	 108.12	 30.63	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5334	 1	 23.95	 6.78	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5335	 1	 166.71	 47.23	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5336	 1	 74.14	 21.01	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5337	 1	 18.78	 5.32	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5338	 1	 80.26	 22.74	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5339	 1	 80.01	 22.67	 0.0	 200.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5340	 1	 33.94	 9.62	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5341	 1	 38.7	 10.97	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5342	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5343	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5344	 1	 94.71	 26.84	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5345	 1	 33.12	 9.38	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5346	 1	 91.3	 25.87	 0.0	 260.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5347	 1	 18.68	 5.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5348	 1	 9.25	 2.62	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5349	 1	 60.83	 17.23	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5350	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5351	 1	 174.28	 49.38	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5352	 1	 41.84	 11.85	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5353	 1	 56.58	 16.03	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5354	 1	 77.72	 22.02	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5355	 1	 5.65	 1.6	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5356	 1	 122.43	 34.69	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5357	 1	 91.04	 25.79	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5358	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5359	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5360	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 13	    1.10000	    0.90000;
	5361	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5362	 1	 33.91	 9.61	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5363	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5364	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5365	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5366	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5367	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5368	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5369	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5370	 1	 105.99	 30.03	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5371	 1	 69.0	 19.55	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5372	 1	 39.8	 11.28	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5373	 1	 156.99	 44.48	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5374	 1	 69.09	 19.58	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5375	 1	 62.09	 17.59	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5376	 1	 47.85	 13.56	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5377	 1	 57.62	 16.33	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5378	 1	 68.06	 19.28	 0.0	 113.05	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5379	 1	 164.73	 46.67	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5380	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 14	    1.10000	    0.90000;
	5381	 1	 79.8	 22.61	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5382	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 14	    1.10000	    0.90000;
	5383	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 14	    1.10000	    0.90000;
	5384	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5385	 1	 240.97	 68.28	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5386	 1	 63.55	 18.0	 0.0	 160.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5387	 1	 77.75	 22.03	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5388	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5389	 1	 87.47	 24.78	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5390	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5391	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 13	    1.10000	    0.90000;
	5392	 1	 7.49	 2.12	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 13	    1.10000	    0.90000;
	5393	 1	 14.92	 4.23	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5394	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 15	    1.10000	    0.90000;
	5395	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 230.0	 15	    1.10000	    0.90000;
	5396	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5397	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 15	    1.10000	    0.90000;
	5398	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 15	    1.10000	    0.90000;
	5399	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 15	    1.10000	    0.90000;
	5400	 1	 108.27	 30.68	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5401	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 18	    1.10000	    0.90000;
	5402	 1	 65.97	 18.69	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5403	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 18	    1.10000	    0.90000;
	5404	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 18	    1.10000	    0.90000;
	5405	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 18	    1.10000	    0.90000;
	5406	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 18.0	 18	    1.10000	    0.90000;
	5407	 1	 21.28	 6.03	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5408	 1	 26.57	 7.53	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5409	 1	 92.56	 26.22	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5410	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5411	 1	 120.07	 34.02	 0.0	 157.39	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5412	 1	 144.59	 40.97	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5413	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 12	    1.10000	    0.90000;
	5414	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5415	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5416	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5417	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5418	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5419	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 12	    1.10000	    0.90000;
	5420	 1	 14.67	 4.16	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5421	 1	 2.01	 0.57	 0.0	 167.52	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5422	 1	 182.95	 51.83	 0.0	 442.39	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5423	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5424	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 13.8	 17	    1.10000	    0.90000;
	5425	 1	 52.93	 15.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5426	 1	 43.86	 12.43	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5427	 1	 25.31	 7.17	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5428	 1	 85.26	 24.16	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5429	 1	 106.17	 30.08	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5430	 1	 60.59	 17.17	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5431	 1	 84.43	 23.92	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5432	 1	 42.02	 11.91	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5433	 1	 116.98	 33.14	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5434	 1	 9.96	 2.82	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5435	 1	 4.5	 1.27	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5436	 1	 72.89	 20.65	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5437	 1	 9.01	 2.55	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5438	 1	 50.24	 14.24	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5439	 1	 113.9	 32.27	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5440	 1	 167.12	 47.35	 0.0	 200.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5441	 1	 145.18	 41.13	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5442	 1	 43.72	 12.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5443	 1	 52.34	 14.83	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5444	 2	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5445	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5446	 1	 40.66	 11.52	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5447	 1	 154.46	 43.76	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5448	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5449	 1	 266.99	 75.65	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5450	 1	 17.1	 4.84	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5451	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 13	    1.10000	    0.90000;
	5452	 1	 106.6	 30.2	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5453	 1	 67.92	 19.24	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5454	 1	 47.76	 13.53	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5455	 1	 9.47	 2.68	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5456	 1	 12.62	 3.58	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5457	 1	 103.54	 29.34	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5458	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5459	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 13	    1.10000	    0.90000;
	5460	 1	 14.16	 4.01	 0.0	 0.0	 5	    1.00000	    0.00000	 115.0	 13	    1.10000	    0.90000;
	5461	 1	 72.8	 20.63	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5462	 1	 86.05	 24.38	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5463	 1	 160.33	 45.43	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5464	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 16	    1.10000	    0.90000;
	5465	 1	 218.17	 61.81	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5466	 1	 7.44	 2.11	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5467	 1	 28.23	 8.0	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5468	 1	 42.13	 11.94	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5469	 1	 8.5	 2.41	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5470	 1	 70.52	 19.98	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5471	 1	 1.44	 0.41	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 12	    1.10000	    0.90000;
	5472	 1	 4.57	 1.29	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5473	 1	 4.03	 1.14	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 18	    1.10000	    0.90000;
	5474	 1	 3.11	 0.88	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5475	 1	 59.28	 16.8	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5476	 1	 10.97	 3.11	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	5477	 1	 79.03	 22.39	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 13	    1.10000	    0.90000;
	5478	 1	 137.94	 39.08	 0.0	 120.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5479	 1	 0.0	 0.0	 0.0	 0.0	 5	    1.00000	    0.00000	 500.0	 17	    1.10000	    0.90000;
	5480	 1	 179.23	 50.78	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5481	 1	 58.18	 16.49	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5482	 1	 69.18	 19.6	 0.0	 260.0	 5	    1.00000	    0.00000	 161.0	 16	    1.10000	    0.90000;
	5483	 1	 84.63	 23.98	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 17	    1.10000	    0.90000;
	5484	 1	 6.29	 1.78	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 15	    1.10000	    0.90000;
	5485	 1	 4.69	 1.33	 0.0	 0.0	 5	    1.00000	    0.00000	 161.0	 14	    1.10000	    0.90000;
	6001	 1	 103.81	 29.41	 0.0	 217.79	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6002	 1	 32.48	 9.2	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6003	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 25	    1.10000	    0.90000;
	6004	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6005	 1	 75.48	 21.39	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6006	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6007	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6008	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6009	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6010	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6011	 1	 24.02	 6.81	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6012	 1	 13.51	 3.83	 0.0	 83.98	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6013	 1	 94.89	 26.89	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6014	 1	 5.51	 1.56	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6015	 1	 24.76	 7.02	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6016	 1	 176.43	 49.99	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6017	 1	 83.31	 23.6	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6018	 1	 2.46	 0.7	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6019	 1	 59.07	 16.74	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6020	 1	 16.53	 4.68	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6021	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6022	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6023	 1	 132.89	 37.65	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6024	 1	 84.99	 24.08	 0.0	 250.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6025	 1	 64.63	 18.31	 0.0	 343.05	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6026	 1	 22.12	 6.27	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6027	 1	 64.98	 18.41	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6028	 1	 103.35	 29.28	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6029	 1	 6.98	 1.98	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6030	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 24	    1.10000	    0.90000;
	6031	 1	 29.18	 8.27	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6032	 1	 36.4	 10.31	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6033	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6034	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6035	 1	 206.37	 58.47	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6036	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6037	 1	 147.53	 41.8	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6038	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6039	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6040	 1	 80.78	 22.89	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6041	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6042	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6043	 1	 148.3	 42.02	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6044	 1	 18.3	 5.18	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6045	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 26	    1.10000	    0.90000;
	6046	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6047	 1	 149.85	 42.46	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6048	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6049	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6050	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6051	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6052	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6053	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6054	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 26	    1.10000	    0.90000;
	6055	 1	 4.93	 1.4	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6056	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6057	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6058	 1	 178.64	 50.61	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6059	 1	 3.44	 0.97	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6060	 1	 74.53	 21.12	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6061	 1	 147.9	 41.91	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6062	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 25	    1.10000	    0.90000;
	6063	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6064	 1	 82.48	 23.37	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6065	 1	 14.86	 4.21	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6066	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6067	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6068	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6069	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 22	    1.10000	    0.90000;
	6070	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 22	    1.10000	    0.90000;
	6071	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 22	    1.10000	    0.90000;
	6072	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 22	    1.10000	    0.90000;
	6073	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 22	    1.10000	    0.90000;
	6074	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 18.0	 22	    1.10000	    0.90000;
	6075	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 25	    1.10000	    0.90000;
	6076	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6077	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6078	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 25	    1.10000	    0.90000;
	6079	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 25	    1.10000	    0.90000;
	6080	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 25	    1.10000	    0.90000;
	6081	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6082	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6083	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6084	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6085	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6086	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6087	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6088	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6089	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6090	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6091	 1	 37.81	 10.71	 0.0	 80.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6092	 1	 35.66	 10.1	 0.0	 41.97	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6093	 1	 40.54	 11.49	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6094	 1	 67.98	 19.26	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6095	 1	 68.37	 19.37	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6096	 1	 25.78	 7.3	 0.0	 72.78	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6097	 1	 105.36	 29.85	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6098	 1	 132.22	 37.46	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6099	 1	 21.38	 6.06	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6100	 1	 37.71	 10.69	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6101	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 25	    1.10000	    0.90000;
	6102	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6103	 1	 34.21	 9.69	 0.0	 43.95	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6104	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6105	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6106	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6107	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 25	    1.10000	    0.90000;
	6108	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6109	 1	 14.44	 4.09	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6110	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6111	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 25	    1.10000	    0.90000;
	6112	 1	 16.16	 4.58	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6113	 1	 20.52	 5.81	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6114	 1	 70.54	 19.99	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6115	 1	 131.13	 37.15	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6116	 1	 56.85	 16.11	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6117	 1	 27.2	 7.71	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6118	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6119	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6120	 1	 195.3	 55.33	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6121	 1	 120.8	 34.23	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6122	 1	 22.71	 6.43	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6123	 1	 45.11	 12.78	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6124	 1	 57.42	 16.27	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6125	 1	 2.59	 0.73	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6126	 1	 50.38	 14.27	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6127	 1	 25.24	 7.15	 0.0	 9.38	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6128	 1	 52.8	 14.96	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6129	 1	 9.86	 2.79	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6130	 1	 13.4	 3.8	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6131	 1	 43.85	 12.43	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6132	 1	 64.74	 18.34	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6133	 1	 10.44	 2.96	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6134	 1	 7.62	 2.16	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6135	 1	 21.71	 6.15	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6136	 1	 71.18	 20.17	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6137	 1	 42.18	 11.95	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6138	 1	 27.68	 7.84	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6139	 1	 9.61	 2.72	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6140	 1	 11.69	 3.31	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6141	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6142	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6143	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6144	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6145	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6146	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6147	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6148	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6149	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6150	 1	 117.27	 33.23	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6151	 1	 16.14	 4.57	 0.0	 50.15	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6152	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6153	 1	 107.97	 30.59	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6154	 1	 43.1	 12.21	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6155	 1	 37.02	 10.49	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6156	 1	 52.66	 14.92	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6157	 1	 28.81	 8.16	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6158	 1	 5.64	 1.6	 0.0	 63.25	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6159	 1	 91.04	 25.79	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6160	 1	 98.28	 27.85	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6161	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6162	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6163	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6164	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6165	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6166	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6167	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6168	 1	 138.23	 39.17	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6169	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 26	    1.10000	    0.90000;
	6170	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6171	 1	 113.76	 32.23	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6172	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 24	    1.10000	    0.90000;
	6173	 1	 35.48	 10.05	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6174	 1	 95.75	 27.13	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6175	 1	 96.6	 27.37	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6176	 1	 45.32	 12.84	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6177	 1	 0.0	 0.0	 0.0	 307.93	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6178	 1	 134.45	 38.09	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6179	 1	 11.85	 3.36	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6180	 1	 34.14	 9.67	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6181	 1	 49.13	 13.92	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6182	 1	 95.83	 27.15	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6183	 1	 26.97	 7.64	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6184	 1	 48.39	 13.71	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6185	 1	 20.84	 5.9	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6186	 1	 39.37	 11.15	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6187	 1	 80.44	 22.79	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6188	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6189	 1	 27.37	 7.75	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6190	 1	 18.47	 5.23	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6191	 1	 16.77	 4.75	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6192	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 25	    1.10000	    0.90000;
	6193	 1	 35.69	 10.11	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6194	 1	 44.42	 12.59	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6195	 1	 2.66	 0.75	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6196	 1	 21.28	 6.03	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6197	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 26	    1.10000	    0.90000;
	6198	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6199	 1	 239.74	 67.93	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6200	 1	 46.28	 13.11	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6201	 1	 39.07	 11.07	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6202	 1	 16.63	 4.71	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6203	 1	 117.59	 33.32	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6204	 1	 7.81	 2.21	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6205	 1	 121.95	 34.55	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6206	 1	 18.83	 5.34	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6207	 1	 29.32	 8.31	 0.0	 141.37	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6208	 1	 140.96	 39.94	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6209	 1	 7.52	 2.13	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6210	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6211	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6212	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6213	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6214	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6215	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6216	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6217	 1	 52.96	 15.01	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6218	 1	 51.24	 14.52	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6219	 1	 63.93	 18.11	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6220	 1	 96.5	 27.34	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6221	 1	 9.16	 2.6	 0.0	 54.02	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6222	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6223	 1	 166.84	 47.27	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6224	 1	 116.67	 33.06	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6225	 1	 85.25	 24.15	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6226	 1	 18.02	 5.11	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6227	 1	 126.35	 35.8	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6228	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6229	 1	 0.0	 0.0	 0.0	 248.71	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6230	 1	 191.51	 54.26	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6231	 1	 70.51	 19.98	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6232	 1	 66.63	 18.88	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6233	 1	 65.09	 18.44	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6234	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 26	    1.10000	    0.90000;
	6235	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6236	 1	 169.53	 48.03	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6237	 1	 1.88	 0.53	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6238	 1	 134.8	 38.19	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6239	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6240	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6241	 1	 175.73	 49.79	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6242	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6243	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6244	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6245	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6246	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6247	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6248	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6249	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 22	    1.10000	    0.90000;
	6250	 1	 86.21	 24.43	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6251	 1	 51.25	 14.52	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6252	 1	 13.48	 3.82	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6253	 1	 13.2	 3.74	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6254	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6255	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6256	 1	 18.25	 5.17	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6257	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6258	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6259	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6260	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6261	 1	 31.18	 8.83	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6262	 1	 28.4	 8.05	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6263	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 24	    1.10000	    0.90000;
	6264	 1	 34.97	 9.91	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6265	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6266	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6267	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6268	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6269	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6270	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6271	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6272	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6273	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6274	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 24	    1.10000	    0.90000;
	6275	 1	 110.59	 31.34	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6276	 1	 39.92	 11.31	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6277	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6278	 1	 135.68	 38.44	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6279	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6280	 1	 136.02	 38.54	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6281	 1	 60.45	 17.13	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6282	 1	 26.19	 7.42	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6283	 1	 6.88	 1.95	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6284	 1	 71.09	 20.14	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6285	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6286	 1	 82.67	 23.42	 0.0	 84.6	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6287	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6288	 1	 166.54	 47.19	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6289	 1	 73.84	 20.92	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6290	 1	 67.61	 19.16	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6291	 1	 20.57	 5.83	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6292	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6293	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6294	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6295	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6296	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6297	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 13.8	 23	    1.10000	    0.90000;
	6298	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 22	    1.10000	    0.90000;
	6299	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6300	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6301	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 22	    1.10000	    0.90000;
	6302	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 22	    1.10000	    0.90000;
	6303	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 22	    1.10000	    0.90000;
	6304	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 22	    1.10000	    0.90000;
	6305	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 22.0	 22	    1.10000	    0.90000;
	6306	 1	 54.19	 15.35	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6307	 1	 130.73	 37.04	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6308	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6309	 1	 41.1	 11.65	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6310	 1	 92.27	 26.14	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6311	 1	 8.58	 2.43	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6312	 1	 45.68	 12.94	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6313	 1	 26.29	 7.45	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6314	 1	 29.51	 8.36	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6315	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6316	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 161.0	 23	    1.10000	    0.90000;
	6317	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 161.0	 23	    1.10000	    0.90000;
	6318	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 161.0	 23	    1.10000	    0.90000;
	6319	 1	 70.22	 19.9	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6320	 1	 47.89	 13.57	 0.0	 221.36	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6321	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 22	    1.10000	    0.90000;
	6322	 1	 66.07	 18.72	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6323	 1	 33.38	 9.46	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6324	 1	 58.22	 16.5	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 22	    1.10000	    0.90000;
	6325	 1	 4.74	 1.34	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6326	 1	 15.43	 4.37	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6327	 1	 17.61	 4.99	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6328	 1	 27.95	 7.92	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6329	 1	 1.79	 0.51	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6330	 1	 133.75	 37.9	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6331	 1	 81.32	 23.04	 0.0	 147.19	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6332	 1	 73.0	 20.68	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6333	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 26	    1.10000	    0.90000;
	6334	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 26	    1.10000	    0.90000;
	6335	 1	 164.71	 46.67	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6336	 1	 26.07	 7.39	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6337	 1	 121.19	 34.34	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6338	 1	 33.61	 9.52	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6339	 1	 34.37	 9.74	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6340	 1	 29.18	 8.27	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 24	    1.10000	    0.90000;
	6341	 1	 6.3	 1.79	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 25	    1.10000	    0.90000;
	6342	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6343	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6344	 1	 158.8	 44.99	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6345	 1	 17.7	 5.02	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6346	 1	 2.3	 0.65	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6349	 2	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 500.0	 23	    1.10000	    0.90000;
	6350	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6351	 1	 23.86	 6.76	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6352	 1	 121.76	 34.5	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6353	 1	 107.96	 30.59	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6354	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6355	 1	 151.82	 43.02	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6356	 1	 135.92	 38.51	 0.0	 344.17	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6357	 1	 30.83	 8.74	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 26	    1.10000	    0.90000;
	6358	 1	 77.99	 22.1	 0.0	 141.53	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	6359	 1	 0.0	 0.0	 0.0	 0.0	 6	    1.00000	    0.00000	 230.0	 23	    1.10000	    0.90000;
	6360	 1	 38.93	 11.03	 0.0	 0.0	 6	    1.00000	    0.00000	 115.0	 23	    1.10000	    0.90000;
	7001	 1	 9.3	 2.64	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7002	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7003	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7004	 1	 221.92	 62.88	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7005	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7006	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7007	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7008	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7009	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7010	 1	 15.65	 4.43	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7011	 1	 35.79	 10.14	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7012	 1	 0.94	 0.27	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7013	 1	 138.05	 39.11	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7014	 1	 52.81	 14.96	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7015	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7016	 1	 85.56	 24.24	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7017	 1	 135.83	 38.48	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7018	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 6	    1.10000	    0.90000;
	7019	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7020	 1	 75.38	 21.36	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7021	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 6	    1.10000	    0.90000;
	7022	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 6	    1.10000	    0.90000;
	7023	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 6	    1.10000	    0.90000;
	7024	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 6	    1.10000	    0.90000;
	7025	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 6	    1.10000	    0.90000;
	7026	 1	 43.39	 12.29	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7027	 1	 109.22	 30.95	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7028	 1	 77.01	 21.82	 0.0	 481.69	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7029	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7030	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7031	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7032	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7033	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7034	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7035	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7036	 1	 92.31	 26.15	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7037	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7038	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7039	 1	 235.5	 66.73	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7040	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7041	 1	 93.88	 26.6	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7042	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 6	    1.10000	    0.90000;
	7043	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7044	 1	 124.64	 35.32	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7045	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7046	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7047	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7048	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7049	 1	 283.15	 80.22	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7050	 1	 72.03	 20.41	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7051	 1	 140.79	 39.89	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7052	 1	 106.66	 30.22	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7053	 1	 105.96	 30.02	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7054	 1	 92.85	 26.31	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7055	 1	 98.08	 27.79	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7056	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7057	 1	 106.11	 30.06	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7058	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 6	    1.10000	    0.90000;
	7059	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7060	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7061	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7062	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7063	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7064	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7065	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7066	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 6	    1.10000	    0.90000;
	7067	 1	 82.69	 23.43	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7068	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7069	 1	 51.16	 14.5	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7070	 1	 101.03	 28.63	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7071	 1	 3.76	 1.07	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7072	 1	 116.42	 32.99	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7073	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7074	 1	 69.13	 19.59	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7075	 1	 160.86	 45.58	 0.0	 342.5	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7076	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7077	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7078	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7079	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7080	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7081	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7082	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7083	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7084	 1	 214.74	 60.84	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7085	 1	 4.1	 1.16	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7086	 1	 53.44	 15.14	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7087	 1	 74.22	 21.03	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7088	 1	 101.05	 28.63	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7089	 1	 70.07	 19.85	 0.0	 316.53	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7090	 1	 13.8	 3.91	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7091	 1	 210.68	 59.69	 0.0	 292.93	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7092	 1	 39.23	 11.11	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7093	 1	 109.15	 30.93	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7094	 1	 76.69	 21.73	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7095	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	7096	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7097	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7098	 3	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7099	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7100	 1	 62.16	 17.61	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7101	 1	 212.51	 60.21	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7102	 1	 118.05	 33.45	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7103	 1	 58.64	 16.61	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7104	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7105	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7106	 1	 92.07	 26.09	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7107	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7108	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7109	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7110	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7111	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7112	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7113	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7114	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7115	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 4	    1.10000	    0.90000;
	7116	 1	 12.16	 3.45	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7117	 1	 84.03	 23.81	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7118	 1	 121.15	 34.33	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7119	 1	 49.7	 14.08	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7120	 1	 149.7	 42.41	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7121	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7122	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7123	 1	 6.63	 1.88	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7124	 1	 164.66	 46.65	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7125	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7126	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7127	 1	 223.54	 63.34	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7128	 1	 63.94	 18.12	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7129	 1	 5.15	 1.46	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7130	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7131	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7132	 1	 72.75	 20.61	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7133	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7134	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7135	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7136	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7137	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7138	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7139	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7140	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7141	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7142	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7143	 1	 59.96	 16.99	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7144	 1	 97.68	 27.68	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7145	 1	 143.78	 40.74	 0.0	 288.02	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7146	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7147	 1	 47.29	 13.4	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7148	 1	 59.46	 16.85	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7149	 1	 12.25	 3.47	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7150	 1	 0.0	 0.0	 0.0	 125.49	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7151	 1	 44.05	 12.48	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7152	 1	 3.59	 1.02	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7153	 1	 26.21	 7.42	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7154	 1	 58.6	 16.6	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7155	 1	 78.41	 22.22	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7156	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7157	 1	 163.83	 46.42	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7158	 1	 78.37	 22.2	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7159	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7160	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7161	 1	 137.54	 38.97	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7162	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7163	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7164	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7165	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7166	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7167	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7168	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7169	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7170	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 3	    1.10000	    0.90000;
	7171	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7172	 1	 91.12	 25.82	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7173	 1	 112.54	 31.89	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7174	 1	 124.67	 35.32	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7175	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 5	    1.10000	    0.90000;
	7176	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7177	 1	 211.63	 59.96	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7178	 1	 122.49	 34.71	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7179	 1	 58.29	 16.52	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7180	 1	 91.45	 25.91	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7181	 1	 148.98	 42.21	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7182	 1	 2.07	 0.59	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7183	 1	 215.91	 61.17	 0.0	 402.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7184	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7185	 1	 168.93	 47.86	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7186	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7187	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7188	 1	 76.58	 21.7	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7189	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7190	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7191	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7192	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7193	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7194	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7195	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7196	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7197	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7198	 1	 86.12	 24.4	 0.0	 206.64	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7199	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 5	    1.10000	    0.90000;
	7200	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7201	 1	 216.79	 61.42	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7202	 1	 35.93	 10.18	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7203	 1	 20.55	 5.82	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7204	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7205	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7206	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7207	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7208	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7209	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7210	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7211	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7212	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7213	 1	 68.5	 19.41	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7214	 1	 83.89	 23.77	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7215	 1	 104.88	 29.72	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7216	 1	 92.56	 26.23	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7217	 1	 76.39	 21.64	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7218	 1	 48.11	 13.63	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7219	 1	 1.25	 0.36	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7220	 1	 141.27	 40.03	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7221	 1	 169.58	 48.05	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7222	 1	 86.99	 24.65	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7223	 1	 49.62	 14.06	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7224	 1	 30.77	 8.72	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7225	 1	 111.44	 31.57	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7226	 1	 45.25	 12.82	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7227	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7228	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7229	 1	 285.41	 80.87	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7230	 1	 7.37	 2.09	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7231	 1	 50.85	 14.41	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7232	 1	 42.92	 12.16	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7233	 1	 33.2	 9.41	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7234	 1	 77.31	 21.9	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7235	 1	 151.62	 42.96	 0.0	 203.69	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7236	 1	 38.27	 10.84	 0.0	 224.97	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7237	 1	 15.09	 4.28	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7238	 1	 47.85	 13.56	 0.0	 88.8	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7239	 1	 42.4	 12.01	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7240	 1	 107.69	 30.51	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7241	 1	 104.32	 29.56	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7242	 1	 80.14	 22.71	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7243	 1	 78.71	 22.3	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7244	 1	 38.02	 10.77	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7245	 1	 98.79	 27.99	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7246	 1	 199.51	 56.53	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7247	 1	 9.2	 2.61	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7248	 1	 220.52	 62.48	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7249	 1	 71.82	 20.35	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7250	 1	 32.62	 9.24	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7251	 1	 35.62	 10.09	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7252	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7253	 1	 90.93	 25.76	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7254	 1	 50.13	 14.2	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7255	 1	 58.99	 16.71	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7256	 1	 86.86	 24.61	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7257	 1	 127.15	 36.03	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7258	 1	 42.99	 12.18	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7259	 1	 146.05	 41.38	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7260	 1	 124.64	 35.31	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7261	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7262	 1	 72.03	 20.41	 0.0	 53.12	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7263	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7264	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7265	 1	 62.91	 17.82	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7266	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7267	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7268	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7269	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7270	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7271	 1	 28.45	 8.06	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7272	 1	 45.88	 13.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7273	 1	 39.39	 11.16	 0.0	 177.5	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7274	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7275	 1	 42.31	 11.99	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7276	 1	 88.67	 25.12	 0.0	 457.62	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7277	 1	 15.99	 4.53	 0.0	 30.34	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7278	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7279	 1	 148.52	 42.08	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7280	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7281	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 4	    1.10000	    0.90000;
	7282	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7283	 1	 109.47	 31.02	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7284	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 4	    1.10000	    0.90000;
	7285	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 4	    1.10000	    0.90000;
	7286	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 4	    1.10000	    0.90000;
	7287	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 4	    1.10000	    0.90000;
	7288	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 4	    1.10000	    0.90000;
	7289	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.2	 4	    1.10000	    0.90000;
	7290	 1	 63.77	 18.07	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7291	 1	 101.91	 28.88	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7292	 1	 94.1	 26.66	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7293	 1	 15.94	 4.52	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7294	 1	 7.25	 2.05	 0.0	 21.96	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7295	 1	 104.37	 29.57	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7296	 1	 93.84	 26.59	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7297	 1	 93.77	 26.57	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7298	 1	 101.23	 28.68	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7299	 1	 18.4	 5.21	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7300	 1	 54.35	 15.4	 0.0	 182.22	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7301	 1	 69.18	 19.6	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7302	 1	 24.43	 6.92	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7303	 1	 6.49	 1.84	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7304	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 1	    1.10000	    0.90000;
	7305	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7306	 1	 7.69	 2.18	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7307	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	7308	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	7309	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	7310	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	7311	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 24.0	 1	    1.10000	    0.90000;
	7312	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7313	 1	 86.22	 24.43	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7314	 1	 28.76	 8.15	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7315	 1	 69.31	 19.64	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7316	 1	 63.23	 17.92	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7317	 1	 142.91	 40.49	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7318	 1	 112.16	 31.78	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7319	 1	 30.19	 8.55	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7320	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 2	    1.10000	    0.90000;
	7321	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7322	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7323	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	7324	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	7325	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	7326	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	7327	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 1	    1.10000	    0.90000;
	7328	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7329	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7330	 1	 196.05	 55.55	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7331	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7332	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7333	 1	 29.21	 8.27	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7334	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7335	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7336	 1	 107.69	 30.51	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7337	 1	 24.56	 6.96	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7338	 1	 109.2	 30.94	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7339	 1	 32.04	 9.08	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7340	 1	 38.64	 10.95	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7341	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7342	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7343	 1	 184.8	 52.36	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7344	 1	 101.41	 28.73	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7345	 1	 73.37	 20.79	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7346	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 3	    1.10000	    0.90000;
	7347	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7348	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7349	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7350	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7351	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7352	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7353	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7354	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7355	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7356	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7357	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7358	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7359	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7360	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7361	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 13.8	 3	    1.10000	    0.90000;
	7362	 1	 56.02	 15.87	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7363	 1	 26.59	 7.53	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7364	 1	 14.27	 4.04	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7365	 1	 80.97	 22.94	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7366	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7367	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7368	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7369	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7370	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7371	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7372	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7373	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7374	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7375	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7376	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7377	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7378	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7379	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 18.0	 4	    1.10000	    0.90000;
	7380	 1	 52.24	 14.8	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7381	 1	 94.75	 26.85	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7382	 1	 78.13	 22.14	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7383	 1	 85.59	 24.25	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7384	 1	 66.87	 18.95	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7385	 1	 135.24	 38.32	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7386	 1	 111.8	 31.68	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7387	 1	 160.73	 45.54	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7388	 1	 125.97	 35.69	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7389	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 5	    1.10000	    0.90000;
	7390	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7391	 1	 42.84	 12.14	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7392	 1	 52.03	 14.74	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7393	 1	 7.31	 2.07	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7394	 1	 37.41	 10.6	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7395	 1	 70.42	 19.95	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7396	 1	 25.49	 7.22	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7397	 1	 105.72	 29.95	 0.0	 100.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7398	 1	 73.59	 20.85	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7399	 1	 56.83	 16.1	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7400	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 4	    1.10000	    0.90000;
	7401	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 4	    1.10000	    0.90000;
	7402	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7403	 1	 69.67	 19.74	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7404	 1	 177.73	 50.36	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7405	 1	 53.26	 15.09	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7406	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 6	    1.10000	    0.90000;
	7407	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7408	 1	 53.66	 15.2	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7409	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 3	    1.10000	    0.90000;
	7410	 1	 215.67	 61.11	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7411	 1	 69.41	 19.67	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7412	 1	 8.59	 2.43	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7413	 1	 42.91	 12.16	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 1	    1.10000	    0.90000;
	7414	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 6	    1.10000	    0.90000;
	7415	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 6	    1.10000	    0.90000;
	7416	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 6	    1.10000	    0.90000;
	7417	 1	 97.88	 27.73	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7418	 1	 48.22	 13.66	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7419	 2	 107.0	 30.32	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 4	    1.10000	    0.90000;
	7420	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 5	    1.10000	    0.90000;
	7421	 1	 90.64	 25.68	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7422	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 2	    1.10000	    0.90000;
	7423	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7424	 1	 139.88	 39.63	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7425	 1	 105.98	 30.03	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7426	 1	 41.8	 11.84	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7427	 1	 156.45	 44.33	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 3	    1.10000	    0.90000;
	7428	 2	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 500.0	 2	    1.10000	    0.90000;
	7429	 1	 0.0	 0.0	 0.0	 0.0	 7	    1.00000	    0.00000	 230.0	 2	    1.10000	    0.90000;
	7430	 1	 46.92	 13.29	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 2	    1.10000	    0.90000;
	7431	 1	 35.57	 10.08	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	7432	 1	 22.94	 6.5	 0.0	 0.0	 7	    1.00000	    0.00000	 115.0	 5	    1.10000	    0.90000;
	8001	 1	 10.82	 3.07	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8002	 1	 11.81	 3.35	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8003	 1	 11.99	 3.4	 0.0	 34.65	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8004	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8005	 1	 102.01	 28.9	 0.0	 133.27	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8006	 1	 37.4	 10.6	 0.0	 70.66	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8007	 1	 30.07	 8.52	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8008	 1	 39.22	 11.11	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8009	 1	 9.81	 2.78	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8010	 1	 5.39	 1.53	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8011	 1	 27.25	 7.72	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8012	 1	 7.6	 2.15	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8013	 1	 60.03	 17.01	 0.0	 50.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8014	 1	 15.15	 4.29	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8015	 1	 23.93	 6.78	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8016	 1	 69.86	 19.79	 0.0	 56.28	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8017	 1	 18.44	 5.22	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8018	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8019	 1	 103.12	 29.22	 0.0	 159.99	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8020	 1	 17.35	 4.92	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8021	 1	 10.73	 3.04	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8022	 1	 6.89	 1.95	 0.0	 16.68	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8023	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8024	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8025	 1	 50.76	 14.38	 0.0	 51.21	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8026	 1	 55.08	 15.61	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8027	 1	 39.38	 11.16	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8028	 1	 24.06	 6.82	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8029	 1	 25.65	 7.27	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8030	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8031	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8032	 1	 77.96	 22.09	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8033	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8034	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8035	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8036	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8037	 1	 11.29	 3.2	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8038	 1	 73.15	 20.73	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8039	 1	 12.61	 3.57	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8040	 1	 18.09	 5.13	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8041	 1	 52.77	 14.95	 0.0	 50.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8042	 1	 27.31	 7.74	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8043	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8044	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8045	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8046	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8047	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8048	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8049	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8050	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8051	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8052	 1	 15.19	 4.3	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8053	 1	 20.96	 5.94	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8054	 1	 16.16	 4.58	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8055	 1	 33.79	 9.57	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8056	 1	 10.55	 2.99	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8057	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8058	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8059	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8060	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8061	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8062	 1	 10.19	 2.89	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8063	 1	 69.38	 19.66	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8064	 1	 21.23	 6.01	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8065	 1	 6.85	 1.94	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8066	 1	 3.23	 0.92	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8067	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8068	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8069	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8070	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8071	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 7	    1.10000	    0.90000;
	8072	 1	 70.08	 19.86	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8073	 1	 19.05	 5.4	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8074	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 8	    1.10000	    0.90000;
	8075	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8076	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8077	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8078	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8079	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8080	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8081	 1	 26.05	 7.38	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8082	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8083	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8084	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 7	    1.10000	    0.90000;
	8085	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 7	    1.10000	    0.90000;
	8086	 1	 21.25	 6.02	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8087	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8088	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 7	    1.10000	    0.90000;
	8089	 1	 21.47	 6.08	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8090	 1	 15.21	 4.31	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8091	 1	 11.87	 3.36	 0.0	 29.13	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8092	 1	 7.11	 2.01	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8093	 1	 4.91	 1.39	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8094	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8095	 1	 146.81	 41.6	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8096	 1	 11.17	 3.16	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8097	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8098	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8099	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8100	 1	 41.13	 11.65	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8101	 1	 12.54	 3.55	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8102	 1	 4.76	 1.35	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8103	 1	 8.15	 2.31	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8104	 1	 46.53	 13.18	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8105	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8106	 1	 99.89	 28.3	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8107	 1	 9.21	 2.61	 0.0	 23.67	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8108	 1	 43.93	 12.45	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8109	 1	 51.76	 14.67	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8110	 1	 20.41	 5.78	 0.0	 40.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8111	 1	 87.11	 24.68	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8112	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 8	    1.10000	    0.90000;
	8113	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8114	 1	 24.41	 6.92	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8115	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8116	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8117	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 13.8	 8	    1.10000	    0.90000;
	8118	 1	 36.62	 10.38	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8119	 1	 48.0	 13.6	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8120	 1	 31.9	 9.04	 0.0	 97.08	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8121	 1	 79.16	 22.43	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8122	 1	 29.41	 8.33	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8123	 1	 17.53	 4.97	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8124	 1	 20.2	 5.72	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8125	 1	 45.16	 12.8	 0.0	 30.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8126	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 8	    1.10000	    0.90000;
	8127	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8128	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8129	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 8	    1.10000	    0.90000;
	8130	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 8	    1.10000	    0.90000;
	8131	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 18.0	 8	    1.10000	    0.90000;
	8132	 1	 21.93	 6.21	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8133	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 8	    1.10000	    0.90000;
	8134	 1	 111.5	 31.59	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8135	 1	 81.21	 23.01	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8136	 1	 10.05	 2.85	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8137	 1	 24.32	 6.89	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8138	 1	 6.5	 1.84	 0.0	 57.65	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8139	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8140	 1	 168.51	 47.75	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8141	 1	 20.94	 5.93	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8142	 1	 22.36	 6.34	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8143	 1	 22.94	 6.5	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8144	 1	 6.04	 1.71	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8145	 1	 6.16	 1.74	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8146	 1	 49.91	 14.14	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8147	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8148	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 161.0	 7	    1.10000	    0.90000;
	8149	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8150	 1	 8.51	 2.41	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8151	 1	 17.38	 4.92	 0.0	 44.1	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8152	 2	 46.35	 13.13	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8153	 1	 38.55	 10.92	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8154	 1	 26.31	 7.46	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 8	    1.10000	    0.90000;
	8155	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8156	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8157	 1	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
	8158	 2	 0.0	 0.0	 0.0	 0.0	 8	    1.00000	    0.00000	 500.0	 7	    1.10000	    0.90000;
	8159	 1	 0.0	 0.0	 0.0	 81.61	 8	    1.00000	    0.00000	 230.0	 7	    1.10000	    0.90000;
	8160	 1	 90.76	 25.71	 0.0	 0.0	 8	    1.00000	    0.00000	 115.0	 7	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin	Pc1	Pc2	Qc1min	Qc1max	Qc2min	Qc2max	ramp_agc	ramp_10	ramp_30	ramp_q	apf
mpc.gen = [
	1004	 158.25	 7.28	 44.94	 -30.38	 1.0	 253.2	 1	 158.25	 158.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 211.0;
	1006	 25.73	 1.185	 7.31	 -4.94	 1.0	 41.16	 1	 25.73	 25.73	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 34.3;
	1009	 61.87	 2.845	 17.57	 -11.88	 1.0	 99.0	 1	 61.87	 61.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.5;
	1011	 6.5	 0.0	 0.0	 0.0	 1.0	 12.0	 1	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	1021	 149.63	 6.88	 42.49	 -28.73	 1.0	 239.4	 1	 149.63	 149.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 199.5;
	1023	 135.0	 6.21	 38.34	 -25.92	 1.0	 216.0	 1	 135.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0;
	1026	 93.15	 4.285	 26.45	 -17.88	 1.0	 149.04	 1	 93.15	 93.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.2;
	1033	 208.5	 9.59	 59.21	 -40.03	 1.0	 333.6	 1	 208.5	 208.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 278.0;
	1035	 67.5	 3.105	 19.17	 -12.96	 1.0	 108.0	 1	 67.5	 67.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.0;
	1039	 110.63	 5.09	 31.42	 -21.24	 1.0	 177.0	 1	 110.63	 110.63	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 147.5;
	1042	 79.235	 4.205	 25.96	 -17.55	 1.0	 146.28	 0	 121.9	 36.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.9;
	1043	 44.1	 2.025	 12.52	 -8.47	 1.0	 70.56	 1	 44.1	 44.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 58.8;
	1048	 211.38	 64.715	 165.53	 -36.1	 1.0	 390.24	 0	 325.2	 97.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 325.2;
	1049	 211.38	 64.715	 165.53	 -36.1	 1.0	 390.24	 0	 325.2	 97.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 325.2;
	1050	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	1051	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	1052	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	1053	 116.22	 35.58	 91.01	 -19.85	 1.0	 214.56	 0	 178.8	 53.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.8;
	1057	 78.0	 4.14	 25.56	 -17.28	 1.0	 144.0	 0	 120.0	 36.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	1059	 3.64	 1.115	 2.85	 -0.62	 1.0	 6.72	 0	 5.6	 1.68	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.6;
	1060	 1.3	 0.4	 1.02	 -0.22	 1.0	 2.4	 0	 2.0	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.0;
	1062	 0.975	 0.0	 0.0	 0.0	 1.0	 1.8	 0	 1.5	 0.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5;
	1063	 149.5	 0.0	 0.0	 0.0	 1.0	 276.0	 0	 230.0	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.0;
	1066	 106.88	 4.915	 30.35	 -20.52	 1.0	 171.0	 1	 106.88	 106.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 142.5;
	1070	 120.38	 5.54	 34.19	 -23.11	 1.0	 192.6	 1	 120.38	 120.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 160.5;
	1072	 124.885	 38.235	 97.8	 -21.33	 1.0	 230.56	 1	 192.13	 57.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.13;
	1073	 124.885	 38.235	 97.8	 -21.33	 1.0	 230.56	 1	 192.13	 57.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.13;
	1074	 124.885	 38.235	 97.8	 -21.33	 1.0	 230.56	 1	 192.13	 57.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.13;
	1075	 124.885	 38.235	 97.8	 -21.33	 1.0	 230.56	 1	 192.13	 57.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.13;
	1076	 124.885	 38.235	 97.8	 -21.33	 1.0	 230.56	 0	 192.13	 57.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.13;
	1077	 124.885	 38.235	 97.8	 -21.33	 1.0	 230.56	 0	 192.13	 57.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 192.13;
	1078	 62.075	 19.005	 48.61	 -10.6	 1.0	 114.6	 1	 95.5	 28.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.5;
	1079	 62.075	 19.005	 48.61	 -10.6	 1.0	 114.6	 1	 95.5	 28.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.5;
	1080	 62.075	 19.005	 48.61	 -10.6	 1.0	 114.6	 1	 95.5	 28.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 95.5;
	1081	 186.225	 57.015	 145.83	 -31.8	 1.0	 343.8	 0	 286.5	 85.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 286.5;
	1082	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	1084	 86.62	 3.985	 24.6	 -16.63	 1.0	 138.6	 1	 86.62	 86.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.5;
	1088	 56.25	 2.585	 15.97	 -10.8	 1.0	 90.0	 1	 56.25	 56.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	1090	 114.37	 5.26	 32.48	 -21.96	 1.0	 183.0	 1	 114.37	 114.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 152.5;
	1090	 27.0	 1.245	 7.67	 -5.18	 1.0	 43.2	 1	 27.0	 27.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 36.0;
	2004	 254.67	 77.97	 199.43	 -43.49	 1.0	 470.16	 0	 391.8	 117.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 391.8;
	2005	 254.67	 77.97	 199.43	 -43.49	 1.0	 470.16	 0	 391.8	 117.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 391.8;
	2006	 254.67	 77.97	 199.43	 -43.49	 1.0	 470.16	 0	 391.8	 117.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 391.8;
	2013	 150.45	 6.92	 42.73	 -28.89	 1.0	 240.72	 1	 150.45	 150.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.6;
	2019	 141.7	 7.52	 46.43	 -31.39	 1.0	 261.6	 0	 218.0	 65.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 218.0;
	2023	 54.165	 16.585	 42.42	 -9.25	 1.0	 100.0	 1	 83.33	 25.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 83.33;
	2024	 108.335	 33.165	 84.83	 -18.5	 1.0	 200.0	 1	 166.67	 50.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 166.67;
	2042	 59.7	 2.745	 16.95	 -11.46	 1.0	 95.52	 1	 59.7	 59.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.6;
	2056	 3.9	 1.035	 2.8	 -0.73	 1.0	 7.2	 0	 6.0	 1.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	2057	 468.0	 123.84	 335.52	 -87.84	 1.0	 864.0	 1	 720.0	 216.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 720.0;
	2059	 60.0	 2.76	 17.04	 -11.52	 1.0	 96.0	 1	 60.0	 60.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.0;
	2062	 101.55	 4.67	 28.84	 -19.5	 1.0	 162.48	 1	 101.55	 101.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.4;
	2071	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	2076	 22.5	 1.035	 6.39	 -4.32	 1.0	 36.0	 1	 22.5	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	2078	 84.38	 3.88	 23.96	 -16.2	 1.0	 135.0	 1	 84.38	 84.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	2083	 13.0	 3.98	 10.18	 -2.22	 1.0	 24.0	 1	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	2084	 13.0	 3.98	 10.18	 -2.22	 1.0	 24.0	 0	 20.0	 6.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 20.0;
	2085	 26.0	 7.96	 20.36	 -4.44	 1.0	 48.0	 0	 40.0	 12.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.0;
	2089	 50.7	 2.335	 14.4	 -9.73	 1.0	 81.12	 1	 50.7	 50.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.6;
	2094	 6.5	 0.345	 2.13	 -1.44	 1.0	 12.0	 0	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	2095	 51.675	 2.74	 16.93	 -11.45	 1.0	 95.4	 0	 79.5	 23.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 79.5;
	2099	 7.5	 0.345	 2.13	 -1.44	 1.0	 12.0	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	2100	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	2103	 174.025	 53.28	 136.28	 -29.72	 1.0	 321.28	 0	 267.73	 80.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.73;
	2104	 174.025	 53.28	 136.28	 -29.72	 1.0	 321.28	 0	 267.73	 80.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.73;
	2105	 174.025	 53.28	 136.28	 -29.72	 1.0	 321.28	 0	 267.73	 80.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.73;
	2115	 120.065	 36.76	 94.02	 -20.5	 1.0	 221.66	 1	 184.72	 55.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.72;
	2116	 120.065	 36.76	 94.02	 -20.5	 1.0	 221.66	 1	 184.72	 55.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.72;
	2117	 120.065	 36.76	 94.02	 -20.5	 1.0	 221.66	 1	 184.72	 55.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.72;
	2118	 120.065	 36.76	 94.02	 -20.5	 1.0	 221.66	 1	 184.72	 55.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.72;
	2119	 120.065	 36.76	 94.02	 -20.5	 1.0	 221.66	 1	 184.72	 55.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.72;
	2120	 120.065	 36.76	 94.02	 -20.5	 1.0	 221.66	 1	 184.72	 55.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 184.72;
	2123	 136.28	 6.27	 38.7	 -26.16	 1.0	 218.04	 1	 136.28	 136.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.7;
	2127	 216.45	 9.955	 61.47	 -41.56	 1.0	 346.32	 1	 216.45	 216.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 288.6;
	3004	 28.13	 1.295	 7.99	 -5.4	 1.0	 45.0	 1	 28.13	 28.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 37.5;
	3017	 127.13	 5.845	 36.1	 -24.41	 1.0	 203.4	 1	 127.13	 127.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 169.5;
	3020	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	3028	 150.0	 6.9	 42.6	 -28.8	 1.0	 240.0	 1	 150.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	3034	 97.87	 4.505	 27.8	 -18.79	 1.0	 156.6	 1	 97.87	 97.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.5;
	3039	 156.75	 7.21	 44.52	 -30.1	 1.0	 250.8	 1	 156.75	 156.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.0;
	3043	 0.845	 0.26	 0.66	 -0.14	 1.0	 1.56	 0	 1.3	 0.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.3;
	3044	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 0	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	3045	 290.55	 88.95	 227.52	 -49.62	 1.0	 536.4	 0	 447.0	 134.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 447.0;
	3048	 180.75	 8.315	 51.33	 -34.7	 1.0	 289.2	 1	 180.75	 180.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 241.0;
	3055	 183.88	 8.46	 52.22	 -35.3	 1.0	 294.2	 1	 183.88	 183.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.17;
	3056	 183.88	 8.46	 52.22	 -35.3	 1.0	 294.2	 1	 183.88	 183.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.17;
	3057	 183.88	 8.46	 52.22	 -35.3	 1.0	 294.2	 1	 183.88	 183.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 245.17;
	3060	 124.22	 5.715	 35.28	 -23.85	 1.0	 198.75	 1	 124.22	 124.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.63;
	3061	 124.22	 5.715	 35.28	 -23.85	 1.0	 198.75	 1	 124.22	 124.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.63;
	3062	 124.22	 5.715	 35.28	 -23.85	 1.0	 198.75	 1	 124.22	 124.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.63;
	3063	 124.22	 5.715	 35.28	 -23.85	 1.0	 198.75	 1	 124.22	 124.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.63;
	3065	 60.37	 2.78	 17.15	 -11.59	 1.0	 96.6	 1	 60.37	 60.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 80.5;
	3068	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	3071	 127.65	 5.87	 36.25	 -24.51	 1.0	 204.24	 1	 127.65	 127.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 170.2;
	3074	 74.85	 3.445	 21.26	 -14.37	 1.0	 119.76	 1	 74.85	 74.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 99.8;
	3081	 186.75	 8.59	 53.04	 -35.86	 1.0	 298.8	 1	 186.75	 186.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 249.0;
	3084	 174.37	 8.02	 49.52	 -33.48	 1.0	 279.0	 1	 174.37	 174.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 232.5;
	3086	 56.25	 2.585	 15.97	 -10.8	 1.0	 90.0	 1	 56.25	 56.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	3087	 48.75	 2.585	 15.97	 -10.8	 1.0	 90.0	 0	 75.0	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	3092	 150.0	 6.9	 42.6	 -28.8	 1.0	 240.0	 1	 150.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	3095	 90.45	 4.16	 25.69	 -17.37	 1.0	 144.72	 1	 90.45	 90.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.6;
	3098	 120.0	 5.52	 34.08	 -23.04	 1.0	 192.0	 1	 120.0	 120.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 160.0;
	3105	 44.5	 8.165	 17.07	 -0.74	 1.0	 18.0	 1	 44.5	 44.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	3106	 53.02	 29.895	 62.48	 -2.69	 1.0	 65.88	 1	 53.02	 53.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 54.9;
	3110	 63.0	 2.895	 17.89	 -12.1	 1.0	 100.8	 1	 63.0	 63.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.0;
	3112	 56.1	 2.58	 15.93	 -10.77	 1.0	 89.76	 1	 56.1	 56.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.8;
	3113	 56.1	 2.58	 15.93	 -10.77	 1.0	 89.76	 1	 56.1	 56.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 74.8;
	3117	 47.25	 2.175	 13.42	 -9.07	 1.0	 75.6	 1	 47.25	 47.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.0;
	3118	 90.0	 4.14	 25.56	 -17.28	 1.0	 144.0	 1	 90.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	3120	 29.7	 0.0	 0.0	 0.0	 1.0	 47.52	 1	 29.7	 29.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 39.6;
	3122	 147.75	 6.795	 41.96	 -28.37	 1.0	 236.4	 1	 147.75	 147.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.0;
	3127	 101.25	 4.66	 28.76	 -19.44	 1.0	 162.0	 1	 101.25	 101.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 135.0;
	3129	 94.88	 4.36	 26.94	 -18.22	 1.0	 151.8	 1	 94.88	 94.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.5;
	3131	 85.5	 3.93	 24.28	 -16.42	 1.0	 136.8	 1	 85.5	 85.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	3133	 33.345	 10.21	 26.11	 -5.69	 1.0	 61.56	 0	 51.3	 15.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	3133	 33.345	 10.21	 26.11	 -5.69	 1.0	 61.56	 0	 51.3	 15.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	3133	 33.345	 10.21	 26.11	 -5.69	 1.0	 61.56	 0	 51.3	 15.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.3;
	3137	 75.9	 3.495	 21.56	 -14.57	 1.0	 121.44	 1	 75.9	 75.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.2;
	3141	 68.62	 3.155	 19.49	 -13.18	 1.0	 109.8	 1	 68.62	 68.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 91.5;
	4010	 151.2	 6.955	 42.94	 -29.03	 1.0	 241.92	 1	 151.2	 151.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.6;
	4026	 266.5	 70.52	 191.06	 -50.02	 1.0	 492.0	 1	 410.0	 123.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 410.0;
	4030	 404.56	 107.055	 290.04	 -75.93	 1.0	 746.88	 1	 622.4	 186.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 622.4;
	4045	 93.4	 17.16	 35.86	 -1.54	 1.0	 37.8	 1	 93.4	 93.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 31.5;
	4046	 28.5	 5.235	 10.94	 -0.47	 1.0	 11.52	 1	 28.5	 28.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	4047	 27.48	 35.935	 75.1	 -3.23	 1.0	 79.2	 1	 27.48	 27.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0;
	4050	 150.0	 6.9	 42.6	 -28.8	 1.0	 240.0	 1	 150.0	 150.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.0;
	4052	 28.73	 8.795	 22.5	 -4.91	 1.0	 53.04	 1	 44.2	 13.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.2;
	4058	 93.6	 28.66	 73.3	 -15.98	 1.0	 172.8	 1	 144.0	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0;
	4059	 93.6	 28.66	 73.3	 -15.98	 1.0	 172.8	 1	 144.0	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0;
	4060	 93.6	 28.66	 73.3	 -15.98	 1.0	 172.8	 1	 144.0	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0;
	4061	 112.015	 34.295	 87.72	 -19.13	 1.0	 206.8	 1	 172.33	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.33;
	4062	 112.015	 34.295	 87.72	 -19.13	 1.0	 206.8	 1	 172.33	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.33;
	4063	 112.015	 34.295	 87.72	 -19.13	 1.0	 206.8	 1	 172.33	 51.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.33;
	4065	 30.55	 9.35	 23.92	 -5.22	 1.0	 56.4	 1	 47.0	 14.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.0;
	4075	 114.615	 35.09	 89.75	 -19.57	 1.0	 211.6	 0	 176.33	 52.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.33;
	4076	 114.615	 35.09	 89.75	 -19.57	 1.0	 211.6	 1	 176.33	 52.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.33;
	4077	 114.615	 35.09	 89.75	 -19.57	 1.0	 211.6	 1	 176.33	 52.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 176.33;
	4082	 158.21	 48.435	 123.89	 -27.02	 1.0	 292.08	 1	 243.4	 73.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 243.4;
	4083	 158.21	 48.435	 123.89	 -27.02	 1.0	 292.08	 1	 243.4	 73.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 243.4;
	4084	 158.21	 48.435	 123.89	 -27.02	 1.0	 292.08	 1	 243.4	 73.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 243.4;
	4085	 228.8	 70.05	 179.17	 -39.07	 1.0	 422.4	 1	 352.0	 105.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 352.0;
	4090	 0.91	 0.24	 0.65	 -0.17	 1.0	 1.68	 0	 1.4	 0.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4;
	4091	 15.275	 4.04	 10.95	 -2.87	 1.0	 28.2	 1	 23.5	 7.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 23.5;
	4092	 4.94	 1.305	 3.54	 -0.93	 1.0	 9.12	 0	 7.6	 2.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.6;
	4093	 18.2	 4.815	 13.05	 -3.42	 1.0	 33.6	 1	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	4094	 18.2	 4.815	 13.05	 -3.42	 1.0	 33.6	 1	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	4095	 18.2	 4.815	 13.05	 -3.42	 1.0	 33.6	 1	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	4096	 18.2	 4.815	 13.05	 -3.42	 1.0	 33.6	 0	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	4097	 18.2	 4.815	 13.05	 -3.42	 1.0	 33.6	 1	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	4098	 18.2	 4.815	 13.05	 -3.42	 1.0	 33.6	 0	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.0;
	4105	 135.0	 6.21	 38.34	 -25.92	 1.0	 216.0	 1	 135.0	 135.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 180.0;
	4115	 85.67	 26.23	 67.09	 -14.63	 1.0	 158.16	 1	 131.8	 39.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 131.8;
	4116	 85.67	 26.23	 67.09	 -14.63	 1.0	 158.16	 1	 131.8	 39.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 131.8;
	4133	 21.84	 6.685	 17.1	 -3.73	 1.0	 40.32	 0	 33.6	 10.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	4134	 21.84	 6.685	 17.1	 -3.73	 1.0	 40.32	 1	 33.6	 10.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	4135	 21.84	 6.685	 17.1	 -3.73	 1.0	 40.32	 1	 33.6	 10.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	4136	 21.84	 6.685	 17.1	 -3.73	 1.0	 40.32	 1	 33.6	 10.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 33.6;
	4137	 43.68	 13.37	 34.2	 -7.46	 1.0	 80.64	 0	 67.2	 20.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 67.2;
	4138	 42.9	 13.13	 33.59	 -7.33	 1.0	 79.2	 0	 66.0	 19.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 66.0;
	4142	 141.0	 6.485	 40.04	 -27.07	 1.0	 225.6	 1	 141.0	 141.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.0;
	4153	 212.4	 9.77	 60.32	 -40.78	 1.0	 339.84	 1	 212.4	 212.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 283.2;
	4160	 128.55	 39.355	 100.66	 -21.95	 1.0	 237.32	 1	 197.77	 59.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.77;
	4161	 128.55	 39.355	 100.66	 -21.95	 1.0	 237.32	 1	 197.77	 59.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.77;
	4162	 128.55	 39.355	 100.66	 -21.95	 1.0	 237.32	 1	 197.77	 59.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 197.77;
	4163	 5.85	 1.79	 4.58	 -1.0	 1.0	 10.8	 0	 9.0	 2.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.0;
	4166	 150.75	 6.935	 42.81	 -28.94	 1.0	 241.2	 1	 150.75	 150.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.0;
	4177	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	4181	 150.07	 6.905	 42.62	 -28.81	 1.0	 240.12	 1	 150.07	 150.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 200.1;
	4183	 152.25	 7.005	 43.24	 -29.23	 1.0	 243.6	 1	 152.25	 152.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 203.0;
	4192	 48.75	 14.92	 38.17	 -8.33	 1.0	 90.0	 1	 75.0	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	4192	 119.45	 36.57	 93.54	 -20.4	 1.0	 220.52	 1	 183.77	 55.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.77;
	4192	 15.6	 4.78	 12.22	 -2.66	 1.0	 28.8	 0	 24.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 24.0;
	4192	 39.65	 12.14	 31.05	 -6.77	 1.0	 73.2	 1	 61.0	 18.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	4192	 6.76	 2.07	 5.29	 -1.15	 1.0	 12.48	 1	 10.4	 3.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4;
	4192	 173.55	 53.13	 135.9	 -29.64	 1.0	 320.4	 1	 267.0	 80.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.0;
	4192	 173.55	 53.13	 135.9	 -29.64	 1.0	 320.4	 1	 267.0	 80.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.0;
	4192	 173.55	 53.13	 135.9	 -29.64	 1.0	 320.4	 1	 267.0	 80.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.0;
	4192	 119.45	 36.57	 93.54	 -20.4	 1.0	 220.52	 1	 183.77	 55.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.77;
	4192	 119.45	 36.57	 93.54	 -20.4	 1.0	 220.52	 1	 183.77	 55.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.77;
	4194	 151.2	 6.955	 42.94	 -29.03	 1.0	 241.92	 1	 151.2	 151.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 201.6;
	4195	 69.0	 3.175	 19.6	 -13.25	 1.0	 110.4	 1	 69.0	 69.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 92.0;
	5020	 90.0	 4.14	 25.56	 -17.28	 1.0	 144.0	 1	 90.0	 90.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 120.0;
	5023	 3.12	 0.955	 2.44	 -0.53	 1.0	 5.76	 0	 4.8	 1.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.8;
	5035	 2.73	 0.835	 2.14	 -0.47	 1.0	 5.04	 0	 4.2	 1.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.2;
	5036	 4.16	 1.275	 3.26	 -0.71	 1.0	 7.68	 0	 6.4	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4;
	5037	 200.505	 61.385	 157.01	 -34.24	 1.0	 370.16	 1	 308.47	 92.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 308.47;
	5038	 200.505	 61.385	 157.01	 -34.24	 1.0	 370.16	 1	 308.47	 92.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 308.47;
	5039	 200.505	 61.385	 157.01	 -34.24	 1.0	 370.16	 1	 308.47	 92.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 308.47;
	5040	 200.505	 61.385	 157.01	 -34.24	 1.0	 370.16	 1	 308.47	 92.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 308.47;
	5041	 200.505	 61.385	 157.01	 -34.24	 1.0	 370.16	 1	 308.47	 92.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 308.47;
	5042	 200.505	 61.385	 157.01	 -34.24	 1.0	 370.16	 1	 308.47	 92.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 308.47;
	5051	 55.055	 16.855	 43.11	 -9.4	 1.0	 101.64	 1	 84.7	 25.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 84.7;
	5057	 206.275	 63.15	 161.53	 -35.23	 1.0	 380.82	 0	 317.35	 95.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.35;
	5058	 206.275	 63.15	 161.53	 -35.23	 1.0	 380.82	 1	 317.35	 95.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 317.35;
	5065	 6.89	 2.11	 5.4	 -1.18	 1.0	 12.72	 1	 10.6	 3.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6;
	5066	 1.17	 0.36	 0.92	 -0.2	 1.0	 2.16	 0	 1.8	 0.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.8;
	5067	 284.875	 87.215	 223.08	 -48.65	 1.0	 525.92	 1	 438.27	 131.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 438.27;
	5068	 284.875	 87.215	 223.08	 -48.65	 1.0	 525.92	 1	 438.27	 131.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 438.27;
	5069	 284.875	 87.215	 223.08	 -48.65	 1.0	 525.92	 1	 438.27	 131.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 438.27;
	5089	 61.95	 22.76	 47.57	 -2.05	 1.0	 50.16	 0	 123.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 41.8;
	5106	 7.02	 1.855	 5.03	 -1.32	 1.0	 12.96	 0	 10.8	 3.24	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.8;
	5107	 3.705	 0.98	 2.66	 -0.7	 1.0	 6.84	 0	 5.7	 1.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.7;
	5166	 82.225	 25.175	 64.39	 -14.04	 1.0	 151.8	 1	 126.5	 37.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 126.5;
	5167	 1.04	 0.315	 0.81	 -0.18	 1.0	 1.92	 1	 1.6	 0.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.6;
	5170	 45.0	 2.07	 12.78	 -8.64	 1.0	 72.0	 1	 45.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	5198	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	5206	 161.635	 49.485	 126.57	 -27.6	 1.0	 298.4	 1	 248.67	 74.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.67;
	5207	 161.635	 49.485	 126.57	 -27.6	 1.0	 298.4	 1	 248.67	 74.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.67;
	5208	 161.635	 49.485	 126.57	 -27.6	 1.0	 298.4	 1	 248.67	 74.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 248.67;
	5238	 168.75	 7.765	 47.93	 -32.4	 1.0	 270.0	 1	 168.75	 168.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.0;
	5243	 112.5	 5.175	 31.95	 -21.6	 1.0	 180.0	 1	 112.5	 112.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	5262	 789.75	 173.745	 447.12	 -99.63	 1.0	 1458.0	 1	 1215.0	 364.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1215.0;
	5263	 789.75	 173.745	 447.12	 -99.63	 1.0	 1458.0	 1	 1215.0	 364.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1215.0;
	5281	 174.025	 53.28	 136.28	 -29.72	 1.0	 321.28	 1	 267.73	 80.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.73;
	5282	 174.025	 53.28	 136.28	 -29.72	 1.0	 321.28	 1	 267.73	 80.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.73;
	5283	 174.025	 53.28	 136.28	 -29.72	 1.0	 321.28	 0	 267.73	 80.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 267.73;
	5297	 2.08	 0.635	 1.63	 -0.36	 1.0	 3.84	 0	 3.2	 0.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2;
	5298	 74.75	 22.885	 58.53	 -12.76	 1.0	 138.0	 1	 115.0	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	5299	 74.75	 22.885	 58.53	 -12.76	 1.0	 138.0	 1	 115.0	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	5300	 74.75	 22.885	 58.53	 -12.76	 1.0	 138.0	 1	 115.0	 34.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 115.0;
	5301	 53.755	 16.455	 42.09	 -9.18	 1.0	 99.24	 1	 82.7	 24.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 82.7;
	5302	 301.44	 92.285	 236.05	 -51.48	 1.0	 556.5	 1	 463.75	 139.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 463.75;
	5303	 301.44	 92.285	 236.05	 -51.48	 1.0	 556.5	 1	 463.75	 139.13	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 463.75;
	5319	 170.82	 52.3	 133.77	 -29.17	 1.0	 315.36	 1	 262.8	 78.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.8;
	5320	 170.82	 52.3	 133.77	 -29.17	 1.0	 315.36	 0	 262.8	 78.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.8;
	5321	 170.82	 52.3	 133.77	 -29.17	 1.0	 315.36	 1	 262.8	 78.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 262.8;
	5324	 184.645	 56.53	 144.59	 -31.53	 1.0	 340.88	 1	 284.07	 85.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 284.07;
	5325	 184.645	 56.53	 144.59	 -31.53	 1.0	 340.88	 1	 284.07	 85.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 284.07;
	5326	 184.645	 56.53	 144.59	 -31.53	 1.0	 340.88	 1	 284.07	 85.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 284.07;
	5342	 8.4	 1.53	 3.2	 -0.14	 1.0	 3.36	 1	 8.4	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.8;
	5343	 207.5	 38.12	 79.67	 -3.43	 1.0	 84.0	 1	 207.5	 207.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 70.0;
	5360	 655.2	 173.375	 469.73	 -122.98	 1.0	 1209.6	 1	 1008.0	 302.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1008.0;
	5363	 6.76	 2.07	 5.29	 -1.15	 1.0	 12.48	 1	 10.4	 3.12	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.4;
	5364	 138.665	 42.455	 108.59	 -23.68	 1.0	 256.0	 1	 213.33	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.33;
	5365	 138.665	 42.455	 108.59	 -23.68	 1.0	 256.0	 1	 213.33	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.33;
	5366	 138.665	 42.455	 108.59	 -23.68	 1.0	 256.0	 1	 213.33	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.33;
	5367	 138.665	 42.455	 108.59	 -23.68	 1.0	 256.0	 1	 213.33	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.33;
	5368	 138.665	 42.455	 108.59	 -23.68	 1.0	 256.0	 1	 213.33	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.33;
	5369	 138.665	 42.455	 108.59	 -23.68	 1.0	 256.0	 1	 213.33	 64.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.33;
	5382	 135.85	 41.59	 106.38	 -23.2	 1.0	 250.8	 1	 209.0	 62.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.0;
	5383	 135.85	 41.59	 106.38	 -23.2	 1.0	 250.8	 1	 209.0	 62.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 209.0;
	5399	 124.2	 5.71	 35.27	 -23.85	 1.0	 198.72	 1	 124.2	 124.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 165.6;
	5403	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	5404	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	5405	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	5406	 58.11	 17.79	 45.5	 -9.92	 1.0	 107.28	 1	 89.4	 26.82	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 89.4;
	5415	 79.3	 24.28	 62.1	 -13.54	 1.0	 146.4	 1	 122.0	 36.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0;
	5416	 79.3	 24.28	 62.1	 -13.54	 1.0	 146.4	 1	 122.0	 36.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0;
	5417	 79.3	 24.28	 62.1	 -13.54	 1.0	 146.4	 1	 122.0	 36.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 122.0;
	5418	 77.22	 23.64	 60.47	 -13.19	 1.0	 142.56	 1	 118.8	 35.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.8;
	5419	 77.22	 23.64	 60.47	 -13.19	 1.0	 142.56	 1	 118.8	 35.64	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 118.8;
	5423	 8.06	 2.465	 6.31	 -1.38	 1.0	 14.88	 1	 12.4	 3.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.4;
	5424	 2.08	 0.635	 1.63	 -0.36	 1.0	 3.84	 0	 3.2	 0.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2;
	5444	 187.85	 57.51	 147.1	 -32.08	 1.0	 346.8	 0	 289.0	 86.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0;
	5444	 187.85	 57.51	 147.1	 -32.08	 1.0	 346.8	 0	 289.0	 86.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0;
	5444	 187.85	 57.51	 147.1	 -32.08	 1.0	 346.8	 0	 289.0	 86.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0;
	5444	 187.85	 57.51	 147.1	 -32.08	 1.0	 346.8	 1	 289.0	 86.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0;
	5444	 187.85	 57.51	 147.1	 -32.08	 1.0	 346.8	 1	 289.0	 86.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0;
	5444	 187.85	 57.51	 147.1	 -32.08	 1.0	 346.8	 0	 289.0	 86.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 289.0;
	5444	 91.845	 28.12	 71.92	 -15.68	 1.0	 169.56	 1	 141.3	 42.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 141.3;
	5444	 91.845	 28.12	 71.92	 -15.68	 1.0	 169.56	 1	 141.3	 42.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 141.3;
	6006	 138.45	 42.39	 108.42	 -23.64	 1.0	 255.6	 1	 213.0	 63.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 213.0;
	6007	 276.9	 84.77	 216.83	 -47.29	 1.0	 511.2	 0	 426.0	 127.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 426.0;
	6008	 128.915	 39.47	 100.95	 -22.01	 1.0	 238.0	 1	 198.33	 59.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.33;
	6009	 128.915	 39.47	 100.95	 -22.01	 1.0	 238.0	 1	 198.33	 59.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.33;
	6010	 128.915	 39.47	 100.95	 -22.01	 1.0	 238.0	 1	 198.33	 59.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 198.33;
	6041	 0.0	 9.8	 20.48	 -0.88	 1.0	 21.6	 1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 18.0;
	6042	 0.0	 58.81	 122.91	 -5.29	 1.0	 129.6	 1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 108.0;
	6048	 2.21	 0.675	 1.73	 -0.38	 1.0	 4.08	 0	 3.4	 1.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.4;
	6049	 6.24	 1.91	 4.89	 -1.07	 1.0	 11.52	 0	 9.6	 2.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 9.6;
	6050	 2.86	 0.875	 2.24	 -0.49	 1.0	 5.28	 0	 4.4	 1.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4;
	6051	 37.31	 11.425	 29.22	 -6.37	 1.0	 68.88	 1	 57.4	 17.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	6052	 37.31	 11.425	 29.22	 -6.37	 1.0	 68.88	 0	 57.4	 17.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	6053	 37.31	 11.425	 29.22	 -6.37	 1.0	 68.88	 1	 57.4	 17.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	6054	 37.31	 11.425	 29.22	 -6.37	 1.0	 68.88	 1	 57.4	 17.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 57.4;
	6069	 117.89	 36.095	 92.32	 -20.13	 1.0	 217.64	 1	 181.37	 54.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.37;
	6070	 117.89	 36.095	 92.32	 -20.13	 1.0	 217.64	 1	 181.37	 54.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.37;
	6071	 117.89	 36.095	 92.32	 -20.13	 1.0	 217.64	 1	 181.37	 54.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.37;
	6072	 117.89	 36.095	 92.32	 -20.13	 1.0	 217.64	 0	 181.37	 54.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.37;
	6073	 117.89	 36.095	 92.32	 -20.13	 1.0	 217.64	 1	 181.37	 54.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.37;
	6074	 117.89	 36.095	 92.32	 -20.13	 1.0	 217.64	 1	 181.37	 54.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.37;
	6078	 366.165	 96.89	 262.51	 -68.73	 1.0	 676.0	 1	 563.33	 169.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 563.33;
	6079	 366.165	 96.89	 262.51	 -68.73	 1.0	 676.0	 1	 563.33	 169.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 563.33;
	6080	 366.165	 96.89	 262.51	 -68.73	 1.0	 676.0	 1	 563.33	 169.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 563.33;
	6082	 41.37	 11.98	 25.04	 -1.08	 1.0	 26.4	 1	 41.37	 41.37	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	6083	 65.3	 11.98	 25.04	 -1.08	 1.0	 26.4	 1	 65.3	 65.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	6085	 1.05	 0.0	 0.0	 0.0	 1.0	 1.68	 1	 1.05	 1.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.4;
	6086	 22.5	 0.0	 0.0	 0.0	 1.0	 36.0	 1	 22.5	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 30.0;
	6087	 3.575	 0.0	 0.0	 0.0	 1.0	 6.6	 0	 5.5	 1.65	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.5;
	6088	 7.95	 0.0	 0.0	 0.0	 1.0	 12.72	 1	 7.95	 7.95	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.6;
	6089	 10.42	 0.0	 0.0	 0.0	 1.0	 16.68	 1	 10.42	 10.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 13.9;
	6090	 30.52	 0.0	 0.0	 0.0	 1.0	 48.84	 1	 30.52	 30.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 40.7;
	6104	 39.325	 12.035	 30.79	 -6.72	 1.0	 72.6	 1	 60.5	 18.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	6105	 39.325	 12.035	 30.79	 -6.72	 1.0	 72.6	 1	 60.5	 18.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.5;
	6106	 78.65	 24.08	 61.59	 -13.43	 1.0	 145.2	 1	 121.0	 36.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 121.0;
	6110	 383.89	 101.585	 275.22	 -72.05	 1.0	 708.72	 1	 590.6	 177.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 590.6;
	6111	 429.975	 113.78	 308.26	 -80.7	 1.0	 793.8	 1	 661.5	 198.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 661.5;
	6144	 5.46	 1.675	 4.28	 -0.93	 1.0	 10.08	 0	 8.4	 2.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 8.4;
	6145	 289.9	 88.75	 227.01	 -49.51	 1.0	 535.2	 1	 446.0	 133.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0;
	6146	 289.9	 88.75	 227.01	 -49.51	 1.0	 535.2	 1	 446.0	 133.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.0;
	6147	 605.8	 185.47	 474.39	 -103.45	 1.0	 1118.4	 1	 932.0	 279.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 932.0;
	6148	 469.3	 143.68	 367.5	 -80.14	 1.0	 866.4	 0	 722.0	 216.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 722.0;
	6149	 469.3	 143.68	 367.5	 -80.14	 1.0	 866.4	 1	 722.0	 216.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 722.0;
	6164	 152.785	 46.775	 119.64	 -26.09	 1.0	 282.06	 1	 235.05	 70.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.05;
	6165	 152.785	 46.775	 119.64	 -26.09	 1.0	 282.06	 1	 235.05	 70.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.05;
	6166	 152.785	 46.775	 119.64	 -26.09	 1.0	 282.06	 1	 235.05	 70.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.05;
	6167	 152.785	 46.775	 119.64	 -26.09	 1.0	 282.06	 1	 235.05	 70.52	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 235.05;
	6213	 177.9	 32.675	 68.29	 -2.94	 1.0	 72.0	 1	 177.9	 177.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 60.0;
	6214	 552.3	 101.465	 212.06	 -9.13	 1.0	 223.6	 1	 552.3	 552.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.33;
	6215	 552.3	 101.465	 212.06	 -9.13	 1.0	 223.6	 1	 552.3	 552.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.33;
	6216	 552.3	 101.465	 212.06	 -9.13	 1.0	 223.6	 1	 552.3	 552.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 186.33;
	6242	 39.65	 12.14	 31.05	 -6.77	 1.0	 73.2	 1	 61.0	 18.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 61.0;
	6243	 118.95	 36.42	 93.15	 -20.31	 1.0	 219.6	 1	 183.0	 54.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.0;
	6244	 193.7	 59.3	 151.68	 -33.08	 1.0	 357.6	 1	 298.0	 89.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0;
	6245	 193.7	 59.3	 151.68	 -33.08	 1.0	 357.6	 1	 298.0	 89.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0;
	6246	 193.7	 59.3	 151.68	 -33.08	 1.0	 357.6	 1	 298.0	 89.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 298.0;
	6247	 119.165	 36.485	 93.32	 -20.35	 1.0	 220.0	 1	 183.33	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.33;
	6248	 119.165	 36.485	 93.32	 -20.35	 1.0	 220.0	 1	 183.33	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.33;
	6249	 119.165	 36.485	 93.32	 -20.35	 1.0	 220.0	 1	 183.33	 55.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.33;
	6257	 126.1	 38.61	 98.75	 -21.53	 1.0	 232.8	 1	 194.0	 58.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 194.0;
	6258	 126.1	 38.61	 98.75	 -21.53	 1.0	 232.8	 1	 194.0	 58.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 194.0;
	6259	 33.41	 10.225	 26.16	 -5.71	 1.0	 61.68	 0	 51.4	 15.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.4;
	6260	 167.05	 51.14	 130.81	 -28.53	 1.0	 308.4	 1	 257.0	 77.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 257.0;
	6266	 4.5	 0.825	 1.72	 -0.07	 1.0	 1.8	 1	 4.5	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5;
	6267	 7.2	 1.305	 2.73	 -0.12	 1.0	 2.88	 1	 7.2	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.4;
	6268	 4.5	 0.825	 1.72	 -0.07	 1.0	 1.8	 1	 4.5	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5;
	6269	 7.2	 1.305	 2.73	 -0.12	 1.0	 2.88	 1	 7.2	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.4;
	6270	 9.0	 3.265	 6.82	 -0.29	 1.0	 7.2	 0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.0;
	6271	 5.5	 1.955	 4.09	 -0.18	 1.0	 4.32	 0	 11.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.6;
	6272	 3.6	 1.305	 2.73	 -0.12	 1.0	 2.88	 0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.4;
	6273	 3.6	 1.305	 2.73	 -0.12	 1.0	 2.88	 0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.4;
	6274	 8.4	 1.53	 3.2	 -0.14	 1.0	 3.36	 1	 8.4	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.8;
	6295	 134.05	 41.04	 104.97	 -22.89	 1.0	 247.48	 1	 206.23	 61.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.23;
	6296	 134.05	 41.04	 104.97	 -22.89	 1.0	 247.48	 1	 206.23	 61.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.23;
	6297	 134.065	 41.04	 104.97	 -22.89	 1.0	 247.48	 1	 206.23	 61.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.23;
	6301	 2.08	 0.635	 1.63	 -0.36	 1.0	 3.84	 0	 3.2	 0.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2;
	6302	 160.715	 49.205	 125.85	 -27.44	 1.0	 296.7	 1	 247.25	 74.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.25;
	6303	 160.715	 49.205	 125.85	 -27.44	 1.0	 296.7	 1	 247.25	 74.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.25;
	6304	 160.715	 49.205	 125.85	 -27.44	 1.0	 296.7	 1	 247.25	 74.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.25;
	6305	 160.715	 49.205	 125.85	 -27.44	 1.0	 296.7	 1	 247.25	 74.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 247.25;
	6349	 7.8	 2.39	 6.11	 -1.33	 1.0	 14.4	 0	 12.0	 3.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 12.0;
	6349	 33.475	 10.245	 26.21	 -5.72	 1.0	 61.8	 0	 51.5	 15.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5;
	6349	 66.95	 20.5	 52.43	 -11.43	 1.0	 123.6	 1	 103.0	 30.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 103.0;
	6349	 1.495	 0.455	 1.17	 -0.26	 1.0	 2.76	 0	 2.3	 0.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 2.3;
	6349	 2.99	 0.915	 2.34	 -0.51	 1.0	 5.52	 0	 4.6	 1.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.6;
	6349	 0.975	 0.295	 0.76	 -0.17	 1.0	 1.8	 0	 1.5	 0.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1.5;
	6349	 2.6	 0.8	 2.04	 -0.44	 1.0	 4.8	 0	 4.0	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0;
	6349	 4.16	 1.275	 3.26	 -0.71	 1.0	 7.68	 0	 6.4	 1.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.4;
	6349	 235.95	 72.24	 184.77	 -40.29	 1.0	 435.6	 1	 363.0	 108.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 363.0;
	6349	 235.95	 72.24	 184.77	 -40.29	 1.0	 435.6	 1	 363.0	 108.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 363.0;
	6349	 33.475	 10.245	 26.21	 -5.72	 1.0	 61.8	 0	 51.5	 15.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.5;
	7005	 105.95	 32.44	 82.97	 -18.09	 1.0	 195.6	 1	 163.0	 48.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0;
	7006	 105.95	 32.44	 82.97	 -18.09	 1.0	 195.6	 1	 163.0	 48.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0;
	7007	 105.95	 32.44	 82.97	 -18.09	 1.0	 195.6	 1	 163.0	 48.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0;
	7008	 105.95	 32.44	 82.97	 -18.09	 1.0	 195.6	 1	 163.0	 48.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0;
	7009	 105.95	 32.44	 82.97	 -18.09	 1.0	 195.6	 1	 163.0	 48.9	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 163.0;
	7015	 2.6	 0.8	 2.04	 -0.44	 1.0	 4.8	 0	 4.0	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0;
	7021	 14.56	 4.455	 11.4	 -2.49	 1.0	 26.88	 1	 22.4	 6.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.4;
	7022	 30.81	 9.435	 24.13	 -5.26	 1.0	 56.88	 1	 47.4	 14.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.4;
	7023	 30.81	 9.435	 24.13	 -5.26	 1.0	 56.88	 1	 47.4	 14.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 47.4;
	7024	 61.62	 18.865	 48.25	 -10.52	 1.0	 113.76	 1	 94.8	 28.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 94.8;
	7025	 2.08	 0.635	 1.63	 -0.36	 1.0	 3.84	 0	 3.2	 0.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.2;
	7031	 29.1	 0.0	 0.0	 0.0	 1.0	 46.56	 1	 29.1	 29.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 38.8;
	7032	 7.5	 0.0	 0.0	 0.0	 1.0	 12.0	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	7033	 7.5	 0.0	 0.0	 0.0	 1.0	 12.0	 1	 7.5	 7.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	7034	 2.86	 0.0	 0.0	 0.0	 1.0	 5.28	 0	 4.4	 1.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.4;
	7045	 122.49	 37.5	 95.92	 -20.92	 1.0	 226.14	 1	 188.45	 56.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.45;
	7046	 122.49	 37.5	 95.92	 -20.92	 1.0	 226.14	 1	 188.45	 56.53	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 188.45;
	7061	 74.685	 22.865	 58.48	 -12.75	 1.0	 137.88	 1	 114.9	 34.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9;
	7062	 74.685	 22.865	 58.48	 -12.75	 1.0	 137.88	 1	 114.9	 34.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9;
	7063	 74.685	 22.865	 58.48	 -12.75	 1.0	 137.88	 1	 114.9	 34.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9;
	7064	 74.685	 22.865	 58.48	 -12.75	 1.0	 137.88	 1	 114.9	 34.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9;
	7065	 74.685	 22.865	 58.48	 -12.75	 1.0	 137.88	 1	 114.9	 34.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9;
	7066	 74.685	 22.865	 58.48	 -12.75	 1.0	 137.88	 1	 114.9	 34.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.9;
	7079	 148.62	 45.5	 116.38	 -25.38	 1.0	 274.38	 1	 228.65	 68.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.65;
	7080	 148.62	 45.5	 116.38	 -25.38	 1.0	 274.38	 1	 228.65	 68.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.65;
	7081	 148.62	 45.5	 116.38	 -25.38	 1.0	 274.38	 1	 228.65	 68.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.65;
	7082	 148.62	 45.5	 116.38	 -25.38	 1.0	 274.38	 1	 228.65	 68.59	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 228.65;
	7098	 880.295	 193.665	 498.38	 -111.05	 1.0	 1625.16	 1	 1354.3	 406.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1354.3;
	7099	 880.295	 193.665	 498.38	 -111.05	 1.0	 1625.16	 1	 1354.3	 406.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 1354.3;
	7107	 97.5	 29.85	 76.35	 -16.65	 1.0	 180.0	 1	 150.0	 45.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 150.0;
	7108	 33.15	 10.15	 25.96	 -5.66	 1.0	 61.2	 1	 51.0	 15.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0;
	7109	 33.15	 10.15	 25.96	 -5.66	 1.0	 61.2	 1	 51.0	 15.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 51.0;
	7110	 127.4	 39.0	 99.76	 -21.76	 1.0	 235.2	 1	 196.0	 58.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	7111	 127.4	 39.0	 99.76	 -21.76	 1.0	 235.2	 1	 196.0	 58.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	7112	 127.4	 39.0	 99.76	 -21.76	 1.0	 235.2	 1	 196.0	 58.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	7113	 127.4	 39.0	 99.76	 -21.76	 1.0	 235.2	 1	 196.0	 58.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	7114	 127.4	 39.0	 99.76	 -21.76	 1.0	 235.2	 1	 196.0	 58.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	7115	 127.4	 39.0	 99.76	 -21.76	 1.0	 235.2	 1	 196.0	 58.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 196.0;
	7121	 2.405	 0.735	 1.88	 -0.41	 1.0	 4.44	 0	 3.7	 1.11	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 3.7;
	7122	 2.795	 0.855	 2.19	 -0.48	 1.0	 5.16	 0	 4.3	 1.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.3;
	7133	 10.595	 3.245	 8.3	 -1.81	 1.0	 19.56	 1	 16.3	 4.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3;
	7134	 134.26	 41.1	 105.13	 -22.93	 1.0	 247.86	 1	 206.55	 61.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.55;
	7135	 134.26	 41.1	 105.13	 -22.93	 1.0	 247.86	 1	 206.55	 61.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.55;
	7136	 134.26	 41.1	 105.13	 -22.93	 1.0	 247.86	 1	 206.55	 61.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.55;
	7137	 134.26	 41.1	 105.13	 -22.93	 1.0	 247.86	 1	 206.55	 61.97	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 206.55;
	7138	 247.455	 75.76	 193.78	 -42.26	 1.0	 456.84	 1	 380.7	 114.21	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 380.7;
	7139	 38.35	 11.74	 30.03	 -6.55	 1.0	 70.8	 1	 59.0	 17.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	7140	 38.35	 11.74	 30.03	 -6.55	 1.0	 70.8	 1	 59.0	 17.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	7141	 38.35	 11.74	 30.03	 -6.55	 1.0	 70.8	 1	 59.0	 17.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	7142	 38.35	 11.74	 30.03	 -6.55	 1.0	 70.8	 1	 59.0	 17.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 59.0;
	7146	 6.63	 2.03	 5.19	 -1.13	 1.0	 12.24	 1	 10.2	 3.06	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.2;
	7162	 71.89	 22.01	 56.3	 -12.28	 1.0	 132.72	 1	 110.6	 33.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.6;
	7163	 71.89	 22.01	 56.3	 -12.28	 1.0	 132.72	 1	 110.6	 33.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.6;
	7164	 71.89	 22.01	 56.3	 -12.28	 1.0	 132.72	 1	 110.6	 33.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.6;
	7165	 71.89	 22.01	 56.3	 -12.28	 1.0	 132.72	 1	 110.6	 33.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.6;
	7166	 71.89	 22.01	 56.3	 -12.28	 1.0	 132.72	 1	 110.6	 33.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.6;
	7167	 71.9	 22.01	 56.3	 -12.28	 1.0	 132.72	 1	 110.6	 33.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 110.6;
	7168	 57.02	 17.455	 44.65	 -9.74	 1.0	 105.26	 1	 87.72	 26.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.72;
	7169	 57.01	 17.455	 44.65	 -9.74	 1.0	 105.26	 1	 87.72	 26.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 87.72;
	7170	 228.065	 69.82	 178.59	 -38.95	 1.0	 421.04	 1	 350.87	 105.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 350.87;
	7189	 4.485	 1.37	 3.51	 -0.77	 1.0	 8.28	 1	 6.9	 2.07	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.9;
	7190	 31.2	 9.55	 24.43	 -5.33	 1.0	 57.6	 1	 48.0	 14.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 48.0;
	7191	 3.25	 1.0	 2.55	 -0.55	 1.0	 6.0	 0	 5.0	 1.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 5.0;
	7192	 22.75	 6.965	 17.81	 -3.88	 1.0	 42.0	 1	 35.0	 10.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 35.0;
	7193	 4.875	 1.495	 3.82	 -0.83	 1.0	 9.0	 1	 7.5	 2.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	7194	 150.115	 45.955	 117.55	 -25.64	 1.0	 277.14	 1	 230.95	 69.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.95;
	7195	 150.115	 45.955	 117.55	 -25.64	 1.0	 277.14	 1	 230.95	 69.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.95;
	7196	 150.115	 45.955	 117.55	 -25.64	 1.0	 277.14	 1	 230.95	 69.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.95;
	7197	 150.115	 45.955	 117.55	 -25.64	 1.0	 277.14	 1	 230.95	 69.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 230.95;
	7207	 2.6	 0.8	 2.04	 -0.44	 1.0	 4.8	 0	 4.0	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0;
	7208	 497.25	 152.235	 389.39	 -84.92	 1.0	 918.0	 1	 765.0	 229.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 765.0;
	7209	 497.25	 152.235	 389.39	 -84.92	 1.0	 918.0	 1	 765.0	 229.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 765.0;
	7210	 116.025	 35.525	 90.86	 -19.81	 1.0	 214.2	 1	 178.5	 53.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5;
	7211	 116.025	 35.525	 90.86	 -19.81	 1.0	 214.2	 1	 178.5	 53.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5;
	7212	 116.025	 35.525	 90.86	 -19.81	 1.0	 214.2	 1	 178.5	 53.55	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 178.5;
	7266	 197.99	 60.615	 155.04	 -33.81	 1.0	 365.52	 1	 304.6	 91.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 304.6;
	7267	 58.915	 18.04	 46.14	 -10.06	 1.0	 108.77	 1	 90.64	 27.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.64;
	7268	 58.915	 18.04	 46.14	 -10.06	 1.0	 108.77	 1	 90.64	 27.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.64;
	7269	 58.915	 18.04	 46.14	 -10.06	 1.0	 108.77	 1	 90.64	 27.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 90.64;
	7270	 117.83	 36.075	 92.27	 -20.12	 1.0	 217.54	 1	 181.28	 54.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 181.28;
	7280	 16.705	 5.115	 13.08	 -2.85	 1.0	 30.84	 0	 25.7	 7.71	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 25.7;
	7281	 9.75	 2.985	 7.64	 -1.67	 1.0	 18.0	 0	 15.0	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 15.0;
	7284	 4.875	 0.0	 0.0	 0.0	 1.0	 9.0	 0	 7.5	 2.25	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 7.5;
	7285	 21.22	 0.0	 0.0	 0.0	 1.0	 33.96	 1	 21.22	 21.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3;
	7286	 21.22	 0.0	 0.0	 0.0	 1.0	 33.96	 1	 21.22	 21.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3;
	7287	 21.22	 0.0	 0.0	 0.0	 1.0	 33.96	 1	 21.22	 21.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3;
	7288	 21.22	 0.0	 0.0	 0.0	 1.0	 33.96	 1	 21.22	 21.22	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 28.3;
	7289	 42.45	 0.0	 0.0	 0.0	 1.0	 67.92	 1	 42.45	 42.45	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 56.6;
	7307	 62.84	 19.24	 49.21	 -10.73	 1.0	 116.02	 1	 96.68	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.68;
	7308	 62.84	 19.24	 49.21	 -10.73	 1.0	 116.02	 1	 96.68	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.68;
	7309	 62.84	 19.24	 49.21	 -10.73	 1.0	 116.02	 0	 96.68	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.68;
	7310	 62.84	 19.24	 49.21	 -10.73	 1.0	 116.02	 1	 96.68	 29.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 96.68;
	7311	 125.69	 38.48	 98.42	 -21.46	 1.0	 232.04	 1	 193.37	 58.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 193.37;
	7323	 80.91	 24.77	 63.36	 -13.82	 1.0	 149.37	 1	 124.48	 37.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.47;
	7324	 80.91	 24.77	 63.36	 -13.82	 1.0	 149.37	 1	 124.48	 37.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.47;
	7325	 80.91	 24.77	 63.36	 -13.82	 1.0	 149.37	 1	 124.48	 37.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.47;
	7326	 80.91	 24.77	 63.36	 -13.82	 1.0	 149.37	 1	 124.48	 37.34	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 124.47;
	7329	 66.235	 20.28	 51.87	 -11.31	 1.0	 122.28	 1	 101.9	 30.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 101.9;
	7334	 3.055	 0.81	 2.19	 -0.57	 1.0	 5.64	 0	 4.7	 1.41	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.7;
	7335	 294.775	 78.0	 211.33	 -55.33	 1.0	 544.2	 1	 453.5	 136.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 453.5;
	7349	 203.99	 62.455	 159.74	 -34.83	 1.0	 376.59	 1	 313.83	 94.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 313.83;
	7350	 203.99	 62.455	 159.74	 -34.83	 1.0	 376.59	 1	 313.83	 94.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 313.83;
	7351	 203.99	 62.455	 159.74	 -34.83	 1.0	 376.59	 1	 313.83	 94.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 313.83;
	7352	 203.99	 62.455	 159.74	 -34.83	 1.0	 376.59	 1	 313.83	 94.15	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 313.83;
	7353	 444.73	 136.155	 348.26	 -75.95	 1.0	 821.04	 1	 684.2	 205.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.2;
	7354	 444.73	 136.155	 348.26	 -75.95	 1.0	 821.04	 1	 684.2	 205.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.2;
	7355	 444.73	 136.155	 348.26	 -75.95	 1.0	 821.04	 1	 684.2	 205.26	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.2;
	7356	 444.6	 136.155	 348.26	 -75.95	 1.0	 821.04	 1	 684.2	 205.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 684.2;
	7357	 10.595	 3.245	 8.3	 -1.81	 1.0	 19.56	 1	 16.3	 4.89	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 16.3;
	7358	 146.38	 44.815	 114.63	 -25.0	 1.0	 270.24	 1	 225.2	 67.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.2;
	7359	 146.38	 44.815	 114.63	 -25.0	 1.0	 270.24	 1	 225.2	 67.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.2;
	7360	 146.38	 44.815	 114.63	 -25.0	 1.0	 270.24	 1	 225.2	 67.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 225.2;
	7361	 66.755	 20.435	 52.27	 -11.4	 1.0	 123.24	 1	 102.7	 30.81	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.7;
	7369	 69.725	 21.345	 54.6	 -11.91	 1.0	 128.72	 1	 107.27	 32.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.27;
	7370	 69.725	 21.345	 54.6	 -11.91	 1.0	 128.72	 1	 107.27	 32.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.27;
	7371	 69.725	 21.345	 54.6	 -11.91	 1.0	 128.72	 1	 107.27	 32.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.27;
	7372	 69.725	 21.345	 54.6	 -11.91	 1.0	 128.72	 1	 107.27	 32.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.27;
	7373	 69.725	 21.345	 54.6	 -11.91	 1.0	 128.72	 1	 107.27	 32.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.27;
	7374	 69.725	 21.345	 54.6	 -11.91	 1.0	 128.72	 1	 107.27	 32.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 107.27;
	7375	 119.38	 36.545	 93.48	 -20.39	 1.0	 220.39	 1	 183.66	 55.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.66;
	7376	 119.38	 36.545	 93.48	 -20.39	 1.0	 220.39	 1	 183.66	 55.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.66;
	7377	 119.38	 36.545	 93.48	 -20.39	 1.0	 220.39	 1	 183.66	 55.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.66;
	7378	 119.38	 36.545	 93.48	 -20.39	 1.0	 220.39	 1	 183.66	 55.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.66;
	7379	 119.38	 36.545	 93.48	 -20.39	 1.0	 220.39	 1	 183.66	 55.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 183.66;
	7389	 352.82	 108.02	 276.29	 -60.25	 1.0	 651.36	 1	 542.8	 162.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 542.8;
	7400	 46.8	 14.33	 36.65	 -7.99	 1.0	 86.4	 1	 72.0	 21.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	7400	 46.8	 14.33	 36.65	 -7.99	 1.0	 86.4	 1	 72.0	 21.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	7400	 46.8	 14.33	 36.65	 -7.99	 1.0	 86.4	 1	 72.0	 21.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	7400	 46.8	 14.33	 36.65	 -7.99	 1.0	 86.4	 1	 72.0	 21.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 72.0;
	7400	 93.6	 28.66	 73.3	 -15.98	 1.0	 172.8	 1	 144.0	 43.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 144.0;
	7400	 290.16	 88.835	 227.22	 -49.55	 1.0	 535.68	 1	 446.4	 133.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 446.4;
	7406	 41.015	 12.56	 32.12	 -7.0	 1.0	 75.72	 1	 63.1	 18.93	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 63.1;
	7406	 201.5	 61.69	 157.79	 -34.41	 1.0	 372.0	 1	 310.0	 93.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 310.0;
	7414	 66.56	 20.375	 52.12	 -11.37	 1.0	 122.88	 1	 102.4	 30.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 102.4;
	7419	 57.33	 17.55	 44.89	 -9.79	 1.0	 105.84	 1	 88.2	 26.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	7419	 57.33	 17.55	 44.89	 -9.79	 1.0	 105.84	 1	 88.2	 26.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 88.2;
	7422	 4.42	 1.355	 3.46	 -0.75	 1.0	 8.16	 1	 6.8	 2.04	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 6.8;
	7422	 111.93	 34.27	 87.65	 -19.11	 1.0	 206.64	 1	 172.2	 51.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.2;
	7422	 111.93	 34.27	 87.65	 -19.11	 1.0	 206.64	 1	 172.2	 51.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.2;
	7422	 73.125	 22.385	 57.26	 -12.49	 1.0	 135.0	 1	 112.5	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	7422	 73.125	 22.385	 57.26	 -12.49	 1.0	 135.0	 1	 112.5	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	7422	 73.125	 22.385	 57.26	 -12.49	 1.0	 135.0	 1	 112.5	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	7422	 73.125	 22.385	 57.26	 -12.49	 1.0	 135.0	 1	 112.5	 33.75	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 112.5;
	7422	 124.215	 38.03	 97.27	 -21.21	 1.0	 229.32	 1	 191.1	 57.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 191.1;
	7422	 111.93	 34.27	 87.65	 -19.11	 1.0	 206.64	 1	 172.2	 51.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.2;
	7422	 111.93	 34.27	 87.65	 -19.11	 1.0	 206.64	 1	 172.2	 51.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.2;
	7422	 111.93	 34.27	 87.65	 -19.11	 1.0	 206.64	 1	 172.2	 51.66	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.2;
	7428	 65.34	 20.0	 51.16	 -11.16	 1.0	 120.62	 1	 100.52	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.52;
	7428	 84.5	 25.87	 66.17	 -14.43	 1.0	 156.0	 1	 130.0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	7428	 84.5	 25.87	 66.17	 -14.43	 1.0	 156.0	 1	 130.0	 39.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 130.0;
	7428	 65.34	 20.0	 51.16	 -11.16	 1.0	 120.62	 1	 100.52	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.52;
	7428	 65.34	 20.0	 51.16	 -11.16	 1.0	 120.62	 1	 100.52	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.52;
	7428	 65.34	 20.0	 51.16	 -11.16	 1.0	 120.62	 1	 100.52	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.52;
	7428	 65.34	 20.0	 51.16	 -11.16	 1.0	 120.62	 1	 100.52	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.52;
	7428	 65.34	 20.0	 51.16	 -11.16	 1.0	 120.62	 1	 100.52	 30.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 100.52;
	7428	 48.75	 14.92	 38.17	 -8.33	 1.0	 90.0	 1	 75.0	 22.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 75.0;
	7428	 52.65	 16.12	 41.23	 -8.99	 1.0	 97.2	 0	 81.0	 24.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 81.0;
	7428	 7.605	 2.33	 5.96	 -1.3	 1.0	 14.04	 1	 11.7	 3.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 11.7;
	8024	 33.0	 0.0	 0.0	 0.0	 1.0	 52.8	 1	 33.0	 33.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 44.0;
	8033	 152.705	 46.75	 119.58	 -26.08	 1.0	 281.91	 0	 234.93	 70.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.93;
	8034	 152.705	 46.75	 119.58	 -26.08	 1.0	 281.91	 0	 234.93	 70.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.93;
	8035	 152.705	 46.75	 119.58	 -26.08	 1.0	 281.91	 0	 234.93	 70.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.93;
	8036	 152.705	 46.75	 119.58	 -26.08	 1.0	 281.91	 0	 234.93	 70.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.93;
	8046	 112.235	 34.36	 87.89	 -19.17	 1.0	 207.2	 1	 172.67	 51.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.67;
	8047	 112.235	 34.36	 87.89	 -19.17	 1.0	 207.2	 0	 172.67	 51.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.67;
	8048	 112.235	 34.36	 87.89	 -19.17	 1.0	 207.2	 1	 172.67	 51.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.67;
	8049	 112.235	 34.36	 87.89	 -19.17	 1.0	 207.2	 1	 172.67	 51.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.67;
	8050	 112.235	 34.36	 87.89	 -19.17	 1.0	 207.2	 0	 172.67	 51.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.67;
	8051	 112.235	 34.36	 87.89	 -19.17	 1.0	 207.2	 0	 172.67	 51.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 172.67;
	8060	 385.71	 102.065	 276.52	 -72.39	 1.0	 712.08	 0	 593.4	 178.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 593.4;
	8061	 385.71	 102.065	 276.52	 -72.39	 1.0	 712.08	 0	 593.4	 178.02	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 593.4;
	8070	 601.185	 159.08	 431.0	 -112.84	 1.0	 1109.88	 0	 924.9	 277.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 924.9;
	8071	 601.185	 159.08	 431.0	 -112.84	 1.0	 1109.88	 1	 924.9	 277.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 924.9;
	8077	 152.685	 46.745	 119.56	 -26.07	 1.0	 281.88	 1	 234.9	 70.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.9;
	8078	 152.685	 46.745	 119.56	 -26.07	 1.0	 281.88	 1	 234.9	 70.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.9;
	8079	 152.685	 46.745	 119.56	 -26.07	 1.0	 281.88	 1	 234.9	 70.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.9;
	8080	 152.685	 46.745	 119.56	 -26.07	 1.0	 281.88	 1	 234.9	 70.47	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 234.9;
	8087	 583.505	 154.405	 418.33	 -109.52	 1.0	 1077.24	 0	 897.7	 269.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 897.7;
	8088	 583.505	 154.405	 418.33	 -109.52	 1.0	 1077.24	 1	 897.7	 269.31	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 897.7;
	8099	 85.5	 0.0	 0.0	 0.0	 1.0	 136.8	 1	 85.5	 85.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 114.0;
	8115	 6.5	 1.72	 4.66	 -1.22	 1.0	 12.0	 0	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 10.0;
	8116	 228.605	 60.49	 163.89	 -42.91	 1.0	 422.04	 0	 351.7	 105.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.7;
	8117	 228.605	 60.49	 163.89	 -42.91	 1.0	 422.04	 1	 351.7	 105.51	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 351.7;
	8129	 429.0	 113.52	 307.56	 -80.52	 1.0	 792.0	 1	 660.0	 198.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0;
	8130	 429.0	 113.52	 307.56	 -80.52	 1.0	 792.0	 1	 660.0	 198.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0;
	8131	 429.0	 113.52	 307.56	 -80.52	 1.0	 792.0	 1	 660.0	 198.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 660.0;
	8147	 2.6	 0.685	 1.86	 -0.49	 1.0	 4.8	 0	 4.0	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 4.0;
	8147	 155.545	 41.16	 111.51	 -29.19	 1.0	 287.16	 0	 239.3	 71.79	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 239.3;
	8152	 14.3	 4.38	 11.2	 -2.44	 1.0	 26.4	 0	 22.0	 6.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 22.0;
	8155	 113.49	 30.03	 81.36	 -21.3	 1.0	 209.52	 0	 174.6	 52.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.6;
	8155	 113.49	 30.03	 81.36	 -21.3	 1.0	 209.52	 1	 174.6	 52.38	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 174.6;
	8158	 68.25	 20.895	 53.44	 -11.65	 1.0	 126.0	 0	 105.0	 31.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 105.0;
	8158	 63.83	 19.54	 49.98	 -10.9	 1.0	 117.84	 0	 98.2	 29.46	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 98.2;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.641000	 1087.800000;
	2	 0.0	 0.0	 3	   0.001000	  18.641000	 1087.800000;
	2	 0.0	 0.0	 3	   0.001000	  17.464000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.464000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.464000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.910000	 868.200000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.046000	 608.400000;
	2	 0.0	 0.0	 3	   0.001000	  17.028000	 603.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.977000	 888.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.977000	 888.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.977000	 888.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.977000	 888.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.977000	 888.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.977000	 888.200000;
	2	 0.0	 0.0	 3	   0.001000	  17.495000	 743.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.495000	 743.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.495000	 743.250000;
	2	 0.0	 0.0	 3	   0.001000	  18.448000	 1029.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  27.494000	 1187.700000;
	2	 0.0	 0.0	 3	   0.002000	  27.494000	 1187.700000;
	2	 0.0	 0.0	 3	   0.002000	  27.494000	 1187.700000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.989000	 724.990000;
	2	 0.0	 0.0	 3	   0.001000	  17.394000	 850.010000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.268000	 236.160000;
	2	 0.0	 0.0	 3	   0.002000	  17.268000	 1398.510000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.033000	 630.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.033000	 630.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.126000	 660.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  26.597000	 1001.590000;
	2	 0.0	 0.0	 3	   0.002000	  26.597000	 1001.590000;
	2	 0.0	 0.0	 3	   0.002000	  26.597000	 1001.590000;
	2	 0.0	 0.0	 3	   0.001000	  17.482000	 877.080000;
	2	 0.0	 0.0	 3	   0.001000	  17.482000	 877.080000;
	2	 0.0	 0.0	 3	   0.001000	  17.482000	 877.080000;
	2	 0.0	 0.0	 3	   0.001000	  17.482000	 877.080000;
	2	 0.0	 0.0	 3	   0.001000	  17.482000	 877.080000;
	2	 0.0	 0.0	 3	   0.001000	  17.482000	 877.080000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.197000	 601.950000;
	2	 0.0	 0.0	 3	   0.002000	  19.693000	 734.100000;
	2	 0.0	 0.0	 3	   0.002000	  21.704000	 1365.860000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.478000	 676.950000;
	2	 0.0	 0.0	 3	   0.002000	  19.478000	 676.950000;
	2	 0.0	 0.0	 3	   0.002000	  19.478000	 676.950000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 1243.080000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 1349.570000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.730000	 666.300000;
	2	 0.0	 0.0	 3	   0.001000	  17.213000	 816.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.213000	 816.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.213000	 816.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.350000	 858.490000;
	2	 0.0	 0.0	 3	   0.001000	  17.350000	 858.490000;
	2	 0.0	 0.0	 3	   0.001000	  17.350000	 858.490000;
	2	 0.0	 0.0	 3	   0.001000	  16.743000	 670.500000;
	2	 0.0	 0.0	 3	   0.002000	  29.085000	 864.490000;
	2	 0.0	 0.0	 3	   0.002000	  29.085000	 864.490000;
	2	 0.0	 0.0	 3	   0.002000	  29.085000	 864.490000;
	2	 0.0	 0.0	 3	   0.001000	  17.694000	 965.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.694000	 965.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.694000	 965.100000;
	2	 0.0	 0.0	 3	   0.001000	  18.220000	 1128.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.040000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.630000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.200000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.750000;
	2	 0.0	 0.0	 3	   0.002000	  17.172000	 236.750000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  28.724000	 797.700000;
	2	 0.0	 0.0	 3	   0.002000	  28.724000	 797.700000;
	2	 0.0	 0.0	 3	   0.002000	  27.928000	 650.400000;
	2	 0.0	 0.0	 3	   0.002000	  27.928000	 650.400000;
	2	 0.0	 0.0	 3	   0.002000	  27.928000	 650.400000;
	2	 0.0	 0.0	 3	   0.002000	  27.928000	 650.400000;
	2	 0.0	 0.0	 3	   0.002000	  28.200000	 700.800000;
	2	 0.0	 0.0	 3	   0.002000	  28.190000	 699.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.473000	 896.660000;
	2	 0.0	 0.0	 3	   0.001000	  17.473000	 896.660000;
	2	 0.0	 0.0	 3	   0.001000	  17.473000	 896.660000;
	2	 0.0	 0.0	 3	   0.001000	  16.559000	 613.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.879000	 712.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.405000	 875.660000;
	2	 0.0	 0.0	 3	   0.001000	  16.632000	 636.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.811000	 691.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.566000	 615.600000;
	2	 0.0	 0.0	 3	   0.001000	  17.808000	 1000.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.808000	 1000.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.808000	 1000.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.405000	 875.660000;
	2	 0.0	 0.0	 3	   0.001000	  17.405000	 875.660000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.962000	 607.200000;
	2	 0.0	 0.0	 3	   0.001000	  15.177000	 606.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.186000	 609.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.529000	 1062.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.529000	 1062.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.529000	 1062.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.529000	 1062.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.529000	 1062.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.529000	 1062.700000;
	2	 0.0	 0.0	 3	   0.001000	  16.996000	 727.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.435000	 1076.030000;
	2	 0.0	 0.0	 3	   0.001000	  17.422000	 1076.030000;
	2	 0.0	 0.0	 3	   0.001000	  15.989000	 615.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.948000	 602.700000;
	2	 0.0	 0.0	 3	   0.001000	  17.987000	 1223.610000;
	2	 0.0	 0.0	 3	   0.001000	  17.987000	 1223.610000;
	2	 0.0	 0.0	 3	   0.001000	  17.987000	 1223.610000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  17.966000	 236.290000;
	2	 0.0	 0.0	 3	   0.002000	  17.966000	 236.150000;
	2	 0.0	 0.0	 3	   0.001000	  16.531000	 789.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.947000	 602.400000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.101000	 973.010000;
	2	 0.0	 0.0	 3	   0.001000	  17.101000	 973.010000;
	2	 0.0	 0.0	 3	   0.001000	  17.101000	 973.010000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   6.975000	 1485.460000;
	2	 0.0	 0.0	 3	   0.000000	   8.110000	 1209.050000;
	2	 0.0	 0.0	 3	   0.002000	  19.596000	 1001.590000;
	2	 0.0	 0.0	 3	   0.002000	  19.596000	 1001.590000;
	2	 0.0	 0.0	 3	   0.002000	  19.596000	 1001.590000;
	2	 0.0	 0.0	 3	   0.001000	  16.600000	 604.800000;
	2	 0.0	 0.0	 3	   0.001000	  17.143000	 772.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.143000	 772.500000;
	2	 0.0	 0.0	 3	   0.001000	  17.143000	 772.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.986000	 724.050000;
	2	 0.0	 0.0	 3	   0.001000	  18.839000	 1638.810000;
	2	 0.0	 0.0	 3	   0.001000	  18.839000	 1638.810000;
	2	 0.0	 0.0	 3	   0.002000	  19.570000	 994.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.570000	 994.200000;
	2	 0.0	 0.0	 3	   0.002000	  19.570000	 994.200000;
	2	 0.0	 0.0	 3	   0.001000	  16.420000	 1026.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.420000	 1026.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.420000	 1026.100000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1542.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.988000	 615.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.936000	 919.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.936000	 919.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.936000	 919.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.936000	 919.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.936000	 919.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.936000	 919.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.087000	 913.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.087000	 913.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.357000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.357000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.357000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.357000	 734.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.510000	 783.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.510000	 783.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.510000	 783.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.495000	 778.200000;
	2	 0.0	 0.0	 3	   0.001000	  16.495000	 778.200000;
	2	 0.0	 0.0	 3	   0.001000	  15.998000	 618.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.955000	 604.800000;
	2	 0.0	 0.0	 3	   0.002000	  19.710000	 1033.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.710000	 1033.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.710000	 1033.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.710000	 1033.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.710000	 1033.500000;
	2	 0.0	 0.0	 3	   0.002000	  19.710000	 1033.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.923000	 811.950000;
	2	 0.0	 0.0	 3	   0.002000	  18.923000	 811.950000;
	2	 0.0	 0.0	 3	   0.001000	  17.595000	 919.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.629000	 1023.670000;
	2	 0.0	 0.0	 3	   0.001000	  17.524000	 897.490000;
	2	 0.0	 0.0	 3	   0.001000	  17.524000	 897.490000;
	2	 0.0	 0.0	 3	   0.001000	  17.524000	 897.490000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.388000	 605.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.416000	 614.400000;
	2	 0.0	 0.0	 3	   0.001000	  15.393000	 606.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.631000	 686.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.631000	 686.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.631000	 686.100000;
	2	 0.0	 0.0	 3	   0.001000	  15.631000	 686.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.442000	 872.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.442000	 872.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.442000	 872.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.442000	 872.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.442000	 872.050000;
	2	 0.0	 0.0	 3	   0.001000	  17.442000	 872.050000;
	2	 0.0	 0.0	 3	   0.002000	  17.597000	 1319.960000;
	2	 0.0	 0.0	 3	   0.002000	  17.597000	 1319.960000;
	2	 0.0	 0.0	 3	   0.002000	  17.597000	 1319.960000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.855000	 690.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.855000	 690.750000;
	2	 0.0	 0.0	 3	   0.001000	  17.149000	 781.500000;
	2	 0.0	 0.0	 3	   0.002000	  17.597000	 1333.630000;
	2	 0.0	 0.0	 3	   0.002000	  17.597000	 1369.180000;
	2	 0.0	 0.0	 3	   0.001000	  15.411000	 612.600000;
	2	 0.0	 0.0	 3	   0.001000	  17.383000	 1349.570000;
	2	 0.0	 0.0	 3	   0.001000	  17.383000	 1349.570000;
	2	 0.0	 0.0	 3	   0.001000	  19.572000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.626000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.626000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.702000	 952.580000;
	2	 0.0	 0.0	 3	   0.001000	  17.702000	 952.580000;
	2	 0.0	 0.0	 3	   0.001000	  17.702000	 952.580000;
	2	 0.0	 0.0	 3	   0.001000	  17.702000	 952.580000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.648000	 691.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.197000	 874.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.716000	 1047.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.716000	 1047.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.716000	 1047.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.199000	 874.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.199000	 874.990000;
	2	 0.0	 0.0	 3	   0.001000	  16.199000	 874.990000;
	2	 0.0	 0.0	 3	   0.001000	  17.503000	 891.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.503000	 891.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.811000	 677.100000;
	2	 0.0	 0.0	 3	   0.001000	  17.809000	 985.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.562000	 909.340000;
	2	 0.0	 0.0	 3	   0.001000	  17.562000	 909.340000;
	2	 0.0	 0.0	 3	   0.001000	  17.562000	 909.340000;
	2	 0.0	 0.0	 3	   0.001000	  16.577000	 604.800000;
	2	 0.0	 0.0	 3	   0.001000	  17.762000	 970.880000;
	2	 0.0	 0.0	 3	   0.001000	  17.762000	 970.880000;
	2	 0.0	 0.0	 3	   0.001000	  17.762000	 970.880000;
	2	 0.0	 0.0	 3	   0.001000	  17.762000	 970.880000;
	2	 0.0	 0.0	 3	   0.001000	  16.620000	 618.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.811000	 677.250000;
	2	 0.0	 0.0	 3	   0.001000	  17.061000	 754.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.572000	 603.450000;
	2	 0.0	 0.0	 3	   0.001000	  16.584000	 606.900000;
	2	 0.0	 0.0	 3	   0.001000	  16.569000	 602.250000;
	2	 0.0	 0.0	 3	   0.001000	  16.581000	 606.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.592000	 609.600000;
	2	 0.0	 0.0	 3	   0.001000	  18.323000	 1144.500000;
	2	 0.0	 0.0	 3	   0.001000	  18.323000	 1144.500000;
	2	 0.0	 0.0	 3	   0.001000	  16.811000	 677.250000;
	2	 0.0	 0.0	 3	   0.001000	  15.681000	 844.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.681000	 844.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.681000	 844.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.681000	 844.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.681000	 844.500000;
	2	 0.0	 0.0	 3	   0.001000	  14.983000	 606.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.624000	 633.600000;
	2	 0.0	 0.0	 3	   0.001000	  16.745000	 671.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.745000	 671.100000;
	2	 0.0	 0.0	 3	   0.001000	  16.974000	 742.200000;
	2	 0.0	 0.0	 3	   0.001000	  16.531000	 604.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.428000	 882.670000;
	2	 0.0	 0.0	 3	   0.001000	  17.428000	 882.670000;
	2	 0.0	 0.0	 3	   0.001000	  17.072000	 772.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.072000	 772.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.072000	 772.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.072000	 772.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.072000	 772.350000;
	2	 0.0	 0.0	 3	   0.001000	  17.072000	 772.350000;
	2	 0.0	 0.0	 3	   0.001000	  15.969000	 942.970000;
	2	 0.0	 0.0	 3	   0.001000	  15.969000	 942.970000;
	2	 0.0	 0.0	 3	   0.001000	  15.969000	 942.970000;
	2	 0.0	 0.0	 3	   0.001000	  15.969000	 942.970000;
	2	 0.0	 0.0	 3	   0.000000	   7.063000	 1447.460000;
	2	 0.0	 0.0	 3	   0.000000	   7.445000	 1025.470000;
	2	 0.0	 0.0	 3	   0.001000	  15.624000	 825.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.190000	 676.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.190000	 676.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.826000	 894.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.826000	 894.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.826000	 894.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.826000	 894.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.826000	 894.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.826000	 894.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.982000	 605.550000;
	2	 0.0	 0.0	 3	   0.001000	  14.985000	 606.450000;
	2	 0.0	 0.0	 3	   0.001000	  15.037000	 624.450000;
	2	 0.0	 0.0	 3	   0.001000	  15.872000	 909.830000;
	2	 0.0	 0.0	 3	   0.001000	  15.872000	 909.830000;
	2	 0.0	 0.0	 3	   0.001000	  15.872000	 909.830000;
	2	 0.0	 0.0	 3	   0.001000	  15.872000	 909.830000;
	2	 0.0	 0.0	 3	   0.001000	  16.636000	 1171.050000;
	2	 0.0	 0.0	 3	   0.001000	  15.225000	 688.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.225000	 688.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.225000	 688.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.225000	 688.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.011000	 615.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.451000	 765.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.451000	 765.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.451000	 765.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.451000	 765.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.451000	 765.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.451000	 765.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.351000	 731.580000;
	2	 0.0	 0.0	 3	   0.001000	  15.351000	 731.580000;
	2	 0.0	 0.0	 3	   0.001000	  16.505000	 1126.310000;
	2	 0.0	 0.0	 3	   0.001000	  14.996000	 610.350000;
	2	 0.0	 0.0	 3	   0.001000	  15.177000	 672.000000;
	2	 0.0	 0.0	 3	   0.001000	  14.988000	 607.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.119000	 652.500000;
	2	 0.0	 0.0	 3	   0.001000	  14.999000	 611.250000;
	2	 0.0	 0.0	 3	   0.001000	  15.979000	 946.420000;
	2	 0.0	 0.0	 3	   0.001000	  15.979000	 946.420000;
	2	 0.0	 0.0	 3	   0.001000	  15.979000	 946.420000;
	2	 0.0	 0.0	 3	   0.001000	  15.979000	 946.420000;
	2	 0.0	 0.0	 3	   0.001000	  14.983000	 606.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.322000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  18.322000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.749000	 867.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.749000	 867.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.749000	 867.750000;
	2	 0.0	 0.0	 3	   0.001000	  16.302000	 1056.900000;
	2	 0.0	 0.0	 3	   0.001000	  15.364000	 735.960000;
	2	 0.0	 0.0	 3	   0.001000	  15.364000	 735.960000;
	2	 0.0	 0.0	 3	   0.001000	  15.364000	 735.960000;
	2	 0.0	 0.0	 3	   0.001000	  15.761000	 871.920000;
	2	 0.0	 0.0	 3	   0.001000	  15.079000	 638.550000;
	2	 0.0	 0.0	 3	   0.001000	  15.032000	 622.500000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.984000	 745.020000;
	2	 0.0	 0.0	 3	   0.001000	  16.984000	 745.020000;
	2	 0.0	 0.0	 3	   0.001000	  16.984000	 745.020000;
	2	 0.0	 0.0	 3	   0.001000	  16.984000	 745.020000;
	2	 0.0	 0.0	 3	   0.001000	  17.452000	 890.050000;
	2	 0.0	 0.0	 3	   0.001000	  15.512000	 786.720000;
	2	 0.0	 0.0	 3	   0.001000	  15.512000	 786.720000;
	2	 0.0	 0.0	 3	   0.001000	  15.512000	 786.720000;
	2	 0.0	 0.0	 3	   0.001000	  15.512000	 786.720000;
	2	 0.0	 0.0	 3	   0.001000	  17.009000	 752.850000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 236.130000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1264.890000;
	2	 0.0	 0.0	 3	   0.001000	  16.343000	 1070.740000;
	2	 0.0	 0.0	 3	   0.001000	  16.343000	 1070.740000;
	2	 0.0	 0.0	 3	   0.001000	  16.343000	 1070.740000;
	2	 0.0	 0.0	 3	   0.001000	  16.343000	 1070.740000;
	2	 0.0	 0.0	 3	   0.001000	  17.967000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.967000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.967000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.967000	 3859.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.037000	 624.450000;
	2	 0.0	 0.0	 3	   0.001000	  15.954000	 937.800000;
	2	 0.0	 0.0	 3	   0.001000	  15.954000	 937.800000;
	2	 0.0	 0.0	 3	   0.001000	  15.954000	 937.800000;
	2	 0.0	 0.0	 3	   0.001000	  15.416000	 754.050000;
	2	 0.0	 0.0	 3	   0.001000	  15.437000	 760.910000;
	2	 0.0	 0.0	 3	   0.001000	  15.437000	 760.910000;
	2	 0.0	 0.0	 3	   0.001000	  15.437000	 760.910000;
	2	 0.0	 0.0	 3	   0.001000	  15.437000	 760.910000;
	2	 0.0	 0.0	 3	   0.001000	  15.437000	 760.910000;
	2	 0.0	 0.0	 3	   0.001000	  15.437000	 760.910000;
	2	 0.0	 0.0	 3	   0.001000	  15.772000	 875.490000;
	2	 0.0	 0.0	 3	   0.001000	  15.772000	 875.490000;
	2	 0.0	 0.0	 3	   0.001000	  15.772000	 875.490000;
	2	 0.0	 0.0	 3	   0.001000	  15.772000	 875.490000;
	2	 0.0	 0.0	 3	   0.001000	  15.772000	 875.490000;
	2	 0.0	 0.0	 3	   0.001000	  17.347000	 2926.930000;
	2	 0.0	 0.0	 3	   0.001000	  15.282000	 708.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.282000	 708.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.282000	 708.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.282000	 708.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.598000	 816.000000;
	2	 0.0	 0.0	 3	   0.001000	  16.924000	 1356.090000;
	2	 0.0	 0.0	 3	   0.001000	  16.821000	 694.650000;
	2	 0.0	 0.0	 3	   0.001000	  18.016000	 1065.000000;
	2	 0.0	 0.0	 3	   0.001000	  17.011000	 753.600000;
	2	 0.0	 0.0	 3	   0.001000	  15.353000	 732.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.353000	 732.300000;
	2	 0.0	 0.0	 3	   0.001000	  14.996000	 610.200000;
	2	 0.0	 0.0	 3	   0.001000	  15.721000	 858.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.721000	 858.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.459000	 768.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.459000	 768.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.459000	 768.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.459000	 768.750000;
	2	 0.0	 0.0	 3	   0.001000	  15.804000	 886.650000;
	2	 0.0	 0.0	 3	   0.001000	  15.721000	 858.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.721000	 858.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.721000	 858.300000;
	2	 0.0	 0.0	 3	   0.001000	  15.407000	 750.780000;
	2	 0.0	 0.0	 3	   0.001000	  15.536000	 795.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.536000	 795.000000;
	2	 0.0	 0.0	 3	   0.001000	  15.407000	 750.780000;
	2	 0.0	 0.0	 3	   0.001000	  15.407000	 750.780000;
	2	 0.0	 0.0	 3	   0.001000	  15.407000	 750.780000;
	2	 0.0	 0.0	 3	   0.001000	  15.407000	 750.780000;
	2	 0.0	 0.0	 3	   0.001000	  15.407000	 750.780000;
	2	 0.0	 0.0	 3	   0.001000	  15.295000	 712.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.321000	 721.500000;
	2	 0.0	 0.0	 3	   0.001000	  15.017000	 617.550000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.422000	 952.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.422000	 952.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.422000	 952.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.422000	 952.400000;
	2	 0.0	 0.0	 3	   0.002000	  19.090000	 859.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.090000	 859.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.090000	 859.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.090000	 859.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.090000	 859.010000;
	2	 0.0	 0.0	 3	   0.002000	  19.090000	 859.010000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1335.030000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1335.030000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1501.240000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1501.240000;
	2	 0.0	 0.0	 3	   0.001000	  16.202000	 952.350000;
	2	 0.0	 0.0	 3	   0.001000	  16.202000	 952.350000;
	2	 0.0	 0.0	 3	   0.001000	  16.202000	 952.350000;
	2	 0.0	 0.0	 3	   0.001000	  16.202000	 952.350000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1487.600000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 1487.600000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  21.838000	 236.270000;
	2	 0.0	 0.0	 3	   0.002000	  21.838000	 1213.850000;
	2	 0.0	 0.0	 3	   0.002000	  21.838000	 1213.850000;
	2	 0.0	 0.0	 3	   0.002000	  16.843000	 1368.420000;
	2	 0.0	 0.0	 3	   0.002000	  16.843000	 1368.420000;
	2	 0.0	 0.0	 3	   0.002000	  16.843000	 1368.420000;
	2	 0.0	 0.0	 3	   0.002000	  21.838000	 236.110000;
	2	 0.0	 0.0	 3	   0.002000	  21.838000	 953.960000;
	2	 0.0	 0.0	 3	   0.002000	  18.287000	 633.000000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 802.560000;
	2	 0.0	 0.0	 3	   0.002000	  18.671000	 802.560000;
	2	 0.0	 0.0	 3	   0.002000	  18.730000	 757.500000;
	2	 0.0	 0.0	 3	   0.002000	  18.693000	 747.300000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	1001	 1064	 0.00524	 0.0358	 0.00609	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1064	 0.00524	 0.0358	 0.00609	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1071	 0.00435	 0.02808	 0.00536	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1001	 1071	 0.00435	 0.02808	 0.00536	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1002	 1007	 0.07776	 0.46693	 0.06336	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 1002	 0.05552	 0.1357	 0.01777	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1004	 1003	 0.0045	 0.11582	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1022	 1003	 0.00485	 0.02012	 0.00341	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 1003	 0.01574	 0.03782	 0.00513	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1004	 3133	 0.0042	 0.03	 0.055	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 1005	 0.00602	 0.14707	 0.0	 42.0	 42.0	 42.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1025	 1005	 0.01842	 0.0821	 0.01204	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 1061	 0.00599	 0.02484	 0.00422	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 1005	 0.01711	 0.04181	 0.00548	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 1015	 0.06224	 0.37375	 0.05072	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 1007	 0.04803	 0.27434	 0.04123	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 1008	 0.00455	 0.09471	 0.0	 120.0	 120.0	 120.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1008	 1032	 0.04501	 0.11002	 0.01441	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 1069	 0.0083	 0.03628	 0.00553	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 1010	 0.00721	 0.3246	 0.0	 46.0	 46.0	 46.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1010	 1015	 0.04703	 0.28243	 0.03833	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 1030	 0.0616	 0.3699	 0.0502	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 1087	 0.04934	 0.20469	 0.03473	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 1012	 0.0571	 0.24977	 0.03804	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1013	 1031	 0.04509	 0.27078	 0.03675	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 1013	 0.00947	 0.06117	 0.01167	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1086	 1013	 0.079	 0.19311	 0.02529	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 1047	 0.03566	 0.14794	 0.0251	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 1083	 0.04105	 0.18293	 0.02682	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 1034	 0.01828	 0.10976	 0.01489	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 1016	 0.02773	 0.15837	 0.0238	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 1017	 0.03227	 0.07887	 0.01033	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 1029	 0.03244	 0.14188	 0.02161	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 1017	 0.00752	 0.03352	 0.00491	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 1017	 0.036	 0.156	 0.024	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1024	 1018	 0.01094	 0.06572	 0.00892	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1040	 0.04978	 0.20651	 0.03504	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1045	 0.01522	 0.0372	 0.00487	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1071	 0.0044	 0.028	 0.0054	 225.0	 225.0	 225.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 1019	 0.0044	 0.028	 0.0054	 225.0	 225.0	 225.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 1084	 0.03	 0.16	 0.025	 220.0	 220.0	 220.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 1020	 0.00327	 0.07812	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1025	 1020	 0.00828	 0.03434	 0.00583	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 1020	 0.01056	 0.06337	 0.0086	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 3059	 0.0189	 0.06	 0.006	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 3130	 0.00996	 0.06938	 0.01134	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 1022	 0.00535	 0.11733	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1022	 1028	 0.01433	 0.09253	 0.01765	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 1028	 0.01433	 0.09253	 0.01765	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1024	 1090	 0.01414	 0.06303	 0.00924	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 1025	 0.0042	 0.18046	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1027	 1045	 0.02505	 0.10957	 0.01669	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 1027	 0.03121	 0.0763	 0.00999	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 3109	 0.00428	 0.01875	 0.00286	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 1056	 0.02054	 0.11733	 0.01763	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 1038	 0.07404	 0.42285	 0.06354	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 1030	 0.06537	 0.37334	 0.0561	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 1032	 0.00283	 0.06758	 0.0	 170.0	 170.0	 170.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1032	 1036	 0.01956	 0.11746	 0.01594	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1038	 1032	 0.045	 0.11	 0.015	 155.0	 155.0	 155.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 1081	 0.003	 0.031	 0.059	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 3050	 0.0139	 0.136	 0.262	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 1034	 0.00438	 0.08496	 0.0	 130.0	 130.0	 130.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1067	 1034	 0.00795	 0.04771	 0.00647	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1088	 1036	 0.02065	 0.11793	 0.01772	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 1071	 0.00669	 0.04319	 0.00824	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 1038	 0.00201	 0.08591	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1082	 1038	 0.01115	 0.04969	 0.00729	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 1038	 0.01	 0.05	 0.007	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 1090	 0.02991	 0.13329	 0.01955	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 1041	 0.00419	 0.11123	 0.0	 145.0	 145.0	 145.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1043	 1041	 0.003	 0.12844	 0.0	 95.0	 95.0	 95.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1065	 1041	 0.00386	 0.02203	 0.00331	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 1067	 0.00393	 0.01722	 0.00262	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 3019	 0.03857	 0.17192	 0.02521	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3130	 1044	 0.02731	 0.19029	 0.03111	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 1064	 0.00545	 0.03794	 0.0062	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 1046	 0.03262	 0.14269	 0.02173	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1046	 3009	 0.05654	 0.23454	 0.0398	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 1047	 0.00335	 0.06576	 0.0	 390.0	 390.0	 390.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1049	 1047	 0.00276	 0.11783	 0.0	 390.0	 390.0	 390.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1050	 1047	 0.00313	 0.09941	 0.0	 124.0	 124.0	 124.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1051	 1047	 0.0056	 0.1283	 0.0	 117.0	 117.0	 117.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1052	 1047	 0.00368	 0.0826	 0.0	 110.0	 110.0	 110.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1053	 1047	 0.0023	 0.08808	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1047	 1085	 0.00947	 0.06117	 0.01167	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 1081	 0.003	 0.03	 0.06	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 1056	 0.02202	 0.09633	 0.01467	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 1054	 0.08737	 0.21357	 0.02796	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 1089	 0.04982	 0.12179	 0.01595	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 1056	 0.00315	 0.1312	 0.0	 160.0	 160.0	 160.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1056	 1061	 0.02267	 0.12946	 0.01945	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 1065	 0.02269	 0.12962	 0.01948	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 1058	 0.02655	 0.46187	 0.0	 33.0	 33.0	 33.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1060	 1058	 0.00894	 0.38854	 0.0	 27.0	 27.0	 27.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1069	 1058	 0.0074	 0.05155	 0.00843	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 1058	 0.0074	 0.05155	 0.00843	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 1087	 0.01573	 0.10956	 0.01791	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 1087	 0.01573	 0.10956	 0.01791	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 1061	 0.0163	 0.31787	 0.0	 29.0	 29.0	 29.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1063	 1061	 0.00567	 0.10409	 0.0	 260.0	 260.0	 260.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1061	 3042	 0.054	 0.18	 0.028	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 1065	 0.00508	 0.12315	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1088	 1068	 0.02962	 0.16921	 0.02543	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1070	 1069	 0.00297	 0.07	 0.0	 220.0	 220.0	 220.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1082	 1069	 0.02137	 0.0952	 0.01396	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 1071	 0.00529	 0.08551	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1073	 1071	 0.00499	 0.14254	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1074	 1071	 0.00575	 0.12453	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1075	 1071	 0.00373	 0.09967	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1076	 1071	 0.00141	 0.04937	 0.0	 230.0	 230.0	 230.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1077	 1071	 0.00641	 0.12047	 0.0	 230.0	 230.0	 230.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1078	 1071	 0.00533	 0.19087	 0.0	 137.0	 137.0	 137.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1079	 1071	 0.00013	 0.046	 0.0	 2000.0	 2000.0	 2000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1080	 1071	 0.01206	 0.20208	 0.0	 136.0	 136.0	 136.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1081	 1071	 0.00167	 0.0665	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3048	 1079	 0.0013	 0.015	 1.02	 2300.0	 2300.0	 2300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 1079	 0.0013	 0.015	 1.02	 2300.0	 2300.0	 2300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1081	 3058	 0.0091	 0.089	 0.171	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 3130	 0.02049	 0.09131	 0.01339	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 1086	 0.03392	 0.14838	 0.0226	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 1085	 0.02018	 0.13786	 0.02346	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 1091	 0.0389	 0.17144	 0.0798	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1091	 2048	 0.02193	 0.09667	 0.045	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 1091	 0.00554	 0.02443	 0.01137	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 2001	 0.00839	 0.03697	 0.01721	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 2001	 0.00955	 0.04062	 0.02032	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 2002	 0.0003	 0.01986	 0.0	 981.0	 981.0	 981.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2004	 2002	 0.00022	 0.01466	 0.0	 635.0	 635.0	 635.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2005	 2002	 0.00033	 0.01714	 0.0	 645.0	 645.0	 645.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2006	 2002	 0.00036	 0.02679	 0.0	 636.0	 636.0	 636.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2021	 2002	 0.00097	 0.01175	 0.78032	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 2101	 0.00031	 0.0037	 0.24573	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 2003	 0.00353	 0.02067	 0.01032	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2003	 2047	 0.0013	 0.0099	 0.0052	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 2114	 0.00888	 0.05207	 0.026	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2007	 2122	 0.00861	 0.03661	 0.01831	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 2008	 0.02253	 0.09931	 0.04623	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 2052	 0.01877	 0.08271	 0.0385	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 2049	 0.01224	 0.07176	 0.03583	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 2082	 0.00735	 0.03126	 0.01563	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 2009	 0.00725	 0.03084	 0.01542	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 2010	 0.02439	 0.10748	 0.05003	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 2079	 0.02061	 0.09083	 0.04228	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 2091	 0.02461	 0.10467	 0.05235	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2011	 0.00044	 0.03546	 0.0	 461.0	 461.0	 461.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2013	 2011	 0.00043	 0.02897	 0.0	 412.0	 412.0	 412.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2127	 2011	 0.00108	 0.01307	 0.86827	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2041	 0.01245	 0.05297	 0.02649	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2052	 0.02008	 0.08851	 0.0412	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2093	 2012	 0.01029	 0.04536	 0.02111	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2012	 2123	 0.00995	 0.0423	 0.02115	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2014	 2029	 0.01859	 0.07908	 0.03955	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 2037	 0.00862	 0.03799	 0.01769	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 2015	 0.00961	 0.04237	 0.01972	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 2016	 0.00593	 0.02614	 0.01217	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 2016	 0.0084	 0.03705	 0.01725	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 2017	 0.00048	 0.05045	 0.0	 271.0	 271.0	 271.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2019	 2017	 0.0002	 0.01182	 0.0	 454.0	 454.0	 454.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2017	 2096	 0.00253	 0.03068	 2.03836	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 2127	 0.00089	 0.01081	 0.71846	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 2093	 0.01163	 0.05125	 0.02386	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 2020	 0.00097	 0.00548	 0.00295	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 2020	 0.00102	 0.00744	 0.00422	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 2021	 0.00034	 0.01888	 0.0	 867.0	 867.0	 867.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2023	 2021	 0.00054	 0.03406	 0.0	 319.0	 319.0	 319.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2024	 2021	 0.00036	 0.02425	 0.0	 391.0	 391.0	 391.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2113	 2021	 0.0001	 0.00124	 0.08207	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2022	 2040	 0.02207	 0.09391	 0.04697	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 2022	 0.00558	 0.03156	 0.01697	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2025	 2055	 0.0023	 0.01016	 0.00473	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 2025	 0.00317	 0.014	 0.00651	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 2026	 0.02475	 0.10526	 0.05264	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 2026	 0.01207	 0.05318	 0.02475	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 2090	 0.01692	 0.07455	 0.0347	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2028	 2045	 0.00363	 0.02129	 0.01063	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2028	 2109	 0.01026	 0.0452	 0.02104	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 2028	 0.00369	 0.02161	 0.01079	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 2106	 0.0118	 0.05199	 0.0242	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2122	 2030	 0.00737	 0.0432	 0.02157	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 2048	 0.02398	 0.10567	 0.04919	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 2087	 0.02177	 0.09259	 0.04631	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2032	 2114	 0.01097	 0.04834	 0.0225	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2122	 2032	 0.01414	 0.06232	 0.02901	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 2033	 0.00522	 0.02298	 0.0107	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 5288	 0.00925	 0.03935	 0.01968	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 2043	 0.00439	 0.01867	 0.00934	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 2034	 0.00468	 0.01993	 0.00997	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 2066	 0.01411	 0.08272	 0.04131	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 2091	 0.01863	 0.10528	 0.05663	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 2055	 0.00216	 0.0092	 0.0046	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 2082	 0.00236	 0.01003	 0.00502	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2037	 2065	 0.00415	 0.02434	 0.01216	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 2037	 0.00307	 0.01798	 0.00898	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 2038	 0.00639	 0.03748	 0.01871	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 2086	 0.00845	 0.03725	 0.01734	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 2039	 0.00569	 0.03334	 0.01665	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 5455	 0.00371	 0.02173	 0.01085	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 2114	 0.02335	 0.09932	 0.04967	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 2040	 0.00894	 0.03938	 0.01833	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2042	 2041	 0.00216	 0.07846	 0.0	 95.0	 95.0	 95.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2041	 2058	 0.0136	 0.05786	 0.02893	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 2044	 0.01021	 0.04497	 0.02093	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2044	 2102	 0.01465	 0.06453	 0.03004	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2063	 2046	 0.00363	 0.02051	 0.01103	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 2047	 0.00376	 0.02203	 0.011	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 2048	 0.02944	 0.12973	 0.06039	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2049	 2061	 0.00912	 0.05349	 0.02671	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2090	 2050	 0.02377	 0.10475	 0.04876	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2050	 5268	 0.01273	 0.05412	 0.02707	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2080	 2051	 0.00691	 0.03904	 0.021	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 2112	 0.00873	 0.04934	 0.02654	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5285	 2053	 0.00757	 0.0428	 0.02302	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2053	 5362	 0.01118	 0.06552	 0.03272	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2055	 2054	 0.00016	 0.00742	 0.0	 1095.0	 1095.0	 1095.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2055	 2054	 0.00016	 0.00742	 0.0	 1095.0	 1095.0	 1095.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2056	 2054	 0.00069	 0.06323	 0.0	 227.0	 227.0	 227.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2057	 2054	 0.00025	 0.01321	 0.0	 1001.0	 1001.0	 1001.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2127	 2054	 0.033	 0.043	 2.3	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 5236	 0.0008	 0.00971	 0.64507	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 2058	 0.00537	 0.10085	 0.0	 99.0	 99.0	 99.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2123	 2058	 0.00524	 0.0231	 0.01075	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 2064	 0.00608	 0.03562	 0.01779	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 2060	 0.00421	 0.02468	 0.01232	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 2061	 0.0016	 0.04103	 0.0	 223.0	 223.0	 223.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2092	 2063	 0.00409	 0.02397	 0.01197	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 2065	 0.00712	 0.04025	 0.02165	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 2066	 0.01087	 0.06371	 0.03181	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 2067	 0.00995	 0.05832	 0.02912	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 2088	 0.00135	 0.00792	 0.00396	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 2072	 0.00557	 0.03267	 0.01631	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2069	 5074	 0.0102	 0.04493	 0.02092	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2071	 2070	 0.00129	 0.05708	 0.0	 249.0	 249.0	 249.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2088	 2070	 0.00235	 0.01376	 0.00687	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2070	 5237	 0.00727	 0.03095	 0.01548	 245.0	 245.0	 245.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2072	 2102	 0.0084	 0.04925	 0.0246	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 2073	 0.00225	 0.04467	 0.0	 144.0	 144.0	 144.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2076	 2073	 0.00347	 0.07389	 0.0	 64.0	 64.0	 64.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2087	 2073	 0.01908	 0.08409	 0.03914	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 3079	 0.01377	 0.08073	 0.04031	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 2074	 0.01303	 0.29308	 0.0	 19.0	 19.0	 19.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3115	 2074	 0.0052	 0.02972	 0.00447	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 2077	 0.002	 0.07139	 0.0	 189.0	 189.0	 189.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2077	 2110	 0.00218	 0.01278	 0.00638	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2077	 2133	 0.00307	 0.01798	 0.00898	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 2080	 0.01338	 0.05896	 0.02745	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 2080	 0.01236	 0.07244	 0.03618	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 2129	 0.01257	 0.05349	 0.02675	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 2082	 0.00401	 0.14309	 0.0	 91.0	 91.0	 91.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2084	 2082	 0.00414	 0.18022	 0.0	 82.0	 82.0	 82.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2085	 2082	 0.00156	 0.07238	 0.0	 98.0	 98.0	 98.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2089	 2088	 0.00259	 0.12398	 0.0	 84.0	 84.0	 84.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2090	 2121	 0.01763	 0.075	 0.03751	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2094	 2093	 0.0017	 0.10337	 0.0	 88.0	 88.0	 88.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2095	 2093	 0.00149	 0.05101	 0.0	 164.0	 164.0	 164.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2097	 2096	 0.00012	 0.00729	 0.0	 836.0	 836.0	 836.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2099	 2096	 0.0003	 0.03477	 0.0	 237.0	 237.0	 237.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2100	 2096	 0.00075	 0.04235	 0.0	 386.0	 386.0	 386.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2098	 2097	 0.00183	 0.13303	 0.0	 146.0	 146.0	 146.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2097	 3096	 0.00546	 0.05679	 0.19351	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 2101	 0.00013	 0.00916	 0.0	 1072.0	 1072.0	 1072.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2103	 2101	 0.00019	 0.01252	 0.0	 542.0	 542.0	 542.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2104	 2101	 0.00022	 0.0164	 0.0	 542.0	 542.0	 542.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2105	 2101	 0.00055	 0.02588	 0.0	 544.0	 544.0	 544.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2101	 5083	 0.00059	 0.00721	 0.47876	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2102	 2107	 0.00156	 0.01139	 0.00646	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2124	 2106	 0.00485	 0.02842	 0.01419	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2106	 2129	 0.00424	 0.01803	 0.00902	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2107	 2125	 0.0109	 0.06393	 0.03192	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2130	 2108	 0.00945	 0.04022	 0.02012	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5472	 2108	 0.01619	 0.07138	 0.03323	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 5187	 0.01319	 0.05811	 0.02705	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 5472	 0.02196	 0.09676	 0.04504	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 2113	 0.00013	 0.00965	 0.0	 924.0	 924.0	 924.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2115	 2113	 0.00077	 0.03843	 0.0	 410.0	 410.0	 410.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2116	 2113	 0.00027	 0.02003	 0.0	 402.0	 402.0	 402.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2117	 2113	 0.00043	 0.0445	 0.0	 404.0	 404.0	 404.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2118	 2113	 0.00064	 0.04928	 0.0	 391.0	 391.0	 391.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2119	 2113	 0.00034	 0.02438	 0.0	 389.0	 389.0	 389.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2120	 2113	 0.0007	 0.04736	 0.0	 392.0	 392.0	 392.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5049	 2113	 0.00053	 0.01087	 0.75821	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2113	 8126	 0.00058	 0.01198	 0.83533	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 2124	 0.00519	 0.02933	 0.01578	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 5078	 0.00981	 0.04323	 0.02012	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 5215	 0.00341	 0.01999	 0.00998	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 5220	 0.0038	 0.02226	 0.01112	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 2127	 0.00066	 0.06242	 0.0	 308.0	 308.0	 308.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2127	 5164	 0.01	 0.1	 3.0	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 5141	 0.00446	 0.02617	 0.01307	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2131	 2130	 0.00178	 0.07699	 0.0	 214.0	 214.0	 214.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2132	 2131	 0.00583	 0.25242	 0.0	 24.0	 24.0	 24.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3021	 2131	 0.02143	 0.09374	 0.01428	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 3001	 0.00103	 0.06934	 0.0	 171.0	 171.0	 171.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3002	 3001	 0.00103	 0.06934	 0.0	 171.0	 171.0	 171.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3001	 6177	 0.00653	 0.06378	 0.12272	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 3001	 0.00639	 0.04566	 0.08324	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 3107	 0.01283	 0.07327	 0.01101	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 3003	 0.00324	 0.10104	 0.0	 51.0	 51.0	 51.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3003	 3103	 0.01071	 0.04441	 0.00754	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 3003	 0.00248	 0.01085	 0.00165	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3005	 3052	 0.07286	 0.17811	 0.02332	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 3005	 0.0221	 0.13272	 0.01801	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 3049	 0.01784	 0.0795	 0.01166	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3145	 3006	 0.01721	 0.07139	 0.01211	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 3013	 0.0282	 0.12334	 0.01878	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 3137	 0.00869	 0.03873	 0.00568	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 3145	 0.01571	 0.08971	 0.01348	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 3036	 0.03575	 0.14831	 0.02517	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3140	 3008	 0.0278	 0.12389	 0.01817	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3143	 3008	 0.04389	 0.1073	 0.01405	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3009	 3024	 0.0285	 0.17117	 0.02323	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3146	 3009	 0.03539	 0.14683	 0.02492	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3010	 3076	 0.02704	 0.16239	 0.02204	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3093	 3010	 0.02325	 0.1396	 0.01894	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 3012	 0.01814	 0.1036	 0.01557	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3011	 3124	 0.02409	 0.1376	 0.02068	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3012	 6226	 0.01815	 0.10369	 0.01558	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3013	 3077	 0.00833	 0.05	 0.00679	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 3124	 0.04522	 0.19779	 0.03012	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 3014	 0.01229	 0.05481	 0.00804	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 3121	 0.00527	 0.03162	 0.00429	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 3127	 0.01148	 0.0656	 0.00986	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3015	 3128	 0.00752	 0.04513	 0.00612	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3017	 3016	 0.00189	 0.07277	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3016	 3083	 0.00919	 0.05252	 0.00789	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 3103	 0.00883	 0.03662	 0.00621	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3016	 3131	 0.03765	 0.09203	 0.01205	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 3016	 0.02927	 0.12143	 0.02061	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3019	 3018	 0.00052	 0.03897	 0.0	 142.2	 142.2	 142.2	 1.0	 0.0	 1	 -30.0	 30.0;
	3019	 3018	 0.00053	 0.03897	 0.0	 142.2	 142.2	 142.2	 1.0	 0.0	 1	 -30.0	 30.0;
	3020	 3018	 0.00133	 0.06779	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3018	 3050	 0.01395	 0.13638	 0.2624	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 3058	 0.0091	 0.0889	 0.17104	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 3019	 0.01378	 0.07869	 0.01182	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 3019	 0.01054	 0.07345	 0.01201	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 3019	 0.01054	 0.07345	 0.01201	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 3021	 0.01086	 0.07565	 0.01237	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5397	 3021	 0.02082	 0.09277	 0.0136	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 3022	 0.06611	 0.16158	 0.02116	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 3022	 0.01233	 0.07039	 0.01058	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3049	 3023	 0.01656	 0.0738	 0.01082	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 3067	 0.09726	 0.23774	 0.03113	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 3115	 0.03509	 0.21073	 0.0286	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 3025	 0.05582	 0.13643	 0.01786	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 3036	 0.0401	 0.16637	 0.02823	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 3101	 0.02809	 0.12288	 0.01871	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 3026	 0.00258	 0.11301	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3028	 3026	 0.00048	 0.03228	 0.0	 270.0	 270.0	 270.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3026	 5395	 0.00227	 0.01625	 0.02963	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3027	 3102	 0.02467	 0.05926	 0.00804	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3147	 3029	 0.01187	 0.06781	 0.01019	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3029	 5241	 0.01232	 0.05113	 0.00868	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3030	 3072	 0.00885	 0.05057	 0.0076	 190.0	 190.0	 190.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3114	 3030	 0.02646	 0.10977	 0.01863	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 3031	 0.03288	 0.08037	 0.01052	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 3070	 0.03731	 0.09121	 0.01194	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3031	 3140	 0.02073	 0.09067	 0.01381	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3032	 3094	 0.00583	 0.04065	 0.00664	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 3032	 0.00703	 0.03076	 0.00468	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 3033	 0.00593	 0.17201	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3136	 3033	 0.00696	 0.01672	 0.00227	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 3066	 0.08317	 0.2033	 0.02662	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3036	 3066	 0.03434	 0.19612	 0.02947	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 3037	 0.00411	 0.1621	 0.0	 82.0	 82.0	 82.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3039	 3037	 0.00051	 0.03079	 0.0	 280.0	 280.0	 280.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3078	 3037	 0.00125	 0.01223	 0.02354	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 3088	 0.00895	 0.08746	 0.16828	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 3080	 0.00768	 0.04384	 0.00659	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 3038	 0.00471	 0.02825	 0.00383	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3072	 3040	 0.02206	 0.09153	 0.01553	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3139	 3040	 0.01922	 0.08563	 0.01256	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 3041	 0.00322	 0.18545	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3043	 3041	 0.00205	 0.14897	 0.0	 57.0	 57.0	 57.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3044	 3041	 0.00154	 0.10487	 0.0	 112.0	 112.0	 112.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3045	 3041	 0.00096	 0.05895	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3041	 3046	 0.0031	 0.02	 0.05832	 820.0	 820.0	 820.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 3058	 0.00347	 0.02481	 0.04523	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 3064	 0.02146	 0.09562	 0.01402	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3111	 3042	 0.01081	 0.04816	 0.00706	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 3046	 0.00338	 0.14142	 0.0	 290.0	 290.0	 290.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3048	 3046	 0.00027	 0.016	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3048	 3046	 0.00027	 0.016	 0.0	 1500.0	 1500.0	 1500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3046	 3078	 0.00316	 0.0309	 0.05946	 820.0	 820.0	 820.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 3046	 0.00313	 0.03062	 0.05891	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 3064	 0.01369	 0.045	 0.00446	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3129	 3047	 0.02116	 0.05173	 0.00677	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 5045	 0.0011	 0.013	 0.63	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 5045	 0.0011	 0.013	 0.63	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 5120	 0.0013	 0.015	 1.02	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3048	 5394	 0.0013	 0.015	 1.02	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 3050	 0.00147	 0.09038	 0.0	 122.0	 122.0	 122.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3051	 3050	 0.00147	 0.09038	 0.0	 122.0	 122.0	 122.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4014	 3050	 0.01665	 0.16272	 0.31309	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 3093	 0.03727	 0.22382	 0.03037	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 3107	 0.01629	 0.09779	 0.01327	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3054	 3053	 0.00422	 0.16643	 0.0	 103.0	 103.0	 103.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3055	 3053	 0.00065	 0.02944	 0.0	 330.0	 330.0	 330.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3056	 3053	 0.00099	 0.0556	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3057	 3053	 0.00152	 0.05399	 0.0	 220.0	 220.0	 220.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3058	 3053	 0.003	 0.03	 0.06	 1000.0	 1000.0	 1000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3082	 3053	 0.00152	 0.0149	 0.02867	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 3088	 0.00333	 0.03466	 0.11812	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3053	 3088	 0.00333	 0.03466	 0.11812	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3059	 3058	 0.00178	 0.135	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3060	 3058	 0.00205	 0.114	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3061	 3058	 0.00132	 0.0814	 0.0	 155.0	 155.0	 155.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3062	 3058	 0.00115	 0.04113	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3063	 3058	 0.00159	 0.0585	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3059	 3111	 0.01912	 0.04672	 0.00612	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3065	 3064	 0.00856	 0.17814	 0.0	 110.0	 110.0	 110.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3064	 3141	 0.01218	 0.05051	 0.00857	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3066	 3142	 0.03037	 0.17347	 0.02607	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3068	 3067	 0.00117	 0.04824	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3067	 3070	 0.01175	 0.06712	 0.01009	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 3094	 0.01576	 0.07025	 0.0103	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 3141	 0.01175	 0.05234	 0.00768	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 3077	 0.01599	 0.09132	 0.01372	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 3140	 0.01354	 0.03311	 0.00434	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3071	 3070	 0.00337	 0.06343	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3070	 3131	 0.00569	 0.02535	 0.00372	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3142	 3072	 0.01958	 0.11184	 0.01681	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3074	 3073	 0.00148	 0.05882	 0.0	 115.0	 115.0	 115.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3073	 3076	 0.01657	 0.09953	 0.01351	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3123	 3073	 0.01212	 0.06921	 0.0104	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 4002	 0.03286	 0.18769	 0.0282	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3132	 3075	 0.07582	 0.18532	 0.02427	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 3138	 0.0747	 0.18259	 0.02391	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 3099	 0.00591	 0.03377	 0.00508	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3077	 3131	 0.01523	 0.06786	 0.00995	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3079	 3078	 0.00156	 0.05913	 0.0	 166.0	 166.0	 166.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 3078	 0.00202	 0.06066	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3078	 3133	 0.0042	 0.03003	 0.05475	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 3079	 0.00542	 0.12325	 0.0	 90.0	 90.0	 90.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3134	 3079	 0.01347	 0.05936	 0.02763	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 3082	 0.00172	 0.064	 0.0	 143.8	 143.8	 143.8	 1.0	 0.0	 1	 -30.0	 30.0;
	3084	 3082	 0.00171	 0.09998	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3137	 3083	 0.00824	 0.03605	 0.00549	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 3085	 0.00703	 0.2158	 0.0	 77.0	 77.0	 77.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3087	 3085	 0.00831	 0.19507	 0.0	 83.0	 83.0	 83.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3085	 3128	 0.0069	 0.01687	 0.00221	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 3088	 0.0005	 0.02042	 0.0	 411.0	 411.0	 411.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3092	 3088	 0.00152	 0.0846	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5395	 3088	 0.00237	 0.0246	 0.08383	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 3088	 0.00237	 0.0246	 0.08383	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3090	 3089	 0.00098	 0.02574	 0.0	 277.0	 277.0	 277.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3089	 5334	 0.0094	 0.05512	 0.02752	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 3090	 0.00127	 0.03474	 0.0	 268.0	 268.0	 268.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3102	 3091	 0.00402	 0.02416	 0.00328	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 3125	 0.01164	 0.02796	 0.00379	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3095	 3094	 0.00352	 0.16184	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3137	 3094	 0.018	 0.04399	 0.00576	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3097	 3096	 0.00239	 0.06155	 0.0	 162.0	 162.0	 162.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3097	 3096	 0.00239	 0.06155	 0.0	 162.0	 162.0	 162.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3098	 3096	 0.0034	 0.134	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3133	 3096	 0.0038	 0.02718	 0.04955	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3109	 3097	 0.00325	 0.02263	 0.0037	 340.0	 340.0	 340.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 3100	 0.01869	 0.08329	 0.01221	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3100	 3102	 0.015	 0.088	 0.012	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3125	 3100	 0.0162	 0.07086	 0.01079	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3104	 3101	 0.01395	 0.07966	 0.01197	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6360	 3101	 0.03353	 0.08195	 0.01073	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3105	 3104	 0.00965	 0.2233	 0.0	 60.0	 60.0	 60.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3106	 3104	 0.00703	 0.22022	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6156	 3104	 0.01785	 0.07953	 0.01166	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3108	 3147	 0.03432	 0.08389	 0.01098	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3108	 6065	 0.02034	 0.11619	 0.01746	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 3109	 0.00505	 0.2206	 0.0	 114.0	 114.0	 114.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3112	 3111	 0.01169	 0.25489	 0.0	 90.0	 90.0	 90.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3113	 3111	 0.00858	 0.25519	 0.0	 90.0	 90.0	 90.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 3115	 0.02115	 0.08773	 0.01489	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 3116	 0.00258	 0.11311	 0.0	 80.0	 80.0	 80.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3118	 3116	 0.00353	 0.07808	 0.0	 139.0	 139.0	 139.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3116	 3136	 0.01168	 0.07015	 0.00952	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 3119	 0.00248	 0.09082	 0.0	 46.0	 46.0	 46.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4002	 3119	 0.02215	 0.13302	 0.01805	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 3119	 0.027	 0.1542	 0.02317	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3122	 3121	 0.00565	 0.10546	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3121	 3129	 0.00954	 0.03956	 0.00671	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3121	 3145	 0.02936	 0.13085	 0.01919	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 3123	 0.05936	 0.14511	 0.019	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 3124	 0.018	 0.1	 0.016	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3126	 6059	 0.04241	 0.10187	 0.01382	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3141	 3127	 0.00595	 0.02651	 0.00389	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3132	 3144	 0.04225	 0.10327	 0.01352	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3134	 3133	 0.00391	 0.20153	 0.0	 83.0	 83.0	 83.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3135	 3134	 0.01014	 0.22418	 0.0	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3136	 3135	 0.00579	 0.2297	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	3138	 3142	 0.02534	 0.14471	 0.02175	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 3146	 0.03674	 0.1607	 0.02447	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3144	 3143	 0.04463	 0.10909	 0.01428	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 4040	 0.01209	 0.07809	 0.0149	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 4003	 0.00838	 0.05414	 0.01033	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 4003	 0.00838	 0.05414	 0.01033	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 4003	 0.01296	 0.09028	 0.01476	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 4004	 0.00169	 0.06285	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4014	 4004	 0.006	 0.06	 0.115	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 4004	 0.00456	 0.03255	 0.05934	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4022	 4005	 0.02734	 0.11343	 0.01925	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4114	 4005	 0.01989	 0.11362	 0.01707	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 4011	 0.0269	 0.11766	 0.01792	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 4197	 0.00624	 0.04344	 0.0071	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 4027	 0.00348	 0.02089	 0.00284	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 4034	 0.00873	 0.03892	 0.00571	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 4122	 0.00469	 0.02091	 0.00307	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 6112	 0.01363	 0.07782	 0.01169	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 4008	 0.01482	 0.06605	 0.00968	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 6346	 0.01174	 0.05229	 0.00767	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 4009	 0.00242	 0.06944	 0.0	 131.0	 131.0	 131.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4010	 4009	 0.00315	 0.06944	 0.0	 131.0	 131.0	 131.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4152	 4009	 0.00542	 0.03498	 0.00667	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 4009	 0.00542	 0.03498	 0.00667	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 4009	 0.00315	 0.02032	 0.00388	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 4009	 0.00315	 0.02032	 0.00388	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4011	 4185	 0.03112	 0.13615	 0.02073	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 4012	 0.01625	 0.09759	 0.01324	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 4103	 0.02485	 0.14192	 0.02133	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 4121	 0.01296	 0.07781	 0.01056	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 4171	 0.02502	 0.11152	 0.01635	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 4089	 0.01437	 0.09281	 0.01771	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 4013	 0.02623	 0.06413	 0.0084	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4013	 4122	 0.00312	 0.01784	 0.00268	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 4014	 0.00058	 0.03637	 0.0	 321.0	 321.0	 321.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4015	 4014	 0.00058	 0.03637	 0.0	 321.0	 321.0	 321.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4014	 4131	 0.01669	 0.11926	 0.21744	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 4015	 0.03538	 0.21243	 0.02883	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 4023	 0.01228	 0.07374	 0.01001	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 4016	 0.01709	 0.0709	 0.01203	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 4017	 0.00217	 0.01515	 0.00248	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 4017	 0.00217	 0.01515	 0.00248	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 4087	 0.00568	 0.02531	 0.00371	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 4123	 0.00492	 0.03426	 0.0056	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 4037	 0.01371	 0.06107	 0.00896	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 4018	 0.01472	 0.06561	 0.00962	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 4067	 0.00919	 0.06276	 0.01068	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 4067	 0.00919	 0.06276	 0.01068	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 4121	 0.02026	 0.04952	 0.00648	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 4020	 0.01602	 0.10945	 0.01862	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 4020	 0.01602	 0.10945	 0.01862	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4020	 4123	 0.00803	 0.03577	 0.00525	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 4020	 0.00418	 0.02912	 0.00476	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 4020	 0.00418	 0.02912	 0.00476	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4089	 4021	 0.01219	 0.05329	 0.00812	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4021	 4167	 0.00965	 0.04299	 0.0063	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4187	 4022	 0.02501	 0.10376	 0.01761	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 4023	 0.04152	 0.10149	 0.01329	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 4024	 0.0013	 0.04477	 0.0	 260.0	 260.0	 260.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4026	 4024	 0.00148	 0.06658	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4026	 4024	 0.00148	 0.06658	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4131	 4024	 0.00611	 0.05974	 0.11495	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 4024	 0.00754	 0.05386	 0.0982	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4025	 4117	 0.00307	 0.01981	 0.00378	 260.0	 260.0	 260.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 4088	 0.00276	 0.01883	 0.0032	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4027	 4088	 0.00276	 0.01883	 0.0032	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 4028	 0.00077	 0.04468	 0.0	 148.8	 148.8	 148.8	 1.0	 0.0	 1	 -30.0	 30.0;
	4029	 4028	 0.00077	 0.04468	 0.0	 148.8	 148.8	 148.8	 1.0	 0.0	 1	 -30.0	 30.0;
	4030	 4028	 0.00053	 0.0395	 0.0	 230.0	 230.0	 230.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4030	 4028	 0.00053	 0.0395	 0.0	 230.0	 230.0	 230.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4030	 4028	 0.00053	 0.0395	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4028	 7043	 0.00286	 0.02045	 0.03728	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 7274	 0.00028	 0.00295	 0.01006	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4028	 7274	 0.00028	 0.00295	 0.01006	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4029	 6253	 0.01201	 0.0776	 0.0148	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 4029	 0.00321	 0.01407	 0.00214	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4031	 4043	 0.04121	 0.18028	 0.02746	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 4031	 0.02053	 0.0898	 0.01368	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 4032	 0.02109	 0.05154	 0.00675	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 4032	 0.01931	 0.08605	 0.01262	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 4101	 0.0036	 0.016	 0.003	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 4147	 0.00984	 0.06854	 0.0112	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 4147	 0.00984	 0.06854	 0.0112	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4033	 4190	 0.00397	 0.01648	 0.0028	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 4154	 0.01506	 0.10289	 0.01751	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 4035	 0.00506	 0.02099	 0.00356	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 4150	 0.02431	 0.05942	 0.00778	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 4036	 0.03455	 0.15396	 0.02258	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4036	 4189	 0.05901	 0.14424	 0.01889	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 4054	 0.00975	 0.05854	 0.00794	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 4037	 0.01617	 0.07075	 0.01077	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4054	 4038	 0.01093	 0.06561	 0.0089	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 4125	 0.01635	 0.09341	 0.01404	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 4178	 0.03181	 0.07775	 0.01018	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4040	 4039	 0.00078	 0.02871	 0.0	 384.0	 384.0	 384.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4040	 4039	 0.00078	 0.02871	 0.0	 384.0	 384.0	 384.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4073	 4039	 0.00022	 0.00224	 0.00764	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 4039	 0.00022	 0.00224	 0.00764	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 4151	 0.00765	 0.07956	 0.27111	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 4151	 0.00765	 0.07956	 0.27111	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4039	 4151	 0.00765	 0.07956	 0.27111	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 4040	 0.00148	 0.00957	 0.00183	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 4040	 0.00148	 0.00957	 0.00183	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 4040	 0.00148	 0.00957	 0.00183	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 4040	 0.00457	 0.03186	 0.00521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 4040	 0.00457	 0.03186	 0.00521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 4040	 0.00457	 0.03186	 0.00521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4042	 4041	 0.00056	 0.03546	 0.0	 442.0	 442.0	 442.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4042	 4041	 0.00056	 0.03546	 0.0	 442.0	 442.0	 442.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4042	 4041	 0.00056	 0.03546	 0.0	 442.0	 442.0	 442.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4073	 4041	 0.0019	 0.01971	 0.06717	 820.0	 820.0	 820.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 4041	 0.0019	 0.01971	 0.06717	 820.0	 820.0	 820.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 4042	 0.00312	 0.02015	 0.00384	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4088	 4042	 0.00312	 0.02015	 0.00384	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 4042	 0.00298	 0.01925	 0.00367	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 4042	 0.00298	 0.01925	 0.00367	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4043	 4119	 0.01218	 0.05428	 0.00796	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4045	 4044	 0.00353	 0.16159	 0.0	 120.0	 120.0	 120.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4046	 4044	 0.00669	 0.2458	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4047	 4044	 0.00557	 0.09157	 0.0	 250.0	 250.0	 250.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4044	 4119	 0.00264	 0.01804	 0.00307	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4185	 4044	 0.03117	 0.13891	 0.02037	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 4154	 0.00408	 0.02784	 0.00474	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 4155	 0.00335	 0.02332	 0.00381	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4048	 4155	 0.00335	 0.02332	 0.00381	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4050	 4049	 0.00389	 0.07962	 0.0	 130.0	 130.0	 130.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4050	 4049	 0.00389	 0.07962	 0.0	 130.0	 130.0	 130.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4086	 4049	 0.00927	 0.04053	 0.00617	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 4194	 0.00379	 0.02643	 0.00432	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4049	 4194	 0.00379	 0.02643	 0.00432	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4052	 4051	 0.00406	 0.16879	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4127	 4051	 0.01554	 0.08876	 0.01334	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 4152	 0.0091	 0.06213	 0.01057	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 4152	 0.0091	 0.06213	 0.01057	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 4191	 0.02289	 0.14783	 0.0282	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4053	 4191	 0.02289	 0.14783	 0.0282	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4078	 0.00454	 0.03104	 0.00528	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4078	 0.00454	 0.03104	 0.00528	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4109	 0.01141	 0.04991	 0.0076	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4145	 0.0037	 0.02577	 0.00421	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4145	 0.0037	 0.02577	 0.00421	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 4056	 0.0009	 0.03263	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4058	 4056	 0.00136	 0.05833	 0.0	 185.0	 185.0	 185.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4059	 4056	 0.00197	 0.04935	 0.0	 185.0	 185.0	 185.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4060	 4056	 0.00213	 0.08417	 0.0	 185.0	 185.0	 185.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4061	 4056	 0.00148	 0.05744	 0.0	 259.0	 259.0	 259.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4062	 4056	 0.00287	 0.0718	 0.0	 264.0	 264.0	 264.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4063	 4056	 0.00077	 0.05841	 0.0	 260.0	 260.0	 260.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4056	 4158	 0.00124	 0.01287	 0.04387	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4056	 4181	 0.00117	 0.01146	 0.02204	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4108	 4057	 0.00271	 0.01748	 0.00334	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4108	 4057	 0.00271	 0.01748	 0.00334	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 4145	 0.00563	 0.03924	 0.00641	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4057	 4145	 0.00563	 0.03924	 0.00641	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4065	 4064	 0.00915	 0.19147	 0.0	 100.0	 100.0	 100.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4069	 4064	 0.00989	 0.02376	 0.00322	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 4099	 0.00946	 0.06459	 0.01099	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 4099	 0.00946	 0.06459	 0.01099	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 4104	 0.00622	 0.04017	 0.00766	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 4104	 0.00622	 0.04017	 0.00766	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4068	 0.013	 0.05797	 0.0085	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4107	 0.00316	 0.02043	 0.0039	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4066	 4107	 0.00316	 0.02043	 0.0039	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 4067	 0.00346	 0.02362	 0.00402	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 4067	 0.00473	 0.03294	 0.00539	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 4067	 0.00473	 0.03294	 0.00539	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4194	 4067	 0.00473	 0.03294	 0.00539	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 4103	 0.00973	 0.05555	 0.00835	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4068	 4186	 0.01855	 0.08268	 0.01212	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4069	 4072	 0.00681	 0.03892	 0.00585	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 4070	 0.00121	 0.04292	 0.0	 353.0	 353.0	 353.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4071	 4070	 0.00121	 0.04292	 0.0	 353.0	 353.0	 353.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4070	 4183	 0.002	 0.02	 0.07	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 4192	 0.00137	 0.01421	 0.04843	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 4192	 0.00137	 0.01421	 0.04843	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 4071	 0.009	 0.0401	 0.00588	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 4156	 0.00671	 0.0278	 0.00472	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 4168	 0.00284	 0.01981	 0.00324	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 4168	 0.00284	 0.01981	 0.00324	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4074	 4073	 0.00046	 0.01717	 0.0	 397.0	 397.0	 397.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4074	 4073	 0.00046	 0.01717	 0.0	 397.0	 397.0	 397.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4075	 4073	 0.0015	 0.06318	 0.0	 220.0	 220.0	 220.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4076	 4073	 0.0015	 0.05994	 0.0	 220.0	 220.0	 220.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4077	 4073	 0.00135	 0.06817	 0.0	 220.0	 220.0	 220.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4146	 4073	 0.006	 0.06	 0.115	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 4183	 0.01015	 0.07248	 0.13214	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 4073	 0.0062	 0.06449	 0.21975	 820.0	 820.0	 820.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4155	 4074	 0.01013	 0.05786	 0.00869	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4120	 4078	 0.00325	 0.01949	 0.00265	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 4180	 0.01569	 0.08959	 0.01346	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 4157	 0.00338	 0.02308	 0.00393	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4079	 4157	 0.00338	 0.02308	 0.00393	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4081	 4080	 0.00112	 0.06024	 0.0	 171.0	 171.0	 171.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4081	 4080	 0.00112	 0.06024	 0.0	 171.0	 171.0	 171.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4082	 4080	 0.00121	 0.05053	 0.0	 342.0	 342.0	 342.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4083	 4080	 0.00111	 0.04655	 0.0	 342.0	 342.0	 342.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4084	 4080	 0.00039	 0.02538	 0.0	 338.0	 338.0	 338.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4085	 4080	 0.00054	 0.02176	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4140	 4080	 0.00421	 0.04377	 0.14917	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 4151	 0.00484	 0.05033	 0.17151	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 4181	 0.00409	 0.03994	 0.07686	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4183	 4080	 0.002	 0.02	 0.07	 820.0	 820.0	 820.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4086	 4106	 0.02192	 0.09592	 0.01461	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4086	 0.01641	 0.07179	 0.01093	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4156	 4087	 0.00563	 0.02463	 0.00375	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4090	 4089	 0.01451	 0.58764	 0.0	 28.0	 28.0	 28.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4091	 4089	 0.00427	 0.20036	 0.0	 37.0	 37.0	 37.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4092	 4089	 0.0034	 0.12539	 0.0	 48.0	 48.0	 48.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4093	 4089	 0.01405	 0.24296	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4094	 4089	 0.00238	 0.09215	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4095	 4089	 0.0077	 0.18665	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4096	 4089	 0.01248	 0.29442	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4097	 4089	 0.00925	 0.21151	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4098	 4089	 0.01041	 0.22475	 0.0	 40.0	 40.0	 40.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4089	 4194	 0.01637	 0.06793	 0.01153	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 4099	 0.00915	 0.0625	 0.01063	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 4099	 0.00915	 0.0625	 0.01063	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 4120	 0.00186	 0.00773	 0.00131	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 4100	 0.00216	 0.01393	 0.00266	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 4100	 0.00216	 0.01393	 0.00266	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 4100	 0.00185	 0.01287	 0.0021	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 4100	 0.00185	 0.01287	 0.0021	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4168	 4100	 0.00185	 0.01287	 0.0021	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4175	 4101	 0.01931	 0.08013	 0.0136	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 4101	 0.02022	 0.09011	 0.01321	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 4102	 0.00411	 0.02652	 0.00506	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4126	 4102	 0.00411	 0.02652	 0.00506	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 4171	 0.00634	 0.04334	 0.00737	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4102	 4171	 0.00634	 0.04334	 0.00737	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 4104	 0.00385	 0.08871	 0.0	 128.0	 128.0	 128.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4105	 4104	 0.00385	 0.08871	 0.0	 128.0	 128.0	 128.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4145	 4104	 0.01294	 0.03109	 0.00422	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 4108	 0.00818	 0.0358	 0.00545	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 4156	 0.00373	 0.02127	 0.0032	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 4171	 0.02886	 0.11974	 0.02032	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 4111	 0.00861	 0.0384	 0.00563	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 4112	 0.01932	 0.13196	 0.02245	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 4112	 0.01932	 0.13196	 0.02245	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 4141	 0.0066	 0.04599	 0.00752	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4112	 4141	 0.0066	 0.04599	 0.00752	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4114	 4113	 0.00072	 0.01874	 0.0	 387.0	 387.0	 387.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4115	 4113	 0.00101	 0.05405	 0.0	 180.0	 180.0	 180.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4116	 4113	 0.00162	 0.05686	 0.0	 180.0	 180.0	 180.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4146	 4113	 0.0025	 0.02448	 0.04711	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 4114	 0.00237	 0.01616	 0.00275	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4190	 4114	 0.00237	 0.01616	 0.00275	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4117	 4172	 0.01489	 0.06176	 0.01048	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 4118	 0.0147	 0.08395	 0.01262	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 4118	 0.0246	 0.14051	 0.02111	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 4119	 0.02453	 0.1676	 0.02851	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 4157	 0.00313	 0.02183	 0.00357	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 4157	 0.00313	 0.02183	 0.00357	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 4180	 0.01637	 0.09826	 0.01333	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 4124	 0.02044	 0.13201	 0.02518	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4128	 4124	 0.02044	 0.13201	 0.02518	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 4125	 0.03218	 0.07865	 0.0103	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 4126	 0.00522	 0.0364	 0.00595	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 4126	 0.00522	 0.0364	 0.00595	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 4126	 0.00522	 0.0364	 0.00595	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4144	 4127	 0.02101	 0.12616	 0.01712	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 4130	 0.03748	 0.09002	 0.01222	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 4176	 0.02359	 0.14166	 0.01922	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4130	 4179	 0.01386	 0.07916	 0.0119	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 4131	 0.00028	 0.01679	 0.0	 246.6	 246.6	 246.6	 1.0	 0.0	 1	 -30.0	 30.0;
	4132	 4131	 0.00028	 0.01679	 0.0	 246.6	 246.6	 246.6	 1.0	 0.0	 1	 -30.0	 30.0;
	4133	 4131	 0.00199	 0.07159	 0.0	 101.0	 101.0	 101.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4134	 4131	 0.00198	 0.14741	 0.0	 103.0	 103.0	 103.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4135	 4131	 0.00314	 0.14014	 0.0	 103.0	 103.0	 103.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4136	 4131	 0.00315	 0.18409	 0.0	 105.0	 105.0	 105.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4137	 4131	 0.00218	 0.08044	 0.0	 140.0	 140.0	 140.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4138	 4131	 0.00058	 0.03762	 0.0	 135.0	 135.0	 135.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4131	 6308	 0.00739	 0.05281	 0.09628	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 4143	 0.02006	 0.08324	 0.01413	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6357	 4132	 0.01827	 0.07994	 0.01217	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 4144	 0.00882	 0.05038	 0.00757	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4139	 4169	 0.01144	 0.05002	 0.00762	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 4140	 0.00072	 0.03223	 0.0	 428.0	 428.0	 428.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4142	 4140	 0.00054	 0.02789	 0.0	 168.0	 168.0	 168.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4140	 4151	 0.00411	 0.02936	 0.05353	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4140	 4196	 0.01639	 0.11706	 0.21342	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4141	 4165	 0.01975	 0.08194	 0.0139	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 4143	 0.02761	 0.11455	 0.01944	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 4146	 0.0002	 0.0123	 0.0	 459.0	 459.0	 459.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4146	 4196	 0.00241	 0.02506	 0.0854	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4146	 4196	 0.00241	 0.02506	 0.0854	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4148	 4179	 0.03149	 0.1891	 0.02566	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 4149	 0.02612	 0.11641	 0.01707	 170.0	 170.0	 170.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 4182	 0.00774	 0.05286	 0.00899	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4152	 4151	 0.00143	 0.08362	 0.0	 78.0	 78.0	 78.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4152	 4151	 0.00143	 0.08362	 0.0	 78.0	 78.0	 78.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4153	 4151	 0.0006	 0.01612	 0.0	 381.0	 381.0	 381.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4151	 4158	 0.00609	 0.06334	 0.21583	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4164	 4155	 0.00412	 0.02661	 0.00508	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 4158	 0.0006	 0.02511	 0.0	 620.0	 620.0	 620.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4159	 4158	 0.0006	 0.02511	 0.0	 620.0	 620.0	 620.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4160	 4158	 0.00047	 0.02419	 0.0	 298.0	 298.0	 298.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4161	 4158	 0.00081	 0.05928	 0.0	 296.0	 296.0	 296.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4162	 4158	 0.00201	 0.05867	 0.0	 293.0	 293.0	 293.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4163	 4158	 0.0037	 0.15066	 0.0	 74.0	 74.0	 74.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4159	 4168	 0.00057	 0.00394	 0.00064	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 4168	 0.00057	 0.00394	 0.00064	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 4168	 0.00057	 0.00394	 0.00064	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4159	 4168	 0.00057	 0.00394	 0.00064	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4166	 4165	 0.00217	 0.09206	 0.0	 132.0	 132.0	 132.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4166	 4165	 0.00217	 0.09206	 0.0	 132.0	 132.0	 132.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4186	 4167	 0.01453	 0.06359	 0.00968	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 4170	 0.00815	 0.03567	 0.00543	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 4172	 0.01492	 0.06529	 0.00994	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 6346	 0.01189	 0.05202	 0.00792	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 4173	 0.02382	 0.10423	 0.01587	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 4174	 0.00722	 0.02995	 0.00508	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6276	 4174	 0.01173	 0.04865	 0.00826	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4176	 4175	 0.02194	 0.09598	 0.01462	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 4176	 0.0053	 0.11274	 0.0	 115.0	 115.0	 115.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4177	 4176	 0.0053	 0.11274	 0.0	 115.0	 115.0	 115.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4178	 6253	 0.02656	 0.11618	 0.01769	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4182	 4181	 0.00321	 0.09306	 0.0	 169.0	 169.0	 169.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7274	 4181	 0.01011	 0.07225	 0.13172	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 4183	 0.00113	 0.06134	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4191	 4184	 0.01223	 0.08358	 0.01422	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4191	 4184	 0.01223	 0.08358	 0.01422	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 4194	 0.00649	 0.04522	 0.00739	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4184	 4194	 0.00649	 0.04522	 0.00739	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4187	 4189	 0.02899	 0.12682	 0.01931	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4193	 4192	 0.00036	 0.02396	 0.0	 438.0	 438.0	 438.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4193	 4192	 0.00036	 0.02396	 0.0	 438.0	 438.0	 438.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4193	 4192	 0.00036	 0.02396	 0.0	 438.0	 438.0	 438.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4196	 4195	 8e-05	 0.00576	 0.0	 1233.0	 1233.0	 1233.0	 1.0	 0.0	 1	 -30.0	 30.0;
	4195	 6239	 0.00265	 0.0321	 2.13231	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4197	 4196	 0.00072	 0.03236	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5003	 5181	 0.00233	 0.01026	 0.00478	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 5003	 0.00127	 0.0072	 0.00387	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 5436	 0.00455	 0.01936	 0.00968	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 5426	 0.00757	 0.04276	 0.023	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5476	 5004	 0.004	 0.0226	 0.01216	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5133	 5005	 0.00846	 0.03598	 0.018	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 5435	 0.00739	 0.03256	 0.01515	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5072	 0.00074	 0.00543	 0.00308	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5072	 0.00074	 0.00543	 0.00308	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5072	 0.00074	 0.00543	 0.00308	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 5006	 0.00065	 0.00498	 0.00262	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 5006	 0.00065	 0.00498	 0.00262	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 5294	 0.00495	 0.02107	 0.01054	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5007	 5012	 0.0011	 0.00645	 0.00322	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 5007	 0.00088	 0.00648	 0.00367	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5134	 5008	 0.01009	 0.05706	 0.03069	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 5008	 0.01147	 0.05055	 0.02353	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5008	 0.00397	 0.02909	 0.01648	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 5009	 0.00175	 0.00769	 0.00358	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5311	 5009	 0.0016	 0.00704	 0.00328	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 5009	 0.00139	 0.0061	 0.00284	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 5096	 0.00127	 0.00969	 0.00509	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5010	 5096	 0.00127	 0.00969	 0.00509	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 5010	 0.00106	 0.00803	 0.00422	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 5010	 0.00106	 0.00803	 0.00422	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 5054	 0.00746	 0.04371	 0.02183	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 5011	 0.00545	 0.03193	 0.01595	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5012	 5017	 0.00663	 0.0292	 0.01359	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5013	 5101	 0.00798	 0.03394	 0.01697	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 5013	 0.00645	 0.02841	 0.01322	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5013	 5226	 0.00745	 0.03283	 0.01528	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 5455	 0.00556	 0.03257	 0.01626	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 5015	 0.00015	 0.01417	 0.0	 1206.0	 1206.0	 1206.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5016	 5015	 0.00015	 0.01417	 0.0	 1206.0	 1206.0	 1206.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5063	 5015	 0.00028	 0.00336	 0.22327	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 5164	 0.00044	 0.00534	 0.35461	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5361	 5015	 0.00044	 0.0053	 0.3546	 4352.0	 4352.0	 4352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 5479	 0.00057	 0.00686	 0.45585	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 5016	 0.00128	 0.00972	 0.00511	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 5016	 0.00128	 0.00972	 0.00511	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5265	 5016	 0.00128	 0.00972	 0.00511	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 5016	 0.00135	 0.01028	 0.0054	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5420	 5016	 0.00135	 0.01028	 0.0054	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 5017	 0.0048	 0.02041	 0.01021	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5017	 5315	 0.00523	 0.02225	 0.01113	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 5018	 0.00058	 0.02598	 0.0	 590.0	 590.0	 590.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5020	 5018	 0.00032	 0.03326	 0.0	 557.0	 557.0	 557.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5055	 5018	 0.00034	 0.00414	 0.27523	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 5236	 0.00037	 0.00753	 0.52503	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 5236	 0.00037	 0.00753	 0.52503	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5018	 5413	 0.00034	 0.00695	 0.48479	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 5176	 0.00561	 0.03288	 0.01642	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 5021	 0.0001	 0.01005	 0.0	 1375.0	 1375.0	 1375.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5022	 5021	 0.0001	 0.01005	 0.0	 1375.0	 1375.0	 1375.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5023	 5021	 0.00028	 0.02693	 0.0	 245.0	 245.0	 245.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5021	 5401	 0.00029	 0.006	 0.41836	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 5413	 0.00056	 0.01139	 0.79467	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 5021	 0.00021	 0.00435	 0.30317	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 5022	 0.00173	 0.01314	 0.0069	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5249	 5022	 0.00173	 0.01314	 0.0069	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 5022	 0.00263	 0.02	 0.0105	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 5022	 0.00263	 0.02	 0.0105	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 5441	 0.00341	 0.02594	 0.01362	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 5441	 0.00341	 0.02594	 0.01362	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 5024	 0.00381	 0.01679	 0.00781	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 5182	 0.003	 0.01323	 0.00616	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 5024	 0.00923	 0.05217	 0.02806	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 5025	 0.00495	 0.03768	 0.01978	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 5025	 0.00495	 0.03768	 0.01978	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 5473	 0.00322	 0.02357	 0.01336	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5025	 5473	 0.00322	 0.02357	 0.01336	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 5104	 0.0014	 0.01063	 0.00558	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 5104	 0.0014	 0.01063	 0.00558	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 5375	 0.00136	 0.00798	 0.00399	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 5098	 0.00294	 0.01659	 0.00893	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 5469	 0.00157	 0.01196	 0.00628	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 5469	 0.00157	 0.01196	 0.00628	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 5481	 0.00206	 0.01564	 0.00821	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 5028	 0.00096	 0.00703	 0.00399	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 5028	 0.00096	 0.00703	 0.00399	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 5233	 0.00165	 0.00966	 0.00482	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5028	 5478	 0.00394	 0.01736	 0.00808	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5029	 5142	 0.00477	 0.02699	 0.01452	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 5029	 0.00376	 0.02202	 0.01099	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 5030	 0.00423	 0.02478	 0.01237	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 5430	 0.00326	 0.0248	 0.01302	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5031	 5296	 0.00345	 0.0202	 0.01009	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 5031	 0.00513	 0.02263	 0.01054	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 5090	 0.00304	 0.01718	 0.00924	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 5032	 0.0022	 0.00969	 0.00451	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 5228	 0.0023	 0.01751	 0.00919	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 5228	 0.0023	 0.01751	 0.00919	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 5032	 0.00188	 0.00829	 0.00386	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 5033	 9e-05	 0.00546	 0.0	 1209.0	 1209.0	 1209.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5035	 5033	 0.00084	 0.07958	 0.0	 243.0	 243.0	 243.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5036	 5033	 0.00077	 0.05006	 0.0	 255.0	 255.0	 255.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5037	 5033	 0.00015	 0.01216	 0.0	 985.0	 985.0	 985.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5038	 5033	 0.00013	 0.01255	 0.0	 989.0	 989.0	 989.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5039	 5033	 8e-05	 0.00552	 0.0	 994.0	 994.0	 994.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5040	 5033	 0.00031	 0.01643	 0.0	 993.0	 993.0	 993.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5041	 5033	 0.00021	 0.01142	 0.0	 1001.0	 1001.0	 1001.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5042	 5033	 0.00013	 0.01345	 0.0	 988.0	 988.0	 988.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5033	 5047	 0.0004	 0.00814	 0.5676	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 5350	 0.00018	 0.00367	 0.25593	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 5384	 6e-05	 0.00115	 0.08036	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 5313	 0.00114	 0.00836	 0.00474	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 5313	 0.00114	 0.00836	 0.00474	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5034	 5313	 0.00114	 0.00836	 0.00474	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5371	 5034	 0.0033	 0.01934	 0.00966	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 5152	 0.00598	 0.03504	 0.0175	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 5284	 0.00758	 0.04445	 0.0222	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 5153	 0.0031	 0.0236	 0.01239	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 5153	 0.0031	 0.0236	 0.01239	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 5044	 0.0032	 0.02431	 0.01276	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 5044	 0.0032	 0.02431	 0.01276	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 5045	 0.00031	 0.02114	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5045	 5120	 0.00127	 0.01539	 1.02213	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5260	 5045	 0.0005	 0.00603	 0.40075	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 5045	 0.00055	 0.00672	 0.4467	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5046	 0.0115	 0.05069	 0.0236	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5048	 5047	 0.00013	 0.01253	 0.0	 1354.0	 1354.0	 1354.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5047	 5179	 0.00054	 0.01097	 0.76512	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5047	 5260	 0.00078	 0.00944	 0.62704	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5047	 5444	 0.00019	 0.00235	 0.15601	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 5048	 0.00268	 0.02037	 0.0107	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 5048	 0.00268	 0.02037	 0.0107	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 5048	 0.00268	 0.02037	 0.0107	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 5048	 0.00268	 0.02037	 0.0107	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5050	 5049	 0.0003	 0.025	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5051	 5049	 0.00024	 0.01633	 0.0	 409.0	 409.0	 409.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5052	 5049	 0.00067	 0.0499	 0.0	 308.0	 308.0	 308.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5049	 5304	 0.00059	 0.00713	 0.47354	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 5350	 0.0007	 0.0085	 0.5646	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5049	 8074	 0.00142	 0.02903	 2.02497	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8126	 5049	 0.006	 0.01	 0.83	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 5050	 0.00279	 0.02125	 0.01116	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 5050	 0.00279	 0.02125	 0.01116	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 8038	 0.013	 0.054	 0.027	 186.0	 186.0	 186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5052	 8124	 0.013	 0.054	 0.027	 186.0	 186.0	 186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 5053	 0.00088	 0.00647	 0.00367	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 5053	 0.00088	 0.00647	 0.00367	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 5357	 0.00118	 0.00895	 0.0047	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5053	 5357	 0.00118	 0.00895	 0.0047	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5054	 5223	 0.00543	 0.03069	 0.01651	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5056	 5055	 0.00023	 0.01209	 0.0	 913.0	 913.0	 913.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5057	 5055	 0.00023	 0.01324	 0.0	 1036.0	 1036.0	 1036.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5058	 5055	 0.00031	 0.01928	 0.0	 1023.0	 1023.0	 1023.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5055	 5196	 0.00034	 0.0041	 0.275	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5187	 5056	 0.01355	 0.05765	 0.02883	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 5056	 0.0075	 0.04397	 0.02196	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 5059	 0.00378	 0.07811	 0.0	 151.0	 151.0	 151.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5059	 5426	 0.00507	 0.02868	 0.01543	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8148	 5059	 0.00396	 0.03012	 0.01581	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5061	 5060	 0.00305	 0.13464	 0.0	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5060	 8065	 0.00719	 0.04106	 0.00617	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5062	 5061	 0.00697	 0.17819	 0.0	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 5063	 0.00013	 0.00901	 0.0	 1277.0	 1277.0	 1277.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5064	 5063	 0.00013	 0.00901	 0.0	 1277.0	 1277.0	 1277.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5065	 5063	 0.00025	 0.01754	 0.0	 290.0	 290.0	 290.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5066	 5063	 0.00142	 0.09165	 0.0	 213.0	 213.0	 213.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5067	 5063	 0.00011	 0.01076	 0.0	 1078.0	 1078.0	 1078.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5068	 5063	 0.00017	 0.0113	 0.0	 1073.0	 1073.0	 1073.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5069	 5063	 0.00021	 0.01202	 0.0	 1079.0	 1079.0	 1079.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5063	 5304	 0.00078	 0.0095	 0.6308	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5322	 5063	 0.00026	 0.00314	 0.20858	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5063	 5401	 0.0005	 0.01016	 0.70838	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 5125	 0.00095	 0.00721	 0.00379	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 5125	 0.00095	 0.00721	 0.00379	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 5125	 0.00095	 0.00721	 0.00379	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5064	 5125	 0.00095	 0.00721	 0.00379	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 5064	 0.00084	 0.00642	 0.00337	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 5064	 0.00084	 0.00642	 0.00337	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 5064	 0.00084	 0.00642	 0.00337	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5070	 5128	 0.00204	 0.00902	 0.0042	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 5070	 0.00111	 0.00651	 0.00325	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 5071	 0.0037	 0.02168	 0.01083	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5071	 5359	 0.00459	 0.03488	 0.01831	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5072	 0.00114	 0.00868	 0.00456	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5072	 0.00114	 0.00868	 0.00456	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5072	 0.00114	 0.00868	 0.00456	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5072	 0.00114	 0.00868	 0.00456	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5072	 0.00114	 0.00868	 0.00456	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 5072	 0.00108	 0.0079	 0.00448	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 5072	 0.00108	 0.0079	 0.00448	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 5073	 0.00516	 0.02272	 0.01058	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5484	 5073	 0.0111	 0.06505	 0.03248	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5147	 0.0043	 0.03272	 0.01718	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5074	 5331	 0.00369	 0.02161	 0.01079	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 5267	 0.02194	 0.09333	 0.04668	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 5377	 0.02449	 0.10791	 0.05023	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5077	 5076	 0.0015	 0.06519	 0.0	 260.0	 260.0	 260.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5227	 5076	 0.00533	 0.02268	 0.01134	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 5077	 0.00971	 0.05831	 0.00791	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 5078	 0.00399	 0.01757	 0.00818	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 5138	 0.00181	 0.01379	 0.00724	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 5138	 0.00181	 0.01379	 0.00724	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5378	 5079	 0.00152	 0.00891	 0.00445	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 5080	 0.00553	 0.03127	 0.01682	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 5328	 0.00866	 0.03817	 0.01777	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 5163	 0.00516	 0.03024	 0.0151	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 5081	 0.00517	 0.0228	 0.01061	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 5377	 0.0068	 0.039	 0.005	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5086	 0.00219	 0.01283	 0.00641	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5330	 0.00214	 0.01253	 0.00625	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5082	 5440	 0.00107	 0.00605	 0.00326	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5084	 5083	 0.00024	 0.01146	 0.0	 1295.0	 1295.0	 1295.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5083	 5295	 7e-05	 0.00134	 0.09371	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 5322	 0.0007	 0.00853	 0.56646	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 5464	 0.0002	 0.00237	 0.15714	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 5084	 0.00149	 0.01134	 0.00596	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 5084	 0.00149	 0.01134	 0.00596	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 5084	 0.00149	 0.01134	 0.00596	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 5085	 0.00229	 0.01293	 0.00695	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5085	 5468	 0.00181	 0.00797	 0.00371	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 5177	 0.00288	 0.01629	 0.00876	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 5210	 0.00527	 0.02323	 0.01081	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5086	 5447	 0.00451	 0.01917	 0.00959	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 5087	 0.00596	 0.02626	 0.01222	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 5345	 0.00569	 0.03217	 0.01731	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 5348	 0.0048	 0.02814	 0.01405	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5089	 5088	 0.00382	 0.09418	 0.0	 150.0	 150.0	 150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5088	 5290	 0.00328	 0.01851	 0.00996	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 5393	 0.00614	 0.03602	 0.01799	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 5122	 0.00277	 0.0122	 0.00568	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 5230	 0.00189	 0.00834	 0.00388	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5090	 5311	 0.00167	 0.0098	 0.00489	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 5091	 0.00311	 0.01823	 0.0091	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5091	 5257	 0.00494	 0.02894	 0.01445	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5092	 5186	 0.00539	 0.03162	 0.01579	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 5092	 0.00849	 0.03611	 0.01806	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 5092	 0.00472	 0.02665	 0.01434	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 5291	 0.00299	 0.01754	 0.00876	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5332	 5093	 0.00371	 0.02175	 0.01086	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 5434	 0.0015	 0.01141	 0.00599	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 5434	 0.0015	 0.01141	 0.00599	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 5381	 0.00329	 0.025	 0.01312	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 5094	 0.00237	 0.01799	 0.00945	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 5095	 0.0038	 0.01676	 0.0078	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 5095	 0.00257	 0.01134	 0.00528	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 5096	 0.00176	 0.01289	 0.0073	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 5096	 0.00176	 0.01289	 0.0073	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 5096	 0.00176	 0.01289	 0.0073	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5096	 5412	 0.00234	 0.01373	 0.00686	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 5125	 0.00078	 0.00569	 0.00322	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 5125	 0.00078	 0.00569	 0.00322	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 5453	 0.00529	 0.04026	 0.02114	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5098	 5475	 0.01191	 0.05066	 0.02533	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 5195	 0.00308	 0.0174	 0.00936	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5099	 5339	 0.00266	 0.01561	 0.00779	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 5100	 0.00057	 0.00414	 0.00235	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 5100	 0.00057	 0.00414	 0.00235	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5100	 0.00124	 0.0091	 0.00516	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5100	 0.00124	 0.0091	 0.00516	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5100	 0.00124	 0.0091	 0.00516	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 5352	 0.00056	 0.00426	 0.00224	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 5352	 0.00056	 0.00426	 0.00224	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 5101	 0.01968	 0.08674	 0.04038	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5102	 0.00026	 0.0114	 0.0	 1345.0	 1345.0	 1345.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5103	 5102	 0.00026	 0.0114	 0.0	 1345.0	 1345.0	 1345.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5102	 5304	 0.00023	 0.00277	 0.18414	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5384	 5102	 0.00039	 0.0047	 0.31216	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5464	 5102	 0.00028	 0.00339	 0.22498	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5130	 0.00117	 0.00856	 0.00485	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 5130	 0.00117	 0.00856	 0.00485	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5199	 0.00503	 0.02843	 0.01529	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 5104	 0.00135	 0.01026	 0.00539	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 5104	 0.00135	 0.01026	 0.00539	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5480	 0.00236	 0.01795	 0.00942	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5480	 0.00236	 0.01795	 0.00942	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5480	 0.00236	 0.01795	 0.00942	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5104	 5480	 0.00236	 0.01795	 0.00942	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5106	 5105	 0.00709	 0.19751	 0.0	 82.0	 82.0	 82.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5107	 5105	 0.00966	 0.19527	 0.0	 75.0	 75.0	 75.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5105	 5148	 0.00212	 0.009	 0.0045	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 5253	 0.00604	 0.02664	 0.0124	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5105	 5422	 0.00354	 0.02074	 0.01036	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 5266	 0.00144	 0.01098	 0.00577	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 5266	 0.00144	 0.01098	 0.00577	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 5353	 0.00106	 0.00809	 0.00425	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5108	 5353	 0.00106	 0.00809	 0.00425	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 5108	 0.0015	 0.01102	 0.00625	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 5108	 0.0015	 0.01102	 0.00625	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 5108	 0.0015	 0.01102	 0.00625	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 5109	 0.00268	 0.01516	 0.00815	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5109	 5333	 0.00213	 0.01247	 0.00623	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 5110	 0.00503	 0.02841	 0.01528	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5200	 0.0045	 0.02638	 0.01317	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 5111	 0.00135	 0.00792	 0.00396	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 5289	 0.00089	 0.00652	 0.0037	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 5289	 0.00089	 0.00652	 0.0037	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5111	 5372	 0.00119	 0.007	 0.0035	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5133	 0.01714	 0.07289	 0.03645	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 5112	 0.008	 0.03402	 0.01701	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5246	 0.01038	 0.04415	 0.02208	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5112	 0.018	 0.078	 0.012	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 5195	 0.00674	 0.0395	 0.01972	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 5218	 0.00858	 0.0378	 0.01759	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 5113	 0.00567	 0.0241	 0.01205	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 5114	 0.00883	 0.03893	 0.01812	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 5222	 0.00513	 0.03755	 0.02128	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 5114	 0.005	 0.03803	 0.01997	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 5421	 0.0025	 0.01413	 0.0076	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 5115	 0.00397	 0.02326	 0.01161	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 5224	 0.00199	 0.01514	 0.00795	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5116	 5224	 0.00199	 0.01514	 0.00795	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 5216	 0.00157	 0.00695	 0.00323	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5117	 5409	 0.00292	 0.01288	 0.00599	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 5118	 0.01328	 0.05646	 0.02824	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5347	 5118	 0.01023	 0.04352	 0.02177	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 5456	 0.00988	 0.05791	 0.02892	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 5205	 0.00604	 0.02658	 0.01237	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 5119	 0.01103	 0.04691	 0.02346	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5121	 5120	 0.00064	 0.04599	 0.0	 298.0	 298.0	 298.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5120	 5239	 0.00087	 0.01049	 0.69666	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 5252	 0.0046	 0.01958	 0.00979	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5122	 5308	 0.00469	 0.02752	 0.01374	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 5123	 0.00266	 0.07286	 0.0	 214.0	 214.0	 214.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5159	 5123	 0.00799	 0.03521	 0.01639	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8157	 5124	 0.01256	 0.05593	 0.0082	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 5330	 0.00087	 0.0064	 0.00362	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 5330	 0.00087	 0.0064	 0.00362	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 5252	 0.0023	 0.00978	 0.00489	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 5309	 0.00399	 0.01755	 0.00817	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5126	 5386	 0.00259	 0.01969	 0.01034	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 5127	 0.00791	 0.03487	 0.01623	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5127	 5231	 0.01585	 0.06741	 0.03371	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5314	 5127	 0.01301	 0.05729	 0.02667	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 5214	 0.00143	 0.0084	 0.0042	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5128	 5467	 0.00166	 0.00974	 0.00486	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5226	 5129	 0.00964	 0.04249	 0.01978	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5129	 5240	 0.01196	 0.05272	 0.02454	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 5130	 0.00095	 0.00693	 0.00393	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 5130	 0.00095	 0.00693	 0.00393	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 5131	 0.00037	 0.01821	 0.0	 981.0	 981.0	 981.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5131	 5279	 0.00022	 0.00271	 0.1803	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 5410	 0.00018	 0.00365	 0.25434	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5131	 6107	 0.00051	 0.01038	 0.72429	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 5132	 0.00318	 0.01866	 0.00932	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 5134	 0.0067	 0.0393	 0.01962	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5155	 5135	 0.00905	 0.05304	 0.02648	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5169	 5135	 0.01055	 0.04486	 0.02244	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5135	 5264	 0.00751	 0.04244	 0.02283	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5136	 5288	 0.00558	 0.03152	 0.01695	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5138	 5137	 0.00014	 0.0092	 0.0	 945.0	 945.0	 945.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5137	 5388	 0.00021	 0.00253	 0.16793	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 5451	 0.00114	 0.01383	 0.91863	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 5183	 0.00187	 0.00825	 0.00384	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 5233	 0.00826	 0.03638	 0.01694	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5139	 0.00178	 0.00785	 0.00365	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 5466	 0.00143	 0.00633	 0.00295	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 5408	 0.00702	 0.03094	 0.0144	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 5466	 0.01638	 0.07217	 0.03359	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5143	 5216	 0.00311	 0.01826	 0.00912	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 5143	 0.00107	 0.00811	 0.00426	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 5143	 0.00107	 0.00811	 0.00426	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5144	 5314	 0.01178	 0.05011	 0.02506	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 5144	 0.00473	 0.02084	 0.0097	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 5251	 0.00125	 0.00917	 0.0052	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 5251	 0.00125	 0.00917	 0.0052	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 5323	 0.00133	 0.00973	 0.00551	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 5323	 0.00133	 0.00973	 0.00551	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5145	 5323	 0.00133	 0.00973	 0.00551	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5149	 0.00482	 0.02826	 0.01411	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5152	 0.00096	 0.0073	 0.00383	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5152	 0.00096	 0.0073	 0.00383	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 5146	 0.00105	 0.00797	 0.00418	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 5146	 0.00105	 0.00797	 0.00418	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5336	 5146	 0.00105	 0.00797	 0.00418	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5146	 5412	 0.00262	 0.01534	 0.00766	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 5188	 0.00308	 0.01312	 0.00656	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5147	 5224	 0.00362	 0.02124	 0.01061	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 5335	 0.00222	 0.00945	 0.00473	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5148	 5457	 0.00612	 0.02601	 0.01301	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 5148	 0.00259	 0.01144	 0.00532	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 5149	 0.00116	 0.00679	 0.00339	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5149	 5309	 0.0028	 0.01233	 0.00574	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 5150	 0.00186	 0.01364	 0.00773	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5150	 5432	 0.01516	 0.11531	 0.06054	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 5151	 0.00778	 0.0343	 0.01597	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 5151	 0.008	 0.03526	 0.01641	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 5151	 0.00814	 0.03465	 0.01733	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 5152	 0.00134	 0.00979	 0.00555	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 5152	 0.00134	 0.00979	 0.00555	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 5153	 0.00418	 0.03177	 0.01668	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 5153	 0.00418	 0.03177	 0.01668	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 5247	 0.0072	 0.03174	 0.01477	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 5154	 0.00545	 0.03196	 0.01596	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5456	 5156	 0.00659	 0.03866	 0.0193	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 5194	 0.00346	 0.01472	 0.00736	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 5157	 0.00236	 0.01792	 0.00941	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 5157	 0.00236	 0.01792	 0.00941	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 5158	 0.00121	 0.0089	 0.00504	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 5158	 0.00121	 0.0089	 0.00504	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 5158	 0.00143	 0.01044	 0.00592	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 5158	 0.00143	 0.01044	 0.00592	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 5159	 0.01947	 0.08578	 0.03993	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 5160	 0.00151	 0.00888	 0.00443	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 5181	 0.00545	 0.02401	 0.01118	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 5272	 0.00401	 0.01705	 0.00853	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 5161	 0.00144	 0.00846	 0.00422	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 5356	 0.00487	 0.02856	 0.01426	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 5211	 0.01066	 0.04696	 0.02186	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5162	 5437	 0.00505	 0.02226	 0.01036	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5163	 5235	 0.00709	 0.03019	 0.0151	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5165	 5164	 8e-05	 0.00485	 0.0	 1379.0	 1379.0	 1379.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5166	 5164	 0.00042	 0.02718	 0.0	 579.0	 579.0	 579.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5167	 5164	 0.0012	 0.09028	 0.0	 215.0	 215.0	 215.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5164	 5204	 0.00057	 0.01164	 0.81214	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5164	 5464	 0.00018	 0.00364	 0.25416	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 5165	 0.00126	 0.00958	 0.00503	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 5165	 0.00126	 0.00958	 0.00503	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 5165	 0.00126	 0.00958	 0.00503	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 5203	 0.00632	 0.02787	 0.01297	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 5245	 0.00821	 0.03616	 0.01683	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5168	 5311	 0.00162	 0.00948	 0.00473	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5170	 5169	 0.00185	 0.06575	 0.0	 222.0	 222.0	 222.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5471	 5169	 0.00598	 0.02635	 0.01226	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5171	 5174	 0.00411	 0.02409	 0.01203	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5306	 5172	 0.00438	 0.02476	 0.01332	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 5172	 0.00249	 0.01461	 0.0073	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5173	 5203	 0.00375	 0.02199	 0.01098	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5474	 5174	 0.00547	 0.03094	 0.01664	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 5175	 0.00254	 0.01433	 0.00771	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 5370	 0.00192	 0.01457	 0.00765	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5175	 5370	 0.00192	 0.01457	 0.00765	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 5186	 0.00555	 0.04069	 0.02305	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 5186	 0.00555	 0.04069	 0.02305	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5177	 5287	 0.00483	 0.02054	 0.01027	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 5178	 0.00517	 0.02281	 0.01062	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 5178	 0.00366	 0.02147	 0.01072	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5178	 5354	 0.00769	 0.03272	 0.01636	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 5179	 0.00019	 0.01541	 0.0	 946.0	 946.0	 946.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5358	 5179	 0.00053	 0.01093	 0.76232	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 5380	 0.00018	 0.004	 0.34742	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 8043	 0.00039	 0.00798	 0.55658	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 8057	 0.00045	 0.00923	 0.64362	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 5485	 0.00261	 0.01983	 0.01041	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 5314	 0.01253	 0.05522	 0.0257	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 5224	 0.00147	 0.00831	 0.00447	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 5373	 0.00681	 0.02896	 0.01448	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 5184	 0.00193	 0.01132	 0.00565	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 5218	 0.00352	 0.02066	 0.01032	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 5185	 0.00242	 0.01843	 0.00967	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5434	 5185	 0.00242	 0.01843	 0.00967	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 5355	 0.00341	 0.02495	 0.01414	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5186	 5355	 0.00341	 0.02495	 0.01414	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 5203	 0.00199	 0.01122	 0.00604	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 5234	 0.00344	 0.02618	 0.01374	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5188	 5253	 0.00739	 0.03143	 0.01572	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 5230	 0.00077	 0.00451	 0.00225	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 5272	 0.00079	 0.00346	 0.00161	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 5352	 0.00101	 0.00766	 0.00402	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 5352	 0.00101	 0.00766	 0.00402	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 5255	 0.01063	 0.06231	 0.03111	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 5264	 0.01177	 0.06902	 0.03446	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 5430	 0.01256	 0.09556	 0.05017	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5191	 5407	 0.00806	 0.03551	 0.01653	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 5192	 0.00022	 0.01302	 0.0	 890.0	 890.0	 890.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5192	 5279	 0.00078	 0.00941	 0.62487	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6316	 5193	 0.00674	 0.02866	 0.01433	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5330	 0.0059	 0.03459	 0.01728	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5376	 0.00067	 0.0051	 0.00268	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5194	 5462	 0.00205	 0.01202	 0.006	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 5196	 0.00034	 0.03164	 0.0	 305.0	 305.0	 305.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5198	 5196	 0.00018	 0.01116	 0.0	 594.0	 594.0	 594.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5196	 5204	 0.00058	 0.00708	 0.47032	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 5197	 0.00702	 0.03093	 0.0144	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 5375	 0.0038	 0.01619	 0.0081	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 5438	 0.00104	 0.00589	 0.00317	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 5200	 0.00506	 0.02964	 0.0148	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5276	 5201	 0.00365	 0.02142	 0.0107	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5327	 5201	 0.00494	 0.02792	 0.01502	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5202	 5381	 0.00904	 0.03848	 0.01924	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5426	 5202	 0.01126	 0.04962	 0.0231	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5205	 5204	 7e-05	 0.00858	 0.0	 1134.0	 1134.0	 1134.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5206	 5204	 0.00033	 0.01983	 0.0	 903.0	 903.0	 903.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5207	 5204	 0.00016	 0.01066	 0.0	 915.0	 915.0	 915.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5208	 5204	 0.00019	 0.01341	 0.0	 913.0	 913.0	 913.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5361	 5204	 0.00011	 0.00234	 0.16342	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5204	 5413	 0.00075	 0.00906	 0.60178	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5209	 5246	 0.00635	 0.02797	 0.01302	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 5209	 0.00664	 0.02927	 0.01362	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 5233	 0.00199	 0.01164	 0.00581	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5210	 5428	 0.00112	 0.00634	 0.00341	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 5275	 0.00613	 0.02704	 0.01259	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 5327	 0.00415	 0.02348	 0.01263	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5212	 5256	 0.00634	 0.04821	 0.02531	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5333	 5212	 0.00352	 0.02679	 0.01407	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5213	 5250	 0.00303	 0.02223	 0.01259	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 5229	 0.00374	 0.01647	 0.00767	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5468	 5214	 0.00075	 0.0057	 0.00299	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5215	 5277	 0.00671	 0.03931	 0.01963	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 5442	 0.00087	 0.00508	 0.00254	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5216	 5443	 0.00194	 0.00852	 0.00397	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 5310	 0.00171	 0.00755	 0.00351	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 5310	 0.00171	 0.00755	 0.00351	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 5433	 0.00438	 0.01931	 0.00899	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5217	 0.00126	 0.00922	 0.00522	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5217	 0.00126	 0.00922	 0.00522	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5219	 5371	 0.00781	 0.03325	 0.01663	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 5411	 0.00803	 0.03536	 0.01646	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 5426	 0.00404	 0.0307	 0.01612	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5222	 5426	 0.00404	 0.0307	 0.01612	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5223	 5275	 0.00911	 0.05341	 0.02667	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 5224	 0.00171	 0.01303	 0.00684	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5225	 5259	 0.00243	 0.01424	 0.00711	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 5225	 0.00183	 0.0134	 0.00759	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 5354	 0.00753	 0.04412	 0.02203	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 5228	 0.00155	 0.01183	 0.00621	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 5228	 0.00155	 0.01183	 0.00621	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5313	 5228	 0.00155	 0.01183	 0.00621	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 5228	 0.0013	 0.00988	 0.00519	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5229	 5309	 0.0027	 0.01582	 0.0079	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 5478	 0.00568	 0.02417	 0.01209	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5286	 5231	 0.01945	 0.08572	 0.0399	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 5251	 0.00634	 0.02792	 0.013	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 5232	 0.00256	 0.01088	 0.00544	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 5442	 0.00617	 0.02716	 0.01264	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5233	 5339	 0.00532	 0.02343	 0.01091	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 5296	 0.00408	 0.03102	 0.01628	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 5296	 0.00408	 0.03102	 0.01628	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 5271	 0.01401	 0.06175	 0.02875	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 5235	 0.00717	 0.03052	 0.01526	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 5236	 0.00052	 0.04304	 0.0	 287.0	 287.0	 287.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5238	 5236	 0.00016	 0.00976	 0.0	 826.0	 826.0	 826.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5236	 5394	 0.00122	 0.01485	 0.98624	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5240	 5239	 0.00052	 0.03641	 0.0	 477.0	 477.0	 477.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5243	 5239	 0.00038	 0.02602	 0.0	 584.0	 584.0	 584.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5451	 5239	 0.00065	 0.00791	 0.52569	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 6210	 0.00119	 0.01447	 0.96116	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 5240	 0.00087	 0.0425	 0.0	 204.0	 204.0	 204.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5242	 5241	 0.01845	 0.47482	 0.0	 24.0	 24.0	 24.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 5306	 0.00707	 0.04143	 0.02069	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 5442	 0.00508	 0.02158	 0.01079	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 5254	 0.00731	 0.03219	 0.01498	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5245	 5339	 0.00345	 0.01469	 0.00734	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 5246	 0.0031	 0.01817	 0.00907	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 5428	 0.0019	 0.01112	 0.00555	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 5457	 0.00198	 0.00875	 0.00407	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 5483	 0.00348	 0.01531	 0.00713	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 5249	 0.0018	 0.0137	 0.0072	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 5249	 0.0018	 0.0137	 0.0072	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5385	 0.00149	 0.0113	 0.00593	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5385	 0.00149	 0.0113	 0.00593	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5385	 0.00149	 0.0113	 0.00593	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 5385	 0.00149	 0.0113	 0.00593	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 5478	 0.00129	 0.00945	 0.00536	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 5478	 0.00129	 0.00945	 0.00536	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 5340	 0.00558	 0.0237	 0.01185	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5252	 5436	 0.00133	 0.00585	 0.00272	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 5253	 0.00126	 0.00956	 0.00502	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5370	 5253	 0.00126	 0.00956	 0.00502	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 5332	 0.00765	 0.03373	 0.0157	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 5420	 0.00202	 0.01533	 0.00805	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 5420	 0.00202	 0.01533	 0.00805	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5254	 5457	 0.00634	 0.02792	 0.01299	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 5256	 0.00207	 0.0117	 0.00629	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 5427	 0.00474	 0.02777	 0.01387	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5439	 5256	 0.0037	 0.02813	 0.01477	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5308	 5258	 0.00332	 0.01947	 0.00972	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5259	 5412	 0.00233	 0.01365	 0.00681	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5261	 5260	 0.00045	 0.02804	 0.0	 375.0	 375.0	 375.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5262	 5260	 0.0001	 0.00632	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5263	 5260	 6e-05	 0.00451	 0.0	 1450.0	 1450.0	 1450.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5317	 5260	 4e-05	 0.00088	 0.07608	 4352.0	 4352.0	 4352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5264	 5471	 0.00664	 0.03754	 0.02019	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5265	 0.00103	 0.00785	 0.00412	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5265	 0.00103	 0.00785	 0.00412	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 5265	 0.00103	 0.00785	 0.00412	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5287	 5266	 0.0022	 0.01287	 0.00643	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5267	 5466	 0.00868	 0.03823	 0.01779	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 5267	 0.01229	 0.05415	 0.02521	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 5288	 0.00791	 0.03365	 0.01683	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 5269	 0.00325	 0.02378	 0.01347	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 5269	 0.0017	 0.01248	 0.00707	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 5269	 0.0017	 0.01248	 0.00707	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 5389	 0.00793	 0.04646	 0.0232	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 5437	 0.00885	 0.03762	 0.01882	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5270	 5474	 0.00513	 0.03004	 0.015	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5271	 5390	 0.00759	 0.03346	 0.01557	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5467	 5272	 0.00108	 0.00476	 0.00222	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 5339	 0.00649	 0.02763	 0.01382	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 5422	 0.00204	 0.01195	 0.00597	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 5329	 0.00478	 0.02801	 0.01399	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5274	 5374	 0.00568	 0.02418	 0.01209	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5275	 5476	 0.01075	 0.063	 0.03146	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 5276	 0.00542	 0.03062	 0.01647	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5277	 5315	 0.00953	 0.04199	 0.01955	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 5278	 0.00202	 0.01184	 0.00591	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 5278	 0.00646	 0.02848	 0.01326	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 5279	 0.0001	 0.00635	 0.0	 1112.0	 1112.0	 1112.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5281	 5279	 0.00021	 0.01977	 0.0	 942.0	 942.0	 942.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5282	 5279	 0.00021	 0.01672	 0.0	 940.0	 940.0	 940.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5283	 5279	 0.00027	 0.01279	 0.0	 935.0	 935.0	 935.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5279	 5358	 0.00074	 0.00901	 0.5983	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 5461	 0.00246	 0.01871	 0.00982	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5284	 5454	 0.00377	 0.02759	 0.01564	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 5436	 0.00048	 0.00367	 0.00192	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5289	 5436	 0.00048	 0.00367	 0.00192	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 5345	 0.00613	 0.03593	 0.01794	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 5292	 0.00267	 0.01563	 0.0078	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 5291	 0.00544	 0.024	 0.01117	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 5438	 0.00699	 0.03084	 0.01436	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5292	 5312	 0.004	 0.01704	 0.00852	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 5338	 0.00404	 0.03072	 0.01613	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 5338	 0.00404	 0.03072	 0.01613	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 5402	 0.00355	 0.02603	 0.01475	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5293	 5402	 0.00355	 0.02603	 0.01475	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 5295	 0.00014	 0.00709	 0.0	 1233.0	 1233.0	 1233.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5297	 5295	 0.00085	 0.06248	 0.0	 223.0	 223.0	 223.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5298	 5295	 0.00015	 0.01082	 0.0	 525.0	 525.0	 525.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5299	 5295	 0.0003	 0.02227	 0.0	 524.0	 524.0	 524.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5300	 5295	 0.00025	 0.01848	 0.0	 519.0	 519.0	 519.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5301	 5295	 0.00058	 0.03088	 0.0	 403.0	 403.0	 403.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5302	 5295	 0.0003	 0.01763	 0.0	 1123.0	 1123.0	 1123.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5303	 5295	 0.00017	 0.01315	 0.0	 1117.0	 1117.0	 1117.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5304	 5295	 0.00011	 0.00134	 0.08928	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5295	 5444	 0.00069	 0.01404	 0.97894	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5296	 5400	 0.00214	 0.01566	 0.00887	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5305	 5304	 0.00014	 0.01047	 0.0	 1239.0	 1239.0	 1239.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5307	 5341	 0.00111	 0.00847	 0.00445	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5307	 5341	 0.00111	 0.00847	 0.00445	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5308	 0.0016	 0.01174	 0.00665	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5308	 0.0016	 0.01174	 0.00665	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 5339	 0.00596	 0.02626	 0.01222	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 5379	 0.00162	 0.00712	 0.00331	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5310	 5438	 0.00421	 0.02468	 0.01232	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5316	 5354	 0.00517	 0.02278	 0.01061	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 5317	 0.00013	 0.01555	 0.0	 1106.0	 1106.0	 1106.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5319	 5317	 0.00024	 0.01893	 0.0	 925.0	 925.0	 925.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5320	 5317	 0.00046	 0.02092	 0.0	 917.0	 917.0	 917.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5321	 5317	 0.00026	 0.01811	 0.0	 921.0	 921.0	 921.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5388	 5317	 0.00128	 0.01548	 1.02824	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5317	 5e-05	 0.00111	 0.09678	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5401	 5317	 5e-05	 0.00111	 0.09678	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 5318	 0.00242	 0.01844	 0.00968	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5473	 5318	 0.00242	 0.01844	 0.00968	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 5322	 0.00012	 0.01249	 0.0	 1334.0	 1334.0	 1334.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5323	 5322	 0.00012	 0.01249	 0.0	 1334.0	 1334.0	 1334.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5324	 5322	 0.00037	 0.02069	 0.0	 952.0	 952.0	 952.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5325	 5322	 0.00022	 0.0207	 0.0	 945.0	 945.0	 945.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5326	 5322	 0.00014	 0.00711	 0.0	 953.0	 953.0	 953.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5322	 5384	 0.00031	 0.00376	 0.24969	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 5322	 0.00014	 0.00164	 0.10912	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5323	 0.00121	 0.00887	 0.00503	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5323	 0.00121	 0.00887	 0.00503	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 5425	 0.00265	 0.02018	 0.01059	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5323	 5425	 0.00265	 0.02018	 0.01059	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 5328	 0.00871	 0.03704	 0.01852	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5330	 5433	 0.00293	 0.02226	 0.01169	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5400	 5331	 0.00473	 0.02774	 0.01385	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5450	 5331	 0.00779	 0.03434	 0.01599	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 5332	 0.00313	 0.01379	 0.00642	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 5333	 0.00478	 0.03636	 0.01909	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 5333	 0.00478	 0.03636	 0.01909	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5334	 5484	 0.01111	 0.06511	 0.03251	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 5372	 0.00458	 0.02019	 0.0094	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5335	 5425	 0.00232	 0.01697	 0.00961	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5336	 0.00118	 0.00899	 0.00472	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5336	 0.00118	 0.00899	 0.00472	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5336	 0.00118	 0.00899	 0.00472	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 5338	 0.00337	 0.02561	 0.01345	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 5338	 0.00337	 0.02561	 0.01345	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 5462	 0.00437	 0.02559	 0.01278	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 5467	 0.00082	 0.00348	 0.00174	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5342	 5341	 0.01026	 0.25106	 0.0	 49.0	 49.0	 49.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5343	 5341	 0.00091	 0.04835	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5422	 5341	 0.00126	 0.00925	 0.00524	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 5341	 0.00126	 0.00925	 0.00524	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 5465	 0.00307	 0.02252	 0.01276	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 5465	 0.00307	 0.02252	 0.01276	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 5465	 0.00307	 0.02252	 0.01276	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5341	 5465	 0.00307	 0.02252	 0.01276	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 5344	 0.00186	 0.00821	 0.00382	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5482	 0.00385	 0.01695	 0.00789	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 5346	 0.00103	 0.00605	 0.00302	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 5441	 0.00168	 0.01277	 0.0067	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5346	 5441	 0.00168	 0.01277	 0.0067	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 5346	 0.0007	 0.00512	 0.0029	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 5346	 0.0007	 0.00512	 0.0029	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 5355	 0.0081	 0.0357	 0.01662	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 5462	 0.00235	 0.01326	 0.00713	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5350	 8e-05	 0.00906	 0.0	 1258.0	 1258.0	 1258.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5351	 5350	 8e-05	 0.00906	 0.0	 1258.0	 1258.0	 1258.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5350	 5448	 0.00061	 0.00734	 0.48762	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5350	 5464	 0.00053	 0.00645	 0.4286	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 5431	 0.00463	 0.02714	 0.01355	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5353	 0.001	 0.007	 0.005	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5376	 5353	 0.001	 0.007	 0.005	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 5468	 0.00184	 0.01402	 0.00736	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 5445	 0.00332	 0.02526	 0.01326	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 5445	 0.00332	 0.02526	 0.01326	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5386	 5356	 0.001	 0.00567	 0.00305	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5356	 5431	 0.00571	 0.0323	 0.01737	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5357	 5386	 0.00324	 0.02375	 0.01346	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5359	 5358	 0.00026	 0.01828	 0.0	 1057.0	 1057.0	 1057.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5360	 5358	 0.00015	 0.0112	 0.0	 1333.0	 1333.0	 1333.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8155	 5358	 0.00037	 0.0075	 0.52342	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5362	 5361	 0.00018	 0.01755	 0.0	 646.0	 646.0	 646.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5363	 5361	 0.00057	 0.03295	 0.0	 282.0	 282.0	 282.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5364	 5361	 0.00014	 0.00948	 0.0	 798.0	 798.0	 798.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5365	 5361	 0.00026	 0.01973	 0.0	 787.0	 787.0	 787.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5366	 5361	 0.00038	 0.02244	 0.0	 795.0	 795.0	 795.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5367	 5361	 0.00031	 0.02178	 0.0	 809.0	 809.0	 809.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5368	 5361	 0.00022	 0.01449	 0.0	 798.0	 798.0	 798.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5369	 5361	 0.00041	 0.02362	 0.0	 796.0	 796.0	 796.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5373	 5433	 0.0024	 0.01407	 0.00702	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 5374	 0.00128	 0.00939	 0.00532	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 5374	 0.00128	 0.00939	 0.00532	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 5374	 0.00128	 0.00939	 0.00532	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 5477	 0.00328	 0.01925	 0.00961	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 5378	 0.00267	 0.01179	 0.00549	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 5442	 0.00383	 0.02248	 0.01122	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 5380	 0.00015	 0.00982	 0.0	 1057.0	 1057.0	 1057.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5382	 5380	 0.00021	 0.01436	 0.0	 786.0	 786.0	 786.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5383	 5380	 0.00023	 0.01636	 0.0	 787.0	 787.0	 787.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5380	 5384	 0.00026	 0.0059	 0.51266	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 5439	 0.00275	 0.02093	 0.01099	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 5439	 0.00275	 0.02093	 0.01099	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5385	 5384	 4e-05	 0.00492	 0.0	 1346.0	 1346.0	 1346.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5385	 5384	 4e-05	 0.00492	 0.0	 1346.0	 1346.0	 1346.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5387	 5429	 0.00362	 0.01597	 0.00743	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 5387	 0.00095	 0.00722	 0.00379	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 5388	 0.00011	 0.00666	 0.0	 1064.0	 1064.0	 1064.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5388	 8067	 0.00062	 0.01267	 0.8835	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 5393	 0.00709	 0.04153	 0.02074	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5391	 5390	 0.0041	 0.10984	 0.0	 65.0	 65.0	 65.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5390	 5458	 0.00669	 0.02948	 0.01372	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5392	 5391	 0.01427	 0.30897	 0.0	 50.0	 50.0	 50.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 5391	 0.00912	 0.05206	 0.00782	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 5394	 9e-05	 0.00527	 0.0	 1163.0	 1163.0	 1163.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5399	 5394	 9e-05	 0.01069	 0.0	 645.0	 645.0	 645.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5396	 5395	 0.00057	 0.04373	 0.0	 320.0	 320.0	 320.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5397	 5396	 0.00233	 0.0652	 0.0	 168.0	 168.0	 168.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5398	 5397	 0.01999	 0.78238	 0.0	 21.0	 21.0	 21.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 5401	 0.00019	 0.01369	 0.0	 1174.0	 1174.0	 1174.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5403	 5401	 0.00028	 0.02956	 0.0	 426.0	 426.0	 426.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5404	 5401	 0.00027	 0.01999	 0.0	 435.0	 435.0	 435.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5405	 5401	 0.0003	 0.02018	 0.0	 440.0	 440.0	 440.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5406	 5401	 0.00024	 0.02866	 0.0	 433.0	 433.0	 433.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5407	 5470	 0.01779	 0.07838	 0.03648	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5408	 5421	 0.00543	 0.02392	 0.01113	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 5447	 0.00189	 0.01068	 0.00574	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 5410	 0.00015	 0.01564	 0.0	 1041.0	 1041.0	 1041.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5410	 5451	 0.0004	 0.0049	 0.32555	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5411	 5477	 0.00331	 0.01942	 0.0097	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6316	 5411	 0.00833	 0.03543	 0.01772	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 5413	 0.00122	 0.05952	 0.0	 315.0	 315.0	 315.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5415	 5413	 0.00043	 0.03186	 0.0	 561.0	 561.0	 561.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5416	 5413	 0.00034	 0.03222	 0.0	 559.0	 559.0	 559.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5417	 5413	 0.00024	 0.0284	 0.0	 574.0	 574.0	 574.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5418	 5413	 0.00058	 0.02748	 0.0	 551.0	 551.0	 551.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5419	 5413	 0.00029	 0.01611	 0.0	 561.0	 561.0	 561.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5414	 5471	 0.01049	 0.04462	 0.02231	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 5422	 0.00234	 0.09836	 0.0	 94.0	 94.0	 94.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5424	 5422	 0.00826	 0.16541	 0.0	 77.0	 77.0	 77.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5432	 5430	 0.00343	 0.02608	 0.01369	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5435	 5471	 0.01193	 0.05076	 0.02538	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 5469	 0.00205	 0.00902	 0.0042	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 5444	 0.0002	 0.01571	 0.0	 1266.0	 1266.0	 1266.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5470	 5446	 0.00445	 0.01961	 0.00913	 187.0	 187.0	 187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5449	 5448	 7e-05	 0.00805	 0.0	 1267.0	 1267.0	 1267.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5448	 5479	 0.00039	 0.00471	 0.31303	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5452	 5451	 0.00023	 0.01073	 0.0	 960.0	 960.0	 960.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5459	 5458	 0.00338	 0.11671	 0.0	 80.0	 80.0	 80.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5460	 5459	 0.01905	 0.34714	 0.0	 35.0	 35.0	 35.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6140	 5459	 0.01042	 0.04644	 0.00681	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 6325	 0.01669	 0.07435	 0.0109	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5463	 5478	 0.00106	 0.00601	 0.00323	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 5464	 8e-05	 0.00976	 0.0	 1284.0	 1284.0	 1284.0	 1.0	 0.0	 1	 -30.0	 30.0;
	5467	 5482	 0.00166	 0.00971	 0.00485	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 5479	 0.00031	 0.01505	 0.0	 961.0	 961.0	 961.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6001	 6281	 0.00258	 0.01473	 0.00221	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6001	 6283	 0.01462	 0.03576	 0.00468	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6001	 6312	 0.00777	 0.03462	 0.00508	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6060	 0.00991	 0.05949	 0.00807	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6291	 0.00199	 0.01285	 0.00245	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6291	 0.00199	 0.01285	 0.00245	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6002	 6332	 0.00746	 0.03326	 0.00488	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6004	 6003	 0.00026	 0.01763	 0.0	 1117.0	 1117.0	 1117.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6006	 6003	 0.00024	 0.01241	 0.0	 788.0	 788.0	 788.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6007	 6003	 0.00012	 0.00801	 0.0	 1069.0	 1069.0	 1069.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6008	 6003	 0.00019	 0.01445	 0.0	 754.0	 754.0	 754.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6009	 6003	 0.00033	 0.02418	 0.0	 758.0	 758.0	 758.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6010	 6003	 0.00034	 0.01683	 0.0	 758.0	 758.0	 758.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6003	 6107	 0.00065	 0.00791	 0.5258	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6292	 6003	 0.0002	 0.00409	 0.28512	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6005	 6004	 0.00134	 0.05853	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6005	 6004	 0.00134	 0.05853	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6102	 6004	 0.00197	 0.0205	 0.06986	 1400.0	 1400.0	 1400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 6005	 0.00833	 0.0569	 0.00968	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 6005	 0.00833	 0.0569	 0.00968	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6005	 6117	 0.00772	 0.04984	 0.00951	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6005	 6117	 0.00772	 0.04984	 0.00951	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 6068	 0.00433	 0.03013	 0.00493	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6163	 6011	 0.00329	 0.02128	 0.00406	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6012	 0.00646	 0.04503	 0.00736	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6012	 0.00646	 0.04503	 0.00736	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 6013	 0.00518	 0.03346	 0.00638	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6013	 6128	 0.0055	 0.033	 0.00448	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6013	 6168	 0.00398	 0.0174	 0.00265	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6013	 6225	 0.0082	 0.04681	 0.00703	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6096	 0.02367	 0.05785	 0.00758	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6133	 6014	 0.01059	 0.04636	 0.00706	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6014	 6139	 0.00975	 0.05851	 0.00794	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 6112	 0.0199	 0.04863	 0.00637	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6015	 0.00985	 0.04086	 0.00693	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6168	 0.00378	 0.0263	 0.0043	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6168	 0.00378	 0.0263	 0.0043	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6016	 0.00208	 0.01421	 0.00242	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6016	 0.00208	 0.01421	 0.00242	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6016	 0.00208	 0.01421	 0.00242	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6016	 6356	 0.00315	 0.01306	 0.00222	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 6017	 0.00427	 0.02759	 0.00526	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 6017	 0.00427	 0.02759	 0.00526	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6068	 6017	 0.00427	 0.02759	 0.00526	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6159	 0.00233	 0.01593	 0.00271	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6159	 0.00233	 0.01593	 0.00271	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6017	 6159	 0.00233	 0.01593	 0.00271	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6018	 0.00176	 0.01201	 0.00204	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6018	 0.00176	 0.01201	 0.00204	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6018	 0.00176	 0.01201	 0.00204	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 6256	 0.00261	 0.01687	 0.00322	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 6256	 0.00261	 0.01687	 0.00322	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 6256	 0.00261	 0.01687	 0.00322	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 6019	 0.0008	 0.00518	 0.00099	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 6019	 0.0008	 0.00518	 0.00099	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 6019	 0.0008	 0.00518	 0.00099	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 6113	 0.00154	 0.00995	 0.0019	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 6113	 0.00154	 0.00995	 0.0019	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 6306	 0.01058	 0.02586	 0.00339	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 6313	 0.00538	 0.03672	 0.00625	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6019	 6313	 0.00538	 0.03672	 0.00625	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 6212	 0.00352	 0.0146	 0.00248	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 6252	 0.01082	 0.04487	 0.00761	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 6021	 0.00033	 0.01733	 0.0	 948.0	 948.0	 948.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6118	 6021	 0.00013	 0.00161	 0.10699	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 6210	 0.00053	 0.00643	 0.42698	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 6022	 0.00043	 0.02783	 0.0	 438.0	 438.0	 438.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6315	 6022	 0.0043	 0.03071	 0.05598	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 6350	 0.00257	 0.01837	 0.03349	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6023	 0.00776	 0.03392	 0.00517	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 6262	 0.00666	 0.04639	 0.00758	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6023	 6262	 0.00666	 0.04639	 0.00758	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6024	 6181	 0.01205	 0.05372	 0.00788	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6024	 6219	 0.004	 0.02403	 0.00326	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6024	 6330	 0.00775	 0.04653	 0.00631	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6025	 6060	 0.00724	 0.04134	 0.00621	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6025	 0.00399	 0.02277	 0.00342	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6025	 6337	 0.00373	 0.02598	 0.00425	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6025	 6337	 0.00373	 0.02598	 0.00425	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6352	 6025	 0.00808	 0.01942	 0.00264	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6026	 6182	 0.00598	 0.04088	 0.00695	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6026	 0.00321	 0.02074	 0.00396	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6026	 0.00321	 0.02074	 0.00396	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6027	 6181	 0.00709	 0.0494	 0.00808	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6028	 0.00239	 0.01662	 0.00272	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6028	 0.00239	 0.01662	 0.00272	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 6223	 0.00261	 0.01816	 0.00297	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 6223	 0.00261	 0.01816	 0.00297	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 6289	 0.0098	 0.05596	 0.00841	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6029	 6221	 0.02678	 0.11107	 0.01885	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6329	 6029	 0.01886	 0.07826	 0.01328	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 6030	 0.00319	 0.1363	 0.0	 124.0	 124.0	 124.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6030	 6172	 0.00307	 0.02195	 0.04002	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 6188	 0.01107	 0.07911	 0.14424	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 7274	 0.0079	 0.05646	 0.10294	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6031	 0.03353	 0.08197	 0.01073	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 6207	 0.01092	 0.04528	 0.00768	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6217	 6032	 0.00379	 0.02164	 0.00325	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 6033	 0.00014	 0.00944	 0.0	 1058.0	 1058.0	 1058.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6107	 6033	 0.00039	 0.00803	 0.56039	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 6342	 0.00011	 0.00135	 0.0896	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 6034	 0.0004	 0.01618	 0.0	 540.0	 540.0	 540.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6035	 6034	 0.0004	 0.01618	 0.0	 540.0	 540.0	 540.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6108	 6034	 0.00498	 0.04865	 0.0936	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 6119	 0.00307	 0.02194	 0.04	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 6255	 0.00338	 0.02413	 0.044	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6034	 6343	 0.00082	 0.00798	 0.01535	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6035	 0.00446	 0.03049	 0.00519	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6035	 0.00446	 0.03049	 0.00519	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6035	 0.00473	 0.03056	 0.00583	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6123	 6035	 0.00473	 0.03056	 0.00583	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6035	 6306	 0.00918	 0.05241	 0.00787	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 6036	 0.00033	 0.0183	 0.0	 467.0	 467.0	 467.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6037	 6036	 0.00033	 0.0183	 0.0	 467.0	 467.0	 467.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6037	 6036	 0.00033	 0.0183	 0.0	 467.0	 467.0	 467.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6036	 6067	 0.00172	 0.01789	 0.06095	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6142	 0.00123	 0.01275	 0.04344	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6142	 0.00123	 0.01275	 0.04344	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6287	 6036	 0.00203	 0.01984	 0.03818	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 6334	 0.00352	 0.02515	 0.04586	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6037	 0.00228	 0.01555	 0.00264	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6037	 0.00228	 0.01555	 0.00264	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6037	 0.00245	 0.01672	 0.00284	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6037	 0.00245	 0.01672	 0.00284	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6037	 0.00245	 0.01672	 0.00284	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6039	 6038	 0.00027	 0.0133	 0.0	 1269.0	 1269.0	 1269.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6041	 6038	 0.0004	 0.02009	 0.0	 296.0	 296.0	 296.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6042	 6038	 0.00042	 0.03102	 0.0	 479.0	 479.0	 479.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6038	 6066	 0.00105	 0.01278	 0.84902	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6254	 6038	 0.00024	 0.00295	 0.19592	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 6038	 0.00017	 0.002	 0.13292	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 6039	 0.00064	 0.0344	 0.0	 271.8	 271.8	 271.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6040	 6039	 0.00064	 0.0344	 0.0	 271.8	 271.8	 271.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 6039	 0.00129	 0.00919	 0.01675	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6040	 6224	 0.00927	 0.03846	 0.00653	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 6236	 0.0039	 0.02665	 0.00453	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6043	 6236	 0.0039	 0.02665	 0.00453	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6335	 6043	 0.00217	 0.01509	 0.00247	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6335	 6043	 0.00217	 0.01509	 0.00247	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 6203	 0.00617	 0.02696	 0.00411	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 6044	 0.00268	 0.01111	 0.00189	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 6284	 0.00593	 0.02596	 0.00395	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 6323	 0.0021	 0.01432	 0.00244	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 6323	 0.0021	 0.01432	 0.00244	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 6045	 8e-05	 0.0073	 0.0	 1198.0	 1198.0	 1198.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6048	 6045	 0.0014	 0.07775	 0.0	 233.0	 233.0	 233.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6049	 6045	 0.00046	 0.04414	 0.0	 283.0	 283.0	 283.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6050	 6045	 0.00056	 0.04367	 0.0	 256.0	 256.0	 256.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6051	 6045	 0.00035	 0.0254	 0.0	 351.0	 351.0	 351.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6052	 6045	 0.00074	 0.03404	 0.0	 342.0	 342.0	 342.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6053	 6045	 0.00028	 0.02922	 0.0	 352.0	 352.0	 352.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6054	 6045	 0.00061	 0.05567	 0.0	 338.0	 338.0	 338.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6066	 6045	 0.00059	 0.00714	 0.47436	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6210	 6045	 0.00142	 0.01727	 1.14708	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 6234	 0.00031	 0.0037	 0.24613	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 6046	 0.00056	 0.0418	 0.0	 320.0	 320.0	 320.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6047	 6046	 0.00056	 0.0418	 0.0	 320.0	 320.0	 320.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6198	 6046	 0.00141	 0.01004	 0.0183	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 6285	 0.00296	 0.02891	 0.05562	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 6150	 0.00335	 0.02337	 0.00382	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6047	 6150	 0.00335	 0.02337	 0.00382	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 6047	 0.00187	 0.01206	 0.0023	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 6047	 0.00187	 0.01206	 0.0023	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6226	 6055	 0.018	 0.10807	 0.01467	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6055	 6286	 0.00882	 0.0504	 0.00757	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 6056	 0.00023	 0.01095	 0.0	 1171.0	 1171.0	 1171.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6056	 6066	 0.00014	 0.00165	 0.10973	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6161	 6056	 0.00011	 0.00227	 0.15827	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6298	 6056	 8e-05	 0.001	 0.06674	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6057	 0.00061	 0.02173	 0.0	 328.0	 328.0	 328.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6058	 6057	 0.00061	 0.02173	 0.0	 328.0	 328.0	 328.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6067	 6057	 0.001	 0.00977	 0.01879	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 6177	 0.00628	 0.06139	 0.11812	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6124	 0.00613	 0.04269	 0.00698	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6124	 0.00613	 0.04269	 0.00698	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6058	 6124	 0.00613	 0.04269	 0.00698	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6300	 6058	 0.00293	 0.01895	 0.00362	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6357	 6059	 0.01709	 0.07089	 0.01203	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6060	 6157	 0.00969	 0.05535	 0.00832	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6314	 6060	 0.00648	 0.02889	 0.00424	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6219	 0.00959	 0.02345	 0.00307	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 6224	 0.01257	 0.03074	 0.00403	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 6062	 0.00012	 0.00745	 0.0	 1206.0	 1206.0	 1206.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6075	 6062	 0.0006	 0.00726	 0.48242	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 6062	 0.00097	 0.01173	 0.77933	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 6063	 0.00104	 0.04096	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6063	 6192	 0.00419	 0.04091	 0.07872	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8094	 6063	 0.00384	 0.03753	 0.07222	 800.0	 800.0	 800.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 6341	 0.01342	 0.05869	 0.00894	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 6262	 0.00781	 0.04461	 0.0067	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 6066	 0.00017	 0.00814	 0.0	 1115.0	 1115.0	 1115.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6069	 6066	 0.00023	 0.01215	 0.0	 667.0	 667.0	 667.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6070	 6066	 0.00044	 0.02944	 0.0	 677.0	 677.0	 677.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6071	 6066	 0.00013	 0.00964	 0.0	 670.0	 670.0	 670.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6072	 6066	 0.00026	 0.02419	 0.0	 679.0	 679.0	 679.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6073	 6066	 0.00026	 0.01616	 0.0	 664.0	 664.0	 664.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6074	 6066	 0.00036	 0.01602	 0.0	 666.0	 666.0	 666.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6068	 6067	 0.00105	 0.0432	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6068	 6067	 0.00105	 0.0432	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6279	 6067	 0.00289	 0.02062	 0.0376	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6076	 6075	 0.00022	 0.01507	 0.0	 1058.0	 1058.0	 1058.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6078	 6075	 0.00016	 0.01164	 0.0	 1159.0	 1159.0	 1159.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6079	 6075	 9e-05	 0.00542	 0.0	 1165.0	 1165.0	 1165.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6080	 6075	 8e-05	 0.0074	 0.0	 1152.0	 1152.0	 1152.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6075	 6101	 0.00034	 0.00413	 0.27429	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 6075	 0.00154	 0.01865	 1.23907	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6076	 0.0007	 0.0251	 0.0	 176.4	 176.4	 176.4	 1.0	 0.0	 1	 -30.0	 30.0;
	6102	 6076	 0.00351	 0.02507	 0.04571	 850.0	 850.0	 850.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6188	 6076	 0.00528	 0.03774	 0.0688	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6135	 0.01114	 0.04621	 0.00784	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6311	 0.01033	 0.04605	 0.00675	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 6081	 0.00602	 0.1165	 0.0	 80.0	 80.0	 80.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6083	 6081	 0.00631	 0.2531	 0.0	 80.0	 80.0	 80.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6081	 6156	 0.00412	 0.01838	 0.0027	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6081	 0.00581	 0.0241	 0.00409	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6085	 6084	 0.01088	 0.45298	 0.0	 31.0	 31.0	 31.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6086	 6084	 0.00567	 0.21309	 0.0	 41.0	 41.0	 41.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6087	 6084	 0.01529	 0.2834	 0.0	 43.0	 43.0	 43.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6088	 6084	 0.00292	 0.0945	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6089	 6084	 0.00558	 0.2567	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6090	 6084	 0.00213	 0.09907	 0.0	 46.0	 46.0	 46.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6084	 6136	 0.00536	 0.03659	 0.00622	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 6355	 0.00317	 0.01386	 0.00211	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6091	 6176	 0.01965	 0.04804	 0.00629	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 6091	 0.00626	 0.03578	 0.00538	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 6092	 0.03066	 0.13415	 0.02043	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6092	 6340	 0.02123	 0.09289	 0.01415	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6093	 0.01077	 0.02588	 0.00351	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6093	 6191	 0.00537	 0.02229	 0.00378	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6352	 0.00312	 0.02171	 0.00355	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 6352	 0.00312	 0.02171	 0.00355	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6116	 6095	 0.02712	 0.06628	 0.00868	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6353	 0.00442	 0.03018	 0.00514	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6353	 0.00442	 0.03018	 0.00514	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6358	 0.00976	 0.04048	 0.00687	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 6096	 0.02156	 0.08942	 0.01517	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 6202	 0.01774	 0.10129	 0.01522	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6096	 6340	 0.02271	 0.13634	 0.0185	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 6220	 0.00366	 0.025	 0.00425	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 6220	 0.00366	 0.025	 0.00425	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6097	 6225	 0.01044	 0.04569	 0.00696	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6123	 0.00317	 0.02048	 0.00391	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6123	 0.00317	 0.02048	 0.00391	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6208	 0.00691	 0.01691	 0.00221	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6098	 6289	 0.00552	 0.02415	 0.00368	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6204	 0.00266	 0.01519	 0.00228	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6225	 0.0031	 0.01769	 0.00266	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6099	 6310	 0.00667	 0.02767	 0.0047	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 6128	 0.01671	 0.10034	 0.01362	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6100	 0.00956	 0.0418	 0.00637	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 6100	 0.00566	 0.0323	 0.00485	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 6101	 0.00013	 0.0085	 0.0	 1307.0	 1307.0	 1307.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6104	 6101	 0.00031	 0.02423	 0.0	 378.0	 378.0	 378.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6105	 6101	 0.00037	 0.03898	 0.0	 368.0	 368.0	 368.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6106	 6101	 0.00018	 0.00963	 0.0	 560.0	 560.0	 560.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6103	 6102	 0.00102	 0.04506	 0.0	 439.0	 439.0	 439.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6103	 6117	 0.00862	 0.06005	 0.00982	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 6117	 0.00862	 0.06005	 0.00982	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6103	 6183	 0.01177	 0.05149	 0.00784	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 6107	 0.00061	 0.04374	 0.0	 380.0	 380.0	 380.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6110	 6107	 0.00015	 0.01079	 0.0	 1181.0	 1181.0	 1181.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6111	 6107	 0.00014	 0.01069	 0.0	 1208.0	 1208.0	 1208.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6107	 8082	 0.00113	 0.01368	 0.90909	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6109	 6108	 0.00252	 0.10367	 0.0	 137.0	 137.0	 137.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6108	 6192	 0.00493	 0.03524	 0.06426	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 6109	 0.03888	 0.09504	 0.01244	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 6175	 0.00078	 0.00501	 0.00096	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 6175	 0.00078	 0.00501	 0.00096	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 6345	 0.00258	 0.01129	 0.00172	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6204	 0.01029	 0.04585	 0.00672	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 6261	 0.00516	 0.03097	 0.0042	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6115	 0.00432	 0.02954	 0.00503	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6159	 6115	 0.00432	 0.02954	 0.00503	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6191	 0.0085	 0.03718	 0.00566	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6225	 0.0095	 0.05707	 0.00774	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 6250	 0.00313	 0.01394	 0.00204	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6181	 6116	 0.01119	 0.06392	 0.00961	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 6118	 0.00021	 0.01219	 0.0	 1133.0	 1133.0	 1133.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6118	 6349	 9e-05	 0.00182	 0.12727	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6119	 0.00056	 0.0289	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6120	 6119	 0.00056	 0.0289	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6119	 6354	 0.00095	 0.00925	 0.01779	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 6120	 0.00336	 0.02297	 0.00391	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 6120	 0.00336	 0.02297	 0.00391	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6174	 0.00587	 0.03351	 0.00504	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6121	 6179	 0.0239	 0.05842	 0.00765	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6121	 0.0032	 0.02187	 0.00372	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6220	 6121	 0.0032	 0.02187	 0.00372	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 6327	 0.03109	 0.07602	 0.00995	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7337	 6122	 0.02322	 0.13264	 0.01993	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 6123	 0.00405	 0.02315	 0.00348	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6131	 0.01842	 0.07644	 0.01297	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 6124	 0.00835	 0.05393	 0.01029	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 6314	 0.01906	 0.08338	 0.0127	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6180	 6125	 0.00599	 0.02482	 0.00421	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 6322	 0.01845	 0.08069	 0.01229	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6130	 0.00394	 0.01755	 0.00257	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6176	 0.00718	 0.05004	 0.00818	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6176	 0.00718	 0.05004	 0.00818	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6313	 0.00918	 0.0551	 0.00748	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 6237	 0.01441	 0.08233	 0.01237	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 6127	 0.01299	 0.07418	 0.01115	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6127	 8102	 0.03512	 0.08585	 0.01124	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 6276	 0.01619	 0.03957	 0.00518	 200.0	 200.0	 200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6309	 0.02452	 0.10724	 0.01633	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 6336	 0.01251	 0.07513	 0.0102	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6230	 0.0041	 0.035	 0.0058	 230.0	 230.0	 230.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6130	 6231	 0.00525	 0.02339	 0.00343	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6131	 6251	 0.02579	 0.06305	 0.00826	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6132	 6137	 0.00931	 0.05592	 0.00759	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6132	 0.00341	 0.01491	 0.00227	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6133	 0.01462	 0.06065	 0.01029	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6140	 0.01102	 0.04818	 0.00734	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6134	 6358	 0.01529	 0.06688	 0.01019	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 6135	 0.018	 0.07467	 0.01267	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6358	 6136	 0.00974	 0.04339	 0.00636	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6184	 0.01801	 0.04326	 0.00587	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6217	 0.00779	 0.01906	 0.0025	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6157	 6138	 0.03762	 0.09196	 0.01204	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6138	 6286	 0.02051	 0.0914	 0.0134	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6139	 6339	 0.01781	 0.10172	 0.01528	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 6141	 0.0002	 0.00909	 0.0	 1326.0	 1326.0	 1326.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6142	 6141	 0.0002	 0.00909	 0.0	 1326.0	 1326.0	 1326.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6144	 6141	 0.00106	 0.04778	 0.0	 265.0	 265.0	 265.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6145	 6141	 0.00027	 0.01788	 0.0	 1093.0	 1093.0	 1093.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6146	 6141	 0.00024	 0.01722	 0.0	 1090.0	 1090.0	 1090.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6147	 6141	 0.0002	 0.01493	 0.0	 1332.0	 1332.0	 1332.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6148	 6141	 0.00013	 0.00914	 0.0	 1248.0	 1248.0	 1248.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6149	 6141	 4e-05	 0.00474	 0.0	 1255.0	 1255.0	 1255.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6141	 6161	 0.00052	 0.00627	 0.4163	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6141	 6197	 0.00014	 0.00318	 0.27573	 4352.0	 4352.0	 4352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6239	 6141	 0.00025	 0.00304	 0.20218	 2400.0	 2400.0	 2400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6142	 0.0003	 0.02159	 0.0	 443.0	 443.0	 443.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6143	 6142	 0.0003	 0.02159	 0.0	 443.0	 443.0	 443.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6143	 6142	 0.0003	 0.02159	 0.0	 443.0	 443.0	 443.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6142	 6162	 0.00533	 0.03805	 0.06937	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6284	 0.00613	 0.04273	 0.00699	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 6284	 0.00613	 0.04273	 0.00699	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 6143	 0.00214	 0.01491	 0.00244	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 6143	 0.00214	 0.01491	 0.00244	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 6143	 0.00214	 0.01491	 0.00244	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 6143	 0.00214	 0.01491	 0.00244	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 6356	 0.00408	 0.02634	 0.00503	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 6356	 0.00408	 0.02634	 0.00503	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 6151	 0.01488	 0.06632	 0.00972	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 6311	 0.02053	 0.09148	 0.01341	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6327	 6151	 0.05056	 0.12359	 0.01618	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 6152	 0.00286	 0.10993	 0.0	 155.0	 155.0	 155.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6152	 6177	 0.00504	 0.036	 0.06563	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 6198	 0.00248	 0.02429	 0.04673	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6153	 0.0044	 0.03067	 0.00501	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6153	 0.0044	 0.03067	 0.00501	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 6324	 0.00612	 0.0418	 0.00711	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 6324	 0.00612	 0.0418	 0.00711	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 6154	 0.01188	 0.04928	 0.00836	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6252	 6154	 0.02199	 0.0912	 0.01548	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6155	 6284	 0.00973	 0.05559	 0.00835	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6156	 6282	 0.00873	 0.05961	 0.01014	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 6341	 0.02816	 0.06884	 0.00901	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 6158	 0.00916	 0.05232	 0.00786	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6281	 6159	 0.00206	 0.00903	 0.00138	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6175	 0.00216	 0.01479	 0.00252	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6175	 0.00216	 0.01479	 0.00252	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6233	 0.00526	 0.02342	 0.00343	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6160	 6330	 0.00719	 0.03146	 0.00479	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6162	 6161	 0.00024	 0.01685	 0.0	 1132.0	 1132.0	 1132.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6164	 6161	 0.00022	 0.01652	 0.0	 880.0	 880.0	 880.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6165	 6161	 0.00034	 0.01841	 0.0	 879.0	 879.0	 879.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6166	 6161	 0.00011	 0.00775	 0.0	 880.0	 880.0	 880.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6167	 6161	 0.0002	 0.01447	 0.0	 883.0	 883.0	 883.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6161	 7018	 0.00084	 0.01712	 1.19421	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6163	 6162	 0.00109	 0.04275	 0.0	 184.2	 184.2	 184.2	 1.0	 0.0	 1	 -30.0	 30.0;
	6162	 6277	 0.00506	 0.03614	 0.0659	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6279	 6162	 0.00087	 0.00624	 0.01138	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6280	 6163	 0.00495	 0.02053	 0.00348	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6209	 0.01804	 0.07482	 0.0127	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6168	 6261	 0.00295	 0.00722	 0.00094	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 6169	 0.00027	 0.01779	 0.0	 1108.0	 1108.0	 1108.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6169	 6239	 0.00065	 0.00782	 0.51936	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6171	 6170	 0.00057	 0.03437	 0.0	 297.0	 297.0	 297.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6170	 6235	 0.0015	 0.01464	 0.02816	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6308	 6170	 0.00343	 0.02448	 0.04463	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6170	 6334	 0.00357	 0.02552	 0.04652	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 6171	 0.00723	 0.05035	 0.00823	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6173	 6172	 0.0013	 0.05717	 0.0	 137.0	 137.0	 137.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6173	 6265	 0.00345	 0.01429	 0.00242	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7020	 6173	 0.03858	 0.09432	 0.01235	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6203	 0.00829	 0.02025	 0.00265	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6250	 0.00258	 0.01476	 0.00222	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6320	 0.00372	 0.02404	 0.00459	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 6320	 0.00372	 0.02404	 0.00459	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6194	 0.01297	 0.05381	 0.00913	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 6289	 0.01181	 0.02887	 0.00378	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6176	 0.0023	 0.016	 0.0026	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6177	 0.00082	 0.04251	 0.0	 172.8	 172.8	 172.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6178	 6177	 0.00082	 0.04251	 0.0	 172.8	 172.8	 172.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6235	 6177	 0.00202	 0.01441	 0.02628	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6287	 0.00317	 0.02266	 0.04132	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6299	 0.00682	 0.06665	 0.12825	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6308	 0.00546	 0.03901	 0.07112	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6334	 6177	 0.00073	 0.00718	 0.01381	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 6209	 0.00915	 0.04079	 0.00598	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 6178	 0.00369	 0.02383	 0.00455	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6291	 6179	 0.00323	 0.0194	 0.00263	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 6201	 0.00497	 0.02172	 0.00331	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6183	 6206	 0.01289	 0.07363	 0.01106	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6185	 0.01258	 0.03077	 0.00403	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6205	 0.00904	 0.04029	 0.00591	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 6219	 0.02323	 0.05678	 0.00744	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 6313	 0.01416	 0.03461	 0.00453	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6187	 0.00175	 0.01131	 0.00216	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6187	 0.00175	 0.01131	 0.00216	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6351	 0.00169	 0.0118	 0.00193	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 6351	 0.00169	 0.0118	 0.00193	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6219	 0.00752	 0.03293	 0.00502	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6187	 6289	 0.00637	 0.02643	 0.00449	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6189	 6188	 0.00227	 0.06067	 0.0	 178.0	 178.0	 178.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6188	 7305	 0.00756	 0.05401	 0.09846	 460.0	 460.0	 460.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6327	 6189	 0.01842	 0.11058	 0.01501	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 6192	 0.00113	 0.06451	 0.0	 125.0	 125.0	 125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6193	 6206	 0.01507	 0.09046	 0.01228	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6193	 6326	 0.03488	 0.08525	 0.01116	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 6194	 0.01994	 0.08268	 0.01403	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6194	 6231	 0.00815	 0.03567	 0.00543	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6194	 0.00593	 0.04134	 0.00676	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6195	 7314	 0.01465	 0.06078	 0.01031	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 6197	 0.00015	 0.01413	 0.0	 1372.0	 1372.0	 1372.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6197	 6234	 0.00025	 0.003	 0.19905	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6197	 6333	 0.00012	 0.00144	 0.09542	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6199	 6198	 0.00048	 0.01693	 0.0	 420.0	 420.0	 420.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6199	 6198	 0.00048	 0.01693	 0.0	 420.0	 420.0	 420.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6199	 6198	 0.00048	 0.01693	 0.0	 420.0	 420.0	 420.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6287	 6198	 0.00092	 0.00901	 0.01734	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6337	 6199	 0.00218	 0.01487	 0.00253	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6337	 6199	 0.00218	 0.01487	 0.00253	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6225	 0.00252	 0.01513	 0.00205	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6275	 0.00286	 0.01632	 0.00245	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6200	 6284	 0.00797	 0.03555	 0.00521	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 6203	 0.01894	 0.04631	 0.00606	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6201	 6356	 0.00518	 0.02956	 0.00444	 245.0	 245.0	 245.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6280	 6202	 0.02835	 0.06931	 0.00908	 115.0	 115.0	 115.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6340	 6202	 0.01509	 0.08621	 0.01295	 115.0	 115.0	 115.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6204	 6337	 0.00539	 0.03236	 0.00439	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 6223	 0.00232	 0.01501	 0.00286	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 6223	 0.00232	 0.01501	 0.00286	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 6282	 0.01027	 0.04493	 0.00684	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 6313	 0.0096	 0.05765	 0.00782	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6331	 6208	 0.00218	 0.0152	 0.00249	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6331	 6208	 0.00218	 0.0152	 0.00249	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6208	 6353	 0.0108	 0.04812	 0.00706	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6309	 6209	 0.018	 0.078	 0.012	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 6210	 0.0003	 0.01639	 0.0	 978.0	 978.0	 978.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6213	 6210	 0.00066	 0.04478	 0.0	 363.0	 363.0	 363.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6214	 6210	 0.00044	 0.02757	 0.0	 718.0	 718.0	 718.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6215	 6210	 0.0001	 0.0071	 0.0	 721.0	 721.0	 721.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6216	 6210	 0.00021	 0.01596	 0.0	 710.0	 710.0	 710.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6210	 6292	 0.00114	 0.01377	 0.91489	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6212	 6211	 0.00083	 0.03328	 0.0	 381.0	 381.0	 381.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6211	 6359	 0.00367	 0.02624	 0.04784	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6218	 6231	 0.02084	 0.09119	 0.01389	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6278	 6218	 0.00985	 0.04084	 0.00693	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6219	 6345	 0.00408	 0.02332	 0.0035	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6221	 6322	 0.01605	 0.09634	 0.01307	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6223	 6222	 0.00029	 0.0171	 0.0	 457.0	 457.0	 457.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6223	 6222	 0.00029	 0.0171	 0.0	 457.0	 457.0	 457.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6223	 6222	 0.00029	 0.0171	 0.0	 457.0	 457.0	 457.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6222	 6229	 0.00375	 0.03669	 0.07059	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6222	 0.00167	 0.01635	 0.03146	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6293	 0.00233	 0.0228	 0.04388	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6222	 6354	 0.00491	 0.03508	 0.06396	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 6223	 0.00231	 0.01613	 0.00264	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 6223	 0.00231	 0.01613	 0.00264	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 6331	 0.00467	 0.01938	 0.00329	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6225	 6307	 0.00669	 0.0298	 0.00437	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 6238	 0.00232	 0.01616	 0.00264	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 6238	 0.00232	 0.01616	 0.00264	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6227	 6330	 0.01472	 0.036	 0.00471	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 6228	 0.00011	 0.01313	 0.0	 1208.0	 1208.0	 1208.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6298	 6228	 0.00022	 0.00262	 0.17409	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6229	 0.00061	 0.03602	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6230	 6229	 0.00061	 0.03602	 0.0	 350.0	 350.0	 350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6277	 6229	 0.00147	 0.01434	 0.0276	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 6278	 0.009	 0.05404	 0.00733	 140.0	 140.0	 140.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6294	 0.00252	 0.01629	 0.00311	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 6294	 0.00252	 0.01629	 0.00311	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 6234	 6e-05	 0.00475	 0.0	 1190.0	 1190.0	 1190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6236	 6235	 0.00075	 0.02962	 0.0	 406.0	 406.0	 406.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6236	 6235	 0.00075	 0.02962	 0.0	 406.0	 406.0	 406.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6325	 6237	 0.01418	 0.05883	 0.00998	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 8102	 0.02383	 0.14308	 0.01942	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6238	 6345	 0.00383	 0.02298	 0.00312	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6239	 0.00028	 0.01264	 0.0	 1194.0	 1194.0	 1194.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6242	 6239	 0.0004	 0.04713	 0.0	 380.0	 380.0	 380.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6243	 6239	 0.00024	 0.01934	 0.0	 690.0	 690.0	 690.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6244	 6239	 0.00024	 0.01637	 0.0	 957.0	 957.0	 957.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6245	 6239	 0.00021	 0.01383	 0.0	 965.0	 965.0	 965.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6246	 6239	 0.00011	 0.00711	 0.0	 967.0	 967.0	 967.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6247	 6239	 0.00014	 0.00867	 0.0	 694.0	 694.0	 694.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6248	 6239	 0.00018	 0.01749	 0.0	 689.0	 689.0	 689.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6249	 6239	 0.00046	 0.02531	 0.0	 685.0	 685.0	 685.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6239	 7414	 0.0015	 0.019	 1.24	 2000.0	 2000.0	 2000.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 6240	 0.00111	 0.05088	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6241	 6240	 0.00111	 0.05088	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6240	 6287	 0.00218	 0.02128	 0.04095	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 6321	 0.00473	 0.03381	 0.06164	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 6329	 0.01564	 0.06488	 0.01101	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6255	 6254	 4e-05	 0.00481	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6257	 6254	 0.00011	 0.01147	 0.0	 726.0	 726.0	 726.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6258	 6254	 0.00037	 0.02186	 0.0	 731.0	 731.0	 731.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6259	 6254	 0.00044	 0.02142	 0.0	 333.0	 333.0	 333.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6260	 6254	 0.00018	 0.01038	 0.0	 914.0	 914.0	 914.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6292	 6254	 7e-05	 0.00142	 0.09917	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6256	 6255	 0.00085	 0.04835	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6256	 6255	 0.00085	 0.04835	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6262	 6319	 0.01214	 0.07287	 0.00989	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 6263	 0.00081	 0.03319	 0.0	 120.0	 120.0	 120.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6321	 6263	 0.00395	 0.03863	 0.07433	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 7274	 0.00452	 0.04698	 0.16009	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6266	 6265	 0.00703	 0.24052	 0.0	 29.0	 29.0	 29.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6267	 6265	 0.01927	 0.55179	 0.0	 35.0	 35.0	 35.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6268	 6265	 0.00822	 0.17407	 0.0	 30.0	 30.0	 30.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6269	 6265	 0.0207	 0.59011	 0.0	 32.0	 32.0	 32.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6270	 6265	 0.01825	 0.32424	 0.0	 47.0	 47.0	 47.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6271	 6265	 0.00336	 0.1392	 0.0	 42.0	 42.0	 42.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6272	 6265	 0.00455	 0.19054	 0.0	 35.0	 35.0	 35.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6273	 6265	 0.00863	 0.26216	 0.0	 32.0	 32.0	 32.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6274	 6265	 0.00902	 0.4175	 0.0	 39.0	 39.0	 39.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6275	 6324	 0.00458	 0.02955	 0.00564	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 6324	 0.00458	 0.02955	 0.00564	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6278	 6277	 0.00046	 0.02831	 0.0	 331.0	 331.0	 331.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6280	 6279	 0.00106	 0.03718	 0.0	 163.2	 163.2	 163.2	 1.0	 0.0	 1	 -30.0	 30.0;
	6279	 6299	 0.00218	 0.02135	 0.04107	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 6285	 0.00032	 0.0236	 0.0	 311.0	 311.0	 311.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6328	 6286	 0.0331	 0.08092	 0.0106	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 6287	 0.00058	 0.03855	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6288	 6287	 0.00058	 0.03855	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6288	 6307	 0.00199	 0.01356	 0.00231	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 6307	 0.00199	 0.01356	 0.00231	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 6323	 0.0013	 0.00886	 0.00151	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 6323	 0.0013	 0.00886	 0.00151	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 6331	 0.00175	 0.01218	 0.00199	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6290	 6331	 0.00175	 0.01218	 0.00199	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6293	 6292	 0.0002	 0.01411	 0.0	 1210.0	 1210.0	 1210.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6295	 6292	 0.00017	 0.00896	 0.0	 756.0	 756.0	 756.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6296	 6292	 0.00013	 0.00766	 0.0	 762.0	 762.0	 762.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6297	 6292	 0.00029	 0.02084	 0.0	 765.0	 765.0	 765.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6294	 6293	 0.00058	 0.02427	 0.0	 217.8	 217.8	 217.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6294	 6339	 0.01129	 0.02712	 0.00368	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6299	 6298	 0.0002	 0.01939	 0.0	 994.0	 994.0	 994.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6301	 6298	 0.00035	 0.02541	 0.0	 225.0	 225.0	 225.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6302	 6298	 0.00029	 0.02162	 0.0	 897.0	 897.0	 897.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6303	 6298	 0.0001	 0.00733	 0.0	 887.0	 887.0	 887.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6304	 6298	 0.00026	 0.01816	 0.0	 896.0	 896.0	 896.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6305	 6298	 0.00037	 0.02188	 0.0	 904.0	 904.0	 904.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6300	 6299	 0.00189	 0.06692	 0.0	 181.0	 181.0	 181.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6309	 6308	 0.00086	 0.06271	 0.0	 122.4	 122.4	 122.4	 1.0	 0.0	 1	 -30.0	 30.0;
	6310	 6312	 0.00222	 0.01548	 0.00253	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6310	 6312	 0.00222	 0.01548	 0.00253	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6320	 6312	 0.00148	 0.01008	 0.00171	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6320	 6312	 0.00148	 0.01008	 0.00171	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6316	 6315	 0.00143	 0.0765	 0.0	 251.0	 251.0	 251.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6343	 6315	 0.00542	 0.0387	 0.07055	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6317	 6316	 0.00181	 0.06783	 0.0	 189.0	 189.0	 189.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6318	 6317	 0.00192	 0.08014	 0.0	 198.0	 198.0	 198.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6319	 6318	 0.00221	 0.05812	 0.0	 163.0	 163.0	 163.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6324	 6320	 0.00553	 0.02416	 0.00368	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6322	 6321	 0.00114	 0.03057	 0.0	 249.0	 249.0	 249.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8140	 6326	 0.02706	 0.06615	 0.00866	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6336	 6328	 0.02009	 0.12065	 0.01637	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6334	 6333	 0.00033	 0.01665	 0.0	 1094.0	 1094.0	 1094.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6335	 6334	 0.00063	 0.03435	 0.0	 271.8	 271.8	 271.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6341	 7202	 0.01405	 0.06262	 0.00918	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 6342	 0.00025	 0.01679	 0.0	 1137.0	 1137.0	 1137.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6344	 6343	 0.00028	 0.01611	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6344	 6343	 0.00028	 0.01611	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6343	 6350	 0.00292	 0.02086	 0.03803	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 6354	 0.00111	 0.0079	 0.01439	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 6353	 0.00211	 0.0144	 0.00245	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6344	 6353	 0.00211	 0.0144	 0.00245	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6350	 6349	 0.00019	 0.01229	 0.0	 1150.0	 1150.0	 1150.0	 1.0	 0.0	 1	 -30.0	 30.0;
	6351	 6350	 0.00179	 0.06637	 0.0	 155.4	 155.4	 155.4	 1.0	 0.0	 1	 -30.0	 30.0;
	6351	 6350	 0.00179	 0.06637	 0.0	 155.4	 155.4	 155.4	 1.0	 0.0	 1	 -30.0	 30.0;
	6350	 6359	 0.00816	 0.05827	 0.10623	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6355	 6354	 0.00076	 0.02753	 0.0	 193.8	 193.8	 193.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6355	 6354	 0.00076	 0.02753	 0.0	 193.8	 193.8	 193.8	 1.0	 0.0	 1	 -30.0	 30.0;
	6360	 6359	 0.00288	 0.10862	 0.0	 136.0	 136.0	 136.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7044	 7001	 0.00753	 0.043	 0.00646	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7149	 7001	 0.02671	 0.0653	 0.00855	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7001	 7337	 0.04314	 0.10362	 0.01406	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7003	 7002	 0.00022	 0.0149	 0.0	 1299.0	 1299.0	 1299.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7005	 7002	 0.00041	 0.02493	 0.0	 630.0	 630.0	 630.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7006	 7002	 0.00012	 0.01417	 0.0	 626.0	 626.0	 626.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7007	 7002	 0.00034	 0.02135	 0.0	 639.0	 639.0	 639.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7008	 7002	 0.00045	 0.02245	 0.0	 629.0	 629.0	 629.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7009	 7002	 0.00049	 0.02499	 0.0	 625.0	 625.0	 625.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7104	 7002	 3e-05	 0.0007	 0.04887	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7002	 7227	 0.00036	 0.00731	 0.51017	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7366	 7002	 0.00016	 0.00189	 0.12566	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7003	 0.0009	 0.03512	 0.0	 386.0	 386.0	 386.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7004	 7003	 0.0009	 0.03512	 0.0	 386.0	 386.0	 386.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7004	 7003	 0.0009	 0.03512	 0.0	 386.0	 386.0	 386.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7003	 7264	 0.00225	 0.01608	 0.02932	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7004	 0.00199	 0.01386	 0.00227	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7004	 0.00199	 0.01386	 0.00227	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7004	 0.00199	 0.01386	 0.00227	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7106	 0.0021	 0.01353	 0.00258	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7106	 0.0021	 0.01353	 0.00258	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7106	 0.0021	 0.01353	 0.00258	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7106	 0.0021	 0.01353	 0.00258	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7345	 0.00591	 0.04035	 0.00687	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7345	 0.00591	 0.04035	 0.00687	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 7345	 0.00591	 0.04035	 0.00687	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 7182	 0.01896	 0.11385	 0.01545	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 7202	 0.00553	 0.02294	 0.00389	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 7010	 0.00425	 0.01763	 0.00299	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7254	 7011	 0.00899	 0.04008	 0.00588	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7011	 7300	 0.00567	 0.0248	 0.00378	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7012	 7116	 0.00531	 0.03627	 0.00617	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7343	 7012	 0.00603	 0.04198	 0.00686	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 7201	 0.00433	 0.0302	 0.00494	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 7201	 0.00433	 0.0302	 0.00494	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7013	 7425	 0.003	 0.02091	 0.00342	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 7014	 0.00981	 0.21665	 0.0	 43.0	 43.0	 43.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7014	 7100	 0.00476	 0.03249	 0.00553	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 7100	 0.00476	 0.03249	 0.00553	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 7124	 0.01606	 0.03857	 0.00523	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 7217	 0.00415	 0.02371	 0.00356	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7365	 0.0068	 0.04642	 0.0079	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7365	 0.0068	 0.04642	 0.0079	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7365	 0.0068	 0.04642	 0.0079	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7365	 0.0068	 0.04642	 0.0079	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7016	 0.002	 0.01369	 0.00233	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7016	 0.002	 0.01369	 0.00233	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7016	 0.002	 0.01369	 0.00233	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7402	 0.00314	 0.02144	 0.00365	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 7402	 0.00314	 0.02144	 0.00365	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 7017	 0.0044	 0.01826	 0.0031	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7183	 0.00737	 0.04422	 0.006	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7229	 0.00604	 0.04129	 0.00702	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7229	 0.00604	 0.04129	 0.00702	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7229	 0.00604	 0.04129	 0.00702	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7241	 0.00382	 0.01669	 0.00254	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7385	 0.00298	 0.01922	 0.00367	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7017	 7385	 0.00298	 0.01922	 0.00367	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 7018	 0.00095	 0.04341	 0.0	 383.0	 383.0	 383.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7021	 7018	 0.00069	 0.05321	 0.0	 311.0	 311.0	 311.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7022	 7018	 0.0007	 0.05667	 0.0	 328.0	 328.0	 328.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7023	 7018	 0.00056	 0.03486	 0.0	 326.0	 326.0	 326.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7024	 7018	 0.00019	 0.01166	 0.0	 456.0	 456.0	 456.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7025	 7018	 0.00094	 0.07002	 0.0	 223.0	 223.0	 223.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7042	 7018	 0.00022	 0.00265	 0.17583	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7018	 7414	 0.00039	 0.00468	 0.3108	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7020	 7019	 0.00076	 0.04319	 0.0	 244.0	 244.0	 244.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7043	 7019	 0.00225	 0.01607	 0.0293	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 7274	 0.00332	 0.02368	 0.04318	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 7072	 0.0032	 0.02067	 0.00394	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 7072	 0.0032	 0.02067	 0.00394	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 7259	 0.01125	 0.07265	 0.01386	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7026	 0.00548	 0.0382	 0.00624	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7026	 0.00548	 0.0382	 0.00624	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 7157	 0.00228	 0.01559	 0.00265	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 7157	 0.00228	 0.01559	 0.00265	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 7234	 0.00431	 0.01886	 0.00287	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 7245	 0.00974	 0.04259	 0.00649	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 7431	 0.015	 0.06687	 0.00981	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 7028	 0.0011	 0.00768	 0.00126	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 7028	 0.0011	 0.00768	 0.00126	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7028	 7220	 0.00381	 0.02289	 0.00311	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7028	 7240	 0.00642	 0.01568	 0.00205	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7028	 7330	 0.01183	 0.02841	 0.00385	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 7029	 0.00115	 0.08558	 0.0	 126.6	 126.6	 126.6	 1.0	 0.0	 1	 -30.0	 30.0;
	7031	 7029	 0.00416	 0.1856	 0.0	 107.0	 107.0	 107.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7032	 7029	 0.00698	 0.23196	 0.0	 73.0	 73.0	 73.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7033	 7029	 0.00566	 0.21439	 0.0	 84.0	 84.0	 84.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7034	 7029	 0.00462	 0.30603	 0.0	 63.0	 63.0	 63.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7274	 7029	 0.00498	 0.03556	 0.06482	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 7407	 0.00374	 0.02669	 0.04866	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 7029	 0.00221	 0.01579	 0.02879	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7036	 7035	 0.00036	 0.02039	 0.0	 368.0	 368.0	 368.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7040	 7035	 0.00756	 0.05402	 0.09848	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7056	 7035	 0.00217	 0.01547	 0.02821	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 7390	 0.00154	 0.01505	 0.02896	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 8031	 0.00526	 0.05146	 0.09901	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7036	 7128	 0.005	 0.02228	 0.00327	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 7036	 0.00448	 0.03123	 0.00511	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7431	 7036	 0.00448	 0.03123	 0.00511	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 7037	 0.00016	 0.00995	 0.0	 1055.0	 1055.0	 1055.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7047	 7037	 0.00024	 0.00293	 0.19466	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7037	 7428	 0.0006	 0.01232	 0.85919	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7038	 0.00084	 0.02618	 0.0	 420.0	 420.0	 420.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7039	 7038	 0.00084	 0.02618	 0.0	 420.0	 420.0	 420.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7126	 7038	 0.00089	 0.00924	 0.03147	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 7038	 0.00089	 0.00924	 0.03147	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 7184	 0.00247	 0.02419	 0.04653	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7409	 7038	 0.0006	 0.00622	 0.02121	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7409	 7038	 0.0006	 0.00622	 0.02121	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7101	 0.00285	 0.01988	 0.00325	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7101	 0.00285	 0.01988	 0.00325	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7101	 0.00285	 0.01988	 0.00325	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7039	 7397	 0.02904	 0.06977	 0.00947	 240.0	 240.0	 240.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 7040	 0.00089	 0.03362	 0.0	 337.0	 337.0	 337.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7041	 7040	 0.00089	 0.03362	 0.0	 337.0	 337.0	 337.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7040	 7077	 0.00208	 0.02159	 0.07357	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 7077	 0.00208	 0.02159	 0.07357	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 7238	 0.01373	 0.06121	 0.00898	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7041	 0.00776	 0.05303	 0.00902	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 7041	 0.00776	 0.05303	 0.00902	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 7042	 8e-05	 0.00908	 0.0	 1048.0	 1048.0	 1048.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7045	 7042	 0.00029	 0.01951	 0.0	 729.0	 729.0	 729.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7046	 7042	 0.00013	 0.009	 0.0	 716.0	 716.0	 716.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7058	 7042	 0.0006	 0.00731	 0.48578	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7044	 7043	 0.00124	 0.05616	 0.0	 137.4	 137.4	 137.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7044	 7416	 0.01974	 0.04824	 0.00632	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7048	 7047	 0.00011	 0.00819	 0.0	 1125.0	 1125.0	 1125.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7199	 7047	 0.00024	 0.00294	 0.19535	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7049	 7048	 0.00068	 0.02653	 0.0	 466.0	 466.0	 466.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7049	 7048	 0.00068	 0.02653	 0.0	 466.0	 466.0	 466.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7228	 7048	 0.00068	 0.00665	 0.01279	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7048	 0.00134	 0.01309	 0.02519	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7049	 7089	 0.00671	 0.04677	 0.00764	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7049	 0.00436	 0.03039	 0.00497	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7049	 0.00436	 0.03039	 0.00497	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7049	 0.00436	 0.03039	 0.00497	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 7090	 0.00351	 0.02269	 0.00433	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 7090	 0.00351	 0.02269	 0.00433	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 7251	 0.01093	 0.04781	 0.00728	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 7086	 0.01063	 0.0465	 0.00708	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 7181	 0.00631	 0.03605	 0.00542	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7276	 7051	 0.00383	 0.01676	 0.00255	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 7365	 0.00182	 0.01243	 0.00211	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 7365	 0.00182	 0.01243	 0.00211	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7052	 7053	 0.00939	 0.06413	 0.01091	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7052	 7053	 0.00939	 0.06413	 0.01091	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7052	 7053	 0.00939	 0.06413	 0.01091	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7052	 7183	 0.00858	 0.03822	 0.0056	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7052	 7221	 0.00969	 0.0402	 0.00682	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 7052	 0.00256	 0.01655	 0.00316	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 7052	 0.00256	 0.01655	 0.00316	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7053	 7348	 0.00216	 0.01507	 0.00246	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7053	 7348	 0.00216	 0.01507	 0.00246	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7053	 7348	 0.00216	 0.01507	 0.00246	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7054	 7086	 0.01035	 0.06217	 0.00844	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7243	 7054	 0.00558	 0.03601	 0.00687	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7054	 7387	 0.00566	 0.0323	 0.00485	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 7124	 0.00357	 0.02439	 0.00415	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7055	 7124	 0.00357	 0.02439	 0.00415	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7055	 0.0014	 0.00978	 0.0016	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7055	 0.0014	 0.00978	 0.0016	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7055	 0.0014	 0.00978	 0.0016	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7055	 0.0014	 0.00978	 0.0016	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7250	 7055	 0.00146	 0.01001	 0.0017	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7250	 7055	 0.00146	 0.01001	 0.0017	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7057	 7056	 0.00161	 0.04976	 0.0	 377.0	 377.0	 377.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7056	 7156	 0.00287	 0.02047	 0.03732	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7056	 7160	 0.00187	 0.01944	 0.06623	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7056	 7420	 0.0013	 0.0093	 0.01695	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 7057	 0.00223	 0.01557	 0.00254	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 7057	 0.00223	 0.01557	 0.00254	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7059	 7058	 0.0002	 0.01603	 0.0	 605.0	 605.0	 605.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7061	 7058	 0.0003	 0.02449	 0.0	 535.0	 535.0	 535.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7062	 7058	 0.0003	 0.02239	 0.0	 531.0	 531.0	 531.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7063	 7058	 0.00039	 0.02417	 0.0	 527.0	 527.0	 527.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7064	 7058	 0.00017	 0.01851	 0.0	 530.0	 530.0	 530.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7065	 7058	 0.00031	 0.02035	 0.0	 520.0	 520.0	 520.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7066	 7058	 0.0003	 0.02188	 0.0	 542.0	 542.0	 542.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7058	 7095	 0.00064	 0.00771	 0.5124	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7406	 7058	 6e-05	 0.00073	 0.04856	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7060	 7059	 0.00168	 0.05948	 0.0	 188.0	 188.0	 188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7059	 7407	 0.00062	 0.00444	 0.00809	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 7060	 0.01191	 0.05306	 0.00778	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 7245	 0.00829	 0.04734	 0.00711	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 7291	 0.00748	 0.04274	 0.00642	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 7344	 0.01002	 0.02449	 0.00321	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7069	 7068	 0.0023	 0.07154	 0.0	 145.8	 145.8	 145.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7305	 7068	 0.0021	 0.0205	 0.03945	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7069	 7413	 0.01312	 0.05846	 0.00857	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7100	 0.00621	 0.04324	 0.00707	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7257	 0.00619	 0.03538	 0.00532	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7317	 0.00528	 0.03607	 0.00614	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7070	 7398	 0.00238	 0.01063	 0.00156	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 7071	 0.0119	 0.02858	 0.00388	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7408	 7071	 0.03482	 0.08511	 0.01114	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7072	 7084	 0.00344	 0.02395	 0.00391	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7072	 7084	 0.00344	 0.02395	 0.00391	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 7073	 0.00062	 0.03776	 0.0	 185.0	 185.0	 185.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7171	 7073	 0.0022	 0.01575	 0.02871	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 7073	 0.00402	 0.03929	 0.07559	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7405	 7074	 0.00499	 0.02067	 0.00351	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7387	 0.01167	 0.07976	 0.01357	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7387	 0.01167	 0.07976	 0.01357	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7398	 0.00592	 0.03823	 0.00729	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7075	 7398	 0.00592	 0.03823	 0.00729	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7077	 7076	 7e-05	 0.00459	 0.0	 1233.0	 1233.0	 1233.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7079	 7076	 0.00024	 0.01675	 0.0	 855.0	 855.0	 855.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7080	 7076	 0.00037	 0.02147	 0.0	 857.0	 857.0	 857.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7081	 7076	 0.0003	 0.02166	 0.0	 863.0	 863.0	 863.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7082	 7076	 0.00028	 0.01719	 0.0	 847.0	 847.0	 847.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7204	 7076	 0.00014	 0.00172	 0.1143	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7076	 7422	 0.00061	 0.00741	 0.49226	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 7077	 0.0011	 0.04562	 0.0	 220.0	 220.0	 220.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7077	 7282	 0.00125	 0.00896	 0.01633	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 7078	 0.00828	 0.03692	 0.00541	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 7279	 0.00273	 0.01863	 0.00317	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 7279	 0.00273	 0.01863	 0.00317	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7084	 7083	 0.00053	 0.03003	 0.0	 355.0	 355.0	 355.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7084	 7083	 0.00053	 0.03003	 0.0	 355.0	 355.0	 355.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7083	 7105	 0.00233	 0.0228	 0.04386	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7083	 7171	 0.00193	 0.01885	 0.03628	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7083	 7184	 0.00606	 0.04326	 0.07887	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7083	 7264	 0.0013	 0.01272	 0.02448	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 7083	 0.00173	 0.01235	 0.02252	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7085	 7244	 0.01057	 0.07367	 0.01204	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7085	 7244	 0.01057	 0.07367	 0.01204	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7412	 7085	 0.00305	 0.02125	 0.00347	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7412	 7085	 0.00305	 0.02125	 0.00347	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7086	 7222	 0.00549	 0.02279	 0.00387	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7086	 7419	 0.01003	 0.0648	 0.01236	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7086	 7419	 0.01003	 0.0648	 0.01236	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7127	 0.00301	 0.01945	 0.00371	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7221	 0.00412	 0.02872	 0.00469	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7221	 0.00412	 0.02872	 0.00469	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7221	 0.00412	 0.02872	 0.00469	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7336	 0.00167	 0.01143	 0.00194	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7336	 0.00167	 0.01143	 0.00194	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7336	 0.00167	 0.01143	 0.00194	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7336	 0.00167	 0.01143	 0.00194	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7087	 7336	 0.00167	 0.01143	 0.00194	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 7116	 0.01894	 0.08439	 0.01238	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7088	 7147	 0.01802	 0.07475	 0.01268	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 7088	 0.01249	 0.05466	 0.00832	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 7388	 0.00679	 0.02818	 0.00478	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 7427	 0.0057	 0.02492	 0.0038	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 7421	 0.00301	 0.02055	 0.0035	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7090	 7421	 0.00301	 0.02055	 0.0035	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7091	 7226	 0.0073	 0.04386	 0.00595	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7091	 7259	 0.00587	 0.04091	 0.00669	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7091	 7259	 0.00587	 0.04091	 0.00669	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7091	 7418	 0.02256	 0.0542	 0.00736	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 7216	 0.00595	 0.01454	 0.0019	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 7250	 0.00437	 0.01813	 0.00308	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 7258	 0.00224	 0.0098	 0.00149	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 7330	 0.00414	 0.01846	 0.00271	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 7384	 0.00356	 0.02036	 0.00306	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 7093	 0.00237	 0.0153	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 7093	 0.00237	 0.0153	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 7225	 0.0099	 0.04331	 0.0066	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7241	 7093	 0.00831	 0.0203	 0.00266	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 7258	 0.01589	 0.03818	 0.00518	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 7276	 0.00341	 0.01414	 0.0024	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 7388	 0.01029	 0.02471	 0.00335	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 7095	 0.00022	 0.01326	 0.0	 846.0	 846.0	 846.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7098	 7095	 0.00028	 0.02986	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7099	 7095	 0.00022	 0.01103	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7304	 7095	 0.00071	 0.00855	 0.56788	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7097	 7096	 0.00097	 0.05173	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7261	 7096	 0.0027	 0.01928	 0.03515	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7097	 7153	 0.03408	 0.08331	 0.01091	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7103	 0.00199	 0.01384	 0.00226	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7103	 0.00199	 0.01384	 0.00226	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7144	 0.00174	 0.01212	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7144	 0.00174	 0.01212	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7144	 0.00174	 0.01212	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7144	 0.00174	 0.01212	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7222	 0.00195	 0.01331	 0.00226	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7100	 7222	 0.00195	 0.01331	 0.00226	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 7183	 0.00837	 0.03729	 0.00547	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 7386	 0.00972	 0.04254	 0.00648	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7102	 7177	 0.0037	 0.0239	 0.00456	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7102	 7177	 0.0037	 0.0239	 0.00456	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7290	 7102	 0.00551	 0.02285	 0.00388	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 7255	 0.00598	 0.02614	 0.00398	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 7381	 0.0191	 0.04669	 0.00611	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 7104	 0.00012	 0.01194	 0.0	 1312.0	 1312.0	 1312.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7107	 7104	 0.00016	 0.01012	 0.0	 592.0	 592.0	 592.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7108	 7104	 0.00066	 0.0454	 0.0	 335.0	 335.0	 335.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7109	 7104	 0.00038	 0.03767	 0.0	 339.0	 339.0	 339.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7110	 7104	 0.00018	 0.01895	 0.0	 731.0	 731.0	 731.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7111	 7104	 0.0002	 0.01942	 0.0	 743.0	 743.0	 743.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7112	 7104	 0.00016	 0.01175	 0.0	 740.0	 740.0	 740.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7113	 7104	 0.00031	 0.0227	 0.0	 748.0	 748.0	 748.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7114	 7104	 0.00018	 0.01098	 0.0	 752.0	 752.0	 752.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7115	 7104	 0.00016	 0.01098	 0.0	 744.0	 744.0	 744.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7130	 7104	 5e-05	 0.00102	 0.07092	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 7105	 0.00051	 0.03345	 0.0	 354.0	 354.0	 354.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7106	 7105	 0.00051	 0.03345	 0.0	 354.0	 354.0	 354.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7105	 7187	 0.00243	 0.02373	 0.04566	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 7205	 0.00202	 0.01979	 0.03807	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7105	 7332	 0.00074	 0.00725	 0.01395	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 7340	 0.01409	 0.0616	 0.00938	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7116	 7364	 0.02897	 0.06959	 0.00944	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7117	 0.00214	 0.01492	 0.00244	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7117	 0.00214	 0.01492	 0.00244	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 7292	 0.00208	 0.01424	 0.00242	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 7292	 0.00208	 0.01424	 0.00242	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 7395	 0.00404	 0.02761	 0.0047	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 7395	 0.00404	 0.02761	 0.0047	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7177	 7118	 0.00272	 0.01856	 0.00316	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7177	 7118	 0.00272	 0.01856	 0.00316	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 7404	 0.0055	 0.03759	 0.0064	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7119	 0.00176	 0.01229	 0.00201	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7119	 0.00176	 0.01229	 0.00201	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7259	 0.01192	 0.02865	 0.00389	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7119	 7318	 0.00442	 0.01971	 0.00289	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7121	 7120	 0.0094	 0.18529	 0.0	 41.0	 41.0	 41.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7122	 7120	 0.00662	 0.19298	 0.0	 46.0	 46.0	 46.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7120	 7248	 0.00645	 0.03687	 0.00554	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 7396	 0.00289	 0.02016	 0.0033	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 7396	 0.00289	 0.02016	 0.0033	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7427	 7120	 0.00159	 0.01024	 0.00195	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7427	 7120	 0.00159	 0.01024	 0.00195	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 7153	 0.0626	 0.15302	 0.02004	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 7180	 0.0069	 0.01687	 0.00221	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 7125	 0.00011	 0.01326	 0.0	 1358.0	 1358.0	 1358.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7126	 7125	 0.00011	 0.01326	 0.0	 1358.0	 1358.0	 1358.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7125	 7331	 0.00057	 0.00696	 0.46259	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7346	 7125	 6e-05	 0.00128	 0.11073	 4352.0	 4352.0	 4352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 7126	 0.00019	 0.01178	 0.0	 512.3	 512.3	 512.3	 1.0	 0.0	 1	 -30.0	 30.0;
	7127	 7126	 0.00019	 0.01178	 0.0	 512.3	 512.3	 512.3	 1.0	 0.0	 1	 -30.0	 30.0;
	7127	 7126	 0.00019	 0.01178	 0.0	 512.3	 512.3	 512.3	 1.0	 0.0	 1	 -30.0	 30.0;
	7127	 7126	 0.00019	 0.01178	 0.0	 512.3	 512.3	 512.3	 1.0	 0.0	 1	 -30.0	 30.0;
	7126	 7305	 0.00691	 0.04934	 0.08995	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 7332	 0.00592	 0.04228	 0.07708	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 7423	 0.00612	 0.04375	 0.07976	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7391	 7128	 0.00567	 0.03872	 0.00659	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 7129	 0.0122	 0.07328	 0.00994	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7303	 7129	 0.02396	 0.05755	 0.00781	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 7130	 0.0003	 0.01434	 0.0	 1373.0	 1373.0	 1373.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7133	 7130	 0.00046	 0.05358	 0.0	 295.0	 295.0	 295.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7134	 7130	 0.0002	 0.01347	 0.0	 776.0	 776.0	 776.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7135	 7130	 0.00024	 0.01692	 0.0	 767.0	 767.0	 767.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7136	 7130	 0.00025	 0.0186	 0.0	 768.0	 768.0	 768.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7137	 7130	 0.00043	 0.01928	 0.0	 781.0	 781.0	 781.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7138	 7130	 0.0001	 0.00697	 0.0	 1053.0	 1053.0	 1053.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7139	 7130	 0.001	 0.0466	 0.0	 357.0	 357.0	 357.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7140	 7130	 0.00043	 0.03937	 0.0	 360.0	 360.0	 360.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7141	 7130	 0.00037	 0.02584	 0.0	 368.0	 368.0	 368.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7142	 7130	 0.00045	 0.03413	 0.0	 363.0	 363.0	 363.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7263	 7130	 0.00015	 0.00182	 0.1209	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7132	 7131	 0.00109	 0.03352	 0.0	 446.0	 446.0	 446.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7132	 7131	 0.00109	 0.03352	 0.0	 446.0	 446.0	 446.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7131	 7160	 0.00484	 0.04731	 0.09103	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 7278	 0.0023	 0.01644	 0.02997	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 7401	 0.00248	 0.01771	 0.03228	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7132	 7283	 0.00306	 0.0198	 0.00378	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7419	 7132	 0.00182	 0.01246	 0.00212	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7419	 7132	 0.00182	 0.01246	 0.00212	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7419	 7132	 0.00182	 0.01246	 0.00212	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 7173	 0.00756	 0.0432	 0.00649	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 7143	 0.00693	 0.04159	 0.00564	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7143	 7238	 0.03371	 0.14747	 0.02246	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7300	 7143	 0.00916	 0.05231	 0.00786	 245.0	 245.0	 245.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7272	 0.00479	 0.03337	 0.00546	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7144	 7272	 0.00479	 0.03337	 0.00546	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7144	 0.00251	 0.01716	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7144	 0.00251	 0.01716	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7144	 0.00251	 0.01716	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7144	 0.00251	 0.01716	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7144	 0.00251	 0.01716	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7144	 0.00251	 0.01716	 0.00292	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7146	 7145	 0.00456	 0.21285	 0.0	 25.0	 25.0	 25.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7145	 7234	 0.0104	 0.06243	 0.00847	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 7243	 0.01348	 0.05591	 0.00949	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7381	 7145	 0.00645	 0.03876	 0.00526	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 7404	 0.01139	 0.06841	 0.00928	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7147	 0.00171	 0.01165	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7147	 0.00171	 0.01165	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7147	 0.00171	 0.01165	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7147	 0.00171	 0.01165	 0.00198	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7386	 7147	 0.00225	 0.01539	 0.00262	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7386	 7147	 0.00225	 0.01539	 0.00262	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7178	 7148	 0.00225	 0.01565	 0.00256	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7178	 7148	 0.00225	 0.01565	 0.00256	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 7245	 0.00801	 0.04577	 0.00688	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 7298	 0.00778	 0.03402	 0.00518	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 7365	 0.0043	 0.02938	 0.005	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7148	 7365	 0.0043	 0.02938	 0.005	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7149	 7408	 0.0135	 0.0771	 0.01159	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7151	 7150	 0.00105	 0.04281	 0.0	 151.8	 151.8	 151.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7150	 7390	 0.00103	 0.01076	 0.03665	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7150	 7390	 0.00103	 0.01076	 0.03665	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7150	 7420	 0.0052	 0.03715	 0.06773	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 7150	 0.01032	 0.1009	 0.19415	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7151	 7254	 0.00477	 0.03078	 0.00587	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 7152	 0.00193	 0.01249	 0.00238	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 7152	 0.00193	 0.01249	 0.00238	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7152	 7399	 0.00147	 0.0095	 0.00181	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7152	 7399	 0.00147	 0.0095	 0.00181	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7154	 7157	 0.00654	 0.04553	 0.00744	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7154	 7157	 0.00654	 0.04553	 0.00744	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7300	 7154	 0.00482	 0.02753	 0.00414	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7154	 7411	 0.00439	 0.02634	 0.00357	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 7258	 0.00356	 0.02032	 0.00305	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 7316	 0.00716	 0.03193	 0.00468	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 7156	 0.00036	 0.02246	 0.0	 424.0	 424.0	 424.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7157	 7156	 0.00036	 0.02246	 0.0	 424.0	 424.0	 424.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7157	 7156	 0.00036	 0.02246	 0.0	 424.0	 424.0	 424.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7176	 7156	 0.00094	 0.00975	 0.03322	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7156	 7367	 0.00253	 0.0263	 0.0896	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7156	 7367	 0.00253	 0.0263	 0.0896	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 7295	 0.00326	 0.02272	 0.00371	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7157	 7295	 0.00326	 0.02272	 0.00371	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 7158	 0.00459	 0.01903	 0.00323	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 7291	 0.00974	 0.0426	 0.00649	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 7394	 0.00264	 0.01704	 0.00325	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 7394	 0.00264	 0.01704	 0.00325	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7160	 7159	 0.0001	 0.00504	 0.0	 1310.0	 1310.0	 1310.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7162	 7159	 0.00022	 0.01603	 0.0	 491.0	 491.0	 491.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7163	 7159	 0.00034	 0.02489	 0.0	 498.0	 498.0	 498.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7164	 7159	 0.00017	 0.01804	 0.0	 498.0	 498.0	 498.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7165	 7159	 0.00017	 0.01624	 0.0	 512.0	 512.0	 512.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7166	 7159	 0.00043	 0.0291	 0.0	 507.0	 507.0	 507.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7167	 7159	 0.0005	 0.03535	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7168	 7159	 0.00025	 0.02347	 0.0	 418.0	 418.0	 418.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7169	 7159	 0.00016	 0.01916	 0.0	 416.0	 416.0	 416.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7170	 7159	 0.00016	 0.01242	 0.0	 1042.0	 1042.0	 1042.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7159	 7175	 8e-05	 0.00168	 0.11713	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 7159	 0.00019	 0.0023	 0.15283	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7159	 7227	 0.00013	 0.00271	 0.18901	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 7160	 0.00037	 0.02002	 0.0	 418.0	 418.0	 418.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7161	 7160	 0.00037	 0.02002	 0.0	 418.0	 418.0	 418.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7161	 7160	 0.00037	 0.02002	 0.0	 418.0	 418.0	 418.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7187	 7160	 0.00262	 0.02562	 0.04929	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 7292	 0.00143	 0.00999	 0.00163	 221.1	 221.1	 221.1	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 7292	 0.00143	 0.00999	 0.00163	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 7292	 0.00143	 0.00999	 0.00163	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 7292	 0.00143	 0.00999	 0.00163	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7172	 7171	 0.00027	 0.01742	 0.0	 352.0	 352.0	 352.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7171	 7252	 0.00752	 0.05372	 0.09795	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7232	 7172	 0.00301	 0.02095	 0.00342	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7232	 7172	 0.00301	 0.02095	 0.00342	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7173	 7387	 0.00415	 0.02368	 0.00356	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 7231	 0.00209	 0.01426	 0.00243	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 7231	 0.00209	 0.01426	 0.00243	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 7257	 0.00838	 0.05031	 0.00683	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 7174	 0.00178	 0.01152	 0.0022	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 7175	 0.00019	 0.01242	 0.0	 1292.0	 1292.0	 1292.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7176	 7175	 0.00019	 0.01242	 0.0	 1292.0	 1292.0	 1292.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7175	 7389	 0.00056	 0.00684	 0.45463	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7177	 7176	 0.00105	 0.0449	 0.0	 439.0	 439.0	 439.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7177	 7176	 0.00105	 0.0449	 0.0	 439.0	 439.0	 439.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7177	 7176	 0.00105	 0.0449	 0.0	 439.0	 439.0	 439.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7176	 7200	 0.0019	 0.01359	 0.02477	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 7409	 0.00513	 0.03666	 0.06684	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7319	 7177	 0.00247	 0.01686	 0.00287	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7319	 7177	 0.00247	 0.01686	 0.00287	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7295	 7178	 0.00541	 0.02409	 0.00353	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7178	 7404	 0.00777	 0.01898	 0.00249	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 7244	 0.00945	 0.04213	 0.00618	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 7257	 0.01429	 0.0593	 0.01006	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7179	 7336	 0.00994	 0.04121	 0.00699	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 7180	 0.00437	 0.01069	 0.0014	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 7298	 0.00299	 0.02086	 0.00341	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 7298	 0.00299	 0.02086	 0.00341	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7388	 7180	 0.00328	 0.02121	 0.00405	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7388	 7180	 0.00328	 0.02121	 0.00405	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 7399	 0.00226	 0.01457	 0.00278	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 7399	 0.00226	 0.01457	 0.00278	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7181	 0.00194	 0.01355	 0.00221	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7385	 7181	 0.01045	 0.02553	 0.00334	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7182	 7237	 0.01327	 0.07579	 0.01139	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7183	 7417	 0.00881	 0.02153	 0.00282	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7185	 7184	 0.00074	 0.0321	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7185	 7184	 0.00074	 0.0321	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7185	 7184	 0.00074	 0.0321	 0.0	 200.0	 200.0	 200.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7347	 7184	 0.00047	 0.00492	 0.01676	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 7184	 0.00047	 0.00492	 0.01676	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 7184	 0.00047	 0.00492	 0.01676	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7383	 7185	 0.00607	 0.04227	 0.00691	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7383	 7185	 0.00607	 0.04227	 0.00691	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7187	 7186	 0.00014	 0.00907	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7187	 7186	 0.00014	 0.00907	 0.0	 1600.0	 1600.0	 1600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7189	 7186	 0.00062	 0.04222	 0.0	 264.0	 264.0	 264.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7190	 7186	 0.00046	 0.05343	 0.0	 337.0	 337.0	 337.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7191	 7186	 0.00053	 0.03094	 0.0	 258.0	 258.0	 258.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7192	 7186	 0.0005	 0.03659	 0.0	 312.0	 312.0	 312.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7193	 7186	 0.00046	 0.02713	 0.0	 256.0	 256.0	 256.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7194	 7186	 0.0002	 0.01508	 0.0	 861.0	 861.0	 861.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7195	 7186	 0.00029	 0.01748	 0.0	 863.0	 863.0	 863.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7196	 7186	 0.00013	 0.0094	 0.0	 866.0	 866.0	 866.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7197	 7186	 8e-05	 0.00604	 0.0	 867.0	 867.0	 867.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7186	 7341	 0.00031	 0.00639	 0.44587	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7346	 7186	 0.00026	 0.00532	 0.37115	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7187	 0.00025	 0.01839	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7188	 7187	 0.00025	 0.01839	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7188	 7187	 0.00027	 0.01839	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7188	 7187	 0.00027	 0.01839	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7187	 7401	 0.00192	 0.01878	 0.03613	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 7255	 0.00102	 0.00714	 0.00117	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 7201	 0.00328	 0.02241	 0.00381	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 7201	 0.00328	 0.02241	 0.00381	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7198	 7225	 0.01119	 0.07798	 0.01275	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7200	 7199	 0.0002	 0.01412	 0.0	 1344.0	 1344.0	 1344.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7199	 7331	 0.0004	 0.00819	 0.57112	 3146.0	 3146.0	 3146.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7201	 7200	 0.0006	 0.03834	 0.0	 213.6	 213.6	 213.6	 1.0	 0.0	 1	 -30.0	 30.0;
	7201	 7200	 0.0006	 0.03834	 0.0	 213.6	 213.6	 213.6	 1.0	 0.0	 1	 -30.0	 30.0;
	7201	 7200	 0.0006	 0.03834	 0.0	 213.6	 213.6	 213.6	 1.0	 0.0	 1	 -30.0	 30.0;
	7420	 7200	 0.00231	 0.02255	 0.04338	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 7247	 0.00676	 0.03864	 0.00581	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 7313	 0.018	 0.078	 0.012	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7393	 7203	 0.03637	 0.08891	 0.01164	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7426	 7203	 0.03596	 0.08792	 0.01151	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 7204	 0.00014	 0.01015	 0.0	 1324.0	 1324.0	 1324.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7207	 7204	 0.00039	 0.02463	 0.0	 243.0	 243.0	 243.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7208	 7204	 0.00013	 0.00923	 0.0	 1265.0	 1265.0	 1265.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7209	 7204	 7e-05	 0.00639	 0.0	 1260.0	 1260.0	 1260.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7210	 7204	 0.00047	 0.02188	 0.0	 664.0	 664.0	 664.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7211	 7204	 0.00025	 0.01573	 0.0	 656.0	 656.0	 656.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7212	 7204	 0.00039	 0.02557	 0.0	 669.0	 669.0	 669.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7263	 7204	 0.00018	 0.00218	 0.14491	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7204	 7428	 0.00115	 0.01399	 0.92975	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 7205	 0.00229	 0.09203	 0.0	 181.0	 181.0	 181.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7282	 7205	 0.00079	 0.00822	 0.02799	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 7294	 0.0068	 0.039	 0.0058	 100.0	 100.0	 100.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7213	 7273	 0.01615	 0.03947	 0.00517	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 7213	 0.0088	 0.03851	 0.00586	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7213	 7363	 0.00686	 0.03916	 0.00588	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7214	 7257	 0.00967	 0.04229	 0.00644	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7214	 7297	 0.00755	 0.03365	 0.00493	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7214	 0.00276	 0.01888	 0.00321	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7214	 0.00276	 0.01888	 0.00321	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7411	 7215	 0.00253	 0.01729	 0.00294	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 7431	 0.00465	 0.02075	 0.00304	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 7382	 0.00725	 0.03234	 0.00474	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 7386	 0.00794	 0.04769	 0.00647	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 7217	 0.00192	 0.01152	 0.00156	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7217	 7276	 0.01308	 0.03197	 0.00419	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7421	 7218	 0.00797	 0.03307	 0.00561	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 8009	 0.02277	 0.05567	 0.00729	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7230	 7219	 0.00954	 0.04175	 0.00636	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 7237	 0.01747	 0.07641	 0.01164	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 7219	 0.0058	 0.03963	 0.00674	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 7219	 0.0058	 0.03963	 0.00674	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 7220	 0.00146	 0.00997	 0.0017	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 7220	 0.00146	 0.00997	 0.0017	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 7396	 0.00651	 0.04448	 0.00757	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 7296	 0.00652	 0.02849	 0.00434	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7222	 7338	 0.00615	 0.01503	 0.00197	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7222	 7362	 0.01114	 0.04873	 0.00742	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 7223	 0.002	 0.01393	 0.00228	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 7223	 0.002	 0.01393	 0.00228	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7223	 7404	 0.0068	 0.02978	 0.00454	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7223	 7425	 0.00566	 0.03229	 0.00485	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7224	 7248	 0.00705	 0.04027	 0.00605	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7384	 7224	 0.00429	 0.01049	 0.00137	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7224	 7417	 0.00479	 0.02874	 0.0039	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 7225	 0.00662	 0.02747	 0.00466	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7225	 7395	 0.00809	 0.04618	 0.00694	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 7240	 0.00701	 0.03067	 0.00467	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 7250	 0.00636	 0.03633	 0.00546	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 7272	 0.00504	 0.02244	 0.00329	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 7338	 0.01145	 0.02798	 0.00366	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7228	 7227	 0.00016	 0.01098	 0.0	 1259.0	 1259.0	 1259.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7227	 7422	 0.00048	 0.00974	 0.67927	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 7228	 0.00043	 0.01801	 0.0	 467.0	 467.0	 467.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7229	 7228	 0.00043	 0.01801	 0.0	 467.0	 467.0	 467.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7229	 7228	 0.00043	 0.01801	 0.0	 467.0	 467.0	 467.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7409	 7228	 0.0016	 0.01143	 0.02083	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 7230	 0.01033	 0.04606	 0.00675	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 7231	 0.00327	 0.02233	 0.0038	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 7231	 0.00327	 0.02233	 0.0038	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 7231	 0.00327	 0.02233	 0.0038	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 7231	 0.00327	 0.02233	 0.0038	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7231	 7403	 0.00187	 0.01275	 0.00217	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7231	 7403	 0.00187	 0.01275	 0.00217	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7232	 0.00198	 0.01376	 0.00225	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7233	 7251	 0.01464	 0.0358	 0.00469	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7251	 7235	 0.01132	 0.04952	 0.00754	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 7315	 0.00551	 0.03841	 0.00628	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 7315	 0.00551	 0.03841	 0.00628	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7236	 7245	 0.00642	 0.02662	 0.00452	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7236	 7292	 0.01113	 0.04618	 0.00784	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7236	 7411	 0.01497	 0.06208	 0.01054	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 7247	 0.03475	 0.15202	 0.02315	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7238	 7392	 0.0068	 0.039	 0.005	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 7239	 0.05931	 0.14497	 0.01898	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 7392	 0.03658	 0.08942	 0.01171	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7241	 7362	 0.00281	 0.01606	 0.00241	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7295	 0.01417	 0.03406	 0.00462	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7319	 0.00493	 0.03187	 0.00608	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7242	 7319	 0.00493	 0.03187	 0.00608	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 7243	 0.00509	 0.03286	 0.00627	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 7243	 0.00509	 0.03286	 0.00627	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 7272	 0.01177	 0.05245	 0.00769	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 7251	 0.01351	 0.07719	 0.0116	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 7410	 0.00919	 0.06404	 0.01047	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 7410	 0.00919	 0.06404	 0.01047	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7425	 7246	 0.00724	 0.01741	 0.00236	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7339	 7247	 0.01441	 0.05979	 0.01015	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7362	 7248	 0.00406	 0.01777	 0.00271	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 7386	 0.00247	 0.01596	 0.00304	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 7386	 0.00247	 0.01596	 0.00304	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 7255	 0.00406	 0.02776	 0.00472	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 7255	 0.00406	 0.02776	 0.00472	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 7344	 0.00383	 0.02615	 0.00445	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 7344	 0.00383	 0.02615	 0.00445	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7249	 7382	 0.01682	 0.04113	 0.00539	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7250	 7276	 0.00404	 0.0261	 0.00498	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7250	 7276	 0.00404	 0.0261	 0.00498	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7252	 0.0009	 0.03239	 0.0	 198.0	 198.0	 198.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7312	 7252	 0.00133	 0.01297	 0.02495	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7327	 7252	 0.00593	 0.04235	 0.07721	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 7252	 0.00363	 0.03547	 0.06824	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7313	 7253	 0.01056	 0.04704	 0.0069	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7412	 0.00665	 0.04295	 0.00819	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 7412	 0.00665	 0.04295	 0.00819	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7258	 0.00242	 0.01655	 0.00282	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7258	 0.00242	 0.01655	 0.00282	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7399	 0.00104	 0.00673	 0.00128	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7399	 0.00104	 0.00673	 0.00128	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7399	 0.00104	 0.00673	 0.00128	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7255	 7399	 0.00104	 0.00673	 0.00128	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 7297	 0.00926	 0.02263	 0.00296	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7257	 7317	 0.00452	 0.03088	 0.00525	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7257	 7317	 0.00452	 0.03088	 0.00525	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7259	 7403	 0.00479	 0.03335	 0.00545	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7259	 7403	 0.00479	 0.03335	 0.00545	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7260	 0.00263	 0.01833	 0.003	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7260	 0.00263	 0.01833	 0.003	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7260	 0.00263	 0.01833	 0.003	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7262	 7261	 0.00059	 0.02478	 0.0	 305.0	 305.0	 305.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7261	 7429	 0.0045	 0.04398	 0.08462	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7262	 7302	 0.01427	 0.06362	 0.00933	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 7263	 0.00013	 0.00819	 0.0	 1362.0	 1362.0	 1362.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7264	 7263	 0.00013	 0.00819	 0.0	 1362.0	 1362.0	 1362.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7266	 7263	 0.00013	 0.00771	 0.0	 983.0	 983.0	 983.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7267	 7263	 0.00069	 0.04478	 0.0	 443.0	 443.0	 443.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7268	 7263	 0.0002	 0.01399	 0.0	 438.0	 438.0	 438.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7269	 7263	 0.00038	 0.04031	 0.0	 440.0	 440.0	 440.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7270	 7263	 0.00019	 0.01203	 0.0	 701.0	 701.0	 701.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7265	 7264	 0.00053	 0.0323	 0.0	 461.0	 461.0	 461.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7265	 7264	 0.00053	 0.0323	 0.0	 461.0	 461.0	 461.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7264	 7332	 0.00258	 0.01841	 0.03356	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 7271	 0.01055	 0.04377	 0.00743	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7271	 7340	 0.01045	 0.04336	 0.00736	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7272	 0.00354	 0.02023	 0.00304	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7273	 7405	 0.01205	 0.06881	 0.01034	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 7274	 0.00248	 0.12538	 0.0	 143.0	 143.0	 143.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7276	 7395	 0.00344	 0.02064	 0.0028	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 7337	 0.02832	 0.06923	 0.00906	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 7278	 0.00131	 0.07995	 0.0	 172.0	 172.0	 172.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7280	 7278	 0.00175	 0.10484	 0.0	 87.0	 87.0	 87.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7281	 7278	 0.00169	 0.12869	 0.0	 91.0	 91.0	 91.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7367	 7278	 0.00241	 0.0172	 0.03135	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7392	 7279	 0.00555	 0.02431	 0.0037	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7283	 7282	 0.00254	 0.07063	 0.0	 145.0	 145.0	 145.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7284	 7282	 0.00703	 0.26257	 0.0	 70.0	 70.0	 70.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7285	 7282	 0.00137	 0.08957	 0.0	 93.0	 93.0	 93.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7286	 7282	 0.00545	 0.20611	 0.0	 93.0	 93.0	 93.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7287	 7282	 0.00328	 0.17841	 0.0	 91.0	 91.0	 91.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7288	 7282	 0.00467	 0.19001	 0.0	 93.0	 93.0	 93.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7289	 7282	 0.00155	 0.07083	 0.0	 124.0	 124.0	 124.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7282	 7332	 0.00276	 0.01973	 0.03596	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7282	 7367	 0.00169	 0.01205	 0.02197	 523.0	 523.0	 523.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7411	 7290	 0.00285	 0.01709	 0.00232	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7291	 7295	 0.00838	 0.03474	 0.0059	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7424	 7293	 0.0065	 0.02894	 0.00424	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 7405	 0.0229	 0.13751	 0.01866	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7296	 7427	 0.0045	 0.011	 0.00144	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7297	 0.00394	 0.01758	 0.00258	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7297	 7384	 0.00423	 0.0185	 0.00282	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 7362	 0.01319	 0.03222	 0.00422	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 7395	 0.00338	 0.0148	 0.00225	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 7299	 0.01228	 0.07011	 0.01053	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7413	 7299	 0.01459	 0.065	 0.00953	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 7318	 0.01182	 0.05168	 0.00787	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7302	 7426	 0.02525	 0.06173	 0.00808	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7303	 7393	 0.07296	 0.17836	 0.02335	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7305	 7304	 0.00017	 0.01241	 0.0	 1160.0	 1160.0	 1160.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7307	 7304	 0.00035	 0.02169	 0.0	 473.0	 473.0	 473.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7308	 7304	 0.00021	 0.02062	 0.0	 459.0	 459.0	 459.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7309	 7304	 0.00056	 0.04001	 0.0	 454.0	 454.0	 454.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7310	 7304	 0.00063	 0.03797	 0.0	 464.0	 464.0	 464.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7311	 7304	 0.00019	 0.01172	 0.0	 729.0	 729.0	 729.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7341	 7304	 0.00071	 0.00864	 0.57375	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 7305	 0.00078	 0.04744	 0.0	 305.0	 305.0	 305.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7305	 7327	 0.0022	 0.01568	 0.02859	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 7413	 0.00627	 0.04371	 0.00714	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 7413	 0.00627	 0.04371	 0.00714	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7313	 7312	 0.00097	 0.06614	 0.0	 168.0	 168.0	 168.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7312	 7321	 0.00143	 0.014	 0.02693	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7312	 7429	 0.00088	 0.00862	 0.01659	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7313	 7430	 0.00541	 0.0309	 0.00464	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7340	 7314	 0.01916	 0.07949	 0.01349	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7383	 0.01217	 0.07861	 0.015	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 7383	 0.01217	 0.07861	 0.015	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 7424	 0.00457	 0.02949	 0.00563	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 7424	 0.00457	 0.02949	 0.00563	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 7424	 0.00457	 0.02949	 0.00563	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7317	 7424	 0.00457	 0.02949	 0.00563	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7318	 7382	 0.00912	 0.04063	 0.00596	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7321	 7320	 0.00023	 0.01682	 0.0	 1000.0	 1000.0	 1000.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7323	 7320	 0.00036	 0.02134	 0.0	 584.0	 584.0	 584.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7324	 7320	 0.00032	 0.02884	 0.0	 577.0	 577.0	 577.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7325	 7320	 0.0003	 0.02899	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7326	 7320	 0.00017	 0.01413	 0.0	 568.0	 568.0	 568.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7320	 7422	 0.00066	 0.00806	 0.53536	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7322	 7321	 0.00198	 0.07214	 0.0	 128.4	 128.4	 128.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7322	 7380	 0.00578	 0.02527	 0.00385	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 7327	 0.00161	 0.04271	 0.0	 172.0	 172.0	 172.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7329	 7327	 0.00104	 0.04807	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7328	 7339	 0.01199	 0.05341	 0.00783	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7362	 7330	 0.00719	 0.01758	 0.0023	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 7331	 0.00024	 0.01699	 0.0	 1122.0	 1122.0	 1122.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7334	 7331	 0.00083	 0.0414	 0.0	 244.0	 244.0	 244.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7335	 7331	 0.00017	 0.0093	 0.0	 1106.0	 1106.0	 1106.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7400	 7331	 8e-05	 0.00168	 0.11713	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7333	 7332	 0.00093	 0.03886	 0.0	 280.8	 280.8	 280.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7333	 7332	 0.00093	 0.03886	 0.0	 280.8	 280.8	 280.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7333	 7332	 0.00093	 0.03886	 0.0	 280.8	 280.8	 280.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7401	 7332	 0.00104	 0.01017	 0.01957	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7418	 0.00361	 0.02463	 0.00419	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7336	 7418	 0.00361	 0.02463	 0.00419	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7338	 0.0023	 0.01602	 0.00262	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7338	 0.0023	 0.01602	 0.00262	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7341	 0.00017	 0.01252	 0.0	 1311.0	 1311.0	 1311.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7343	 7342	 0.00185	 0.0832	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7343	 7342	 0.00185	 0.0832	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7342	 7409	 0.00056	 0.00583	 0.01986	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7342	 7409	 0.00056	 0.00583	 0.01986	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7344	 7404	 0.00903	 0.03745	 0.00635	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7382	 0.00439	 0.02833	 0.00541	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7345	 7382	 0.00439	 0.02833	 0.00541	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 7346	 0.00014	 0.00986	 0.0	 1271.0	 1271.0	 1271.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7347	 7346	 0.00014	 0.00986	 0.0	 1271.0	 1271.0	 1271.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7349	 7346	 8e-05	 0.00563	 0.0	 1019.0	 1019.0	 1019.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7350	 7346	 0.00022	 0.01346	 0.0	 1021.0	 1021.0	 1021.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7351	 7346	 0.00031	 0.01784	 0.0	 1018.0	 1018.0	 1018.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7352	 7346	 0.00034	 0.01655	 0.0	 1025.0	 1025.0	 1025.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7353	 7346	 0.00019	 0.01203	 0.0	 1225.0	 1225.0	 1225.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7354	 7346	 6e-05	 0.00671	 0.0	 1222.0	 1222.0	 1222.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7355	 7346	 6e-05	 0.00677	 0.0	 1218.0	 1218.0	 1218.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7356	 7346	 0.00012	 0.00609	 0.0	 1219.0	 1219.0	 1219.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7357	 7346	 0.00066	 0.04067	 0.0	 287.0	 287.0	 287.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7358	 7346	 0.0003	 0.02129	 0.0	 835.0	 835.0	 835.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7359	 7346	 0.00013	 0.00906	 0.0	 846.0	 846.0	 846.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7360	 7346	 0.00021	 0.01514	 0.0	 845.0	 845.0	 845.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7361	 7346	 0.00026	 0.02464	 0.0	 471.0	 471.0	 471.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7348	 7347	 0.00062	 0.02698	 0.0	 407.0	 407.0	 407.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7348	 7347	 0.00062	 0.02698	 0.0	 407.0	 407.0	 407.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7380	 7363	 0.03224	 0.13375	 0.0227	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7365	 7381	 0.00343	 0.01423	 0.00241	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7367	 7366	 0.00021	 0.01366	 0.0	 1249.0	 1249.0	 1249.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7367	 7366	 0.00021	 0.01366	 0.0	 1249.0	 1249.0	 1249.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7369	 7366	 0.00053	 0.03243	 0.0	 494.0	 494.0	 494.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7370	 7366	 0.00065	 0.04118	 0.0	 480.0	 480.0	 480.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7371	 7366	 0.00049	 0.03404	 0.0	 469.0	 469.0	 469.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7372	 7366	 0.00049	 0.03162	 0.0	 485.0	 485.0	 485.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7373	 7366	 0.0001	 0.01184	 0.0	 491.0	 491.0	 491.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7374	 7366	 0.0004	 0.0255	 0.0	 487.0	 487.0	 487.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7375	 7366	 0.00045	 0.02708	 0.0	 712.0	 712.0	 712.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7376	 7366	 0.00035	 0.02498	 0.0	 713.0	 713.0	 713.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7377	 7366	 0.00031	 0.01898	 0.0	 705.0	 705.0	 705.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7378	 7366	 0.00036	 0.02384	 0.0	 694.0	 694.0	 694.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7379	 7366	 0.00031	 0.02202	 0.0	 700.0	 700.0	 700.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7366	 7400	 0.00014	 0.00168	 0.11182	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 7367	 0.00086	 0.03726	 0.0	 392.0	 392.0	 392.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7368	 7367	 0.00086	 0.03726	 0.0	 392.0	 392.0	 392.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7368	 7367	 0.00086	 0.03726	 0.0	 392.0	 392.0	 392.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7385	 7404	 0.00674	 0.03846	 0.00578	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7390	 7389	 0.00019	 0.01131	 0.0	 1278.0	 1278.0	 1278.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8030	 7389	 0.00054	 0.00651	 0.43275	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7391	 7390	 0.00148	 0.044	 0.0	 127.2	 127.2	 127.2	 1.0	 0.0	 1	 -30.0	 30.0;
	7396	 7410	 0.00293	 0.01892	 0.00361	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 7410	 0.00293	 0.01892	 0.00361	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7396	 7410	 0.00293	 0.01892	 0.00361	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 7398	 0.00218	 0.01408	 0.00269	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 7398	 0.00218	 0.01408	 0.00269	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7399	 7417	 0.00504	 0.03508	 0.00573	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7399	 7417	 0.00504	 0.03508	 0.00573	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7401	 7400	 0.00011	 0.00786	 0.0	 1297.0	 1297.0	 1297.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7402	 7401	 0.00049	 0.03223	 0.0	 423.0	 423.0	 423.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7401	 7409	 0.00483	 0.04717	 0.09075	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 7419	 0.00504	 0.03445	 0.00586	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7403	 7419	 0.00504	 0.03445	 0.00586	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7407	 7406	 0.0002	 0.01441	 0.0	 1026.0	 1026.0	 1026.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7414	 7406	 0.00034	 0.0041	 0.275	 2295.0	 2295.0	 2295.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7408	 7407	 0.00118	 0.08057	 0.0	 143.8	 143.8	 143.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7410	 7409	 0.00054	 0.03923	 0.0	 248.4	 248.4	 248.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7410	 7409	 0.00054	 0.03923	 0.0	 248.4	 248.4	 248.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7410	 7409	 0.00054	 0.03923	 0.0	 248.4	 248.4	 248.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7409	 7420	 0.00502	 0.04904	 0.09435	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 7414	 0.0004	 0.04372	 0.0	 239.0	 239.0	 239.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7416	 7415	 0.00128	 0.09703	 0.0	 109.0	 109.0	 109.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7417	 7418	 0.00278	 0.01937	 0.00317	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 7418	 0.00278	 0.01937	 0.00317	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7421	 7420	 0.00106	 0.06841	 0.0	 161.4	 161.4	 161.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7421	 7420	 0.00106	 0.06841	 0.0	 161.4	 161.4	 161.4	 1.0	 0.0	 1	 -30.0	 30.0;
	7423	 7422	 0.00014	 0.00897	 0.0	 1350.0	 1350.0	 1350.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7424	 7423	 0.00105	 0.04353	 0.0	 213.0	 213.0	 213.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7424	 7423	 0.00105	 0.04353	 0.0	 213.0	 213.0	 213.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7424	 7423	 0.00105	 0.04353	 0.0	 213.0	 213.0	 213.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7429	 7428	 0.00026	 0.01258	 0.0	 927.0	 927.0	 927.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7430	 7429	 0.00214	 0.08887	 0.0	 133.8	 133.8	 133.8	 1.0	 0.0	 1	 -30.0	 30.0;
	7432	 8003	 0.02966	 0.07251	 0.00949	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 8037	 0.0136	 0.05948	 0.00906	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 8141	 0.03471	 0.2084	 0.02828	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8003	 8001	 0.01464	 0.06073	 0.01031	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8010	 8001	 0.01076	 0.04467	 0.00758	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8028	 8002	 0.01939	 0.04659	 0.00632	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 8100	 0.00588	 0.03355	 0.00504	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8004	 0.00029	 0.01244	 0.0	 459.0	 459.0	 459.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8005	 8004	 0.00029	 0.01244	 0.0	 459.0	 459.0	 459.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8097	 8004	 0.0073	 0.05215	 0.09507	 443.0	 443.0	 443.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8023	 0.00379	 0.02588	 0.0044	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8005	 8023	 0.00379	 0.02588	 0.0044	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 8005	 0.02182	 0.09544	 0.01454	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 8007	 0.00768	 0.04613	 0.00626	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 8134	 0.00667	 0.02973	 0.00436	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8007	 8017	 0.00629	 0.03774	 0.00512	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 8053	 0.01567	 0.09407	 0.01277	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8081	 8008	 0.02514	 0.06143	 0.00804	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 8104	 0.01187	 0.06777	 0.01018	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8086	 8010	 0.0146	 0.0834	 0.01253	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8010	 8103	 0.00735	 0.04411	 0.00599	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8045	 8011	 0.00606	 0.03914	 0.00747	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8045	 8011	 0.00606	 0.03914	 0.00747	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8072	 8011	 0.00722	 0.05031	 0.00822	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8012	 8032	 0.00861	 0.03768	 0.00574	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8104	 8012	 0.01361	 0.05953	 0.00907	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8026	 8013	 0.01793	 0.10765	 0.01461	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 8039	 0.02164	 0.12994	 0.01763	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 8136	 0.01354	 0.05923	 0.00902	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8014	 8037	 0.01899	 0.08308	 0.01265	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 8014	 0.01481	 0.08893	 0.01207	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 8015	 0.02139	 0.05228	 0.00685	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 8150	 0.00949	 0.05422	 0.00815	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 8122	 0.03388	 0.08282	 0.01084	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 8152	 0.00375	 0.01641	 0.0025	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8017	 8040	 0.01458	 0.08752	 0.01188	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 8018	 0.00115	 0.03658	 0.0	 360.0	 360.0	 360.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8019	 8018	 0.00115	 0.03658	 0.0	 360.0	 360.0	 360.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8127	 8018	 0.00839	 0.08205	 0.15788	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 8133	 0.00093	 0.00905	 0.01742	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 8052	 0.00643	 0.02664	 0.00452	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 8100	 0.0068	 0.043	 0.0058	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 8135	 0.00212	 0.0148	 0.00242	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 8135	 0.00212	 0.0148	 0.00242	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 8029	 0.01833	 0.0817	 0.01198	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 8040	 0.02253	 0.09344	 0.01586	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 8153	 0.01361	 0.08173	 0.01109	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 8154	 0.04852	 0.1186	 0.01553	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 8021	 0.06068	 0.14832	 0.01942	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 8041	 0.01109	 0.0485	 0.00739	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8021	 8119	 0.01573	 0.06526	 0.01107	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8022	 8150	 0.05259	 0.12855	 0.01683	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8024	 8023	 0.01105	 0.18799	 0.0	 47.0	 47.0	 47.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8023	 8111	 0.00548	 0.03542	 0.00676	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8023	 8111	 0.00548	 0.03542	 0.00676	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8025	 8055	 0.04211	 0.10294	 0.01348	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8025	 8121	 0.03375	 0.08251	 0.0108	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8025	 8151	 0.02868	 0.1722	 0.02337	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8026	 8154	 0.02053	 0.05018	 0.00657	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8100	 8027	 0.00732	 0.03203	 0.00488	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 8134	 0.00435	 0.02974	 0.00506	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8146	 8028	 0.02838	 0.06936	 0.00908	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 8029	 0.02002	 0.08756	 0.01333	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 8030	 7e-05	 0.00828	 0.0	 1036.0	 1036.0	 1036.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8033	 8030	 0.00029	 0.02168	 0.0	 826.0	 826.0	 826.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8034	 8030	 0.00021	 0.01721	 0.0	 818.0	 818.0	 818.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 8030	 0.00021	 0.01536	 0.0	 830.0	 830.0	 830.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8036	 8030	 0.00021	 0.01615	 0.0	 820.0	 820.0	 820.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8158	 8030	 0.00069	 0.0084	 0.55816	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 8031	 0.00099	 0.03425	 0.0	 400.0	 400.0	 400.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8143	 8032	 0.017	 0.07576	 0.01111	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 8066	 0.01227	 0.05467	 0.00802	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 8124	 0.01143	 0.06861	 0.00931	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8039	 8081	 0.01342	 0.07667	 0.01152	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8040	 8072	 0.02142	 0.09547	 0.014	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8109	 8040	 0.015	 0.088	 0.012	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8041	 8063	 0.02127	 0.05109	 0.00693	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 8042	 0.02452	 0.05992	 0.00785	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 8042	 0.02735	 0.16423	 0.02229	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 8043	 9e-05	 0.00881	 0.0	 1072.0	 1072.0	 1072.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8046	 8043	 0.00013	 0.01356	 0.0	 606.0	 606.0	 606.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8047	 8043	 0.00021	 0.01156	 0.0	 613.0	 613.0	 613.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8048	 8043	 0.00055	 0.02691	 0.0	 598.0	 598.0	 598.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8049	 8043	 0.00017	 0.00903	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8050	 8043	 0.00032	 0.0182	 0.0	 618.0	 618.0	 618.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8051	 8043	 0.00013	 0.00831	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8043	 8067	 0.0004	 0.00819	 0.57108	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8045	 8044	 0.00042	 0.02402	 0.0	 388.0	 388.0	 388.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8147	 8044	 0.00245	 0.02399	 0.04616	 647.0	 647.0	 647.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8045	 8091	 0.02272	 0.09941	 0.01514	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8045	 8144	 0.01434	 0.08609	 0.01168	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8081	 8052	 0.01891	 0.04622	 0.00605	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8053	 8065	 0.0229	 0.10022	 0.01526	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8053	 8153	 0.01818	 0.10383	 0.0156	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8054	 8092	 0.00962	 0.05775	 0.00784	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8132	 8054	 0.01211	 0.06914	 0.01039	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8055	 8098	 0.011	 0.078	 0.013	 220.0	 220.0	 220.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8121	 8055	 0.02807	 0.06863	 0.00899	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8056	 8089	 0.0071	 0.04055	 0.00609	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8056	 8138	 0.00777	 0.04664	 0.00633	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8058	 8057	 0.00019	 0.02064	 0.0	 491.0	 491.0	 491.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8060	 8057	 0.00013	 0.00977	 0.0	 1157.0	 1157.0	 1157.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8061	 8057	 0.00019	 0.01179	 0.0	 1152.0	 1152.0	 1152.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8057	 8112	 0.0013	 0.01581	 1.05006	 2020.0	 2020.0	 2020.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8059	 8058	 0.00191	 0.06531	 0.0	 143.8	 143.8	 143.8	 1.0	 0.0	 1	 -30.0	 30.0;
	8058	 8068	 0.00454	 0.04438	 0.0854	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8058	 8147	 0.00321	 0.03142	 0.06046	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8064	 8059	 0.00422	 0.01881	 0.00276	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 8098	 0.00445	 0.01944	 0.00296	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 8062	 0.01516	 0.06756	 0.00991	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 8063	 0.01764	 0.10595	 0.01438	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8063	 8125	 0.03529	 0.08625	 0.01129	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8144	 8064	 0.01683	 0.06982	 0.01185	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8065	 8149	 0.00226	 0.01459	 0.00278	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8065	 8149	 0.00226	 0.01459	 0.00278	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8066	 8093	 0.04293	 0.19131	 0.02805	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8142	 8066	 0.01064	 0.0474	 0.00695	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8068	 8067	 0.00035	 0.03434	 0.0	 285.0	 285.0	 285.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8070	 8067	 0.00016	 0.01452	 0.0	 1325.0	 1325.0	 1325.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8071	 8067	 0.00014	 0.01049	 0.0	 1314.0	 1314.0	 1314.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8069	 8068	 0.00074	 0.05407	 0.0	 143.0	 143.0	 143.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8068	 8083	 0.00329	 0.03216	 0.06187	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8103	 8069	 0.01048	 0.04673	 0.00685	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 8108	 0.01751	 0.10003	 0.01503	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8136	 8073	 0.015	 0.088	 0.012	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8075	 8074	 0.00028	 0.02981	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8075	 8074	 0.00028	 0.02981	 0.0	 550.0	 550.0	 550.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8077	 8074	 0.00016	 0.01864	 0.0	 806.0	 806.0	 806.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8078	 8074	 0.00029	 0.01964	 0.0	 818.0	 818.0	 818.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8079	 8074	 0.0002	 0.0153	 0.0	 818.0	 818.0	 818.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8080	 8074	 0.00022	 0.01762	 0.0	 814.0	 814.0	 814.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8076	 8075	 0.00099	 0.04033	 0.0	 320.0	 320.0	 320.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8075	 8097	 0.00445	 0.03181	 0.05799	 740.0	 740.0	 740.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 8076	 0.00591	 0.0412	 0.00674	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 8076	 0.00591	 0.0412	 0.00674	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8083	 8082	 0.00031	 0.01574	 0.0	 1134.0	 1134.0	 1134.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8087	 8082	 8e-05	 0.00888	 0.0	 1315.0	 1315.0	 1315.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8088	 8082	 8e-05	 0.00591	 0.0	 1307.0	 1307.0	 1307.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8155	 8082	 0.00016	 0.00337	 0.23512	 2768.0	 2768.0	 2768.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8084	 8083	 0.00236	 0.06305	 0.0	 184.8	 184.8	 184.8	 1.0	 0.0	 1	 -30.0	 30.0;
	8085	 8084	 0.00092	 0.02498	 0.0	 231.0	 231.0	 231.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8086	 8085	 0.00184	 0.06658	 0.0	 205.0	 205.0	 205.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8089	 8135	 0.00521	 0.03628	 0.00593	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8089	 8135	 0.00521	 0.03628	 0.00593	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8090	 8092	 0.01569	 0.08961	 0.01347	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8151	 8090	 0.01339	 0.08041	 0.01091	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8091	 8109	 0.07888	 0.19284	 0.02525	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 8093	 0.018	 0.078	 0.012	 150.0	 150.0	 150.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8093	 8128	 0.01795	 0.07854	 0.01196	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8095	 8094	 0.00041	 0.03017	 0.0	 317.0	 317.0	 317.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8094	 8139	 0.00069	 0.00679	 0.01307	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8094	 8159	 0.00239	 0.02336	 0.04495	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8095	 8140	 0.01066	 0.02604	 0.00341	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8096	 8110	 0.0448	 0.10762	 0.0146	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8096	 8153	 0.0128	 0.07686	 0.01043	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 8097	 0.00373	 0.10051	 0.0	 117.0	 117.0	 117.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8099	 8097	 0.00303	 0.097	 0.0	 184.0	 184.0	 184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8097	 8113	 0.00194	 0.01386	 0.02527	 800.0	 800.0	 800.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 8100	 0.01582	 0.03801	 0.00516	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 8137	 0.01472	 0.08841	 0.012	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 8157	 0.00742	 0.03309	 0.00485	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 8105	 0.00098	 0.05869	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8105	 8127	 0.00276	 0.02696	 0.05188	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8142	 8106	 0.01907	 0.08501	 0.01247	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8128	 8107	 0.01223	 0.05352	 0.00815	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8145	 8107	 0.01849	 0.08086	 0.01231	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8153	 8108	 0.013	 0.054	 0.027	 186.0	 186.0	 186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8109	 8123	 0.00627	 0.0358	 0.00538	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8124	 8110	 0.00917	 0.05504	 0.00747	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8111	 8125	 0.01474	 0.0885	 0.01201	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 8112	 9e-05	 0.00481	 0.0	 1290.0	 1290.0	 1290.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8115	 8112	 0.00071	 0.04514	 0.0	 273.0	 273.0	 273.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8116	 8112	 0.00024	 0.01298	 0.0	 1026.0	 1026.0	 1026.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8117	 8112	 0.00025	 0.01118	 0.0	 1034.0	 1034.0	 1034.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8114	 8113	 0.00077	 0.03155	 0.0	 190.0	 190.0	 190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8113	 8133	 0.003	 0.0312	 0.10631	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8113	 8133	 0.003	 0.0312	 0.10631	 750.0	 750.0	 750.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8121	 8114	 0.01148	 0.07843	 0.01334	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 8151	 0.01924	 0.11555	 0.01568	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8120	 8122	 0.03382	 0.08268	 0.01083	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8120	 8140	 0.01216	 0.07301	 0.00991	 170.0	 170.0	 170.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8120	 8141	 0.0166	 0.06885	 0.01168	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8143	 8120	 0.01659	 0.07254	 0.01105	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8149	 8123	 0.00474	 0.02711	 0.00407	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8127	 8126	 0.00011	 0.00797	 0.0	 1175.0	 1175.0	 1175.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8127	 8126	 0.00011	 0.00797	 0.0	 1175.0	 1175.0	 1175.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8129	 8126	 8e-05	 0.00487	 0.0	 1190.0	 1190.0	 1190.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8130	 8126	 0.00026	 0.01215	 0.0	 1192.0	 1192.0	 1192.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8131	 8126	 0.0001	 0.00621	 0.0	 1173.0	 1173.0	 1173.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8128	 8127	 0.0004	 0.02178	 0.0	 286.0	 286.0	 286.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8132	 8144	 0.02494	 0.10345	 0.01756	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8134	 8133	 0.00067	 0.03526	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8134	 8133	 0.00067	 0.03526	 0.0	 300.0	 300.0	 300.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8133	 8147	 0.00702	 0.06865	 0.13208	 548.0	 548.0	 548.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8154	 8135	 0.00895	 0.03991	 0.00585	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8136	 8145	 0.01057	 0.04623	 0.00704	 149.0	 149.0	 149.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 8146	 0.02103	 0.12014	 0.01805	 98.0	 98.0	 98.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8140	 8139	 0.00037	 0.02517	 0.0	 365.0	 365.0	 365.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8148	 8147	 0.00049	 0.03635	 0.0	 201.3	 201.3	 201.3	 1.0	 0.0	 1	 -30.0	 30.0;
	8148	 8147	 0.00049	 0.03635	 0.0	 201.3	 201.3	 201.3	 1.0	 0.0	 1	 -30.0	 30.0;
	8149	 8148	 0.00259	 0.0686	 0.0	 254.0	 254.0	 254.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8152	 8160	 0.00538	 0.03751	 0.00613	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8152	 8160	 0.00538	 0.03751	 0.00613	 221.0	 221.0	 221.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 8155	 0.00077	 0.04753	 0.0	 500.0	 500.0	 500.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8157	 8156	 0.0013	 0.06678	 0.0	 240.0	 240.0	 240.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8156	 8159	 0.00621	 0.04434	 0.08084	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8159	 8158	 0.00013	 0.01364	 0.0	 1204.0	 1204.0	 1204.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8160	 8159	 0.0008	 0.05008	 0.0	 377.0	 377.0	 377.0	 1.0	 0.0	 1	 -30.0	 30.0;
	8160	 8159	 0.0008	 0.05008	 0.0	 377.0	 377.0	 377.0	 1.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 2075-2074 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 2132-2131 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3090-3089 connects the same voltage levels (161.0, 161.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 3135-3134 connects the same voltage levels (161.0, 161.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5061-5060 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5062-5061 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5242-5241 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5392-5391 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5398-5397 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 5460-5459 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6317-6316 connects the same voltage levels (161.0, 161.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 6318-6317 connects the same voltage levels (161.0, 161.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 7161-7292 connects the same voltage levels (115.0, 115.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8085-8084 connects the same voltage levels (161.0, 161.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : Updated Thermal Rating: on line 1001-1064 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1001-1064 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1001-1071 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1001-1071 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1002-1007 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1010-1002 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 1004-1003 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 1022-1003 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1055-1003 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1004-3133 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on transformer 1006-1005 : Rate B, Rate C - 0.0, 0.0 -> 42.0, 42.0
% INFO    : Updated Thermal Rating: on line 1025-1005 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1005-1061 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1067-1005 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1007-1015 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1031-1007 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 1009-1008 : Rate B, Rate C - 0.0, 0.0 -> 120.0, 120.0
% INFO    : Updated Thermal Rating: on line 1008-1032 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1008-1069 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 1011-1010 : Rate B, Rate C - 0.0, 0.0 -> 46.0, 46.0
% INFO    : Updated Thermal Rating: on line 1010-1015 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1010-1030 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1012-1087 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3051-1012 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1013-1031 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1047-1013 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1086-1013 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1014-1047 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1014-1083 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1016-1034 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1068-1016 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1018-1017 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1017-1029 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1037-1017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1047-1017 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 1024-1018 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1019-1040 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1019-1045 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1019-1071 : Rate B, Rate C - 0.0, 0.0 -> 225.0, 225.0
% INFO    : Updated Thermal Rating: on line 1071-1019 : Rate B, Rate C - 0.0, 0.0 -> 225.0, 225.0
% INFO    : Updated Thermal Rating: on line 1019-1084 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on transformer 1021-1020 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 1025-1020 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1084-1020 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1020-3059 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 1020-3130 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 1023-1022 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 1022-1028 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1022-1028 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1024-1090 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 1026-1025 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 1027-1045 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1056-1027 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 1028-3109 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 1029-1056 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1030-1038 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1083-1030 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 1033-1032 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on line 1032-1036 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1038-1032 : Rate B, Rate C - 0.0, 0.0 -> 155.0, 155.0
% INFO    : Updated Thermal Rating: on line 1033-1081 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 1033-3050 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on transformer 1035-1034 : Rate B, Rate C - 0.0, 0.0 -> 130.0, 130.0
% INFO    : Updated Thermal Rating: on line 1067-1034 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1088-1036 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1037-1071 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 1039-1038 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 1082-1038 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1083-1038 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1040-1090 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 1042-1041 : Rate B, Rate C - 0.0, 0.0 -> 145.0, 145.0
% INFO    : Updated Thermal Rating: on transformer 1043-1041 : Rate B, Rate C - 0.0, 0.0 -> 95.0, 95.0
% INFO    : Updated Thermal Rating: on line 1065-1041 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1041-1067 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1044-3019 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3130-1044 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1045-1064 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1087-1046 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1046-3009 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 1048-1047 : Rate B, Rate C - 0.0, 0.0 -> 390.0, 390.0
% INFO    : Updated Thermal Rating: on transformer 1049-1047 : Rate B, Rate C - 0.0, 0.0 -> 390.0, 390.0
% INFO    : Updated Thermal Rating: on transformer 1050-1047 : Rate B, Rate C - 0.0, 0.0 -> 124.0, 124.0
% INFO    : Updated Thermal Rating: on transformer 1051-1047 : Rate B, Rate C - 0.0, 0.0 -> 117.0, 117.0
% INFO    : Updated Thermal Rating: on transformer 1052-1047 : Rate B, Rate C - 0.0, 0.0 -> 110.0, 110.0
% INFO    : Updated Thermal Rating: on transformer 1053-1047 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 1047-1085 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1053-1081 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 1054-1056 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1089-1054 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 1055-1089 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 1057-1056 : Rate B, Rate C - 0.0, 0.0 -> 160.0, 160.0
% INFO    : Updated Thermal Rating: on line 1056-1061 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 1056-1065 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 1059-1058 : Rate B, Rate C - 0.0, 0.0 -> 33.0, 33.0
% INFO    : Updated Thermal Rating: on transformer 1060-1058 : Rate B, Rate C - 0.0, 0.0 -> 27.0, 27.0
% INFO    : Updated Thermal Rating: on line 1069-1058 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1069-1058 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1058-1087 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1058-1087 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 1062-1061 : Rate B, Rate C - 0.0, 0.0 -> 29.0, 29.0
% INFO    : Updated Thermal Rating: on transformer 1063-1061 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 1061-3042 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 1066-1065 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 1088-1068 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 1070-1069 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on line 1082-1069 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 1072-1071 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 1073-1071 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 1074-1071 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 1075-1071 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 1076-1071 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on transformer 1077-1071 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on transformer 1078-1071 : Rate B, Rate C - 0.0, 0.0 -> 137.0, 137.0
% INFO    : Updated Thermal Rating: on transformer 1079-1071 : Rate B, Rate C - 0.0, 0.0 -> 2000.0, 2000.0
% INFO    : Updated Thermal Rating: on transformer 1080-1071 : Rate B, Rate C - 0.0, 0.0 -> 136.0, 136.0
% INFO    : Updated Thermal Rating: on transformer 1081-1071 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 3048-1079 : Rate B, Rate C - 0.0, 0.0 -> 2300.0, 2300.0
% INFO    : Updated Thermal Rating: on line 3048-1079 : Rate B, Rate C - 0.0, 0.0 -> 2300.0, 2300.0
% INFO    : Updated Thermal Rating: on line 1081-3058 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 1084-3130 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 1085-1086 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 1090-1085 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 2029-1091 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 1091-2048 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2098-1091 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2022-2001 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2027-2001 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2003-2002 : Rate B, Rate C - 0.0, 0.0 -> 981.0, 981.0
% INFO    : Updated Thermal Rating: on transformer 2004-2002 : Rate B, Rate C - 0.0, 0.0 -> 635.0, 635.0
% INFO    : Updated Thermal Rating: on transformer 2005-2002 : Rate B, Rate C - 0.0, 0.0 -> 645.0, 645.0
% INFO    : Updated Thermal Rating: on transformer 2006-2002 : Rate B, Rate C - 0.0, 0.0 -> 636.0, 636.0
% INFO    : Updated Thermal Rating: on line 2021-2002 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 2002-2101 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2038-2003 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2003-2047 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 2007-2114 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2007-2122 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2014-2008 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2008-2052 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2009-2049 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2009-2082 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2109-2009 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 2061-2010 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2010-2079 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2010-2091 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2012-2011 : Rate B, Rate C - 0.0, 0.0 -> 461.0, 461.0
% INFO    : Updated Thermal Rating: on transformer 2013-2011 : Rate B, Rate C - 0.0, 0.0 -> 412.0, 412.0
% INFO    : Updated Thermal Rating: on line 2127-2011 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2012-2041 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2012-2052 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2093-2012 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2012-2123 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2014-2029 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2015-2037 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5014-2015 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2043-2016 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2069-2016 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2018-2017 : Rate B, Rate C - 0.0, 0.0 -> 271.0, 271.0
% INFO    : Updated Thermal Rating: on transformer 2019-2017 : Rate B, Rate C - 0.0, 0.0 -> 454.0, 454.0
% INFO    : Updated Thermal Rating: on line 2017-2096 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2017-2127 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2018-2093 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2045-2020 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 2055-2020 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 2022-2021 : Rate B, Rate C - 0.0, 0.0 -> 867.0, 867.0
% INFO    : Updated Thermal Rating: on transformer 2023-2021 : Rate B, Rate C - 0.0, 0.0 -> 319.0, 319.0
% INFO    : Updated Thermal Rating: on transformer 2024-2021 : Rate B, Rate C - 0.0, 0.0 -> 391.0, 391.0
% INFO    : Updated Thermal Rating: on line 2113-2021 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2022-2040 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2064-2022 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2025-2055 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2067-2025 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2058-2026 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2128-2026 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2027-2090 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2028-2045 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2028-2109 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 2112-2028 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 2030-2106 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2122-2030 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2031-2048 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2031-2087 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2032-2114 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2122-2032 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2129-2033 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2033-5288 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2034-2043 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2046-2034 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2035-2066 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2035-2091 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2036-2055 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 2036-2082 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 2037-2065 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2110-2037 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2081-2038 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2039-2086 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5285-2039 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2039-5455 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2040-2114 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2121-2040 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2042-2041 : Rate B, Rate C - 0.0, 0.0 -> 95.0, 95.0
% INFO    : Updated Thermal Rating: on line 2041-2058 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2065-2044 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2044-2102 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2063-2046 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2092-2047 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2079-2048 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2049-2061 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2090-2050 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2050-5268 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2080-2051 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2051-2112 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5285-2053 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2053-5362 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 2055-2054 : Rate B, Rate C - 0.0, 0.0 -> 1095.0, 1095.0
% INFO    : Updated Thermal Rating: on transformer 2055-2054 : Rate B, Rate C - 0.0, 0.0 -> 1095.0, 1095.0
% INFO    : Updated Thermal Rating: on transformer 2056-2054 : Rate B, Rate C - 0.0, 0.0 -> 227.0, 227.0
% INFO    : Updated Thermal Rating: on transformer 2057-2054 : Rate B, Rate C - 0.0, 0.0 -> 1001.0, 1001.0
% INFO    : Updated Thermal Rating: on line 2127-2054 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2054-5236 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 2059-2058 : Rate B, Rate C - 0.0, 0.0 -> 99.0, 99.0
% INFO    : Updated Thermal Rating: on line 2123-2058 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2060-2064 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5136-2060 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 2062-2061 : Rate B, Rate C - 0.0, 0.0 -> 223.0, 223.0
% INFO    : Updated Thermal Rating: on line 2092-2063 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2126-2065 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2073-2066 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2068-2067 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2068-2088 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2069-2072 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2069-5074 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2071-2070 : Rate B, Rate C - 0.0, 0.0 -> 249.0, 249.0
% INFO    : Updated Thermal Rating: on line 2088-2070 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2070-5237 : Rate B, Rate C - 0.0, 0.0 -> 245.0, 245.0
% INFO    : Updated Thermal Rating: on line 2072-2102 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 2074-2073 : Rate B, Rate C - 0.0, 0.0 -> 144.0, 144.0
% INFO    : Updated Thermal Rating: on transformer 2076-2073 : Rate B, Rate C - 0.0, 0.0 -> 64.0, 64.0
% INFO    : Updated Thermal Rating: on line 2087-2073 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2073-3079 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2075-2074 : Rate B, Rate C - 0.0, 0.0 -> 19.0, 19.0
% INFO    : Updated Thermal Rating: on line 3115-2074 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 2078-2077 : Rate B, Rate C - 0.0, 0.0 -> 189.0, 189.0
% INFO    : Updated Thermal Rating: on line 2077-2110 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 2077-2133 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2086-2080 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2133-2080 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2081-2129 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2083-2082 : Rate B, Rate C - 0.0, 0.0 -> 91.0, 91.0
% INFO    : Updated Thermal Rating: on transformer 2084-2082 : Rate B, Rate C - 0.0, 0.0 -> 82.0, 82.0
% INFO    : Updated Thermal Rating: on transformer 2085-2082 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 2089-2088 : Rate B, Rate C - 0.0, 0.0 -> 84.0, 84.0
% INFO    : Updated Thermal Rating: on line 2090-2121 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2094-2093 : Rate B, Rate C - 0.0, 0.0 -> 88.0, 88.0
% INFO    : Updated Thermal Rating: on transformer 2095-2093 : Rate B, Rate C - 0.0, 0.0 -> 164.0, 164.0
% INFO    : Updated Thermal Rating: on transformer 2097-2096 : Rate B, Rate C - 0.0, 0.0 -> 836.0, 836.0
% INFO    : Updated Thermal Rating: on transformer 2099-2096 : Rate B, Rate C - 0.0, 0.0 -> 237.0, 237.0
% INFO    : Updated Thermal Rating: on transformer 2100-2096 : Rate B, Rate C - 0.0, 0.0 -> 386.0, 386.0
% INFO    : Updated Thermal Rating: on transformer 2098-2097 : Rate B, Rate C - 0.0, 0.0 -> 146.0, 146.0
% INFO    : Updated Thermal Rating: on line 2097-3096 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on transformer 2102-2101 : Rate B, Rate C - 0.0, 0.0 -> 1072.0, 1072.0
% INFO    : Updated Thermal Rating: on transformer 2103-2101 : Rate B, Rate C - 0.0, 0.0 -> 542.0, 542.0
% INFO    : Updated Thermal Rating: on transformer 2104-2101 : Rate B, Rate C - 0.0, 0.0 -> 542.0, 542.0
% INFO    : Updated Thermal Rating: on transformer 2105-2101 : Rate B, Rate C - 0.0, 0.0 -> 544.0, 544.0
% INFO    : Updated Thermal Rating: on line 2101-5083 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 2102-2107 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 2124-2106 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2106-2129 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2107-2125 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2130-2108 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5472-2108 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2111-5187 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2111-5472 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 2114-2113 : Rate B, Rate C - 0.0, 0.0 -> 924.0, 924.0
% INFO    : Updated Thermal Rating: on transformer 2115-2113 : Rate B, Rate C - 0.0, 0.0 -> 410.0, 410.0
% INFO    : Updated Thermal Rating: on transformer 2116-2113 : Rate B, Rate C - 0.0, 0.0 -> 402.0, 402.0
% INFO    : Updated Thermal Rating: on transformer 2117-2113 : Rate B, Rate C - 0.0, 0.0 -> 404.0, 404.0
% INFO    : Updated Thermal Rating: on transformer 2118-2113 : Rate B, Rate C - 0.0, 0.0 -> 391.0, 391.0
% INFO    : Updated Thermal Rating: on transformer 2119-2113 : Rate B, Rate C - 0.0, 0.0 -> 389.0, 389.0
% INFO    : Updated Thermal Rating: on transformer 2120-2113 : Rate B, Rate C - 0.0, 0.0 -> 392.0, 392.0
% INFO    : Updated Thermal Rating: on line 5049-2113 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 2113-8126 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5450-2124 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2125-5078 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 2125-5215 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 2126-5220 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 2128-2127 : Rate B, Rate C - 0.0, 0.0 -> 308.0, 308.0
% INFO    : Updated Thermal Rating: on line 2127-5164 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 2129-5141 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 2131-2130 : Rate B, Rate C - 0.0, 0.0 -> 214.0, 214.0
% INFO    : Updated Thermal Rating: on line 2132-2131 : Rate B, Rate C - 0.0, 0.0 -> 24.0, 24.0
% INFO    : Updated Thermal Rating: on line 3021-2131 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 3002-3001 : Rate B, Rate C - 0.0, 0.0 -> 171.0, 171.0
% INFO    : Updated Thermal Rating: on transformer 3002-3001 : Rate B, Rate C - 0.0, 0.0 -> 171.0, 171.0
% INFO    : Updated Thermal Rating: on line 3001-6177 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6285-3001 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 3002-3107 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3004-3003 : Rate B, Rate C - 0.0, 0.0 -> 51.0, 51.0
% INFO    : Updated Thermal Rating: on line 3003-3103 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3141-3003 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3005-3052 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3126-3005 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3006-3049 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3145-3006 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3007-3013 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3007-3137 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3007-3145 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3008-3036 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3140-3008 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3143-3008 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3009-3024 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3146-3009 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3010-3076 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3093-3010 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3011-3012 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3011-3124 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3012-6226 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3013-3077 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3014-3124 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6212-3014 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3015-3121 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3015-3127 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3015-3128 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3017-3016 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 3016-3083 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3016-3103 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3016-3131 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3139-3016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 3019-3018 : Rate B, Rate C - 0.0, 0.0 -> 142.2, 142.2
% INFO    : Updated Thermal Rating: on transformer 3019-3018 : Rate B, Rate C - 0.0, 0.0 -> 142.2, 142.2
% INFO    : Updated Thermal Rating: on transformer 3020-3018 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 3018-3050 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 3018-3058 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 3024-3019 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3114-3019 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3114-3019 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3049-3021 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 5397-3021 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3033-3022 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3085-3022 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3049-3023 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3023-3067 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3023-3115 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3035-3025 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3025-3036 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3025-3101 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 3027-3026 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 3028-3026 : Rate B, Rate C - 0.0, 0.0 -> 270.0, 270.0
% INFO    : Updated Thermal Rating: on line 3026-5395 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 3027-3102 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3147-3029 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3029-5241 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3030-3072 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 3114-3030 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3054-3031 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3031-3070 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 3031-3140 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3032-3094 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3099-3032 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 3034-3033 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 3136-3033 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3035-3066 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3036-3066 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3038-3037 : Rate B, Rate C - 0.0, 0.0 -> 82.0, 82.0
% INFO    : Updated Thermal Rating: on transformer 3039-3037 : Rate B, Rate C - 0.0, 0.0 -> 280.0, 280.0
% INFO    : Updated Thermal Rating: on line 3078-3037 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 3037-3088 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 3038-3080 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3085-3038 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3072-3040 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3139-3040 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 3042-3041 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 3043-3041 : Rate B, Rate C - 0.0, 0.0 -> 57.0, 57.0
% INFO    : Updated Thermal Rating: on transformer 3044-3041 : Rate B, Rate C - 0.0, 0.0 -> 112.0, 112.0
% INFO    : Updated Thermal Rating: on transformer 3045-3041 : Rate B, Rate C - 0.0, 0.0 -> 550.0, 550.0
% INFO    : Updated Thermal Rating: on line 3041-3046 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 3041-3058 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 3042-3064 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3111-3042 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 3047-3046 : Rate B, Rate C - 0.0, 0.0 -> 290.0, 290.0
% INFO    : Updated Thermal Rating: on transformer 3048-3046 : Rate B, Rate C - 0.0, 0.0 -> 1500.0, 1500.0
% INFO    : Updated Thermal Rating: on transformer 3048-3046 : Rate B, Rate C - 0.0, 0.0 -> 1500.0, 1500.0
% INFO    : Updated Thermal Rating: on line 3046-3078 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 3082-3046 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 3047-3064 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3129-3047 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3048-5045 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 3048-5045 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 3048-5120 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 3048-5394 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 3051-3050 : Rate B, Rate C - 0.0, 0.0 -> 122.0, 122.0
% INFO    : Updated Thermal Rating: on transformer 3051-3050 : Rate B, Rate C - 0.0, 0.0 -> 122.0, 122.0
% INFO    : Updated Thermal Rating: on line 4014-3050 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 3052-3093 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3052-3107 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3054-3053 : Rate B, Rate C - 0.0, 0.0 -> 103.0, 103.0
% INFO    : Updated Thermal Rating: on transformer 3055-3053 : Rate B, Rate C - 0.0, 0.0 -> 330.0, 330.0
% INFO    : Updated Thermal Rating: on transformer 3056-3053 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 3057-3053 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on line 3058-3053 : Rate B, Rate C - 0.0, 0.0 -> 1000.0, 1000.0
% INFO    : Updated Thermal Rating: on line 3082-3053 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 3053-3088 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 3053-3088 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on transformer 3059-3058 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 3060-3058 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 3061-3058 : Rate B, Rate C - 0.0, 0.0 -> 155.0, 155.0
% INFO    : Updated Thermal Rating: on transformer 3062-3058 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on transformer 3063-3058 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 3059-3111 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 3065-3064 : Rate B, Rate C - 0.0, 0.0 -> 110.0, 110.0
% INFO    : Updated Thermal Rating: on line 3064-3141 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3066-3142 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3068-3067 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 3067-3070 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3067-3094 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3067-3141 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3069-3077 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3069-3140 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3071-3070 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 3070-3131 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3142-3072 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3074-3073 : Rate B, Rate C - 0.0, 0.0 -> 115.0, 115.0
% INFO    : Updated Thermal Rating: on line 3073-3076 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3123-3073 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3073-4002 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3132-3075 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3075-3138 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3077-3099 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3077-3131 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 3079-3078 : Rate B, Rate C - 0.0, 0.0 -> 166.0, 166.0
% INFO    : Updated Thermal Rating: on transformer 3081-3078 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 3078-3133 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on transformer 3080-3079 : Rate B, Rate C - 0.0, 0.0 -> 90.0, 90.0
% INFO    : Updated Thermal Rating: on line 3134-3079 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 3083-3082 : Rate B, Rate C - 0.0, 0.0 -> 143.8, 143.8
% INFO    : Updated Thermal Rating: on transformer 3084-3082 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 3137-3083 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 3086-3085 : Rate B, Rate C - 0.0, 0.0 -> 77.0, 77.0
% INFO    : Updated Thermal Rating: on transformer 3087-3085 : Rate B, Rate C - 0.0, 0.0 -> 83.0, 83.0
% INFO    : Updated Thermal Rating: on line 3085-3128 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3089-3088 : Rate B, Rate C - 0.0, 0.0 -> 411.0, 411.0
% INFO    : Updated Thermal Rating: on transformer 3092-3088 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 5395-3088 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 5395-3088 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 3090-3089 : Rate B, Rate C - 0.0, 0.0 -> 277.0, 277.0
% INFO    : Updated Thermal Rating: on line 3089-5334 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 3091-3090 : Rate B, Rate C - 0.0, 0.0 -> 268.0, 268.0
% INFO    : Updated Thermal Rating: on line 3102-3091 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3091-3125 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3095-3094 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3137-3094 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 3097-3096 : Rate B, Rate C - 0.0, 0.0 -> 162.0, 162.0
% INFO    : Updated Thermal Rating: on transformer 3097-3096 : Rate B, Rate C - 0.0, 0.0 -> 162.0, 162.0
% INFO    : Updated Thermal Rating: on transformer 3098-3096 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 3133-3096 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 3109-3097 : Rate B, Rate C - 0.0, 0.0 -> 340.0, 340.0
% INFO    : Updated Thermal Rating: on line 3099-3100 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3100-3102 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3125-3100 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3104-3101 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6360-3101 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3105-3104 : Rate B, Rate C - 0.0, 0.0 -> 60.0, 60.0
% INFO    : Updated Thermal Rating: on transformer 3106-3104 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 6156-3104 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3108-3147 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3108-6065 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3110-3109 : Rate B, Rate C - 0.0, 0.0 -> 114.0, 114.0
% INFO    : Updated Thermal Rating: on transformer 3112-3111 : Rate B, Rate C - 0.0, 0.0 -> 90.0, 90.0
% INFO    : Updated Thermal Rating: on transformer 3113-3111 : Rate B, Rate C - 0.0, 0.0 -> 90.0, 90.0
% INFO    : Updated Thermal Rating: on line 3116-3115 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 3117-3116 : Rate B, Rate C - 0.0, 0.0 -> 80.0, 80.0
% INFO    : Updated Thermal Rating: on transformer 3118-3116 : Rate B, Rate C - 0.0, 0.0 -> 139.0, 139.0
% INFO    : Updated Thermal Rating: on line 3116-3136 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 3120-3119 : Rate B, Rate C - 0.0, 0.0 -> 46.0, 46.0
% INFO    : Updated Thermal Rating: on line 4002-3119 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4188-3119 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3122-3121 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 3121-3129 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3121-3145 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3126-3123 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6286-3124 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 3126-6059 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3141-3127 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 3132-3144 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 3134-3133 : Rate B, Rate C - 0.0, 0.0 -> 83.0, 83.0
% INFO    : Updated Thermal Rating: on line 3135-3134 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 3136-3135 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 3138-3142 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 3138-3146 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 3144-3143 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4003-4040 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4103-4003 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4103-4003 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4128-4003 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4005-4004 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 4014-4004 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 4113-4004 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4022-4005 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4114-4005 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4006-4011 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4006-4197 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4007-4027 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4007-4034 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4007-4122 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4008-6112 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6155-4008 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4008-6346 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4010-4009 : Rate B, Rate C - 0.0, 0.0 -> 131.0, 131.0
% INFO    : Updated Thermal Rating: on transformer 4010-4009 : Rate B, Rate C - 0.0, 0.0 -> 131.0, 131.0
% INFO    : Updated Thermal Rating: on line 4152-4009 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4152-4009 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4165-4009 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4165-4009 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4011-4185 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4034-4012 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4012-4103 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4012-4121 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4012-4171 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4013-4089 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4107-4013 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4013-4122 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 4015-4014 : Rate B, Rate C - 0.0, 0.0 -> 321.0, 321.0
% INFO    : Updated Thermal Rating: on transformer 4015-4014 : Rate B, Rate C - 0.0, 0.0 -> 321.0, 321.0
% INFO    : Updated Thermal Rating: on line 4014-4131 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4188-4015 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4016-4023 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4117-4016 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4081-4017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4081-4017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4017-4087 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4017-4123 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4018-4037 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4149-4018 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4019-4067 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4019-4067 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4019-4121 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4051-4020 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4051-4020 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4020-4123 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4150-4020 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4150-4020 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4089-4021 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4021-4167 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4187-4022 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6112-4023 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 4025-4024 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on transformer 4026-4024 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on transformer 4026-4024 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 4131-4024 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6263-4024 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4025-4117 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 4027-4088 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4027-4088 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4029-4028 : Rate B, Rate C - 0.0, 0.0 -> 148.8, 148.8
% INFO    : Updated Thermal Rating: on transformer 4029-4028 : Rate B, Rate C - 0.0, 0.0 -> 148.8, 148.8
% INFO    : Updated Thermal Rating: on transformer 4030-4028 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on transformer 4030-4028 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on transformer 4030-4028 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4028-7043 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4028-7274 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4028-7274 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4029-6253 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7275-4029 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4031-4043 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4147-4031 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4051-4032 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4141-4032 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4033-4101 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 4033-4147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4033-4147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4033-4190 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4034-4154 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4064-4035 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4035-4150 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4132-4036 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4036-4189 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4037-4054 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4099-4037 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4054-4038 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4038-4125 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4038-4178 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 4040-4039 : Rate B, Rate C - 0.0, 0.0 -> 384.0, 384.0
% INFO    : Updated Thermal Rating: on transformer 4040-4039 : Rate B, Rate C - 0.0, 0.0 -> 384.0, 384.0
% INFO    : Updated Thermal Rating: on line 4073-4039 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4073-4039 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4039-4151 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4039-4151 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4039-4151 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4074-4040 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4074-4040 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4074-4040 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4079-4040 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4079-4040 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4079-4040 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 4042-4041 : Rate B, Rate C - 0.0, 0.0 -> 442.0, 442.0
% INFO    : Updated Thermal Rating: on transformer 4042-4041 : Rate B, Rate C - 0.0, 0.0 -> 442.0, 442.0
% INFO    : Updated Thermal Rating: on transformer 4042-4041 : Rate B, Rate C - 0.0, 0.0 -> 442.0, 442.0
% INFO    : Updated Thermal Rating: on line 4073-4041 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 4073-4041 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 4088-4042 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4088-4042 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4107-4042 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4107-4042 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4043-4119 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4045-4044 : Rate B, Rate C - 0.0, 0.0 -> 120.0, 120.0
% INFO    : Updated Thermal Rating: on transformer 4046-4044 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 4047-4044 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4044-4119 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4185-4044 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4048-4154 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4048-4155 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4048-4155 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4050-4049 : Rate B, Rate C - 0.0, 0.0 -> 130.0, 130.0
% INFO    : Updated Thermal Rating: on transformer 4050-4049 : Rate B, Rate C - 0.0, 0.0 -> 130.0, 130.0
% INFO    : Updated Thermal Rating: on line 4086-4049 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4049-4194 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4049-4194 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4052-4051 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 4127-4051 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4053-4152 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4053-4152 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4053-4191 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4053-4191 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4055-4078 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4055-4078 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4055-4109 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4055-4145 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4055-4145 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4057-4056 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on transformer 4058-4056 : Rate B, Rate C - 0.0, 0.0 -> 185.0, 185.0
% INFO    : Updated Thermal Rating: on transformer 4059-4056 : Rate B, Rate C - 0.0, 0.0 -> 185.0, 185.0
% INFO    : Updated Thermal Rating: on transformer 4060-4056 : Rate B, Rate C - 0.0, 0.0 -> 185.0, 185.0
% INFO    : Updated Thermal Rating: on transformer 4061-4056 : Rate B, Rate C - 0.0, 0.0 -> 259.0, 259.0
% INFO    : Updated Thermal Rating: on transformer 4062-4056 : Rate B, Rate C - 0.0, 0.0 -> 264.0, 264.0
% INFO    : Updated Thermal Rating: on transformer 4063-4056 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 4056-4158 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4056-4181 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 4108-4057 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4108-4057 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4057-4145 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4057-4145 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4065-4064 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 4069-4064 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4064-4099 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4064-4099 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4064-4104 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4064-4104 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4066-4068 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4066-4107 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4066-4107 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4111-4067 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4194-4067 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4194-4067 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4194-4067 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4068-4103 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4068-4186 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4069-4072 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 4071-4070 : Rate B, Rate C - 0.0, 0.0 -> 353.0, 353.0
% INFO    : Updated Thermal Rating: on transformer 4071-4070 : Rate B, Rate C - 0.0, 0.0 -> 353.0, 353.0
% INFO    : Updated Thermal Rating: on line 4070-4183 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4070-4192 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4070-4192 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4106-4071 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4072-4156 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4072-4168 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4072-4168 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4074-4073 : Rate B, Rate C - 0.0, 0.0 -> 397.0, 397.0
% INFO    : Updated Thermal Rating: on transformer 4074-4073 : Rate B, Rate C - 0.0, 0.0 -> 397.0, 397.0
% INFO    : Updated Thermal Rating: on transformer 4075-4073 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on transformer 4076-4073 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on transformer 4077-4073 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on line 4146-4073 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 4073-4183 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4192-4073 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 4155-4074 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4120-4078 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4078-4180 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4079-4157 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4079-4157 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 4081-4080 : Rate B, Rate C - 0.0, 0.0 -> 171.0, 171.0
% INFO    : Updated Thermal Rating: on transformer 4081-4080 : Rate B, Rate C - 0.0, 0.0 -> 171.0, 171.0
% INFO    : Updated Thermal Rating: on transformer 4082-4080 : Rate B, Rate C - 0.0, 0.0 -> 342.0, 342.0
% INFO    : Updated Thermal Rating: on transformer 4083-4080 : Rate B, Rate C - 0.0, 0.0 -> 342.0, 342.0
% INFO    : Updated Thermal Rating: on transformer 4084-4080 : Rate B, Rate C - 0.0, 0.0 -> 338.0, 338.0
% INFO    : Updated Thermal Rating: on transformer 4085-4080 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 4140-4080 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4080-4151 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4080-4181 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 4183-4080 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 4086-4106 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4110-4086 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4156-4087 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4090-4089 : Rate B, Rate C - 0.0, 0.0 -> 28.0, 28.0
% INFO    : Updated Thermal Rating: on transformer 4091-4089 : Rate B, Rate C - 0.0, 0.0 -> 37.0, 37.0
% INFO    : Updated Thermal Rating: on transformer 4092-4089 : Rate B, Rate C - 0.0, 0.0 -> 48.0, 48.0
% INFO    : Updated Thermal Rating: on transformer 4093-4089 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 4094-4089 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 4095-4089 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 4096-4089 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 4097-4089 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on transformer 4098-4089 : Rate B, Rate C - 0.0, 0.0 -> 40.0, 40.0
% INFO    : Updated Thermal Rating: on line 4089-4194 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4169-4099 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4169-4099 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4100-4120 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4150-4100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4150-4100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4168-4100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4168-4100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4168-4100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4175-4101 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4197-4101 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4126-4102 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4126-4102 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 4102-4171 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4102-4171 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 4105-4104 : Rate B, Rate C - 0.0, 0.0 -> 128.0, 128.0
% INFO    : Updated Thermal Rating: on transformer 4105-4104 : Rate B, Rate C - 0.0, 0.0 -> 128.0, 128.0
% INFO    : Updated Thermal Rating: on line 4145-4104 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4170-4108 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4109-4156 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4110-4171 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4186-4111 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4124-4112 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4124-4112 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4112-4141 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4112-4141 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4114-4113 : Rate B, Rate C - 0.0, 0.0 -> 387.0, 387.0
% INFO    : Updated Thermal Rating: on transformer 4115-4113 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on transformer 4116-4113 : Rate B, Rate C - 0.0, 0.0 -> 180.0, 180.0
% INFO    : Updated Thermal Rating: on line 4146-4113 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 4190-4114 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4190-4114 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4117-4172 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4139-4118 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4148-4118 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4164-4119 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4122-4157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4122-4157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4123-4180 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4128-4124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4128-4124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6264-4125 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4193-4126 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4193-4126 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4193-4126 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4144-4127 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4129-4130 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4129-4176 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4130-4179 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 4132-4131 : Rate B, Rate C - 0.0, 0.0 -> 246.6, 246.6
% INFO    : Updated Thermal Rating: on transformer 4132-4131 : Rate B, Rate C - 0.0, 0.0 -> 246.6, 246.6
% INFO    : Updated Thermal Rating: on transformer 4133-4131 : Rate B, Rate C - 0.0, 0.0 -> 101.0, 101.0
% INFO    : Updated Thermal Rating: on transformer 4134-4131 : Rate B, Rate C - 0.0, 0.0 -> 103.0, 103.0
% INFO    : Updated Thermal Rating: on transformer 4135-4131 : Rate B, Rate C - 0.0, 0.0 -> 103.0, 103.0
% INFO    : Updated Thermal Rating: on transformer 4136-4131 : Rate B, Rate C - 0.0, 0.0 -> 105.0, 105.0
% INFO    : Updated Thermal Rating: on transformer 4137-4131 : Rate B, Rate C - 0.0, 0.0 -> 140.0, 140.0
% INFO    : Updated Thermal Rating: on transformer 4138-4131 : Rate B, Rate C - 0.0, 0.0 -> 135.0, 135.0
% INFO    : Updated Thermal Rating: on line 4131-6308 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4132-4143 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6357-4132 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4139-4144 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4139-4169 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4141-4140 : Rate B, Rate C - 0.0, 0.0 -> 428.0, 428.0
% INFO    : Updated Thermal Rating: on transformer 4142-4140 : Rate B, Rate C - 0.0, 0.0 -> 168.0, 168.0
% INFO    : Updated Thermal Rating: on line 4140-4151 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 4140-4196 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 4141-4165 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4189-4143 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4147-4146 : Rate B, Rate C - 0.0, 0.0 -> 459.0, 459.0
% INFO    : Updated Thermal Rating: on line 4146-4196 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4146-4196 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4148-4179 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 4173-4149 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on line 4149-4182 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4152-4151 : Rate B, Rate C - 0.0, 0.0 -> 78.0, 78.0
% INFO    : Updated Thermal Rating: on transformer 4152-4151 : Rate B, Rate C - 0.0, 0.0 -> 78.0, 78.0
% INFO    : Updated Thermal Rating: on transformer 4153-4151 : Rate B, Rate C - 0.0, 0.0 -> 381.0, 381.0
% INFO    : Updated Thermal Rating: on line 4151-4158 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 4164-4155 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 4159-4158 : Rate B, Rate C - 0.0, 0.0 -> 620.0, 620.0
% INFO    : Updated Thermal Rating: on transformer 4159-4158 : Rate B, Rate C - 0.0, 0.0 -> 620.0, 620.0
% INFO    : Updated Thermal Rating: on transformer 4160-4158 : Rate B, Rate C - 0.0, 0.0 -> 298.0, 298.0
% INFO    : Updated Thermal Rating: on transformer 4161-4158 : Rate B, Rate C - 0.0, 0.0 -> 296.0, 296.0
% INFO    : Updated Thermal Rating: on transformer 4162-4158 : Rate B, Rate C - 0.0, 0.0 -> 293.0, 293.0
% INFO    : Updated Thermal Rating: on transformer 4163-4158 : Rate B, Rate C - 0.0, 0.0 -> 74.0, 74.0
% INFO    : Updated Thermal Rating: on line 4159-4168 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4159-4168 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4159-4168 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4159-4168 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 4166-4165 : Rate B, Rate C - 0.0, 0.0 -> 132.0, 132.0
% INFO    : Updated Thermal Rating: on transformer 4166-4165 : Rate B, Rate C - 0.0, 0.0 -> 132.0, 132.0
% INFO    : Updated Thermal Rating: on line 4186-4167 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4180-4170 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6221-4172 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4172-6346 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7030-4173 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6015-4174 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6276-4174 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 4176-4175 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4177-4176 : Rate B, Rate C - 0.0, 0.0 -> 115.0, 115.0
% INFO    : Updated Thermal Rating: on transformer 4177-4176 : Rate B, Rate C - 0.0, 0.0 -> 115.0, 115.0
% INFO    : Updated Thermal Rating: on line 4178-6253 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4182-4181 : Rate B, Rate C - 0.0, 0.0 -> 169.0, 169.0
% INFO    : Updated Thermal Rating: on line 7274-4181 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 4184-4183 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on line 4191-4184 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4191-4184 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 4184-4194 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4184-4194 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 4187-4189 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 4193-4192 : Rate B, Rate C - 0.0, 0.0 -> 438.0, 438.0
% INFO    : Updated Thermal Rating: on transformer 4193-4192 : Rate B, Rate C - 0.0, 0.0 -> 438.0, 438.0
% INFO    : Updated Thermal Rating: on transformer 4193-4192 : Rate B, Rate C - 0.0, 0.0 -> 438.0, 438.0
% INFO    : Updated Thermal Rating: on transformer 4196-4195 : Rate B, Rate C - 0.0, 0.0 -> 1233.0, 1233.0
% INFO    : Updated Thermal Rating: on line 4195-6239 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 4197-4196 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 5003-5181 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5213-5003 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5003-5436 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5004-5426 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5476-5004 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5133-5005 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5005-5435 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5006-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5006-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5006-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5289-5006 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5289-5006 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5006-5294 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5007-5012 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5165-5007 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5134-5008 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5347-5008 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5396-5008 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on line 5294-5009 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5311-5009 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5482-5009 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5010-5096 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5010-5096 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5386-5010 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5386-5010 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5011-5054 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 8084-5011 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5012-5017 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5013-5101 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5156-5013 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5013-5226 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5014-5455 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5016-5015 : Rate B, Rate C - 0.0, 0.0 -> 1206.0, 1206.0
% INFO    : Updated Thermal Rating: on transformer 5016-5015 : Rate B, Rate C - 0.0, 0.0 -> 1206.0, 1206.0
% INFO    : Updated Thermal Rating: on line 5063-5015 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5015-5164 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5361-5015 : Rate B, Rate C - 0.0, 0.0 -> 4352.0, 4352.0
% INFO    : Updated Thermal Rating: on line 5015-5479 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5265-5016 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5265-5016 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5265-5016 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5420-5016 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5420-5016 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5218-5017 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5017-5315 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5019-5018 : Rate B, Rate C - 0.0, 0.0 -> 590.0, 590.0
% INFO    : Updated Thermal Rating: on transformer 5020-5018 : Rate B, Rate C - 0.0, 0.0 -> 557.0, 557.0
% INFO    : Updated Thermal Rating: on line 5055-5018 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5018-5236 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5018-5236 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5018-5413 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5019-5176 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5022-5021 : Rate B, Rate C - 0.0, 0.0 -> 1375.0, 1375.0
% INFO    : Updated Thermal Rating: on transformer 5022-5021 : Rate B, Rate C - 0.0, 0.0 -> 1375.0, 1375.0
% INFO    : Updated Thermal Rating: on transformer 5023-5021 : Rate B, Rate C - 0.0, 0.0 -> 245.0, 245.0
% INFO    : Updated Thermal Rating: on line 5021-5401 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5021-5413 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5479-5021 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5249-5022 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5249-5022 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5306-5022 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5306-5022 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5022-5441 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5022-5441 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5140-5024 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5024-5182 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5452-5024 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5453-5025 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5453-5025 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5025-5473 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5025-5473 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5026-5104 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5026-5104 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5026-5375 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5027-5098 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5027-5469 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5027-5469 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5027-5481 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5097-5028 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5097-5028 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5028-5233 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5028-5478 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5029-5142 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5461-5029 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5312-5030 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5030-5430 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5031-5296 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5408-5031 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5032-5090 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5214-5032 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5032-5228 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5032-5228 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5329-5032 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5034-5033 : Rate B, Rate C - 0.0, 0.0 -> 1209.0, 1209.0
% INFO    : Updated Thermal Rating: on transformer 5035-5033 : Rate B, Rate C - 0.0, 0.0 -> 243.0, 243.0
% INFO    : Updated Thermal Rating: on transformer 5036-5033 : Rate B, Rate C - 0.0, 0.0 -> 255.0, 255.0
% INFO    : Updated Thermal Rating: on transformer 5037-5033 : Rate B, Rate C - 0.0, 0.0 -> 985.0, 985.0
% INFO    : Updated Thermal Rating: on transformer 5038-5033 : Rate B, Rate C - 0.0, 0.0 -> 989.0, 989.0
% INFO    : Updated Thermal Rating: on transformer 5039-5033 : Rate B, Rate C - 0.0, 0.0 -> 994.0, 994.0
% INFO    : Updated Thermal Rating: on transformer 5040-5033 : Rate B, Rate C - 0.0, 0.0 -> 993.0, 993.0
% INFO    : Updated Thermal Rating: on transformer 5041-5033 : Rate B, Rate C - 0.0, 0.0 -> 1001.0, 1001.0
% INFO    : Updated Thermal Rating: on transformer 5042-5033 : Rate B, Rate C - 0.0, 0.0 -> 988.0, 988.0
% INFO    : Updated Thermal Rating: on line 5033-5047 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5033-5350 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5033-5384 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5034-5313 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5034-5313 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5034-5313 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5371-5034 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5043-5152 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5043-5284 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5044-5153 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5044-5153 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5185-5044 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5185-5044 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5046-5045 : Rate B, Rate C - 0.0, 0.0 -> 550.0, 550.0
% INFO    : Updated Thermal Rating: on line 5045-5120 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5260-5045 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 5413-5045 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5286-5046 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5048-5047 : Rate B, Rate C - 0.0, 0.0 -> 1354.0, 1354.0
% INFO    : Updated Thermal Rating: on line 5047-5179 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5047-5260 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 5047-5444 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5480-5048 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5480-5048 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5480-5048 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5480-5048 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5050-5049 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on transformer 5051-5049 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 5052-5049 : Rate B, Rate C - 0.0, 0.0 -> 308.0, 308.0
% INFO    : Updated Thermal Rating: on line 5049-5304 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 5049-5350 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 5049-8074 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 8126-5049 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5454-5050 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5454-5050 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5052-8038 : Rate B, Rate C - 0.0, 0.0 -> 186.0, 186.0
% INFO    : Updated Thermal Rating: on line 5052-8124 : Rate B, Rate C - 0.0, 0.0 -> 186.0, 186.0
% INFO    : Updated Thermal Rating: on line 5173-5053 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5173-5053 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5053-5357 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5053-5357 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5054-5223 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5056-5055 : Rate B, Rate C - 0.0, 0.0 -> 913.0, 913.0
% INFO    : Updated Thermal Rating: on transformer 5057-5055 : Rate B, Rate C - 0.0, 0.0 -> 1036.0, 1036.0
% INFO    : Updated Thermal Rating: on transformer 5058-5055 : Rate B, Rate C - 0.0, 0.0 -> 1023.0, 1023.0
% INFO    : Updated Thermal Rating: on line 5055-5196 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5187-5056 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5197-5056 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5060-5059 : Rate B, Rate C - 0.0, 0.0 -> 151.0, 151.0
% INFO    : Updated Thermal Rating: on line 5059-5426 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 8148-5059 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5061-5060 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 5060-8065 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 5062-5061 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on transformer 5064-5063 : Rate B, Rate C - 0.0, 0.0 -> 1277.0, 1277.0
% INFO    : Updated Thermal Rating: on transformer 5064-5063 : Rate B, Rate C - 0.0, 0.0 -> 1277.0, 1277.0
% INFO    : Updated Thermal Rating: on transformer 5065-5063 : Rate B, Rate C - 0.0, 0.0 -> 290.0, 290.0
% INFO    : Updated Thermal Rating: on transformer 5066-5063 : Rate B, Rate C - 0.0, 0.0 -> 213.0, 213.0
% INFO    : Updated Thermal Rating: on transformer 5067-5063 : Rate B, Rate C - 0.0, 0.0 -> 1078.0, 1078.0
% INFO    : Updated Thermal Rating: on transformer 5068-5063 : Rate B, Rate C - 0.0, 0.0 -> 1073.0, 1073.0
% INFO    : Updated Thermal Rating: on transformer 5069-5063 : Rate B, Rate C - 0.0, 0.0 -> 1079.0, 1079.0
% INFO    : Updated Thermal Rating: on line 5063-5304 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5322-5063 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 5063-5401 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5064-5125 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5064-5125 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5064-5125 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5064-5125 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5143-5064 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5143-5064 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5143-5064 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5070-5128 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5425-5070 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5138-5071 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5071-5359 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5103-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5103-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5103-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5103-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5103-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5116-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5116-5072 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5121-5073 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5484-5073 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5074-5147 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5074-5331 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5075-5267 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5075-5377 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5077-5076 : Rate B, Rate C - 0.0, 0.0 -> 260.0, 260.0
% INFO    : Updated Thermal Rating: on line 5227-5076 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 8108-5077 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 5160-5078 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5079-5138 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5079-5138 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5378-5079 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5142-5080 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5080-5328 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5081-5163 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5221-5081 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5081-5377 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 5082-5086 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5082-5330 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5082-5440 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 5084-5083 : Rate B, Rate C - 0.0, 0.0 -> 1295.0, 1295.0
% INFO    : Updated Thermal Rating: on line 5083-5295 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5083-5322 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5083-5464 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5357-5084 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5357-5084 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5357-5084 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5157-5085 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5085-5468 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5086-5177 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5086-5210 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5086-5447 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5257-5087 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5087-5345 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5087-5348 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5089-5088 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 5088-5290 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5088-5393 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5090-5122 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5090-5230 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5090-5311 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5171-5091 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5091-5257 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5092-5186 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5453-5092 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5475-5092 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5093-5291 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5332-5093 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5093-5434 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5093-5434 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5094-5381 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5485-5094 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5277-5095 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5341-5095 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5305-5096 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5305-5096 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5305-5096 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5096-5412 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5097-5125 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5097-5125 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5098-5453 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5098-5475 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5099-5195 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5099-5339 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5229-5100 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5229-5100 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5250-5100 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5250-5100 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5250-5100 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5100-5352 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5100-5352 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5231-5101 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5103-5102 : Rate B, Rate C - 0.0, 0.0 -> 1345.0, 1345.0
% INFO    : Updated Thermal Rating: on transformer 5103-5102 : Rate B, Rate C - 0.0, 0.0 -> 1345.0, 1345.0
% INFO    : Updated Thermal Rating: on line 5102-5304 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 5384-5102 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5464-5102 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5103-5130 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5103-5130 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5104-5199 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5447-5104 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5447-5104 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5104-5480 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5104-5480 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5104-5480 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5104-5480 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5106-5105 : Rate B, Rate C - 0.0, 0.0 -> 82.0, 82.0
% INFO    : Updated Thermal Rating: on transformer 5107-5105 : Rate B, Rate C - 0.0, 0.0 -> 75.0, 75.0
% INFO    : Updated Thermal Rating: on line 5105-5148 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5105-5253 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5105-5422 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5108-5266 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5108-5266 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5108-5353 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5108-5353 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5449-5108 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5449-5108 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5449-5108 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5274-5109 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5109-5333 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5176-5110 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5110-5200 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5203-5111 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5111-5289 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5111-5289 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5111-5372 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5112-5133 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5191-5112 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5112-5246 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5286-5112 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 5113-5195 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5113-5218 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5220-5113 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5219-5114 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5114-5222 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5227-5114 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5115-5421 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5454-5115 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5116-5224 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5116-5224 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5117-5216 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5117-5409 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5334-5118 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5347-5118 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5118-5456 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5119-5205 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5337-5119 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5121-5120 : Rate B, Rate C - 0.0, 0.0 -> 298.0, 298.0
% INFO    : Updated Thermal Rating: on line 5120-5239 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5122-5252 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5122-5308 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5124-5123 : Rate B, Rate C - 0.0, 0.0 -> 214.0, 214.0
% INFO    : Updated Thermal Rating: on line 5159-5123 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 8157-5124 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 5125-5330 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5125-5330 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5126-5252 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5126-5309 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5126-5386 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5191-5127 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5127-5231 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5314-5127 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5128-5214 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5128-5467 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5226-5129 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5129-5240 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5173-5130 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5173-5130 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5132-5131 : Rate B, Rate C - 0.0, 0.0 -> 981.0, 981.0
% INFO    : Updated Thermal Rating: on line 5131-5279 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5131-5410 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5131-6107 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5163-5132 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5155-5134 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5155-5135 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5169-5135 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5135-5264 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5136-5288 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5138-5137 : Rate B, Rate C - 0.0, 0.0 -> 945.0, 945.0
% INFO    : Updated Thermal Rating: on line 5137-5388 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5137-5451 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5139-5183 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5139-5233 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5344-5139 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5140-5466 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5141-5408 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5142-5466 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5143-5216 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5428-5143 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5428-5143 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5144-5314 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5389-5144 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5145-5251 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5145-5251 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5145-5323 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5145-5323 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5145-5323 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5146-5149 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5146-5152 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5146-5152 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5336-5146 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5336-5146 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5336-5146 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5146-5412 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5147-5188 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5147-5224 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5148-5335 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5148-5457 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5463-5148 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5294-5149 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5149-5309 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5197-5150 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5150-5432 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5154-5151 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5191-5151 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5407-5151 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5181-5152 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5181-5152 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5205-5153 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5205-5153 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5154-5247 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5290-5154 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5456-5156 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5157-5194 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5333-5157 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5333-5157 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5316-5158 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5316-5158 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5374-5158 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 5374-5158 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 5271-5159 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5165-5160 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5161-5181 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5161-5272 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5316-5161 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5161-5356 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5162-5211 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5162-5437 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5163-5235 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5165-5164 : Rate B, Rate C - 0.0, 0.0 -> 1379.0, 1379.0
% INFO    : Updated Thermal Rating: on transformer 5166-5164 : Rate B, Rate C - 0.0, 0.0 -> 579.0, 579.0
% INFO    : Updated Thermal Rating: on transformer 5167-5164 : Rate B, Rate C - 0.0, 0.0 -> 215.0, 215.0
% INFO    : Updated Thermal Rating: on line 5164-5204 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5164-5464 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5175-5165 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5175-5165 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5175-5165 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5168-5203 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5168-5245 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5168-5311 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5170-5169 : Rate B, Rate C - 0.0, 0.0 -> 222.0, 222.0
% INFO    : Updated Thermal Rating: on line 5471-5169 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5171-5174 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5306-5172 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5430-5172 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5173-5203 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5474-5174 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5195-5175 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5175-5370 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5175-5370 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5177-5186 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5177-5186 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5177-5287 : Rate B, Rate C - 0.0, 0.0 -> 360.0, 360.0
% INFO    : Updated Thermal Rating: on line 5258-5178 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5308-5178 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5178-5354 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5180-5179 : Rate B, Rate C - 0.0, 0.0 -> 946.0, 946.0
% INFO    : Updated Thermal Rating: on line 5358-5179 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5179-5380 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5179-8043 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5179-8057 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5180-5485 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5182-5314 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5183-5224 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5184-5373 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5387-5184 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5185-5218 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5434-5185 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5434-5185 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5186-5355 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5186-5355 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5188-5203 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5188-5234 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5188-5253 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5189-5230 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5189-5272 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5189-5352 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5189-5352 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5190-5255 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5190-5264 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5190-5430 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5191-5407 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5193-5192 : Rate B, Rate C - 0.0, 0.0 -> 890.0, 890.0
% INFO    : Updated Thermal Rating: on line 5192-5279 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6316-5193 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5194-5330 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5194-5376 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5194-5462 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5197-5196 : Rate B, Rate C - 0.0, 0.0 -> 305.0, 305.0
% INFO    : Updated Thermal Rating: on transformer 5198-5196 : Rate B, Rate C - 0.0, 0.0 -> 594.0, 594.0
% INFO    : Updated Thermal Rating: on line 5196-5204 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5337-5197 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5199-5375 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5199-5438 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5255-5200 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5276-5201 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5327-5201 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5202-5381 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5426-5202 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5205-5204 : Rate B, Rate C - 0.0, 0.0 -> 1134.0, 1134.0
% INFO    : Updated Thermal Rating: on transformer 5206-5204 : Rate B, Rate C - 0.0, 0.0 -> 903.0, 903.0
% INFO    : Updated Thermal Rating: on transformer 5207-5204 : Rate B, Rate C - 0.0, 0.0 -> 915.0, 915.0
% INFO    : Updated Thermal Rating: on transformer 5208-5204 : Rate B, Rate C - 0.0, 0.0 -> 913.0, 913.0
% INFO    : Updated Thermal Rating: on line 5361-5204 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5204-5413 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5209-5246 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5247-5209 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5210-5233 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5210-5428 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5211-5275 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5211-5327 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5212-5256 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5333-5212 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5213-5250 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5214-5229 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5468-5214 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5215-5277 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5216-5442 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5216-5443 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5217-5310 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5217-5310 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5217-5433 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5483-5217 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5483-5217 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5219-5371 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5221-5411 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5222-5426 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5222-5426 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5223-5275 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5307-5224 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5225-5259 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5421-5225 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5227-5354 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5313-5228 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5313-5228 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5313-5228 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5349-5228 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5229-5309 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5230-5478 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5286-5231 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5232-5251 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5440-5232 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 5232-5442 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5233-5339 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5234-5296 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5234-5296 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5235-5271 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5411-5235 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5237-5236 : Rate B, Rate C - 0.0, 0.0 -> 287.0, 287.0
% INFO    : Updated Thermal Rating: on transformer 5238-5236 : Rate B, Rate C - 0.0, 0.0 -> 826.0, 826.0
% INFO    : Updated Thermal Rating: on line 5236-5394 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 5240-5239 : Rate B, Rate C - 0.0, 0.0 -> 477.0, 477.0
% INFO    : Updated Thermal Rating: on transformer 5243-5239 : Rate B, Rate C - 0.0, 0.0 -> 584.0, 584.0
% INFO    : Updated Thermal Rating: on line 5451-5239 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5239-6210 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 5241-5240 : Rate B, Rate C - 0.0, 0.0 -> 204.0, 204.0
% INFO    : Updated Thermal Rating: on line 5242-5241 : Rate B, Rate C - 0.0, 0.0 -> 24.0, 24.0
% INFO    : Updated Thermal Rating: on line 5244-5306 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5244-5442 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5245-5254 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5245-5339 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5261-5246 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5248-5428 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5248-5457 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5248-5483 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5292-5249 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5292-5249 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5250-5385 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 5250-5385 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 5250-5385 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 5250-5385 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on line 5251-5478 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5251-5478 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5252-5340 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5252-5436 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5370-5253 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5370-5253 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5254-5332 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5254-5420 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5254-5420 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5254-5457 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5257-5256 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5256-5427 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5439-5256 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5308-5258 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5259-5412 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5261-5260 : Rate B, Rate C - 0.0, 0.0 -> 375.0, 375.0
% INFO    : Updated Thermal Rating: on transformer 5262-5260 : Rate B, Rate C - 0.0, 0.0 -> 1450.0, 1450.0
% INFO    : Updated Thermal Rating: on transformer 5263-5260 : Rate B, Rate C - 0.0, 0.0 -> 1450.0, 1450.0
% INFO    : Updated Thermal Rating: on line 5317-5260 : Rate B, Rate C - 0.0, 0.0 -> 4352.0, 4352.0
% INFO    : Updated Thermal Rating: on line 5264-5471 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5483-5265 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5483-5265 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5483-5265 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5287-5266 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5267-5466 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5470-5267 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5268-5288 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5427-5269 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5445-5269 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5445-5269 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5270-5389 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5270-5437 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5270-5474 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5271-5390 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5467-5272 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5273-5339 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5273-5422 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5274-5329 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5274-5374 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5275-5476 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5359-5276 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5277-5315 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5280-5278 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5390-5278 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5280-5279 : Rate B, Rate C - 0.0, 0.0 -> 1112.0, 1112.0
% INFO    : Updated Thermal Rating: on transformer 5281-5279 : Rate B, Rate C - 0.0, 0.0 -> 942.0, 942.0
% INFO    : Updated Thermal Rating: on transformer 5282-5279 : Rate B, Rate C - 0.0, 0.0 -> 940.0, 940.0
% INFO    : Updated Thermal Rating: on transformer 5283-5279 : Rate B, Rate C - 0.0, 0.0 -> 935.0, 935.0
% INFO    : Updated Thermal Rating: on line 5279-5358 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5280-5461 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5284-5454 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5289-5436 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5289-5436 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5290-5345 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5291-5292 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5429-5291 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5291-5438 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5292-5312 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5293-5338 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5293-5338 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5293-5402 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5293-5402 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 5296-5295 : Rate B, Rate C - 0.0, 0.0 -> 1233.0, 1233.0
% INFO    : Updated Thermal Rating: on transformer 5297-5295 : Rate B, Rate C - 0.0, 0.0 -> 223.0, 223.0
% INFO    : Updated Thermal Rating: on transformer 5298-5295 : Rate B, Rate C - 0.0, 0.0 -> 525.0, 525.0
% INFO    : Updated Thermal Rating: on transformer 5299-5295 : Rate B, Rate C - 0.0, 0.0 -> 524.0, 524.0
% INFO    : Updated Thermal Rating: on transformer 5300-5295 : Rate B, Rate C - 0.0, 0.0 -> 519.0, 519.0
% INFO    : Updated Thermal Rating: on transformer 5301-5295 : Rate B, Rate C - 0.0, 0.0 -> 403.0, 403.0
% INFO    : Updated Thermal Rating: on transformer 5302-5295 : Rate B, Rate C - 0.0, 0.0 -> 1123.0, 1123.0
% INFO    : Updated Thermal Rating: on transformer 5303-5295 : Rate B, Rate C - 0.0, 0.0 -> 1117.0, 1117.0
% INFO    : Updated Thermal Rating: on line 5304-5295 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5295-5444 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5296-5400 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 5305-5304 : Rate B, Rate C - 0.0, 0.0 -> 1239.0, 1239.0
% INFO    : Updated Thermal Rating: on line 5307-5341 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5307-5341 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5351-5308 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5351-5308 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5310-5339 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5310-5379 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5310-5438 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5316-5354 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5318-5317 : Rate B, Rate C - 0.0, 0.0 -> 1106.0, 1106.0
% INFO    : Updated Thermal Rating: on transformer 5319-5317 : Rate B, Rate C - 0.0, 0.0 -> 925.0, 925.0
% INFO    : Updated Thermal Rating: on transformer 5320-5317 : Rate B, Rate C - 0.0, 0.0 -> 917.0, 917.0
% INFO    : Updated Thermal Rating: on transformer 5321-5317 : Rate B, Rate C - 0.0, 0.0 -> 921.0, 921.0
% INFO    : Updated Thermal Rating: on line 5388-5317 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5401-5317 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5401-5317 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5473-5318 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5473-5318 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5323-5322 : Rate B, Rate C - 0.0, 0.0 -> 1334.0, 1334.0
% INFO    : Updated Thermal Rating: on transformer 5323-5322 : Rate B, Rate C - 0.0, 0.0 -> 1334.0, 1334.0
% INFO    : Updated Thermal Rating: on transformer 5324-5322 : Rate B, Rate C - 0.0, 0.0 -> 952.0, 952.0
% INFO    : Updated Thermal Rating: on transformer 5325-5322 : Rate B, Rate C - 0.0, 0.0 -> 945.0, 945.0
% INFO    : Updated Thermal Rating: on transformer 5326-5322 : Rate B, Rate C - 0.0, 0.0 -> 953.0, 953.0
% INFO    : Updated Thermal Rating: on line 5322-5384 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5448-5322 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5376-5323 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5376-5323 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5323-5425 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5323-5425 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5446-5328 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5330-5433 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5400-5331 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5450-5331 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5429-5332 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5427-5333 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5427-5333 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5334-5484 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5335-5372 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5335-5425 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5351-5336 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5351-5336 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5351-5336 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5481-5338 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5481-5338 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5340-5462 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5340-5467 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5342-5341 : Rate B, Rate C - 0.0, 0.0 -> 49.0, 49.0
% INFO    : Updated Thermal Rating: on transformer 5343-5341 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on line 5422-5341 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5422-5341 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5341-5465 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5341-5465 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5341-5465 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5341-5465 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5372-5344 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5344-5482 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5375-5346 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5346-5441 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5346-5441 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5443-5346 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5443-5346 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5348-5355 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5349-5462 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5351-5350 : Rate B, Rate C - 0.0, 0.0 -> 1258.0, 1258.0
% INFO    : Updated Thermal Rating: on transformer 5351-5350 : Rate B, Rate C - 0.0, 0.0 -> 1258.0, 1258.0
% INFO    : Updated Thermal Rating: on line 5350-5448 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5350-5464 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5351-5431 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5376-5353 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 5376-5353 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 5353-5468 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5355-5445 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5355-5445 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5386-5356 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5356-5431 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5357-5386 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5359-5358 : Rate B, Rate C - 0.0, 0.0 -> 1057.0, 1057.0
% INFO    : Updated Thermal Rating: on transformer 5360-5358 : Rate B, Rate C - 0.0, 0.0 -> 1333.0, 1333.0
% INFO    : Updated Thermal Rating: on line 8155-5358 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 5362-5361 : Rate B, Rate C - 0.0, 0.0 -> 646.0, 646.0
% INFO    : Updated Thermal Rating: on transformer 5363-5361 : Rate B, Rate C - 0.0, 0.0 -> 282.0, 282.0
% INFO    : Updated Thermal Rating: on transformer 5364-5361 : Rate B, Rate C - 0.0, 0.0 -> 798.0, 798.0
% INFO    : Updated Thermal Rating: on transformer 5365-5361 : Rate B, Rate C - 0.0, 0.0 -> 787.0, 787.0
% INFO    : Updated Thermal Rating: on transformer 5366-5361 : Rate B, Rate C - 0.0, 0.0 -> 795.0, 795.0
% INFO    : Updated Thermal Rating: on transformer 5367-5361 : Rate B, Rate C - 0.0, 0.0 -> 809.0, 809.0
% INFO    : Updated Thermal Rating: on transformer 5368-5361 : Rate B, Rate C - 0.0, 0.0 -> 798.0, 798.0
% INFO    : Updated Thermal Rating: on transformer 5369-5361 : Rate B, Rate C - 0.0, 0.0 -> 796.0, 796.0
% INFO    : Updated Thermal Rating: on line 5373-5433 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5385-5374 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5385-5374 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5385-5374 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5377-5477 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 5470-5378 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on line 5379-5442 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5381-5380 : Rate B, Rate C - 0.0, 0.0 -> 1057.0, 1057.0
% INFO    : Updated Thermal Rating: on transformer 5382-5380 : Rate B, Rate C - 0.0, 0.0 -> 786.0, 786.0
% INFO    : Updated Thermal Rating: on transformer 5383-5380 : Rate B, Rate C - 0.0, 0.0 -> 787.0, 787.0
% INFO    : Updated Thermal Rating: on line 5380-5384 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 5381-5439 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5381-5439 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5385-5384 : Rate B, Rate C - 0.0, 0.0 -> 1346.0, 1346.0
% INFO    : Updated Thermal Rating: on transformer 5385-5384 : Rate B, Rate C - 0.0, 0.0 -> 1346.0, 1346.0
% INFO    : Updated Thermal Rating: on line 5387-5429 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5469-5387 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on transformer 5389-5388 : Rate B, Rate C - 0.0, 0.0 -> 1064.0, 1064.0
% INFO    : Updated Thermal Rating: on line 5388-8067 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 5389-5393 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5391-5390 : Rate B, Rate C - 0.0, 0.0 -> 65.0, 65.0
% INFO    : Updated Thermal Rating: on line 5390-5458 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5392-5391 : Rate B, Rate C - 0.0, 0.0 -> 50.0, 50.0
% INFO    : Updated Thermal Rating: on line 5459-5391 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 5395-5394 : Rate B, Rate C - 0.0, 0.0 -> 1163.0, 1163.0
% INFO    : Updated Thermal Rating: on transformer 5399-5394 : Rate B, Rate C - 0.0, 0.0 -> 645.0, 645.0
% INFO    : Updated Thermal Rating: on transformer 5396-5395 : Rate B, Rate C - 0.0, 0.0 -> 320.0, 320.0
% INFO    : Updated Thermal Rating: on transformer 5397-5396 : Rate B, Rate C - 0.0, 0.0 -> 168.0, 168.0
% INFO    : Updated Thermal Rating: on line 5398-5397 : Rate B, Rate C - 0.0, 0.0 -> 21.0, 21.0
% INFO    : Updated Thermal Rating: on transformer 5402-5401 : Rate B, Rate C - 0.0, 0.0 -> 1174.0, 1174.0
% INFO    : Updated Thermal Rating: on transformer 5403-5401 : Rate B, Rate C - 0.0, 0.0 -> 426.0, 426.0
% INFO    : Updated Thermal Rating: on transformer 5404-5401 : Rate B, Rate C - 0.0, 0.0 -> 435.0, 435.0
% INFO    : Updated Thermal Rating: on transformer 5405-5401 : Rate B, Rate C - 0.0, 0.0 -> 440.0, 440.0
% INFO    : Updated Thermal Rating: on transformer 5406-5401 : Rate B, Rate C - 0.0, 0.0 -> 433.0, 433.0
% INFO    : Updated Thermal Rating: on line 5407-5470 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5408-5421 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5409-5447 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on transformer 5411-5410 : Rate B, Rate C - 0.0, 0.0 -> 1041.0, 1041.0
% INFO    : Updated Thermal Rating: on line 5410-5451 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 5411-5477 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 6316-5411 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5414-5413 : Rate B, Rate C - 0.0, 0.0 -> 315.0, 315.0
% INFO    : Updated Thermal Rating: on transformer 5415-5413 : Rate B, Rate C - 0.0, 0.0 -> 561.0, 561.0
% INFO    : Updated Thermal Rating: on transformer 5416-5413 : Rate B, Rate C - 0.0, 0.0 -> 559.0, 559.0
% INFO    : Updated Thermal Rating: on transformer 5417-5413 : Rate B, Rate C - 0.0, 0.0 -> 574.0, 574.0
% INFO    : Updated Thermal Rating: on transformer 5418-5413 : Rate B, Rate C - 0.0, 0.0 -> 551.0, 551.0
% INFO    : Updated Thermal Rating: on transformer 5419-5413 : Rate B, Rate C - 0.0, 0.0 -> 561.0, 561.0
% INFO    : Updated Thermal Rating: on line 5414-5471 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5423-5422 : Rate B, Rate C - 0.0, 0.0 -> 94.0, 94.0
% INFO    : Updated Thermal Rating: on transformer 5424-5422 : Rate B, Rate C - 0.0, 0.0 -> 77.0, 77.0
% INFO    : Updated Thermal Rating: on line 5432-5430 : Rate B, Rate C - 0.0, 0.0 -> 310.0, 310.0
% INFO    : Updated Thermal Rating: on line 5435-5471 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on line 5443-5469 : Rate B, Rate C - 0.0, 0.0 -> 380.0, 380.0
% INFO    : Updated Thermal Rating: on transformer 5445-5444 : Rate B, Rate C - 0.0, 0.0 -> 1266.0, 1266.0
% INFO    : Updated Thermal Rating: on line 5470-5446 : Rate B, Rate C - 0.0, 0.0 -> 187.0, 187.0
% INFO    : Updated Thermal Rating: on transformer 5449-5448 : Rate B, Rate C - 0.0, 0.0 -> 1267.0, 1267.0
% INFO    : Updated Thermal Rating: on line 5448-5479 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 5452-5451 : Rate B, Rate C - 0.0, 0.0 -> 960.0, 960.0
% INFO    : Updated Thermal Rating: on transformer 5459-5458 : Rate B, Rate C - 0.0, 0.0 -> 80.0, 80.0
% INFO    : Updated Thermal Rating: on line 5460-5459 : Rate B, Rate C - 0.0, 0.0 -> 35.0, 35.0
% INFO    : Updated Thermal Rating: on line 6140-5459 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 5459-6325 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 5463-5478 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 5465-5464 : Rate B, Rate C - 0.0, 0.0 -> 1284.0, 1284.0
% INFO    : Updated Thermal Rating: on line 5467-5482 : Rate B, Rate C - 0.0, 0.0 -> 409.0, 409.0
% INFO    : Updated Thermal Rating: on transformer 5480-5479 : Rate B, Rate C - 0.0, 0.0 -> 961.0, 961.0
% INFO    : Updated Thermal Rating: on line 6001-6281 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6001-6283 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6001-6312 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6002-6060 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6002-6291 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6002-6291 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6002-6332 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6004-6003 : Rate B, Rate C - 0.0, 0.0 -> 1117.0, 1117.0
% INFO    : Updated Thermal Rating: on transformer 6006-6003 : Rate B, Rate C - 0.0, 0.0 -> 788.0, 788.0
% INFO    : Updated Thermal Rating: on transformer 6007-6003 : Rate B, Rate C - 0.0, 0.0 -> 1069.0, 1069.0
% INFO    : Updated Thermal Rating: on transformer 6008-6003 : Rate B, Rate C - 0.0, 0.0 -> 754.0, 754.0
% INFO    : Updated Thermal Rating: on transformer 6009-6003 : Rate B, Rate C - 0.0, 0.0 -> 758.0, 758.0
% INFO    : Updated Thermal Rating: on transformer 6010-6003 : Rate B, Rate C - 0.0, 0.0 -> 758.0, 758.0
% INFO    : Updated Thermal Rating: on line 6003-6107 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6292-6003 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 6005-6004 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 6005-6004 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 6102-6004 : Rate B, Rate C - 0.0, 0.0 -> 1400.0, 1400.0
% INFO    : Updated Thermal Rating: on line 6012-6005 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6012-6005 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6005-6117 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6005-6117 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6011-6068 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6163-6011 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6027-6012 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6027-6012 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6026-6013 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6013-6128 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6013-6168 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6013-6225 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6014-6096 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6133-6014 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6014-6139 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6015-6112 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6236-6015 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6016-6168 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6016-6168 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6199-6016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6199-6016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6199-6016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6016-6356 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on line 6068-6017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6068-6017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6068-6017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6017-6159 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6017-6159 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6017-6159 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6160-6018 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6160-6018 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6160-6018 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6018-6256 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6018-6256 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6018-6256 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6040-6019 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6040-6019 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6040-6019 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6019-6113 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6019-6113 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6019-6306 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6019-6313 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6019-6313 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6020-6212 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6020-6252 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6022-6021 : Rate B, Rate C - 0.0, 0.0 -> 948.0, 948.0
% INFO    : Updated Thermal Rating: on line 6118-6021 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6021-6210 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6023-6022 : Rate B, Rate C - 0.0, 0.0 -> 438.0, 438.0
% INFO    : Updated Thermal Rating: on line 6315-6022 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6022-6350 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6120-6023 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6023-6262 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6023-6262 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6024-6181 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6024-6219 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 6024-6330 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6025-6060 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6121-6025 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6025-6337 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6025-6337 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6352-6025 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6026-6182 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6236-6026 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6236-6026 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6027-6181 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 6126-6028 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6126-6028 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6028-6223 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6028-6223 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6028-6289 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6029-6221 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6329-6029 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6031-6030 : Rate B, Rate C - 0.0, 0.0 -> 124.0, 124.0
% INFO    : Updated Thermal Rating: on line 6030-6172 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6030-6188 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6030-7274 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6173-6031 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6032-6207 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6217-6032 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6034-6033 : Rate B, Rate C - 0.0, 0.0 -> 1058.0, 1058.0
% INFO    : Updated Thermal Rating: on line 6107-6033 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 6033-6342 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6035-6034 : Rate B, Rate C - 0.0, 0.0 -> 540.0, 540.0
% INFO    : Updated Thermal Rating: on transformer 6035-6034 : Rate B, Rate C - 0.0, 0.0 -> 540.0, 540.0
% INFO    : Updated Thermal Rating: on line 6108-6034 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6034-6119 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6034-6255 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6034-6343 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6061-6035 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6061-6035 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6123-6035 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6123-6035 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6035-6306 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6037-6036 : Rate B, Rate C - 0.0, 0.0 -> 467.0, 467.0
% INFO    : Updated Thermal Rating: on transformer 6037-6036 : Rate B, Rate C - 0.0, 0.0 -> 467.0, 467.0
% INFO    : Updated Thermal Rating: on transformer 6037-6036 : Rate B, Rate C - 0.0, 0.0 -> 467.0, 467.0
% INFO    : Updated Thermal Rating: on line 6036-6067 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 6036-6142 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 6036-6142 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 6287-6036 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6036-6334 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6094-6037 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6094-6037 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6220-6037 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6220-6037 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6220-6037 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6039-6038 : Rate B, Rate C - 0.0, 0.0 -> 1269.0, 1269.0
% INFO    : Updated Thermal Rating: on transformer 6041-6038 : Rate B, Rate C - 0.0, 0.0 -> 296.0, 296.0
% INFO    : Updated Thermal Rating: on transformer 6042-6038 : Rate B, Rate C - 0.0, 0.0 -> 479.0, 479.0
% INFO    : Updated Thermal Rating: on line 6038-6066 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6254-6038 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6349-6038 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6040-6039 : Rate B, Rate C - 0.0, 0.0 -> 271.8, 271.8
% INFO    : Updated Thermal Rating: on transformer 6040-6039 : Rate B, Rate C - 0.0, 0.0 -> 271.8, 271.8
% INFO    : Updated Thermal Rating: on line 6222-6039 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6040-6224 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6043-6236 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6043-6236 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6335-6043 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6335-6043 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6044-6203 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6204-6044 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6044-6284 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6044-6323 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6044-6323 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6046-6045 : Rate B, Rate C - 0.0, 0.0 -> 1198.0, 1198.0
% INFO    : Updated Thermal Rating: on transformer 6048-6045 : Rate B, Rate C - 0.0, 0.0 -> 233.0, 233.0
% INFO    : Updated Thermal Rating: on transformer 6049-6045 : Rate B, Rate C - 0.0, 0.0 -> 283.0, 283.0
% INFO    : Updated Thermal Rating: on transformer 6050-6045 : Rate B, Rate C - 0.0, 0.0 -> 256.0, 256.0
% INFO    : Updated Thermal Rating: on transformer 6051-6045 : Rate B, Rate C - 0.0, 0.0 -> 351.0, 351.0
% INFO    : Updated Thermal Rating: on transformer 6052-6045 : Rate B, Rate C - 0.0, 0.0 -> 342.0, 342.0
% INFO    : Updated Thermal Rating: on transformer 6053-6045 : Rate B, Rate C - 0.0, 0.0 -> 352.0, 352.0
% INFO    : Updated Thermal Rating: on transformer 6054-6045 : Rate B, Rate C - 0.0, 0.0 -> 338.0, 338.0
% INFO    : Updated Thermal Rating: on line 6066-6045 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6210-6045 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6045-6234 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6047-6046 : Rate B, Rate C - 0.0, 0.0 -> 320.0, 320.0
% INFO    : Updated Thermal Rating: on transformer 6047-6046 : Rate B, Rate C - 0.0, 0.0 -> 320.0, 320.0
% INFO    : Updated Thermal Rating: on line 6198-6046 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 6046-6285 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6047-6150 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6047-6150 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6291-6047 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6291-6047 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6226-6055 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6055-6286 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6057-6056 : Rate B, Rate C - 0.0, 0.0 -> 1171.0, 1171.0
% INFO    : Updated Thermal Rating: on line 6056-6066 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6161-6056 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 6298-6056 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6058-6057 : Rate B, Rate C - 0.0, 0.0 -> 328.0, 328.0
% INFO    : Updated Thermal Rating: on transformer 6058-6057 : Rate B, Rate C - 0.0, 0.0 -> 328.0, 328.0
% INFO    : Updated Thermal Rating: on line 6067-6057 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6057-6177 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6058-6124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6058-6124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6058-6124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6300-6058 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6357-6059 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6060-6157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6314-6060 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6061-6219 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6061-6224 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6063-6062 : Rate B, Rate C - 0.0, 0.0 -> 1206.0, 1206.0
% INFO    : Updated Thermal Rating: on line 6075-6062 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7199-6062 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6064-6063 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 6063-6192 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 8094-6063 : Rate B, Rate C - 0.0, 0.0 -> 800.0, 800.0
% INFO    : Updated Thermal Rating: on line 6064-6341 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6065-6262 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6067-6066 : Rate B, Rate C - 0.0, 0.0 -> 1115.0, 1115.0
% INFO    : Updated Thermal Rating: on transformer 6069-6066 : Rate B, Rate C - 0.0, 0.0 -> 667.0, 667.0
% INFO    : Updated Thermal Rating: on transformer 6070-6066 : Rate B, Rate C - 0.0, 0.0 -> 677.0, 677.0
% INFO    : Updated Thermal Rating: on transformer 6071-6066 : Rate B, Rate C - 0.0, 0.0 -> 670.0, 670.0
% INFO    : Updated Thermal Rating: on transformer 6072-6066 : Rate B, Rate C - 0.0, 0.0 -> 679.0, 679.0
% INFO    : Updated Thermal Rating: on transformer 6073-6066 : Rate B, Rate C - 0.0, 0.0 -> 664.0, 664.0
% INFO    : Updated Thermal Rating: on transformer 6074-6066 : Rate B, Rate C - 0.0, 0.0 -> 666.0, 666.0
% INFO    : Updated Thermal Rating: on transformer 6068-6067 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 6068-6067 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 6279-6067 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 6076-6075 : Rate B, Rate C - 0.0, 0.0 -> 1058.0, 1058.0
% INFO    : Updated Thermal Rating: on transformer 6078-6075 : Rate B, Rate C - 0.0, 0.0 -> 1159.0, 1159.0
% INFO    : Updated Thermal Rating: on transformer 6079-6075 : Rate B, Rate C - 0.0, 0.0 -> 1165.0, 1165.0
% INFO    : Updated Thermal Rating: on transformer 6080-6075 : Rate B, Rate C - 0.0, 0.0 -> 1152.0, 1152.0
% INFO    : Updated Thermal Rating: on line 6075-6101 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7018-6075 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6077-6076 : Rate B, Rate C - 0.0, 0.0 -> 176.4, 176.4
% INFO    : Updated Thermal Rating: on line 6102-6076 : Rate B, Rate C - 0.0, 0.0 -> 850.0, 850.0
% INFO    : Updated Thermal Rating: on line 6188-6076 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6077-6135 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6077-6311 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6082-6081 : Rate B, Rate C - 0.0, 0.0 -> 80.0, 80.0
% INFO    : Updated Thermal Rating: on transformer 6083-6081 : Rate B, Rate C - 0.0, 0.0 -> 80.0, 80.0
% INFO    : Updated Thermal Rating: on line 6081-6156 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6212-6081 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6085-6084 : Rate B, Rate C - 0.0, 0.0 -> 31.0, 31.0
% INFO    : Updated Thermal Rating: on transformer 6086-6084 : Rate B, Rate C - 0.0, 0.0 -> 41.0, 41.0
% INFO    : Updated Thermal Rating: on transformer 6087-6084 : Rate B, Rate C - 0.0, 0.0 -> 43.0, 43.0
% INFO    : Updated Thermal Rating: on transformer 6088-6084 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 6089-6084 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on transformer 6090-6084 : Rate B, Rate C - 0.0, 0.0 -> 46.0, 46.0
% INFO    : Updated Thermal Rating: on line 6084-6136 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6084-6355 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6091-6176 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6251-6091 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6265-6092 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6092-6340 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6094-6093 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6093-6191 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6094-6352 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6094-6352 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6116-6095 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6095-6353 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6095-6353 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6095-6358 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6196-6096 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6096-6202 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6096-6340 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6097-6220 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6097-6220 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6097-6225 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6098-6123 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6098-6123 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6098-6208 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6098-6289 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6099-6204 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6099-6225 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6099-6310 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6100-6128 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6180-6100 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6283-6100 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6102-6101 : Rate B, Rate C - 0.0, 0.0 -> 1307.0, 1307.0
% INFO    : Updated Thermal Rating: on transformer 6104-6101 : Rate B, Rate C - 0.0, 0.0 -> 378.0, 378.0
% INFO    : Updated Thermal Rating: on transformer 6105-6101 : Rate B, Rate C - 0.0, 0.0 -> 368.0, 368.0
% INFO    : Updated Thermal Rating: on transformer 6106-6101 : Rate B, Rate C - 0.0, 0.0 -> 560.0, 560.0
% INFO    : Updated Thermal Rating: on transformer 6103-6102 : Rate B, Rate C - 0.0, 0.0 -> 439.0, 439.0
% INFO    : Updated Thermal Rating: on line 6103-6117 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6103-6117 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6103-6183 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6108-6107 : Rate B, Rate C - 0.0, 0.0 -> 380.0, 380.0
% INFO    : Updated Thermal Rating: on transformer 6110-6107 : Rate B, Rate C - 0.0, 0.0 -> 1181.0, 1181.0
% INFO    : Updated Thermal Rating: on transformer 6111-6107 : Rate B, Rate C - 0.0, 0.0 -> 1208.0, 1208.0
% INFO    : Updated Thermal Rating: on line 6107-8082 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6109-6108 : Rate B, Rate C - 0.0, 0.0 -> 137.0, 137.0
% INFO    : Updated Thermal Rating: on line 6108-6192 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 6338-6109 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6113-6175 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6113-6175 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6113-6345 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6114-6204 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6114-6261 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6159-6115 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6159-6115 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6115-6191 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6115-6225 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6115-6250 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6181-6116 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6119-6118 : Rate B, Rate C - 0.0, 0.0 -> 1133.0, 1133.0
% INFO    : Updated Thermal Rating: on line 6118-6349 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 6120-6119 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on transformer 6120-6119 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 6119-6354 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6290-6120 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6290-6120 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6121-6174 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6121-6179 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6220-6121 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6220-6121 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6122-6327 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7337-6122 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6233-6123 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6124-6131 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6191-6124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6124-6314 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6180-6125 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6125-6322 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6126-6130 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6126-6176 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6126-6176 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6126-6313 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6127-6237 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6338-6127 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6127-8102 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6128-6276 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 6129-6309 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6129-6336 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6130-6230 : Rate B, Rate C - 0.0, 0.0 -> 230.0, 230.0
% INFO    : Updated Thermal Rating: on line 6130-6231 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6131-6251 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6132-6137 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6175-6132 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6190-6133 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6134-6140 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6134-6358 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6195-6135 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6358-6136 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6137-6184 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6137-6217 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6157-6138 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6138-6286 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6139-6339 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6142-6141 : Rate B, Rate C - 0.0, 0.0 -> 1326.0, 1326.0
% INFO    : Updated Thermal Rating: on transformer 6142-6141 : Rate B, Rate C - 0.0, 0.0 -> 1326.0, 1326.0
% INFO    : Updated Thermal Rating: on transformer 6144-6141 : Rate B, Rate C - 0.0, 0.0 -> 265.0, 265.0
% INFO    : Updated Thermal Rating: on transformer 6145-6141 : Rate B, Rate C - 0.0, 0.0 -> 1093.0, 1093.0
% INFO    : Updated Thermal Rating: on transformer 6146-6141 : Rate B, Rate C - 0.0, 0.0 -> 1090.0, 1090.0
% INFO    : Updated Thermal Rating: on transformer 6147-6141 : Rate B, Rate C - 0.0, 0.0 -> 1332.0, 1332.0
% INFO    : Updated Thermal Rating: on transformer 6148-6141 : Rate B, Rate C - 0.0, 0.0 -> 1248.0, 1248.0
% INFO    : Updated Thermal Rating: on transformer 6149-6141 : Rate B, Rate C - 0.0, 0.0 -> 1255.0, 1255.0
% INFO    : Updated Thermal Rating: on line 6141-6161 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6141-6197 : Rate B, Rate C - 0.0, 0.0 -> 4352.0, 4352.0
% INFO    : Updated Thermal Rating: on line 6239-6141 : Rate B, Rate C - 0.0, 0.0 -> 2400.0, 2400.0
% INFO    : Updated Thermal Rating: on transformer 6143-6142 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 6143-6142 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 6143-6142 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6142-6162 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6143-6284 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6143-6284 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6312-6143 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6312-6143 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6312-6143 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6312-6143 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6150-6356 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6150-6356 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6190-6151 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6151-6311 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6327-6151 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 6153-6152 : Rate B, Rate C - 0.0, 0.0 -> 155.0, 155.0
% INFO    : Updated Thermal Rating: on line 6152-6177 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6152-6198 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6241-6153 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6241-6153 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6153-6324 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6153-6324 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6176-6154 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6252-6154 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6155-6284 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6156-6282 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6158-6341 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8104-6158 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6281-6159 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6160-6175 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6160-6175 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6160-6233 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6160-6330 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6162-6161 : Rate B, Rate C - 0.0, 0.0 -> 1132.0, 1132.0
% INFO    : Updated Thermal Rating: on transformer 6164-6161 : Rate B, Rate C - 0.0, 0.0 -> 880.0, 880.0
% INFO    : Updated Thermal Rating: on transformer 6165-6161 : Rate B, Rate C - 0.0, 0.0 -> 879.0, 879.0
% INFO    : Updated Thermal Rating: on transformer 6166-6161 : Rate B, Rate C - 0.0, 0.0 -> 880.0, 880.0
% INFO    : Updated Thermal Rating: on transformer 6167-6161 : Rate B, Rate C - 0.0, 0.0 -> 883.0, 883.0
% INFO    : Updated Thermal Rating: on line 6161-7018 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on transformer 6163-6162 : Rate B, Rate C - 0.0, 0.0 -> 184.2, 184.2
% INFO    : Updated Thermal Rating: on line 6162-6277 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6279-6162 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6280-6163 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6168-6209 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6168-6261 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6170-6169 : Rate B, Rate C - 0.0, 0.0 -> 1108.0, 1108.0
% INFO    : Updated Thermal Rating: on line 6169-6239 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6171-6170 : Rate B, Rate C - 0.0, 0.0 -> 297.0, 297.0
% INFO    : Updated Thermal Rating: on line 6170-6235 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6308-6170 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6170-6334 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6236-6171 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6173-6172 : Rate B, Rate C - 0.0, 0.0 -> 137.0, 137.0
% INFO    : Updated Thermal Rating: on line 6173-6265 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7020-6173 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6174-6203 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6174-6250 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6174-6320 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6174-6320 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6175-6194 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6175-6289 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6230-6176 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6178-6177 : Rate B, Rate C - 0.0, 0.0 -> 172.8, 172.8
% INFO    : Updated Thermal Rating: on transformer 6178-6177 : Rate B, Rate C - 0.0, 0.0 -> 172.8, 172.8
% INFO    : Updated Thermal Rating: on line 6235-6177 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 6177-6287 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6177-6299 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6177-6308 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6334-6177 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6178-6209 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6332-6178 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6291-6179 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6182-6201 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6183-6206 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6184-6185 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6184-6205 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6184-6219 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6185-6313 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6186-6187 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6186-6187 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6186-6351 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6186-6351 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6187-6219 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6187-6289 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6189-6188 : Rate B, Rate C - 0.0, 0.0 -> 178.0, 178.0
% INFO    : Updated Thermal Rating: on line 6188-7305 : Rate B, Rate C - 0.0, 0.0 -> 460.0, 460.0
% INFO    : Updated Thermal Rating: on line 6327-6189 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6193-6192 : Rate B, Rate C - 0.0, 0.0 -> 125.0, 125.0
% INFO    : Updated Thermal Rating: on line 6193-6206 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6193-6326 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6196-6194 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6194-6231 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6232-6194 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6195-7314 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6198-6197 : Rate B, Rate C - 0.0, 0.0 -> 1372.0, 1372.0
% INFO    : Updated Thermal Rating: on line 6197-6234 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 6197-6333 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6199-6198 : Rate B, Rate C - 0.0, 0.0 -> 420.0, 420.0
% INFO    : Updated Thermal Rating: on transformer 6199-6198 : Rate B, Rate C - 0.0, 0.0 -> 420.0, 420.0
% INFO    : Updated Thermal Rating: on transformer 6199-6198 : Rate B, Rate C - 0.0, 0.0 -> 420.0, 420.0
% INFO    : Updated Thermal Rating: on line 6287-6198 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6337-6199 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6337-6199 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6200-6225 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6200-6275 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6200-6284 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6201-6203 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6201-6356 : Rate B, Rate C - 0.0, 0.0 -> 245.0, 245.0
% INFO    : Updated Thermal Rating: on line 6280-6202 : Rate B, Rate C - 0.0, 0.0 -> 115.0, 115.0
% INFO    : Updated Thermal Rating: on line 6340-6202 : Rate B, Rate C - 0.0, 0.0 -> 115.0, 115.0
% INFO    : Updated Thermal Rating: on line 6204-6337 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6205-6223 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6205-6223 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6207-6282 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6207-6313 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6331-6208 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6331-6208 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6208-6353 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6309-6209 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on transformer 6211-6210 : Rate B, Rate C - 0.0, 0.0 -> 978.0, 978.0
% INFO    : Updated Thermal Rating: on transformer 6213-6210 : Rate B, Rate C - 0.0, 0.0 -> 363.0, 363.0
% INFO    : Updated Thermal Rating: on transformer 6214-6210 : Rate B, Rate C - 0.0, 0.0 -> 718.0, 718.0
% INFO    : Updated Thermal Rating: on transformer 6215-6210 : Rate B, Rate C - 0.0, 0.0 -> 721.0, 721.0
% INFO    : Updated Thermal Rating: on transformer 6216-6210 : Rate B, Rate C - 0.0, 0.0 -> 710.0, 710.0
% INFO    : Updated Thermal Rating: on line 6210-6292 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6212-6211 : Rate B, Rate C - 0.0, 0.0 -> 381.0, 381.0
% INFO    : Updated Thermal Rating: on line 6211-6359 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6218-6231 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6278-6218 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6219-6345 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6221-6322 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6223-6222 : Rate B, Rate C - 0.0, 0.0 -> 457.0, 457.0
% INFO    : Updated Thermal Rating: on transformer 6223-6222 : Rate B, Rate C - 0.0, 0.0 -> 457.0, 457.0
% INFO    : Updated Thermal Rating: on transformer 6223-6222 : Rate B, Rate C - 0.0, 0.0 -> 457.0, 457.0
% INFO    : Updated Thermal Rating: on line 6222-6229 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6255-6222 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6222-6293 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6222-6354 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6227-6223 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6227-6223 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6224-6331 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6225-6307 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6227-6238 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6227-6238 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6227-6330 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6229-6228 : Rate B, Rate C - 0.0, 0.0 -> 1208.0, 1208.0
% INFO    : Updated Thermal Rating: on line 6298-6228 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 6230-6229 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on transformer 6230-6229 : Rate B, Rate C - 0.0, 0.0 -> 350.0, 350.0
% INFO    : Updated Thermal Rating: on line 6277-6229 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 6230-6278 : Rate B, Rate C - 0.0, 0.0 -> 140.0, 140.0
% INFO    : Updated Thermal Rating: on line 6232-6294 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6232-6294 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6235-6234 : Rate B, Rate C - 0.0, 0.0 -> 1190.0, 1190.0
% INFO    : Updated Thermal Rating: on transformer 6236-6235 : Rate B, Rate C - 0.0, 0.0 -> 406.0, 406.0
% INFO    : Updated Thermal Rating: on transformer 6236-6235 : Rate B, Rate C - 0.0, 0.0 -> 406.0, 406.0
% INFO    : Updated Thermal Rating: on line 6325-6237 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 6237-8102 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6238-6345 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6240-6239 : Rate B, Rate C - 0.0, 0.0 -> 1194.0, 1194.0
% INFO    : Updated Thermal Rating: on transformer 6242-6239 : Rate B, Rate C - 0.0, 0.0 -> 380.0, 380.0
% INFO    : Updated Thermal Rating: on transformer 6243-6239 : Rate B, Rate C - 0.0, 0.0 -> 690.0, 690.0
% INFO    : Updated Thermal Rating: on transformer 6244-6239 : Rate B, Rate C - 0.0, 0.0 -> 957.0, 957.0
% INFO    : Updated Thermal Rating: on transformer 6245-6239 : Rate B, Rate C - 0.0, 0.0 -> 965.0, 965.0
% INFO    : Updated Thermal Rating: on transformer 6246-6239 : Rate B, Rate C - 0.0, 0.0 -> 967.0, 967.0
% INFO    : Updated Thermal Rating: on transformer 6247-6239 : Rate B, Rate C - 0.0, 0.0 -> 694.0, 694.0
% INFO    : Updated Thermal Rating: on transformer 6248-6239 : Rate B, Rate C - 0.0, 0.0 -> 689.0, 689.0
% INFO    : Updated Thermal Rating: on transformer 6249-6239 : Rate B, Rate C - 0.0, 0.0 -> 685.0, 685.0
% INFO    : Updated Thermal Rating: on line 6239-7414 : Rate B, Rate C - 0.0, 0.0 -> 2000.0, 2000.0
% INFO    : Updated Thermal Rating: on transformer 6241-6240 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 6241-6240 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 6240-6287 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6240-6321 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6253-6329 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6255-6254 : Rate B, Rate C - 0.0, 0.0 -> 1350.0, 1350.0
% INFO    : Updated Thermal Rating: on transformer 6257-6254 : Rate B, Rate C - 0.0, 0.0 -> 726.0, 726.0
% INFO    : Updated Thermal Rating: on transformer 6258-6254 : Rate B, Rate C - 0.0, 0.0 -> 731.0, 731.0
% INFO    : Updated Thermal Rating: on transformer 6259-6254 : Rate B, Rate C - 0.0, 0.0 -> 333.0, 333.0
% INFO    : Updated Thermal Rating: on transformer 6260-6254 : Rate B, Rate C - 0.0, 0.0 -> 914.0, 914.0
% INFO    : Updated Thermal Rating: on line 6292-6254 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 6256-6255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 6256-6255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 6262-6319 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6264-6263 : Rate B, Rate C - 0.0, 0.0 -> 120.0, 120.0
% INFO    : Updated Thermal Rating: on line 6321-6263 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 6263-7274 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on transformer 6266-6265 : Rate B, Rate C - 0.0, 0.0 -> 29.0, 29.0
% INFO    : Updated Thermal Rating: on transformer 6267-6265 : Rate B, Rate C - 0.0, 0.0 -> 35.0, 35.0
% INFO    : Updated Thermal Rating: on transformer 6268-6265 : Rate B, Rate C - 0.0, 0.0 -> 30.0, 30.0
% INFO    : Updated Thermal Rating: on transformer 6269-6265 : Rate B, Rate C - 0.0, 0.0 -> 32.0, 32.0
% INFO    : Updated Thermal Rating: on transformer 6270-6265 : Rate B, Rate C - 0.0, 0.0 -> 47.0, 47.0
% INFO    : Updated Thermal Rating: on transformer 6271-6265 : Rate B, Rate C - 0.0, 0.0 -> 42.0, 42.0
% INFO    : Updated Thermal Rating: on transformer 6272-6265 : Rate B, Rate C - 0.0, 0.0 -> 35.0, 35.0
% INFO    : Updated Thermal Rating: on transformer 6273-6265 : Rate B, Rate C - 0.0, 0.0 -> 32.0, 32.0
% INFO    : Updated Thermal Rating: on transformer 6274-6265 : Rate B, Rate C - 0.0, 0.0 -> 39.0, 39.0
% INFO    : Updated Thermal Rating: on line 6275-6324 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6275-6324 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6278-6277 : Rate B, Rate C - 0.0, 0.0 -> 331.0, 331.0
% INFO    : Updated Thermal Rating: on transformer 6280-6279 : Rate B, Rate C - 0.0, 0.0 -> 163.2, 163.2
% INFO    : Updated Thermal Rating: on line 6279-6299 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on transformer 6286-6285 : Rate B, Rate C - 0.0, 0.0 -> 311.0, 311.0
% INFO    : Updated Thermal Rating: on line 6328-6286 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6288-6287 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 6288-6287 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 6288-6307 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6288-6307 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6288-6323 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6288-6323 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6290-6331 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6290-6331 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 6293-6292 : Rate B, Rate C - 0.0, 0.0 -> 1210.0, 1210.0
% INFO    : Updated Thermal Rating: on transformer 6295-6292 : Rate B, Rate C - 0.0, 0.0 -> 756.0, 756.0
% INFO    : Updated Thermal Rating: on transformer 6296-6292 : Rate B, Rate C - 0.0, 0.0 -> 762.0, 762.0
% INFO    : Updated Thermal Rating: on transformer 6297-6292 : Rate B, Rate C - 0.0, 0.0 -> 765.0, 765.0
% INFO    : Updated Thermal Rating: on transformer 6294-6293 : Rate B, Rate C - 0.0, 0.0 -> 217.8, 217.8
% INFO    : Updated Thermal Rating: on line 6294-6339 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6299-6298 : Rate B, Rate C - 0.0, 0.0 -> 994.0, 994.0
% INFO    : Updated Thermal Rating: on transformer 6301-6298 : Rate B, Rate C - 0.0, 0.0 -> 225.0, 225.0
% INFO    : Updated Thermal Rating: on transformer 6302-6298 : Rate B, Rate C - 0.0, 0.0 -> 897.0, 897.0
% INFO    : Updated Thermal Rating: on transformer 6303-6298 : Rate B, Rate C - 0.0, 0.0 -> 887.0, 887.0
% INFO    : Updated Thermal Rating: on transformer 6304-6298 : Rate B, Rate C - 0.0, 0.0 -> 896.0, 896.0
% INFO    : Updated Thermal Rating: on transformer 6305-6298 : Rate B, Rate C - 0.0, 0.0 -> 904.0, 904.0
% INFO    : Updated Thermal Rating: on transformer 6300-6299 : Rate B, Rate C - 0.0, 0.0 -> 181.0, 181.0
% INFO    : Updated Thermal Rating: on transformer 6309-6308 : Rate B, Rate C - 0.0, 0.0 -> 122.4, 122.4
% INFO    : Updated Thermal Rating: on line 6310-6312 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6310-6312 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 6320-6312 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6320-6312 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 6316-6315 : Rate B, Rate C - 0.0, 0.0 -> 251.0, 251.0
% INFO    : Updated Thermal Rating: on line 6343-6315 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6317-6316 : Rate B, Rate C - 0.0, 0.0 -> 189.0, 189.0
% INFO    : Updated Thermal Rating: on line 6318-6317 : Rate B, Rate C - 0.0, 0.0 -> 198.0, 198.0
% INFO    : Updated Thermal Rating: on transformer 6319-6318 : Rate B, Rate C - 0.0, 0.0 -> 163.0, 163.0
% INFO    : Updated Thermal Rating: on line 6324-6320 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 6322-6321 : Rate B, Rate C - 0.0, 0.0 -> 249.0, 249.0
% INFO    : Updated Thermal Rating: on line 8140-6326 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 6336-6328 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 6334-6333 : Rate B, Rate C - 0.0, 0.0 -> 1094.0, 1094.0
% INFO    : Updated Thermal Rating: on transformer 6335-6334 : Rate B, Rate C - 0.0, 0.0 -> 271.8, 271.8
% INFO    : Updated Thermal Rating: on line 6341-7202 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 6343-6342 : Rate B, Rate C - 0.0, 0.0 -> 1137.0, 1137.0
% INFO    : Updated Thermal Rating: on transformer 6344-6343 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on transformer 6344-6343 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on line 6343-6350 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6343-6354 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 6344-6353 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 6344-6353 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 6350-6349 : Rate B, Rate C - 0.0, 0.0 -> 1150.0, 1150.0
% INFO    : Updated Thermal Rating: on transformer 6351-6350 : Rate B, Rate C - 0.0, 0.0 -> 155.4, 155.4
% INFO    : Updated Thermal Rating: on transformer 6351-6350 : Rate B, Rate C - 0.0, 0.0 -> 155.4, 155.4
% INFO    : Updated Thermal Rating: on line 6350-6359 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 6355-6354 : Rate B, Rate C - 0.0, 0.0 -> 193.8, 193.8
% INFO    : Updated Thermal Rating: on transformer 6355-6354 : Rate B, Rate C - 0.0, 0.0 -> 193.8, 193.8
% INFO    : Updated Thermal Rating: on transformer 6360-6359 : Rate B, Rate C - 0.0, 0.0 -> 136.0, 136.0
% INFO    : Updated Thermal Rating: on line 7044-7001 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7149-7001 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7001-7337 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7003-7002 : Rate B, Rate C - 0.0, 0.0 -> 1299.0, 1299.0
% INFO    : Updated Thermal Rating: on transformer 7005-7002 : Rate B, Rate C - 0.0, 0.0 -> 630.0, 630.0
% INFO    : Updated Thermal Rating: on transformer 7006-7002 : Rate B, Rate C - 0.0, 0.0 -> 626.0, 626.0
% INFO    : Updated Thermal Rating: on transformer 7007-7002 : Rate B, Rate C - 0.0, 0.0 -> 639.0, 639.0
% INFO    : Updated Thermal Rating: on transformer 7008-7002 : Rate B, Rate C - 0.0, 0.0 -> 629.0, 629.0
% INFO    : Updated Thermal Rating: on transformer 7009-7002 : Rate B, Rate C - 0.0, 0.0 -> 625.0, 625.0
% INFO    : Updated Thermal Rating: on line 7104-7002 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 7002-7227 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 7366-7002 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7004-7003 : Rate B, Rate C - 0.0, 0.0 -> 386.0, 386.0
% INFO    : Updated Thermal Rating: on transformer 7004-7003 : Rate B, Rate C - 0.0, 0.0 -> 386.0, 386.0
% INFO    : Updated Thermal Rating: on transformer 7004-7003 : Rate B, Rate C - 0.0, 0.0 -> 386.0, 386.0
% INFO    : Updated Thermal Rating: on line 7003-7264 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 7075-7004 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7075-7004 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7075-7004 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7004-7106 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7004-7106 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7004-7106 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7004-7106 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7004-7345 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7004-7345 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7004-7345 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7010-7182 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7010-7202 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7233-7010 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7254-7011 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7011-7300 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7012-7116 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7343-7012 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7013-7201 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7013-7201 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7013-7425 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7015-7014 : Rate B, Rate C - 0.0, 0.0 -> 43.0, 43.0
% INFO    : Updated Thermal Rating: on line 7014-7100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7014-7100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7014-7124 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7014-7217 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7016-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7016-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7016-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7016-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7368-7016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7368-7016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7368-7016 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7016-7402 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7016-7402 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7089-7017 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7017-7183 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7017-7229 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7017-7229 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7017-7229 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7017-7241 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7017-7385 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7017-7385 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7019-7018 : Rate B, Rate C - 0.0, 0.0 -> 383.0, 383.0
% INFO    : Updated Thermal Rating: on transformer 7021-7018 : Rate B, Rate C - 0.0, 0.0 -> 311.0, 311.0
% INFO    : Updated Thermal Rating: on transformer 7022-7018 : Rate B, Rate C - 0.0, 0.0 -> 328.0, 328.0
% INFO    : Updated Thermal Rating: on transformer 7023-7018 : Rate B, Rate C - 0.0, 0.0 -> 326.0, 326.0
% INFO    : Updated Thermal Rating: on transformer 7024-7018 : Rate B, Rate C - 0.0, 0.0 -> 456.0, 456.0
% INFO    : Updated Thermal Rating: on transformer 7025-7018 : Rate B, Rate C - 0.0, 0.0 -> 223.0, 223.0
% INFO    : Updated Thermal Rating: on line 7042-7018 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7018-7414 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on transformer 7020-7019 : Rate B, Rate C - 0.0, 0.0 -> 244.0, 244.0
% INFO    : Updated Thermal Rating: on line 7043-7019 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7019-7274 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7026-7072 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7026-7072 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7026-7259 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7273-7026 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7273-7026 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7027-7157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7027-7157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7027-7234 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7027-7245 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7027-7431 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7147-7028 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7147-7028 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7028-7220 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7028-7240 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7028-7330 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7030-7029 : Rate B, Rate C - 0.0, 0.0 -> 126.6, 126.6
% INFO    : Updated Thermal Rating: on transformer 7031-7029 : Rate B, Rate C - 0.0, 0.0 -> 107.0, 107.0
% INFO    : Updated Thermal Rating: on transformer 7032-7029 : Rate B, Rate C - 0.0, 0.0 -> 73.0, 73.0
% INFO    : Updated Thermal Rating: on transformer 7033-7029 : Rate B, Rate C - 0.0, 0.0 -> 84.0, 84.0
% INFO    : Updated Thermal Rating: on transformer 7034-7029 : Rate B, Rate C - 0.0, 0.0 -> 63.0, 63.0
% INFO    : Updated Thermal Rating: on line 7274-7029 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7029-7407 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7415-7029 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 7036-7035 : Rate B, Rate C - 0.0, 0.0 -> 368.0, 368.0
% INFO    : Updated Thermal Rating: on line 7040-7035 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 7056-7035 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7035-7390 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7035-8031 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7036-7128 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7431-7036 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7431-7036 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7038-7037 : Rate B, Rate C - 0.0, 0.0 -> 1055.0, 1055.0
% INFO    : Updated Thermal Rating: on line 7047-7037 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7037-7428 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 7039-7038 : Rate B, Rate C - 0.0, 0.0 -> 420.0, 420.0
% INFO    : Updated Thermal Rating: on transformer 7039-7038 : Rate B, Rate C - 0.0, 0.0 -> 420.0, 420.0
% INFO    : Updated Thermal Rating: on line 7126-7038 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7126-7038 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7038-7184 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 7409-7038 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7409-7038 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7039-7101 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7039-7101 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7039-7101 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7039-7397 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on transformer 7041-7040 : Rate B, Rate C - 0.0, 0.0 -> 337.0, 337.0
% INFO    : Updated Thermal Rating: on transformer 7041-7040 : Rate B, Rate C - 0.0, 0.0 -> 337.0, 337.0
% INFO    : Updated Thermal Rating: on line 7040-7077 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7040-7077 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7041-7238 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7394-7041 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7394-7041 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7043-7042 : Rate B, Rate C - 0.0, 0.0 -> 1048.0, 1048.0
% INFO    : Updated Thermal Rating: on transformer 7045-7042 : Rate B, Rate C - 0.0, 0.0 -> 729.0, 729.0
% INFO    : Updated Thermal Rating: on transformer 7046-7042 : Rate B, Rate C - 0.0, 0.0 -> 716.0, 716.0
% INFO    : Updated Thermal Rating: on line 7058-7042 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on transformer 7044-7043 : Rate B, Rate C - 0.0, 0.0 -> 137.4, 137.4
% INFO    : Updated Thermal Rating: on line 7044-7416 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7048-7047 : Rate B, Rate C - 0.0, 0.0 -> 1125.0, 1125.0
% INFO    : Updated Thermal Rating: on line 7199-7047 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7049-7048 : Rate B, Rate C - 0.0, 0.0 -> 466.0, 466.0
% INFO    : Updated Thermal Rating: on transformer 7049-7048 : Rate B, Rate C - 0.0, 0.0 -> 466.0, 466.0
% INFO    : Updated Thermal Rating: on line 7228-7048 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7342-7048 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7049-7089 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7315-7049 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7315-7049 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7315-7049 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7050-7090 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7050-7090 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7050-7251 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7051-7086 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7051-7181 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7276-7051 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7051-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7051-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7052-7053 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7052-7053 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7052-7053 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7052-7183 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7052-7221 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7256-7052 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7256-7052 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7053-7348 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7053-7348 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7053-7348 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7054-7086 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7243-7054 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7054-7387 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7055-7124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7055-7124 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7188-7055 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7188-7055 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7188-7055 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7188-7055 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7250-7055 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7250-7055 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 7057-7056 : Rate B, Rate C - 0.0, 0.0 -> 377.0, 377.0
% INFO    : Updated Thermal Rating: on line 7056-7156 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7056-7160 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7056-7420 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7215-7057 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7215-7057 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7059-7058 : Rate B, Rate C - 0.0, 0.0 -> 605.0, 605.0
% INFO    : Updated Thermal Rating: on transformer 7061-7058 : Rate B, Rate C - 0.0, 0.0 -> 535.0, 535.0
% INFO    : Updated Thermal Rating: on transformer 7062-7058 : Rate B, Rate C - 0.0, 0.0 -> 531.0, 531.0
% INFO    : Updated Thermal Rating: on transformer 7063-7058 : Rate B, Rate C - 0.0, 0.0 -> 527.0, 527.0
% INFO    : Updated Thermal Rating: on transformer 7064-7058 : Rate B, Rate C - 0.0, 0.0 -> 530.0, 530.0
% INFO    : Updated Thermal Rating: on transformer 7065-7058 : Rate B, Rate C - 0.0, 0.0 -> 520.0, 520.0
% INFO    : Updated Thermal Rating: on transformer 7066-7058 : Rate B, Rate C - 0.0, 0.0 -> 542.0, 542.0
% INFO    : Updated Thermal Rating: on line 7058-7095 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on line 7406-7058 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7060-7059 : Rate B, Rate C - 0.0, 0.0 -> 188.0, 188.0
% INFO    : Updated Thermal Rating: on line 7059-7407 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7129-7060 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7067-7245 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7067-7291 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7067-7344 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7069-7068 : Rate B, Rate C - 0.0, 0.0 -> 145.8, 145.8
% INFO    : Updated Thermal Rating: on line 7305-7068 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7069-7413 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7070-7100 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7070-7257 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7070-7317 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7070-7398 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7123-7071 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7408-7071 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7072-7084 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7072-7084 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7074-7073 : Rate B, Rate C - 0.0, 0.0 -> 185.0, 185.0
% INFO    : Updated Thermal Rating: on line 7171-7073 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7205-7073 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7405-7074 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7075-7387 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7075-7387 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7075-7398 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7075-7398 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7077-7076 : Rate B, Rate C - 0.0, 0.0 -> 1233.0, 1233.0
% INFO    : Updated Thermal Rating: on transformer 7079-7076 : Rate B, Rate C - 0.0, 0.0 -> 855.0, 855.0
% INFO    : Updated Thermal Rating: on transformer 7080-7076 : Rate B, Rate C - 0.0, 0.0 -> 857.0, 857.0
% INFO    : Updated Thermal Rating: on transformer 7081-7076 : Rate B, Rate C - 0.0, 0.0 -> 863.0, 863.0
% INFO    : Updated Thermal Rating: on transformer 7082-7076 : Rate B, Rate C - 0.0, 0.0 -> 847.0, 847.0
% INFO    : Updated Thermal Rating: on line 7204-7076 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7076-7422 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7078-7077 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on line 7077-7282 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 7206-7078 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7078-7279 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7078-7279 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7084-7083 : Rate B, Rate C - 0.0, 0.0 -> 355.0, 355.0
% INFO    : Updated Thermal Rating: on transformer 7084-7083 : Rate B, Rate C - 0.0, 0.0 -> 355.0, 355.0
% INFO    : Updated Thermal Rating: on line 7083-7105 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7083-7171 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7083-7184 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7083-7264 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 7423-7083 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7085-7244 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7085-7244 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7412-7085 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7412-7085 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7086-7222 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7086-7419 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7086-7419 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7127 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7221 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7221 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7221 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7336 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7336 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7336 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7336 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7087-7336 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7088-7116 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7088-7147 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7237-7088 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7089-7388 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7089-7427 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7090-7421 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7090-7421 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7091-7226 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7091-7259 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7091-7259 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7091-7418 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7092-7216 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7092-7250 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7092-7258 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7092-7330 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7092-7384 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7221-7093 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7221-7093 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7093-7225 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7241-7093 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7093-7258 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7094-7276 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7094-7388 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7096-7095 : Rate B, Rate C - 0.0, 0.0 -> 846.0, 846.0
% INFO    : Updated Thermal Rating: on transformer 7098-7095 : Rate B, Rate C - 0.0, 0.0 -> 1600.0, 1600.0
% INFO    : Updated Thermal Rating: on transformer 7099-7095 : Rate B, Rate C - 0.0, 0.0 -> 1600.0, 1600.0
% INFO    : Updated Thermal Rating: on line 7304-7095 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7097-7096 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 7261-7096 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 7097-7153 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7103 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7103 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7222 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7100-7222 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7101-7183 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7101-7386 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7102-7177 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7102-7177 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7290-7102 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7103-7255 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7103-7381 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 7105-7104 : Rate B, Rate C - 0.0, 0.0 -> 1312.0, 1312.0
% INFO    : Updated Thermal Rating: on transformer 7107-7104 : Rate B, Rate C - 0.0, 0.0 -> 592.0, 592.0
% INFO    : Updated Thermal Rating: on transformer 7108-7104 : Rate B, Rate C - 0.0, 0.0 -> 335.0, 335.0
% INFO    : Updated Thermal Rating: on transformer 7109-7104 : Rate B, Rate C - 0.0, 0.0 -> 339.0, 339.0
% INFO    : Updated Thermal Rating: on transformer 7110-7104 : Rate B, Rate C - 0.0, 0.0 -> 731.0, 731.0
% INFO    : Updated Thermal Rating: on transformer 7111-7104 : Rate B, Rate C - 0.0, 0.0 -> 743.0, 743.0
% INFO    : Updated Thermal Rating: on transformer 7112-7104 : Rate B, Rate C - 0.0, 0.0 -> 740.0, 740.0
% INFO    : Updated Thermal Rating: on transformer 7113-7104 : Rate B, Rate C - 0.0, 0.0 -> 748.0, 748.0
% INFO    : Updated Thermal Rating: on transformer 7114-7104 : Rate B, Rate C - 0.0, 0.0 -> 752.0, 752.0
% INFO    : Updated Thermal Rating: on transformer 7115-7104 : Rate B, Rate C - 0.0, 0.0 -> 744.0, 744.0
% INFO    : Updated Thermal Rating: on line 7130-7104 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 7106-7105 : Rate B, Rate C - 0.0, 0.0 -> 354.0, 354.0
% INFO    : Updated Thermal Rating: on transformer 7106-7105 : Rate B, Rate C - 0.0, 0.0 -> 354.0, 354.0
% INFO    : Updated Thermal Rating: on line 7105-7187 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7105-7205 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7105-7332 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7116-7340 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7116-7364 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7242-7117 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7242-7117 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7117-7292 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7117-7292 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7117-7395 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7117-7395 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7177-7118 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7177-7118 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7118-7404 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7144-7119 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7144-7119 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7119-7259 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7119-7318 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 7121-7120 : Rate B, Rate C - 0.0, 0.0 -> 41.0, 41.0
% INFO    : Updated Thermal Rating: on transformer 7122-7120 : Rate B, Rate C - 0.0, 0.0 -> 46.0, 46.0
% INFO    : Updated Thermal Rating: on line 7120-7248 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7120-7396 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7120-7396 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7427-7120 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7427-7120 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7123-7153 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7124-7180 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7126-7125 : Rate B, Rate C - 0.0, 0.0 -> 1358.0, 1358.0
% INFO    : Updated Thermal Rating: on transformer 7126-7125 : Rate B, Rate C - 0.0, 0.0 -> 1358.0, 1358.0
% INFO    : Updated Thermal Rating: on line 7125-7331 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7346-7125 : Rate B, Rate C - 0.0, 0.0 -> 4352.0, 4352.0
% INFO    : Updated Thermal Rating: on transformer 7127-7126 : Rate B, Rate C - 0.0, 0.0 -> 512.3, 512.3
% INFO    : Updated Thermal Rating: on transformer 7127-7126 : Rate B, Rate C - 0.0, 0.0 -> 512.3, 512.3
% INFO    : Updated Thermal Rating: on transformer 7127-7126 : Rate B, Rate C - 0.0, 0.0 -> 512.3, 512.3
% INFO    : Updated Thermal Rating: on transformer 7127-7126 : Rate B, Rate C - 0.0, 0.0 -> 512.3, 512.3
% INFO    : Updated Thermal Rating: on line 7126-7305 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7126-7332 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7126-7423 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7391-7128 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7277-7129 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7303-7129 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7131-7130 : Rate B, Rate C - 0.0, 0.0 -> 1373.0, 1373.0
% INFO    : Updated Thermal Rating: on transformer 7133-7130 : Rate B, Rate C - 0.0, 0.0 -> 295.0, 295.0
% INFO    : Updated Thermal Rating: on transformer 7134-7130 : Rate B, Rate C - 0.0, 0.0 -> 776.0, 776.0
% INFO    : Updated Thermal Rating: on transformer 7135-7130 : Rate B, Rate C - 0.0, 0.0 -> 767.0, 767.0
% INFO    : Updated Thermal Rating: on transformer 7136-7130 : Rate B, Rate C - 0.0, 0.0 -> 768.0, 768.0
% INFO    : Updated Thermal Rating: on transformer 7137-7130 : Rate B, Rate C - 0.0, 0.0 -> 781.0, 781.0
% INFO    : Updated Thermal Rating: on transformer 7138-7130 : Rate B, Rate C - 0.0, 0.0 -> 1053.0, 1053.0
% INFO    : Updated Thermal Rating: on transformer 7139-7130 : Rate B, Rate C - 0.0, 0.0 -> 357.0, 357.0
% INFO    : Updated Thermal Rating: on transformer 7140-7130 : Rate B, Rate C - 0.0, 0.0 -> 360.0, 360.0
% INFO    : Updated Thermal Rating: on transformer 7141-7130 : Rate B, Rate C - 0.0, 0.0 -> 368.0, 368.0
% INFO    : Updated Thermal Rating: on transformer 7142-7130 : Rate B, Rate C - 0.0, 0.0 -> 363.0, 363.0
% INFO    : Updated Thermal Rating: on line 7263-7130 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7132-7131 : Rate B, Rate C - 0.0, 0.0 -> 446.0, 446.0
% INFO    : Updated Thermal Rating: on transformer 7132-7131 : Rate B, Rate C - 0.0, 0.0 -> 446.0, 446.0
% INFO    : Updated Thermal Rating: on line 7131-7160 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7131-7278 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7131-7401 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7132-7283 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7419-7132 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7419-7132 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7419-7132 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7143-7173 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7234-7143 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7143-7238 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7300-7143 : Rate B, Rate C - 0.0, 0.0 -> 245.0, 245.0
% INFO    : Updated Thermal Rating: on line 7144-7272 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7144-7272 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7333-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7333-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7333-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7333-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7333-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7333-7144 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7146-7145 : Rate B, Rate C - 0.0, 0.0 -> 25.0, 25.0
% INFO    : Updated Thermal Rating: on line 7145-7234 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7145-7243 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7381-7145 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7145-7404 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7336-7147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7336-7147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7336-7147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7336-7147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7386-7147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7386-7147 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7178-7148 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7178-7148 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7148-7245 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7148-7298 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7148-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7148-7365 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7149-7408 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7151-7150 : Rate B, Rate C - 0.0, 0.0 -> 151.8, 151.8
% INFO    : Updated Thermal Rating: on line 7150-7390 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7150-7390 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7150-7420 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 8004-7150 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 7151-7254 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7330-7152 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7330-7152 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7152-7399 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7152-7399 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7154-7157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7154-7157 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7300-7154 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7154-7411 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7155-7258 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7155-7316 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 7157-7156 : Rate B, Rate C - 0.0, 0.0 -> 424.0, 424.0
% INFO    : Updated Thermal Rating: on transformer 7157-7156 : Rate B, Rate C - 0.0, 0.0 -> 424.0, 424.0
% INFO    : Updated Thermal Rating: on transformer 7157-7156 : Rate B, Rate C - 0.0, 0.0 -> 424.0, 424.0
% INFO    : Updated Thermal Rating: on line 7176-7156 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7156-7367 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7156-7367 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7157-7295 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7157-7295 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7173-7158 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7158-7291 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7158-7394 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7158-7394 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7160-7159 : Rate B, Rate C - 0.0, 0.0 -> 1310.0, 1310.0
% INFO    : Updated Thermal Rating: on transformer 7162-7159 : Rate B, Rate C - 0.0, 0.0 -> 491.0, 491.0
% INFO    : Updated Thermal Rating: on transformer 7163-7159 : Rate B, Rate C - 0.0, 0.0 -> 498.0, 498.0
% INFO    : Updated Thermal Rating: on transformer 7164-7159 : Rate B, Rate C - 0.0, 0.0 -> 498.0, 498.0
% INFO    : Updated Thermal Rating: on transformer 7165-7159 : Rate B, Rate C - 0.0, 0.0 -> 512.0, 512.0
% INFO    : Updated Thermal Rating: on transformer 7166-7159 : Rate B, Rate C - 0.0, 0.0 -> 507.0, 507.0
% INFO    : Updated Thermal Rating: on transformer 7167-7159 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on transformer 7168-7159 : Rate B, Rate C - 0.0, 0.0 -> 418.0, 418.0
% INFO    : Updated Thermal Rating: on transformer 7169-7159 : Rate B, Rate C - 0.0, 0.0 -> 416.0, 416.0
% INFO    : Updated Thermal Rating: on transformer 7170-7159 : Rate B, Rate C - 0.0, 0.0 -> 1042.0, 1042.0
% INFO    : Updated Thermal Rating: on line 7159-7175 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on line 7199-7159 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7159-7227 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on transformer 7161-7160 : Rate B, Rate C - 0.0, 0.0 -> 418.0, 418.0
% INFO    : Updated Thermal Rating: on transformer 7161-7160 : Rate B, Rate C - 0.0, 0.0 -> 418.0, 418.0
% INFO    : Updated Thermal Rating: on transformer 7161-7160 : Rate B, Rate C - 0.0, 0.0 -> 418.0, 418.0
% INFO    : Updated Thermal Rating: on line 7187-7160 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7161-7292 : Rate B, Rate C - 0.0, 0.0 -> 221.1, 221.1
% INFO    : Updated Thermal Rating: on line 7161-7292 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7161-7292 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7161-7292 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 7172-7171 : Rate B, Rate C - 0.0, 0.0 -> 352.0, 352.0
% INFO    : Updated Thermal Rating: on line 7171-7252 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7232-7172 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7232-7172 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7173-7387 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7174-7231 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7174-7231 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7174-7257 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7301-7174 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7176-7175 : Rate B, Rate C - 0.0, 0.0 -> 1292.0, 1292.0
% INFO    : Updated Thermal Rating: on transformer 7176-7175 : Rate B, Rate C - 0.0, 0.0 -> 1292.0, 1292.0
% INFO    : Updated Thermal Rating: on line 7175-7389 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7177-7176 : Rate B, Rate C - 0.0, 0.0 -> 439.0, 439.0
% INFO    : Updated Thermal Rating: on transformer 7177-7176 : Rate B, Rate C - 0.0, 0.0 -> 439.0, 439.0
% INFO    : Updated Thermal Rating: on transformer 7177-7176 : Rate B, Rate C - 0.0, 0.0 -> 439.0, 439.0
% INFO    : Updated Thermal Rating: on line 7176-7200 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7176-7409 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7319-7177 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7319-7177 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7295-7178 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7178-7404 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7179-7244 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7179-7257 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7179-7336 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7216-7180 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7180-7298 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7180-7298 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7388-7180 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7388-7180 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7180-7399 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7180-7399 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7242-7181 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7385-7181 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7182-7237 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7183-7417 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 7185-7184 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 7185-7184 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on transformer 7185-7184 : Rate B, Rate C - 0.0, 0.0 -> 200.0, 200.0
% INFO    : Updated Thermal Rating: on line 7347-7184 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7347-7184 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7347-7184 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7383-7185 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7383-7185 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7187-7186 : Rate B, Rate C - 0.0, 0.0 -> 1600.0, 1600.0
% INFO    : Updated Thermal Rating: on transformer 7187-7186 : Rate B, Rate C - 0.0, 0.0 -> 1600.0, 1600.0
% INFO    : Updated Thermal Rating: on transformer 7189-7186 : Rate B, Rate C - 0.0, 0.0 -> 264.0, 264.0
% INFO    : Updated Thermal Rating: on transformer 7190-7186 : Rate B, Rate C - 0.0, 0.0 -> 337.0, 337.0
% INFO    : Updated Thermal Rating: on transformer 7191-7186 : Rate B, Rate C - 0.0, 0.0 -> 258.0, 258.0
% INFO    : Updated Thermal Rating: on transformer 7192-7186 : Rate B, Rate C - 0.0, 0.0 -> 312.0, 312.0
% INFO    : Updated Thermal Rating: on transformer 7193-7186 : Rate B, Rate C - 0.0, 0.0 -> 256.0, 256.0
% INFO    : Updated Thermal Rating: on transformer 7194-7186 : Rate B, Rate C - 0.0, 0.0 -> 861.0, 861.0
% INFO    : Updated Thermal Rating: on transformer 7195-7186 : Rate B, Rate C - 0.0, 0.0 -> 863.0, 863.0
% INFO    : Updated Thermal Rating: on transformer 7196-7186 : Rate B, Rate C - 0.0, 0.0 -> 866.0, 866.0
% INFO    : Updated Thermal Rating: on transformer 7197-7186 : Rate B, Rate C - 0.0, 0.0 -> 867.0, 867.0
% INFO    : Updated Thermal Rating: on line 7186-7341 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on line 7346-7186 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 7188-7187 : Rate B, Rate C - 0.0, 0.0 -> 600.0, 600.0
% INFO    : Updated Thermal Rating: on transformer 7188-7187 : Rate B, Rate C - 0.0, 0.0 -> 600.0, 600.0
% INFO    : Updated Thermal Rating: on transformer 7188-7187 : Rate B, Rate C - 0.0, 0.0 -> 600.0, 600.0
% INFO    : Updated Thermal Rating: on transformer 7188-7187 : Rate B, Rate C - 0.0, 0.0 -> 600.0, 600.0
% INFO    : Updated Thermal Rating: on line 7187-7401 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7188-7255 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 7198-7201 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7198-7201 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7198-7225 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7200-7199 : Rate B, Rate C - 0.0, 0.0 -> 1344.0, 1344.0
% INFO    : Updated Thermal Rating: on line 7199-7331 : Rate B, Rate C - 0.0, 0.0 -> 3146.0, 3146.0
% INFO    : Updated Thermal Rating: on transformer 7201-7200 : Rate B, Rate C - 0.0, 0.0 -> 213.6, 213.6
% INFO    : Updated Thermal Rating: on transformer 7201-7200 : Rate B, Rate C - 0.0, 0.0 -> 213.6, 213.6
% INFO    : Updated Thermal Rating: on transformer 7201-7200 : Rate B, Rate C - 0.0, 0.0 -> 213.6, 213.6
% INFO    : Updated Thermal Rating: on line 7420-7200 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7203-7247 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7203-7313 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 7393-7203 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7426-7203 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7205-7204 : Rate B, Rate C - 0.0, 0.0 -> 1324.0, 1324.0
% INFO    : Updated Thermal Rating: on transformer 7207-7204 : Rate B, Rate C - 0.0, 0.0 -> 243.0, 243.0
% INFO    : Updated Thermal Rating: on transformer 7208-7204 : Rate B, Rate C - 0.0, 0.0 -> 1265.0, 1265.0
% INFO    : Updated Thermal Rating: on transformer 7209-7204 : Rate B, Rate C - 0.0, 0.0 -> 1260.0, 1260.0
% INFO    : Updated Thermal Rating: on transformer 7210-7204 : Rate B, Rate C - 0.0, 0.0 -> 664.0, 664.0
% INFO    : Updated Thermal Rating: on transformer 7211-7204 : Rate B, Rate C - 0.0, 0.0 -> 656.0, 656.0
% INFO    : Updated Thermal Rating: on transformer 7212-7204 : Rate B, Rate C - 0.0, 0.0 -> 669.0, 669.0
% INFO    : Updated Thermal Rating: on line 7263-7204 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on line 7204-7428 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7206-7205 : Rate B, Rate C - 0.0, 0.0 -> 181.0, 181.0
% INFO    : Updated Thermal Rating: on line 7282-7205 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7206-7294 : Rate B, Rate C - 0.0, 0.0 -> 100.0, 100.0
% INFO    : Updated Thermal Rating: on line 7213-7273 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7293-7213 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7213-7363 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7214-7257 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7214-7297 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7345-7214 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7345-7214 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7411-7215 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7215-7431 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7216-7382 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7216-7386 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7249-7217 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7217-7276 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 7421-7218 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7218-8009 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7230-7219 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7219-7237 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7413-7219 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7413-7219 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7221-7220 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7221-7220 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7220-7396 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7221-7296 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7222-7338 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7222-7362 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7292-7223 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7292-7223 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7223-7404 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7223-7425 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7224-7248 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7384-7224 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7224-7417 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7246-7225 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7225-7395 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7226-7240 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7226-7250 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7226-7272 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7226-7338 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7228-7227 : Rate B, Rate C - 0.0, 0.0 -> 1259.0, 1259.0
% INFO    : Updated Thermal Rating: on line 7227-7422 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 7229-7228 : Rate B, Rate C - 0.0, 0.0 -> 467.0, 467.0
% INFO    : Updated Thermal Rating: on transformer 7229-7228 : Rate B, Rate C - 0.0, 0.0 -> 467.0, 467.0
% INFO    : Updated Thermal Rating: on transformer 7229-7228 : Rate B, Rate C - 0.0, 0.0 -> 467.0, 467.0
% INFO    : Updated Thermal Rating: on line 7409-7228 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7397-7230 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7265-7231 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7265-7231 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7265-7231 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7265-7231 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7231-7403 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7231-7403 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7273-7232 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7233-7251 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7251-7235 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7235-7315 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7235-7315 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7236-7245 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7236-7292 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7236-7411 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7237-7247 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7238-7392 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7294-7239 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7239-7392 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7241-7362 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7242-7295 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7242-7319 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7242-7319 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7260-7243 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7260-7243 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7244-7272 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7246-7251 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7246-7410 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7246-7410 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7425-7246 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7339-7247 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7362-7248 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7248-7386 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7248-7386 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7249-7255 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7249-7255 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7249-7344 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7249-7344 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7249-7382 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7250-7276 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7250-7276 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7253-7252 : Rate B, Rate C - 0.0, 0.0 -> 198.0, 198.0
% INFO    : Updated Thermal Rating: on line 7312-7252 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 7327-7252 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7347-7252 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7313-7253 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7253-7412 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7253-7412 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7255-7258 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7255-7258 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7255-7399 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7255-7399 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7255-7399 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7255-7399 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 7256-7297 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7257-7317 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7257-7317 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7259-7403 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7259-7403 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7368-7260 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7368-7260 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7368-7260 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7262-7261 : Rate B, Rate C - 0.0, 0.0 -> 305.0, 305.0
% INFO    : Updated Thermal Rating: on line 7261-7429 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7262-7302 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 7264-7263 : Rate B, Rate C - 0.0, 0.0 -> 1362.0, 1362.0
% INFO    : Updated Thermal Rating: on transformer 7264-7263 : Rate B, Rate C - 0.0, 0.0 -> 1362.0, 1362.0
% INFO    : Updated Thermal Rating: on transformer 7266-7263 : Rate B, Rate C - 0.0, 0.0 -> 983.0, 983.0
% INFO    : Updated Thermal Rating: on transformer 7267-7263 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on transformer 7268-7263 : Rate B, Rate C - 0.0, 0.0 -> 438.0, 438.0
% INFO    : Updated Thermal Rating: on transformer 7269-7263 : Rate B, Rate C - 0.0, 0.0 -> 440.0, 440.0
% INFO    : Updated Thermal Rating: on transformer 7270-7263 : Rate B, Rate C - 0.0, 0.0 -> 701.0, 701.0
% INFO    : Updated Thermal Rating: on transformer 7265-7264 : Rate B, Rate C - 0.0, 0.0 -> 461.0, 461.0
% INFO    : Updated Thermal Rating: on transformer 7265-7264 : Rate B, Rate C - 0.0, 0.0 -> 461.0, 461.0
% INFO    : Updated Thermal Rating: on line 7264-7332 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 7315-7271 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7271-7340 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7316-7272 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7273-7405 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7275-7274 : Rate B, Rate C - 0.0, 0.0 -> 143.0, 143.0
% INFO    : Updated Thermal Rating: on line 7276-7395 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7277-7337 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7279-7278 : Rate B, Rate C - 0.0, 0.0 -> 172.0, 172.0
% INFO    : Updated Thermal Rating: on transformer 7280-7278 : Rate B, Rate C - 0.0, 0.0 -> 87.0, 87.0
% INFO    : Updated Thermal Rating: on transformer 7281-7278 : Rate B, Rate C - 0.0, 0.0 -> 91.0, 91.0
% INFO    : Updated Thermal Rating: on line 7367-7278 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7392-7279 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7283-7282 : Rate B, Rate C - 0.0, 0.0 -> 145.0, 145.0
% INFO    : Updated Thermal Rating: on transformer 7284-7282 : Rate B, Rate C - 0.0, 0.0 -> 70.0, 70.0
% INFO    : Updated Thermal Rating: on transformer 7285-7282 : Rate B, Rate C - 0.0, 0.0 -> 93.0, 93.0
% INFO    : Updated Thermal Rating: on transformer 7286-7282 : Rate B, Rate C - 0.0, 0.0 -> 93.0, 93.0
% INFO    : Updated Thermal Rating: on transformer 7287-7282 : Rate B, Rate C - 0.0, 0.0 -> 91.0, 91.0
% INFO    : Updated Thermal Rating: on transformer 7288-7282 : Rate B, Rate C - 0.0, 0.0 -> 93.0, 93.0
% INFO    : Updated Thermal Rating: on transformer 7289-7282 : Rate B, Rate C - 0.0, 0.0 -> 124.0, 124.0
% INFO    : Updated Thermal Rating: on line 7282-7332 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7282-7367 : Rate B, Rate C - 0.0, 0.0 -> 523.0, 523.0
% INFO    : Updated Thermal Rating: on line 7411-7290 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7291-7295 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7424-7293 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7294-7405 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7296-7427 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7316-7297 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7297-7384 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7298-7362 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7298-7395 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7364-7299 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7413-7299 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7301-7318 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7302-7426 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7303-7393 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7305-7304 : Rate B, Rate C - 0.0, 0.0 -> 1160.0, 1160.0
% INFO    : Updated Thermal Rating: on transformer 7307-7304 : Rate B, Rate C - 0.0, 0.0 -> 473.0, 473.0
% INFO    : Updated Thermal Rating: on transformer 7308-7304 : Rate B, Rate C - 0.0, 0.0 -> 459.0, 459.0
% INFO    : Updated Thermal Rating: on transformer 7309-7304 : Rate B, Rate C - 0.0, 0.0 -> 454.0, 454.0
% INFO    : Updated Thermal Rating: on transformer 7310-7304 : Rate B, Rate C - 0.0, 0.0 -> 464.0, 464.0
% INFO    : Updated Thermal Rating: on transformer 7311-7304 : Rate B, Rate C - 0.0, 0.0 -> 729.0, 729.0
% INFO    : Updated Thermal Rating: on line 7341-7304 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7306-7305 : Rate B, Rate C - 0.0, 0.0 -> 305.0, 305.0
% INFO    : Updated Thermal Rating: on line 7305-7327 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 7306-7413 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7306-7413 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7313-7312 : Rate B, Rate C - 0.0, 0.0 -> 168.0, 168.0
% INFO    : Updated Thermal Rating: on line 7312-7321 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7312-7429 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7313-7430 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7340-7314 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7316-7383 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7316-7383 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7317-7424 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7317-7424 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7317-7424 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7317-7424 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7318-7382 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 7321-7320 : Rate B, Rate C - 0.0, 0.0 -> 1000.0, 1000.0
% INFO    : Updated Thermal Rating: on transformer 7323-7320 : Rate B, Rate C - 0.0, 0.0 -> 584.0, 584.0
% INFO    : Updated Thermal Rating: on transformer 7324-7320 : Rate B, Rate C - 0.0, 0.0 -> 577.0, 577.0
% INFO    : Updated Thermal Rating: on transformer 7325-7320 : Rate B, Rate C - 0.0, 0.0 -> 581.0, 581.0
% INFO    : Updated Thermal Rating: on transformer 7326-7320 : Rate B, Rate C - 0.0, 0.0 -> 568.0, 568.0
% INFO    : Updated Thermal Rating: on line 7320-7422 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7322-7321 : Rate B, Rate C - 0.0, 0.0 -> 128.4, 128.4
% INFO    : Updated Thermal Rating: on line 7322-7380 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 7328-7327 : Rate B, Rate C - 0.0, 0.0 -> 172.0, 172.0
% INFO    : Updated Thermal Rating: on transformer 7329-7327 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 7328-7339 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7362-7330 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7332-7331 : Rate B, Rate C - 0.0, 0.0 -> 1122.0, 1122.0
% INFO    : Updated Thermal Rating: on transformer 7334-7331 : Rate B, Rate C - 0.0, 0.0 -> 244.0, 244.0
% INFO    : Updated Thermal Rating: on transformer 7335-7331 : Rate B, Rate C - 0.0, 0.0 -> 1106.0, 1106.0
% INFO    : Updated Thermal Rating: on line 7400-7331 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 7333-7332 : Rate B, Rate C - 0.0, 0.0 -> 280.8, 280.8
% INFO    : Updated Thermal Rating: on transformer 7333-7332 : Rate B, Rate C - 0.0, 0.0 -> 280.8, 280.8
% INFO    : Updated Thermal Rating: on transformer 7333-7332 : Rate B, Rate C - 0.0, 0.0 -> 280.8, 280.8
% INFO    : Updated Thermal Rating: on line 7401-7332 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7336-7418 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7336-7418 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7345-7338 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7345-7338 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7342-7341 : Rate B, Rate C - 0.0, 0.0 -> 1311.0, 1311.0
% INFO    : Updated Thermal Rating: on transformer 7343-7342 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on transformer 7343-7342 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 7342-7409 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7342-7409 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 7344-7404 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7345-7382 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7345-7382 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7347-7346 : Rate B, Rate C - 0.0, 0.0 -> 1271.0, 1271.0
% INFO    : Updated Thermal Rating: on transformer 7347-7346 : Rate B, Rate C - 0.0, 0.0 -> 1271.0, 1271.0
% INFO    : Updated Thermal Rating: on transformer 7349-7346 : Rate B, Rate C - 0.0, 0.0 -> 1019.0, 1019.0
% INFO    : Updated Thermal Rating: on transformer 7350-7346 : Rate B, Rate C - 0.0, 0.0 -> 1021.0, 1021.0
% INFO    : Updated Thermal Rating: on transformer 7351-7346 : Rate B, Rate C - 0.0, 0.0 -> 1018.0, 1018.0
% INFO    : Updated Thermal Rating: on transformer 7352-7346 : Rate B, Rate C - 0.0, 0.0 -> 1025.0, 1025.0
% INFO    : Updated Thermal Rating: on transformer 7353-7346 : Rate B, Rate C - 0.0, 0.0 -> 1225.0, 1225.0
% INFO    : Updated Thermal Rating: on transformer 7354-7346 : Rate B, Rate C - 0.0, 0.0 -> 1222.0, 1222.0
% INFO    : Updated Thermal Rating: on transformer 7355-7346 : Rate B, Rate C - 0.0, 0.0 -> 1218.0, 1218.0
% INFO    : Updated Thermal Rating: on transformer 7356-7346 : Rate B, Rate C - 0.0, 0.0 -> 1219.0, 1219.0
% INFO    : Updated Thermal Rating: on transformer 7357-7346 : Rate B, Rate C - 0.0, 0.0 -> 287.0, 287.0
% INFO    : Updated Thermal Rating: on transformer 7358-7346 : Rate B, Rate C - 0.0, 0.0 -> 835.0, 835.0
% INFO    : Updated Thermal Rating: on transformer 7359-7346 : Rate B, Rate C - 0.0, 0.0 -> 846.0, 846.0
% INFO    : Updated Thermal Rating: on transformer 7360-7346 : Rate B, Rate C - 0.0, 0.0 -> 845.0, 845.0
% INFO    : Updated Thermal Rating: on transformer 7361-7346 : Rate B, Rate C - 0.0, 0.0 -> 471.0, 471.0
% INFO    : Updated Thermal Rating: on transformer 7348-7347 : Rate B, Rate C - 0.0, 0.0 -> 407.0, 407.0
% INFO    : Updated Thermal Rating: on transformer 7348-7347 : Rate B, Rate C - 0.0, 0.0 -> 407.0, 407.0
% INFO    : Updated Thermal Rating: on line 7380-7363 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7365-7381 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on transformer 7367-7366 : Rate B, Rate C - 0.0, 0.0 -> 1249.0, 1249.0
% INFO    : Updated Thermal Rating: on transformer 7367-7366 : Rate B, Rate C - 0.0, 0.0 -> 1249.0, 1249.0
% INFO    : Updated Thermal Rating: on transformer 7369-7366 : Rate B, Rate C - 0.0, 0.0 -> 494.0, 494.0
% INFO    : Updated Thermal Rating: on transformer 7370-7366 : Rate B, Rate C - 0.0, 0.0 -> 480.0, 480.0
% INFO    : Updated Thermal Rating: on transformer 7371-7366 : Rate B, Rate C - 0.0, 0.0 -> 469.0, 469.0
% INFO    : Updated Thermal Rating: on transformer 7372-7366 : Rate B, Rate C - 0.0, 0.0 -> 485.0, 485.0
% INFO    : Updated Thermal Rating: on transformer 7373-7366 : Rate B, Rate C - 0.0, 0.0 -> 491.0, 491.0
% INFO    : Updated Thermal Rating: on transformer 7374-7366 : Rate B, Rate C - 0.0, 0.0 -> 487.0, 487.0
% INFO    : Updated Thermal Rating: on transformer 7375-7366 : Rate B, Rate C - 0.0, 0.0 -> 712.0, 712.0
% INFO    : Updated Thermal Rating: on transformer 7376-7366 : Rate B, Rate C - 0.0, 0.0 -> 713.0, 713.0
% INFO    : Updated Thermal Rating: on transformer 7377-7366 : Rate B, Rate C - 0.0, 0.0 -> 705.0, 705.0
% INFO    : Updated Thermal Rating: on transformer 7378-7366 : Rate B, Rate C - 0.0, 0.0 -> 694.0, 694.0
% INFO    : Updated Thermal Rating: on transformer 7379-7366 : Rate B, Rate C - 0.0, 0.0 -> 700.0, 700.0
% INFO    : Updated Thermal Rating: on line 7366-7400 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on transformer 7368-7367 : Rate B, Rate C - 0.0, 0.0 -> 392.0, 392.0
% INFO    : Updated Thermal Rating: on transformer 7368-7367 : Rate B, Rate C - 0.0, 0.0 -> 392.0, 392.0
% INFO    : Updated Thermal Rating: on transformer 7368-7367 : Rate B, Rate C - 0.0, 0.0 -> 392.0, 392.0
% INFO    : Updated Thermal Rating: on line 7385-7404 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 7390-7389 : Rate B, Rate C - 0.0, 0.0 -> 1278.0, 1278.0
% INFO    : Updated Thermal Rating: on line 8030-7389 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 7391-7390 : Rate B, Rate C - 0.0, 0.0 -> 127.2, 127.2
% INFO    : Updated Thermal Rating: on line 7396-7410 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7396-7410 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7396-7410 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7403-7398 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7403-7398 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7399-7417 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7399-7417 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7401-7400 : Rate B, Rate C - 0.0, 0.0 -> 1297.0, 1297.0
% INFO    : Updated Thermal Rating: on transformer 7402-7401 : Rate B, Rate C - 0.0, 0.0 -> 423.0, 423.0
% INFO    : Updated Thermal Rating: on line 7401-7409 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 7403-7419 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7403-7419 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7407-7406 : Rate B, Rate C - 0.0, 0.0 -> 1026.0, 1026.0
% INFO    : Updated Thermal Rating: on line 7414-7406 : Rate B, Rate C - 0.0, 0.0 -> 2295.0, 2295.0
% INFO    : Updated Thermal Rating: on transformer 7408-7407 : Rate B, Rate C - 0.0, 0.0 -> 143.8, 143.8
% INFO    : Updated Thermal Rating: on transformer 7410-7409 : Rate B, Rate C - 0.0, 0.0 -> 248.4, 248.4
% INFO    : Updated Thermal Rating: on transformer 7410-7409 : Rate B, Rate C - 0.0, 0.0 -> 248.4, 248.4
% INFO    : Updated Thermal Rating: on transformer 7410-7409 : Rate B, Rate C - 0.0, 0.0 -> 248.4, 248.4
% INFO    : Updated Thermal Rating: on line 7409-7420 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on transformer 7415-7414 : Rate B, Rate C - 0.0, 0.0 -> 239.0, 239.0
% INFO    : Updated Thermal Rating: on transformer 7416-7415 : Rate B, Rate C - 0.0, 0.0 -> 109.0, 109.0
% INFO    : Updated Thermal Rating: on line 7417-7418 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 7417-7418 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 7421-7420 : Rate B, Rate C - 0.0, 0.0 -> 161.4, 161.4
% INFO    : Updated Thermal Rating: on transformer 7421-7420 : Rate B, Rate C - 0.0, 0.0 -> 161.4, 161.4
% INFO    : Updated Thermal Rating: on transformer 7423-7422 : Rate B, Rate C - 0.0, 0.0 -> 1350.0, 1350.0
% INFO    : Updated Thermal Rating: on transformer 7424-7423 : Rate B, Rate C - 0.0, 0.0 -> 213.0, 213.0
% INFO    : Updated Thermal Rating: on transformer 7424-7423 : Rate B, Rate C - 0.0, 0.0 -> 213.0, 213.0
% INFO    : Updated Thermal Rating: on transformer 7424-7423 : Rate B, Rate C - 0.0, 0.0 -> 213.0, 213.0
% INFO    : Updated Thermal Rating: on transformer 7429-7428 : Rate B, Rate C - 0.0, 0.0 -> 927.0, 927.0
% INFO    : Updated Thermal Rating: on transformer 7430-7429 : Rate B, Rate C - 0.0, 0.0 -> 133.8, 133.8
% INFO    : Updated Thermal Rating: on line 7432-8003 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 7432-8037 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 7432-8141 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8003-8001 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8010-8001 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8028-8002 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8002-8100 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8005-8004 : Rate B, Rate C - 0.0, 0.0 -> 459.0, 459.0
% INFO    : Updated Thermal Rating: on transformer 8005-8004 : Rate B, Rate C - 0.0, 0.0 -> 459.0, 459.0
% INFO    : Updated Thermal Rating: on line 8097-8004 : Rate B, Rate C - 0.0, 0.0 -> 443.0, 443.0
% INFO    : Updated Thermal Rating: on line 8005-8023 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8005-8023 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8137-8005 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8006-8007 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8006-8134 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 8007-8017 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8008-8053 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8081-8008 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8009-8104 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8086-8010 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8010-8103 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8045-8011 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8045-8011 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8072-8011 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8012-8032 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8104-8012 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8026-8013 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8013-8039 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8013-8136 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8014-8037 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8118-8014 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8111-8015 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8015-8150 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8016-8122 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8016-8152 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8017-8040 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8019-8018 : Rate B, Rate C - 0.0, 0.0 -> 360.0, 360.0
% INFO    : Updated Thermal Rating: on transformer 8019-8018 : Rate B, Rate C - 0.0, 0.0 -> 360.0, 360.0
% INFO    : Updated Thermal Rating: on line 8127-8018 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 8018-8133 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8019-8052 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8019-8100 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 8019-8135 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8019-8135 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8020-8029 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8020-8040 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8020-8153 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8020-8154 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8022-8021 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8021-8041 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8021-8119 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8022-8150 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8024-8023 : Rate B, Rate C - 0.0, 0.0 -> 47.0, 47.0
% INFO    : Updated Thermal Rating: on line 8023-8111 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8023-8111 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8025-8055 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8025-8121 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8025-8151 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8026-8154 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8100-8027 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8027-8134 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8146-8028 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8073-8029 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 8031-8030 : Rate B, Rate C - 0.0, 0.0 -> 1036.0, 1036.0
% INFO    : Updated Thermal Rating: on transformer 8033-8030 : Rate B, Rate C - 0.0, 0.0 -> 826.0, 826.0
% INFO    : Updated Thermal Rating: on transformer 8034-8030 : Rate B, Rate C - 0.0, 0.0 -> 818.0, 818.0
% INFO    : Updated Thermal Rating: on transformer 8035-8030 : Rate B, Rate C - 0.0, 0.0 -> 830.0, 830.0
% INFO    : Updated Thermal Rating: on transformer 8036-8030 : Rate B, Rate C - 0.0, 0.0 -> 820.0, 820.0
% INFO    : Updated Thermal Rating: on line 8158-8030 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 8032-8031 : Rate B, Rate C - 0.0, 0.0 -> 400.0, 400.0
% INFO    : Updated Thermal Rating: on line 8143-8032 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 8038-8066 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8038-8124 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8039-8081 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8040-8072 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8109-8040 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8041-8063 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8111-8042 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8118-8042 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8044-8043 : Rate B, Rate C - 0.0, 0.0 -> 1072.0, 1072.0
% INFO    : Updated Thermal Rating: on transformer 8046-8043 : Rate B, Rate C - 0.0, 0.0 -> 606.0, 606.0
% INFO    : Updated Thermal Rating: on transformer 8047-8043 : Rate B, Rate C - 0.0, 0.0 -> 613.0, 613.0
% INFO    : Updated Thermal Rating: on transformer 8048-8043 : Rate B, Rate C - 0.0, 0.0 -> 598.0, 598.0
% INFO    : Updated Thermal Rating: on transformer 8049-8043 : Rate B, Rate C - 0.0, 0.0 -> 608.0, 608.0
% INFO    : Updated Thermal Rating: on transformer 8050-8043 : Rate B, Rate C - 0.0, 0.0 -> 618.0, 618.0
% INFO    : Updated Thermal Rating: on transformer 8051-8043 : Rate B, Rate C - 0.0, 0.0 -> 608.0, 608.0
% INFO    : Updated Thermal Rating: on line 8043-8067 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 8045-8044 : Rate B, Rate C - 0.0, 0.0 -> 388.0, 388.0
% INFO    : Updated Thermal Rating: on line 8147-8044 : Rate B, Rate C - 0.0, 0.0 -> 647.0, 647.0
% INFO    : Updated Thermal Rating: on line 8045-8091 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8045-8144 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8081-8052 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8053-8065 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8053-8153 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8054-8092 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8132-8054 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8055-8098 : Rate B, Rate C - 0.0, 0.0 -> 220.0, 220.0
% INFO    : Updated Thermal Rating: on line 8121-8055 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8056-8089 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8056-8138 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8058-8057 : Rate B, Rate C - 0.0, 0.0 -> 491.0, 491.0
% INFO    : Updated Thermal Rating: on transformer 8060-8057 : Rate B, Rate C - 0.0, 0.0 -> 1157.0, 1157.0
% INFO    : Updated Thermal Rating: on transformer 8061-8057 : Rate B, Rate C - 0.0, 0.0 -> 1152.0, 1152.0
% INFO    : Updated Thermal Rating: on line 8057-8112 : Rate B, Rate C - 0.0, 0.0 -> 2020.0, 2020.0
% INFO    : Updated Thermal Rating: on transformer 8059-8058 : Rate B, Rate C - 0.0, 0.0 -> 143.8, 143.8
% INFO    : Updated Thermal Rating: on line 8058-8068 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8058-8147 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8064-8059 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8062-8098 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8119-8062 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8101-8063 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8063-8125 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8144-8064 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8065-8149 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8065-8149 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8066-8093 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8142-8066 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 8068-8067 : Rate B, Rate C - 0.0, 0.0 -> 285.0, 285.0
% INFO    : Updated Thermal Rating: on transformer 8070-8067 : Rate B, Rate C - 0.0, 0.0 -> 1325.0, 1325.0
% INFO    : Updated Thermal Rating: on transformer 8071-8067 : Rate B, Rate C - 0.0, 0.0 -> 1314.0, 1314.0
% INFO    : Updated Thermal Rating: on transformer 8069-8068 : Rate B, Rate C - 0.0, 0.0 -> 143.0, 143.0
% INFO    : Updated Thermal Rating: on line 8068-8083 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8103-8069 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8073-8108 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8136-8073 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8075-8074 : Rate B, Rate C - 0.0, 0.0 -> 550.0, 550.0
% INFO    : Updated Thermal Rating: on transformer 8075-8074 : Rate B, Rate C - 0.0, 0.0 -> 550.0, 550.0
% INFO    : Updated Thermal Rating: on transformer 8077-8074 : Rate B, Rate C - 0.0, 0.0 -> 806.0, 806.0
% INFO    : Updated Thermal Rating: on transformer 8078-8074 : Rate B, Rate C - 0.0, 0.0 -> 818.0, 818.0
% INFO    : Updated Thermal Rating: on transformer 8079-8074 : Rate B, Rate C - 0.0, 0.0 -> 818.0, 818.0
% INFO    : Updated Thermal Rating: on transformer 8080-8074 : Rate B, Rate C - 0.0, 0.0 -> 814.0, 814.0
% INFO    : Updated Thermal Rating: on transformer 8076-8075 : Rate B, Rate C - 0.0, 0.0 -> 320.0, 320.0
% INFO    : Updated Thermal Rating: on line 8075-8097 : Rate B, Rate C - 0.0, 0.0 -> 740.0, 740.0
% INFO    : Updated Thermal Rating: on line 8119-8076 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8119-8076 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 8083-8082 : Rate B, Rate C - 0.0, 0.0 -> 1134.0, 1134.0
% INFO    : Updated Thermal Rating: on transformer 8087-8082 : Rate B, Rate C - 0.0, 0.0 -> 1315.0, 1315.0
% INFO    : Updated Thermal Rating: on transformer 8088-8082 : Rate B, Rate C - 0.0, 0.0 -> 1307.0, 1307.0
% INFO    : Updated Thermal Rating: on line 8155-8082 : Rate B, Rate C - 0.0, 0.0 -> 2768.0, 2768.0
% INFO    : Updated Thermal Rating: on transformer 8084-8083 : Rate B, Rate C - 0.0, 0.0 -> 184.8, 184.8
% INFO    : Updated Thermal Rating: on line 8085-8084 : Rate B, Rate C - 0.0, 0.0 -> 231.0, 231.0
% INFO    : Updated Thermal Rating: on transformer 8086-8085 : Rate B, Rate C - 0.0, 0.0 -> 205.0, 205.0
% INFO    : Updated Thermal Rating: on line 8089-8135 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8089-8135 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8090-8092 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8151-8090 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8091-8109 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8106-8093 : Rate B, Rate C - 0.0, 0.0 -> 150.0, 150.0
% INFO    : Updated Thermal Rating: on line 8093-8128 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 8095-8094 : Rate B, Rate C - 0.0, 0.0 -> 317.0, 317.0
% INFO    : Updated Thermal Rating: on line 8094-8139 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8094-8159 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8095-8140 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 8096-8110 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8096-8153 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8098-8097 : Rate B, Rate C - 0.0, 0.0 -> 117.0, 117.0
% INFO    : Updated Thermal Rating: on transformer 8099-8097 : Rate B, Rate C - 0.0, 0.0 -> 184.0, 184.0
% INFO    : Updated Thermal Rating: on line 8097-8113 : Rate B, Rate C - 0.0, 0.0 -> 800.0, 800.0
% INFO    : Updated Thermal Rating: on line 8138-8100 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8101-8137 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8102-8157 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 8106-8105 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 8105-8127 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8142-8106 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8128-8107 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8145-8107 : Rate B, Rate C - 0.0, 0.0 -> 250.0, 250.0
% INFO    : Updated Thermal Rating: on line 8153-8108 : Rate B, Rate C - 0.0, 0.0 -> 186.0, 186.0
% INFO    : Updated Thermal Rating: on line 8109-8123 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8124-8110 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8111-8125 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 8113-8112 : Rate B, Rate C - 0.0, 0.0 -> 1290.0, 1290.0
% INFO    : Updated Thermal Rating: on transformer 8115-8112 : Rate B, Rate C - 0.0, 0.0 -> 273.0, 273.0
% INFO    : Updated Thermal Rating: on transformer 8116-8112 : Rate B, Rate C - 0.0, 0.0 -> 1026.0, 1026.0
% INFO    : Updated Thermal Rating: on transformer 8117-8112 : Rate B, Rate C - 0.0, 0.0 -> 1034.0, 1034.0
% INFO    : Updated Thermal Rating: on transformer 8114-8113 : Rate B, Rate C - 0.0, 0.0 -> 190.0, 190.0
% INFO    : Updated Thermal Rating: on line 8113-8133 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 8113-8133 : Rate B, Rate C - 0.0, 0.0 -> 750.0, 750.0
% INFO    : Updated Thermal Rating: on line 8121-8114 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8118-8151 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8120-8122 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on line 8120-8140 : Rate B, Rate C - 0.0, 0.0 -> 170.0, 170.0
% INFO    : Updated Thermal Rating: on line 8120-8141 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8143-8120 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8149-8123 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8127-8126 : Rate B, Rate C - 0.0, 0.0 -> 1175.0, 1175.0
% INFO    : Updated Thermal Rating: on transformer 8127-8126 : Rate B, Rate C - 0.0, 0.0 -> 1175.0, 1175.0
% INFO    : Updated Thermal Rating: on transformer 8129-8126 : Rate B, Rate C - 0.0, 0.0 -> 1190.0, 1190.0
% INFO    : Updated Thermal Rating: on transformer 8130-8126 : Rate B, Rate C - 0.0, 0.0 -> 1192.0, 1192.0
% INFO    : Updated Thermal Rating: on transformer 8131-8126 : Rate B, Rate C - 0.0, 0.0 -> 1173.0, 1173.0
% INFO    : Updated Thermal Rating: on transformer 8128-8127 : Rate B, Rate C - 0.0, 0.0 -> 286.0, 286.0
% INFO    : Updated Thermal Rating: on line 8132-8144 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on transformer 8134-8133 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on transformer 8134-8133 : Rate B, Rate C - 0.0, 0.0 -> 300.0, 300.0
% INFO    : Updated Thermal Rating: on line 8133-8147 : Rate B, Rate C - 0.0, 0.0 -> 548.0, 548.0
% INFO    : Updated Thermal Rating: on line 8154-8135 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8136-8145 : Rate B, Rate C - 0.0, 0.0 -> 149.0, 149.0
% INFO    : Updated Thermal Rating: on line 8138-8146 : Rate B, Rate C - 0.0, 0.0 -> 98.0, 98.0
% INFO    : Updated Thermal Rating: on transformer 8140-8139 : Rate B, Rate C - 0.0, 0.0 -> 365.0, 365.0
% INFO    : Updated Thermal Rating: on transformer 8148-8147 : Rate B, Rate C - 0.0, 0.0 -> 201.3, 201.3
% INFO    : Updated Thermal Rating: on transformer 8148-8147 : Rate B, Rate C - 0.0, 0.0 -> 201.3, 201.3
% INFO    : Updated Thermal Rating: on transformer 8149-8148 : Rate B, Rate C - 0.0, 0.0 -> 254.0, 254.0
% INFO    : Updated Thermal Rating: on line 8152-8160 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on line 8152-8160 : Rate B, Rate C - 0.0, 0.0 -> 221.0, 221.0
% INFO    : Updated Thermal Rating: on transformer 8156-8155 : Rate B, Rate C - 0.0, 0.0 -> 500.0, 500.0
% INFO    : Updated Thermal Rating: on transformer 8157-8156 : Rate B, Rate C - 0.0, 0.0 -> 240.0, 240.0
% INFO    : Updated Thermal Rating: on line 8156-8159 : Rate B, Rate C - 0.0, 0.0 -> 600.0, 600.0
% INFO    : Updated Thermal Rating: on transformer 8159-8158 : Rate B, Rate C - 0.0, 0.0 -> 1204.0, 1204.0
% INFO    : Updated Thermal Rating: on transformer 8160-8159 : Rate B, Rate C - 0.0, 0.0 -> 377.0, 377.0
% INFO    : Updated Thermal Rating: on transformer 8160-8159 : Rate B, Rate C - 0.0, 0.0 -> 377.0, 377.0
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1001	: V=0.9794356, theta=-22.734844 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.0127364, theta=-18.088545 -> V=1.0, theta=0.0
% INFO    : Bus 1003	: V=1.0092629, theta=-17.086699 -> V=1.0, theta=0.0
% INFO    : Bus 1004	: V=1.0130707, theta=-18.933999 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=1.0055761, theta=-16.077157 -> V=1.0, theta=0.0
% INFO    : Bus 1006	: V=1.0, theta=-13.905591 -> V=1.0, theta=0.0
% INFO    : Bus 1007	: V=1.02, theta=-18.467212 -> V=1.0, theta=0.0
% INFO    : Bus 1008	: V=1.0192851, theta=-8.605207 -> V=1.0, theta=0.0
% INFO    : Bus 1009	: V=1.0092402, theta=-5.309598 -> V=1.0, theta=0.0
% INFO    : Bus 1010	: V=1.02, theta=-16.792355 -> V=1.0, theta=0.0
% INFO    : Bus 1011	: V=1.0202111, theta=-15.009826 -> V=1.0, theta=0.0
% INFO    : Bus 1012	: V=1.0059921, theta=-25.342783 -> V=1.0, theta=0.0
% INFO    : Bus 1013	: V=1.0056772, theta=-15.436565 -> V=1.0, theta=0.0
% INFO    : Bus 1014	: V=1.0123505, theta=-11.91325 -> V=1.0, theta=0.0
% INFO    : Bus 1015	: V=1.0218177, theta=-18.214501 -> V=1.0, theta=0.0
% INFO    : Bus 1016	: V=1.0174069, theta=-15.485448 -> V=1.0, theta=0.0
% INFO    : Bus 1017	: V=0.9816734, theta=-21.426222 -> V=1.0, theta=0.0
% INFO    : Bus 1018	: V=0.9911469, theta=-20.216148 -> V=1.0, theta=0.0
% INFO    : Bus 1019	: V=0.9994919, theta=-22.320417 -> V=1.0, theta=0.0
% INFO    : Bus 1020	: V=1.02, theta=-15.230064 -> V=1.0, theta=0.0
% INFO    : Bus 1021	: V=1.0, theta=-8.606761 -> V=1.0, theta=0.0
% INFO    : Bus 1022	: V=1.0124231, theta=-16.204693 -> V=1.0, theta=0.0
% INFO    : Bus 1023	: V=1.01, theta=-7.300393 -> V=1.0, theta=0.0
% INFO    : Bus 1024	: V=0.9944951, theta=-19.200249 -> V=1.0, theta=0.0
% INFO    : Bus 1025	: V=1.0162883, theta=-14.170406 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=1.0, theta=-4.641462 -> V=1.0, theta=0.0
% INFO    : Bus 1027	: V=1.0053046, theta=-25.833336 -> V=1.0, theta=0.0
% INFO    : Bus 1028	: V=1.0154159, theta=-17.717136 -> V=1.0, theta=0.0
% INFO    : Bus 1029	: V=1.0024174, theta=-24.858888 -> V=1.0, theta=0.0
% INFO    : Bus 1030	: V=1.0122298, theta=-13.41143 -> V=1.0, theta=0.0
% INFO    : Bus 1031	: V=1.0121888, theta=-17.672258 -> V=1.0, theta=0.0
% INFO    : Bus 1032	: V=1.0006583, theta=-12.280471 -> V=1.0, theta=0.0
% INFO    : Bus 1033	: V=1.0167542, theta=-16.898515 -> V=1.0, theta=0.0
% INFO    : Bus 1034	: V=1.0045345, theta=-14.320349 -> V=1.0, theta=0.0
% INFO    : Bus 1035	: V=1.0, theta=-11.030416 -> V=1.0, theta=0.0
% INFO    : Bus 1036	: V=0.9976248, theta=-12.526972 -> V=1.0, theta=0.0
% INFO    : Bus 1037	: V=0.9745044, theta=-22.5448 -> V=1.0, theta=0.0
% INFO    : Bus 1038	: V=1.0165674, theta=-7.646607 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.0, theta=-2.263052 -> V=1.0, theta=0.0
% INFO    : Bus 1040	: V=0.9940145, theta=-20.480041 -> V=1.0, theta=0.0
% INFO    : Bus 1041	: V=1.0017746, theta=-15.107504 -> V=1.0, theta=0.0
% INFO    : Bus 1042	: V=1.0017746, theta=-15.107504 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=1.0, theta=-11.864177 -> V=1.0, theta=0.0
% INFO    : Bus 1044	: V=1.0067555, theta=-25.963881 -> V=1.0, theta=0.0
% INFO    : Bus 1045	: V=0.9774255, theta=-24.447556 -> V=1.0, theta=0.0
% INFO    : Bus 1046	: V=1.0176344, theta=-22.491396 -> V=1.0, theta=0.0
% INFO    : Bus 1047	: V=1.0052508, theta=-13.35005 -> V=1.0, theta=0.0
% INFO    : Bus 1048	: V=1.0052508, theta=-13.35005 -> V=1.0, theta=0.0
% INFO    : Bus 1049	: V=1.0052508, theta=-13.35005 -> V=1.0, theta=0.0
% INFO    : Bus 1050	: V=1.0, theta=-8.284789 -> V=1.0, theta=0.0
% INFO    : Bus 1051	: V=1.0, theta=-6.807389 -> V=1.0, theta=0.0
% INFO    : Bus 1052	: V=1.0, theta=-9.134369 -> V=1.0, theta=0.0
% INFO    : Bus 1053	: V=1.0174089, theta=-17.33616 -> V=1.0, theta=0.0
% INFO    : Bus 1054	: V=1.0036844, theta=-22.292331 -> V=1.0, theta=0.0
% INFO    : Bus 1055	: V=1.001405, theta=-18.129563 -> V=1.0, theta=0.0
% INFO    : Bus 1056	: V=1.02, theta=-21.819612 -> V=1.0, theta=0.0
% INFO    : Bus 1057	: V=1.02, theta=-21.819612 -> V=1.0, theta=0.0
% INFO    : Bus 1058	: V=1.0193738, theta=-11.220883 -> V=1.0, theta=0.0
% INFO    : Bus 1059	: V=1.0193738, theta=-11.220883 -> V=1.0, theta=0.0
% INFO    : Bus 1060	: V=1.0193738, theta=-11.220883 -> V=1.0, theta=0.0
% INFO    : Bus 1061	: V=1.0065566, theta=-17.219364 -> V=1.0, theta=0.0
% INFO    : Bus 1062	: V=1.0065566, theta=-17.219364 -> V=1.0, theta=0.0
% INFO    : Bus 1063	: V=1.0065566, theta=-17.219364 -> V=1.0, theta=0.0
% INFO    : Bus 1064	: V=0.9720345, theta=-24.153272 -> V=1.0, theta=0.0
% INFO    : Bus 1065	: V=1.0042605, theta=-14.932578 -> V=1.0, theta=0.0
% INFO    : Bus 1066	: V=1.0, theta=-7.399054 -> V=1.0, theta=0.0
% INFO    : Bus 1067	: V=0.9985952, theta=-15.68248 -> V=1.0, theta=0.0
% INFO    : Bus 1068	: V=0.9868034, theta=-16.436894 -> V=1.0, theta=0.0
% INFO    : Bus 1069	: V=1.0225598, theta=-8.732588 -> V=1.0, theta=0.0
% INFO    : Bus 1070	: V=1.04, theta=-4.228777 -> V=1.0, theta=0.0
% INFO    : Bus 1071	: V=0.9870267, theta=-21.47404 -> V=1.0, theta=0.0
% INFO    : Bus 1072	: V=1.01, theta=-12.110027 -> V=1.0, theta=0.0
% INFO    : Bus 1073	: V=1.01, theta=-5.681972 -> V=1.0, theta=0.0
% INFO    : Bus 1074	: V=1.01, theta=-7.738009 -> V=1.0, theta=0.0
% INFO    : Bus 1075	: V=1.01, theta=-10.505543 -> V=1.0, theta=0.0
% INFO    : Bus 1076	: V=0.9870267, theta=-21.47404 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=0.9870267, theta=-21.47404 -> V=1.0, theta=0.0
% INFO    : Bus 1078	: V=1.01, theta=-11.024659 -> V=1.0, theta=0.0
% INFO    : Bus 1079	: V=1.0162141, theta=-38.582859 -> V=1.0, theta=0.0
% INFO    : Bus 1080	: V=1.01, theta=-10.448676 -> V=1.0, theta=0.0
% INFO    : Bus 1081	: V=1.02, theta=-18.691287 -> V=1.0, theta=0.0
% INFO    : Bus 1082	: V=1.0194126, theta=-5.910392 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=1.0188617, theta=-9.886743 -> V=1.0, theta=0.0
% INFO    : Bus 1084	: V=1.0225199, theta=-16.467206 -> V=1.0, theta=0.0
% INFO    : Bus 1085	: V=1.008987, theta=-15.342869 -> V=1.0, theta=0.0
% INFO    : Bus 1086	: V=1.015374, theta=-17.585057 -> V=1.0, theta=0.0
% INFO    : Bus 1087	: V=1.02, theta=-16.125402 -> V=1.0, theta=0.0
% INFO    : Bus 1088	: V=1.0, theta=-11.878466 -> V=1.0, theta=0.0
% INFO    : Bus 1089	: V=0.9806318, theta=-21.306753 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.02, theta=-16.145053 -> V=1.0, theta=0.0
% INFO    : Bus 1091	: V=1.0248315, theta=-31.017725 -> V=1.0, theta=0.0
% INFO    : Bus 2001	: V=1.0017518, theta=-59.982147 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=1.011061, theta=-61.566631 -> V=1.0, theta=0.0
% INFO    : Bus 2003	: V=1.0093382, theta=-63.828546 -> V=1.0, theta=0.0
% INFO    : Bus 2004	: V=1.011061, theta=-61.566631 -> V=1.0, theta=0.0
% INFO    : Bus 2005	: V=1.011061, theta=-61.566631 -> V=1.0, theta=0.0
% INFO    : Bus 2006	: V=1.011061, theta=-61.566631 -> V=1.0, theta=0.0
% INFO    : Bus 2007	: V=1.0025088, theta=-59.751902 -> V=1.0, theta=0.0
% INFO    : Bus 2008	: V=1.0161296, theta=-32.833005 -> V=1.0, theta=0.0
% INFO    : Bus 2009	: V=1.02, theta=-45.215386 -> V=1.0, theta=0.0
% INFO    : Bus 2010	: V=1.02, theta=-36.405086 -> V=1.0, theta=0.0
% INFO    : Bus 2011	: V=1.0388703, theta=-32.100979 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=1.0270973, theta=-29.869241 -> V=1.0, theta=0.0
% INFO    : Bus 2013	: V=1.0305102, theta=-29.76103 -> V=1.0, theta=0.0
% INFO    : Bus 2014	: V=1.014488, theta=-33.408935 -> V=1.0, theta=0.0
% INFO    : Bus 2015	: V=1.0060782, theta=-63.292789 -> V=1.0, theta=0.0
% INFO    : Bus 2016	: V=1.0060187, theta=-69.954795 -> V=1.0, theta=0.0
% INFO    : Bus 2017	: V=1.0283919, theta=-32.24683 -> V=1.0, theta=0.0
% INFO    : Bus 2018	: V=1.0264922, theta=-31.456709 -> V=1.0, theta=0.0
% INFO    : Bus 2019	: V=1.0283919, theta=-32.24683 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=0.9951749, theta=-44.885383 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=1.0138733, theta=-56.702369 -> V=1.0, theta=0.0
% INFO    : Bus 2022	: V=1.0100102, theta=-58.637546 -> V=1.0, theta=0.0
% INFO    : Bus 2023	: V=1.02, theta=-55.13952 -> V=1.0, theta=0.0
% INFO    : Bus 2024	: V=1.02, theta=-54.474073 -> V=1.0, theta=0.0
% INFO    : Bus 2025	: V=0.994074, theta=-44.124136 -> V=1.0, theta=0.0
% INFO    : Bus 2026	: V=1.0264805, theta=-31.081493 -> V=1.0, theta=0.0
% INFO    : Bus 2027	: V=1.0021966, theta=-60.413018 -> V=1.0, theta=0.0
% INFO    : Bus 2028	: V=0.9945927, theta=-47.249778 -> V=1.0, theta=0.0
% INFO    : Bus 2029	: V=1.0200518, theta=-32.781385 -> V=1.0, theta=0.0
% INFO    : Bus 2030	: V=0.9883653, theta=-64.039783 -> V=1.0, theta=0.0
% INFO    : Bus 2031	: V=1.0204588, theta=-29.638731 -> V=1.0, theta=0.0
% INFO    : Bus 2032	: V=1.004536, theta=-59.146912 -> V=1.0, theta=0.0
% INFO    : Bus 2033	: V=0.9908717, theta=-65.552183 -> V=1.0, theta=0.0
% INFO    : Bus 2034	: V=1.0046209, theta=-69.283118 -> V=1.0, theta=0.0
% INFO    : Bus 2035	: V=1.0152073, theta=-30.560737 -> V=1.0, theta=0.0
% INFO    : Bus 2036	: V=0.998941, theta=-44.48325 -> V=1.0, theta=0.0
% INFO    : Bus 2037	: V=1.0166773, theta=-63.62606 -> V=1.0, theta=0.0
% INFO    : Bus 2038	: V=1.0063308, theta=-64.301324 -> V=1.0, theta=0.0
% INFO    : Bus 2039	: V=0.9912537, theta=-60.671164 -> V=1.0, theta=0.0
% INFO    : Bus 2040	: V=1.0074385, theta=-59.308023 -> V=1.0, theta=0.0
% INFO    : Bus 2041	: V=1.0280219, theta=-27.686092 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=1.0194284, theta=-25.11083 -> V=1.0, theta=0.0
% INFO    : Bus 2043	: V=1.0050458, theta=-69.589647 -> V=1.0, theta=0.0
% INFO    : Bus 2044	: V=1.0130566, theta=-65.383329 -> V=1.0, theta=0.0
% INFO    : Bus 2045	: V=0.9944497, theta=-45.423966 -> V=1.0, theta=0.0
% INFO    : Bus 2046	: V=1.0045595, theta=-68.896782 -> V=1.0, theta=0.0
% INFO    : Bus 2047	: V=1.0079022, theta=-64.729913 -> V=1.0, theta=0.0
% INFO    : Bus 2048	: V=1.0237031, theta=-31.710962 -> V=1.0, theta=0.0
% INFO    : Bus 2049	: V=1.0177581, theta=-40.946465 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=0.9941919, theta=-63.23541 -> V=1.0, theta=0.0
% INFO    : Bus 2051	: V=0.989552, theta=-54.140347 -> V=1.0, theta=0.0
% INFO    : Bus 2052	: V=1.0174448, theta=-31.96347 -> V=1.0, theta=0.0
% INFO    : Bus 2053	: V=0.9910634, theta=-59.360379 -> V=1.0, theta=0.0
% INFO    : Bus 2054	: V=0.9977811, theta=-43.13131 -> V=1.0, theta=0.0
% INFO    : Bus 2055	: V=0.9973321, theta=-43.960678 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=0.9977811, theta=-43.13131 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=0.99, theta=-38.725286 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=1.0283596, theta=-27.258033 -> V=1.0, theta=0.0
% INFO    : Bus 2059	: V=1.0183617, theta=-23.911715 -> V=1.0, theta=0.0
% INFO    : Bus 2060	: V=0.9974049, theta=-61.950951 -> V=1.0, theta=0.0
% INFO    : Bus 2061	: V=1.0211752, theta=-37.427819 -> V=1.0, theta=0.0
% INFO    : Bus 2062	: V=1.02, theta=-35.131 -> V=1.0, theta=0.0
% INFO    : Bus 2063	: V=1.0060645, theta=-68.258359 -> V=1.0, theta=0.0
% INFO    : Bus 2064	: V=1.0031055, theta=-60.277381 -> V=1.0, theta=0.0
% INFO    : Bus 2065	: V=1.02, theta=-65.600732 -> V=1.0, theta=0.0
% INFO    : Bus 2066	: V=1.014436, theta=-27.628767 -> V=1.0, theta=0.0
% INFO    : Bus 2067	: V=0.9923568, theta=-44.047987 -> V=1.0, theta=0.0
% INFO    : Bus 2068	: V=0.9989951, theta=-42.016304 -> V=1.0, theta=0.0
% INFO    : Bus 2069	: V=1.02, theta=-69.116814 -> V=1.0, theta=0.0
% INFO    : Bus 2070	: V=1.0010765, theta=-41.598099 -> V=1.0, theta=0.0
% INFO    : Bus 2071	: V=1.0, theta=-37.919678 -> V=1.0, theta=0.0
% INFO    : Bus 2072	: V=1.0148759, theta=-67.240635 -> V=1.0, theta=0.0
% INFO    : Bus 2073	: V=1.0155141, theta=-25.108834 -> V=1.0, theta=0.0
% INFO    : Bus 2074	: V=1.0058489, theta=-23.236834 -> V=1.0, theta=0.0
% INFO    : Bus 2075	: V=1.0058489, theta=-23.236834 -> V=1.0, theta=0.0
% INFO    : Bus 2076	: V=1.0207772, theta=-24.20214 -> V=1.0, theta=0.0
% INFO    : Bus 2077	: V=1.0178964, theta=-61.197723 -> V=1.0, theta=0.0
% INFO    : Bus 2078	: V=1.02, theta=-57.875001 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=1.0222991, theta=-34.626738 -> V=1.0, theta=0.0
% INFO    : Bus 2080	: V=0.9946218, theta=-57.499175 -> V=1.0, theta=0.0
% INFO    : Bus 2081	: V=1.0009362, theta=-65.107672 -> V=1.0, theta=0.0
% INFO    : Bus 2082	: V=1.002871, theta=-44.826631 -> V=1.0, theta=0.0
% INFO    : Bus 2083	: V=1.0175906, theta=-43.247104 -> V=1.0, theta=0.0
% INFO    : Bus 2084	: V=1.002871, theta=-44.826631 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=1.002871, theta=-44.826631 -> V=1.0, theta=0.0
% INFO    : Bus 2086	: V=0.9924453, theta=-59.474499 -> V=1.0, theta=0.0
% INFO    : Bus 2087	: V=1.017379, theta=-27.472635 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=1.0000706, theta=-41.716402 -> V=1.0, theta=0.0
% INFO    : Bus 2089	: V=1.0, theta=-38.113501 -> V=1.0, theta=0.0
% INFO    : Bus 2090	: V=1.0025227, theta=-61.033299 -> V=1.0, theta=0.0
% INFO    : Bus 2091	: V=1.0162815, theta=-33.97855 -> V=1.0, theta=0.0
% INFO    : Bus 2092	: V=1.0054244, theta=-66.568503 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=1.0272713, theta=-30.621379 -> V=1.0, theta=0.0
% INFO    : Bus 2094	: V=1.0272713, theta=-30.621379 -> V=1.0, theta=0.0
% INFO    : Bus 2095	: V=1.0272713, theta=-30.621379 -> V=1.0, theta=0.0
% INFO    : Bus 2096	: V=1.0199998, theta=-27.84317 -> V=1.0, theta=0.0
% INFO    : Bus 2097	: V=1.0192658, theta=-27.282308 -> V=1.0, theta=0.0
% INFO    : Bus 2098	: V=1.0256479, theta=-30.426538 -> V=1.0, theta=0.0
% INFO    : Bus 2099	: V=1.02, theta=-27.699549 -> V=1.0, theta=0.0
% INFO    : Bus 2100	: V=1.02, theta=-25.218709 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=1.010539, theta=-62.673279 -> V=1.0, theta=0.0
% INFO    : Bus 2102	: V=1.0105919, theta=-64.120882 -> V=1.0, theta=0.0
% INFO    : Bus 2103	: V=1.010539, theta=-62.673279 -> V=1.0, theta=0.0
% INFO    : Bus 2104	: V=1.010539, theta=-62.673279 -> V=1.0, theta=0.0
% INFO    : Bus 2105	: V=1.010539, theta=-62.673279 -> V=1.0, theta=0.0
% INFO    : Bus 2106	: V=0.9891329, theta=-66.198009 -> V=1.0, theta=0.0
% INFO    : Bus 2107	: V=1.0051501, theta=-64.992908 -> V=1.0, theta=0.0
% INFO    : Bus 2108	: V=0.9991016, theta=-43.691094 -> V=1.0, theta=0.0
% INFO    : Bus 2109	: V=1.0066134, theta=-46.357265 -> V=1.0, theta=0.0
% INFO    : Bus 2110	: V=1.02, theta=-62.269561 -> V=1.0, theta=0.0
% INFO    : Bus 2111	: V=0.9946072, theta=-48.990101 -> V=1.0, theta=0.0
% INFO    : Bus 2112	: V=0.9916571, theta=-49.379366 -> V=1.0, theta=0.0
% INFO    : Bus 2113	: V=1.0137786, theta=-56.233081 -> V=1.0, theta=0.0
% INFO    : Bus 2114	: V=1.0113736, theta=-57.520113 -> V=1.0, theta=0.0
% INFO    : Bus 2115	: V=1.0048888, theta=-52.23961 -> V=1.0, theta=0.0
% INFO    : Bus 2116	: V=1.0095429, theta=-54.163985 -> V=1.0, theta=0.0
% INFO    : Bus 2117	: V=1.0021538, theta=-51.600268 -> V=1.0, theta=0.0
% INFO    : Bus 2118	: V=1.0007844, theta=-51.092416 -> V=1.0, theta=0.0
% INFO    : Bus 2119	: V=1.0084621, theta=-53.711535 -> V=1.0, theta=0.0
% INFO    : Bus 2120	: V=1.01, theta=-51.344328 -> V=1.0, theta=0.0
% INFO    : Bus 2121	: V=1.0061151, theta=-59.941306 -> V=1.0, theta=0.0
% INFO    : Bus 2122	: V=0.9963019, theta=-61.14302 -> V=1.0, theta=0.0
% INFO    : Bus 2123	: V=1.0285431, theta=-27.029356 -> V=1.0, theta=0.0
% INFO    : Bus 2124	: V=0.9877701, theta=-67.273303 -> V=1.0, theta=0.0
% INFO    : Bus 2125	: V=0.9932884, theta=-67.337716 -> V=1.0, theta=0.0
% INFO    : Bus 2126	: V=1.0068733, theta=-67.004796 -> V=1.0, theta=0.0
% INFO    : Bus 2127	: V=1.04, theta=-33.967593 -> V=1.0, theta=0.0
% INFO    : Bus 2128	: V=1.0300583, theta=-32.47773 -> V=1.0, theta=0.0
% INFO    : Bus 2129	: V=0.9922046, theta=-66.114879 -> V=1.0, theta=0.0
% INFO    : Bus 2130	: V=1.0007321, theta=-42.301537 -> V=1.0, theta=0.0
% INFO    : Bus 2131	: V=0.9951718, theta=-39.712836 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=1.0111016, theta=-41.451971 -> V=1.0, theta=0.0
% INFO    : Bus 2133	: V=1.0129003, theta=-60.522664 -> V=1.0, theta=0.0
% INFO    : Bus 3001	: V=1.0045071, theta=-56.055858 -> V=1.0, theta=0.0
% INFO    : Bus 3002	: V=0.9925381, theta=-58.537415 -> V=1.0, theta=0.0
% INFO    : Bus 3003	: V=1.0139253, theta=-18.246162 -> V=1.0, theta=0.0
% INFO    : Bus 3004	: V=1.009025, theta=-16.644394 -> V=1.0, theta=0.0
% INFO    : Bus 3005	: V=1.0105581, theta=-58.521456 -> V=1.0, theta=0.0
% INFO    : Bus 3006	: V=0.9998442, theta=-26.877872 -> V=1.0, theta=0.0
% INFO    : Bus 3007	: V=1.0123256, theta=-24.724902 -> V=1.0, theta=0.0
% INFO    : Bus 3008	: V=0.9910125, theta=-37.183753 -> V=1.0, theta=0.0
% INFO    : Bus 3009	: V=1.0111101, theta=-31.252042 -> V=1.0, theta=0.0
% INFO    : Bus 3010	: V=0.9970474, theta=-57.524886 -> V=1.0, theta=0.0
% INFO    : Bus 3011	: V=1.0068971, theta=-61.494144 -> V=1.0, theta=0.0
% INFO    : Bus 3012	: V=1.00822, theta=-61.089137 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=1.0157866, theta=-28.589048 -> V=1.0, theta=0.0
% INFO    : Bus 3014	: V=1.013961, theta=-53.58773 -> V=1.0, theta=0.0
% INFO    : Bus 3015	: V=1.0111514, theta=-17.008563 -> V=1.0, theta=0.0
% INFO    : Bus 3016	: V=1.0091303, theta=-21.984673 -> V=1.0, theta=0.0
% INFO    : Bus 3017	: V=1.01, theta=-16.780818 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.0229356, theta=-29.156049 -> V=1.0, theta=0.0
% INFO    : Bus 3019	: V=1.02, theta=-30.777457 -> V=1.0, theta=0.0
% INFO    : Bus 3020	: V=1.03, theta=-25.014342 -> V=1.0, theta=0.0
% INFO    : Bus 3021	: V=0.999226, theta=-35.741111 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=0.9959859, theta=-18.121194 -> V=1.0, theta=0.0
% INFO    : Bus 3023	: V=1.02, theta=-26.986888 -> V=1.0, theta=0.0
% INFO    : Bus 3024	: V=1.0156701, theta=-31.222678 -> V=1.0, theta=0.0
% INFO    : Bus 3025	: V=0.9934448, theta=-45.629015 -> V=1.0, theta=0.0
% INFO    : Bus 3026	: V=1.0240344, theta=-36.852919 -> V=1.0, theta=0.0
% INFO    : Bus 3027	: V=1.0169718, theta=-37.434869 -> V=1.0, theta=0.0
% INFO    : Bus 3028	: V=1.036934, theta=-34.250404 -> V=1.0, theta=0.0
% INFO    : Bus 3029	: V=1.0220906, theta=-53.840897 -> V=1.0, theta=0.0
% INFO    : Bus 3030	: V=1.0081662, theta=-40.188617 -> V=1.0, theta=0.0
% INFO    : Bus 3031	: V=0.9971917, theta=-26.254366 -> V=1.0, theta=0.0
% INFO    : Bus 3032	: V=0.999911, theta=-27.145405 -> V=1.0, theta=0.0
% INFO    : Bus 3033	: V=1.0072273, theta=-15.053231 -> V=1.0, theta=0.0
% INFO    : Bus 3034	: V=1.03, theta=-5.774789 -> V=1.0, theta=0.0
% INFO    : Bus 3035	: V=0.9959845, theta=-44.739905 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=0.9928838, theta=-41.904562 -> V=1.0, theta=0.0
% INFO    : Bus 3037	: V=1.0228519, theta=-25.530863 -> V=1.0, theta=0.0
% INFO    : Bus 3038	: V=1.0038849, theta=-20.121033 -> V=1.0, theta=0.0
% INFO    : Bus 3039	: V=1.0358056, theta=-22.932201 -> V=1.0, theta=0.0
% INFO    : Bus 3040	: V=0.9901182, theta=-34.465473 -> V=1.0, theta=0.0
% INFO    : Bus 3041	: V=1.0161746, theta=-29.2954 -> V=1.0, theta=0.0
% INFO    : Bus 3042	: V=1.0022267, theta=-18.843463 -> V=1.0, theta=0.0
% INFO    : Bus 3043	: V=1.0161746, theta=-29.2954 -> V=1.0, theta=0.0
% INFO    : Bus 3044	: V=1.0161746, theta=-29.2954 -> V=1.0, theta=0.0
% INFO    : Bus 3045	: V=1.0161746, theta=-29.2954 -> V=1.0, theta=0.0
% INFO    : Bus 3046	: V=1.0123792, theta=-34.755563 -> V=1.0, theta=0.0
% INFO    : Bus 3047	: V=1.02, theta=-20.528194 -> V=1.0, theta=0.0
% INFO    : Bus 3048	: V=1.0180016, theta=-41.667111 -> V=1.0, theta=0.0
% INFO    : Bus 3049	: V=1.0003414, theta=-30.031027 -> V=1.0, theta=0.0
% INFO    : Bus 3050	: V=1.0137598, theta=-34.098699 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=0.9953169, theta=-36.015782 -> V=1.0, theta=0.0
% INFO    : Bus 3052	: V=0.9975297, theta=-58.953369 -> V=1.0, theta=0.0
% INFO    : Bus 3053	: V=1.0259886, theta=-27.208467 -> V=1.0, theta=0.0
% INFO    : Bus 3054	: V=1.0057989, theta=-26.722572 -> V=1.0, theta=0.0
% INFO    : Bus 3055	: V=1.04, theta=-24.317883 -> V=1.0, theta=0.0
% INFO    : Bus 3056	: V=1.04, theta=-21.727173 -> V=1.0, theta=0.0
% INFO    : Bus 3057	: V=1.04, theta=-21.894762 -> V=1.0, theta=0.0
% INFO    : Bus 3058	: V=1.0289719, theta=-24.015596 -> V=1.0, theta=0.0
% INFO    : Bus 3059	: V=1.0078403, theta=-17.326662 -> V=1.0, theta=0.0
% INFO    : Bus 3060	: V=1.04, theta=-16.429085 -> V=1.0, theta=0.0
% INFO    : Bus 3061	: V=1.04, theta=-18.606442 -> V=1.0, theta=0.0
% INFO    : Bus 3062	: V=1.04, theta=-21.295915 -> V=1.0, theta=0.0
% INFO    : Bus 3063	: V=1.04, theta=-20.13927 -> V=1.0, theta=0.0
% INFO    : Bus 3064	: V=1.0155387, theta=-18.483476 -> V=1.0, theta=0.0
% INFO    : Bus 3065	: V=1.0, theta=-12.363914 -> V=1.0, theta=0.0
% INFO    : Bus 3066	: V=1.0008227, theta=-42.961112 -> V=1.0, theta=0.0
% INFO    : Bus 3067	: V=1.0257376, theta=-19.847452 -> V=1.0, theta=0.0
% INFO    : Bus 3068	: V=1.04, theta=-16.950774 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=0.9961637, theta=-29.61393 -> V=1.0, theta=0.0
% INFO    : Bus 3070	: V=1.0172657, theta=-21.149531 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=1.0027765, theta=-16.550419 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=1.0030653, theta=-38.791736 -> V=1.0, theta=0.0
% INFO    : Bus 3073	: V=1.0009688, theta=-54.686037 -> V=1.0, theta=0.0
% INFO    : Bus 3074	: V=1.0, theta=-52.163522 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=0.9948176, theta=-40.369102 -> V=1.0, theta=0.0
% INFO    : Bus 3076	: V=0.9972582, theta=-56.137487 -> V=1.0, theta=0.0
% INFO    : Bus 3077	: V=1.0003948, theta=-28.088496 -> V=1.0, theta=0.0
% INFO    : Bus 3078	: V=1.0182663, theta=-25.88082 -> V=1.0, theta=0.0
% INFO    : Bus 3079	: V=1.0142237, theta=-24.090342 -> V=1.0, theta=0.0
% INFO    : Bus 3080	: V=1.0044855, theta=-21.19207 -> V=1.0, theta=0.0
% INFO    : Bus 3081	: V=1.04, theta=-19.785023 -> V=1.0, theta=0.0
% INFO    : Bus 3082	: V=1.0173671, theta=-28.074949 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.0112436, theta=-24.253755 -> V=1.0, theta=0.0
% INFO    : Bus 3084	: V=1.0, theta=-18.202932 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=1.0036466, theta=-18.446704 -> V=1.0, theta=0.0
% INFO    : Bus 3086	: V=1.0, theta=-11.49954 -> V=1.0, theta=0.0
% INFO    : Bus 3087	: V=1.0036466, theta=-18.446704 -> V=1.0, theta=0.0
% INFO    : Bus 3088	: V=1.02, theta=-33.277037 -> V=1.0, theta=0.0
% INFO    : Bus 3089	: V=1.0194197, theta=-35.945769 -> V=1.0, theta=0.0
% INFO    : Bus 3090	: V=1.0195628, theta=-36.614078 -> V=1.0, theta=0.0
% INFO    : Bus 3091	: V=1.02, theta=-37.51549 -> V=1.0, theta=0.0
% INFO    : Bus 3092	: V=1.04, theta=-26.431971 -> V=1.0, theta=0.0
% INFO    : Bus 3093	: V=0.9973061, theta=-58.33215 -> V=1.0, theta=0.0
% INFO    : Bus 3094	: V=1.0137247, theta=-23.300486 -> V=1.0, theta=0.0
% INFO    : Bus 3095	: V=1.04, theta=-15.360146 -> V=1.0, theta=0.0
% INFO    : Bus 3096	: V=1.0196496, theta=-21.48134 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=1.0160797, theta=-19.625366 -> V=1.0, theta=0.0
% INFO    : Bus 3098	: V=1.04, theta=-12.800146 -> V=1.0, theta=0.0
% INFO    : Bus 3099	: V=0.9985501, theta=-28.885531 -> V=1.0, theta=0.0
% INFO    : Bus 3100	: V=1.0003795, theta=-35.020793 -> V=1.0, theta=0.0
% INFO    : Bus 3101	: V=1.0017495, theta=-48.15402 -> V=1.0, theta=0.0
% INFO    : Bus 3102	: V=1.0108836, theta=-37.659122 -> V=1.0, theta=0.0
% INFO    : Bus 3103	: V=1.0067647, theta=-20.706659 -> V=1.0, theta=0.0
% INFO    : Bus 3104	: V=1.0087332, theta=-47.729381 -> V=1.0, theta=0.0
% INFO    : Bus 3105	: V=1.0065081, theta=-42.108732 -> V=1.0, theta=0.0
% INFO    : Bus 3106	: V=1.0, theta=-41.07228 -> V=1.0, theta=0.0
% INFO    : Bus 3107	: V=0.9922886, theta=-59.06577 -> V=1.0, theta=0.0
% INFO    : Bus 3108	: V=1.0009429, theta=-57.072045 -> V=1.0, theta=0.0
% INFO    : Bus 3109	: V=1.0166353, theta=-18.237594 -> V=1.0, theta=0.0
% INFO    : Bus 3110	: V=1.04, theta=-10.722222 -> V=1.0, theta=0.0
% INFO    : Bus 3111	: V=1.0075028, theta=-16.49223 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=1.0, theta=-8.322669 -> V=1.0, theta=0.0
% INFO    : Bus 3113	: V=1.0, theta=-8.319085 -> V=1.0, theta=0.0
% INFO    : Bus 3114	: V=1.0055665, theta=-34.546572 -> V=1.0, theta=0.0
% INFO    : Bus 3115	: V=1.0026805, theta=-21.923846 -> V=1.0, theta=0.0
% INFO    : Bus 3116	: V=1.0044781, theta=-15.292694 -> V=1.0, theta=0.0
% INFO    : Bus 3117	: V=1.0, theta=-12.2372 -> V=1.0, theta=0.0
% INFO    : Bus 3118	: V=1.0, theta=-11.267693 -> V=1.0, theta=0.0
% INFO    : Bus 3119	: V=1.0228104, theta=-52.15856 -> V=1.0, theta=0.0
% INFO    : Bus 3120	: V=1.0231904, theta=-50.68164 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=1.0131802, theta=-16.426052 -> V=1.0, theta=0.0
% INFO    : Bus 3122	: V=1.0, theta=-7.550604 -> V=1.0, theta=0.0
% INFO    : Bus 3123	: V=0.992523, theta=-57.214879 -> V=1.0, theta=0.0
% INFO    : Bus 3124	: V=1.02, theta=-60.021115 -> V=1.0, theta=0.0
% INFO    : Bus 3125	: V=1.0038304, theta=-37.687886 -> V=1.0, theta=0.0
% INFO    : Bus 3126	: V=1.02, theta=-57.577916 -> V=1.0, theta=0.0
% INFO    : Bus 3127	: V=1.0148025, theta=-16.483385 -> V=1.0, theta=0.0
% INFO    : Bus 3128	: V=1.0066934, theta=-18.075987 -> V=1.0, theta=0.0
% INFO    : Bus 3129	: V=1.0204972, theta=-16.897979 -> V=1.0, theta=0.0
% INFO    : Bus 3130	: V=1.0025904, theta=-19.10825 -> V=1.0, theta=0.0
% INFO    : Bus 3131	: V=1.0175503, theta=-22.172623 -> V=1.0, theta=0.0
% INFO    : Bus 3132	: V=0.9910961, theta=-40.363964 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=1.0165218, theta=-22.12467 -> V=1.0, theta=0.0
% INFO    : Bus 3134	: V=1.0159936, theta=-22.900335 -> V=1.0, theta=0.0
% INFO    : Bus 3135	: V=1.0073827, theta=-19.339517 -> V=1.0, theta=0.0
% INFO    : Bus 3136	: V=1.0013606, theta=-15.648669 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=1.0171566, theta=-23.627709 -> V=1.0, theta=0.0
% INFO    : Bus 3138	: V=1.0098204, theta=-39.150745 -> V=1.0, theta=0.0
% INFO    : Bus 3139	: V=0.9882783, theta=-29.678592 -> V=1.0, theta=0.0
% INFO    : Bus 3140	: V=0.9931273, theta=-30.103057 -> V=1.0, theta=0.0
% INFO    : Bus 3141	: V=1.0157242, theta=-17.828457 -> V=1.0, theta=0.0
% INFO    : Bus 3142	: V=1.0183086, theta=-40.345005 -> V=1.0, theta=0.0
% INFO    : Bus 3143	: V=1.0000361, theta=-38.881057 -> V=1.0, theta=0.0
% INFO    : Bus 3144	: V=0.9940359, theta=-39.807665 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=1.0049354, theta=-23.759681 -> V=1.0, theta=0.0
% INFO    : Bus 3146	: V=1.0165387, theta=-35.68992 -> V=1.0, theta=0.0
% INFO    : Bus 3147	: V=1.02, theta=-56.13382 -> V=1.0, theta=0.0
% INFO    : Bus 4002	: V=1.0150866, theta=-53.25442 -> V=1.0, theta=0.0
% INFO    : Bus 4003	: V=0.9953162, theta=-72.588868 -> V=1.0, theta=0.0
% INFO    : Bus 4004	: V=1.0174615, theta=-56.258627 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=1.0152602, theta=-60.471782 -> V=1.0, theta=0.0
% INFO    : Bus 4006	: V=1.0218593, theta=-55.75123 -> V=1.0, theta=0.0
% INFO    : Bus 4007	: V=0.9994315, theta=-73.182023 -> V=1.0, theta=0.0
% INFO    : Bus 4008	: V=0.9886254, theta=-55.039968 -> V=1.0, theta=0.0
% INFO    : Bus 4009	: V=1.0221857, theta=-46.738805 -> V=1.0, theta=0.0
% INFO    : Bus 4010	: V=1.03, theta=-43.89651 -> V=1.0, theta=0.0
% INFO    : Bus 4011	: V=1.0151829, theta=-57.738883 -> V=1.0, theta=0.0
% INFO    : Bus 4012	: V=1.0144721, theta=-69.422294 -> V=1.0, theta=0.0
% INFO    : Bus 4013	: V=1.0012721, theta=-71.685477 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=1.0166327, theta=-53.200432 -> V=1.0, theta=0.0
% INFO    : Bus 4015	: V=1.02, theta=-54.698433 -> V=1.0, theta=0.0
% INFO    : Bus 4016	: V=1.0035259, theta=-50.350186 -> V=1.0, theta=0.0
% INFO    : Bus 4017	: V=1.0082429, theta=-48.630046 -> V=1.0, theta=0.0
% INFO    : Bus 4018	: V=0.9999583, theta=-47.432605 -> V=1.0, theta=0.0
% INFO    : Bus 4019	: V=0.9854058, theta=-67.650039 -> V=1.0, theta=0.0
% INFO    : Bus 4020	: V=0.9824545, theta=-50.499389 -> V=1.0, theta=0.0
% INFO    : Bus 4021	: V=0.9937482, theta=-66.959248 -> V=1.0, theta=0.0
% INFO    : Bus 4022	: V=1.0026665, theta=-59.942857 -> V=1.0, theta=0.0
% INFO    : Bus 4023	: V=1.0034572, theta=-52.491945 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=1.0170594, theta=-42.38539 -> V=1.0, theta=0.0
% INFO    : Bus 4025	: V=1.013294, theta=-46.293544 -> V=1.0, theta=0.0
% INFO    : Bus 4026	: V=1.03, theta=-34.943464 -> V=1.0, theta=0.0
% INFO    : Bus 4027	: V=1.0118439, theta=-73.200171 -> V=1.0, theta=0.0
% INFO    : Bus 4028	: V=1.0139851, theta=-33.929123 -> V=1.0, theta=0.0
% INFO    : Bus 4029	: V=1.013593, theta=-35.899201 -> V=1.0, theta=0.0
% INFO    : Bus 4030	: V=1.01, theta=-30.532262 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=1.017365, theta=-57.989348 -> V=1.0, theta=0.0
% INFO    : Bus 4032	: V=0.9801593, theta=-55.258857 -> V=1.0, theta=0.0
% INFO    : Bus 4033	: V=1.0019671, theta=-59.036823 -> V=1.0, theta=0.0
% INFO    : Bus 4034	: V=0.999186, theta=-71.648315 -> V=1.0, theta=0.0
% INFO    : Bus 4035	: V=0.9849779, theta=-48.942528 -> V=1.0, theta=0.0
% INFO    : Bus 4036	: V=0.991126, theta=-55.745898 -> V=1.0, theta=0.0
% INFO    : Bus 4037	: V=1.0085001, theta=-49.34612 -> V=1.0, theta=0.0
% INFO    : Bus 4038	: V=0.9915965, theta=-48.698232 -> V=1.0, theta=0.0
% INFO    : Bus 4039	: V=1.0118192, theta=-61.34303 -> V=1.0, theta=0.0
% INFO    : Bus 4040	: V=1.02, theta=-64.962558 -> V=1.0, theta=0.0
% INFO    : Bus 4041	: V=1.0042423, theta=-65.905051 -> V=1.0, theta=0.0
% INFO    : Bus 4042	: V=1.0097818, theta=-71.139773 -> V=1.0, theta=0.0
% INFO    : Bus 4043	: V=1.0108197, theta=-58.17846 -> V=1.0, theta=0.0
% INFO    : Bus 4044	: V=1.0133873, theta=-56.903558 -> V=1.0, theta=0.0
% INFO    : Bus 4045	: V=1.02, theta=-48.525449 -> V=1.0, theta=0.0
% INFO    : Bus 4046	: V=1.02, theta=-53.028412 -> V=1.0, theta=0.0
% INFO    : Bus 4047	: V=1.02, theta=-55.526981 -> V=1.0, theta=0.0
% INFO    : Bus 4048	: V=0.999781, theta=-66.471509 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=1.004468, theta=-60.64223 -> V=1.0, theta=0.0
% INFO    : Bus 4050	: V=1.0, theta=-57.218408 -> V=1.0, theta=0.0
% INFO    : Bus 4051	: V=0.9830021, theta=-54.697028 -> V=1.0, theta=0.0
% INFO    : Bus 4052	: V=1.019367, theta=-50.491538 -> V=1.0, theta=0.0
% INFO    : Bus 4053	: V=1.0124327, theta=-50.681833 -> V=1.0, theta=0.0
% INFO    : Bus 4054	: V=0.9999935, theta=-49.140342 -> V=1.0, theta=0.0
% INFO    : Bus 4055	: V=0.9882786, theta=-47.779043 -> V=1.0, theta=0.0
% INFO    : Bus 4056	: V=1.0197263, theta=-39.172142 -> V=1.0, theta=0.0
% INFO    : Bus 4057	: V=1.0009379, theta=-44.655429 -> V=1.0, theta=0.0
% INFO    : Bus 4058	: V=1.03, theta=-36.015071 -> V=1.0, theta=0.0
% INFO    : Bus 4059	: V=1.03, theta=-36.929282 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=1.03, theta=-33.469023 -> V=1.0, theta=0.0
% INFO    : Bus 4061	: V=1.03, theta=-34.518886 -> V=1.0, theta=0.0
% INFO    : Bus 4062	: V=1.03, theta=-32.453909 -> V=1.0, theta=0.0
% INFO    : Bus 4063	: V=1.03, theta=-35.20287 -> V=1.0, theta=0.0
% INFO    : Bus 4064	: V=0.99297, theta=-48.15766 -> V=1.0, theta=0.0
% INFO    : Bus 4065	: V=1.02, theta=-43.148107 -> V=1.0, theta=0.0
% INFO    : Bus 4066	: V=1.0118625, theta=-73.748469 -> V=1.0, theta=0.0
% INFO    : Bus 4067	: V=0.9876811, theta=-64.761386 -> V=1.0, theta=0.0
% INFO    : Bus 4068	: V=1.0018135, theta=-73.14954 -> V=1.0, theta=0.0
% INFO    : Bus 4069	: V=0.9937521, theta=-48.021948 -> V=1.0, theta=0.0
% INFO    : Bus 4070	: V=1.0130314, theta=-51.566956 -> V=1.0, theta=0.0
% INFO    : Bus 4071	: V=0.995135, theta=-56.055373 -> V=1.0, theta=0.0
% INFO    : Bus 4072	: V=0.9947355, theta=-47.711152 -> V=1.0, theta=0.0
% INFO    : Bus 4073	: V=1.0115984, theta=-61.536012 -> V=1.0, theta=0.0
% INFO    : Bus 4074	: V=1.0182823, theta=-64.090802 -> V=1.0, theta=0.0
% INFO    : Bus 4075	: V=1.0115984, theta=-61.536012 -> V=1.0, theta=0.0
% INFO    : Bus 4076	: V=1.03, theta=-55.760267 -> V=1.0, theta=0.0
% INFO    : Bus 4077	: V=1.03, theta=-57.916656 -> V=1.0, theta=0.0
% INFO    : Bus 4078	: V=0.9855115, theta=-48.23115 -> V=1.0, theta=0.0
% INFO    : Bus 4079	: V=1.0072798, theta=-68.026211 -> V=1.0, theta=0.0
% INFO    : Bus 4080	: V=1.0282361, theta=-44.302914 -> V=1.0, theta=0.0
% INFO    : Bus 4081	: V=1.0133673, theta=-47.764069 -> V=1.0, theta=0.0
% INFO    : Bus 4082	: V=1.04, theta=-37.738175 -> V=1.0, theta=0.0
% INFO    : Bus 4083	: V=1.04, theta=-38.257771 -> V=1.0, theta=0.0
% INFO    : Bus 4084	: V=1.04, theta=-41.011239 -> V=1.0, theta=0.0
% INFO    : Bus 4085	: V=1.04, theta=-42.359185 -> V=1.0, theta=0.0
% INFO    : Bus 4086	: V=1.02, theta=-61.302781 -> V=1.0, theta=0.0
% INFO    : Bus 4087	: V=1.0149695, theta=-49.305226 -> V=1.0, theta=0.0
% INFO    : Bus 4088	: V=1.02, theta=-72.875457 -> V=1.0, theta=0.0
% INFO    : Bus 4089	: V=1.0022485, theta=-64.747037 -> V=1.0, theta=0.0
% INFO    : Bus 4090	: V=1.0022485, theta=-64.747037 -> V=1.0, theta=0.0
% INFO    : Bus 4091	: V=1.01, theta=-62.098031 -> V=1.0, theta=0.0
% INFO    : Bus 4092	: V=1.0022485, theta=-64.747037 -> V=1.0, theta=0.0
% INFO    : Bus 4093	: V=1.01, theta=-60.924596 -> V=1.0, theta=0.0
% INFO    : Bus 4094	: V=1.01, theta=-63.301481 -> V=1.0, theta=0.0
% INFO    : Bus 4095	: V=1.01, theta=-61.812281 -> V=1.0, theta=0.0
% INFO    : Bus 4096	: V=1.0022485, theta=-64.747037 -> V=1.0, theta=0.0
% INFO    : Bus 4097	: V=1.01, theta=-61.419655 -> V=1.0, theta=0.0
% INFO    : Bus 4098	: V=1.0022485, theta=-64.747037 -> V=1.0, theta=0.0
% INFO    : Bus 4099	: V=0.9920806, theta=-50.159937 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=0.9923566, theta=-47.608662 -> V=1.0, theta=0.0
% INFO    : Bus 4101	: V=0.9993778, theta=-58.884792 -> V=1.0, theta=0.0
% INFO    : Bus 4102	: V=1.0038421, theta=-58.882738 -> V=1.0, theta=0.0
% INFO    : Bus 4103	: V=1.004882, theta=-74.23801 -> V=1.0, theta=0.0
% INFO    : Bus 4104	: V=0.9976876, theta=-46.690048 -> V=1.0, theta=0.0
% INFO    : Bus 4105	: V=1.01, theta=-43.311953 -> V=1.0, theta=0.0
% INFO    : Bus 4106	: V=0.9964684, theta=-58.201038 -> V=1.0, theta=0.0
% INFO    : Bus 4107	: V=1.0073043, theta=-72.660762 -> V=1.0, theta=0.0
% INFO    : Bus 4108	: V=0.9980118, theta=-45.215826 -> V=1.0, theta=0.0
% INFO    : Bus 4109	: V=0.9822351, theta=-49.95144 -> V=1.0, theta=0.0
% INFO    : Bus 4110	: V=1.0031488, theta=-63.107453 -> V=1.0, theta=0.0
% INFO    : Bus 4111	: V=0.9848204, theta=-67.349875 -> V=1.0, theta=0.0
% INFO    : Bus 4112	: V=1.0098694, theta=-54.663217 -> V=1.0, theta=0.0
% INFO    : Bus 4113	: V=1.0216271, theta=-55.738632 -> V=1.0, theta=0.0
% INFO    : Bus 4114	: V=1.0116506, theta=-57.926734 -> V=1.0, theta=0.0
% INFO    : Bus 4115	: V=1.04, theta=-51.925268 -> V=1.0, theta=0.0
% INFO    : Bus 4116	: V=1.04, theta=-51.970916 -> V=1.0, theta=0.0
% INFO    : Bus 4117	: V=1.0092417, theta=-48.036754 -> V=1.0, theta=0.0
% INFO    : Bus 4118	: V=0.9821868, theta=-56.409922 -> V=1.0, theta=0.0
% INFO    : Bus 4119	: V=1.0085597, theta=-58.1532 -> V=1.0, theta=0.0
% INFO    : Bus 4120	: V=0.9889244, theta=-47.922079 -> V=1.0, theta=0.0
% INFO    : Bus 4121	: V=1.0103282, theta=-68.810858 -> V=1.0, theta=0.0
% INFO    : Bus 4122	: V=1.0068724, theta=-71.892262 -> V=1.0, theta=0.0
% INFO    : Bus 4123	: V=0.9885219, theta=-50.068629 -> V=1.0, theta=0.0
% INFO    : Bus 4124	: V=0.9927773, theta=-62.572249 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=0.9924637, theta=-46.260047 -> V=1.0, theta=0.0
% INFO    : Bus 4126	: V=1.0041991, theta=-56.484022 -> V=1.0, theta=0.0
% INFO    : Bus 4127	: V=0.9988259, theta=-58.181454 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=0.9957573, theta=-69.675533 -> V=1.0, theta=0.0
% INFO    : Bus 4129	: V=1.0247231, theta=-56.325496 -> V=1.0, theta=0.0
% INFO    : Bus 4130	: V=1.02, theta=-57.775884 -> V=1.0, theta=0.0
% INFO    : Bus 4131	: V=1.02, theta=-50.629744 -> V=1.0, theta=0.0
% INFO    : Bus 4132	: V=1.0180104, theta=-51.568094 -> V=1.0, theta=0.0
% INFO    : Bus 4133	: V=1.02, theta=-50.629744 -> V=1.0, theta=0.0
% INFO    : Bus 4134	: V=1.0146714, theta=-49.792392 -> V=1.0, theta=0.0
% INFO    : Bus 4135	: V=1.0150672, theta=-49.831406 -> V=1.0, theta=0.0
% INFO    : Bus 4136	: V=1.0133706, theta=-49.58127 -> V=1.0, theta=0.0
% INFO    : Bus 4137	: V=1.02, theta=-50.629744 -> V=1.0, theta=0.0
% INFO    : Bus 4138	: V=1.02, theta=-50.629744 -> V=1.0, theta=0.0
% INFO    : Bus 4139	: V=0.9828805, theta=-54.805601 -> V=1.0, theta=0.0
% INFO    : Bus 4140	: V=1.0284504, theta=-48.735268 -> V=1.0, theta=0.0
% INFO    : Bus 4141	: V=1.02, theta=-51.913309 -> V=1.0, theta=0.0
% INFO    : Bus 4142	: V=1.0392398, theta=-46.638291 -> V=1.0, theta=0.0
% INFO    : Bus 4143	: V=1.0014347, theta=-54.199628 -> V=1.0, theta=0.0
% INFO    : Bus 4144	: V=0.9846782, theta=-56.116972 -> V=1.0, theta=0.0
% INFO    : Bus 4145	: V=0.9925058, theta=-46.723511 -> V=1.0, theta=0.0
% INFO    : Bus 4146	: V=1.0214046, theta=-55.90079 -> V=1.0, theta=0.0
% INFO    : Bus 4147	: V=1.02, theta=-57.744443 -> V=1.0, theta=0.0
% INFO    : Bus 4148	: V=0.98881, theta=-57.961671 -> V=1.0, theta=0.0
% INFO    : Bus 4149	: V=0.9939825, theta=-45.086022 -> V=1.0, theta=0.0
% INFO    : Bus 4150	: V=0.9883994, theta=-48.598934 -> V=1.0, theta=0.0
% INFO    : Bus 4151	: V=1.0228111, theta=-49.969081 -> V=1.0, theta=0.0
% INFO    : Bus 4152	: V=1.018349, theta=-48.544303 -> V=1.0, theta=0.0
% INFO    : Bus 4153	: V=1.0329325, theta=-48.131552 -> V=1.0, theta=0.0
% INFO    : Bus 4154	: V=0.9967079, theta=-67.892963 -> V=1.0, theta=0.0
% INFO    : Bus 4155	: V=1.0018169, theta=-65.794833 -> V=1.0, theta=0.0
% INFO    : Bus 4156	: V=0.9917195, theta=-49.550614 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.0039692, theta=-70.332688 -> V=1.0, theta=0.0
% INFO    : Bus 4158	: V=1.0140282, theta=-42.173247 -> V=1.0, theta=0.0
% INFO    : Bus 4159	: V=0.9989053, theta=-46.393269 -> V=1.0, theta=0.0
% INFO    : Bus 4160	: V=1.03, theta=-39.572965 -> V=1.0, theta=0.0
% INFO    : Bus 4161	: V=1.03, theta=-39.330103 -> V=1.0, theta=0.0
% INFO    : Bus 4162	: V=1.03, theta=-38.581804 -> V=1.0, theta=0.0
% INFO    : Bus 4163	: V=1.0140282, theta=-42.173247 -> V=1.0, theta=0.0
% INFO    : Bus 4164	: V=1.0019971, theta=-64.771365 -> V=1.0, theta=0.0
% INFO    : Bus 4165	: V=1.0209679, theta=-46.52214 -> V=1.0, theta=0.0
% INFO    : Bus 4166	: V=1.0070147, theta=-42.634669 -> V=1.0, theta=0.0
% INFO    : Bus 4167	: V=0.9945078, theta=-68.007046 -> V=1.0, theta=0.0
% INFO    : Bus 4168	: V=0.9973913, theta=-46.704142 -> V=1.0, theta=0.0
% INFO    : Bus 4169	: V=0.9870834, theta=-52.22943 -> V=1.0, theta=0.0
% INFO    : Bus 4170	: V=0.9886613, theta=-46.962951 -> V=1.0, theta=0.0
% INFO    : Bus 4171	: V=1.0092521, theta=-62.492743 -> V=1.0, theta=0.0
% INFO    : Bus 4172	: V=1.0020348, theta=-50.905923 -> V=1.0, theta=0.0
% INFO    : Bus 4173	: V=0.9984828, theta=-40.644489 -> V=1.0, theta=0.0
% INFO    : Bus 4174	: V=1.0126731, theta=-57.738859 -> V=1.0, theta=0.0
% INFO    : Bus 4175	: V=1.02, theta=-56.22585 -> V=1.0, theta=0.0
% INFO    : Bus 4176	: V=1.034496, theta=-52.807237 -> V=1.0, theta=0.0
% INFO    : Bus 4177	: V=1.04, theta=-49.439583 -> V=1.0, theta=0.0
% INFO    : Bus 4178	: V=1.02, theta=-46.812409 -> V=1.0, theta=0.0
% INFO    : Bus 4179	: V=1.0067454, theta=-58.432107 -> V=1.0, theta=0.0
% INFO    : Bus 4180	: V=0.9864044, theta=-48.01862 -> V=1.0, theta=0.0
% INFO    : Bus 4181	: V=1.022373, theta=-39.371145 -> V=1.0, theta=0.0
% INFO    : Bus 4182	: V=1.002904, theta=-43.431028 -> V=1.0, theta=0.0
% INFO    : Bus 4183	: V=1.0170732, theta=-49.910218 -> V=1.0, theta=0.0
% INFO    : Bus 4184	: V=1.0035301, theta=-57.692272 -> V=1.0, theta=0.0
% INFO    : Bus 4185	: V=1.0167208, theta=-58.881248 -> V=1.0, theta=0.0
% INFO    : Bus 4186	: V=0.9972866, theta=-69.364133 -> V=1.0, theta=0.0
% INFO    : Bus 4187	: V=0.992393, theta=-59.111382 -> V=1.0, theta=0.0
% INFO    : Bus 4188	: V=1.0224832, theta=-53.386837 -> V=1.0, theta=0.0
% INFO    : Bus 4189	: V=0.9879807, theta=-57.016369 -> V=1.0, theta=0.0
% INFO    : Bus 4190	: V=1.0055584, theta=-58.682221 -> V=1.0, theta=0.0
% INFO    : Bus 4191	: V=1.0004634, theta=-55.834697 -> V=1.0, theta=0.0
% INFO    : Bus 4192	: V=1.02, theta=-50.725959 -> V=1.0, theta=0.0
% INFO    : Bus 4193	: V=1.012689, theta=-53.473848 -> V=1.0, theta=0.0
% INFO    : Bus 4194	: V=0.9994659, theta=-61.602117 -> V=1.0, theta=0.0
% INFO    : Bus 4195	: V=1.0305723, theta=-51.459012 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=1.0281583, theta=-52.957769 -> V=1.0, theta=0.0
% INFO    : Bus 4197	: V=1.023493, theta=-54.957405 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=0.9881979, theta=-70.877461 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=0.9866893, theta=-63.624837 -> V=1.0, theta=0.0
% INFO    : Bus 5005	: V=1.0093481, theta=-55.202858 -> V=1.0, theta=0.0
% INFO    : Bus 5006	: V=0.9938726, theta=-70.413557 -> V=1.0, theta=0.0
% INFO    : Bus 5007	: V=0.9935528, theta=-66.108374 -> V=1.0, theta=0.0
% INFO    : Bus 5008	: V=1.0061407, theta=-43.584492 -> V=1.0, theta=0.0
% INFO    : Bus 5009	: V=0.9958585, theta=-71.667254 -> V=1.0, theta=0.0
% INFO    : Bus 5010	: V=0.995436, theta=-69.630466 -> V=1.0, theta=0.0
% INFO    : Bus 5011	: V=1.0035773, theta=-55.469556 -> V=1.0, theta=0.0
% INFO    : Bus 5012	: V=0.9913186, theta=-66.588772 -> V=1.0, theta=0.0
% INFO    : Bus 5013	: V=1.02, theta=-51.51441 -> V=1.0, theta=0.0
% INFO    : Bus 5014	: V=0.9945227, theta=-62.796069 -> V=1.0, theta=0.0
% INFO    : Bus 5015	: V=1.0031861, theta=-61.564671 -> V=1.0, theta=0.0
% INFO    : Bus 5016	: V=1.0013037, theta=-66.191412 -> V=1.0, theta=0.0
% INFO    : Bus 5017	: V=0.9912948, theta=-67.458749 -> V=1.0, theta=0.0
% INFO    : Bus 5018	: V=1.0040797, theta=-48.691906 -> V=1.0, theta=0.0
% INFO    : Bus 5019	: V=1.0014802, theta=-50.447919 -> V=1.0, theta=0.0
% INFO    : Bus 5020	: V=1.0, theta=-46.981377 -> V=1.0, theta=0.0
% INFO    : Bus 5021	: V=1.000305, theta=-59.459441 -> V=1.0, theta=0.0
% INFO    : Bus 5022	: V=0.9976124, theta=-63.185817 -> V=1.0, theta=0.0
% INFO    : Bus 5023	: V=1.000305, theta=-59.459441 -> V=1.0, theta=0.0
% INFO    : Bus 5024	: V=1.0025643, theta=-55.893326 -> V=1.0, theta=0.0
% INFO    : Bus 5025	: V=0.9947174, theta=-62.513049 -> V=1.0, theta=0.0
% INFO    : Bus 5026	: V=0.9896091, theta=-67.694085 -> V=1.0, theta=0.0
% INFO    : Bus 5027	: V=0.9929789, theta=-68.554695 -> V=1.0, theta=0.0
% INFO    : Bus 5028	: V=0.9979943, theta=-68.658914 -> V=1.0, theta=0.0
% INFO    : Bus 5029	: V=1.0010118, theta=-54.814168 -> V=1.0, theta=0.0
% INFO    : Bus 5030	: V=0.9898628, theta=-66.293625 -> V=1.0, theta=0.0
% INFO    : Bus 5031	: V=1.0019907, theta=-66.736039 -> V=1.0, theta=0.0
% INFO    : Bus 5032	: V=0.9920347, theta=-69.807997 -> V=1.0, theta=0.0
% INFO    : Bus 5033	: V=1.0108272, theta=-63.990366 -> V=1.0, theta=0.0
% INFO    : Bus 5034	: V=1.0045242, theta=-66.208417 -> V=1.0, theta=0.0
% INFO    : Bus 5035	: V=1.0108272, theta=-63.990366 -> V=1.0, theta=0.0
% INFO    : Bus 5036	: V=1.0108272, theta=-63.990366 -> V=1.0, theta=0.0
% INFO    : Bus 5037	: V=1.02, theta=-63.363294 -> V=1.0, theta=0.0
% INFO    : Bus 5038	: V=1.02, theta=-63.341972 -> V=1.0, theta=0.0
% INFO    : Bus 5039	: V=1.0193907, theta=-63.709639 -> V=1.0, theta=0.0
% INFO    : Bus 5040	: V=1.02, theta=-63.144114 -> V=1.0, theta=0.0
% INFO    : Bus 5041	: V=1.02, theta=-63.404899 -> V=1.0, theta=0.0
% INFO    : Bus 5042	: V=1.02, theta=-63.294734 -> V=1.0, theta=0.0
% INFO    : Bus 5043	: V=0.9849512, theta=-69.76912 -> V=1.0, theta=0.0
% INFO    : Bus 5044	: V=0.99624, theta=-63.170031 -> V=1.0, theta=0.0
% INFO    : Bus 5045	: V=1.0101953, theta=-48.990173 -> V=1.0, theta=0.0
% INFO    : Bus 5046	: V=1.0076662, theta=-51.030472 -> V=1.0, theta=0.0
% INFO    : Bus 5047	: V=1.008209, theta=-59.913277 -> V=1.0, theta=0.0
% INFO    : Bus 5048	: V=0.9961088, theta=-64.259438 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=1.0061526, theta=-59.97429 -> V=1.0, theta=0.0
% INFO    : Bus 5050	: V=1.0022885, theta=-64.457261 -> V=1.0, theta=0.0
% INFO    : Bus 5051	: V=1.01321, theta=-59.204881 -> V=1.0, theta=0.0
% INFO    : Bus 5052	: V=1.0040685, theta=-63.170691 -> V=1.0, theta=0.0
% INFO    : Bus 5053	: V=0.988509, theta=-69.590178 -> V=1.0, theta=0.0
% INFO    : Bus 5054	: V=0.9939944, theta=-57.448254 -> V=1.0, theta=0.0
% INFO    : Bus 5055	: V=1.0028488, theta=-50.212442 -> V=1.0, theta=0.0
% INFO    : Bus 5056	: V=1.0013891, theta=-51.068301 -> V=1.0, theta=0.0
% INFO    : Bus 5057	: V=1.0028488, theta=-50.212442 -> V=1.0, theta=0.0
% INFO    : Bus 5058	: V=1.0, theta=-47.442478 -> V=1.0, theta=0.0
% INFO    : Bus 5059	: V=0.9954944, theta=-64.250557 -> V=1.0, theta=0.0
% INFO    : Bus 5060	: V=0.9983701, theta=-66.61182 -> V=1.0, theta=0.0
% INFO    : Bus 5061	: V=1.02, theta=-69.97037 -> V=1.0, theta=0.0
% INFO    : Bus 5062	: V=0.9916922, theta=-74.340444 -> V=1.0, theta=0.0
% INFO    : Bus 5063	: V=1.0102842, theta=-62.188112 -> V=1.0, theta=0.0
% INFO    : Bus 5064	: V=1.0014714, theta=-66.397616 -> V=1.0, theta=0.0
% INFO    : Bus 5065	: V=1.0112453, theta=-62.084891 -> V=1.0, theta=0.0
% INFO    : Bus 5066	: V=1.0102842, theta=-62.188112 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=1.03, theta=-59.6097 -> V=1.0, theta=0.0
% INFO    : Bus 5068	: V=1.03, theta=-59.485033 -> V=1.0, theta=0.0
% INFO    : Bus 5069	: V=1.03, theta=-59.314316 -> V=1.0, theta=0.0
% INFO    : Bus 5070	: V=0.9904136, theta=-70.297001 -> V=1.0, theta=0.0
% INFO    : Bus 5071	: V=1.009716, theta=-54.850173 -> V=1.0, theta=0.0
% INFO    : Bus 5072	: V=0.9937663, theta=-69.873004 -> V=1.0, theta=0.0
% INFO    : Bus 5073	: V=1.0174034, theta=-46.702322 -> V=1.0, theta=0.0
% INFO    : Bus 5074	: V=0.9954315, theta=-69.57021 -> V=1.0, theta=0.0
% INFO    : Bus 5075	: V=1.0023458, theta=-56.953983 -> V=1.0, theta=0.0
% INFO    : Bus 5076	: V=1.0003492, theta=-71.668567 -> V=1.0, theta=0.0
% INFO    : Bus 5077	: V=1.02, theta=-72.655727 -> V=1.0, theta=0.0
% INFO    : Bus 5078	: V=0.9891633, theta=-66.892194 -> V=1.0, theta=0.0
% INFO    : Bus 5079	: V=1.0135063, theta=-56.311754 -> V=1.0, theta=0.0
% INFO    : Bus 5080	: V=0.9947927, theta=-57.204626 -> V=1.0, theta=0.0
% INFO    : Bus 5081	: V=0.9998592, theta=-55.861695 -> V=1.0, theta=0.0
% INFO    : Bus 5082	: V=0.9947262, theta=-69.665281 -> V=1.0, theta=0.0
% INFO    : Bus 5083	: V=1.0090512, theta=-63.680084 -> V=1.0, theta=0.0
% INFO    : Bus 5084	: V=0.994379, theta=-67.977407 -> V=1.0, theta=0.0
% INFO    : Bus 5085	: V=0.9881085, theta=-69.837505 -> V=1.0, theta=0.0
% INFO    : Bus 5086	: V=0.9889081, theta=-69.240985 -> V=1.0, theta=0.0
% INFO    : Bus 5087	: V=0.9906554, theta=-63.829471 -> V=1.0, theta=0.0
% INFO    : Bus 5088	: V=0.9974456, theta=-59.156058 -> V=1.0, theta=0.0
% INFO    : Bus 5089	: V=0.9974456, theta=-59.156058 -> V=1.0, theta=0.0
% INFO    : Bus 5090	: V=0.9972223, theta=-71.06439 -> V=1.0, theta=0.0
% INFO    : Bus 5091	: V=0.9906147, theta=-63.229588 -> V=1.0, theta=0.0
% INFO    : Bus 5092	: V=0.9924315, theta=-67.146668 -> V=1.0, theta=0.0
% INFO    : Bus 5093	: V=1.0055571, theta=-67.669604 -> V=1.0, theta=0.0
% INFO    : Bus 5094	: V=1.0074121, theta=-61.042774 -> V=1.0, theta=0.0
% INFO    : Bus 5095	: V=1.0021916, theta=-69.576129 -> V=1.0, theta=0.0
% INFO    : Bus 5096	: V=0.9960835, theta=-68.670092 -> V=1.0, theta=0.0
% INFO    : Bus 5097	: V=0.997885, theta=-68.007142 -> V=1.0, theta=0.0
% INFO    : Bus 5098	: V=1.0115393, theta=-68.853435 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=1.02, theta=-69.8461 -> V=1.0, theta=0.0
% INFO    : Bus 5100	: V=0.9958114, theta=-69.428968 -> V=1.0, theta=0.0
% INFO    : Bus 5101	: V=1.0144915, theta=-52.696875 -> V=1.0, theta=0.0
% INFO    : Bus 5102	: V=1.0044233, theta=-64.722692 -> V=1.0, theta=0.0
% INFO    : Bus 5103	: V=0.9948101, theta=-69.010093 -> V=1.0, theta=0.0
% INFO    : Bus 5104	: V=0.9889341, theta=-67.209662 -> V=1.0, theta=0.0
% INFO    : Bus 5105	: V=0.9941778, theta=-70.710651 -> V=1.0, theta=0.0
% INFO    : Bus 5106	: V=0.9941778, theta=-70.710651 -> V=1.0, theta=0.0
% INFO    : Bus 5107	: V=0.9941778, theta=-70.710651 -> V=1.0, theta=0.0
% INFO    : Bus 5108	: V=1.0109548, theta=-68.307063 -> V=1.0, theta=0.0
% INFO    : Bus 5109	: V=0.9854655, theta=-69.200746 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=0.9880366, theta=-54.507333 -> V=1.0, theta=0.0
% INFO    : Bus 5111	: V=0.9934501, theta=-71.108891 -> V=1.0, theta=0.0
% INFO    : Bus 5112	: V=1.0092249, theta=-56.070872 -> V=1.0, theta=0.0
% INFO    : Bus 5113	: V=0.998664, theta=-67.755705 -> V=1.0, theta=0.0
% INFO    : Bus 5114	: V=0.9899661, theta=-69.181123 -> V=1.0, theta=0.0
% INFO    : Bus 5115	: V=1.0106333, theta=-67.203942 -> V=1.0, theta=0.0
% INFO    : Bus 5116	: V=0.9925265, theta=-70.500099 -> V=1.0, theta=0.0
% INFO    : Bus 5117	: V=0.984546, theta=-69.211167 -> V=1.0, theta=0.0
% INFO    : Bus 5118	: V=1.0053914, theta=-44.907048 -> V=1.0, theta=0.0
% INFO    : Bus 5119	: V=1.0007521, theta=-56.263513 -> V=1.0, theta=0.0
% INFO    : Bus 5120	: V=1.0237229, theta=-46.788066 -> V=1.0, theta=0.0
% INFO    : Bus 5121	: V=1.0191014, theta=-47.410149 -> V=1.0, theta=0.0
% INFO    : Bus 5122	: V=0.9931224, theta=-70.817338 -> V=1.0, theta=0.0
% INFO    : Bus 5123	: V=1.0052716, theta=-52.824385 -> V=1.0, theta=0.0
% INFO    : Bus 5124	: V=1.0023328, theta=-51.872428 -> V=1.0, theta=0.0
% INFO    : Bus 5125	: V=0.9988884, theta=-67.350088 -> V=1.0, theta=0.0
% INFO    : Bus 5126	: V=0.9878538, theta=-71.357811 -> V=1.0, theta=0.0
% INFO    : Bus 5127	: V=1.0106436, theta=-56.343168 -> V=1.0, theta=0.0
% INFO    : Bus 5128	: V=0.9909872, theta=-70.588514 -> V=1.0, theta=0.0
% INFO    : Bus 5129	: V=1.0222101, theta=-51.178908 -> V=1.0, theta=0.0
% INFO    : Bus 5130	: V=0.990531, theta=-69.549916 -> V=1.0, theta=0.0
% INFO    : Bus 5131	: V=1.0207407, theta=-50.671252 -> V=1.0, theta=0.0
% INFO    : Bus 5132	: V=1.0130469, theta=-52.90339 -> V=1.0, theta=0.0
% INFO    : Bus 5133	: V=1.0084332, theta=-55.652426 -> V=1.0, theta=0.0
% INFO    : Bus 5134	: V=1.0013979, theta=-47.731605 -> V=1.0, theta=0.0
% INFO    : Bus 5135	: V=1.0115574, theta=-52.920916 -> V=1.0, theta=0.0
% INFO    : Bus 5136	: V=0.9939977, theta=-63.065891 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=1.0157223, theta=-54.220468 -> V=1.0, theta=0.0
% INFO    : Bus 5138	: V=1.0130897, theta=-55.52338 -> V=1.0, theta=0.0
% INFO    : Bus 5139	: V=1.0076491, theta=-71.895508 -> V=1.0, theta=0.0
% INFO    : Bus 5140	: V=1.0008337, theta=-56.346643 -> V=1.0, theta=0.0
% INFO    : Bus 5141	: V=0.9951554, theta=-67.006122 -> V=1.0, theta=0.0
% INFO    : Bus 5142	: V=0.9979037, theta=-56.117934 -> V=1.0, theta=0.0
% INFO    : Bus 5143	: V=0.9984353, theta=-67.180754 -> V=1.0, theta=0.0
% INFO    : Bus 5144	: V=1.003407, theta=-56.489341 -> V=1.0, theta=0.0
% INFO    : Bus 5145	: V=0.996099, theta=-68.835575 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=0.9917877, theta=-69.31304 -> V=1.0, theta=0.0
% INFO    : Bus 5147	: V=0.9881179, theta=-70.864682 -> V=1.0, theta=0.0
% INFO    : Bus 5148	: V=0.9893839, theta=-70.871957 -> V=1.0, theta=0.0
% INFO    : Bus 5149	: V=0.9880698, theta=-71.258972 -> V=1.0, theta=0.0
% INFO    : Bus 5150	: V=0.9990052, theta=-54.803089 -> V=1.0, theta=0.0
% INFO    : Bus 5151	: V=1.0078566, theta=-57.79634 -> V=1.0, theta=0.0
% INFO    : Bus 5152	: V=0.990242, theta=-69.941317 -> V=1.0, theta=0.0
% INFO    : Bus 5153	: V=0.9970397, theta=-60.568036 -> V=1.0, theta=0.0
% INFO    : Bus 5154	: V=1.0004208, theta=-58.562682 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=1.0048598, theta=-50.002954 -> V=1.0, theta=0.0
% INFO    : Bus 5156	: V=1.015832, theta=-50.176534 -> V=1.0, theta=0.0
% INFO    : Bus 5157	: V=0.9853623, theta=-69.513923 -> V=1.0, theta=0.0
% INFO    : Bus 5158	: V=1.0115197, theta=-69.735688 -> V=1.0, theta=0.0
% INFO    : Bus 5159	: V=1.004983, theta=-53.298749 -> V=1.0, theta=0.0
% INFO    : Bus 5160	: V=0.9933777, theta=-66.07115 -> V=1.0, theta=0.0
% INFO    : Bus 5161	: V=1.0113745, theta=-71.192281 -> V=1.0, theta=0.0
% INFO    : Bus 5162	: V=0.9956451, theta=-58.513669 -> V=1.0, theta=0.0
% INFO    : Bus 5163	: V=1.0085389, theta=-54.142675 -> V=1.0, theta=0.0
% INFO    : Bus 5164	: V=1.0029498, theta=-62.326903 -> V=1.0, theta=0.0
% INFO    : Bus 5165	: V=0.9975683, theta=-65.367392 -> V=1.0, theta=0.0
% INFO    : Bus 5166	: V=1.0200715, theta=-60.421533 -> V=1.0, theta=0.0
% INFO    : Bus 5167	: V=1.0036964, theta=-62.24547 -> V=1.0, theta=0.0
% INFO    : Bus 5168	: V=0.9898585, theta=-71.760209 -> V=1.0, theta=0.0
% INFO    : Bus 5169	: V=1.0136162, theta=-52.93305 -> V=1.0, theta=0.0
% INFO    : Bus 5170	: V=1.0083788, theta=-51.265285 -> V=1.0, theta=0.0
% INFO    : Bus 5171	: V=0.9914893, theta=-62.444813 -> V=1.0, theta=0.0
% INFO    : Bus 5172	: V=1.0172388, theta=-65.266625 -> V=1.0, theta=0.0
% INFO    : Bus 5173	: V=0.9885457, theta=-69.794956 -> V=1.0, theta=0.0
% INFO    : Bus 5174	: V=0.9928004, theta=-61.393334 -> V=1.0, theta=0.0
% INFO    : Bus 5175	: V=0.9952244, theta=-66.652615 -> V=1.0, theta=0.0
% INFO    : Bus 5176	: V=0.9934871, theta=-52.675965 -> V=1.0, theta=0.0
% INFO    : Bus 5177	: V=0.9878311, theta=-68.999172 -> V=1.0, theta=0.0
% INFO    : Bus 5178	: V=0.9906539, theta=-70.18489 -> V=1.0, theta=0.0
% INFO    : Bus 5179	: V=1.0152782, theta=-57.725501 -> V=1.0, theta=0.0
% INFO    : Bus 5180	: V=1.0109085, theta=-59.233324 -> V=1.0, theta=0.0
% INFO    : Bus 5181	: V=0.9901721, theta=-70.639269 -> V=1.0, theta=0.0
% INFO    : Bus 5182	: V=1.0030223, theta=-56.018038 -> V=1.0, theta=0.0
% INFO    : Bus 5183	: V=0.9985697, theta=-71.803058 -> V=1.0, theta=0.0
% INFO    : Bus 5184	: V=0.9817172, theta=-70.318365 -> V=1.0, theta=0.0
% INFO    : Bus 5185	: V=0.9980377, theta=-65.727376 -> V=1.0, theta=0.0
% INFO    : Bus 5186	: V=0.9911411, theta=-66.827461 -> V=1.0, theta=0.0
% INFO    : Bus 5187	: V=0.9964081, theta=-50.286011 -> V=1.0, theta=0.0
% INFO    : Bus 5188	: V=0.98756, theta=-70.433991 -> V=1.0, theta=0.0
% INFO    : Bus 5189	: V=0.9960082, theta=-70.492888 -> V=1.0, theta=0.0
% INFO    : Bus 5190	: V=1.0006512, theta=-58.161375 -> V=1.0, theta=0.0
% INFO    : Bus 5191	: V=1.0143868, theta=-57.060828 -> V=1.0, theta=0.0
% INFO    : Bus 5192	: V=1.0166856, theta=-51.47506 -> V=1.0, theta=0.0
% INFO    : Bus 5193	: V=1.012502, theta=-52.783387 -> V=1.0, theta=0.0
% INFO    : Bus 5194	: V=0.994301, theta=-69.064496 -> V=1.0, theta=0.0
% INFO    : Bus 5195	: V=1.0032599, theta=-68.251629 -> V=1.0, theta=0.0
% INFO    : Bus 5196	: V=1.0023516, theta=-52.018675 -> V=1.0, theta=0.0
% INFO    : Bus 5197	: V=1.0006975, theta=-53.749548 -> V=1.0, theta=0.0
% INFO    : Bus 5198	: V=1.0000645, theta=-51.298819 -> V=1.0, theta=0.0
% INFO    : Bus 5199	: V=0.9919234, theta=-68.403767 -> V=1.0, theta=0.0
% INFO    : Bus 5200	: V=0.9840969, theta=-56.169192 -> V=1.0, theta=0.0
% INFO    : Bus 5201	: V=1.0030336, theta=-55.455558 -> V=1.0, theta=0.0
% INFO    : Bus 5202	: V=0.9972238, theta=-63.640557 -> V=1.0, theta=0.0
% INFO    : Bus 5203	: V=0.9882676, theta=-71.059797 -> V=1.0, theta=0.0
% INFO    : Bus 5204	: V=1.0032434, theta=-55.201692 -> V=1.0, theta=0.0
% INFO    : Bus 5205	: V=1.0021153, theta=-56.940899 -> V=1.0, theta=0.0
% INFO    : Bus 5206	: V=1.01, theta=-52.885387 -> V=1.0, theta=0.0
% INFO    : Bus 5207	: V=1.01, theta=-54.122298 -> V=1.0, theta=0.0
% INFO    : Bus 5208	: V=1.01, theta=-53.842047 -> V=1.0, theta=0.0
% INFO    : Bus 5209	: V=1.0046621, theta=-56.819978 -> V=1.0, theta=0.0
% INFO    : Bus 5210	: V=0.9953266, theta=-68.785269 -> V=1.0, theta=0.0
% INFO    : Bus 5211	: V=0.9954624, theta=-58.165686 -> V=1.0, theta=0.0
% INFO    : Bus 5212	: V=0.9834648, theta=-67.816501 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=0.9886971, theta=-70.546651 -> V=1.0, theta=0.0
% INFO    : Bus 5214	: V=0.990879, theta=-70.124515 -> V=1.0, theta=0.0
% INFO    : Bus 5215	: V=0.9918042, theta=-68.226667 -> V=1.0, theta=0.0
% INFO    : Bus 5216	: V=0.9901777, theta=-68.837676 -> V=1.0, theta=0.0
% INFO    : Bus 5217	: V=1.0110624, theta=-69.268979 -> V=1.0, theta=0.0
% INFO    : Bus 5218	: V=0.9944219, theta=-67.01754 -> V=1.0, theta=0.0
% INFO    : Bus 5219	: V=0.9992607, theta=-68.473102 -> V=1.0, theta=0.0
% INFO    : Bus 5220	: V=1.0009933, theta=-67.622565 -> V=1.0, theta=0.0
% INFO    : Bus 5221	: V=1.0013186, theta=-55.870598 -> V=1.0, theta=0.0
% INFO    : Bus 5222	: V=0.9873023, theta=-66.648052 -> V=1.0, theta=0.0
% INFO    : Bus 5223	: V=0.9901191, theta=-58.490171 -> V=1.0, theta=0.0
% INFO    : Bus 5224	: V=0.9948135, theta=-71.101059 -> V=1.0, theta=0.0
% INFO    : Bus 5225	: V=1.0092556, theta=-68.378674 -> V=1.0, theta=0.0
% INFO    : Bus 5226	: V=1.0207817, theta=-51.424521 -> V=1.0, theta=0.0
% INFO    : Bus 5227	: V=0.9947281, theta=-71.230162 -> V=1.0, theta=0.0
% INFO    : Bus 5228	: V=0.9960362, theta=-68.25067 -> V=1.0, theta=0.0
% INFO    : Bus 5229	: V=0.994304, theta=-69.709927 -> V=1.0, theta=0.0
% INFO    : Bus 5230	: V=0.9954517, theta=-70.738169 -> V=1.0, theta=0.0
% INFO    : Bus 5231	: V=1.0093757, theta=-54.690836 -> V=1.0, theta=0.0
% INFO    : Bus 5232	: V=0.994938, theta=-70.029683 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=0.9992942, theta=-69.536724 -> V=1.0, theta=0.0
% INFO    : Bus 5234	: V=0.9908375, theta=-68.266064 -> V=1.0, theta=0.0
% INFO    : Bus 5235	: V=1.0121651, theta=-54.217629 -> V=1.0, theta=0.0
% INFO    : Bus 5236	: V=1.0043724, theta=-45.721833 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=0.9981103, theta=-43.359574 -> V=1.0, theta=0.0
% INFO    : Bus 5238	: V=1.0013485, theta=-44.78055 -> V=1.0, theta=0.0
% INFO    : Bus 5239	: V=1.0276184, theta=-48.649124 -> V=1.0, theta=0.0
% INFO    : Bus 5240	: V=1.026799, theta=-50.459785 -> V=1.0, theta=0.0
% INFO    : Bus 5241	: V=1.0275998, theta=-51.980436 -> V=1.0, theta=0.0
% INFO    : Bus 5242	: V=1.0275998, theta=-51.980436 -> V=1.0, theta=0.0
% INFO    : Bus 5243	: V=1.0221367, theta=-47.047671 -> V=1.0, theta=0.0
% INFO    : Bus 5244	: V=0.9902426, theta=-68.017521 -> V=1.0, theta=0.0
% INFO    : Bus 5245	: V=0.9986181, theta=-70.826124 -> V=1.0, theta=0.0
% INFO    : Bus 5246	: V=1.0071175, theta=-55.940536 -> V=1.0, theta=0.0
% INFO    : Bus 5247	: V=1.0024753, theta=-57.68351 -> V=1.0, theta=0.0
% INFO    : Bus 5248	: V=0.993783, theta=-68.949705 -> V=1.0, theta=0.0
% INFO    : Bus 5249	: V=0.9917504, theta=-64.841875 -> V=1.0, theta=0.0
% INFO    : Bus 5250	: V=0.9988064, theta=-68.395572 -> V=1.0, theta=0.0
% INFO    : Bus 5251	: V=0.9940597, theta=-69.710371 -> V=1.0, theta=0.0
% INFO    : Bus 5252	: V=0.9909498, theta=-71.187609 -> V=1.0, theta=0.0
% INFO    : Bus 5253	: V=0.9887417, theta=-69.126776 -> V=1.0, theta=0.0
% INFO    : Bus 5254	: V=0.9956912, theta=-68.439377 -> V=1.0, theta=0.0
% INFO    : Bus 5255	: V=0.9888859, theta=-56.928679 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=0.9900291, theta=-65.038315 -> V=1.0, theta=0.0
% INFO    : Bus 5257	: V=0.9899441, theta=-64.388248 -> V=1.0, theta=0.0
% INFO    : Bus 5258	: V=0.9878673, theta=-70.006914 -> V=1.0, theta=0.0
% INFO    : Bus 5259	: V=1.0008299, theta=-68.892184 -> V=1.0, theta=0.0
% INFO    : Bus 5260	: V=1.0081301, theta=-53.846003 -> V=1.0, theta=0.0
% INFO    : Bus 5261	: V=1.0087587, theta=-55.112707 -> V=1.0, theta=0.0
% INFO    : Bus 5262	: V=1.01, theta=-49.536234 -> V=1.0, theta=0.0
% INFO    : Bus 5263	: V=1.01, theta=-51.248171 -> V=1.0, theta=0.0
% INFO    : Bus 5264	: V=1.02, theta=-54.586694 -> V=1.0, theta=0.0
% INFO    : Bus 5265	: V=1.0017869, theta=-67.411025 -> V=1.0, theta=0.0
% INFO    : Bus 5266	: V=1.002575, theta=-69.058953 -> V=1.0, theta=0.0
% INFO    : Bus 5267	: V=0.9999758, theta=-57.373472 -> V=1.0, theta=0.0
% INFO    : Bus 5268	: V=0.9892545, theta=-64.253043 -> V=1.0, theta=0.0
% INFO    : Bus 5269	: V=0.9945728, theta=-64.577204 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=0.998202, theta=-58.538406 -> V=1.0, theta=0.0
% INFO    : Bus 5271	: V=1.0083029, theta=-53.759585 -> V=1.0, theta=0.0
% INFO    : Bus 5272	: V=0.9974701, theta=-70.754561 -> V=1.0, theta=0.0
% INFO    : Bus 5273	: V=1.0138222, theta=-70.862708 -> V=1.0, theta=0.0
% INFO    : Bus 5274	: V=0.9910199, theta=-69.1707 -> V=1.0, theta=0.0
% INFO    : Bus 5275	: V=0.9913302, theta=-59.264924 -> V=1.0, theta=0.0
% INFO    : Bus 5276	: V=1.0069896, theta=-54.258505 -> V=1.0, theta=0.0
% INFO    : Bus 5277	: V=0.992394, theta=-69.53569 -> V=1.0, theta=0.0
% INFO    : Bus 5278	: V=1.0102024, theta=-52.554014 -> V=1.0, theta=0.0
% INFO    : Bus 5279	: V=1.0181547, theta=-50.531719 -> V=1.0, theta=0.0
% INFO    : Bus 5280	: V=1.013529, theta=-51.845998 -> V=1.0, theta=0.0
% INFO    : Bus 5281	: V=1.0115594, theta=-47.590612 -> V=1.0, theta=0.0
% INFO    : Bus 5282	: V=1.0128451, theta=-48.047284 -> V=1.0, theta=0.0
% INFO    : Bus 5283	: V=1.0181547, theta=-50.531719 -> V=1.0, theta=0.0
% INFO    : Bus 5284	: V=0.9918793, theta=-67.852669 -> V=1.0, theta=0.0
% INFO    : Bus 5285	: V=0.9905622, theta=-60.206901 -> V=1.0, theta=0.0
% INFO    : Bus 5286	: V=1.0052144, theta=-53.831069 -> V=1.0, theta=0.0
% INFO    : Bus 5287	: V=0.9897372, theta=-69.86086 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=0.9912369, theta=-64.286172 -> V=1.0, theta=0.0
% INFO    : Bus 5289	: V=0.9954071, theta=-70.890738 -> V=1.0, theta=0.0
% INFO    : Bus 5290	: V=0.9950207, theta=-59.905346 -> V=1.0, theta=0.0
% INFO    : Bus 5291	: V=0.9909141, theta=-68.086831 -> V=1.0, theta=0.0
% INFO    : Bus 5292	: V=0.9895244, theta=-66.14022 -> V=1.0, theta=0.0
% INFO    : Bus 5293	: V=0.9891966, theta=-62.153881 -> V=1.0, theta=0.0
% INFO    : Bus 5294	: V=0.9903335, theta=-71.482225 -> V=1.0, theta=0.0
% INFO    : Bus 5295	: V=1.0118986, theta=-63.160096 -> V=1.0, theta=0.0
% INFO    : Bus 5296	: V=1.0030607, theta=-65.770355 -> V=1.0, theta=0.0
% INFO    : Bus 5297	: V=1.0118986, theta=-63.160096 -> V=1.0, theta=0.0
% INFO    : Bus 5298	: V=1.0182148, theta=-62.474949 -> V=1.0, theta=0.0
% INFO    : Bus 5299	: V=1.0246525, theta=-61.758381 -> V=1.0, theta=0.0
% INFO    : Bus 5300	: V=1.0225474, theta=-61.994606 -> V=1.0, theta=0.0
% INFO    : Bus 5301	: V=1.0247494, theta=-61.76631 -> V=1.0, theta=0.0
% INFO    : Bus 5302	: V=1.04, theta=-58.745525 -> V=1.0, theta=0.0
% INFO    : Bus 5303	: V=1.04, theta=-59.868613 -> V=1.0, theta=0.0
% INFO    : Bus 5304	: V=1.0082389, theta=-63.450438 -> V=1.0, theta=0.0
% INFO    : Bus 5305	: V=0.9988872, theta=-67.469886 -> V=1.0, theta=0.0
% INFO    : Bus 5306	: V=1.0004879, theta=-64.53213 -> V=1.0, theta=0.0
% INFO    : Bus 5307	: V=1.0047799, theta=-70.069158 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=0.9943756, theta=-68.779885 -> V=1.0, theta=0.0
% INFO    : Bus 5309	: V=0.9878137, theta=-71.070443 -> V=1.0, theta=0.0
% INFO    : Bus 5310	: V=1.0051586, theta=-69.577416 -> V=1.0, theta=0.0
% INFO    : Bus 5311	: V=0.9939398, theta=-71.580696 -> V=1.0, theta=0.0
% INFO    : Bus 5312	: V=0.9855713, theta=-66.661783 -> V=1.0, theta=0.0
% INFO    : Bus 5313	: V=1.0007257, theta=-67.064238 -> V=1.0, theta=0.0
% INFO    : Bus 5314	: V=1.0051578, theta=-56.413618 -> V=1.0, theta=0.0
% INFO    : Bus 5315	: V=0.9892711, theta=-68.434377 -> V=1.0, theta=0.0
% INFO    : Bus 5316	: V=1.02, theta=-70.678332 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=1.0080908, theta=-55.056425 -> V=1.0, theta=0.0
% INFO    : Bus 5318	: V=1.0044714, theta=-58.222685 -> V=1.0, theta=0.0
% INFO    : Bus 5319	: V=1.01, theta=-54.207004 -> V=1.0, theta=0.0
% INFO    : Bus 5320	: V=1.0080908, theta=-55.056425 -> V=1.0, theta=0.0
% INFO    : Bus 5321	: V=1.01, theta=-54.244012 -> V=1.0, theta=0.0
% INFO    : Bus 5322	: V=1.0099515, theta=-63.697051 -> V=1.0, theta=0.0
% INFO    : Bus 5323	: V=0.9993, theta=-68.008163 -> V=1.0, theta=0.0
% INFO    : Bus 5324	: V=1.038225, theta=-60.522063 -> V=1.0, theta=0.0
% INFO    : Bus 5325	: V=1.0378266, theta=-60.507418 -> V=1.0, theta=0.0
% INFO    : Bus 5326	: V=1.0202276, theta=-62.58827 -> V=1.0, theta=0.0
% INFO    : Bus 5327	: V=0.9985814, theta=-56.952327 -> V=1.0, theta=0.0
% INFO    : Bus 5328	: V=0.9968147, theta=-57.749102 -> V=1.0, theta=0.0
% INFO    : Bus 5329	: V=0.9871331, theta=-70.18317 -> V=1.0, theta=0.0
% INFO    : Bus 5330	: V=0.9965855, theta=-68.188574 -> V=1.0, theta=0.0
% INFO    : Bus 5331	: V=0.9923225, theta=-68.599422 -> V=1.0, theta=0.0
% INFO    : Bus 5332	: V=0.9916667, theta=-68.929235 -> V=1.0, theta=0.0
% INFO    : Bus 5333	: V=0.9839362, theta=-68.847776 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=1.0098473, theta=-41.806469 -> V=1.0, theta=0.0
% INFO    : Bus 5335	: V=0.9878591, theta=-71.149131 -> V=1.0, theta=0.0
% INFO    : Bus 5336	: V=0.9940233, theta=-68.539612 -> V=1.0, theta=0.0
% INFO    : Bus 5337	: V=0.9991174, theta=-54.939632 -> V=1.0, theta=0.0
% INFO    : Bus 5338	: V=0.9846285, theta=-65.03727 -> V=1.0, theta=0.0
% INFO    : Bus 5339	: V=1.0142057, theta=-70.446415 -> V=1.0, theta=0.0
% INFO    : Bus 5340	: V=0.994689, theta=-70.882977 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=1.0106115, theta=-69.40844 -> V=1.0, theta=0.0
% INFO    : Bus 5342	: V=1.0191371, theta=-68.253457 -> V=1.0, theta=0.0
% INFO    : Bus 5343	: V=1.04, theta=-63.965393 -> V=1.0, theta=0.0
% INFO    : Bus 5344	: V=1.0002566, theta=-71.852282 -> V=1.0, theta=0.0
% INFO    : Bus 5345	: V=0.9899261, theta=-62.28552 -> V=1.0, theta=0.0
% INFO    : Bus 5346	: V=0.997061, theta=-68.104671 -> V=1.0, theta=0.0
% INFO    : Bus 5347	: V=1.0040003, theta=-44.533103 -> V=1.0, theta=0.0
% INFO    : Bus 5348	: V=0.9919926, theta=-64.511993 -> V=1.0, theta=0.0
% INFO    : Bus 5349	: V=0.9929598, theta=-69.041616 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=1.0048688, theta=-64.318742 -> V=1.0, theta=0.0
% INFO    : Bus 5351	: V=0.9976758, theta=-67.548429 -> V=1.0, theta=0.0
% INFO    : Bus 5352	: V=0.9956137, theta=-69.841151 -> V=1.0, theta=0.0
% INFO    : Bus 5353	: V=1.0026057, theta=-68.677627 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=1.0009126, theta=-71.080311 -> V=1.0, theta=0.0
% INFO    : Bus 5355	: V=0.9942036, theta=-65.201819 -> V=1.0, theta=0.0
% INFO    : Bus 5356	: V=0.9961997, theta=-70.491124 -> V=1.0, theta=0.0
% INFO    : Bus 5357	: V=0.9913487, theta=-68.922778 -> V=1.0, theta=0.0
% INFO    : Bus 5358	: V=1.0175023, theta=-49.994358 -> V=1.0, theta=0.0
% INFO    : Bus 5359	: V=1.0147522, theta=-52.391074 -> V=1.0, theta=0.0
% INFO    : Bus 5360	: V=1.01, theta=-43.70288 -> V=1.0, theta=0.0
% INFO    : Bus 5361	: V=1.0019943, theta=-56.039999 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=0.9996355, theta=-57.008435 -> V=1.0, theta=0.0
% INFO    : Bus 5363	: V=1.0016692, theta=-55.844546 -> V=1.0, theta=0.0
% INFO    : Bus 5364	: V=1.0, theta=-54.88496 -> V=1.0, theta=0.0
% INFO    : Bus 5365	: V=1.0, theta=-53.637979 -> V=1.0, theta=0.0
% INFO    : Bus 5366	: V=1.0, theta=-53.307634 -> V=1.0, theta=0.0
% INFO    : Bus 5367	: V=1.0, theta=-53.388333 -> V=1.0, theta=0.0
% INFO    : Bus 5368	: V=1.0, theta=-54.275356 -> V=1.0, theta=0.0
% INFO    : Bus 5369	: V=1.0, theta=-53.163939 -> V=1.0, theta=0.0
% INFO    : Bus 5370	: V=0.9898376, theta=-68.314982 -> V=1.0, theta=0.0
% INFO    : Bus 5371	: V=0.9990842, theta=-67.494191 -> V=1.0, theta=0.0
% INFO    : Bus 5372	: V=0.9947156, theta=-71.470433 -> V=1.0, theta=0.0
% INFO    : Bus 5373	: V=0.9809199, theta=-70.989893 -> V=1.0, theta=0.0
% INFO    : Bus 5374	: V=1.0057338, theta=-68.137642 -> V=1.0, theta=0.0
% INFO    : Bus 5375	: V=0.9927714, theta=-68.109008 -> V=1.0, theta=0.0
% INFO    : Bus 5376	: V=0.9989449, theta=-68.607522 -> V=1.0, theta=0.0
% INFO    : Bus 5377	: V=1.0020741, theta=-56.173519 -> V=1.0, theta=0.0
% INFO    : Bus 5378	: V=1.0150235, theta=-57.154007 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=0.9973767, theta=-69.93122 -> V=1.0, theta=0.0
% INFO    : Bus 5380	: V=1.0145678, theta=-60.609095 -> V=1.0, theta=0.0
% INFO    : Bus 5381	: V=1.0057336, theta=-62.172007 -> V=1.0, theta=0.0
% INFO    : Bus 5382	: V=1.029499, theta=-60.121057 -> V=1.0, theta=0.0
% INFO    : Bus 5383	: V=1.0315334, theta=-60.053641 -> V=1.0, theta=0.0
% INFO    : Bus 5384	: V=1.0086261, theta=-64.346118 -> V=1.0, theta=0.0
% INFO    : Bus 5385	: V=1.0052249, theta=-66.916159 -> V=1.0, theta=0.0
% INFO    : Bus 5386	: V=0.9972452, theta=-70.126538 -> V=1.0, theta=0.0
% INFO    : Bus 5387	: V=0.985951, theta=-69.547 -> V=1.0, theta=0.0
% INFO    : Bus 5388	: V=1.0145632, theta=-54.396598 -> V=1.0, theta=0.0
% INFO    : Bus 5389	: V=1.0101978, theta=-55.706892 -> V=1.0, theta=0.0
% INFO    : Bus 5390	: V=1.0078189, theta=-53.494612 -> V=1.0, theta=0.0
% INFO    : Bus 5391	: V=1.0057948, theta=-54.879081 -> V=1.0, theta=0.0
% INFO    : Bus 5392	: V=0.9978881, theta=-56.183684 -> V=1.0, theta=0.0
% INFO    : Bus 5393	: V=1.0019788, theta=-57.70293 -> V=1.0, theta=0.0
% INFO    : Bus 5394	: V=1.0186515, theta=-40.187168 -> V=1.0, theta=0.0
% INFO    : Bus 5395	: V=1.0162923, theta=-38.070704 -> V=1.0, theta=0.0
% INFO    : Bus 5396	: V=1.0099424, theta=-40.828796 -> V=1.0, theta=0.0
% INFO    : Bus 5397	: V=1.0009101, theta=-38.806773 -> V=1.0, theta=0.0
% INFO    : Bus 5398	: V=1.0009101, theta=-38.806773 -> V=1.0, theta=0.0
% INFO    : Bus 5399	: V=1.0223664, theta=-39.458446 -> V=1.0, theta=0.0
% INFO    : Bus 5400	: V=0.994643, theta=-67.385022 -> V=1.0, theta=0.0
% INFO    : Bus 5401	: V=1.0078384, theta=-55.780791 -> V=1.0, theta=0.0
% INFO    : Bus 5402	: V=0.9986592, theta=-59.28462 -> V=1.0, theta=0.0
% INFO    : Bus 5403	: V=1.0209295, theta=-54.320276 -> V=1.0, theta=0.0
% INFO    : Bus 5404	: V=1.0168754, theta=-54.924513 -> V=1.0, theta=0.0
% INFO    : Bus 5405	: V=1.0169789, theta=-54.832091 -> V=1.0, theta=0.0
% INFO    : Bus 5406	: V=1.0205178, theta=-54.363383 -> V=1.0, theta=0.0
% INFO    : Bus 5407	: V=1.0092175, theta=-57.64721 -> V=1.0, theta=0.0
% INFO    : Bus 5408	: V=1.0046092, theta=-67.309371 -> V=1.0, theta=0.0
% INFO    : Bus 5409	: V=0.9826454, theta=-68.99184 -> V=1.0, theta=0.0
% INFO    : Bus 5410	: V=1.0214164, theta=-51.323068 -> V=1.0, theta=0.0
% INFO    : Bus 5411	: V=1.02, theta=-54.18347 -> V=1.0, theta=0.0
% INFO    : Bus 5412	: V=0.9932948, theta=-69.322418 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=1.0038606, theta=-51.501099 -> V=1.0, theta=0.0
% INFO    : Bus 5414	: V=1.0118748, theta=-52.680413 -> V=1.0, theta=0.0
% INFO    : Bus 5415	: V=1.0, theta=-49.285465 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=1.0, theta=-49.261136 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=1.0, theta=-49.526965 -> V=1.0, theta=0.0
% INFO    : Bus 5418	: V=1.0003941, theta=-49.639043 -> V=1.0, theta=0.0
% INFO    : Bus 5419	: V=1.0019011, theta=-50.411623 -> V=1.0, theta=0.0
% INFO    : Bus 5420	: V=0.9987242, theta=-67.115974 -> V=1.0, theta=0.0
% INFO    : Bus 5421	: V=1.0175787, theta=-67.796623 -> V=1.0, theta=0.0
% INFO    : Bus 5422	: V=1.02, theta=-70.307658 -> V=1.0, theta=0.0
% INFO    : Bus 5423	: V=1.0188815, theta=-69.635323 -> V=1.0, theta=0.0
% INFO    : Bus 5424	: V=1.02, theta=-70.307658 -> V=1.0, theta=0.0
% INFO    : Bus 5425	: V=0.9920582, theta=-69.820644 -> V=1.0, theta=0.0
% INFO    : Bus 5426	: V=0.9885187, theta=-65.321528 -> V=1.0, theta=0.0
% INFO    : Bus 5427	: V=0.9874495, theta=-66.568896 -> V=1.0, theta=0.0
% INFO    : Bus 5428	: V=0.9960564, theta=-68.107995 -> V=1.0, theta=0.0
% INFO    : Bus 5429	: V=0.9863671, theta=-69.279226 -> V=1.0, theta=0.0
% INFO    : Bus 5430	: V=1.002199, theta=-64.823986 -> V=1.0, theta=0.0
% INFO    : Bus 5431	: V=0.9911678, theta=-69.579283 -> V=1.0, theta=0.0
% INFO    : Bus 5432	: V=0.9963417, theta=-63.486293 -> V=1.0, theta=0.0
% INFO    : Bus 5433	: V=0.9911132, theta=-70.069302 -> V=1.0, theta=0.0
% INFO    : Bus 5434	: V=1.0024574, theta=-66.950063 -> V=1.0, theta=0.0
% INFO    : Bus 5435	: V=1.0111243, theta=-54.637447 -> V=1.0, theta=0.0
% INFO    : Bus 5436	: V=0.9936079, theta=-71.013515 -> V=1.0, theta=0.0
% INFO    : Bus 5437	: V=0.9961481, theta=-58.593306 -> V=1.0, theta=0.0
% INFO    : Bus 5438	: V=0.9929895, theta=-68.676902 -> V=1.0, theta=0.0
% INFO    : Bus 5439	: V=0.9977241, theta=-63.421008 -> V=1.0, theta=0.0
% INFO    : Bus 5440	: V=0.9995155, theta=-70.236704 -> V=1.0, theta=0.0
% INFO    : Bus 5441	: V=0.9939077, theta=-66.828473 -> V=1.0, theta=0.0
% INFO    : Bus 5442	: V=0.9910271, theta=-69.082571 -> V=1.0, theta=0.0
% INFO    : Bus 5443	: V=0.9945198, theta=-68.429186 -> V=1.0, theta=0.0
% INFO    : Bus 5444	: V=1.01, theta=-59.904119 -> V=1.0, theta=0.0
% INFO    : Bus 5445	: V=0.9988996, theta=-63.75909 -> V=1.0, theta=0.0
% INFO    : Bus 5446	: V=1.0007188, theta=-57.996328 -> V=1.0, theta=0.0
% INFO    : Bus 5447	: V=0.9855936, theta=-68.26031 -> V=1.0, theta=0.0
% INFO    : Bus 5448	: V=1.0073427, theta=-63.848926 -> V=1.0, theta=0.0
% INFO    : Bus 5449	: V=1.0087692, theta=-67.27007 -> V=1.0, theta=0.0
% INFO    : Bus 5450	: V=0.9889866, theta=-68.031629 -> V=1.0, theta=0.0
% INFO    : Bus 5451	: V=1.0224514, theta=-51.302315 -> V=1.0, theta=0.0
% INFO    : Bus 5452	: V=1.0173985, theta=-52.602974 -> V=1.0, theta=0.0
% INFO    : Bus 5453	: V=0.9952791, theta=-65.588086 -> V=1.0, theta=0.0
% INFO    : Bus 5454	: V=1.0010474, theta=-65.992649 -> V=1.0, theta=0.0
% INFO    : Bus 5455	: V=0.9920074, theta=-61.593252 -> V=1.0, theta=0.0
% INFO    : Bus 5456	: V=1.0098701, theta=-48.242211 -> V=1.0, theta=0.0
% INFO    : Bus 5457	: V=0.9904179, theta=-69.542892 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=1.0063243, theta=-53.862605 -> V=1.0, theta=0.0
% INFO    : Bus 5459	: V=1.005084, theta=-55.322466 -> V=1.0, theta=0.0
% INFO    : Bus 5460	: V=0.9870488, theta=-58.117739 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=1.0048676, theta=-53.602821 -> V=1.0, theta=0.0
% INFO    : Bus 5462	: V=0.991824, theta=-69.65704 -> V=1.0, theta=0.0
% INFO    : Bus 5463	: V=0.989657, theta=-70.804802 -> V=1.0, theta=0.0
% INFO    : Bus 5464	: V=1.0059232, theta=-64.052134 -> V=1.0, theta=0.0
% INFO    : Bus 5465	: V=1.0078318, theta=-67.865893 -> V=1.0, theta=0.0
% INFO    : Bus 5466	: V=1.0004435, theta=-56.488153 -> V=1.0, theta=0.0
% INFO    : Bus 5467	: V=0.9960545, theta=-70.943419 -> V=1.0, theta=0.0
% INFO    : Bus 5468	: V=0.9917295, theta=-69.81791 -> V=1.0, theta=0.0
% INFO    : Bus 5469	: V=0.9907545, theta=-68.85818 -> V=1.0, theta=0.0
% INFO    : Bus 5470	: V=1.0066127, theta=-57.696901 -> V=1.0, theta=0.0
% INFO    : Bus 5471	: V=1.0143817, theta=-53.627198 -> V=1.0, theta=0.0
% INFO    : Bus 5472	: V=0.9967958, theta=-46.056698 -> V=1.0, theta=0.0
% INFO    : Bus 5473	: V=0.9996316, theta=-60.107888 -> V=1.0, theta=0.0
% INFO    : Bus 5474	: V=0.9953282, theta=-59.969131 -> V=1.0, theta=0.0
% INFO    : Bus 5475	: V=0.9945358, theta=-68.291986 -> V=1.0, theta=0.0
% INFO    : Bus 5476	: V=0.9869568, theta=-62.575095 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=1.0074718, theta=-55.584043 -> V=1.0, theta=0.0
% INFO    : Bus 5478	: V=0.9942696, theta=-70.236386 -> V=1.0, theta=0.0
% INFO    : Bus 5479	: V=1.0027011, theta=-61.963574 -> V=1.0, theta=0.0
% INFO    : Bus 5480	: V=0.9926412, theta=-65.502921 -> V=1.0, theta=0.0
% INFO    : Bus 5481	: V=0.9863182, theta=-66.8608 -> V=1.0, theta=0.0
% INFO    : Bus 5482	: V=1.0038408, theta=-71.681094 -> V=1.0, theta=0.0
% INFO    : Bus 5483	: V=1.0035636, theta=-68.244149 -> V=1.0, theta=0.0
% INFO    : Bus 5484	: V=1.0128539, theta=-44.383761 -> V=1.0, theta=0.0
% INFO    : Bus 5485	: V=1.0088631, theta=-60.205178 -> V=1.0, theta=0.0
% INFO    : Bus 6001	: V=1.02, theta=-57.145911 -> V=1.0, theta=0.0
% INFO    : Bus 6002	: V=1.0020095, theta=-57.147142 -> V=1.0, theta=0.0
% INFO    : Bus 6003	: V=1.0305849, theta=-46.541158 -> V=1.0, theta=0.0
% INFO    : Bus 6004	: V=1.0152004, theta=-42.924688 -> V=1.0, theta=0.0
% INFO    : Bus 6005	: V=1.0148009, theta=-46.15148 -> V=1.0, theta=0.0
% INFO    : Bus 6006	: V=1.04, theta=-45.141843 -> V=1.0, theta=0.0
% INFO    : Bus 6007	: V=1.0305849, theta=-46.541158 -> V=1.0, theta=0.0
% INFO    : Bus 6008	: V=1.04, theta=-45.02013 -> V=1.0, theta=0.0
% INFO    : Bus 6009	: V=1.04, theta=-43.991316 -> V=1.0, theta=0.0
% INFO    : Bus 6010	: V=1.04, theta=-44.771917 -> V=1.0, theta=0.0
% INFO    : Bus 6011	: V=1.0072892, theta=-52.595785 -> V=1.0, theta=0.0
% INFO    : Bus 6012	: V=1.02, theta=-49.998432 -> V=1.0, theta=0.0
% INFO    : Bus 6013	: V=0.9866496, theta=-58.169646 -> V=1.0, theta=0.0
% INFO    : Bus 6014	: V=1.0108276, theta=-51.980883 -> V=1.0, theta=0.0
% INFO    : Bus 6015	: V=1.0015089, theta=-56.462291 -> V=1.0, theta=0.0
% INFO    : Bus 6016	: V=1.0032448, theta=-57.247275 -> V=1.0, theta=0.0
% INFO    : Bus 6017	: V=1.0003992, theta=-55.488203 -> V=1.0, theta=0.0
% INFO    : Bus 6018	: V=0.9889906, theta=-56.894225 -> V=1.0, theta=0.0
% INFO    : Bus 6019	: V=0.9877333, theta=-57.563717 -> V=1.0, theta=0.0
% INFO    : Bus 6020	: V=1.0150397, theta=-51.837982 -> V=1.0, theta=0.0
% INFO    : Bus 6021	: V=1.0251829, theta=-49.223128 -> V=1.0, theta=0.0
% INFO    : Bus 6022	: V=1.0133061, theta=-51.936966 -> V=1.0, theta=0.0
% INFO    : Bus 6023	: V=0.996817, theta=-55.744073 -> V=1.0, theta=0.0
% INFO    : Bus 6024	: V=1.0175626, theta=-59.340525 -> V=1.0, theta=0.0
% INFO    : Bus 6025	: V=1.02, theta=-57.485172 -> V=1.0, theta=0.0
% INFO    : Bus 6026	: V=0.9941741, theta=-56.295405 -> V=1.0, theta=0.0
% INFO    : Bus 6027	: V=1.0088223, theta=-52.734633 -> V=1.0, theta=0.0
% INFO    : Bus 6028	: V=0.9860633, theta=-57.307881 -> V=1.0, theta=0.0
% INFO    : Bus 6029	: V=1.0136023, theta=-46.775005 -> V=1.0, theta=0.0
% INFO    : Bus 6030	: V=1.0128595, theta=-35.973163 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=1.0080131, theta=-38.635731 -> V=1.0, theta=0.0
% INFO    : Bus 6032	: V=0.9902783, theta=-59.914525 -> V=1.0, theta=0.0
% INFO    : Bus 6033	: V=1.0144259, theta=-50.974652 -> V=1.0, theta=0.0
% INFO    : Bus 6034	: V=1.0032863, theta=-53.153084 -> V=1.0, theta=0.0
% INFO    : Bus 6035	: V=0.9918216, theta=-56.203084 -> V=1.0, theta=0.0
% INFO    : Bus 6036	: V=1.0080707, theta=-52.029643 -> V=1.0, theta=0.0
% INFO    : Bus 6037	: V=1.0029147, theta=-54.748312 -> V=1.0, theta=0.0
% INFO    : Bus 6038	: V=1.0238171, theta=-49.532066 -> V=1.0, theta=0.0
% INFO    : Bus 6039	: V=1.0034386, theta=-53.39117 -> V=1.0, theta=0.0
% INFO    : Bus 6040	: V=0.989049, theta=-57.313792 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=1.0278202, theta=-49.536526 -> V=1.0, theta=0.0
% INFO    : Bus 6042	: V=1.04, theta=-49.544328 -> V=1.0, theta=0.0
% INFO    : Bus 6043	: V=0.9921119, theta=-55.799315 -> V=1.0, theta=0.0
% INFO    : Bus 6044	: V=0.9904657, theta=-57.090937 -> V=1.0, theta=0.0
% INFO    : Bus 6045	: V=1.0221792, theta=-49.143124 -> V=1.0, theta=0.0
% INFO    : Bus 6046	: V=1.0145212, theta=-52.283327 -> V=1.0, theta=0.0
% INFO    : Bus 6047	: V=1.0060686, theta=-56.795098 -> V=1.0, theta=0.0
% INFO    : Bus 6048	: V=1.0221792, theta=-49.143124 -> V=1.0, theta=0.0
% INFO    : Bus 6049	: V=1.0221792, theta=-49.143124 -> V=1.0, theta=0.0
% INFO    : Bus 6050	: V=1.0221792, theta=-49.143124 -> V=1.0, theta=0.0
% INFO    : Bus 6051	: V=1.0294869, theta=-48.357067 -> V=1.0, theta=0.0
% INFO    : Bus 6052	: V=1.0221792, theta=-49.143124 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=1.0304925, theta=-48.237773 -> V=1.0, theta=0.0
% INFO    : Bus 6054	: V=1.0377347, theta=-47.43131 -> V=1.0, theta=0.0
% INFO    : Bus 6055	: V=1.0156228, theta=-59.115309 -> V=1.0, theta=0.0
% INFO    : Bus 6056	: V=1.0219396, theta=-46.727696 -> V=1.0, theta=0.0
% INFO    : Bus 6057	: V=1.0150475, theta=-49.599546 -> V=1.0, theta=0.0
% INFO    : Bus 6058	: V=1.0068577, theta=-51.947603 -> V=1.0, theta=0.0
% INFO    : Bus 6059	: V=1.0160537, theta=-55.715938 -> V=1.0, theta=0.0
% INFO    : Bus 6060	: V=0.9995669, theta=-58.191201 -> V=1.0, theta=0.0
% INFO    : Bus 6061	: V=0.9858053, theta=-58.092888 -> V=1.0, theta=0.0
% INFO    : Bus 6062	: V=1.0146557, theta=-33.668984 -> V=1.0, theta=0.0
% INFO    : Bus 6063	: V=1.0103229, theta=-36.702929 -> V=1.0, theta=0.0
% INFO    : Bus 6064	: V=1.0025514, theta=-39.962196 -> V=1.0, theta=0.0
% INFO    : Bus 6065	: V=0.9923879, theta=-57.086382 -> V=1.0, theta=0.0
% INFO    : Bus 6066	: V=1.0240189, theta=-47.346963 -> V=1.0, theta=0.0
% INFO    : Bus 6067	: V=1.0159132, theta=-49.679612 -> V=1.0, theta=0.0
% INFO    : Bus 6068	: V=1.0067932, theta=-53.543801 -> V=1.0, theta=0.0
% INFO    : Bus 6069	: V=1.03, theta=-46.535884 -> V=1.0, theta=0.0
% INFO    : Bus 6070	: V=1.03, theta=-45.251954 -> V=1.0, theta=0.0
% INFO    : Bus 6071	: V=1.03, theta=-46.796851 -> V=1.0, theta=0.0
% INFO    : Bus 6072	: V=1.0240189, theta=-47.346963 -> V=1.0, theta=0.0
% INFO    : Bus 6073	: V=1.03, theta=-46.199633 -> V=1.0, theta=0.0
% INFO    : Bus 6074	: V=1.03, theta=-46.211546 -> V=1.0, theta=0.0
% INFO    : Bus 6075	: V=1.0159003, theta=-32.143234 -> V=1.0, theta=0.0
% INFO    : Bus 6076	: V=1.0162191, theta=-34.342643 -> V=1.0, theta=0.0
% INFO    : Bus 6077	: V=1.0150255, theta=-36.439002 -> V=1.0, theta=0.0
% INFO    : Bus 6078	: V=1.0072111, theta=-29.024572 -> V=1.0, theta=0.0
% INFO    : Bus 6079	: V=1.0123594, theta=-31.146567 -> V=1.0, theta=0.0
% INFO    : Bus 6080	: V=1.0108425, theta=-30.782013 -> V=1.0, theta=0.0
% INFO    : Bus 6081	: V=1.0192485, theta=-50.930184 -> V=1.0, theta=0.0
% INFO    : Bus 6082	: V=1.04, theta=-48.380342 -> V=1.0, theta=0.0
% INFO    : Bus 6083	: V=1.04, theta=-42.001575 -> V=1.0, theta=0.0
% INFO    : Bus 6084	: V=1.0002117, theta=-55.520058 -> V=1.0, theta=0.0
% INFO    : Bus 6085	: V=1.0003146, theta=-55.247685 -> V=1.0, theta=0.0
% INFO    : Bus 6086	: V=1.000338, theta=-52.773455 -> V=1.0, theta=0.0
% INFO    : Bus 6087	: V=1.0002117, theta=-55.520058 -> V=1.0, theta=0.0
% INFO    : Bus 6088	: V=1.0004155, theta=-55.089875 -> V=1.0, theta=0.0
% INFO    : Bus 6089	: V=1.0004354, theta=-53.988311 -> V=1.0, theta=0.0
% INFO    : Bus 6090	: V=1.0004047, theta=-53.788457 -> V=1.0, theta=0.0
% INFO    : Bus 6091	: V=1.0017026, theta=-58.780156 -> V=1.0, theta=0.0
% INFO    : Bus 6092	: V=1.02, theta=-48.15525 -> V=1.0, theta=0.0
% INFO    : Bus 6093	: V=0.9939976, theta=-56.347205 -> V=1.0, theta=0.0
% INFO    : Bus 6094	: V=1.0013936, theta=-55.87612 -> V=1.0, theta=0.0
% INFO    : Bus 6095	: V=0.9981678, theta=-57.818528 -> V=1.0, theta=0.0
% INFO    : Bus 6096	: V=1.02, theta=-53.54396 -> V=1.0, theta=0.0
% INFO    : Bus 6097	: V=0.991662, theta=-56.883561 -> V=1.0, theta=0.0
% INFO    : Bus 6098	: V=0.9800188, theta=-58.600316 -> V=1.0, theta=0.0
% INFO    : Bus 6099	: V=0.9917895, theta=-57.059193 -> V=1.0, theta=0.0
% INFO    : Bus 6100	: V=0.9931043, theta=-57.193845 -> V=1.0, theta=0.0
% INFO    : Bus 6101	: V=1.0183246, theta=-33.148816 -> V=1.0, theta=0.0
% INFO    : Bus 6102	: V=1.0161934, theta=-36.313929 -> V=1.0, theta=0.0
% INFO    : Bus 6103	: V=1.02, theta=-42.13066 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=1.0256821, theta=-32.35213 -> V=1.0, theta=0.0
% INFO    : Bus 6105	: V=1.0299408, theta=-31.870217 -> V=1.0, theta=0.0
% INFO    : Bus 6106	: V=1.0242652, theta=-32.516598 -> V=1.0, theta=0.0
% INFO    : Bus 6107	: V=1.0295819, theta=-48.079675 -> V=1.0, theta=0.0
% INFO    : Bus 6108	: V=1.0079822, theta=-48.094672 -> V=1.0, theta=0.0
% INFO    : Bus 6109	: V=1.0020973, theta=-50.975051 -> V=1.0, theta=0.0
% INFO    : Bus 6110	: V=1.04, theta=-46.348611 -> V=1.0, theta=0.0
% INFO    : Bus 6111	: V=1.04, theta=-46.407475 -> V=1.0, theta=0.0
% INFO    : Bus 6112	: V=0.995737, theta=-55.303272 -> V=1.0, theta=0.0
% INFO    : Bus 6113	: V=0.9848337, theta=-57.966533 -> V=1.0, theta=0.0
% INFO    : Bus 6114	: V=0.9827326, theta=-58.649977 -> V=1.0, theta=0.0
% INFO    : Bus 6115	: V=0.9909609, theta=-57.362442 -> V=1.0, theta=0.0
% INFO    : Bus 6116	: V=0.9906801, theta=-58.452052 -> V=1.0, theta=0.0
% INFO    : Bus 6117	: V=1.0154177, theta=-44.521073 -> V=1.0, theta=0.0
% INFO    : Bus 6118	: V=1.0245311, theta=-49.664104 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=1.0064166, theta=-53.179337 -> V=1.0, theta=0.0
% INFO    : Bus 6120	: V=0.9947036, theta=-56.427275 -> V=1.0, theta=0.0
% INFO    : Bus 6121	: V=1.0011928, theta=-57.005974 -> V=1.0, theta=0.0
% INFO    : Bus 6122	: V=1.0031342, theta=-39.448426 -> V=1.0, theta=0.0
% INFO    : Bus 6123	: V=0.9827518, theta=-57.869933 -> V=1.0, theta=0.0
% INFO    : Bus 6124	: V=0.9997188, theta=-54.146273 -> V=1.0, theta=0.0
% INFO    : Bus 6125	: V=0.991773, theta=-54.393602 -> V=1.0, theta=0.0
% INFO    : Bus 6126	: V=0.9876835, theta=-57.322137 -> V=1.0, theta=0.0
% INFO    : Bus 6127	: V=0.9966121, theta=-52.976736 -> V=1.0, theta=0.0
% INFO    : Bus 6128	: V=0.9867809, theta=-58.659778 -> V=1.0, theta=0.0
% INFO    : Bus 6129	: V=0.9939284, theta=-57.564686 -> V=1.0, theta=0.0
% INFO    : Bus 6130	: V=0.9889104, theta=-57.003515 -> V=1.0, theta=0.0
% INFO    : Bus 6131	: V=0.9872801, theta=-57.600295 -> V=1.0, theta=0.0
% INFO    : Bus 6132	: V=0.9781848, theta=-58.864572 -> V=1.0, theta=0.0
% INFO    : Bus 6133	: V=1.0080216, theta=-49.999418 -> V=1.0, theta=0.0
% INFO    : Bus 6134	: V=1.0112914, theta=-57.583418 -> V=1.0, theta=0.0
% INFO    : Bus 6135	: V=1.0020148, theta=-37.892541 -> V=1.0, theta=0.0
% INFO    : Bus 6136	: V=1.0033349, theta=-57.710137 -> V=1.0, theta=0.0
% INFO    : Bus 6137	: V=0.9780433, theta=-59.868034 -> V=1.0, theta=0.0
% INFO    : Bus 6138	: V=1.0020877, theta=-59.434947 -> V=1.0, theta=0.0
% INFO    : Bus 6139	: V=1.0045686, theta=-52.898826 -> V=1.0, theta=0.0
% INFO    : Bus 6140	: V=1.0067395, theta=-56.582944 -> V=1.0, theta=0.0
% INFO    : Bus 6141	: V=1.024081, theta=-46.402368 -> V=1.0, theta=0.0
% INFO    : Bus 6142	: V=1.0150927, theta=-49.965762 -> V=1.0, theta=0.0
% INFO    : Bus 6143	: V=1.0113717, theta=-53.501197 -> V=1.0, theta=0.0
% INFO    : Bus 6144	: V=1.024081, theta=-46.402368 -> V=1.0, theta=0.0
% INFO    : Bus 6145	: V=1.03, theta=-43.270787 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=1.03, theta=-43.386254 -> V=1.0, theta=0.0
% INFO    : Bus 6147	: V=1.03, theta=-44.109558 -> V=1.0, theta=0.0
% INFO    : Bus 6148	: V=1.024081, theta=-46.402368 -> V=1.0, theta=0.0
% INFO    : Bus 6149	: V=1.03, theta=-45.840239 -> V=1.0, theta=0.0
% INFO    : Bus 6150	: V=1.0095183, theta=-57.934254 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=1.02, theta=-43.235281 -> V=1.0, theta=0.0
% INFO    : Bus 6152	: V=1.0104647, theta=-53.097064 -> V=1.0, theta=0.0
% INFO    : Bus 6153	: V=0.9905418, theta=-55.254344 -> V=1.0, theta=0.0
% INFO    : Bus 6154	: V=0.99088, theta=-56.379406 -> V=1.0, theta=0.0
% INFO    : Bus 6155	: V=0.9863765, theta=-56.214168 -> V=1.0, theta=0.0
% INFO    : Bus 6156	: V=1.0114978, theta=-51.793344 -> V=1.0, theta=0.0
% INFO    : Bus 6157	: V=0.9963574, theta=-59.173765 -> V=1.0, theta=0.0
% INFO    : Bus 6158	: V=1.02, theta=-43.310626 -> V=1.0, theta=0.0
% INFO    : Bus 6159	: V=0.9991662, theta=-56.375804 -> V=1.0, theta=0.0
% INFO    : Bus 6160	: V=0.9854247, theta=-57.632833 -> V=1.0, theta=0.0
% INFO    : Bus 6161	: V=1.0237677, theta=-45.517462 -> V=1.0, theta=0.0
% INFO    : Bus 6162	: V=1.0173473, theta=-49.105834 -> V=1.0, theta=0.0
% INFO    : Bus 6163	: V=1.0101261, theta=-51.651626 -> V=1.0, theta=0.0
% INFO    : Bus 6164	: V=1.03, theta=-44.880835 -> V=1.0, theta=0.0
% INFO    : Bus 6165	: V=1.03, theta=-44.809174 -> V=1.0, theta=0.0
% INFO    : Bus 6166	: V=1.03, theta=-45.22156 -> V=1.0, theta=0.0
% INFO    : Bus 6167	: V=1.03, theta=-44.960579 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=0.9902297, theta=-58.211482 -> V=1.0, theta=0.0
% INFO    : Bus 6169	: V=1.0258044, theta=-46.04155 -> V=1.0, theta=0.0
% INFO    : Bus 6170	: V=1.0169473, theta=-50.271244 -> V=1.0, theta=0.0
% INFO    : Bus 6171	: V=1.0030947, theta=-53.489989 -> V=1.0, theta=0.0
% INFO    : Bus 6172	: V=1.0110807, theta=-36.815353 -> V=1.0, theta=0.0
% INFO    : Bus 6173	: V=1.0108386, theta=-39.005232 -> V=1.0, theta=0.0
% INFO    : Bus 6174	: V=0.9979889, theta=-57.222986 -> V=1.0, theta=0.0
% INFO    : Bus 6175	: V=0.983618, theta=-58.057617 -> V=1.0, theta=0.0
% INFO    : Bus 6176	: V=0.9948196, theta=-56.775257 -> V=1.0, theta=0.0
% INFO    : Bus 6177	: V=1.02, theta=-52.176338 -> V=1.0, theta=0.0
% INFO    : Bus 6178	: V=1.0060474, theta=-55.336707 -> V=1.0, theta=0.0
% INFO    : Bus 6179	: V=1.0022385, theta=-57.113167 -> V=1.0, theta=0.0
% INFO    : Bus 6180	: V=0.9891304, theta=-55.730504 -> V=1.0, theta=0.0
% INFO    : Bus 6181	: V=1.0027575, theta=-57.094455 -> V=1.0, theta=0.0
% INFO    : Bus 6182	: V=0.9905357, theta=-58.563831 -> V=1.0, theta=0.0
% INFO    : Bus 6183	: V=1.007062, theta=-43.612933 -> V=1.0, theta=0.0
% INFO    : Bus 6184	: V=0.9816743, theta=-58.889196 -> V=1.0, theta=0.0
% INFO    : Bus 6185	: V=0.9838722, theta=-58.677697 -> V=1.0, theta=0.0
% INFO    : Bus 6186	: V=0.9912455, theta=-57.091187 -> V=1.0, theta=0.0
% INFO    : Bus 6187	: V=0.9884722, theta=-57.664702 -> V=1.0, theta=0.0
% INFO    : Bus 6188	: V=1.0145349, theta=-33.751656 -> V=1.0, theta=0.0
% INFO    : Bus 6189	: V=1.0110826, theta=-36.481053 -> V=1.0, theta=0.0
% INFO    : Bus 6190	: V=1.0097775, theta=-47.055407 -> V=1.0, theta=0.0
% INFO    : Bus 6191	: V=0.9937955, theta=-56.295775 -> V=1.0, theta=0.0
% INFO    : Bus 6192	: V=1.0042335, theta=-43.334277 -> V=1.0, theta=0.0
% INFO    : Bus 6193	: V=0.9977424, theta=-45.156398 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=0.9873924, theta=-56.720221 -> V=1.0, theta=0.0
% INFO    : Bus 6195	: V=0.989587, theta=-39.418126 -> V=1.0, theta=0.0
% INFO    : Bus 6196	: V=0.9984611, theta=-55.664524 -> V=1.0, theta=0.0
% INFO    : Bus 6197	: V=1.0193682, theta=-48.682962 -> V=1.0, theta=0.0
% INFO    : Bus 6198	: V=1.0083829, theta=-53.278197 -> V=1.0, theta=0.0
% INFO    : Bus 6199	: V=1.0052173, theta=-56.072097 -> V=1.0, theta=0.0
% INFO    : Bus 6200	: V=0.9857009, theta=-57.383381 -> V=1.0, theta=0.0
% INFO    : Bus 6201	: V=0.9979618, theta=-58.641642 -> V=1.0, theta=0.0
% INFO    : Bus 6202	: V=1.0087668, theta=-52.613631 -> V=1.0, theta=0.0
% INFO    : Bus 6203	: V=0.9887, theta=-58.016683 -> V=1.0, theta=0.0
% INFO    : Bus 6204	: V=0.9922951, theta=-57.247913 -> V=1.0, theta=0.0
% INFO    : Bus 6205	: V=0.984659, theta=-57.389584 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=0.9997022, theta=-44.721805 -> V=1.0, theta=0.0
% INFO    : Bus 6207	: V=1.02, theta=-58.479228 -> V=1.0, theta=0.0
% INFO    : Bus 6208	: V=0.9846156, theta=-58.803848 -> V=1.0, theta=0.0
% INFO    : Bus 6209	: V=1.0010409, theta=-56.127462 -> V=1.0, theta=0.0
% INFO    : Bus 6210	: V=1.0333316, theta=-46.496658 -> V=1.0, theta=0.0
% INFO    : Bus 6211	: V=1.0266639, theta=-48.484966 -> V=1.0, theta=0.0
% INFO    : Bus 6212	: V=1.0198188, theta=-51.170249 -> V=1.0, theta=0.0
% INFO    : Bus 6213	: V=1.04, theta=-42.252352 -> V=1.0, theta=0.0
% INFO    : Bus 6214	: V=1.04, theta=-38.364177 -> V=1.0, theta=0.0
% INFO    : Bus 6215	: V=1.04, theta=-44.410867 -> V=1.0, theta=0.0
% INFO    : Bus 6216	: V=1.04, theta=-41.798416 -> V=1.0, theta=0.0
% INFO    : Bus 6217	: V=0.9807444, theta=-60.225488 -> V=1.0, theta=0.0
% INFO    : Bus 6218	: V=0.9843107, theta=-56.743214 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=0.9909082, theta=-58.708719 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=0.9985617, theta=-55.971907 -> V=1.0, theta=0.0
% INFO    : Bus 6221	: V=1.02, theta=-49.892748 -> V=1.0, theta=0.0
% INFO    : Bus 6222	: V=0.9985479, theta=-54.026601 -> V=1.0, theta=0.0
% INFO    : Bus 6223	: V=0.9890718, theta=-56.59883 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=0.982494, theta=-58.71962 -> V=1.0, theta=0.0
% INFO    : Bus 6225	: V=0.9865055, theta=-57.539036 -> V=1.0, theta=0.0
% INFO    : Bus 6226	: V=1.008238, theta=-60.636792 -> V=1.0, theta=0.0
% INFO    : Bus 6227	: V=0.9824816, theta=-57.969276 -> V=1.0, theta=0.0
% INFO    : Bus 6228	: V=1.0191692, theta=-47.455314 -> V=1.0, theta=0.0
% INFO    : Bus 6229	: V=1.02, theta=-51.613867 -> V=1.0, theta=0.0
% INFO    : Bus 6230	: V=0.9993983, theta=-55.56461 -> V=1.0, theta=0.0
% INFO    : Bus 6231	: V=0.9833983, theta=-57.349675 -> V=1.0, theta=0.0
% INFO    : Bus 6232	: V=0.9958891, theta=-54.495963 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=0.9803022, theta=-58.175985 -> V=1.0, theta=0.0
% INFO    : Bus 6234	: V=1.0189461, theta=-49.405551 -> V=1.0, theta=0.0
% INFO    : Bus 6235	: V=1.0154199, theta=-50.902517 -> V=1.0, theta=0.0
% INFO    : Bus 6236	: V=0.9990204, theta=-55.023697 -> V=1.0, theta=0.0
% INFO    : Bus 6237	: V=1.0020401, theta=-53.325714 -> V=1.0, theta=0.0
% INFO    : Bus 6238	: V=0.9794164, theta=-58.526225 -> V=1.0, theta=0.0
% INFO    : Bus 6239	: V=1.0315995, theta=-44.217834 -> V=1.0, theta=0.0
% INFO    : Bus 6240	: V=1.0124682, theta=-48.604875 -> V=1.0, theta=0.0
% INFO    : Bus 6241	: V=0.9940034, theta=-53.68588 -> V=1.0, theta=0.0
% INFO    : Bus 6242	: V=1.04, theta=-42.690619 -> V=1.0, theta=0.0
% INFO    : Bus 6243	: V=1.04, theta=-42.338552 -> V=1.0, theta=0.0
% INFO    : Bus 6244	: V=1.04, theta=-41.626153 -> V=1.0, theta=0.0
% INFO    : Bus 6245	: V=1.04, theta=-42.029677 -> V=1.0, theta=0.0
% INFO    : Bus 6246	: V=1.04, theta=-43.096515 -> V=1.0, theta=0.0
% INFO    : Bus 6247	: V=1.0395182, theta=-43.377912 -> V=1.0, theta=0.0
% INFO    : Bus 6248	: V=1.04, theta=-42.51486 -> V=1.0, theta=0.0
% INFO    : Bus 6249	: V=1.04, theta=-41.754605 -> V=1.0, theta=0.0
% INFO    : Bus 6250	: V=0.9914014, theta=-57.638163 -> V=1.0, theta=0.0
% INFO    : Bus 6251	: V=0.9893414, theta=-59.057496 -> V=1.0, theta=0.0
% INFO    : Bus 6252	: V=1.0046035, theta=-53.530016 -> V=1.0, theta=0.0
% INFO    : Bus 6253	: V=1.0132467, theta=-42.105377 -> V=1.0, theta=0.0
% INFO    : Bus 6254	: V=1.0210706, theta=-49.018351 -> V=1.0, theta=0.0
% INFO    : Bus 6255	: V=1.0124055, theta=-51.164528 -> V=1.0, theta=0.0
% INFO    : Bus 6256	: V=0.9944429, theta=-55.859171 -> V=1.0, theta=0.0
% INFO    : Bus 6257	: V=1.02, theta=-48.645757 -> V=1.0, theta=0.0
% INFO    : Bus 6258	: V=1.02, theta=-47.730829 -> V=1.0, theta=0.0
% INFO    : Bus 6259	: V=1.0210706, theta=-49.018351 -> V=1.0, theta=0.0
% INFO    : Bus 6260	: V=1.02, theta=-48.571236 -> V=1.0, theta=0.0
% INFO    : Bus 6261	: V=0.9873017, theta=-58.379134 -> V=1.0, theta=0.0
% INFO    : Bus 6262	: V=0.9916501, theta=-56.719814 -> V=1.0, theta=0.0
% INFO    : Bus 6263	: V=1.0072983, theta=-42.392408 -> V=1.0, theta=0.0
% INFO    : Bus 6264	: V=1.0044006, theta=-43.969857 -> V=1.0, theta=0.0
% INFO    : Bus 6265	: V=1.0129418, theta=-39.684256 -> V=1.0, theta=0.0
% INFO    : Bus 6266	: V=1.0172625, theta=-39.089141 -> V=1.0, theta=0.0
% INFO    : Bus 6267	: V=1.0282062, theta=-37.527084 -> V=1.0, theta=0.0
% INFO    : Bus 6268	: V=1.016222, theta=-39.256117 -> V=1.0, theta=0.0
% INFO    : Bus 6269	: V=1.0292044, theta=-37.379573 -> V=1.0, theta=0.0
% INFO    : Bus 6270	: V=1.0129418, theta=-39.684256 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=1.0129418, theta=-39.684256 -> V=1.0, theta=0.0
% INFO    : Bus 6272	: V=1.0129418, theta=-39.684256 -> V=1.0, theta=0.0
% INFO    : Bus 6273	: V=1.0129418, theta=-39.684256 -> V=1.0, theta=0.0
% INFO    : Bus 6274	: V=1.0261362, theta=-37.766648 -> V=1.0, theta=0.0
% INFO    : Bus 6275	: V=0.9848972, theta=-57.415369 -> V=1.0, theta=0.0
% INFO    : Bus 6276	: V=0.9939875, theta=-58.747105 -> V=1.0, theta=0.0
% INFO    : Bus 6277	: V=1.0109219, theta=-52.04303 -> V=1.0, theta=0.0
% INFO    : Bus 6278	: V=0.995838, theta=-55.328941 -> V=1.0, theta=0.0
% INFO    : Bus 6279	: V=1.0159593, theta=-49.423212 -> V=1.0, theta=0.0
% INFO    : Bus 6280	: V=1.0066423, theta=-51.946358 -> V=1.0, theta=0.0
% INFO    : Bus 6281	: V=1.0052989, theta=-56.868793 -> V=1.0, theta=0.0
% INFO    : Bus 6282	: V=1.0139717, theta=-55.941414 -> V=1.0, theta=0.0
% INFO    : Bus 6283	: V=1.0048156, theta=-57.152617 -> V=1.0, theta=0.0
% INFO    : Bus 6284	: V=0.9945501, theta=-56.04352 -> V=1.0, theta=0.0
% INFO    : Bus 6285	: V=1.0126098, theta=-55.71663 -> V=1.0, theta=0.0
% INFO    : Bus 6286	: V=1.02, theta=-58.278583 -> V=1.0, theta=0.0
% INFO    : Bus 6287	: V=1.0055883, theta=-52.758013 -> V=1.0, theta=0.0
% INFO    : Bus 6288	: V=0.9889945, theta=-56.81255 -> V=1.0, theta=0.0
% INFO    : Bus 6289	: V=0.9811772, theta=-58.322723 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=0.9905221, theta=-57.977379 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.0036194, theta=-57.015809 -> V=1.0, theta=0.0
% INFO    : Bus 6292	: V=1.0229721, theta=-48.343658 -> V=1.0, theta=0.0
% INFO    : Bus 6293	: V=1.0103305, theta=-51.355345 -> V=1.0, theta=0.0
% INFO    : Bus 6294	: V=1.0002116, theta=-53.764954 -> V=1.0, theta=0.0
% INFO    : Bus 6295	: V=1.0210528, theta=-48.033501 -> V=1.0, theta=0.0
% INFO    : Bus 6296	: V=1.0213242, theta=-48.078765 -> V=1.0, theta=0.0
% INFO    : Bus 6297	: V=1.02, theta=-47.62374 -> V=1.0, theta=0.0
% INFO    : Bus 6298	: V=1.0205294, theta=-46.626583 -> V=1.0, theta=0.0
% INFO    : Bus 6299	: V=1.0187473, theta=-48.832901 -> V=1.0, theta=0.0
% INFO    : Bus 6300	: V=1.0104604, theta=-51.264047 -> V=1.0, theta=0.0
% INFO    : Bus 6301	: V=1.0205294, theta=-46.626583 -> V=1.0, theta=0.0
% INFO    : Bus 6302	: V=1.0140252, theta=-43.669479 -> V=1.0, theta=0.0
% INFO    : Bus 6303	: V=1.0186484, theta=-45.76119 -> V=1.0, theta=0.0
% INFO    : Bus 6304	: V=1.0152964, theta=-44.145912 -> V=1.0, theta=0.0
% INFO    : Bus 6305	: V=1.014116, theta=-43.632989 -> V=1.0, theta=0.0
% INFO    : Bus 6306	: V=0.9844066, theta=-57.615738 -> V=1.0, theta=0.0
% INFO    : Bus 6307	: V=0.98541, theta=-57.352754 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.0157587, theta=-51.578681 -> V=1.0, theta=0.0
% INFO    : Bus 6309	: V=1.0049897, theta=-55.169894 -> V=1.0, theta=0.0
% INFO    : Bus 6310	: V=1.0037734, theta=-55.677512 -> V=1.0, theta=0.0
% INFO    : Bus 6311	: V=1.0140925, theta=-38.861838 -> V=1.0, theta=0.0
% INFO    : Bus 6312	: V=1.0096037, theta=-54.900641 -> V=1.0, theta=0.0
% INFO    : Bus 6313	: V=0.9913402, theta=-58.064127 -> V=1.0, theta=0.0
% INFO    : Bus 6314	: V=0.9960037, theta=-57.494969 -> V=1.0, theta=0.0
% INFO    : Bus 6315	: V=1.0102731, theta=-52.820107 -> V=1.0, theta=0.0
% INFO    : Bus 6316	: V=1.0123602, theta=-53.561551 -> V=1.0, theta=0.0
% INFO    : Bus 6317	: V=1.0017088, theta=-55.008175 -> V=1.0, theta=0.0
% INFO    : Bus 6318	: V=0.9900502, theta=-56.757734 -> V=1.0, theta=0.0
% INFO    : Bus 6319	: V=0.9818673, theta=-58.045893 -> V=1.0, theta=0.0
% INFO    : Bus 6320	: V=1.0106544, theta=-55.849785 -> V=1.0, theta=0.0
% INFO    : Bus 6321	: V=1.0060238, theta=-47.290894 -> V=1.0, theta=0.0
% INFO    : Bus 6322	: V=1.0036937, theta=-49.991156 -> V=1.0, theta=0.0
% INFO    : Bus 6323	: V=0.9891672, theta=-56.97039 -> V=1.0, theta=0.0
% INFO    : Bus 6324	: V=0.9914735, theta=-56.527291 -> V=1.0, theta=0.0
% INFO    : Bus 6325	: V=1.0026408, theta=-54.29914 -> V=1.0, theta=0.0
% INFO    : Bus 6326	: V=0.9899843, theta=-46.257406 -> V=1.0, theta=0.0
% INFO    : Bus 6327	: V=1.0098798, theta=-39.846142 -> V=1.0, theta=0.0
% INFO    : Bus 6328	: V=1.0000099, theta=-59.146048 -> V=1.0, theta=0.0
% INFO    : Bus 6329	: V=1.0126802, theta=-44.261218 -> V=1.0, theta=0.0
% INFO    : Bus 6330	: V=0.9831929, theta=-59.178951 -> V=1.0, theta=0.0
% INFO    : Bus 6331	: V=0.9903278, theta=-58.571849 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=1.000053, theta=-56.637882 -> V=1.0, theta=0.0
% INFO    : Bus 6333	: V=1.0187552, theta=-48.912375 -> V=1.0, theta=0.0
% INFO    : Bus 6334	: V=1.0150717, theta=-51.587148 -> V=1.0, theta=0.0
% INFO    : Bus 6335	: V=0.9930425, theta=-55.616852 -> V=1.0, theta=0.0
% INFO    : Bus 6336	: V=0.9912361, theta=-58.846901 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.0060959, theta=-56.94729 -> V=1.0, theta=0.0
% INFO    : Bus 6338	: V=0.989408, theta=-52.880451 -> V=1.0, theta=0.0
% INFO    : Bus 6339	: V=0.9971138, theta=-53.970673 -> V=1.0, theta=0.0
% INFO    : Bus 6340	: V=1.0097523, theta=-51.759904 -> V=1.0, theta=0.0
% INFO    : Bus 6341	: V=1.0020869, theta=-42.005501 -> V=1.0, theta=0.0
% INFO    : Bus 6342	: V=1.0134302, theta=-51.161065 -> V=1.0, theta=0.0
% INFO    : Bus 6343	: V=1.003996, theta=-53.537474 -> V=1.0, theta=0.0
% INFO    : Bus 6344	: V=0.9985163, theta=-55.606827 -> V=1.0, theta=0.0
% INFO    : Bus 6345	: V=0.9843318, theta=-58.346 -> V=1.0, theta=0.0
% INFO    : Bus 6346	: V=0.9945221, theta=-52.988984 -> V=1.0, theta=0.0
% INFO    : Bus 6349	: V=1.0271752, theta=-49.65217 -> V=1.0, theta=0.0
% INFO    : Bus 6350	: V=1.0145417, theta=-51.853906 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=0.9951246, theta=-56.366312 -> V=1.0, theta=0.0
% INFO    : Bus 6352	: V=1.0048379, theta=-56.825664 -> V=1.0, theta=0.0
% INFO    : Bus 6353	: V=0.9951349, theta=-56.812769 -> V=1.0, theta=0.0
% INFO    : Bus 6354	: V=1.0026976, theta=-53.829648 -> V=1.0, theta=0.0
% INFO    : Bus 6355	: V=0.9984485, theta=-55.251691 -> V=1.0, theta=0.0
% INFO    : Bus 6356	: V=1.02, theta=-58.382576 -> V=1.0, theta=0.0
% INFO    : Bus 6357	: V=1.0109896, theta=-54.370847 -> V=1.0, theta=0.0
% INFO    : Bus 6358	: V=1.02, theta=-58.681728 -> V=1.0, theta=0.0
% INFO    : Bus 6359	: V=1.0201496, theta=-49.563469 -> V=1.0, theta=0.0
% INFO    : Bus 6360	: V=0.9980803, theta=-49.890752 -> V=1.0, theta=0.0
% INFO    : Bus 7001	: V=0.9988253, theta=-35.897275 -> V=1.0, theta=0.0
% INFO    : Bus 7002	: V=1.0308896, theta=-25.167512 -> V=1.0, theta=0.0
% INFO    : Bus 7003	: V=1.0157277, theta=-29.461772 -> V=1.0, theta=0.0
% INFO    : Bus 7004	: V=1.0088972, theta=-34.145434 -> V=1.0, theta=0.0
% INFO    : Bus 7005	: V=1.04, theta=-23.00984 -> V=1.0, theta=0.0
% INFO    : Bus 7006	: V=1.04, theta=-23.940836 -> V=1.0, theta=0.0
% INFO    : Bus 7007	: V=1.04, theta=-23.320668 -> V=1.0, theta=0.0
% INFO    : Bus 7008	: V=1.04, theta=-23.227021 -> V=1.0, theta=0.0
% INFO    : Bus 7009	: V=1.04, theta=-23.006108 -> V=1.0, theta=0.0
% INFO    : Bus 7010	: V=0.9834083, theta=-42.902605 -> V=1.0, theta=0.0
% INFO    : Bus 7011	: V=1.0130227, theta=-42.32804 -> V=1.0, theta=0.0
% INFO    : Bus 7012	: V=0.9780719, theta=-38.925948 -> V=1.0, theta=0.0
% INFO    : Bus 7013	: V=0.9905195, theta=-40.640496 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=0.9875111, theta=-38.364442 -> V=1.0, theta=0.0
% INFO    : Bus 7015	: V=0.9875111, theta=-38.364442 -> V=1.0, theta=0.0
% INFO    : Bus 7016	: V=0.9987491, theta=-35.467172 -> V=1.0, theta=0.0
% INFO    : Bus 7017	: V=0.9936244, theta=-39.539804 -> V=1.0, theta=0.0
% INFO    : Bus 7018	: V=1.0229242, theta=-32.820212 -> V=1.0, theta=0.0
% INFO    : Bus 7019	: V=1.0162947, theta=-33.865569 -> V=1.0, theta=0.0
% INFO    : Bus 7020	: V=1.0115354, theta=-36.622257 -> V=1.0, theta=0.0
% INFO    : Bus 7021	: V=1.0289052, theta=-32.177441 -> V=1.0, theta=0.0
% INFO    : Bus 7022	: V=1.0361187, theta=-31.381131 -> V=1.0, theta=0.0
% INFO    : Bus 7023	: V=1.0312153, theta=-31.93252 -> V=1.0, theta=0.0
% INFO    : Bus 7024	: V=1.0285136, theta=-32.224903 -> V=1.0, theta=0.0
% INFO    : Bus 7025	: V=1.0229242, theta=-32.820212 -> V=1.0, theta=0.0
% INFO    : Bus 7026	: V=1.0066727, theta=-35.475671 -> V=1.0, theta=0.0
% INFO    : Bus 7027	: V=0.990767, theta=-39.909008 -> V=1.0, theta=0.0
% INFO    : Bus 7028	: V=1.0093886, theta=-38.861453 -> V=1.0, theta=0.0
% INFO    : Bus 7029	: V=1.0156771, theta=-32.349799 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=1.0134417, theta=-36.053598 -> V=1.0, theta=0.0
% INFO    : Bus 7031	: V=1.0154757, theta=-29.3481 -> V=1.0, theta=0.0
% INFO    : Bus 7032	: V=1.016048, theta=-31.383864 -> V=1.0, theta=0.0
% INFO    : Bus 7033	: V=1.0159716, theta=-31.456969 -> V=1.0, theta=0.0
% INFO    : Bus 7034	: V=1.0156771, theta=-32.349799 -> V=1.0, theta=0.0
% INFO    : Bus 7035	: V=1.0078649, theta=-37.013629 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=0.9960813, theta=-39.530914 -> V=1.0, theta=0.0
% INFO    : Bus 7037	: V=1.0204474, theta=-31.262108 -> V=1.0, theta=0.0
% INFO    : Bus 7038	: V=1.0074036, theta=-32.788943 -> V=1.0, theta=0.0
% INFO    : Bus 7039	: V=0.9987369, theta=-37.255034 -> V=1.0, theta=0.0
% INFO    : Bus 7040	: V=1.0131665, theta=-31.069658 -> V=1.0, theta=0.0
% INFO    : Bus 7041	: V=1.0026901, theta=-34.748222 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=1.0230586, theta=-31.588727 -> V=1.0, theta=0.0
% INFO    : Bus 7043	: V=1.0185878, theta=-32.968894 -> V=1.0, theta=0.0
% INFO    : Bus 7044	: V=0.9993562, theta=-35.777402 -> V=1.0, theta=0.0
% INFO    : Bus 7045	: V=1.03, theta=-29.600643 -> V=1.0, theta=0.0
% INFO    : Bus 7046	: V=1.03, theta=-30.674595 -> V=1.0, theta=0.0
% INFO    : Bus 7047	: V=1.0186959, theta=-31.703194 -> V=1.0, theta=0.0
% INFO    : Bus 7048	: V=1.0086827, theta=-33.864973 -> V=1.0, theta=0.0
% INFO    : Bus 7049	: V=1.0026432, theta=-38.589194 -> V=1.0, theta=0.0
% INFO    : Bus 7050	: V=0.9830103, theta=-42.568627 -> V=1.0, theta=0.0
% INFO    : Bus 7051	: V=0.9911559, theta=-39.321637 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=0.9934178, theta=-37.586035 -> V=1.0, theta=0.0
% INFO    : Bus 7053	: V=1.0040276, theta=-32.912949 -> V=1.0, theta=0.0
% INFO    : Bus 7054	: V=0.9812715, theta=-39.271522 -> V=1.0, theta=0.0
% INFO    : Bus 7055	: V=0.9953525, theta=-37.230302 -> V=1.0, theta=0.0
% INFO    : Bus 7056	: V=1.0035508, theta=-36.329916 -> V=1.0, theta=0.0
% INFO    : Bus 7057	: V=0.9845577, theta=-40.95062 -> V=1.0, theta=0.0
% INFO    : Bus 7058	: V=1.0185645, theta=-28.544197 -> V=1.0, theta=0.0
% INFO    : Bus 7059	: V=1.0184176, theta=-29.881624 -> V=1.0, theta=0.0
% INFO    : Bus 7060	: V=1.0198371, theta=-32.059455 -> V=1.0, theta=0.0
% INFO    : Bus 7061	: V=1.015559, theta=-27.631997 -> V=1.0, theta=0.0
% INFO    : Bus 7062	: V=1.0158446, theta=-27.710276 -> V=1.0, theta=0.0
% INFO    : Bus 7063	: V=1.0156621, theta=-27.643345 -> V=1.0, theta=0.0
% INFO    : Bus 7064	: V=1.0162685, theta=-27.690809 -> V=1.0, theta=0.0
% INFO    : Bus 7065	: V=1.016128, theta=-27.604972 -> V=1.0, theta=0.0
% INFO    : Bus 7066	: V=1.0159135, theta=-27.716963 -> V=1.0, theta=0.0
% INFO    : Bus 7067	: V=0.9743229, theta=-41.330203 -> V=1.0, theta=0.0
% INFO    : Bus 7068	: V=1.0123756, theta=-30.013819 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=1.0010453, theta=-33.915726 -> V=1.0, theta=0.0
% INFO    : Bus 7070	: V=0.9904485, theta=-36.571628 -> V=1.0, theta=0.0
% INFO    : Bus 7071	: V=0.9936273, theta=-31.960872 -> V=1.0, theta=0.0
% INFO    : Bus 7072	: V=1.00254, theta=-35.012364 -> V=1.0, theta=0.0
% INFO    : Bus 7073	: V=1.0131661, theta=-31.222349 -> V=1.0, theta=0.0
% INFO    : Bus 7074	: V=1.0084187, theta=-33.794597 -> V=1.0, theta=0.0
% INFO    : Bus 7075	: V=1.013432, theta=-35.328229 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=1.0338607, theta=-25.300027 -> V=1.0, theta=0.0
% INFO    : Bus 7077	: V=1.0258764, theta=-27.617169 -> V=1.0, theta=0.0
% INFO    : Bus 7078	: V=1.0135048, theta=-32.148465 -> V=1.0, theta=0.0
% INFO    : Bus 7079	: V=1.04, theta=-23.877629 -> V=1.0, theta=0.0
% INFO    : Bus 7080	: V=1.04, theta=-23.411904 -> V=1.0, theta=0.0
% INFO    : Bus 7081	: V=1.04, theta=-23.394085 -> V=1.0, theta=0.0
% INFO    : Bus 7082	: V=1.04, theta=-23.789187 -> V=1.0, theta=0.0
% INFO    : Bus 7083	: V=1.0135396, theta=-30.313824 -> V=1.0, theta=0.0
% INFO    : Bus 7084	: V=1.0037947, theta=-33.715566 -> V=1.0, theta=0.0
% INFO    : Bus 7085	: V=0.9955472, theta=-34.998489 -> V=1.0, theta=0.0
% INFO    : Bus 7086	: V=0.9888144, theta=-37.406188 -> V=1.0, theta=0.0
% INFO    : Bus 7087	: V=0.9994783, theta=-36.234208 -> V=1.0, theta=0.0
% INFO    : Bus 7088	: V=0.9744316, theta=-40.186082 -> V=1.0, theta=0.0
% INFO    : Bus 7089	: V=1.0103803, theta=-40.348574 -> V=1.0, theta=0.0
% INFO    : Bus 7090	: V=0.9850108, theta=-42.073173 -> V=1.0, theta=0.0
% INFO    : Bus 7091	: V=1.02, theta=-39.739036 -> V=1.0, theta=0.0
% INFO    : Bus 7092	: V=0.9886391, theta=-38.692314 -> V=1.0, theta=0.0
% INFO    : Bus 7093	: V=0.9843832, theta=-39.473037 -> V=1.0, theta=0.0
% INFO    : Bus 7094	: V=0.9994356, theta=-40.178534 -> V=1.0, theta=0.0
% INFO    : Bus 7095	: V=1.0074381, theta=-21.541453 -> V=1.0, theta=0.0
% INFO    : Bus 7096	: V=1.0123956, theta=-23.770226 -> V=1.0, theta=0.0
% INFO    : Bus 7097	: V=1.0125023, theta=-25.474344 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=1.0, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 7099	: V=1.0, theta=-13.039145 -> V=1.0, theta=0.0
% INFO    : Bus 7100	: V=0.9898851, theta=-37.231914 -> V=1.0, theta=0.0
% INFO    : Bus 7101	: V=0.9962049, theta=-38.442941 -> V=1.0, theta=0.0
% INFO    : Bus 7102	: V=0.9797028, theta=-40.822507 -> V=1.0, theta=0.0
% INFO    : Bus 7103	: V=0.9903254, theta=-37.579193 -> V=1.0, theta=0.0
% INFO    : Bus 7104	: V=1.0311756, theta=-24.706667 -> V=1.0, theta=0.0
% INFO    : Bus 7105	: V=1.0168298, theta=-29.208458 -> V=1.0, theta=0.0
% INFO    : Bus 7106	: V=1.0103643, theta=-33.45267 -> V=1.0, theta=0.0
% INFO    : Bus 7107	: V=1.0387431, theta=-23.903447 -> V=1.0, theta=0.0
% INFO    : Bus 7108	: V=1.04, theta=-23.480049 -> V=1.0, theta=0.0
% INFO    : Bus 7109	: V=1.04, theta=-23.687999 -> V=1.0, theta=0.0
% INFO    : Bus 7110	: V=1.04, theta=-22.732252 -> V=1.0, theta=0.0
% INFO    : Bus 7111	: V=1.04, theta=-22.683544 -> V=1.0, theta=0.0
% INFO    : Bus 7112	: V=1.04, theta=-23.486224 -> V=1.0, theta=0.0
% INFO    : Bus 7113	: V=1.04, theta=-22.342502 -> V=1.0, theta=0.0
% INFO    : Bus 7114	: V=1.04, theta=-23.567937 -> V=1.0, theta=0.0
% INFO    : Bus 7115	: V=1.04, theta=-23.567088 -> V=1.0, theta=0.0
% INFO    : Bus 7116	: V=0.9775222, theta=-39.663835 -> V=1.0, theta=0.0
% INFO    : Bus 7117	: V=0.9898801, theta=-39.317748 -> V=1.0, theta=0.0
% INFO    : Bus 7118	: V=0.9802876, theta=-40.405512 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=0.9904056, theta=-37.122593 -> V=1.0, theta=0.0
% INFO    : Bus 7120	: V=0.9806181, theta=-40.454047 -> V=1.0, theta=0.0
% INFO    : Bus 7121	: V=0.9806181, theta=-40.454047 -> V=1.0, theta=0.0
% INFO    : Bus 7122	: V=0.9806181, theta=-40.454047 -> V=1.0, theta=0.0
% INFO    : Bus 7123	: V=0.9928242, theta=-31.471018 -> V=1.0, theta=0.0
% INFO    : Bus 7124	: V=0.9876848, theta=-38.594345 -> V=1.0, theta=0.0
% INFO    : Bus 7125	: V=1.0269447, theta=-25.549087 -> V=1.0, theta=0.0
% INFO    : Bus 7126	: V=1.0092878, theta=-31.847686 -> V=1.0, theta=0.0
% INFO    : Bus 7127	: V=1.0044857, theta=-34.52889 -> V=1.0, theta=0.0
% INFO    : Bus 7128	: V=0.994936, theta=-39.907748 -> V=1.0, theta=0.0
% INFO    : Bus 7129	: V=1.0153959, theta=-34.037317 -> V=1.0, theta=0.0
% INFO    : Bus 7130	: V=1.028166, theta=-24.428513 -> V=1.0, theta=0.0
% INFO    : Bus 7131	: V=1.0148025, theta=-29.281402 -> V=1.0, theta=0.0
% INFO    : Bus 7132	: V=1.0025517, theta=-32.941326 -> V=1.0, theta=0.0
% INFO    : Bus 7133	: V=1.0272597, theta=-23.955606 -> V=1.0, theta=0.0
% INFO    : Bus 7134	: V=1.0251977, theta=-22.917745 -> V=1.0, theta=0.0
% INFO    : Bus 7135	: V=1.024296, theta=-22.529141 -> V=1.0, theta=0.0
% INFO    : Bus 7136	: V=1.02382, theta=-22.339673 -> V=1.0, theta=0.0
% INFO    : Bus 7137	: V=1.0239783, theta=-22.261472 -> V=1.0, theta=0.0
% INFO    : Bus 7138	: V=1.0253386, theta=-22.98795 -> V=1.0, theta=0.0
% INFO    : Bus 7139	: V=1.0254138, theta=-22.934792 -> V=1.0, theta=0.0
% INFO    : Bus 7140	: V=1.0256498, theta=-23.168351 -> V=1.0, theta=0.0
% INFO    : Bus 7141	: V=1.0266225, theta=-23.601931 -> V=1.0, theta=0.0
% INFO    : Bus 7142	: V=1.0260585, theta=-23.336257 -> V=1.0, theta=0.0
% INFO    : Bus 7143	: V=0.99249, theta=-41.11236 -> V=1.0, theta=0.0
% INFO    : Bus 7144	: V=0.9919879, theta=-36.5718 -> V=1.0, theta=0.0
% INFO    : Bus 7145	: V=1.02, theta=-41.123288 -> V=1.0, theta=0.0
% INFO    : Bus 7146	: V=1.0178698, theta=-39.925572 -> V=1.0, theta=0.0
% INFO    : Bus 7147	: V=1.000142, theta=-38.300312 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=0.9839619, theta=-40.197327 -> V=1.0, theta=0.0
% INFO    : Bus 7149	: V=0.998534, theta=-34.867836 -> V=1.0, theta=0.0
% INFO    : Bus 7150	: V=1.02, theta=-38.46942 -> V=1.0, theta=0.0
% INFO    : Bus 7151	: V=1.0120568, theta=-40.963825 -> V=1.0, theta=0.0
% INFO    : Bus 7152	: V=0.9910062, theta=-38.268732 -> V=1.0, theta=0.0
% INFO    : Bus 7153	: V=0.99523, theta=-28.296497 -> V=1.0, theta=0.0
% INFO    : Bus 7154	: V=0.9974807, theta=-40.910001 -> V=1.0, theta=0.0
% INFO    : Bus 7155	: V=0.9832022, theta=-38.540655 -> V=1.0, theta=0.0
% INFO    : Bus 7156	: V=1.0001774, theta=-35.418586 -> V=1.0, theta=0.0
% INFO    : Bus 7157	: V=0.9931671, theta=-38.756271 -> V=1.0, theta=0.0
% INFO    : Bus 7158	: V=0.9785253, theta=-39.587309 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=1.0246319, theta=-31.315636 -> V=1.0, theta=0.0
% INFO    : Bus 7160	: V=1.0116466, theta=-33.610369 -> V=1.0, theta=0.0
% INFO    : Bus 7161	: V=1.0013965, theta=-36.996483 -> V=1.0, theta=0.0
% INFO    : Bus 7162	: V=1.0334586, theta=-30.365682 -> V=1.0, theta=0.0
% INFO    : Bus 7163	: V=1.0381547, theta=-29.84716 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=1.0344526, theta=-30.245221 -> V=1.0, theta=0.0
% INFO    : Bus 7165	: V=1.033515, theta=-30.351678 -> V=1.0, theta=0.0
% INFO    : Bus 7166	: V=1.04, theta=-29.602421 -> V=1.0, theta=0.0
% INFO    : Bus 7167	: V=1.04, theta=-29.231157 -> V=1.0, theta=0.0
% INFO    : Bus 7168	: V=1.0347804, theta=-30.21216 -> V=1.0, theta=0.0
% INFO    : Bus 7169	: V=1.0329223, theta=-30.412133 -> V=1.0, theta=0.0
% INFO    : Bus 7170	: V=1.04, theta=-29.097528 -> V=1.0, theta=0.0
% INFO    : Bus 7171	: V=1.012522, theta=-31.611706 -> V=1.0, theta=0.0
% INFO    : Bus 7172	: V=1.0130216, theta=-33.767686 -> V=1.0, theta=0.0
% INFO    : Bus 7173	: V=0.9767976, theta=-40.468521 -> V=1.0, theta=0.0
% INFO    : Bus 7174	: V=0.9888966, theta=-35.891139 -> V=1.0, theta=0.0
% INFO    : Bus 7175	: V=1.0224548, theta=-32.45866 -> V=1.0, theta=0.0
% INFO    : Bus 7176	: V=1.0074744, theta=-34.836339 -> V=1.0, theta=0.0
% INFO    : Bus 7177	: V=0.9850025, theta=-39.655639 -> V=1.0, theta=0.0
% INFO    : Bus 7178	: V=0.9809384, theta=-40.62814 -> V=1.0, theta=0.0
% INFO    : Bus 7179	: V=0.9876968, theta=-37.536835 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=0.9881201, theta=-39.069418 -> V=1.0, theta=0.0
% INFO    : Bus 7181	: V=0.981272, theta=-40.54751 -> V=1.0, theta=0.0
% INFO    : Bus 7182	: V=0.9824496, theta=-40.519679 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=1.02, theta=-40.08188 -> V=1.0, theta=0.0
% INFO    : Bus 7184	: V=1.0167445, theta=-28.59447 -> V=1.0, theta=0.0
% INFO    : Bus 7185	: V=1.0060354, theta=-31.087515 -> V=1.0, theta=0.0
% INFO    : Bus 7186	: V=1.02292, theta=-26.830234 -> V=1.0, theta=0.0
% INFO    : Bus 7187	: V=1.0082568, theta=-31.263917 -> V=1.0, theta=0.0
% INFO    : Bus 7188	: V=0.9973159, theta=-36.382617 -> V=1.0, theta=0.0
% INFO    : Bus 7189	: V=1.0244044, theta=-26.672583 -> V=1.0, theta=0.0
% INFO    : Bus 7190	: V=1.03, theta=-25.442783 -> V=1.0, theta=0.0
% INFO    : Bus 7191	: V=1.02292, theta=-26.830234 -> V=1.0, theta=0.0
% INFO    : Bus 7192	: V=1.0293462, theta=-26.140142 -> V=1.0, theta=0.0
% INFO    : Bus 7193	: V=1.0239638, theta=-26.720203 -> V=1.0, theta=0.0
% INFO    : Bus 7194	: V=1.03, theta=-24.946595 -> V=1.0, theta=0.0
% INFO    : Bus 7195	: V=1.03, theta=-24.647155 -> V=1.0, theta=0.0
% INFO    : Bus 7196	: V=1.03, theta=-25.65831 -> V=1.0, theta=0.0
% INFO    : Bus 7197	: V=1.0299048, theta=-26.0788 -> V=1.0, theta=0.0
% INFO    : Bus 7198	: V=1.02, theta=-40.057986 -> V=1.0, theta=0.0
% INFO    : Bus 7199	: V=1.0211892, theta=-31.390498 -> V=1.0, theta=0.0
% INFO    : Bus 7200	: V=1.0086871, theta=-35.520765 -> V=1.0, theta=0.0
% INFO    : Bus 7201	: V=1.0059173, theta=-39.20213 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=0.9853626, theta=-42.994059 -> V=1.0, theta=0.0
% INFO    : Bus 7203	: V=0.9927872, theta=-34.122814 -> V=1.0, theta=0.0
% INFO    : Bus 7204	: V=1.0337236, theta=-24.518469 -> V=1.0, theta=0.0
% INFO    : Bus 7205	: V=1.0241681, theta=-27.640063 -> V=1.0, theta=0.0
% INFO    : Bus 7206	: V=1.0195164, theta=-31.735465 -> V=1.0, theta=0.0
% INFO    : Bus 7207	: V=1.0337236, theta=-24.518469 -> V=1.0, theta=0.0
% INFO    : Bus 7208	: V=1.04, theta=-20.769064 -> V=1.0, theta=0.0
% INFO    : Bus 7209	: V=1.04, theta=-21.923763 -> V=1.0, theta=0.0
% INFO    : Bus 7210	: V=1.04, theta=-22.449677 -> V=1.0, theta=0.0
% INFO    : Bus 7211	: V=1.04, theta=-23.031525 -> V=1.0, theta=0.0
% INFO    : Bus 7212	: V=1.04, theta=-22.097557 -> V=1.0, theta=0.0
% INFO    : Bus 7213	: V=1.0000986, theta=-35.77108 -> V=1.0, theta=0.0
% INFO    : Bus 7214	: V=0.9858099, theta=-37.756776 -> V=1.0, theta=0.0
% INFO    : Bus 7215	: V=0.9842558, theta=-41.204935 -> V=1.0, theta=0.0
% INFO    : Bus 7216	: V=0.9852337, theta=-39.093828 -> V=1.0, theta=0.0
% INFO    : Bus 7217	: V=0.9886059, theta=-39.192467 -> V=1.0, theta=0.0
% INFO    : Bus 7218	: V=0.9836069, theta=-42.735419 -> V=1.0, theta=0.0
% INFO    : Bus 7219	: V=0.9981012, theta=-36.7793 -> V=1.0, theta=0.0
% INFO    : Bus 7220	: V=0.9888217, theta=-39.155262 -> V=1.0, theta=0.0
% INFO    : Bus 7221	: V=0.9878622, theta=-38.833482 -> V=1.0, theta=0.0
% INFO    : Bus 7222	: V=0.9876384, theta=-37.757631 -> V=1.0, theta=0.0
% INFO    : Bus 7223	: V=0.9915919, theta=-39.091796 -> V=1.0, theta=0.0
% INFO    : Bus 7224	: V=0.9860973, theta=-39.365149 -> V=1.0, theta=0.0
% INFO    : Bus 7225	: V=0.9821239, theta=-41.071923 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=0.9943576, theta=-38.591911 -> V=1.0, theta=0.0
% INFO    : Bus 7227	: V=1.0252862, theta=-29.866898 -> V=1.0, theta=0.0
% INFO    : Bus 7228	: V=1.0076262, theta=-33.825499 -> V=1.0, theta=0.0
% INFO    : Bus 7229	: V=1.0007768, theta=-36.221085 -> V=1.0, theta=0.0
% INFO    : Bus 7230	: V=1.0034724, theta=-38.407952 -> V=1.0, theta=0.0
% INFO    : Bus 7231	: V=0.9956042, theta=-34.800269 -> V=1.0, theta=0.0
% INFO    : Bus 7232	: V=1.0149031, theta=-34.558085 -> V=1.0, theta=0.0
% INFO    : Bus 7233	: V=0.9830131, theta=-43.051383 -> V=1.0, theta=0.0
% INFO    : Bus 7234	: V=0.991912, theta=-40.902369 -> V=1.0, theta=0.0
% INFO    : Bus 7235	: V=1.02, theta=-42.347378 -> V=1.0, theta=0.0
% INFO    : Bus 7236	: V=1.02, theta=-41.022355 -> V=1.0, theta=0.0
% INFO    : Bus 7237	: V=0.9827633, theta=-38.831621 -> V=1.0, theta=0.0
% INFO    : Bus 7238	: V=1.016549, theta=-36.47764 -> V=1.0, theta=0.0
% INFO    : Bus 7239	: V=0.9951102, theta=-35.424593 -> V=1.0, theta=0.0
% INFO    : Bus 7240	: V=0.9972216, theta=-39.317732 -> V=1.0, theta=0.0
% INFO    : Bus 7241	: V=0.9838542, theta=-39.896736 -> V=1.0, theta=0.0
% INFO    : Bus 7242	: V=0.9848717, theta=-39.951895 -> V=1.0, theta=0.0
% INFO    : Bus 7243	: V=0.9936668, theta=-38.017051 -> V=1.0, theta=0.0
% INFO    : Bus 7244	: V=0.9894474, theta=-36.869563 -> V=1.0, theta=0.0
% INFO    : Bus 7245	: V=0.9917498, theta=-41.155192 -> V=1.0, theta=0.0
% INFO    : Bus 7246	: V=0.9767317, theta=-41.367276 -> V=1.0, theta=0.0
% INFO    : Bus 7247	: V=0.9926268, theta=-34.544355 -> V=1.0, theta=0.0
% INFO    : Bus 7248	: V=0.9823297, theta=-40.057874 -> V=1.0, theta=0.0
% INFO    : Bus 7249	: V=0.9857463, theta=-39.026662 -> V=1.0, theta=0.0
% INFO    : Bus 7250	: V=0.9969289, theta=-38.139542 -> V=1.0, theta=0.0
% INFO    : Bus 7251	: V=0.9896157, theta=-42.733576 -> V=1.0, theta=0.0
% INFO    : Bus 7252	: V=1.017083, theta=-29.96596 -> V=1.0, theta=0.0
% INFO    : Bus 7253	: V=1.0026492, theta=-33.209932 -> V=1.0, theta=0.0
% INFO    : Bus 7254	: V=1.0088152, theta=-42.016941 -> V=1.0, theta=0.0
% INFO    : Bus 7255	: V=0.9948268, theta=-37.032743 -> V=1.0, theta=0.0
% INFO    : Bus 7256	: V=0.9887749, theta=-38.142861 -> V=1.0, theta=0.0
% INFO    : Bus 7257	: V=0.9868027, theta=-36.862634 -> V=1.0, theta=0.0
% INFO    : Bus 7258	: V=0.9899728, theta=-38.136861 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=0.9983176, theta=-37.765313 -> V=1.0, theta=0.0
% INFO    : Bus 7260	: V=0.997128, theta=-35.855421 -> V=1.0, theta=0.0
% INFO    : Bus 7261	: V=1.0159234, theta=-26.4122 -> V=1.0, theta=0.0
% INFO    : Bus 7262	: V=1.02, theta=-28.512469 -> V=1.0, theta=0.0
% INFO    : Bus 7263	: V=1.0272757, theta=-24.770256 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=1.0192214, theta=-27.768401 -> V=1.0, theta=0.0
% INFO    : Bus 7265	: V=1.0023096, theta=-33.128019 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=1.0248623, theta=-23.493258 -> V=1.0, theta=0.0
% INFO    : Bus 7267	: V=1.0227154, theta=-22.558575 -> V=1.0, theta=0.0
% INFO    : Bus 7268	: V=1.026006, theta=-24.081747 -> V=1.0, theta=0.0
% INFO    : Bus 7269	: V=1.0230286, theta=-22.781375 -> V=1.0, theta=0.0
% INFO    : Bus 7270	: V=1.0250295, theta=-23.584777 -> V=1.0, theta=0.0
% INFO    : Bus 7271	: V=0.9885136, theta=-40.891701 -> V=1.0, theta=0.0
% INFO    : Bus 7272	: V=0.989351, theta=-37.609159 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=1.02, theta=-35.275216 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=1.0140366, theta=-34.251137 -> V=1.0, theta=0.0
% INFO    : Bus 7275	: V=1.0115516, theta=-36.014433 -> V=1.0, theta=0.0
% INFO    : Bus 7276	: V=1.009303, theta=-39.679339 -> V=1.0, theta=0.0
% INFO    : Bus 7277	: V=1.02, theta=-36.168155 -> V=1.0, theta=0.0
% INFO    : Bus 7278	: V=1.013357, theta=-29.938319 -> V=1.0, theta=0.0
% INFO    : Bus 7279	: V=1.0083658, theta=-33.188095 -> V=1.0, theta=0.0
% INFO    : Bus 7280	: V=1.013357, theta=-29.938319 -> V=1.0, theta=0.0
% INFO    : Bus 7281	: V=1.013357, theta=-29.938319 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=1.02029, theta=-28.412487 -> V=1.0, theta=0.0
% INFO    : Bus 7283	: V=1.0004525, theta=-32.878949 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=1.02029, theta=-28.412487 -> V=1.0, theta=0.0
% INFO    : Bus 7285	: V=1.0204049, theta=-27.366422 -> V=1.0, theta=0.0
% INFO    : Bus 7286	: V=1.0205227, theta=-26.005085 -> V=1.0, theta=0.0
% INFO    : Bus 7287	: V=1.0202972, theta=-26.328319 -> V=1.0, theta=0.0
% INFO    : Bus 7288	: V=1.0204958, theta=-26.193175 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=1.0205093, theta=-26.757718 -> V=1.0, theta=0.0
% INFO    : Bus 7290	: V=0.980972, theta=-41.543655 -> V=1.0, theta=0.0
% INFO    : Bus 7291	: V=0.9719395, theta=-41.051491 -> V=1.0, theta=0.0
% INFO    : Bus 7292	: V=0.9970579, theta=-38.072624 -> V=1.0, theta=0.0
% INFO    : Bus 7293	: V=0.9993127, theta=-35.122295 -> V=1.0, theta=0.0
% INFO    : Bus 7294	: V=1.02, theta=-33.027867 -> V=1.0, theta=0.0
% INFO    : Bus 7295	: V=0.983818, theta=-40.023612 -> V=1.0, theta=0.0
% INFO    : Bus 7296	: V=0.9795305, theta=-40.610867 -> V=1.0, theta=0.0
% INFO    : Bus 7297	: V=0.9828466, theta=-38.532012 -> V=1.0, theta=0.0
% INFO    : Bus 7298	: V=0.9858147, theta=-39.810746 -> V=1.0, theta=0.0
% INFO    : Bus 7299	: V=0.9861781, theta=-37.409658 -> V=1.0, theta=0.0
% INFO    : Bus 7300	: V=1.02, theta=-42.057317 -> V=1.0, theta=0.0
% INFO    : Bus 7301	: V=0.98493, theta=-36.638558 -> V=1.0, theta=0.0
% INFO    : Bus 7302	: V=1.0023339, theta=-31.292994 -> V=1.0, theta=0.0
% INFO    : Bus 7303	: V=1.009455, theta=-34.284925 -> V=1.0, theta=0.0
% INFO    : Bus 7304	: V=1.021028, theta=-24.842832 -> V=1.0, theta=0.0
% INFO    : Bus 7305	: V=1.0174411, theta=-28.925143 -> V=1.0, theta=0.0
% INFO    : Bus 7306	: V=1.0056465, theta=-33.464884 -> V=1.0, theta=0.0
% INFO    : Bus 7307	: V=1.0315048, theta=-23.714513 -> V=1.0, theta=0.0
% INFO    : Bus 7308	: V=1.0308872, theta=-23.766251 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=1.021028, theta=-24.842832 -> V=1.0, theta=0.0
% INFO    : Bus 7310	: V=1.0389985, theta=-22.882074 -> V=1.0, theta=0.0
% INFO    : Bus 7311	: V=1.0323257, theta=-23.624418 -> V=1.0, theta=0.0
% INFO    : Bus 7312	: V=1.0228524, theta=-29.221501 -> V=1.0, theta=0.0
% INFO    : Bus 7313	: V=1.0036803, theta=-32.856105 -> V=1.0, theta=0.0
% INFO    : Bus 7314	: V=0.9801294, theta=-40.589037 -> V=1.0, theta=0.0
% INFO    : Bus 7315	: V=1.0041188, theta=-40.256651 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=0.9848857, theta=-37.765528 -> V=1.0, theta=0.0
% INFO    : Bus 7317	: V=0.9927256, theta=-35.694781 -> V=1.0, theta=0.0
% INFO    : Bus 7318	: V=0.9817293, theta=-37.995675 -> V=1.0, theta=0.0
% INFO    : Bus 7319	: V=0.984279, theta=-39.852701 -> V=1.0, theta=0.0
% INFO    : Bus 7320	: V=1.0343309, theta=-27.490988 -> V=1.0, theta=0.0
% INFO    : Bus 7321	: V=1.0269042, theta=-28.786486 -> V=1.0, theta=0.0
% INFO    : Bus 7322	: V=1.01341, theta=-32.101226 -> V=1.0, theta=0.0
% INFO    : Bus 7323	: V=1.031574, theta=-27.054888 -> V=1.0, theta=0.0
% INFO    : Bus 7324	: V=1.0305261, theta=-26.902252 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=1.030498, theta=-26.899335 -> V=1.0, theta=0.0
% INFO    : Bus 7326	: V=1.0324888, theta=-27.202994 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=1.0202572, theta=-29.489388 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=1.0134969, theta=-31.163094 -> V=1.0, theta=0.0
% INFO    : Bus 7329	: V=1.04, theta=-28.709321 -> V=1.0, theta=0.0
% INFO    : Bus 7330	: V=0.9886133, theta=-38.995872 -> V=1.0, theta=0.0
% INFO    : Bus 7331	: V=1.0260853, theta=-26.864459 -> V=1.0, theta=0.0
% INFO    : Bus 7332	: V=1.0132386, theta=-29.740447 -> V=1.0, theta=0.0
% INFO    : Bus 7333	: V=0.996697, theta=-35.366118 -> V=1.0, theta=0.0
% INFO    : Bus 7334	: V=1.0260853, theta=-26.864459 -> V=1.0, theta=0.0
% INFO    : Bus 7335	: V=1.04, theta=-26.190361 -> V=1.0, theta=0.0
% INFO    : Bus 7336	: V=0.9988208, theta=-37.340748 -> V=1.0, theta=0.0
% INFO    : Bus 7337	: V=1.0024036, theta=-37.289513 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=0.98803, theta=-37.884801 -> V=1.0, theta=0.0
% INFO    : Bus 7339	: V=0.9990177, theta=-33.228432 -> V=1.0, theta=0.0
% INFO    : Bus 7340	: V=0.9793425, theta=-40.852041 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=1.0173175, theta=-27.500714 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=1.0059637, theta=-32.758672 -> V=1.0, theta=0.0
% INFO    : Bus 7343	: V=0.9787817, theta=-38.048324 -> V=1.0, theta=0.0
% INFO    : Bus 7344	: V=0.9797261, theta=-40.409409 -> V=1.0, theta=0.0
% INFO    : Bus 7345	: V=0.9898532, theta=-37.290583 -> V=1.0, theta=0.0
% INFO    : Bus 7346	: V=1.0323519, theta=-24.130807 -> V=1.0, theta=0.0
% INFO    : Bus 7347	: V=1.0198246, theta=-27.878001 -> V=1.0, theta=0.0
% INFO    : Bus 7348	: V=1.0096868, theta=-31.544046 -> V=1.0, theta=0.0
% INFO    : Bus 7349	: V=1.04, theta=-23.196451 -> V=1.0, theta=0.0
% INFO    : Bus 7350	: V=1.04, theta=-21.889339 -> V=1.0, theta=0.0
% INFO    : Bus 7351	: V=1.04, theta=-21.157837 -> V=1.0, theta=0.0
% INFO    : Bus 7352	: V=1.04, theta=-21.374649 -> V=1.0, theta=0.0
% INFO    : Bus 7353	: V=1.04, theta=-20.316938 -> V=1.0, theta=0.0
% INFO    : Bus 7354	: V=1.04, theta=-22.01779 -> V=1.0, theta=0.0
% INFO    : Bus 7355	: V=1.04, theta=-21.998822 -> V=1.0, theta=0.0
% INFO    : Bus 7356	: V=1.04, theta=-22.217919 -> V=1.0, theta=0.0
% INFO    : Bus 7357	: V=1.0356954, theta=-23.77949 -> V=1.0, theta=0.0
% INFO    : Bus 7358	: V=1.04, theta=-21.584766 -> V=1.0, theta=0.0
% INFO    : Bus 7359	: V=1.04, theta=-23.050971 -> V=1.0, theta=0.0
% INFO    : Bus 7360	: V=1.04, theta=-22.322006 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=1.04, theta=-22.788518 -> V=1.0, theta=0.0
% INFO    : Bus 7362	: V=0.9834327, theta=-39.636696 -> V=1.0, theta=0.0
% INFO    : Bus 7363	: V=0.9971705, theta=-35.642934 -> V=1.0, theta=0.0
% INFO    : Bus 7364	: V=0.9813207, theta=-38.808081 -> V=1.0, theta=0.0
% INFO    : Bus 7365	: V=0.9905108, theta=-38.767329 -> V=1.0, theta=0.0
% INFO    : Bus 7366	: V=1.029746, theta=-25.48785 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=1.0143242, theta=-29.93556 -> V=1.0, theta=0.0
% INFO    : Bus 7368	: V=1.0019398, theta=-34.639163 -> V=1.0, theta=0.0
% INFO    : Bus 7369	: V=1.04, theta=-23.640879 -> V=1.0, theta=0.0
% INFO    : Bus 7370	: V=1.04, theta=-23.139642 -> V=1.0, theta=0.0
% INFO    : Bus 7371	: V=1.04, theta=-23.547654 -> V=1.0, theta=0.0
% INFO    : Bus 7372	: V=1.04, theta=-23.686789 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=1.0360172, theta=-24.810559 -> V=1.0, theta=0.0
% INFO    : Bus 7374	: V=1.04, theta=-24.037211 -> V=1.0, theta=0.0
% INFO    : Bus 7375	: V=1.04, theta=-22.843241 -> V=1.0, theta=0.0
% INFO    : Bus 7376	: V=1.04, theta=-23.04769 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=1.04, theta=-23.637084 -> V=1.0, theta=0.0
% INFO    : Bus 7378	: V=1.04, theta=-23.160045 -> V=1.0, theta=0.0
% INFO    : Bus 7379	: V=1.04, theta=-23.337889 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=1.0052299, theta=-33.245411 -> V=1.0, theta=0.0
% INFO    : Bus 7381	: V=0.9912422, theta=-39.57174 -> V=1.0, theta=0.0
% INFO    : Bus 7382	: V=0.9851075, theta=-38.338585 -> V=1.0, theta=0.0
% INFO    : Bus 7383	: V=0.9925314, theta=-34.045312 -> V=1.0, theta=0.0
% INFO    : Bus 7384	: V=0.9844195, theta=-39.146531 -> V=1.0, theta=0.0
% INFO    : Bus 7385	: V=0.9854974, theta=-40.431551 -> V=1.0, theta=0.0
% INFO    : Bus 7386	: V=0.9895974, theta=-39.30438 -> V=1.0, theta=0.0
% INFO    : Bus 7387	: V=0.9798729, theta=-39.679151 -> V=1.0, theta=0.0
% INFO    : Bus 7388	: V=0.9922309, theta=-39.969651 -> V=1.0, theta=0.0
% INFO    : Bus 7389	: V=1.0308025, theta=-34.570962 -> V=1.0, theta=0.0
% INFO    : Bus 7390	: V=1.0199605, theta=-37.300025 -> V=1.0, theta=0.0
% INFO    : Bus 7391	: V=1.0044436, theta=-39.192463 -> V=1.0, theta=0.0
% INFO    : Bus 7392	: V=1.0053537, theta=-34.972694 -> V=1.0, theta=0.0
% INFO    : Bus 7393	: V=0.9963403, theta=-34.422625 -> V=1.0, theta=0.0
% INFO    : Bus 7394	: V=0.9828875, theta=-38.527518 -> V=1.0, theta=0.0
% INFO    : Bus 7395	: V=0.9908102, theta=-39.930811 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=0.9849088, theta=-39.11739 -> V=1.0, theta=0.0
% INFO    : Bus 7397	: V=1.0117649, theta=-39.994087 -> V=1.0, theta=0.0
% INFO    : Bus 7398	: V=0.9964661, theta=-35.997159 -> V=1.0, theta=0.0
% INFO    : Bus 7399	: V=0.992992, theta=-37.708448 -> V=1.0, theta=0.0
% INFO    : Bus 7400	: V=1.0258734, theta=-26.096847 -> V=1.0, theta=0.0
% INFO    : Bus 7401	: V=1.0160442, theta=-29.208588 -> V=1.0, theta=0.0
% INFO    : Bus 7402	: V=1.0046904, theta=-33.898802 -> V=1.0, theta=0.0
% INFO    : Bus 7403	: V=0.9959994, theta=-35.573248 -> V=1.0, theta=0.0
% INFO    : Bus 7404	: V=0.9812995, theta=-40.852457 -> V=1.0, theta=0.0
% INFO    : Bus 7405	: V=1.0082349, theta=-34.437576 -> V=1.0, theta=0.0
% INFO    : Bus 7406	: V=1.0201151, theta=-29.008011 -> V=1.0, theta=0.0
% INFO    : Bus 7407	: V=1.0178759, theta=-30.089312 -> V=1.0, theta=0.0
% INFO    : Bus 7408	: V=0.9981157, theta=-33.229044 -> V=1.0, theta=0.0
% INFO    : Bus 7409	: V=1.0045676, theta=-33.390827 -> V=1.0, theta=0.0
% INFO    : Bus 7410	: V=0.9881384, theta=-38.19117 -> V=1.0, theta=0.0
% INFO    : Bus 7411	: V=0.9875598, theta=-41.450979 -> V=1.0, theta=0.0
% INFO    : Bus 7412	: V=0.99753, theta=-34.437754 -> V=1.0, theta=0.0
% INFO    : Bus 7413	: V=0.9981364, theta=-35.477165 -> V=1.0, theta=0.0
% INFO    : Bus 7414	: V=1.0219843, theta=-32.101961 -> V=1.0, theta=0.0
% INFO    : Bus 7415	: V=1.0163377, theta=-32.549503 -> V=1.0, theta=0.0
% INFO    : Bus 7416	: V=1.0098485, theta=-34.735217 -> V=1.0, theta=0.0
% INFO    : Bus 7417	: V=0.9990376, theta=-38.871954 -> V=1.0, theta=0.0
% INFO    : Bus 7418	: V=1.0000798, theta=-38.436568 -> V=1.0, theta=0.0
% INFO    : Bus 7419	: V=1.0, theta=-33.695264 -> V=1.0, theta=0.0
% INFO    : Bus 7420	: V=1.0033509, theta=-36.808768 -> V=1.0, theta=0.0
% INFO    : Bus 7421	: V=0.9873732, theta=-41.545383 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=1.04, theta=-27.550633 -> V=1.0, theta=0.0
% INFO    : Bus 7423	: V=1.0200636, theta=-30.318818 -> V=1.0, theta=0.0
% INFO    : Bus 7424	: V=1.0010212, theta=-34.386346 -> V=1.0, theta=0.0
% INFO    : Bus 7425	: V=0.981958, theta=-41.048138 -> V=1.0, theta=0.0
% INFO    : Bus 7426	: V=0.9877318, theta=-33.240854 -> V=1.0, theta=0.0
% INFO    : Bus 7427	: V=0.9816208, theta=-40.753567 -> V=1.0, theta=0.0
% INFO    : Bus 7428	: V=1.04, theta=-27.614319 -> V=1.0, theta=0.0
% INFO    : Bus 7429	: V=1.0275228, theta=-28.548117 -> V=1.0, theta=0.0
% INFO    : Bus 7430	: V=1.0070402, theta=-32.339121 -> V=1.0, theta=0.0
% INFO    : Bus 7431	: V=0.9901473, theta=-40.368073 -> V=1.0, theta=0.0
% INFO    : Bus 7432	: V=1.0010677, theta=-59.954634 -> V=1.0, theta=0.0
% INFO    : Bus 8001	: V=1.0154124, theta=-57.861966 -> V=1.0, theta=0.0
% INFO    : Bus 8002	: V=1.0070921, theta=-71.026386 -> V=1.0, theta=0.0
% INFO    : Bus 8003	: V=1.02, theta=-59.229985 -> V=1.0, theta=0.0
% INFO    : Bus 8004	: V=1.0161603, theta=-58.626266 -> V=1.0, theta=0.0
% INFO    : Bus 8005	: V=1.02, theta=-59.872644 -> V=1.0, theta=0.0
% INFO    : Bus 8006	: V=1.02, theta=-68.00605 -> V=1.0, theta=0.0
% INFO    : Bus 8007	: V=1.0046032, theta=-68.965794 -> V=1.0, theta=0.0
% INFO    : Bus 8008	: V=0.9793656, theta=-71.766523 -> V=1.0, theta=0.0
% INFO    : Bus 8009	: V=0.9904705, theta=-43.352914 -> V=1.0, theta=0.0
% INFO    : Bus 8010	: V=1.014586, theta=-56.594488 -> V=1.0, theta=0.0
% INFO    : Bus 8011	: V=0.999424, theta=-61.905312 -> V=1.0, theta=0.0
% INFO    : Bus 8012	: V=1.0085327, theta=-42.538597 -> V=1.0, theta=0.0
% INFO    : Bus 8013	: V=0.9960636, theta=-72.259569 -> V=1.0, theta=0.0
% INFO    : Bus 8014	: V=0.9893511, theta=-64.690094 -> V=1.0, theta=0.0
% INFO    : Bus 8015	: V=0.9989699, theta=-64.440498 -> V=1.0, theta=0.0
% INFO    : Bus 8016	: V=1.02, theta=-48.019975 -> V=1.0, theta=0.0
% INFO    : Bus 8017	: V=0.996993, theta=-69.148445 -> V=1.0, theta=0.0
% INFO    : Bus 8018	: V=1.0149819, theta=-64.594299 -> V=1.0, theta=0.0
% INFO    : Bus 8019	: V=1.02, theta=-68.925975 -> V=1.0, theta=0.0
% INFO    : Bus 8020	: V=0.9848407, theta=-71.235609 -> V=1.0, theta=0.0
% INFO    : Bus 8021	: V=1.0129316, theta=-64.205098 -> V=1.0, theta=0.0
% INFO    : Bus 8022	: V=1.0175067, theta=-65.027051 -> V=1.0, theta=0.0
% INFO    : Bus 8023	: V=1.0132456, theta=-61.228891 -> V=1.0, theta=0.0
% INFO    : Bus 8024	: V=1.0149931, theta=-57.770634 -> V=1.0, theta=0.0
% INFO    : Bus 8025	: V=1.0198675, theta=-67.422849 -> V=1.0, theta=0.0
% INFO    : Bus 8026	: V=0.9849828, theta=-72.653265 -> V=1.0, theta=0.0
% INFO    : Bus 8027	: V=1.0119291, theta=-68.542732 -> V=1.0, theta=0.0
% INFO    : Bus 8028	: V=0.9970681, theta=-72.112984 -> V=1.0, theta=0.0
% INFO    : Bus 8029	: V=0.9808531, theta=-72.137199 -> V=1.0, theta=0.0
% INFO    : Bus 8030	: V=1.0256854, theta=-36.853099 -> V=1.0, theta=0.0
% INFO    : Bus 8031	: V=1.0214036, theta=-37.71737 -> V=1.0, theta=0.0
% INFO    : Bus 8032	: V=1.0132229, theta=-41.742691 -> V=1.0, theta=0.0
% INFO    : Bus 8033	: V=1.0256854, theta=-36.853099 -> V=1.0, theta=0.0
% INFO    : Bus 8034	: V=1.0256854, theta=-36.853099 -> V=1.0, theta=0.0
% INFO    : Bus 8035	: V=1.0256854, theta=-36.853099 -> V=1.0, theta=0.0
% INFO    : Bus 8036	: V=1.0256854, theta=-36.853099 -> V=1.0, theta=0.0
% INFO    : Bus 8037	: V=0.9937035, theta=-62.133501 -> V=1.0, theta=0.0
% INFO    : Bus 8038	: V=0.9925412, theta=-64.480236 -> V=1.0, theta=0.0
% INFO    : Bus 8039	: V=0.9906377, theta=-72.015544 -> V=1.0, theta=0.0
% INFO    : Bus 8040	: V=0.9859314, theta=-68.676719 -> V=1.0, theta=0.0
% INFO    : Bus 8041	: V=1.0117955, theta=-66.513025 -> V=1.0, theta=0.0
% INFO    : Bus 8042	: V=0.9915476, theta=-64.944249 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.0149102, theta=-54.867188 -> V=1.0, theta=0.0
% INFO    : Bus 8044	: V=1.0123318, theta=-57.056713 -> V=1.0, theta=0.0
% INFO    : Bus 8045	: V=1.008692, theta=-60.249936 -> V=1.0, theta=0.0
% INFO    : Bus 8046	: V=1.0123007, theta=-53.563576 -> V=1.0, theta=0.0
% INFO    : Bus 8047	: V=1.0149102, theta=-54.867188 -> V=1.0, theta=0.0
% INFO    : Bus 8048	: V=1.0376534, theta=-52.37178 -> V=1.0, theta=0.0
% INFO    : Bus 8049	: V=1.0133743, theta=-53.999145 -> V=1.0, theta=0.0
% INFO    : Bus 8050	: V=1.0149102, theta=-54.867188 -> V=1.0, theta=0.0
% INFO    : Bus 8051	: V=1.0149102, theta=-54.867188 -> V=1.0, theta=0.0
% INFO    : Bus 8052	: V=1.0095626, theta=-69.949077 -> V=1.0, theta=0.0
% INFO    : Bus 8053	: V=0.9819298, theta=-70.505296 -> V=1.0, theta=0.0
% INFO    : Bus 8054	: V=0.9905644, theta=-66.62181 -> V=1.0, theta=0.0
% INFO    : Bus 8055	: V=1.0142046, theta=-65.231421 -> V=1.0, theta=0.0
% INFO    : Bus 8056	: V=1.0158358, theta=-70.626743 -> V=1.0, theta=0.0
% INFO    : Bus 8057	: V=1.0236968, theta=-58.14123 -> V=1.0, theta=0.0
% INFO    : Bus 8058	: V=1.0157965, theta=-57.870691 -> V=1.0, theta=0.0
% INFO    : Bus 8059	: V=1.0107767, theta=-59.851233 -> V=1.0, theta=0.0
% INFO    : Bus 8060	: V=1.0236968, theta=-58.14123 -> V=1.0, theta=0.0
% INFO    : Bus 8061	: V=1.0236968, theta=-58.14123 -> V=1.0, theta=0.0
% INFO    : Bus 8062	: V=1.016968, theta=-61.489078 -> V=1.0, theta=0.0
% INFO    : Bus 8063	: V=0.996268, theta=-67.10215 -> V=1.0, theta=0.0
% INFO    : Bus 8064	: V=1.00755, theta=-60.415068 -> V=1.0, theta=0.0
% INFO    : Bus 8065	: V=0.9941836, theta=-66.767841 -> V=1.0, theta=0.0
% INFO    : Bus 8066	: V=0.995321, theta=-62.925639 -> V=1.0, theta=0.0
% INFO    : Bus 8067	: V=1.0119376, theta=-52.232943 -> V=1.0, theta=0.0
% INFO    : Bus 8068	: V=1.0172148, theta=-53.054855 -> V=1.0, theta=0.0
% INFO    : Bus 8069	: V=1.018187, theta=-54.435754 -> V=1.0, theta=0.0
% INFO    : Bus 8070	: V=1.0119376, theta=-52.232943 -> V=1.0, theta=0.0
% INFO    : Bus 8071	: V=1.0, theta=-46.740014 -> V=1.0, theta=0.0
% INFO    : Bus 8072	: V=0.9847605, theta=-65.502756 -> V=1.0, theta=0.0
% INFO    : Bus 8073	: V=0.9872891, theta=-71.843614 -> V=1.0, theta=0.0
% INFO    : Bus 8074	: V=1.0285011, theta=-51.277635 -> V=1.0, theta=0.0
% INFO    : Bus 8075	: V=1.0268502, theta=-54.455362 -> V=1.0, theta=0.0
% INFO    : Bus 8076	: V=1.0227133, theta=-58.384424 -> V=1.0, theta=0.0
% INFO    : Bus 8077	: V=1.03, theta=-48.916387 -> V=1.0, theta=0.0
% INFO    : Bus 8078	: V=1.03, theta=-48.79011 -> V=1.0, theta=0.0
% INFO    : Bus 8079	: V=1.03, theta=-49.340066 -> V=1.0, theta=0.0
% INFO    : Bus 8080	: V=1.03, theta=-49.045994 -> V=1.0, theta=0.0
% INFO    : Bus 8081	: V=0.9908967, theta=-71.321577 -> V=1.0, theta=0.0
% INFO    : Bus 8082	: V=1.0316333, theta=-46.78417 -> V=1.0, theta=0.0
% INFO    : Bus 8083	: V=1.0250297, theta=-49.552385 -> V=1.0, theta=0.0
% INFO    : Bus 8084	: V=1.0118832, theta=-53.912871 -> V=1.0, theta=0.0
% INFO    : Bus 8085	: V=1.0115713, theta=-54.430183 -> V=1.0, theta=0.0
% INFO    : Bus 8086	: V=1.0113669, theta=-55.809719 -> V=1.0, theta=0.0
% INFO    : Bus 8087	: V=1.0316333, theta=-46.78417 -> V=1.0, theta=0.0
% INFO    : Bus 8088	: V=1.04, theta=-43.964419 -> V=1.0, theta=0.0
% INFO    : Bus 8089	: V=1.0139703, theta=-70.143054 -> V=1.0, theta=0.0
% INFO    : Bus 8090	: V=1.0061551, theta=-68.009139 -> V=1.0, theta=0.0
% INFO    : Bus 8091	: V=1.02, theta=-63.476973 -> V=1.0, theta=0.0
% INFO    : Bus 8092	: V=0.9958807, theta=-67.309217 -> V=1.0, theta=0.0
% INFO    : Bus 8093	: V=1.0111602, theta=-59.43829 -> V=1.0, theta=0.0
% INFO    : Bus 8094	: V=1.0000519, theta=-43.092813 -> V=1.0, theta=0.0
% INFO    : Bus 8095	: V=0.989627, theta=-46.098378 -> V=1.0, theta=0.0
% INFO    : Bus 8096	: V=0.9896834, theta=-70.256825 -> V=1.0, theta=0.0
% INFO    : Bus 8097	: V=1.0236068, theta=-58.199305 -> V=1.0, theta=0.0
% INFO    : Bus 8098	: V=1.017562, theta=-61.696743 -> V=1.0, theta=0.0
% INFO    : Bus 8099	: V=1.0229234, theta=-53.65634 -> V=1.0, theta=0.0
% INFO    : Bus 8100	: V=1.0127833, theta=-70.02308 -> V=1.0, theta=0.0
% INFO    : Bus 8101	: V=0.9955535, theta=-65.360121 -> V=1.0, theta=0.0
% INFO    : Bus 8102	: V=1.0063333, theta=-51.432632 -> V=1.0, theta=0.0
% INFO    : Bus 8103	: V=1.0148887, theta=-55.64631 -> V=1.0, theta=0.0
% INFO    : Bus 8104	: V=1.0032874, theta=-43.563027 -> V=1.0, theta=0.0
% INFO    : Bus 8105	: V=1.0186087, theta=-56.374683 -> V=1.0, theta=0.0
% INFO    : Bus 8106	: V=1.0023568, theta=-60.324847 -> V=1.0, theta=0.0
% INFO    : Bus 8107	: V=1.02, theta=-61.023701 -> V=1.0, theta=0.0
% INFO    : Bus 8108	: V=0.9949295, theta=-72.677322 -> V=1.0, theta=0.0
% INFO    : Bus 8109	: V=0.9841612, theta=-67.780997 -> V=1.0, theta=0.0
% INFO    : Bus 8110	: V=1.0120432, theta=-67.549664 -> V=1.0, theta=0.0
% INFO    : Bus 8111	: V=1.0041215, theta=-63.44221 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=1.0299812, theta=-59.037645 -> V=1.0, theta=0.0
% INFO    : Bus 8113	: V=1.0255926, theta=-59.887946 -> V=1.0, theta=0.0
% INFO    : Bus 8114	: V=1.0208706, theta=-61.873912 -> V=1.0, theta=0.0
% INFO    : Bus 8115	: V=1.0299812, theta=-59.037645 -> V=1.0, theta=0.0
% INFO    : Bus 8116	: V=1.0299812, theta=-59.037645 -> V=1.0, theta=0.0
% INFO    : Bus 8117	: V=1.04, theta=-57.689152 -> V=1.0, theta=0.0
% INFO    : Bus 8118	: V=0.9942125, theta=-66.641962 -> V=1.0, theta=0.0
% INFO    : Bus 8119	: V=1.0180517, theta=-60.406378 -> V=1.0, theta=0.0
% INFO    : Bus 8120	: V=1.02, theta=-49.075401 -> V=1.0, theta=0.0
% INFO    : Bus 8121	: V=1.0097711, theta=-65.810016 -> V=1.0, theta=0.0
% INFO    : Bus 8122	: V=1.0120271, theta=-49.155763 -> V=1.0, theta=0.0
% INFO    : Bus 8123	: V=0.9886799, theta=-67.199688 -> V=1.0, theta=0.0
% INFO    : Bus 8124	: V=1.0007413, theta=-65.331558 -> V=1.0, theta=0.0
% INFO    : Bus 8125	: V=1.0057386, theta=-66.523122 -> V=1.0, theta=0.0
% INFO    : Bus 8126	: V=1.0317803, theta=-53.486857 -> V=1.0, theta=0.0
% INFO    : Bus 8127	: V=1.0296548, theta=-54.643581 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=1.0283219, theta=-56.957295 -> V=1.0, theta=0.0
% INFO    : Bus 8129	: V=1.03, theta=-51.756881 -> V=1.0, theta=0.0
% INFO    : Bus 8130	: V=1.03, theta=-49.170905 -> V=1.0, theta=0.0
% INFO    : Bus 8131	: V=1.03, theta=-51.2813 -> V=1.0, theta=0.0
% INFO    : Bus 8132	: V=0.9892636, theta=-65.161885 -> V=1.0, theta=0.0
% INFO    : Bus 8133	: V=1.0161024, theta=-63.537729 -> V=1.0, theta=0.0
% INFO    : Bus 8134	: V=1.0149822, theta=-66.570175 -> V=1.0, theta=0.0
% INFO    : Bus 8135	: V=1.0145415, theta=-69.719557 -> V=1.0, theta=0.0
% INFO    : Bus 8136	: V=0.99328, theta=-69.853108 -> V=1.0, theta=0.0
% INFO    : Bus 8137	: V=0.9998399, theta=-63.292469 -> V=1.0, theta=0.0
% INFO    : Bus 8138	: V=1.02, theta=-70.915872 -> V=1.0, theta=0.0
% INFO    : Bus 8139	: V=0.9968942, theta=-43.819994 -> V=1.0, theta=0.0
% INFO    : Bus 8140	: V=0.9906159, theta=-46.575094 -> V=1.0, theta=0.0
% INFO    : Bus 8141	: V=1.0048151, theta=-52.325946 -> V=1.0, theta=0.0
% INFO    : Bus 8142	: V=0.9944025, theta=-62.362288 -> V=1.0, theta=0.0
% INFO    : Bus 8143	: V=1.0108316, theta=-45.948648 -> V=1.0, theta=0.0
% INFO    : Bus 8144	: V=1.0025901, theta=-61.731595 -> V=1.0, theta=0.0
% INFO    : Bus 8145	: V=0.9995799, theta=-66.689799 -> V=1.0, theta=0.0
% INFO    : Bus 8146	: V=0.9937714, theta=-72.887444 -> V=1.0, theta=0.0
% INFO    : Bus 8147	: V=1.0082265, theta=-59.865546 -> V=1.0, theta=0.0
% INFO    : Bus 8148	: V=1.0027854, theta=-62.214098 -> V=1.0, theta=0.0
% INFO    : Bus 8149	: V=0.9942873, theta=-66.499437 -> V=1.0, theta=0.0
% INFO    : Bus 8150	: V=1.0034097, theta=-64.742015 -> V=1.0, theta=0.0
% INFO    : Bus 8151	: V=1.02, theta=-67.957417 -> V=1.0, theta=0.0
% INFO    : Bus 8152	: V=1.0172593, theta=-47.081348 -> V=1.0, theta=0.0
% INFO    : Bus 8153	: V=0.9864209, theta=-71.762511 -> V=1.0, theta=0.0
% INFO    : Bus 8154	: V=0.9980448, theta=-71.337128 -> V=1.0, theta=0.0
% INFO    : Bus 8155	: V=1.0270114, theta=-47.490401 -> V=1.0, theta=0.0
% INFO    : Bus 8156	: V=1.0158958, theta=-46.253077 -> V=1.0, theta=0.0
% INFO    : Bus 8157	: V=1.0102811, theta=-50.323335 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=1.0222086, theta=-38.944432 -> V=1.0, theta=0.0
% INFO    : Bus 8159	: V=1.02, theta=-42.356614 -> V=1.0, theta=0.0
% INFO    : Bus 8160	: V=1.0166512, theta=-45.575246 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 1004	: Pg=158.25, Qg=-30.38 -> Pg=158.25, Qg=7.28
% INFO    : Gen at bus 1004	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1006	: Pg=25.73, Qg=-4.35 -> Pg=25.73, Qg=1.185
% INFO    : Gen at bus 1006	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1009	: Pg=61.87, Qg=-11.88 -> Pg=61.87, Qg=2.845
% INFO    : Gen at bus 1009	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1011	: Pg=9.97, Qg=0.0 -> Pg=6.5, Qg=0.0
% INFO    : Gen at bus 1011	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1021	: Pg=149.63, Qg=-23.15 -> Pg=149.63, Qg=6.88
% INFO    : Gen at bus 1021	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1023	: Pg=135.0, Qg=2.26 -> Pg=135.0, Qg=6.21
% INFO    : Gen at bus 1023	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1026	: Pg=93.15, Qg=-3.42 -> Pg=93.15, Qg=4.285
% INFO    : Gen at bus 1026	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1033	: Pg=208.5, Qg=-40.03 -> Pg=208.5, Qg=9.59
% INFO    : Gen at bus 1033	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1035	: Pg=67.5, Qg=-6.87 -> Pg=67.5, Qg=3.105
% INFO    : Gen at bus 1035	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1039	: Pg=110.63, Qg=-16.65 -> Pg=110.63, Qg=5.09
% INFO    : Gen at bus 1039	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1042	: Pg=0.0, Qg=0.0 -> Pg=79.235, Qg=4.205
% INFO    : Gen at bus 1042	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1043	: Pg=44.1, Qg=-1.16 -> Pg=44.1, Qg=2.025
% INFO    : Gen at bus 1043	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1048	: Pg=0.0, Qg=0.0 -> Pg=211.38, Qg=64.715
% INFO    : Gen at bus 1048	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1049	: Pg=0.0, Qg=0.0 -> Pg=211.38, Qg=64.715
% INFO    : Gen at bus 1049	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1050	: Pg=89.15, Qg=-4.14 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 1050	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1051	: Pg=89.15, Qg=-2.88 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 1051	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1052	: Pg=89.15, Qg=-7.04 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 1052	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1053	: Pg=0.0, Qg=0.0 -> Pg=116.22, Qg=35.58
% INFO    : Gen at bus 1053	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1057	: Pg=0.0, Qg=0.0 -> Pg=78.0, Qg=4.14
% INFO    : Gen at bus 1057	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1059	: Pg=0.0, Qg=0.0 -> Pg=3.64, Qg=1.115
% INFO    : Gen at bus 1059	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 1060	: Pg=0.0, Qg=0.0 -> Pg=1.3, Qg=0.4
% INFO    : Gen at bus 1060	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 1062	: Pg=0.0, Qg=0.0 -> Pg=0.975, Qg=0.0
% INFO    : Gen at bus 1062	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1063	: Pg=0.0, Qg=0.0 -> Pg=149.5, Qg=0.0
% INFO    : Gen at bus 1063	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1066	: Pg=106.88, Qg=-0.83 -> Pg=106.88, Qg=4.915
% INFO    : Gen at bus 1066	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1070	: Pg=120.38, Qg=25.49 -> Pg=120.38, Qg=5.54
% INFO    : Gen at bus 1070	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 1072	: Pg=191.59, Qg=30.82 -> Pg=124.885, Qg=38.235
% INFO    : Gen at bus 1072	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1073	: Pg=191.59, Qg=35.97 -> Pg=124.885, Qg=38.235
% INFO    : Gen at bus 1073	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1074	: Pg=191.59, Qg=32.68 -> Pg=124.885, Qg=38.235
% INFO    : Gen at bus 1074	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1075	: Pg=191.59, Qg=34.38 -> Pg=124.885, Qg=38.235
% INFO    : Gen at bus 1075	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1076	: Pg=0.0, Qg=0.0 -> Pg=124.885, Qg=38.235
% INFO    : Gen at bus 1076	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1077	: Pg=0.0, Qg=0.0 -> Pg=124.885, Qg=38.235
% INFO    : Gen at bus 1077	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1078	: Pg=95.23, Qg=18.16 -> Pg=62.075, Qg=19.005
% INFO    : Gen at bus 1078	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1079	: Pg=95.23, Qg=-10.6 -> Pg=62.075, Qg=19.005
% INFO    : Gen at bus 1079	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1080	: Pg=95.23, Qg=14.9 -> Pg=62.075, Qg=19.005
% INFO    : Gen at bus 1080	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1081	: Pg=0.0, Qg=0.0 -> Pg=186.225, Qg=57.015
% INFO    : Gen at bus 1081	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1082	: Pg=112.5, Qg=-21.6 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 1082	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1084	: Pg=86.62, Qg=24.6 -> Pg=86.62, Qg=3.985
% INFO    : Gen at bus 1084	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 1088	: Pg=56.25, Qg=-0.29 -> Pg=56.25, Qg=2.585
% INFO    : Gen at bus 1088	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1090	: Pg=114.37, Qg=31.03 -> Pg=114.37, Qg=5.26
% INFO    : Gen at bus 1090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 1090	: Pg=27.0, Qg=7.67 -> Pg=27.0, Qg=1.245
% INFO    : Gen at bus 1090	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2004	: Pg=0.0, Qg=0.0 -> Pg=254.67, Qg=77.97
% INFO    : Gen at bus 2004	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2005	: Pg=0.0, Qg=0.0 -> Pg=254.67, Qg=77.97
% INFO    : Gen at bus 2005	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2006	: Pg=0.0, Qg=0.0 -> Pg=254.67, Qg=77.97
% INFO    : Gen at bus 2006	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2013	: Pg=150.45, Qg=-28.89 -> Pg=150.45, Qg=6.92
% INFO    : Gen at bus 2013	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2019	: Pg=0.0, Qg=0.0 -> Pg=141.7, Qg=7.52
% INFO    : Gen at bus 2019	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 2023	: Pg=83.1, Qg=18.16 -> Pg=54.165, Qg=16.585
% INFO    : Gen at bus 2023	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2024	: Pg=166.2, Qg=26.53 -> Pg=108.335, Qg=33.165
% INFO    : Gen at bus 2024	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2042	: Pg=59.7, Qg=-11.46 -> Pg=59.7, Qg=2.745
% INFO    : Gen at bus 2042	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 2056	: Pg=0.0, Qg=0.0 -> Pg=3.9, Qg=1.035
% INFO    : Gen at bus 2056	: Vg=0.99 -> Vg=1.0
% INFO    : Gen at bus 2057	: Pg=573.57, Qg=-47.07 -> Pg=468.0, Qg=123.84
% INFO    : Gen at bus 2057	: Vg=0.99 -> Vg=1.0
% INFO    : Gen at bus 2059	: Pg=60.0, Qg=-11.52 -> Pg=60.0, Qg=2.76
% INFO    : Gen at bus 2059	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2062	: Pg=101.55, Qg=-4.84 -> Pg=101.55, Qg=4.67
% INFO    : Gen at bus 2062	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2071	: Pg=112.5, Qg=-0.82 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 2071	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2076	: Pg=22.5, Qg=6.39 -> Pg=22.5, Qg=1.035
% INFO    : Gen at bus 2076	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 2078	: Pg=84.38, Qg=3.09 -> Pg=84.38, Qg=3.88
% INFO    : Gen at bus 2078	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2083	: Pg=19.94, Qg=10.18 -> Pg=13.0, Qg=3.98
% INFO    : Gen at bus 2083	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2084	: Pg=0.0, Qg=0.0 -> Pg=13.0, Qg=3.98
% INFO    : Gen at bus 2084	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2085	: Pg=0.0, Qg=0.0 -> Pg=26.0, Qg=7.96
% INFO    : Gen at bus 2085	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2089	: Pg=50.7, Qg=0.48 -> Pg=50.7, Qg=2.335
% INFO    : Gen at bus 2089	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2094	: Pg=0.0, Qg=0.0 -> Pg=6.5, Qg=0.345
% INFO    : Gen at bus 2094	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2095	: Pg=0.0, Qg=0.0 -> Pg=51.675, Qg=2.74
% INFO    : Gen at bus 2095	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2099	: Pg=7.5, Qg=-0.05 -> Pg=7.5, Qg=0.345
% INFO    : Gen at bus 2099	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2100	: Pg=112.5, Qg=0.58 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 2100	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 2103	: Pg=0.0, Qg=0.0 -> Pg=174.025, Qg=53.28
% INFO    : Gen at bus 2103	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2104	: Pg=0.0, Qg=0.0 -> Pg=174.025, Qg=53.28
% INFO    : Gen at bus 2104	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2105	: Pg=0.0, Qg=0.0 -> Pg=174.025, Qg=53.28
% INFO    : Gen at bus 2105	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2115	: Pg=184.2, Qg=-20.5 -> Pg=120.065, Qg=36.76
% INFO    : Gen at bus 2115	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2116	: Pg=184.2, Qg=-20.5 -> Pg=120.065, Qg=36.76
% INFO    : Gen at bus 2116	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2117	: Pg=184.2, Qg=-20.5 -> Pg=120.065, Qg=36.76
% INFO    : Gen at bus 2117	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2118	: Pg=184.2, Qg=-20.5 -> Pg=120.065, Qg=36.76
% INFO    : Gen at bus 2118	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2119	: Pg=184.2, Qg=-20.5 -> Pg=120.065, Qg=36.76
% INFO    : Gen at bus 2119	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2120	: Pg=184.2, Qg=-2.92 -> Pg=120.065, Qg=36.76
% INFO    : Gen at bus 2120	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 2123	: Pg=136.28, Qg=-26.16 -> Pg=136.28, Qg=6.27
% INFO    : Gen at bus 2123	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 2127	: Pg=216.45, Qg=-0.02 -> Pg=216.45, Qg=9.955
% INFO    : Gen at bus 2127	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3004	: Pg=28.13, Qg=-5.4 -> Pg=28.13, Qg=1.295
% INFO    : Gen at bus 3004	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3017	: Pg=127.13, Qg=3.68 -> Pg=127.13, Qg=5.845
% INFO    : Gen at bus 3017	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 3020	: Pg=112.5, Qg=12.59 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 3020	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 3028	: Pg=150.0, Qg=42.6 -> Pg=150.0, Qg=6.9
% INFO    : Gen at bus 3028	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3034	: Pg=97.87, Qg=18.15 -> Pg=97.87, Qg=4.505
% INFO    : Gen at bus 3034	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 3039	: Pg=156.75, Qg=44.52 -> Pg=156.75, Qg=7.21
% INFO    : Gen at bus 3039	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3043	: Pg=0.0, Qg=0.0 -> Pg=0.845, Qg=0.26
% INFO    : Gen at bus 3043	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3044	: Pg=0.0, Qg=0.0 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 3044	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3045	: Pg=0.0, Qg=0.0 -> Pg=290.55, Qg=88.95
% INFO    : Gen at bus 3045	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3048	: Pg=180.75, Qg=51.33 -> Pg=180.75, Qg=8.315
% INFO    : Gen at bus 3048	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3055	: Pg=183.88, Qg=50.05 -> Pg=183.88, Qg=8.46
% INFO    : Gen at bus 3055	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3056	: Pg=183.88, Qg=31.71 -> Pg=183.88, Qg=8.46
% INFO    : Gen at bus 3056	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3057	: Pg=183.88, Qg=30.31 -> Pg=183.88, Qg=8.46
% INFO    : Gen at bus 3057	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3060	: Pg=124.22, Qg=16.04 -> Pg=124.22, Qg=5.715
% INFO    : Gen at bus 3060	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3061	: Pg=124.22, Qg=17.93 -> Pg=124.22, Qg=5.715
% INFO    : Gen at bus 3061	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3062	: Pg=124.22, Qg=27.34 -> Pg=124.22, Qg=5.715
% INFO    : Gen at bus 3062	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3063	: Pg=124.22, Qg=20.41 -> Pg=124.22, Qg=5.715
% INFO    : Gen at bus 3063	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3065	: Pg=60.37, Qg=-8.38 -> Pg=60.37, Qg=2.78
% INFO    : Gen at bus 3065	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3068	: Pg=112.5, Qg=30.84 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 3068	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3071	: Pg=127.65, Qg=-24.51 -> Pg=127.65, Qg=5.87
% INFO    : Gen at bus 3071	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3074	: Pg=74.85, Qg=-1.88 -> Pg=74.85, Qg=3.445
% INFO    : Gen at bus 3074	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3081	: Pg=186.75, Qg=40.91 -> Pg=186.75, Qg=8.59
% INFO    : Gen at bus 3081	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3084	: Pg=174.37, Qg=-5.29 -> Pg=174.37, Qg=8.02
% INFO    : Gen at bus 3084	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3086	: Pg=56.25, Qg=-0.11 -> Pg=56.25, Qg=2.585
% INFO    : Gen at bus 3086	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3087	: Pg=0.0, Qg=0.0 -> Pg=48.75, Qg=2.585
% INFO    : Gen at bus 3087	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3092	: Pg=150.0, Qg=30.83 -> Pg=150.0, Qg=6.9
% INFO    : Gen at bus 3092	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3095	: Pg=90.45, Qg=21.16 -> Pg=90.45, Qg=4.16
% INFO    : Gen at bus 3095	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3098	: Pg=120.0, Qg=21.82 -> Pg=120.0, Qg=5.52
% INFO    : Gen at bus 3098	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3105	: Pg=44.5, Qg=-0.74 -> Pg=44.5, Qg=8.165
% INFO    : Gen at bus 3105	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3106	: Pg=53.02, Qg=-2.57 -> Pg=53.02, Qg=29.895
% INFO    : Gen at bus 3106	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3110	: Pg=63.0, Qg=13.69 -> Pg=63.0, Qg=2.895
% INFO    : Gen at bus 3110	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3112	: Pg=56.1, Qg=-1.51 -> Pg=56.1, Qg=2.58
% INFO    : Gen at bus 3112	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3113	: Pg=56.1, Qg=-0.82 -> Pg=56.1, Qg=2.58
% INFO    : Gen at bus 3113	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3117	: Pg=47.25, Qg=-3.77 -> Pg=47.25, Qg=2.175
% INFO    : Gen at bus 3117	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3118	: Pg=90.0, Qg=-6.63 -> Pg=90.0, Qg=4.14
% INFO    : Gen at bus 3118	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3120	: Pg=29.7, Qg=0.0 -> Pg=29.7, Qg=0.0
% INFO    : Gen at bus 3120	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3122	: Pg=147.75, Qg=-8.91 -> Pg=147.75, Qg=6.795
% INFO    : Gen at bus 3122	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3127	: Pg=101.25, Qg=-19.44 -> Pg=101.25, Qg=4.66
% INFO    : Gen at bus 3127	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3129	: Pg=94.88, Qg=-18.22 -> Pg=94.88, Qg=4.36
% INFO    : Gen at bus 3129	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 3131	: Pg=85.5, Qg=24.28 -> Pg=85.5, Qg=3.93
% INFO    : Gen at bus 3131	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 3133	: Pg=0.0, Qg=0.0 -> Pg=33.345, Qg=10.21
% INFO    : Gen at bus 3133	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3133	: Pg=0.0, Qg=0.0 -> Pg=33.345, Qg=10.21
% INFO    : Gen at bus 3133	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3133	: Pg=0.0, Qg=0.0 -> Pg=33.345, Qg=10.21
% INFO    : Gen at bus 3133	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 3137	: Pg=75.9, Qg=21.56 -> Pg=75.9, Qg=3.495
% INFO    : Gen at bus 3137	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 3141	: Pg=68.62, Qg=-13.18 -> Pg=68.62, Qg=3.155
% INFO    : Gen at bus 3141	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4010	: Pg=151.2, Qg=20.85 -> Pg=151.2, Qg=6.955
% INFO    : Gen at bus 4010	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4026	: Pg=408.86, Qg=57.46 -> Pg=266.5, Qg=70.52
% INFO    : Gen at bus 4026	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4030	: Pg=460.56, Qg=-23.08 -> Pg=404.56, Qg=107.055
% INFO    : Gen at bus 4030	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4045	: Pg=93.4, Qg=8.96 -> Pg=93.4, Qg=17.16
% INFO    : Gen at bus 4045	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4046	: Pg=28.5, Qg=2.93 -> Pg=28.5, Qg=5.235
% INFO    : Gen at bus 4046	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4047	: Pg=27.48, Qg=6.02 -> Pg=27.48, Qg=35.935
% INFO    : Gen at bus 4047	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4050	: Pg=150.0, Qg=-14.05 -> Pg=150.0, Qg=6.9
% INFO    : Gen at bus 4050	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4052	: Pg=44.08, Qg=22.5 -> Pg=28.73, Qg=8.795
% INFO    : Gen at bus 4052	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4058	: Pg=99.6, Qg=18.55 -> Pg=93.6, Qg=28.66
% INFO    : Gen at bus 4058	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4059	: Pg=84.08, Qg=19.72 -> Pg=93.6, Qg=28.66
% INFO    : Gen at bus 4059	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4060	: Pg=124.4, Qg=15.6 -> Pg=93.6, Qg=28.66
% INFO    : Gen at bus 4060	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4061	: Pg=148.87, Qg=20.61 -> Pg=112.015, Qg=34.295
% INFO    : Gen at bus 4061	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4062	: Pg=171.85, Qg=17.91 -> Pg=112.015, Qg=34.295
% INFO    : Gen at bus 4062	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4063	: Pg=124.75, Qg=20.79 -> Pg=112.015, Qg=34.295
% INFO    : Gen at bus 4063	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4065	: Pg=46.87, Qg=14.18 -> Pg=30.55, Qg=9.35
% INFO    : Gen at bus 4065	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4075	: Pg=0.0, Qg=0.0 -> Pg=114.615, Qg=35.09
% INFO    : Gen at bus 4075	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4076	: Pg=175.84, Qg=36.05 -> Pg=114.615, Qg=35.09
% INFO    : Gen at bus 4076	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4077	: Pg=97.06, Qg=28.93 -> Pg=114.615, Qg=35.09
% INFO    : Gen at bus 4077	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4082	: Pg=242.72, Qg=32.28 -> Pg=158.21, Qg=48.435
% INFO    : Gen at bus 4082	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4083	: Pg=242.72, Qg=33.27 -> Pg=158.21, Qg=48.435
% INFO    : Gen at bus 4083	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4084	: Pg=242.72, Qg=51.43 -> Pg=158.21, Qg=48.435
% INFO    : Gen at bus 4084	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4085	: Pg=168.05, Qg=54.88 -> Pg=228.8, Qg=70.05
% INFO    : Gen at bus 4085	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4090	: Pg=0.0, Qg=0.0 -> Pg=0.91, Qg=0.24
% INFO    : Gen at bus 4090	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4091	: Pg=23.43, Qg=3.95 -> Pg=15.275, Qg=4.04
% INFO    : Gen at bus 4091	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4092	: Pg=0.0, Qg=0.0 -> Pg=4.94, Qg=1.305
% INFO    : Gen at bus 4092	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4093	: Pg=27.92, Qg=2.53 -> Pg=18.2, Qg=4.815
% INFO    : Gen at bus 4093	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4094	: Pg=27.92, Qg=8.12 -> Pg=18.2, Qg=4.815
% INFO    : Gen at bus 4094	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4095	: Pg=27.92, Qg=3.75 -> Pg=18.2, Qg=4.815
% INFO    : Gen at bus 4095	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4096	: Pg=0.0, Qg=0.0 -> Pg=18.2, Qg=4.815
% INFO    : Gen at bus 4096	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4097	: Pg=27.92, Qg=3.29 -> Pg=18.2, Qg=4.815
% INFO    : Gen at bus 4097	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4098	: Pg=0.0, Qg=0.0 -> Pg=18.2, Qg=4.815
% INFO    : Gen at bus 4098	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4105	: Pg=135.0, Qg=26.12 -> Pg=135.0, Qg=6.21
% INFO    : Gen at bus 4105	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 4115	: Pg=131.43, Qg=37.25 -> Pg=85.67, Qg=26.23
% INFO    : Gen at bus 4115	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4116	: Pg=123.76, Qg=34.12 -> Pg=85.67, Qg=26.23
% INFO    : Gen at bus 4116	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4133	: Pg=0.0, Qg=0.0 -> Pg=21.84, Qg=6.685
% INFO    : Gen at bus 4133	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4134	: Pg=10.21, Qg=-3.73 -> Pg=21.84, Qg=6.685
% INFO    : Gen at bus 4134	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4135	: Pg=10.21, Qg=-3.73 -> Pg=21.84, Qg=6.685
% INFO    : Gen at bus 4135	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4136	: Pg=10.21, Qg=-3.73 -> Pg=21.84, Qg=6.685
% INFO    : Gen at bus 4136	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4137	: Pg=0.0, Qg=0.0 -> Pg=43.68, Qg=13.37
% INFO    : Gen at bus 4137	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4138	: Pg=0.0, Qg=0.0 -> Pg=42.9, Qg=13.13
% INFO    : Gen at bus 4138	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4142	: Pg=141.0, Qg=40.04 -> Pg=141.0, Qg=6.485
% INFO    : Gen at bus 4142	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4153	: Pg=212.4, Qg=60.32 -> Pg=212.4, Qg=9.77
% INFO    : Gen at bus 4153	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4160	: Pg=197.22, Qg=68.62 -> Pg=128.55, Qg=39.355
% INFO    : Gen at bus 4160	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4161	: Pg=87.79, Qg=28.72 -> Pg=128.55, Qg=39.355
% INFO    : Gen at bus 4161	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4162	: Pg=112.46, Qg=27.68 -> Pg=128.55, Qg=39.355
% INFO    : Gen at bus 4162	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4163	: Pg=0.0, Qg=0.0 -> Pg=5.85, Qg=1.79
% INFO    : Gen at bus 4163	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4166	: Pg=150.75, Qg=-28.94 -> Pg=150.75, Qg=6.935
% INFO    : Gen at bus 4166	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 4177	: Pg=112.5, Qg=8.16 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 4177	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4181	: Pg=150.07, Qg=42.62 -> Pg=150.07, Qg=6.905
% INFO    : Gen at bus 4181	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 4183	: Pg=152.25, Qg=43.24 -> Pg=152.25, Qg=7.005
% INFO    : Gen at bus 4183	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=74.79, Qg=21.27 -> Pg=48.75, Qg=14.92
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=183.26, Qg=21.27 -> Pg=119.45, Qg=36.57
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=0.0, Qg=0.0 -> Pg=15.6, Qg=4.78
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=60.83, Qg=21.27 -> Pg=39.65, Qg=12.14
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=10.37, Qg=5.29 -> Pg=6.76, Qg=2.07
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=136.48, Qg=21.27 -> Pg=173.55, Qg=53.13
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=155.9, Qg=21.27 -> Pg=173.55, Qg=53.13
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=155.9, Qg=21.27 -> Pg=173.55, Qg=53.13
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=183.26, Qg=21.27 -> Pg=119.45, Qg=36.57
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4192	: Pg=183.26, Qg=21.27 -> Pg=119.45, Qg=36.57
% INFO    : Gen at bus 4192	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4194	: Pg=151.2, Qg=42.94 -> Pg=151.2, Qg=6.955
% INFO    : Gen at bus 4194	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 4195	: Pg=69.0, Qg=-13.25 -> Pg=69.0, Qg=3.175
% INFO    : Gen at bus 4195	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5020	: Pg=90.0, Qg=-11.79 -> Pg=90.0, Qg=4.14
% INFO    : Gen at bus 5020	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5023	: Pg=0.0, Qg=0.0 -> Pg=3.12, Qg=0.955
% INFO    : Gen at bus 5023	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5035	: Pg=0.0, Qg=0.0 -> Pg=2.73, Qg=0.835
% INFO    : Gen at bus 5035	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5036	: Pg=0.0, Qg=0.0 -> Pg=4.16, Qg=1.275
% INFO    : Gen at bus 5036	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5037	: Pg=93.74, Qg=76.29 -> Pg=200.505, Qg=61.385
% INFO    : Gen at bus 5037	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5038	: Pg=93.74, Qg=74.11 -> Pg=200.505, Qg=61.385
% INFO    : Gen at bus 5038	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5039	: Pg=93.74, Qg=157.01 -> Pg=200.505, Qg=61.385
% INFO    : Gen at bus 5039	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5040	: Pg=93.74, Qg=55.86 -> Pg=200.505, Qg=61.385
% INFO    : Gen at bus 5040	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5041	: Pg=93.74, Qg=80.68 -> Pg=200.505, Qg=61.385
% INFO    : Gen at bus 5041	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5042	: Pg=93.74, Qg=69.22 -> Pg=200.505, Qg=61.385
% INFO    : Gen at bus 5042	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5051	: Pg=84.46, Qg=43.11 -> Pg=55.055, Qg=16.855
% INFO    : Gen at bus 5051	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 5057	: Pg=0.0, Qg=0.0 -> Pg=206.275, Qg=63.15
% INFO    : Gen at bus 5057	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5058	: Pg=251.16, Qg=-12.74 -> Pg=206.275, Qg=63.15
% INFO    : Gen at bus 5058	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5065	: Pg=10.57, Qg=5.4 -> Pg=6.89, Qg=2.11
% INFO    : Gen at bus 5065	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5066	: Pg=0.0, Qg=0.0 -> Pg=1.17, Qg=0.36
% INFO    : Gen at bus 5066	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5067	: Pg=437.05, Qg=194.05 -> Pg=284.875, Qg=87.215
% INFO    : Gen at bus 5067	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5068	: Pg=437.05, Qg=183.38 -> Pg=284.875, Qg=87.215
% INFO    : Gen at bus 5068	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5069	: Pg=437.05, Qg=172.2 -> Pg=284.875, Qg=87.215
% INFO    : Gen at bus 5069	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5089	: Pg=0.0, Qg=0.0 -> Pg=61.95, Qg=22.76
% INFO    : Gen at bus 5089	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5106	: Pg=0.0, Qg=0.0 -> Pg=7.02, Qg=1.855
% INFO    : Gen at bus 5106	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5107	: Pg=0.0, Qg=0.0 -> Pg=3.705, Qg=0.98
% INFO    : Gen at bus 5107	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5166	: Pg=126.15, Qg=64.39 -> Pg=82.225, Qg=25.175
% INFO    : Gen at bus 5166	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5167	: Pg=1.6, Qg=0.81 -> Pg=1.04, Qg=0.315
% INFO    : Gen at bus 5167	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5170	: Pg=45.0, Qg=-8.64 -> Pg=45.0, Qg=2.07
% INFO    : Gen at bus 5170	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5198	: Pg=112.5, Qg=-21.6 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 5198	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5206	: Pg=207.1, Qg=35.14 -> Pg=161.635, Qg=49.485
% INFO    : Gen at bus 5206	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5207	: Pg=180.01, Qg=63.0 -> Pg=161.635, Qg=49.485
% INFO    : Gen at bus 5207	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5208	: Pg=180.01, Qg=50.47 -> Pg=161.635, Qg=49.485
% INFO    : Gen at bus 5208	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5238	: Pg=168.75, Qg=-32.4 -> Pg=168.75, Qg=7.765
% INFO    : Gen at bus 5238	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5243	: Pg=112.5, Qg=-21.6 -> Pg=112.5, Qg=5.175
% INFO    : Gen at bus 5243	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5262	: Pg=1211.61, Qg=56.27 -> Pg=789.75, Qg=173.745
% INFO    : Gen at bus 5262	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5263	: Pg=1023.98, Qg=51.46 -> Pg=789.75, Qg=173.745
% INFO    : Gen at bus 5263	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5281	: Pg=266.98, Qg=-29.72 -> Pg=174.025, Qg=53.28
% INFO    : Gen at bus 5281	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5282	: Pg=266.98, Qg=-29.72 -> Pg=174.025, Qg=53.28
% INFO    : Gen at bus 5282	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5283	: Pg=0.0, Qg=0.0 -> Pg=174.025, Qg=53.28
% INFO    : Gen at bus 5283	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5297	: Pg=0.0, Qg=0.0 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 5297	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5298	: Pg=114.68, Qg=58.53 -> Pg=74.75, Qg=22.885
% INFO    : Gen at bus 5298	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5299	: Pg=114.68, Qg=58.53 -> Pg=74.75, Qg=22.885
% INFO    : Gen at bus 5299	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5300	: Pg=114.68, Qg=58.53 -> Pg=74.75, Qg=22.885
% INFO    : Gen at bus 5300	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5301	: Pg=82.47, Qg=42.09 -> Pg=53.755, Qg=16.455
% INFO    : Gen at bus 5301	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5302	: Pg=462.46, Qg=175.61 -> Pg=301.44, Qg=92.285
% INFO    : Gen at bus 5302	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5303	: Pg=462.46, Qg=229.47 -> Pg=301.44, Qg=92.285
% INFO    : Gen at bus 5303	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5319	: Pg=79.86, Qg=9.76 -> Pg=170.82, Qg=52.3
% INFO    : Gen at bus 5319	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5320	: Pg=0.0, Qg=0.0 -> Pg=170.82, Qg=52.3
% INFO    : Gen at bus 5320	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5321	: Pg=79.86, Qg=10.07 -> Pg=170.82, Qg=52.3
% INFO    : Gen at bus 5321	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5324	: Pg=283.28, Qg=144.59 -> Pg=184.645, Qg=56.53
% INFO    : Gen at bus 5324	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5325	: Pg=283.28, Qg=144.59 -> Pg=184.645, Qg=56.53
% INFO    : Gen at bus 5325	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5326	: Pg=283.28, Qg=144.59 -> Pg=184.645, Qg=56.53
% INFO    : Gen at bus 5326	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5342	: Pg=8.4, Qg=3.2 -> Pg=8.4, Qg=1.53
% INFO    : Gen at bus 5342	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5343	: Pg=207.5, Qg=69.11 -> Pg=207.5, Qg=38.12
% INFO    : Gen at bus 5343	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5360	: Pg=1005.19, Qg=-25.85 -> Pg=655.2, Qg=173.375
% INFO    : Gen at bus 5360	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5363	: Pg=10.37, Qg=-1.15 -> Pg=6.76, Qg=2.07
% INFO    : Gen at bus 5363	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5364	: Pg=212.73, Qg=-22.03 -> Pg=138.665, Qg=42.455
% INFO    : Gen at bus 5364	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5365	: Pg=212.73, Qg=-8.45 -> Pg=138.665, Qg=42.455
% INFO    : Gen at bus 5365	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5366	: Pg=212.73, Qg=-7.41 -> Pg=138.665, Qg=42.455
% INFO    : Gen at bus 5366	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5367	: Pg=212.73, Qg=-7.26 -> Pg=138.665, Qg=42.455
% INFO    : Gen at bus 5367	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5368	: Pg=212.73, Qg=-13.71 -> Pg=138.665, Qg=42.455
% INFO    : Gen at bus 5368	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5369	: Pg=212.73, Qg=-6.79 -> Pg=138.665, Qg=42.455
% INFO    : Gen at bus 5369	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5382	: Pg=63.51, Qg=106.38 -> Pg=135.85, Qg=41.59
% INFO    : Gen at bus 5382	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5383	: Pg=63.51, Qg=106.38 -> Pg=135.85, Qg=41.59
% INFO    : Gen at bus 5383	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5399	: Pg=124.2, Qg=35.27 -> Pg=124.2, Qg=5.71
% INFO    : Gen at bus 5399	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 5403	: Pg=89.15, Qg=45.5 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 5403	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5404	: Pg=77.23, Qg=45.5 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 5404	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5405	: Pg=84.77, Qg=45.5 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 5405	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5406	: Pg=89.15, Qg=45.5 -> Pg=58.11, Qg=17.79
% INFO    : Gen at bus 5406	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 5415	: Pg=121.66, Qg=-11.4 -> Pg=79.3, Qg=24.28
% INFO    : Gen at bus 5415	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5416	: Pg=121.66, Qg=-10.89 -> Pg=79.3, Qg=24.28
% INFO    : Gen at bus 5416	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5417	: Pg=121.66, Qg=-12.52 -> Pg=79.3, Qg=24.28
% INFO    : Gen at bus 5417	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5418	: Pg=118.47, Qg=-13.19 -> Pg=77.22, Qg=23.64
% INFO    : Gen at bus 5418	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5419	: Pg=118.47, Qg=-13.19 -> Pg=77.22, Qg=23.64
% INFO    : Gen at bus 5419	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5423	: Pg=12.37, Qg=-1.38 -> Pg=8.06, Qg=2.465
% INFO    : Gen at bus 5423	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5424	: Pg=0.0, Qg=0.0 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 5424	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=0.0, Qg=0.0 -> Pg=187.85, Qg=57.51
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=0.0, Qg=0.0 -> Pg=187.85, Qg=57.51
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=0.0, Qg=0.0 -> Pg=187.85, Qg=57.51
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=288.19, Qg=19.06 -> Pg=187.85, Qg=57.51
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=288.19, Qg=19.06 -> Pg=187.85, Qg=57.51
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=0.0, Qg=0.0 -> Pg=187.85, Qg=57.51
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=140.91, Qg=19.06 -> Pg=91.845, Qg=28.12
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=140.91, Qg=19.06 -> Pg=91.845, Qg=28.12
% INFO    : Gen at bus 5444	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 6006	: Pg=212.41, Qg=77.37 -> Pg=138.45, Qg=42.39
% INFO    : Gen at bus 6006	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6007	: Pg=0.0, Qg=0.0 -> Pg=276.9, Qg=84.77
% INFO    : Gen at bus 6007	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6008	: Pg=197.78, Qg=67.78 -> Pg=128.915, Qg=39.47
% INFO    : Gen at bus 6008	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6009	: Pg=197.78, Qg=42.18 -> Pg=128.915, Qg=39.47
% INFO    : Gen at bus 6009	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6010	: Pg=197.78, Qg=57.22 -> Pg=128.915, Qg=39.47
% INFO    : Gen at bus 6010	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6041	: Pg=0.0, Qg=20.48 -> Pg=0.0, Qg=9.8
% INFO    : Gen at bus 6041	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6042	: Pg=0.0, Qg=54.26 -> Pg=0.0, Qg=58.81
% INFO    : Gen at bus 6042	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6048	: Pg=0.0, Qg=0.0 -> Pg=2.21, Qg=0.675
% INFO    : Gen at bus 6048	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6049	: Pg=0.0, Qg=0.0 -> Pg=6.24, Qg=1.91
% INFO    : Gen at bus 6049	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6050	: Pg=0.0, Qg=0.0 -> Pg=2.86, Qg=0.875
% INFO    : Gen at bus 6050	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6051	: Pg=57.24, Qg=29.22 -> Pg=37.31, Qg=11.425
% INFO    : Gen at bus 6051	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6052	: Pg=0.0, Qg=0.0 -> Pg=37.31, Qg=11.425
% INFO    : Gen at bus 6052	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6053	: Pg=57.24, Qg=29.22 -> Pg=37.31, Qg=11.425
% INFO    : Gen at bus 6053	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6054	: Pg=57.24, Qg=29.22 -> Pg=37.31, Qg=11.425
% INFO    : Gen at bus 6054	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6069	: Pg=123.82, Qg=49.23 -> Pg=117.89, Qg=36.095
% INFO    : Gen at bus 6069	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6070	: Pg=131.29, Qg=21.36 -> Pg=117.89, Qg=36.095
% INFO    : Gen at bus 6070	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6071	: Pg=105.9, Qg=62.98 -> Pg=117.89, Qg=36.095
% INFO    : Gen at bus 6071	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6072	: Pg=0.0, Qg=0.0 -> Pg=117.89, Qg=36.095
% INFO    : Gen at bus 6072	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6073	: Pg=131.29, Qg=37.32 -> Pg=117.89, Qg=36.095
% INFO    : Gen at bus 6073	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6074	: Pg=131.29, Qg=36.8 -> Pg=117.89, Qg=36.095
% INFO    : Gen at bus 6074	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6078	: Pg=477.3, Qg=-68.73 -> Pg=366.165, Qg=96.89
% INFO    : Gen at bus 6078	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6079	: Pg=328.92, Qg=-68.73 -> Pg=366.165, Qg=96.89
% INFO    : Gen at bus 6079	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6080	: Pg=328.92, Qg=-68.73 -> Pg=366.165, Qg=96.89
% INFO    : Gen at bus 6080	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6082	: Pg=41.37, Qg=17.29 -> Pg=41.37, Qg=11.98
% INFO    : Gen at bus 6082	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6083	: Pg=65.3, Qg=11.97 -> Pg=65.3, Qg=11.98
% INFO    : Gen at bus 6083	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6085	: Pg=1.05, Qg=0.0 -> Pg=1.05, Qg=0.0
% INFO    : Gen at bus 6085	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6086	: Pg=22.5, Qg=0.0 -> Pg=22.5, Qg=0.0
% INFO    : Gen at bus 6086	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6087	: Pg=0.0, Qg=0.0 -> Pg=3.575, Qg=0.0
% INFO    : Gen at bus 6087	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6088	: Pg=7.95, Qg=0.0 -> Pg=7.95, Qg=0.0
% INFO    : Gen at bus 6088	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6089	: Pg=10.42, Qg=0.0 -> Pg=10.42, Qg=0.0
% INFO    : Gen at bus 6089	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6090	: Pg=30.52, Qg=0.0 -> Pg=30.52, Qg=0.0
% INFO    : Gen at bus 6090	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6104	: Pg=60.33, Qg=30.79 -> Pg=39.325, Qg=12.035
% INFO    : Gen at bus 6104	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6105	: Pg=60.33, Qg=30.79 -> Pg=39.325, Qg=12.035
% INFO    : Gen at bus 6105	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6106	: Pg=120.66, Qg=61.59 -> Pg=78.65, Qg=24.08
% INFO    : Gen at bus 6106	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6110	: Pg=301.18, Qg=100.76 -> Pg=383.89, Qg=101.585
% INFO    : Gen at bus 6110	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6111	: Pg=293.63, Qg=101.78 -> Pg=429.975, Qg=113.78
% INFO    : Gen at bus 6111	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6144	: Pg=0.0, Qg=0.0 -> Pg=5.46, Qg=1.675
% INFO    : Gen at bus 6144	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6145	: Pg=322.85, Qg=38.03 -> Pg=289.9, Qg=88.75
% INFO    : Gen at bus 6145	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6146	: Pg=322.85, Qg=39.39 -> Pg=289.9, Qg=88.75
% INFO    : Gen at bus 6146	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6147	: Pg=283.22, Qg=42.7 -> Pg=605.8, Qg=185.47
% INFO    : Gen at bus 6147	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6148	: Pg=0.0, Qg=0.0 -> Pg=469.3, Qg=143.68
% INFO    : Gen at bus 6148	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6149	: Pg=219.4, Qg=127.84 -> Pg=469.3, Qg=143.68
% INFO    : Gen at bus 6149	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6164	: Pg=71.43, Qg=38.3 -> Pg=152.785, Qg=46.775
% INFO    : Gen at bus 6164	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6165	: Pg=71.43, Qg=33.99 -> Pg=152.785, Qg=46.775
% INFO    : Gen at bus 6165	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6166	: Pg=71.43, Qg=82.0 -> Pg=152.785, Qg=46.775
% INFO    : Gen at bus 6166	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6167	: Pg=71.43, Qg=43.72 -> Pg=152.785, Qg=46.775
% INFO    : Gen at bus 6167	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 6213	: Pg=177.9, Qg=19.45 -> Pg=177.9, Qg=32.675
% INFO    : Gen at bus 6213	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6214	: Pg=552.3, Qg=55.54 -> Pg=552.3, Qg=101.465
% INFO    : Gen at bus 6214	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6215	: Pg=552.3, Qg=99.93 -> Pg=552.3, Qg=101.465
% INFO    : Gen at bus 6215	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6216	: Pg=552.3, Qg=58.81 -> Pg=552.3, Qg=101.465
% INFO    : Gen at bus 6216	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6242	: Pg=60.83, Qg=18.83 -> Pg=39.65, Qg=12.14
% INFO    : Gen at bus 6242	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6243	: Pg=182.49, Qg=45.89 -> Pg=118.95, Qg=36.42
% INFO    : Gen at bus 6243	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6244	: Pg=297.17, Qg=55.72 -> Pg=193.7, Qg=59.3
% INFO    : Gen at bus 6244	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6245	: Pg=297.17, Qg=64.31 -> Pg=193.7, Qg=59.3
% INFO    : Gen at bus 6245	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6246	: Pg=297.17, Qg=121.17 -> Pg=193.7, Qg=59.3
% INFO    : Gen at bus 6246	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6247	: Pg=182.82, Qg=93.32 -> Pg=119.165, Qg=36.485
% INFO    : Gen at bus 6247	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6248	: Pg=182.82, Qg=50.78 -> Pg=119.165, Qg=36.485
% INFO    : Gen at bus 6248	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6249	: Pg=182.82, Qg=35.11 -> Pg=119.165, Qg=36.485
% INFO    : Gen at bus 6249	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6257	: Pg=58.95, Qg=-9.89 -> Pg=126.1, Qg=38.61
% INFO    : Gen at bus 6257	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6258	: Pg=106.96, Qg=-5.6 -> Pg=126.1, Qg=38.61
% INFO    : Gen at bus 6258	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6259	: Pg=0.0, Qg=0.0 -> Pg=33.41, Qg=10.225
% INFO    : Gen at bus 6259	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6260	: Pg=78.1, Qg=-11.57 -> Pg=167.05, Qg=51.14
% INFO    : Gen at bus 6260	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6266	: Pg=4.5, Qg=1.72 -> Pg=4.5, Qg=0.825
% INFO    : Gen at bus 6266	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6267	: Pg=7.2, Qg=2.73 -> Pg=7.2, Qg=1.305
% INFO    : Gen at bus 6267	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6268	: Pg=4.5, Qg=1.72 -> Pg=4.5, Qg=0.825
% INFO    : Gen at bus 6268	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6269	: Pg=7.2, Qg=2.73 -> Pg=7.2, Qg=1.305
% INFO    : Gen at bus 6269	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6270	: Pg=0.0, Qg=0.0 -> Pg=9.0, Qg=3.265
% INFO    : Gen at bus 6270	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6271	: Pg=0.0, Qg=0.0 -> Pg=5.5, Qg=1.955
% INFO    : Gen at bus 6271	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6272	: Pg=0.0, Qg=0.0 -> Pg=3.6, Qg=1.305
% INFO    : Gen at bus 6272	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6273	: Pg=0.0, Qg=0.0 -> Pg=3.6, Qg=1.305
% INFO    : Gen at bus 6273	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6274	: Pg=8.4, Qg=3.2 -> Pg=8.4, Qg=1.53
% INFO    : Gen at bus 6274	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6295	: Pg=62.67, Qg=-22.89 -> Pg=134.05, Qg=41.04
% INFO    : Gen at bus 6295	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6296	: Pg=62.67, Qg=-22.89 -> Pg=134.05, Qg=41.04
% INFO    : Gen at bus 6296	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6297	: Pg=62.7, Qg=-15.02 -> Pg=134.065, Qg=41.04
% INFO    : Gen at bus 6297	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 6301	: Pg=0.0, Qg=0.0 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 6301	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6302	: Pg=246.56, Qg=-27.44 -> Pg=160.715, Qg=49.205
% INFO    : Gen at bus 6302	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6303	: Pg=213.83, Qg=-27.44 -> Pg=160.715, Qg=49.205
% INFO    : Gen at bus 6303	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6304	: Pg=246.56, Qg=-27.44 -> Pg=160.715, Qg=49.205
% INFO    : Gen at bus 6304	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6305	: Pg=246.56, Qg=-27.44 -> Pg=160.715, Qg=49.205
% INFO    : Gen at bus 6305	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=7.8, Qg=2.39
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=33.475, Qg=10.245
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=31.3, Qg=52.43 -> Pg=66.95, Qg=20.5
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=1.495, Qg=0.455
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=2.99, Qg=0.915
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=0.975, Qg=0.295
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=2.6, Qg=0.8
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=4.16, Qg=1.275
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=110.31, Qg=184.77 -> Pg=235.95, Qg=72.24
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=110.31, Qg=184.77 -> Pg=235.95, Qg=72.24
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 6349	: Pg=0.0, Qg=0.0 -> Pg=33.475, Qg=10.245
% INFO    : Gen at bus 6349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7005	: Pg=162.54, Qg=38.38 -> Pg=105.95, Qg=32.44
% INFO    : Gen at bus 7005	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7006	: Pg=162.54, Qg=67.22 -> Pg=105.95, Qg=32.44
% INFO    : Gen at bus 7006	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7007	: Pg=162.54, Qg=44.4 -> Pg=105.95, Qg=32.44
% INFO    : Gen at bus 7007	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7008	: Pg=162.54, Qg=41.68 -> Pg=105.95, Qg=32.44
% INFO    : Gen at bus 7008	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7009	: Pg=162.54, Qg=37.78 -> Pg=105.95, Qg=32.44
% INFO    : Gen at bus 7009	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7015	: Pg=0.0, Qg=0.0 -> Pg=2.6, Qg=0.8
% INFO    : Gen at bus 7015	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7021	: Pg=22.34, Qg=11.4 -> Pg=14.56, Qg=4.455
% INFO    : Gen at bus 7021	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7022	: Pg=47.27, Qg=24.13 -> Pg=30.81, Qg=9.435
% INFO    : Gen at bus 7022	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7023	: Pg=47.27, Qg=24.13 -> Pg=30.81, Qg=9.435
% INFO    : Gen at bus 7023	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7024	: Pg=94.54, Qg=48.25 -> Pg=61.62, Qg=18.865
% INFO    : Gen at bus 7024	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7025	: Pg=0.0, Qg=0.0 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 7025	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7031	: Pg=29.1, Qg=0.0 -> Pg=29.1, Qg=0.0
% INFO    : Gen at bus 7031	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7032	: Pg=7.5, Qg=0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 7032	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7033	: Pg=7.5, Qg=0.0 -> Pg=7.5, Qg=0.0
% INFO    : Gen at bus 7033	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7034	: Pg=0.0, Qg=0.0 -> Pg=2.86, Qg=0.0
% INFO    : Gen at bus 7034	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7045	: Pg=187.92, Qg=37.1 -> Pg=122.49, Qg=37.5
% INFO    : Gen at bus 7045	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7046	: Pg=187.92, Qg=78.22 -> Pg=122.49, Qg=37.5
% INFO    : Gen at bus 7046	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7061	: Pg=67.09, Qg=-12.75 -> Pg=74.685, Qg=22.865
% INFO    : Gen at bus 7061	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7062	: Pg=67.09, Qg=-12.75 -> Pg=74.685, Qg=22.865
% INFO    : Gen at bus 7062	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7063	: Pg=67.09, Qg=-12.75 -> Pg=74.685, Qg=22.865
% INFO    : Gen at bus 7063	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7064	: Pg=83.17, Qg=-12.75 -> Pg=74.685, Qg=22.865
% INFO    : Gen at bus 7064	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7065	: Pg=83.17, Qg=-12.75 -> Pg=74.685, Qg=22.865
% INFO    : Gen at bus 7065	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7066	: Pg=68.1, Qg=-12.75 -> Pg=74.685, Qg=22.865
% INFO    : Gen at bus 7066	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7079	: Pg=159.89, Qg=37.81 -> Pg=148.62, Qg=45.5
% INFO    : Gen at bus 7079	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7080	: Pg=165.51, Qg=29.6 -> Pg=148.62, Qg=45.5
% INFO    : Gen at bus 7080	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7081	: Pg=165.51, Qg=29.93 -> Pg=148.62, Qg=45.5
% INFO    : Gen at bus 7081	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7082	: Pg=165.51, Qg=36.62 -> Pg=148.62, Qg=45.5
% INFO    : Gen at bus 7082	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7098	: Pg=1240.67, Qg=199.11 -> Pg=880.295, Qg=193.665
% INFO    : Gen at bus 7098	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7099	: Pg=1350.52, Qg=6.01 -> Pg=880.295, Qg=193.665
% INFO    : Gen at bus 7099	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7107	: Pg=149.58, Qg=76.35 -> Pg=97.5, Qg=29.85
% INFO    : Gen at bus 7107	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7108	: Pg=50.86, Qg=20.02 -> Pg=33.15, Qg=10.15
% INFO    : Gen at bus 7108	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7109	: Pg=50.86, Qg=24.3 -> Pg=33.15, Qg=10.15
% INFO    : Gen at bus 7109	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7110	: Pg=195.45, Qg=49.93 -> Pg=127.4, Qg=39.0
% INFO    : Gen at bus 7110	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7111	: Pg=195.45, Qg=48.69 -> Pg=127.4, Qg=39.0
% INFO    : Gen at bus 7111	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7112	: Pg=195.45, Qg=77.51 -> Pg=127.4, Qg=39.0
% INFO    : Gen at bus 7112	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7113	: Pg=195.45, Qg=41.78 -> Pg=127.4, Qg=39.0
% INFO    : Gen at bus 7113	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7114	: Pg=195.45, Qg=82.31 -> Pg=127.4, Qg=39.0
% INFO    : Gen at bus 7114	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7115	: Pg=195.45, Qg=82.67 -> Pg=127.4, Qg=39.0
% INFO    : Gen at bus 7115	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7121	: Pg=0.0, Qg=0.0 -> Pg=2.405, Qg=0.735
% INFO    : Gen at bus 7121	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7122	: Pg=0.0, Qg=0.0 -> Pg=2.795, Qg=0.855
% INFO    : Gen at bus 7122	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7133	: Pg=16.25, Qg=-1.81 -> Pg=10.595, Qg=3.245
% INFO    : Gen at bus 7133	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7134	: Pg=205.97, Qg=-22.93 -> Pg=134.26, Qg=41.1
% INFO    : Gen at bus 7134	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7135	: Pg=205.97, Qg=-22.93 -> Pg=134.26, Qg=41.1
% INFO    : Gen at bus 7135	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7136	: Pg=205.97, Qg=-22.93 -> Pg=134.26, Qg=41.1
% INFO    : Gen at bus 7136	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7137	: Pg=205.97, Qg=-22.93 -> Pg=134.26, Qg=41.1
% INFO    : Gen at bus 7137	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7138	: Pg=379.64, Qg=-42.26 -> Pg=247.455, Qg=75.76
% INFO    : Gen at bus 7138	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7139	: Pg=58.84, Qg=-6.55 -> Pg=38.35, Qg=11.74
% INFO    : Gen at bus 7139	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7140	: Pg=58.84, Qg=-6.55 -> Pg=38.35, Qg=11.74
% INFO    : Gen at bus 7140	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7141	: Pg=58.84, Qg=-6.55 -> Pg=38.35, Qg=11.74
% INFO    : Gen at bus 7141	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7142	: Pg=58.84, Qg=-6.55 -> Pg=38.35, Qg=11.74
% INFO    : Gen at bus 7142	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7146	: Pg=10.17, Qg=-1.13 -> Pg=6.63, Qg=2.03
% INFO    : Gen at bus 7146	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 7162	: Pg=110.29, Qg=56.3 -> Pg=71.89, Qg=22.01
% INFO    : Gen at bus 7162	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7163	: Pg=110.29, Qg=56.3 -> Pg=71.89, Qg=22.01
% INFO    : Gen at bus 7163	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7164	: Pg=110.29, Qg=56.3 -> Pg=71.89, Qg=22.01
% INFO    : Gen at bus 7164	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7165	: Pg=110.29, Qg=56.3 -> Pg=71.89, Qg=22.01
% INFO    : Gen at bus 7165	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7166	: Pg=110.29, Qg=54.93 -> Pg=71.89, Qg=22.01
% INFO    : Gen at bus 7166	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7167	: Pg=110.29, Qg=45.65 -> Pg=71.9, Qg=22.01
% INFO    : Gen at bus 7167	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7168	: Pg=87.48, Qg=44.65 -> Pg=57.02, Qg=17.455
% INFO    : Gen at bus 7168	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7169	: Pg=87.48, Qg=44.65 -> Pg=57.01, Qg=17.455
% INFO    : Gen at bus 7169	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7170	: Pg=333.76, Qg=130.81 -> Pg=228.065, Qg=69.82
% INFO    : Gen at bus 7170	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7189	: Pg=6.88, Qg=3.51 -> Pg=4.485, Qg=1.37
% INFO    : Gen at bus 7189	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7190	: Pg=47.87, Qg=13.81 -> Pg=31.2, Qg=9.55
% INFO    : Gen at bus 7190	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7191	: Pg=0.0, Qg=0.0 -> Pg=3.25, Qg=1.0
% INFO    : Gen at bus 7191	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7192	: Pg=34.9, Qg=17.81 -> Pg=22.75, Qg=6.965
% INFO    : Gen at bus 7192	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7193	: Pg=7.48, Qg=3.82 -> Pg=4.875, Qg=1.495
% INFO    : Gen at bus 7193	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7194	: Pg=230.31, Qg=49.08 -> Pg=150.115, Qg=45.955
% INFO    : Gen at bus 7194	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7195	: Pg=230.31, Qg=42.27 -> Pg=150.115, Qg=45.955
% INFO    : Gen at bus 7195	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7196	: Pg=230.31, Qg=76.74 -> Pg=150.115, Qg=45.955
% INFO    : Gen at bus 7196	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7197	: Pg=230.31, Qg=117.55 -> Pg=150.115, Qg=45.955
% INFO    : Gen at bus 7197	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7207	: Pg=0.0, Qg=0.0 -> Pg=2.6, Qg=0.8
% INFO    : Gen at bus 7207	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7208	: Pg=762.86, Qg=84.91 -> Pg=497.25, Qg=152.235
% INFO    : Gen at bus 7208	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7209	: Pg=762.86, Qg=111.04 -> Pg=497.25, Qg=152.235
% INFO    : Gen at bus 7209	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7210	: Pg=178.0, Qg=29.21 -> Pg=116.025, Qg=35.525
% INFO    : Gen at bus 7210	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7211	: Pg=178.0, Qg=40.97 -> Pg=116.025, Qg=35.525
% INFO    : Gen at bus 7211	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7212	: Pg=178.0, Qg=26.57 -> Pg=116.025, Qg=35.525
% INFO    : Gen at bus 7212	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7266	: Pg=303.75, Qg=-33.81 -> Pg=197.99, Qg=60.615
% INFO    : Gen at bus 7266	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 7267	: Pg=90.39, Qg=-10.06 -> Pg=58.915, Qg=18.04
% INFO    : Gen at bus 7267	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 7268	: Pg=90.39, Qg=-10.06 -> Pg=58.915, Qg=18.04
% INFO    : Gen at bus 7268	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 7269	: Pg=90.39, Qg=-10.06 -> Pg=58.915, Qg=18.04
% INFO    : Gen at bus 7269	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 7270	: Pg=180.77, Qg=-20.12 -> Pg=117.83, Qg=36.075
% INFO    : Gen at bus 7270	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 7280	: Pg=0.0, Qg=0.0 -> Pg=16.705, Qg=5.115
% INFO    : Gen at bus 7280	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7281	: Pg=0.0, Qg=0.0 -> Pg=9.75, Qg=2.985
% INFO    : Gen at bus 7281	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7284	: Pg=0.0, Qg=0.0 -> Pg=4.875, Qg=0.0
% INFO    : Gen at bus 7284	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7285	: Pg=21.22, Qg=0.0 -> Pg=21.22, Qg=0.0
% INFO    : Gen at bus 7285	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7286	: Pg=21.22, Qg=0.0 -> Pg=21.22, Qg=0.0
% INFO    : Gen at bus 7286	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7287	: Pg=21.22, Qg=0.0 -> Pg=21.22, Qg=0.0
% INFO    : Gen at bus 7287	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7288	: Pg=21.22, Qg=0.0 -> Pg=21.22, Qg=0.0
% INFO    : Gen at bus 7288	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7289	: Pg=42.45, Qg=0.0 -> Pg=42.45, Qg=0.0
% INFO    : Gen at bus 7289	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7307	: Pg=96.41, Qg=49.21 -> Pg=62.84, Qg=19.24
% INFO    : Gen at bus 7307	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7308	: Pg=96.41, Qg=49.21 -> Pg=62.84, Qg=19.24
% INFO    : Gen at bus 7308	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7309	: Pg=0.0, Qg=0.0 -> Pg=62.84, Qg=19.24
% INFO    : Gen at bus 7309	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7310	: Pg=96.41, Qg=49.21 -> Pg=62.84, Qg=19.24
% INFO    : Gen at bus 7310	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7311	: Pg=192.83, Qg=98.42 -> Pg=125.69, Qg=38.48
% INFO    : Gen at bus 7311	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7323	: Pg=37.82, Qg=-13.82 -> Pg=80.91, Qg=24.77
% INFO    : Gen at bus 7323	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7324	: Pg=37.82, Qg=-13.82 -> Pg=80.91, Qg=24.77
% INFO    : Gen at bus 7324	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7325	: Pg=37.82, Qg=-13.82 -> Pg=80.91, Qg=24.77
% INFO    : Gen at bus 7325	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7326	: Pg=37.82, Qg=-13.82 -> Pg=80.91, Qg=24.77
% INFO    : Gen at bus 7326	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 7329	: Pg=30.97, Qg=42.25 -> Pg=66.235, Qg=20.28
% INFO    : Gen at bus 7329	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7334	: Pg=0.0, Qg=0.0 -> Pg=3.055, Qg=0.81
% INFO    : Gen at bus 7334	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7335	: Pg=137.81, Qg=153.88 -> Pg=294.775, Qg=78.0
% INFO    : Gen at bus 7335	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7349	: Pg=312.95, Qg=139.37 -> Pg=203.99, Qg=62.455
% INFO    : Gen at bus 7349	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7350	: Pg=312.95, Qg=60.08 -> Pg=203.99, Qg=62.455
% INFO    : Gen at bus 7350	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7351	: Pg=312.95, Qg=47.25 -> Pg=203.99, Qg=62.455
% INFO    : Gen at bus 7351	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7352	: Pg=312.95, Qg=49.14 -> Pg=203.99, Qg=62.455
% INFO    : Gen at bus 7352	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7353	: Pg=594.84, Qg=76.49 -> Pg=444.73, Qg=136.155
% INFO    : Gen at bus 7353	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7354	: Pg=591.07, Qg=124.13 -> Pg=444.73, Qg=136.155
% INFO    : Gen at bus 7354	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7355	: Pg=591.07, Qg=123.23 -> Pg=444.73, Qg=136.155
% INFO    : Gen at bus 7355	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7356	: Pg=591.02, Qg=128.79 -> Pg=444.6, Qg=136.155
% INFO    : Gen at bus 7356	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7357	: Pg=16.25, Qg=8.3 -> Pg=10.595, Qg=3.245
% INFO    : Gen at bus 7357	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7358	: Pg=224.57, Qg=39.17 -> Pg=146.38, Qg=44.815
% INFO    : Gen at bus 7358	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7359	: Pg=224.57, Qg=86.67 -> Pg=146.38, Qg=44.815
% INFO    : Gen at bus 7359	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7360	: Pg=224.57, Qg=52.95 -> Pg=146.38, Qg=44.815
% INFO    : Gen at bus 7360	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7361	: Pg=102.41, Qg=32.4 -> Pg=66.755, Qg=20.435
% INFO    : Gen at bus 7361	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7369	: Pg=106.97, Qg=32.85 -> Pg=69.725, Qg=21.345
% INFO    : Gen at bus 7369	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7370	: Pg=106.97, Qg=26.39 -> Pg=69.725, Qg=21.345
% INFO    : Gen at bus 7370	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7371	: Pg=106.97, Qg=31.59 -> Pg=69.725, Qg=21.345
% INFO    : Gen at bus 7371	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7372	: Pg=106.97, Qg=33.74 -> Pg=69.725, Qg=21.345
% INFO    : Gen at bus 7372	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7373	: Pg=106.97, Qg=54.6 -> Pg=69.725, Qg=21.345
% INFO    : Gen at bus 7373	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7374	: Pg=106.97, Qg=41.49 -> Pg=69.725, Qg=21.345
% INFO    : Gen at bus 7374	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7375	: Pg=183.15, Qg=40.55 -> Pg=119.38, Qg=36.545
% INFO    : Gen at bus 7375	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7376	: Pg=183.15, Qg=44.01 -> Pg=119.38, Qg=36.545
% INFO    : Gen at bus 7376	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7377	: Pg=183.15, Qg=56.14 -> Pg=119.38, Qg=36.545
% INFO    : Gen at bus 7377	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7378	: Pg=183.15, Qg=45.67 -> Pg=119.38, Qg=36.545
% INFO    : Gen at bus 7378	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7379	: Pg=183.15, Qg=49.27 -> Pg=119.38, Qg=36.545
% INFO    : Gen at bus 7379	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7389	: Pg=541.28, Qg=276.29 -> Pg=352.82, Qg=108.02
% INFO    : Gen at bus 7389	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7400	: Pg=71.8, Qg=-7.99 -> Pg=46.8, Qg=14.33
% INFO    : Gen at bus 7400	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7400	: Pg=71.8, Qg=-7.99 -> Pg=46.8, Qg=14.33
% INFO    : Gen at bus 7400	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7400	: Pg=71.8, Qg=-7.99 -> Pg=46.8, Qg=14.33
% INFO    : Gen at bus 7400	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7400	: Pg=71.8, Qg=-7.99 -> Pg=46.8, Qg=14.33
% INFO    : Gen at bus 7400	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7400	: Pg=143.6, Qg=-15.98 -> Pg=93.6, Qg=28.66
% INFO    : Gen at bus 7400	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7400	: Pg=445.15, Qg=-49.55 -> Pg=290.16, Qg=88.835
% INFO    : Gen at bus 7400	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7406	: Pg=62.92, Qg=32.12 -> Pg=41.015, Qg=12.56
% INFO    : Gen at bus 7406	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7406	: Pg=309.13, Qg=157.79 -> Pg=201.5, Qg=61.69
% INFO    : Gen at bus 7406	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7414	: Pg=102.11, Qg=52.12 -> Pg=66.56, Qg=20.375
% INFO    : Gen at bus 7414	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 7419	: Pg=87.95, Qg=12.12 -> Pg=57.33, Qg=17.55
% INFO    : Gen at bus 7419	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7419	: Pg=87.95, Qg=12.12 -> Pg=57.33, Qg=17.55
% INFO    : Gen at bus 7419	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=2.07, Qg=3.46 -> Pg=4.42, Qg=1.355
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=52.33, Qg=50.12 -> Pg=111.93, Qg=34.27
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=52.33, Qg=50.12 -> Pg=111.93, Qg=34.27
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=34.19, Qg=50.12 -> Pg=73.125, Qg=22.385
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=34.19, Qg=50.12 -> Pg=73.125, Qg=22.385
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=34.19, Qg=50.12 -> Pg=73.125, Qg=22.385
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=34.19, Qg=50.12 -> Pg=73.125, Qg=22.385
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=58.07, Qg=50.12 -> Pg=124.215, Qg=38.03
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=52.33, Qg=50.12 -> Pg=111.93, Qg=34.27
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=52.33, Qg=50.12 -> Pg=111.93, Qg=34.27
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7422	: Pg=52.33, Qg=50.12 -> Pg=111.93, Qg=34.27
% INFO    : Gen at bus 7422	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=30.55, Qg=27.28 -> Pg=65.34, Qg=20.0
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=39.5, Qg=27.28 -> Pg=84.5, Qg=25.87
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=39.5, Qg=27.28 -> Pg=84.5, Qg=25.87
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=30.55, Qg=27.28 -> Pg=65.34, Qg=20.0
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=30.55, Qg=27.28 -> Pg=65.34, Qg=20.0
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=30.55, Qg=27.28 -> Pg=65.34, Qg=20.0
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=30.55, Qg=27.28 -> Pg=65.34, Qg=20.0
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=30.55, Qg=27.28 -> Pg=65.34, Qg=20.0
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=22.79, Qg=27.28 -> Pg=48.75, Qg=14.92
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=0.0, Qg=0.0 -> Pg=52.65, Qg=16.12
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=3.56, Qg=5.96 -> Pg=7.605, Qg=2.33
% INFO    : Gen at bus 7428	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8024	: Pg=33.0, Qg=0.0 -> Pg=33.0, Qg=0.0
% INFO    : Gen at bus 8024	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8033	: Pg=0.0, Qg=0.0 -> Pg=152.705, Qg=46.75
% INFO    : Gen at bus 8033	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8034	: Pg=0.0, Qg=0.0 -> Pg=152.705, Qg=46.75
% INFO    : Gen at bus 8034	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8035	: Pg=0.0, Qg=0.0 -> Pg=152.705, Qg=46.75
% INFO    : Gen at bus 8035	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8036	: Pg=0.0, Qg=0.0 -> Pg=152.705, Qg=46.75
% INFO    : Gen at bus 8036	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8046	: Pg=172.19, Qg=-19.17 -> Pg=112.235, Qg=34.36
% INFO    : Gen at bus 8046	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 8047	: Pg=0.0, Qg=0.0 -> Pg=112.235, Qg=34.36
% INFO    : Gen at bus 8047	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 8048	: Pg=172.19, Qg=87.89 -> Pg=112.235, Qg=34.36
% INFO    : Gen at bus 8048	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8049	: Pg=172.19, Qg=-19.17 -> Pg=112.235, Qg=34.36
% INFO    : Gen at bus 8049	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 8050	: Pg=0.0, Qg=0.0 -> Pg=112.235, Qg=34.36
% INFO    : Gen at bus 8050	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 8051	: Pg=0.0, Qg=0.0 -> Pg=112.235, Qg=34.36
% INFO    : Gen at bus 8051	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 8060	: Pg=0.0, Qg=0.0 -> Pg=385.71, Qg=102.065
% INFO    : Gen at bus 8060	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8061	: Pg=0.0, Qg=0.0 -> Pg=385.71, Qg=102.065
% INFO    : Gen at bus 8061	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8070	: Pg=0.0, Qg=0.0 -> Pg=601.185, Qg=159.08
% INFO    : Gen at bus 8070	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8071	: Pg=922.32, Qg=-81.81 -> Pg=601.185, Qg=159.08
% INFO    : Gen at bus 8071	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8077	: Pg=234.24, Qg=11.1 -> Pg=152.685, Qg=46.745
% INFO    : Gen at bus 8077	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8078	: Pg=234.24, Qg=9.48 -> Pg=152.685, Qg=46.745
% INFO    : Gen at bus 8078	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8079	: Pg=234.24, Qg=10.99 -> Pg=152.685, Qg=46.745
% INFO    : Gen at bus 8079	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8080	: Pg=234.24, Qg=10.4 -> Pg=152.685, Qg=46.745
% INFO    : Gen at bus 8080	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8087	: Pg=0.0, Qg=0.0 -> Pg=583.505, Qg=154.405
% INFO    : Gen at bus 8087	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8088	: Pg=895.19, Qg=157.09 -> Pg=583.505, Qg=154.405
% INFO    : Gen at bus 8088	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8099	: Pg=85.5, Qg=0.0 -> Pg=85.5, Qg=0.0
% INFO    : Gen at bus 8099	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8115	: Pg=0.0, Qg=0.0 -> Pg=6.5, Qg=1.72
% INFO    : Gen at bus 8115	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8116	: Pg=0.0, Qg=0.0 -> Pg=228.605, Qg=60.49
% INFO    : Gen at bus 8116	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8117	: Pg=227.51, Qg=90.76 -> Pg=228.605, Qg=60.49
% INFO    : Gen at bus 8117	: Vg=1.04 -> Vg=1.0
% INFO    : Gen at bus 8129	: Pg=658.16, Qg=-38.52 -> Pg=429.0, Qg=113.52
% INFO    : Gen at bus 8129	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8130	: Pg=658.16, Qg=-4.37 -> Pg=429.0, Qg=113.52
% INFO    : Gen at bus 8130	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8131	: Pg=658.16, Qg=-27.45 -> Pg=429.0, Qg=113.52
% INFO    : Gen at bus 8131	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8147	: Pg=0.0, Qg=0.0 -> Pg=2.6, Qg=0.685
% INFO    : Gen at bus 8147	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8147	: Pg=0.0, Qg=0.0 -> Pg=155.545, Qg=41.16
% INFO    : Gen at bus 8147	: Vg=1.03 -> Vg=1.0
% INFO    : Gen at bus 8152	: Pg=0.0, Qg=0.0 -> Pg=14.3, Qg=4.38
% INFO    : Gen at bus 8152	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8155	: Pg=0.0, Qg=0.0 -> Pg=113.49, Qg=30.03
% INFO    : Gen at bus 8155	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8155	: Pg=174.11, Qg=-21.3 -> Pg=113.49, Qg=30.03
% INFO    : Gen at bus 8155	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8158	: Pg=0.0, Qg=0.0 -> Pg=68.25, Qg=20.895
% INFO    : Gen at bus 8158	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 8158	: Pg=0.0, Qg=0.0 -> Pg=63.83, Qg=19.54
% INFO    : Gen at bus 8158	: Vg=1.0 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
